(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  19198501,     883162]*)
(*NotebookOutlinePosition[  19204475,     883299]*)
(*  CellTagsIndexPosition[  19203460,     883275]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Solutions to Differential Equations: Special Functions", "Title",
  CellTags->"mmtag:26:special_functions"],

Cell["Visualizing a few special functions", "Subtitle"],

Cell[CellGroupData[{

Cell["Bessel's equation", "Subsection",
  CellTags->"mmtag:26:Bessels_ODE"],

Cell[CellGroupData[{

Cell["\<\
Bessel's equation is a second-order ODE having the following form, \
with the parameter \[Nu] being real and nonnegative.\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BesselODE = \(x\^2\) \(y''\)[x]\  + \ 
          x\ \(y'\)[x]\  + \((x\^2 - \[Nu]\^2)\) y[x]\  \[Equal] 0\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\((x\^2 - \[Nu]\^2)\)\ y[x]\), "+", 
        RowBox[{"x", " ", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}], "+", 
        RowBox[{\(x\^2\), " ", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}]}], "\[Equal]", 
      "0"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Bessel's equation arises in problems in heat conduction and mass diffusion \
for problems with cylindrical symmetry (and many other situations). It's \
solution is a linear combination of two ",
  StyleBox["special functions",
    FontSlant->"Italic"],
  " called ",
  StyleBox["Bessel functions of the first kind",
    FontSlant->"Italic"],
  ", ",
  StyleBox["BesselJ",
    FontWeight->"Bold"],
  " in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["Bessel functions of the second kind",
    FontSlant->"Italic"],
  ", ",
  StyleBox["BesselY",
    FontWeight->"Bold"],
  " in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".",
  StyleBox[" ",
    FontWeight->"Bold"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[BesselODE, \ y[x], x]\)], "Input",
  CellTags->{
  "mmtag:26:Bessels_function", "mmtag:26:BesselJ[]", "mmtag:26:BesselY[]"}],

Cell[BoxData[
    \({{y[x] \[Rule] 
          BesselJ[\[Nu], x]\ C[1] + BesselY[\[Nu], x]\ C[2]}}\)], "Output",
  CellTags->{
  "mmtag:26:Bessels_function", "mmtag:26:BesselJ[]", "mmtag:26:BesselY[]"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The functions ",
  StyleBox["BesselJ",
    FontWeight->"Bold"],
  " and ",
  StyleBox["BesselY",
    FontWeight->"Bold"],
  " can be evaluated numerically and of course ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has this capability built-in."
}], "Subsubsection"],

Cell[BoxData[
    \(MyPlotStyle[HowMany_Integer]\  := \ 
      Table[{Hue[0.66*i/HowMany], Thickness[0.01]}, {i, 0, 
          HowMany}]\)], "Input",
  CellTags->"mmtag:26:MyPlotStyle[]__example_graphics_option_function"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{BesselJ[0, x], \ BesselY[0, x]}, {x, 0, 20}, \ 
      PlotStyle \[Rule] MyPlotStyle[2]]\)], "Input",
  CellTags->"mmtag:26:Bessels_function__visualizing"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.313363 0.289956 [
[.2619 .30086 -7 -20 ]
[.2619 .30086 7 0 ]
[.5 .30086 -12 -20 ]
[.5 .30086 12 0 ]
[.7381 .30086 -12 -20 ]
[.7381 .30086 12 0 ]
[.97619 .30086 -12 -20 ]
[.97619 .30086 12 0 ]
[.01131 .02341 -26.9375 -10 ]
[.01131 .02341 0 10 ]
[.01131 .16838 -41.9375 -10 ]
[.01131 .16838 0 10 ]
[.01131 .45834 -29 -10 ]
[.01131 .45834 0 10 ]
[.01131 .60332 -14 -10 ]
[.01131 .60332 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .31336 m
.2619 .31961 L
s
gsave
.2619 .30086 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .31336 m
.5 .31961 L
s
gsave
.5 .30086 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7381 .31336 m
.7381 .31961 L
s
gsave
.7381 .30086 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.97619 .31336 m
.97619 .31961 L
s
gsave
.97619 .30086 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .31336 m
.07143 .31711 L
s
.11905 .31336 m
.11905 .31711 L
s
.16667 .31336 m
.16667 .31711 L
s
.21429 .31336 m
.21429 .31711 L
s
.30952 .31336 m
.30952 .31711 L
s
.35714 .31336 m
.35714 .31711 L
s
.40476 .31336 m
.40476 .31711 L
s
.45238 .31336 m
.45238 .31711 L
s
.54762 .31336 m
.54762 .31711 L
s
.59524 .31336 m
.59524 .31711 L
s
.64286 .31336 m
.64286 .31711 L
s
.69048 .31336 m
.69048 .31711 L
s
.78571 .31336 m
.78571 .31711 L
s
.83333 .31336 m
.83333 .31711 L
s
.88095 .31336 m
.88095 .31711 L
s
.92857 .31336 m
.92857 .31711 L
s
.01 w
0 .31336 m
1 .31336 L
s
.25 Mabswid
.02381 .02341 m
.03006 .02341 L
s
gsave
.01131 .02341 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .16838 m
.03006 .16838 L
s
gsave
.01131 .16838 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .45834 m
.03006 .45834 L
s
gsave
.01131 .45834 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .60332 m
.03006 .60332 L
s
gsave
.01131 .60332 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .0524 m
.02756 .0524 L
s
.02381 .0814 m
.02756 .0814 L
s
.02381 .11039 m
.02756 .11039 L
s
.02381 .13939 m
.02756 .13939 L
s
.02381 .19738 m
.02756 .19738 L
s
.02381 .22638 m
.02756 .22638 L
s
.02381 .25537 m
.02756 .25537 L
s
.02381 .28437 m
.02756 .28437 L
s
.02381 .34236 m
.02756 .34236 L
s
.02381 .37135 m
.02756 .37135 L
s
.02381 .40035 m
.02756 .40035 L
s
.02381 .42935 m
.02756 .42935 L
s
.02381 .48734 m
.02756 .48734 L
s
.02381 .51633 m
.02756 .51633 L
s
.02381 .54533 m
.02756 .54533 L
s
.02381 .57432 m
.02756 .57432 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02381 .60332 m
.02499 .60327 L
.02605 .60316 L
.02729 .60293 L
.02846 .60263 L
.03053 .60188 L
.03279 .60075 L
.03527 .59914 L
.0379 .59701 L
.04262 .59212 L
.05205 .57837 L
.06244 .55753 L
.0842 .49794 L
.10458 .4294 L
.14335 .29784 L
.15346 .26919 L
.16449 .24257 L
.1749 .22261 L
.18458 .20901 L
.18965 .20385 L
.19232 .20169 L
.19514 .19982 L
.19762 .19854 L
.19892 .19799 L
.20033 .1975 L
.20162 .19714 L
.2028 .19689 L
.20398 .19672 L
.2051 .19662 L
.20617 .19658 L
.20734 .19661 L
.20857 .19672 L
.20973 .19689 L
.2108 .1971 L
.21179 .19736 L
.21401 .1981 L
.21627 .1991 L
.21873 .20047 L
.22371 .20409 L
.22899 .20913 L
.23398 .21493 L
.24332 .22822 L
.26427 .26662 L
.30273 .34506 L
.32261 .37671 L
.33263 .38811 L
.33832 .393 L
.34109 .39493 L
.34365 .39647 L
.34626 .39777 L
Mistroke
.34863 .39873 L
.35126 .39954 L
.3527 .39987 L
.35406 .4001 L
.35526 .40025 L
.35653 .40035 L
.35762 .40038 L
.35881 .40037 L
.36009 .40029 L
.36081 .40022 L
.36146 .40014 L
.36274 .39993 L
.36394 .39968 L
.36618 .39908 L
.36856 .39823 L
.37282 .3962 L
.37741 .3933 L
.38248 .3893 L
.3926 .37898 L
.40186 .3672 L
.42273 .33519 L
.4433 .30128 L
.46241 .27305 L
.47191 .26158 L
.48087 .25284 L
.48583 .24897 L
.4912 .24561 L
.49357 .24441 L
.49608 .24334 L
.49823 .24257 L
.50057 .24191 L
.50189 .24161 L
.50311 .24138 L
.50427 .24121 L
.50552 .24108 L
.50662 .241 L
.50766 .24096 L
.5088 .24096 L
.51003 .24101 L
.51126 .2411 L
.51196 .24118 L
.51261 .24126 L
.51403 .24149 L
.51532 .24175 L
.51767 .24236 L
.52018 .2432 L
.5247 .24518 L
.5296 .24801 L
.53851 .2548 L
.55836 .27632 L
Mistroke
.57939 .30496 L
.59917 .33247 L
.61725 .35411 L
.62721 .36346 L
.63667 .3702 L
.64185 .37292 L
.64666 .37479 L
.64943 .37558 L
.65194 .37612 L
.65333 .37634 L
.65406 .37643 L
.65483 .37651 L
.65551 .37657 L
.65625 .37662 L
.65756 .37667 L
.65886 .37667 L
.66007 .37663 L
.6607 .3766 L
.6614 .37654 L
.6628 .37639 L
.66404 .37622 L
.66537 .37598 L
.66777 .37543 L
.67014 .37473 L
.67263 .37384 L
.67708 .37185 L
.68707 .36561 L
.698 .3563 L
.73858 .30863 L
.75733 .2865 L
.7672 .27652 L
.77765 .26782 L
.78294 .26426 L
.78876 .26108 L
.79132 .25993 L
.79406 .25888 L
.79663 .25806 L
.79901 .25744 L
.8016 .25693 L
.80296 .25673 L
.80366 .25665 L
.80441 .25657 L
.80514 .25651 L
.8058 .25646 L
.80711 .25641 L
.80829 .2564 L
.80954 .25642 L
.81069 .25648 L
.81192 .25658 L
.81308 .2567 L
Mistroke
.81413 .25685 L
.81672 .25732 L
.81916 .25791 L
.82377 .25943 L
.82885 .26166 L
.83913 .2679 L
.84865 .27549 L
.85757 .28389 L
.89633 .32683 L
.91603 .34637 L
.92718 .35496 L
.93251 .35826 L
.93754 .36084 L
.94225 .36276 L
.94473 .36358 L
.94735 .36429 L
.94956 .36477 L
.95073 .36498 L
.95198 .36517 L
.95313 .36531 L
.95418 .36541 L
.95524 .36549 L
.95624 .36554 L
.95739 .36557 L
.95865 .36557 L
.95997 .36552 L
.9612 .36545 L
.96236 .36534 L
.96341 .36522 L
.9658 .36486 L
.96821 .36436 L
.97086 .36366 L
.97619 .36179 L
Mfstroke
.02 1 0 r
.03345 0 m
.0379 .07651 L
.04262 .13503 L
.05224 .22284 L
.06244 .29139 L
.0728 .34536 L
.0825 .38522 L
.09313 .41879 L
.09911 .43336 L
.10458 .44411 L
.10935 .45155 L
.11196 .45489 L
.11442 .45756 L
.11673 .45964 L
.11922 .46146 L
.12148 .46272 L
.12357 .46357 L
.12476 .46391 L
.12605 .46418 L
.12726 .46432 L
.12837 .46437 L
.12967 .46432 L
.1304 .46424 L
.13108 .46414 L
.13232 .46387 L
.13364 .46348 L
.13625 .46239 L
.1387 .46098 L
.14429 .45645 L
.14898 .45131 L
.15412 .44441 L
.16447 .42689 L
.18298 .38657 L
.20423 .33341 L
.22354 .28679 L
.23317 .26632 L
.24362 .24731 L
.25349 .23299 L
.26258 .22331 L
.26726 .21971 L
.26983 .21814 L
.27228 .21692 L
.27454 .21603 L
.27574 .21565 L
.27702 .21531 L
.27819 .21507 L
.27926 .2149 L
.28034 .21478 L
.28135 .21471 L
.28255 .21469 L
Mistroke
.28386 .21473 L
.28452 .21479 L
.28524 .21486 L
.28652 .21506 L
.28779 .21532 L
.289 .21563 L
.29127 .21638 L
.29394 .21754 L
.2964 .21887 L
.30199 .22275 L
.31164 .23212 L
.32069 .24362 L
.3413 .2769 L
.38004 .34594 L
.39045 .3614 L
.40012 .37338 L
.41021 .38295 L
.41555 .38668 L
.41831 .38824 L
.42124 .3896 L
.42378 .39055 L
.42513 .39096 L
.42658 .39132 L
.42791 .3916 L
.42913 .39179 L
.43035 .39194 L
.4315 .39203 L
.43214 .39206 L
.43284 .39207 L
.43358 .39207 L
.43427 .39205 L
.4355 .39198 L
.43619 .39191 L
.43683 .39184 L
.43817 .39164 L
.43965 .39134 L
.44262 .39053 L
.44526 .38956 L
.44767 .38848 L
.45306 .38539 L
.46279 .37765 L
.47275 .36714 L
.48195 .35559 L
.50273 .32535 L
.52307 .29484 L
.53301 .28125 L
.54211 .27025 L
.55083 .26133 L
.56035 .25374 L
.56556 .25063 L
Mistroke
.5681 .24939 L
.57041 .24843 L
.57263 .24765 L
.57503 .24698 L
.57635 .24668 L
.57757 .24645 L
.57872 .24627 L
.57996 .24612 L
.58123 .24602 L
.58242 .24597 L
.58359 .24596 L
.58467 .24599 L
.58583 .24605 L
.58711 .24617 L
.58845 .24635 L
.58971 .24657 L
.59199 .24707 L
.59408 .24767 L
.5988 .24947 L
.60361 .25193 L
.60887 .25531 L
.61947 .26411 L
.63909 .28593 L
.66005 .31336 L
.67998 .33869 L
.69047 .35023 L
.70157 .36031 L
.71148 .36706 L
.71712 .36984 L
.71982 .37088 L
.72238 .3717 L
.7247 .37229 L
.72592 .37255 L
.72722 .37278 L
.72842 .37295 L
.72951 .37307 L
.73061 .37316 L
.73164 .37322 L
.73285 .37325 L
.73413 .37324 L
.73522 .3732 L
.73641 .37312 L
.7377 .37299 L
.73908 .3728 L
.74157 .37234 L
.74414 .37169 L
.74688 .37082 L
.75178 .3688 L
.75705 .36598 L
.76286 .36216 L
Mistroke
.783 .34404 L
.82328 .29733 L
.84181 .27839 L
.8523 .27 L
.86204 .26417 L
.8674 .26185 L
.87226 .26032 L
.87496 .25971 L
.87647 .25944 L
.87787 .25925 L
.8791 .25911 L
.8798 .25905 L
.88044 .25901 L
.88112 .25897 L
.88185 .25895 L
.88316 .25893 L
.88441 .25895 L
.88573 .25902 L
.88685 .25911 L
.8881 .25924 L
.88943 .25942 L
.89087 .25967 L
.89348 .26023 L
.89857 .26179 L
.90325 .26373 L
.91305 .26928 L
.92216 .27606 L
.94286 .29574 L
.97619 .33153 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00;_oonfX5o`000?oooo]ZoooonfX?oookJP00;_oonfX5
o`000?oooo]ZoooonfX?oookJP00;_oonfX5o`0000Go1Ol0oooonf[ooookJP[ooo]Z000^oookJPGo
00001Ol5o`3ooookJ_oooo]Z2_oonfX002kooo]Z1Ol00005o`Go0?oooo]ZoooonfX:oookJP00;_oo
nfX5o`0000Go1Ol0oooonf[ooookJP[ooo]Z000^oookJPGo00001Ol5o`3ooookJ_oooo]Z2_oonfX0
02kooo]Z1Ol00005o`Go0?oooo]ZoooonfX:oookJP00;_oonfX5o`0000Ko1Ol0oooonf[ooookJPWo
oo]Z000^oookJPGo00001_l5o`3ooookJ_oooo]Z2OoonfX002kooo]Z1Ol00006o`Go0?oooo]Zoooo
nfX9oookJP008_oonfX3o`00O`Wooo]Z1Ol00006o`Go0?oooo]ZoooonfX9oookJP008_oonfX3o`00
O`Wooo]Z1Ol000000ooonf[o1Ol0o`Go0003o`Go0?oooo]ZoooonfX9oookJP008_oonfX3o`00O`Wo
oo]Z1Ol000000ooonf[o1Ol0o`Go0003o`Go0?oooo]ZoooonfX9oookJP004_oonfX:o`00O`Kooo]Z
0ol007l9oookJPGo000000?ooo]Zo`Go0?l5o`000ol5o`3ooookJ_oooo]Z2OoonfX001;ooo]Z2_l0
07l6oookJP?o001o2OoonfX6o`0000Go1Ol0oooonf[ooookJPWooo]Z000RoookJP?o001o2OoonfX5
o`000003oookJ_l5o`3o1Ol000?o1Ol0oooonf[ooookJPWooo]Z000RoookJP?o001o2OoonfX5o`00
0003oookJ_l5o`3o1Ol000?o1Ol0oooonf[ooookJPWooo]Z000RoookJP?o001o2OoonfX5o`000003
oookJ_l5o`3o1Ol000?o1Ol0oooonf[ooookJPWooo]Z000RoookJP?o001o2OoonfX5o`000003oook
J_l5o`3o1Ol000?o1Ol0oooonf[ooookJPWooo]Z000OoookJPKo001o2OoonfX5o`000003oookJ_l5
o`3o1Ol000?o1Ol0oooonf[ooookJPWooo]Z000OoookJPKo001o2OoonfX5o`000003oookJ_l5o`3o
1Ol000Co1Ol0oooonf[ooookJPSooo]Z000QoookJPCo001o2OoonfX5o`000003oookJ_l5o`3o1Ol0
00Co1Ol0oooonf[ooookJPSooo]Z000RoookJP?o001o2OoonfX5o`000003oookJ_l5o`3o1Ol000Co
1Ol0oooonf[ooookJPSooo]Z000^oookJPGo000000?ooo]Zo`Go0?l5o`001?l5o`3ooookJ_oooo]Z
2?oonfX002kooo]Z1Ol00002oookJPGo1Ol0oooonf[ooookJPSooo]Z000^oookJPGo00000_oonfX5
o`Go0?oooo]ZoooonfX8oookJP00;_oonfX5o`0000;ooo]Z1Ol5o`3ooookJ_oooo]Z2?oonfX002ko
oo]Z1Ol00002oookJPGo1Ol0oooonf[ooookJPSooo]Z000^oookJPGo00000_oonfX5o`Go0?oooo]Z
oooonfX8oookJP00;_oonfX5o`0000;ooo]Z1Ol5o`3ooookJ_oooo]Z2?oonfX002kooo]Z1Ol00002
oookJPGo1Ol0oooonf[ooookJPSooo]Z000^oookJPGo00000_oonfX5o`Go0?oooo]ZoooonfX8oook
JP00;_oonfX5o`0000;ooo]Z1Ol5o`3ooookJ_oooo]Z2?oonfX002kooo]Z1Ol00002oookJPGo1Ol0
oooonf[ooookJPSooo]Z000^oookJPGo00000_oonfX6o`Go0?oooo]ZoooonfX7oookJP00;_oonfX5
o`0000;ooo]Z1_l5o`3ooookJ_oooo]Z1ooonfX002kooo]Z1Ol00002oookJPKo1Ol0oooonf[ooook
JPOooo]Z000^oookJPGo00000_oonfX6o`Go0?oooo]ZoooonfX7oookJP00;_oonfX5o`0000?ooo]Z
1Ol5o`3ooookJ_oooo]Z1ooonfX002kooo]Z1Ol00003oookJPGo1Ol0oooonf[ooookJPOooo]Z000^
oookJPGo00000ooonfX5o`Go0?oooo]ZoooonfX7oookJP00;_oonfX5o`0000?ooo]Z1Ol5o`3ooook
J_oooo]Z1ooonfX002kooo]Z1Ol00003oookJPGo1Ol0oooonf[ooookJPOooo]Z000^oookJPGo0000
0ooonfX5o`Go0?oooo]ZoooonfX7oookJP00;_oonfX5o`0000?ooo]Z1Ol5o`3ooookJ_oooo]Z1ooo
nfX002kooo]Z1Ol00003oookJPGo1Ol0oooonf[ooookJPOooo]Z000^oookJPGo00000ooonfX5o`Go
0?oooo]ZoooonfX7oookJP00;_oonfX5o`0000?ooo]Z1Ol5o`3ooookJ_oooo]Z1ooonfX002kooo]Z
1Ol00003oookJPGo1Ol0oooonf[ooookJPOooo]Z000^oookJPGo00000ooonfX6o`Go0?oooo]Zoooo
nfX6oookJP00;_oonfX5o`0000?ooo]Z1_l5o`3ooookJ_oooo]Z1_oonfX002kooo]Z1Ol00003oook
JPKo1Ol0oooonf[ooookJPKooo]Z000^oookJPGo00000ooonfX6o`Go0?oooo]ZoooonfX6oookJP00
;_oonfX5o`0000Cooo]Z1Ol5o`3ooookJ_oooo]Z1_oonfX002kooo]Z1Ol00004oookJPGo1Ol0oooo
nf[ooookJPKooo]Z000^oookJPGo00001?oonfX5o`Go0?oooo]ZoooonfX6oookJP00;_oonfX5o`00
00Cooo]Z1Ol5o`3ooookJ_oooo]Z1_oonfX002kooo]Z1Ol00004oookJPGo1Ol0oooonf[ooookJPKo
oo]Z000^oookJPGo00001?oonfX5o`Go0?oooo]ZoooonfX6oookJP00;_oonfX5o`0000Cooo]Z1Ol5
o`3ooookJ_oooo]Z1_oonfX002kooo]Z1Ol00004oookJPGo1Ol0oooonf[ooookJPKooo]Z000^oook
JPGo00001?oonfX5o`Go0?oooo]ZoooonfX6oookJP00;_oonfX5o`0000Cooo]Z1Ol5o`3ooookJ_oo
oo]Z1_oonfX002kooo]Z1Ol00004oookJPGo1Ol0oooonf[ooookJPKooo]Z000^oookJPGo00001?oo
nfX5o`Go0?oooo]ZoooonfX6oookJP00;_oonfX5o`0000Cooo]Z1_l5o`3ooookJ_oooo]Z1OoonfX0
02kooo]Z1Ol00004oookJPKo1Ol0oooonf[ooookJPGooo]Z000^oookJPGo00001?oonfX6o`Go0?oo
oo]ZoooonfX5oookJP00;_oonfX5o`0000Cooo]Z1_l5o`3ooookJ_oooo]Z1OoonfX002kooo]Z1Ol0
0005oookJPGo1Ol0oooonf[ooookJPGooo]Z000^oookJPGo00001OoonfX5o`Go0?oooo]ZoooonfX5
oookJP00;_oonfX5o`0000Gooo]Z1Ol5o`3ooookJ_oooo]Z1OoonfX002kooo]Z1Ol00005oookJPGo
1Ol0oooonf[ooookJPGooo]Z000^oookJPGo00001OoonfX5o`Go0?oooo]ZoooonfX5oookJP00;_oo
nfX5o`0000Gooo]Z1Ol5o`3ooookJ_oooo]Z1OoonfX002kooo]Z1Ol00005oookJPGo1Ol0oooonf[o
oookJPGooo]Z000^oookJPGo00001OoonfX5o`Go0?oooo]ZoooonfX5oookJP00;_oonfX5o`0000Go
oo]Z1Ol5o`3ooookJ_oooo]Z1OoonfX002kooo]Z1Ol00005oookJPKo1Ol0oooonf[ooookJPCooo]Z
000^oookJPGo00001OoonfX6o`Go0?oooo]ZoooonfX4oookJP00;_oonfX5o`0000Gooo]Z1_l5o`3o
oookJ_oooo]Z1?oonfX002kooo]Z1Ol00005oookJPKo1Ol0oooonf[ooookJPCooo]Z000^oookJPGo
00001_oonfX5o`Go0?oooo]ZoooonfX4oookJP00;_oonfX5o`0000Kooo]Z1Ol5o`3ooookJ_oooo]Z
1?oonfX002kooo]Z1Ol00006oookJPGo1Ol0oooonf[ooookJPCooo]Z000^oookJPGo00001_oonfX5
o`Go0?oooo]ZoooonfX4oookJP00;_oonfX5o`0000Kooo]Z1Ol5o`3ooookJ_oooo]Z1?oonfX002ko
oo]Z1Ol00006oookJPKo1Ol0oooonf[ooookJP?ooo]Z000AoookJPGo001o1?oonfX3o`00O`?ooo]Z
1Ol007l9oookJPGo00001_oonfX6o`Go0?oooo]ZoooonfX3oookJP004?oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX5o`0000Kooo]Z1_l5o`3ooookJ_oooo]Z0ooonfX0013ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00
Ool007l8oookJPGo00001_oonfX6o`Go0?oooo]ZoooonfX3oookJP000ooonfX:o`00O`;ooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo00001ooonfX5o`Go0?oooo]Zoooo
nfX3oookJP000ooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1ol00005
oookJPGo1Ol0oooonf[ooookJP?ooo]Z000?oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oook
JPGo00001ooonfX5o`Go0?oooo]ZoooonfX3oookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o
001o0_oonfX4o`00O`Oooo]Z1Ol00007oookJPGo1Ol0oooonf[ooookJP?ooo]Z000?oookJP?o001o
0ooonfX3o`00O`Oooo]Z1ol007l8oookJPGo00001ooonfX5o`Go0?oooo]ZoooonfX3oookJP003ooo
nfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2OoonfX5o`0000Oooo]Z1_l5o`3ooookJ_oooo]Z0_oo
nfX000oooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`gooo]Z1Ol00007oookJPKo1Ol0oooonf[o
oookJP;ooo]Z000@oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`gooo]Z1Ol00007
oookJPKo1Ol0oooonf[ooookJP;ooo]Z000@oookJPOo001o2OoonfX7o`00O`Oooo]Z1Ol00007oook
JPKo1Ol0oooonf[ooookJP;ooo]Z000AoookJPGo001o2_oonfX7o`00O`Oooo]Z1Ol00008oookJPGo
1Ol0oooonf[ooookJP;ooo]Z000^oookJPGo00002?oonfX5o`Go0?oooo]ZoooonfX2oookJP00;_oo
nfX5o`0000Sooo]Z1Ol5o`3ooookJ_oooo]Z0_oonfX002kooo]Z1Ol00008oookJPGo1Ol0oooonf[o
oookJP;ooo]Z000^oookJPGo00002?oonfX5o`Go0?oooo]ZoooonfX2oookJP00;_oonfX5o`0000So
oo]Z1Ol5o`1<oookJPcoo`00oooonfZYoookJP00;_oonfX5o`0000Sooo]Z1_l5o`19oookJQ7oo`00
oooonfZVoookJP00;_oonfX5o`0000Sooo]Z1_l5o`18oookJQ?oo`00oooonfZUoookJP00;_oonfX5
o`0000Sooo]Z1_l5o`17oookJQGoo`00oooonfZToookJP00;_oonfX5o`0000Sooo]Z1_l5o`15oook
JQWoo`00oooonfZRoookJP00;_oonfX5o`0000Wooo]Z1Ol5o`14oookJP_oo`001?oonfX<ool00?oo
oo]ZXOoonfX002kooo]Z1Ol00009oookJPGo1Ol0@ooonfX:ool000Wooo]Z2_oo003ooookJZ3ooo]Z
000^oookJPGo00002OoonfX5o`Go04?ooo]Z2Ooo000;oookJPWoo`00oooonfZPoookJP00;_oonfX5
o`0000Wooo]Z1Ol5o`12oookJPWoo`003OoonfX9ool00?oooo]ZWooonfX002kooo]Z1Ol00009oook
JPGo1Ol0@OoonfX8ool0017ooo]Z2?oo000EoookJPOo1Ol0oooonfZ2oookJP00;_oonfX5o`0000Wo
oo]Z1_l5o`10oookJPOoo`004ooonfX8ool0013ooo]Z3ol5o`3ooookJWkooo]Z000^oookJPGo0000
2OoonfX6o`Go03oooo]Z2?oo000CoookJPSoo`003_oonfXBo`Go0?oooo]ZOOoonfX002kooo]Z1Ol0
0009oookJPKo1Ol0?ooonfX7ool001Gooo]Z2?oo000;oookJQKo1Ol0oooonfYkoookJP00;_oonfX5
o`0000Wooo]Z1_l5o`0noookJPOoo`005ooonfX8ool000Wooo]Z6?l5o`3ooookJW[ooo]Z000^oook
JPGo00002_oonfX5o`Go03gooo]Z2?oo000HoookJPSoo`001ooonfXKo`Go0?oooo]ZN?oonfX002ko
oo]Z1Ol0000:oookJPGo1Ol0?OoonfX7ool001Wooo]Z2?oo0006oookJP_o1Ol01ooonfX;o`Go0?oo
oo]ZMooonfX002kooo]Z1Ol0000:oookJPGo1Ol0??oonfX8ool001[ooo]Z2?oo0004oookJP[o1Ol0
2_oonfX;o`Go0?oooo]ZM_oonfX002kooo]Z1Ol0000:oookJPGo1Ol0??oonfX7ool001cooo]Z2?oo
0002oookJPWo1Ol03_oonfX:o`Go0?oooo]ZMOoonfX002kooo]Z1Ol0000:oookJPKo1Ol0>_oonfX7
ool001kooo]Z1ooo00000ooonf[o1Ol0o`Go0007o`Go013ooo]Z2_l5o`3ooookJWCooo]Z000^oook
JPGo00002_oonfX6o`Go03[ooo]Z1ooo000NoookJPOoo`002Ol5o`0CoookJPWo1Ol0oooonfYcoook
JP00;_oonfX5o`0000[ooo]Z1_l5o`0ioookJPOoo`008?oonfX6ool000So1Ol05OoonfX8o`Go0?oo
oo]ZLooonfX002kooo]Z1Ol0000:oookJPKo1Ol0>OoonfX7ool0027ooo]Z1?oo0008o`Go01Oooo]Z
2?l5o`3ooookJW;ooo]Z000^oookJPGo00002ooonfX5o`Go03Sooo]Z1ooo000RoookJP?oo`002?l5
o`0IoookJPSo1Ol0oooonfYaoookJP00;_oonfX5o`0000_ooo]Z1Ol5o`0hoookJPOoo`008ooonfX2
ool000Oo1Ol06ooonfX7o`Go0?oooo]ZLOoonfX002kooo]Z1Ol0000;oookJPKo1Ol0=_oonfX7ool0
02Cooo]Z00?oo`00o`Go0?l5o`001_l5o`0KoookJPSo1Ol0FooonfX@ool00?oooo]Z1OoonfX002ko
oo]Z1Ol0000;oookJPKo1Ol0=_oonfX7ool002Gooo]Z1ol5o`0MoookJPSo1Ol0F?oonfXEool00?oo
oo]Z0_oonfX002kooo]Z1Ol0000;oookJPKo1Ol0=OoonfX7ool002Gooo]Z1ol5o`02ool001gooo]Z
1ol5o`1FoookJQWoo`005_oonfX;o`Go0=kooo]Z000^oookJPGo00002ooonfX6o`Go03Gooo]Z1ooo
000ToookJPSo1Ol00_oo000MoookJPSo1Ol0E?oonfXLool0017ooo]Z4ol5o`3IoookJP00;_oonfX5
o`0000cooo]Z1Ol5o`0eoookJPKoo`009OoonfX7o`Go00Coo`007OoonfX8o`Go057ooo]Z7ooo000>
oookJQOo1Ol0eooonfX002kooo]Z1Ol0000<oookJPGo1Ol0=?oonfX7ool002Cooo]Z2?l5o`04ool0
01kooo]Z1ol5o`1@oookJPcoo`002?oonfX=ool000_ooo]Z6ol5o`3EoookJP00;_oonfX5o`0000co
oo]Z1_l5o`0coookJPKoo`009?oonfX8o`Go00Koo`007OoonfX8o`Go04kooo]Z2ooo000=oookJP_o
o`001ooonfXOo`Go0=Cooo]Z000^oookJPGo00003?oonfX6o`Go03;ooo]Z1ooo000ToookJPOo1Ol0
1ooo000NoookJPOo1Ol0C_oonfX9ool0017ooo]Z2_oo0005oookJQ3o1Ol00_oonfX@o`Go0=;ooo]Z
000^oookJPGo00003?oonfX6o`Go03;ooo]Z1ooo000SoookJPSo1Ol000?ooo]Zool00?oo00001Ooo
000NoookJPOo1Ol0C?oonfX9ool001Cooo]Z2Ooo0003oookJPgo1Ol02ooonfX<o`Go05oooo]Z3ooo
001SoookJP00;_oonfX5o`0000cooo]Z1_l5o`0boookJPKoo`009?oonfX7o`Go00;ooo]Z2?oo000M
oookJPSo1Ol0B_oonfX8ool001Oooo]Z2Ooo00000ooonf[o1Ol0o`Go000:o`Go00oooo]Z2ol5o`1K
oookJQKoo`005ooonfX<o`Go03cooo]Z000^oookJPGo00003OoonfX5o`Go037ooo]Z1ooo000Soook
JPOo1Ol01?oonfX7ool001kooo]Z1ol5o`19oookJPSoo`006OoonfX8ool000_o1Ol04ooonfX:o`Go
05Kooo]Z6ooo000BoookJQ?o1Ol0>OoonfX002kooo]Z1Ol0000=oookJPGo1Ol0<OoonfX6ool002?o
oo]Z2?l5o`04oookJPSoo`007OoonfX8o`Go04Oooo]Z2Ooo000JoookJPKoo`002Ol5o`0GoookJP[o
1Ol0E?oonfXNool000kooo]Z6?l5o`0foookJP00;_oonfX5o`0000gooo]Z1Ol5o`0`oookJPOoo`00
8ooonfX7o`Go00Kooo]Z1ooo000NoookJPOo1Ol0A_oonfX9ool001cooo]Z1?oo0009o`Go01[ooo]Z
2Ol5o`1BoookJR7oo`002OoonfXMo`Go03Cooo]Z000^oookJPGo00003OoonfX6o`Go02oooo]Z1ooo
000RoookJPSo1Ol01ooonfX7ool001kooo]Z1ol5o`14oookJPWoo`007_oonfX2ool000Wo1Ol07?oo
nfX8o`Go057ooo]Z3_oo0007oookJPooo`001OoonfXQo`Go03;ooo]Z000^oookJPGo00003OoonfX6
o`Go02oooo]Z1_oo000SoookJPOo1Ol02?oonfX7ool001kooo]Z2?l5o`12oookJPWoo`008?oonfX9
o`Go01kooo]Z2?l5o`1>oookJPgoo`003_oonfX=ool000;ooo]Z4?l5o`03oookJQ3o1Ol0<OoonfX0
02kooo]Z1Ol0000=oookJPKo1Ol0;_oonfX7ool002;ooo]Z1ol5o`0:oookJPOoo`007_oonfX7o`Go
047ooo]Z2Ooo000PoookJPWo1Ol00_oo000NoookJPSo1Ol0C?oonfX:ool001?ooo]Z3?oo000>o`Go
00_ooo]Z3_l5o`0_oookJP00;_oonfX5o`0000gooo]Z1_l5o`0^oookJPKoo`008ooonfX7o`Go00[o
oo]Z1ooo000NoookJPSo1Ol0?ooonfX9ool0027ooo]Z2?l5o`04ool001kooo]Z2?l5o`1:oookJP[o
o`005_oonfX9ool000go1Ol04?oonfX=o`Go02gooo]Z000^oookJPGo00003_oonfX5o`Go02gooo]Z
1ooo000RoookJPOo1Ol03?oonfX7ool001kooo]Z1ol5o`0noookJPWoo`008OoonfX8o`Go00Koo`00
7OoonfX9o`Go04Sooo]Z2_oo000IoookJPKoo`002ol5o`0EoookJPco1Ol0;?oonfX002kooo]Z1Ol0
000>oookJPGo1Ol0;OoonfX7ool002;ooo]Z1ol5o`0<oookJPOoo`007ooonfX7o`Go03gooo]Z2?oo
000QoookJPSo1Ol02?oo000MoookJPWo1Ol0A_oonfX:ool001cooo]Z0ooo000:o`Go01Wooo]Z2ol5
o`0[oookJP00;_oonfX5o`0000kooo]Z1_l5o`0/oookJPKoo`008_oonfX7o`Go00kooo]Z1ooo000N
oookJPSo1Ol0>ooonfX8ool0027ooo]Z2?l5o`000ooonf[oo`00ool00006ool001kooo]Z2?l5o`15
oookJPWoo`008?oonfX:o`Go01_ooo]Z2ol5o`0ZoookJP00;_oonfX5o`0000kooo]Z1_l5o`0[oook
JPOoo`008_oonfX7o`Go00_ooo]Z0ol007l7ool001oooo]Z1ol5o`0joookJPSoo`002ooonfX3o`00
O`Gooo]Z1Ol007l9oookJPWo1Ol00_oonfX8ool001kooo]Z2?l5o`0`oookJP?o001o1OoonfX5o`00
O`Kooo]Z2Ooo000PoookJPWo1Ol000?oo`00oookJ_oonfX07?oonfX:o`Go00kooo]Z2Ol007l3oook
JPGo001o2_oonfX002kooo]Z1Ol0000>oookJPKo1Ol0:ooonfX6ool002?ooo]Z1_l5o`0;oookJPGo
001o1ooo000NoookJPSo1Ol0>OoonfX7ool000cooo]Z0ol007l4oookJPOo001o1ooonfX9o`Go00Co
oo]Z2?oo000NoookJPSo1Ol0;ooonfX3o`00O`Cooo]Z1ol007l4oookJPWoo`008?oonfX9o`Go00?o
o`007ooonfX9o`Go00gooo]Z2Ol007l2oookJPOo001o2OoonfX002kooo]Z1Ol0000>oookJPKo1Ol0
:_oonfX7ool002;ooo]Z1ol5o`0:oookJPCo001o00?ooo]Zo`00Oooo00001_oo000OoookJPOo1Ol0
>?oonfX8ool000cooo]Z0ol007l4oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX8o`Go00Ko
oo]Z1ooo000OoookJPSo1Ol0;_oonfX3o`00O`?ooo]Z1?l007l01?oonf[o001oo`00Ool007l3oook
JPWoo`008?oonfX9o`Go00Goo`007ooonfX9o`Go00cooo]Z1?l007l7oookJP?o001o00Cooo]Zo`00
Ool007oo001o2OoonfX002kooo]Z1Ol0000?oookJPGo1Ol0:_oonfX7ool002;ooo]Z1_l5o`0;oook
JP?o001o0ooonfX00ol007ooo`00ool00005ool001oooo]Z1ol5o`0foookJPSoo`003OoonfX3o`00
O`?ooo]Z0ol007l3oookJP?o001o1OoonfX8o`Go00Oooo]Z2?oo000NoookJPWo1Ol0;OoonfX3o`00
O`?ooo]Z0ol007l3oookJP?o001o00?ooo]Zool00?oo00001ooo000PoookJPWo1Ol01ooo000Ooook
JPWo1Ol03?oonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o2?oonfX002kooo]Z1Ol0000?oookJPGo
1Ol0:_oonfX6ool002;ooo]Z1ol5o`0AoookJP03o`00Oooo003oo`0000Goo`007ooonfX8o`Go03Go
oo]Z1ooo000>oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l4oookJPSo1Ol02OoonfX8ool001ko
oo]Z2Ol5o`0/oookJP?o001o2OoonfX3o`00O`Woo`008?oonfX9o`Go00Soo`008?oonfX9o`Go00co
oo]Z1Ol007l3oookJP?o001o0ooonfX3o`00O`Sooo]Z000^oookJPGo00003ooonfX6o`Go02Sooo]Z
1ooo000RoookJPOo1Ol04OoonfX2o`00O`Ooo`007ooonfX7o`Go03Cooo]Z2?oo000>oookJP?o001o
0ooonfX3o`00O`?ooo]Z0ol007l3oookJPSo1Ol02ooonfX7ool001oooo]Z2?l5o`0/oookJP?o001o
2OoonfX3o`00O`Soo`008?oonfX9o`Go00;ooo]Z2?oo000PoookJPWo1Ol03OoonfX4o`00O`;ooo]Z
0ol007l3oookJP?o001o2?oonfX002kooo]Z1Ol0000?oookJPKo1Ol0:?oonfX6ool002;ooo]Z1ol5
o`0=oookJP;o001o0_oonfX3o`00O`Ooo`007ooonfX8o`Go03;ooo]Z2?oo000?oookJP?o001o0ooo
nfX3o`00O`?ooo]Z0ol007l3oookJPSo1Ol02ooonfX8ool001oooo]Z2?l5o`0[oookJP?o001o1?oo
nfX2o`00O`;ooo]Z0ol007l8ool0023ooo]Z2Ol5o`04oookJPSoo`008?oonfX9o`Go00gooo]Z0ol0
07l2oookJP?o001o0ooonfX3o`00O`Sooo]Z000^oookJPGo00003ooonfX6o`Go02Oooo]Z1ooo000R
oookJPOo1Ol03OoonfX7o`00O`03oookJ_oo003oo`0000Goo`007ooonfX7o`Go03;ooo]Z1ooo000@
oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l2oookJPSo1Ol03OoonfX8ool001oooo]Z2?l5o`0Z
oookJP?o001o1?oonfX6o`00O`Soo`008?oonfX9o`Go00Kooo]Z2?oo000PoookJPWo1Ol03OoonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l8oookJP00;_oonfX5o`0000oooo]Z1_l5o`0W
oookJPOoo`008_oonfX6o`Go00kooo]Z1_l007l2oookJPOoo`008?oonfX7o`Go033ooo]Z2?oo000@
oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l00ooonf[o1Ol0o`Go0006o`Go00oooo]Z2?oo000O
oookJPSo1Ol0:OoonfX3o`00O`Cooo]Z1Ol007l8ool0023ooo]Z2Ol5o`07oookJPWoo`008?oonfX9
o`Go00Kooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Sooo]Z000^
oookJPGo00004?oonfX5o`Go02Oooo]Z1_oo000RoookJPOo1Ol03_oonfX2o`00O`Oooo]Z1ooo000O
oookJPOo1Ol0;ooonfX8ool000kooo]Z1_l007l3oookJP?o001o0ooonfX3o`00O`03oookJ_l5o`3o
1Ol000Go1Ol04?oonfX8ool001oooo]Z2Ol5o`0UoookJPKo001o1?oonfX2o`00O`;ooo]Z2Ooo000O
oookJPWo1Ol02OoonfX9ool0023ooo]Z2Ol5o`05oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l8oookJP00;_oonfX5o`00013ooo]Z1Ol5o`0VoookJPOoo`008_oonfX6
o`Go00oooo]Z0_l007l7oookJPOoo`008?oonfX7o`Go02kooo]Z1ooo000?oookJPKo001o1?oonfX3
o`00O`05oookJ_l007oo001oo`00OooonfX02?l5o`0AoookJPSoo`007ooonfX8o`Go02Gooo]Z1_l0
07l4oookJP;o001o00?ooo]Zool00?oo00001ooo000OoookJPWo1Ol02ooonfX9ool0023ooo]Z2?l5
o`05oookJPCo001o0_oonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l9oookJP00;_oo
nfX5o`00013ooo]Z1_l5o`0UoookJPKoo`008_oonfX7o`Go013ooo]Z1ol007l2oookJPOoo`007ooo
nfX8o`Go02cooo]Z2?oo000AoookJPCo001o1?oonfX7o`00O`So1Ol04ooonfX8ool001oooo]Z2?l5
o`0VoookJPCo001o1OoonfX2o`00O`Soo`008?oonfX8o`Go00gooo]Z2Ooo000PoookJPSo1Ol01Ooo
nfX7o`00O`?ooo]Z1ol007l9oookJP00;_oonfX5o`00013ooo]Z1_l5o`0UoookJPKoo`008_oonfX7
o`Go013ooo]Z1ol007l2oookJPOoo`008?oonfX7o`Go02_ooo]Z2?oo000CoookJP?o001o1OoonfX5
o`00O`03oookJ_l5o`3o1Ol000Go1Ol05OoonfX7ool0023ooo]Z2?l5o`0VoookJP?o001o1OoonfX0
0ol007ooo`00ool00006ool0023ooo]Z2?l5o`0?oookJPWoo`008?oonfX8o`Go00Gooo]Z1Ol007l5
oookJPGo001o2_oonfX002kooo]Z1Ol0000@oookJPKo1Ol09?oonfX7ool002;ooo]Z1_l5o`0Koook
JPOoo`007ooonfX8o`Go02[ooo]Z1ooo000QoookJPSo1Ol05OoonfX8ool0023ooo]Z2?l5o`0]oook
JPSoo`008?oonfX8o`Go017ooo]Z2Ooo000PoookJPSo1Ol07OoonfX002kooo]Z1Ol0000@oookJPKo
1Ol09?oonfX6ool002;ooo]Z1ol5o`0KoookJPOoo`008?oonfX7o`Go02Wooo]Z2?oo000PoookJPSo
1Ol05ooonfX8ool001oooo]Z2?l5o`0/oookJPSoo`008?oonfX8o`Go01?ooo]Z2Ooo000OoookJPWo
1Ol07?oonfX002kooo]Z1Ol0000AoookJPGo1Ol09?oonfX6ool002;ooo]Z1_l5o`0MoookJPOoo`00
8?oonfX7o`Go02Oooo]Z2?oo000QoookJPOo1Ol06OoonfX7ool0023ooo]Z2?l5o`0ZoookJPWoo`00
7ooonfX9o`Go01Cooo]Z2Ooo000OoookJPWo1Ol06ooonfX002kooo]Z1Ol0000AoookJPGo1Ol08ooo
nfX7ool0027ooo]Z1ol5o`0MoookJPOoo`008?oonfX7o`Go02Oooo]Z1ooo000QoookJPSo1Ol06Ooo
nfX8ool0023ooo]Z2?l5o`0XoookJPWoo`007ooonfX9o`Go01Kooo]Z2?oo000PoookJPWo1Ol06_oo
nfX002kooo]Z1Ol0000AoookJPKo1Ol08_oonfX6ool002;ooo]Z1ol5o`0NoookJPOoo`008?oonfX7
o`Go02Gooo]Z2?oo000PoookJPSo1Ol06ooonfX8ool0023ooo]Z2?l5o`0WoookJPSoo`007ooonfX9
o`Go01Sooo]Z2?oo000PoookJPWo1Ol06OoonfX0027ooo]Z8ol00006o`Go02;o00001_oo000Ro`00
00Ko1Ol07ol00007ool0023o00002?l5o`0To`0000Ooo`008Ol00007o`Go01go00002?oo000Oo`00
00Wo1Ol09Ol00008ool001oo00002Ol5o`0Jo`0000Soo`008?l00009o`Go01Oo00000OoonfX0027o
oo]Z8ol00006o`Go027o00001ooo000Qo`0000Oo1Ol08?l00007ool0023o00001ol5o`0So`0000Oo
o`008Ol00008o`Go01go00002?oo000Po`0000So1Ol09?l00008ool0023o00002?l5o`0Lo`0000So
o`008?l00009o`Go01Ko00000OoonfX0027ooo]Z8ol00006o`Go027o00001_oo000Ro`0000Ko1Ol0
8Ol00007ool0023o00002?l5o`0Qo`0000Soo`008Ol00007o`Go01oo00002?oo000Po`0000So1Ol0
8_l00008ool0023o00002?l5o`0Mo`0000Woo`008?l00009o`Go01Go00000OoonfX0027ooo]Z9?l0
0005o`Go027o00001_oo000Qo`0000Oo1Ol08_l00007ool0023o00001ol5o`0Qo`0000Ooo`008Ol0
0007o`Go027o00002?oo000Po`0000So1Ol08?l00009ool001oo00002?l5o`0Oo`0000Woo`008?l0
0009o`Go01Co00000OoonfX0027ooo]Z9?l00006o`Go023o00001_oo000Qo`0000Oo1Ol08_l00007
ool0027o00001ol5o`0Oo`0000Soo`008?l00008o`Go02;o00002?oo000Po`0000So1Ol07_l00009
ool001oo00002?l5o`0Qo`0000Woo`008?l00009o`Go01?o00000OoonfX002kooo]Z1Ol0000Boook
JPKo1Ol07ooonfX6ool002;ooo]Z1_l5o`0HoookJP03o`000?oonf[ooo]Z00Wooo]Z1ooo000Poook
JPOo1Ol07ooonfX7ool0023ooo]Z00?o0000o`Go0?l5o`001Ol5o`0SoookJPSoo`008?oonfX9o`Go
01cooo]Z2Ooo000OoookJPWo1Ol08_oonfX9ool0023ooo]Z2Ol5o`02oookJP03o`000?oonf[ooo]Z
00kooo]Z000^oookJPGo00004_oonfX6o`Go01oooo]Z1_oo000QoookJPOo1Ol06?oonfX00ol0003o
oo]ZoookJP09oookJPOoo`008OoonfX7o`Go01gooo]Z1ooo000QoookJPSo1Ol09?oonfX8ool0023o
oo]Z2?l5o`0KoookJPWoo`007ooonfX9o`Go02Cooo]Z2Ooo000PoookJPWo1Ol000?ooo]Zo`000?oo
nfX03ooonfX002kooo]Z1Ol0000BoookJPKo1Ol07ooonfX6ool0027ooo]Z1_l5o`0VoookJPOoo`00
8?oonfX7o`Go01cooo]Z2?oo000PoookJPSo1Ol09_oonfX8ool0023ooo]Z2?l5o`0JoookJPSoo`00
7ooonfX9o`Go02Kooo]Z2Ooo000PoookJPWo1Ol04OoonfX002kooo]Z1Ol0000CoookJPGo1Ol07_oo
nfX7ool0023ooo]Z1ol5o`0VoookJPOoo`008OoonfX7o`Go01_ooo]Z1ooo000QoookJPOo1Ol0:?oo
nfX7ool0027ooo]Z2?l5o`0HoookJPSoo`007ooonfX9o`Go02Sooo]Z2_oo000OoookJPWo1Ol04?oo
nfX002kooo]Z1Ol0000CoookJPGo1Ol07_oonfX6ool0027ooo]Z1ol5o`0WoookJPOoo`008?oonfX8
o`Go01Wooo]Z2?oo000PoookJPSo1Ol0:?oonfX8ool0027ooo]Z2?l5o`0FoookJPSoo`007ooonfX9
o`Go02[ooo]Z2_oo000OoookJPWo1Ol03ooonfX002kooo]Z1Ol0000CoookJPKo1Ol07OoonfX6ool0
027ooo]Z1_l5o`0XoookJPOoo`008OoonfX7o`Go01Wooo]Z1ooo000PoookJPSo1Ol0:_oonfX8ool0
023ooo]Z2?l5o`0EoookJPSoo`008?oonfX8o`Go02cooo]Z2_oo000OoookJPWo1Ol03_oonfX002ko
oo]Z1Ol0000CoookJPKo1Ol07OoonfX6ool0023ooo]Z1ol5o`0YoookJPOoo`008?oonfX8o`Go01Oo
oo]Z1ooo000QoookJPOo1Ol0;?oonfX8ool0023ooo]Z2?l5o`0CoookJPWoo`007ooonfX8o`Go02ko
oo]Z2_oo000OoookJPSo1Ol03_oonfX002kooo]Z1Ol0000CoookJPKo1Ol07?oonfX6ool0027ooo]Z
1_l5o`0ZoookJPOoo`008OoonfX7o`Go01Kooo]Z2?oo000PoookJPSo1Ol0;?oonfX8ool0027ooo]Z
2?l5o`0AoookJPWoo`007ooonfX8o`Go033ooo]Z2_oo000OoookJPOo1Ol03_oonfX002kooo]Z1Ol0
000CoookJPKo1Ol07?oonfX6ool0023ooo]Z1ol5o`0[oookJPOoo`008OoonfX7o`Go01Gooo]Z1ooo
000PoookJPSo1Ol0;_oonfX8ool0027ooo]Z2?l5o`0?oookJPWoo`007ooonfX8o`Go03?ooo]Z2Ooo
000OoookJPKo1Ol03_oonfX002kooo]Z1Ol0000DoookJPGo1Ol07?oonfX6ool0023ooo]Z1ol5o`0[
oookJPOoo`008OoonfX7o`Go01Cooo]Z2?oo000PoookJPOo1Ol0<?oonfX8ool0023ooo]Z2Ol5o`0=
oookJPWoo`007ooonfX9o`Go03Cooo]Z2Ooo000OoookJPGo1Ol03_oonfX002kooo]Z1Ol0000Doook
JPGo1Ol06ooonfX7ool0023ooo]Z1_l5o`0]oookJPOoo`008OoonfX7o`Go01;ooo]Z2?oo000Poook
JPSo1Ol0<OoonfX8ool0023ooo]Z2Ol5o`0;oookJPWoo`007ooonfX9o`Go03Kooo]Z2Ooo000aoook
JP00;_oonfX5o`0001Cooo]Z1_l5o`0JoookJPKoo`008?oonfX7o`Go02gooo]Z1ooo000QoookJPSo
1Ol04OoonfX7ool0023ooo]Z2?l5o`0boookJPWoo`008?oonfX9o`Go00[ooo]Z2?oo000OoookJPWo
1Ol0>?oonfX9ool0033ooo]Z000^oookJPGo00005?oonfX6o`Go01[ooo]Z1_oo000PoookJPKo1Ol0
;ooonfX7ool0027ooo]Z1ol5o`0@oookJPSoo`007ooonfX8o`Go03Cooo]Z2Ooo000PoookJPWo1Ol0
2?oonfX8ool001oooo]Z2Ol5o`0joookJPWoo`00;ooonfX002kooo]Z1Ol0000DoookJPKo1Ol06Ooo
nfX7ool0023ooo]Z1_l5o`0_oookJPOoo`008OoonfX8o`Go00kooo]Z2?oo000PoookJPSo1Ol0=Ooo
nfX8ool0027ooo]Z2Ol5o`06oookJPSoo`007ooonfX9o`Go03cooo]Z2_oo000]oookJP00;_oonfX5
o`0001Cooo]Z1_l5o`0IoookJPKoo`008?oonfX7o`Go033ooo]Z1ooo000QoookJPOo1Ol03_oonfX7
ool0023ooo]Z2?l5o`0goookJPSoo`008OoonfX9o`Go00Cooo]Z2?oo000OoookJPWo1Ol0?_oonfX:
ool002cooo]Z000^oookJPGo00005OoonfX5o`Go01Wooo]Z1_oo000PoookJPKo1Ol0<OoonfX7ool0
02;ooo]Z1ol5o`0<oookJPSoo`007ooonfX8o`Go03Wooo]Z2?oo000QoookJPWo1Ol00_oonfX9ool0
01kooo]Z2Ol5o`10oookJP[oo`00:ooonfX002kooo]Z1Ol0000EoookJPKo1Ol06?oonfX6ool001oo
oo]Z1ol5o`0boookJPOoo`008OoonfX8o`Go00[ooo]Z2?oo000PoookJPOo1Ol0>ooonfX8ool0027o
oo]Z2Ol5o`09ool001kooo]Z2Ol5o`12oookJP[oo`00:_oonfX002kooo]Z1Ol0000EoookJPKo1Ol0
5ooonfX6ool0023ooo]Z1ol5o`0boookJPSoo`008OoonfX8o`Go00Wooo]Z1ooo000PoookJPSo1Ol0
>ooonfX:ool0023ooo]Z2Ol5o`07ool001kooo]Z2Ol5o`14oookJP[oo`00:OoonfX002kooo]Z1Ol0
000EoookJPKo1Ol05ooonfX6ool0023ooo]Z1_l5o`0doookJPOoo`008OoonfX8o`Go00Sooo]Z2?oo
000OoookJPSo1Ol0?OoonfX:ool0023ooo]Z2Ol5o`05ool001kooo]Z2Ol5o`17oookJP_oo`009_oo
nfX002kooo]Z1Ol0000EoookJPOo1Ol05_oonfX6ool001oooo]Z1ol5o`0doookJPSoo`008OoonfX8
o`Go00Oooo]Z1ooo000PoookJPOo1Ol0?ooonfX:ool0023ooo]Z2Ol5o`03ool001kooo]Z2Ol5o`19
oookJP_oo`009OoonfX002kooo]Z1Ol0000FoookJPKo1Ol05OoonfX7ool001oooo]Z1_l5o`0foook
JPOoo`008_oonfX8o`Go00Gooo]Z1ooo000PoookJPSo1Ol0@?oonfX:ool0023ooo]Z2Ol5o`000ooo
003ooo]ZoookJP0LoookJPWo1Ol0BooonfX;ool002Cooo]Z000^oookJPGo00005_oonfX6o`Go01Go
oo]Z1_oo000OoookJPOo1Ol0=ooonfX7ool002;ooo]Z2?l5o`03oookJPSoo`007ooonfX8o`Go04;o
oo]Z2_oo000NoookJP;oo`002_l5o`0LoookJPWo1Ol0COoonfX=ool000gooo]Z1_oo000>oookJP00
;_oonfX5o`0001Kooo]Z1_l5o`0EoookJPKoo`007ooonfX7o`Go03Oooo]Z2?oo000QoookJPSo1Ol0
0ooonfX7ool001oooo]Z2?l5o`15oookJP[oo`006ooonfX4ool000_o1Ol06?oonfX:o`Go04oooo]Z
3ooo0008oookJPSoo`003_oonfX002kooo]Z1Ol0000GoookJPKo1Ol04ooonfX7ool001oooo]Z1_l5
o`0ioookJPOoo`008_oonfX8o`Go0003oookJ_oo003oo`0000Koo`007_oonfX9o`Go04Kooo]Z2_oo
000HoookJPOoo`002ol5o`0EoookJP_o1Ol0DooonfXLool000kooo]Z000^oookJPGo00005ooonfX6
o`Go01?ooo]Z1_oo000OoookJPOo1Ol0>OoonfX8ool002;ooo]Z2?l5o`07ool001kooo]Z2Ol5o`18
oookJP[oo`005_oonfX9ool000co1Ol04OoonfX<o`Go05Gooo]Z6ooo000>oookJP00;_oonfX5o`00
01Oooo]Z1_l5o`0CoookJPKoo`007ooonfX6o`Go03_ooo]Z1ooo000SoookJPSo1Ol01Ooo000Ooook
JPSo1Ol0B_oonfX:ool001Cooo]Z2_oo00000ooonf[o1Ol0o`Go000:o`Go00kooo]Z3Ol5o`1Goook
JQ[oo`003_oonfX002kooo]Z1Ol0000GoookJPOo1Ol04_oonfX6ool001oooo]Z1_l5o`0loookJPOo
o`008_oonfX8o`Go00Goo`007_oonfX8o`Go04cooo]Z3?oo000@oookJP[oo`001?oonfX=o`Go00Wo
oo]Z3_l5o`1KoookJQGoo`004?oonfX002kooo]Z1Ol0000HoookJPKo1Ol04OoonfX6ool001oooo]Z
1ol5o`0loookJPSoo`008_oonfX8o`Go00?oo`007_oonfX8o`Go04oooo]Z3?oo000<oookJP_oo`00
1ooonfXPo`Go063ooo]Z4?oo000BoookJP00;_oonfX5o`0001Sooo]Z1_l5o`0AoookJPKoo`007ooo
nfX6o`Go03kooo]Z1ooo000SoookJPSo1Ol000?oo`00oookJ_oonfX07?oonfX8o`Go057ooo]Z3Ooo
0007oookJPcoo`002_oonfXMo`Go08Cooo]Z000^oookJPGo00006?oonfX6o`Go017ooo]Z1_oo000N
oookJPOo1Ol0?_oonfX8ool002?ooo]Z2?l5o`0MoookJPWo1Ol0D_oonfXNool000gooo]Z6Ol5o`26
oookJP00;_oonfX5o`0001Wooo]Z1_l5o`0?oookJPOoo`007_oonfX7o`Go03oooo]Z2?oo000Qoook
JP03ool00?l5o`3o1Ol000Oo1Ol06_oonfX:o`Go05Cooo]Z7?oo000?oookJQKo1Ol0R?oonfX002ko
oo]Z1Ol0000IoookJPKo1Ol03ooonfX6ool001oooo]Z1_l5o`11oookJPSoo`007ooonfX3ool000Wo
1Ol06?oonfX:o`Go05Sooo]Z6?oo000CoookJQ7o1Ol0R_oonfX002kooo]Z1Ol0000IoookJPKo1Ol0
3ooonfX6ool001kooo]Z1ol5o`11oookJPWoo`007OoonfX5ool000Wo1Ol05OoonfX;o`Go05_ooo]Z
5?oo002`oookJP00;_oonfX5o`0001Wooo]Z1ol5o`0>oookJPKoo`007_oonfX6o`Go04?ooo]Z2Ooo
000KoookJPOoo`002_l5o`0BoookJP_o1Ol0G_oonfX?ool00;?ooo]Z000^oookJPGo00006_oonfX6
o`Go00gooo]Z1_oo000OoookJPKo1Ol0A?oonfX9ool001Wooo]Z2Ooo000:o`Go013ooo]Z2ol5o`3o
oookJR;ooo]Z000^oookJPGo00006_oonfX6o`Go00gooo]Z1_oo000NoookJPOo1Ol0AOoonfX9ool0
01Oooo]Z2Ooo0002oookJP_o1Ol03OoonfX:o`Go0?oooo]Z9?oonfX002kooo]Z1Ol0000JoookJPKo
1Ol03OoonfX6ool001kooo]Z1_l5o`17oookJPWoo`005?oonfX:ool000Cooo]Z3Ol5o`07oookJPco
1Ol0oooonfXUoookJP00;_oonfX5o`0001_ooo]Z1_l5o`0;oookJPOoo`007OoonfX7o`Go04Sooo]Z
2Ooo000BoookJP[oo`001_oonfXMo`Go0?oooo]Z9ooonfX002kooo]Z1Ol0000KoookJPKo1Ol02ooo
nfX6ool001kooo]Z1ol5o`19oookJPWoo`003ooonfX;ool000Wooo]Z6_l5o`3ooookJRSooo]Z000^
oookJPGo00006ooonfX6o`Go00_ooo]Z1_oo000MoookJPOo1Ol0BooonfX:ool000cooo]Z2ooo000;
oookJQSo1Ol0oooonfXYoookJP00;_oonfX5o`0001_ooo]Z1ol5o`09oookJPOoo`007OoonfX7o`Go
04cooo]Z2_oo0009oookJPcoo`003_oonfXEo`Go0?oooo]Z:_oonfX002kooo]Z1Ol0000LoookJPKo
1Ol02OoonfX6ool001gooo]Z1ol5o`1>oookJPcoo`001?oonfX<ool001?ooo]Z3ol5o`3ooookJRgo
oo]Z000^oookJPGo00007?oonfX6o`Go00Wooo]Z1_oo000MoookJPOo1Ol0CooonfXJool001Oooo]Z
2?l5o`3ooookJS7ooo]Z000^oookJPGo00007?oonfX6o`Go00Wooo]Z1_oo000LoookJPOo1Ol0DOoo
nfXGool00?oooo]ZD_oonfX002kooo]Z1Ol0000MoookJPKo1Ol01ooonfX6ool001gooo]Z1ol5o`1C
oookJQCoo`00oooonfYCoookJP00;_oonfX5o`0001gooo]Z1_l5o`07oookJPKoo`007?oonfX7o`Go
05Gooo]Z4Ooo003ooookJUGooo]Z000^oookJPGo00007OoonfX6o`Go00Oooo]Z1_oo000LoookJPOo
1Ol0F?oonfX<ool00?oooo]ZEooonfX002kooo]Z1Ol0000MoookJPKo1Ol01_oonfX7ool001cooo]Z
1_l5o`3ooookJ[cooo]Z000^oookJPGo00007_oonfX6o`Go00Gooo]Z1_oo000LoookJPOo1Ol0oooo
nfZloookJP00;_oonfX5o`0001kooo]Z1_l5o`05oookJPKoo`007?oonfX6o`Go0?oooo]Z_OoonfX0
02kooo]Z1Ol0000NoookJPKo1Ol01OoonfX6ool001_ooo]Z1ol5o`3ooookJ[gooo]Z000^oookJPGo
00007_oonfX7o`Go00?ooo]Z1_oo000LoookJPOo1Ol0oooonfZmoookJP00;_oonfX5o`0001oooo]Z
1_l5o`03oookJPKoo`006ooonfX7o`Go0?oooo]Z__oonfX002kooo]Z1Ol0000OoookJPKo1Ol00ooo
nfX6ool001_ooo]Z1ol5o`3ooookJ[kooo]Z000^oookJPGo00007ooonfX7o`Go0003oookJ_oo003o
o`0000Goo`006_oonfX7o`Go0?oooo]Z_ooonfX002kooo]Z1Ol0000PoookJPKo1Ol000?ooo]Zool0
0?oo00001?oo000KoookJPOo1Ol0oooonfZooookJP00;_oonfX5o`00023ooo]Z1ol5o`06ool001[o
oo]Z1ol5o`3ooookJ/3ooo]Z000^oookJPGo00008?oonfX7o`Go00Koo`006_oonfX7o`Go0?oooo]Z
`?oonfX002kooo]Z1Ol0000QoookJPOo1Ol01?oo000JoookJPOo1Ol0oooonf[1oookJP00;_oonfX5
o`00027ooo]Z1ol5o`04ool001Wooo]Z2?l5o`3ooookJ/7ooo]Z000^oookJPGo00008_oonfX7o`Go
00?oo`006OoonfX7o`Go0?oooo]Z`_oonfX002kooo]Z1Ol0000RoookJPOo1Ol00_oo000IoookJPSo
1Ol0oooonf[2oookJP00;_oonfX5o`0002?ooo]Z1ol5o`000ooo003ooo]ZoookJP0GoookJPOo1Ol0
oooonf[3oookJP00;_oonfX5o`0002?ooo]Z1ol5o`000ooo003ooo]ZoookJP0FoookJPOo1Ol0oooo
nf[4oookJP00;_oonfX5o`0002Cooo]Z1_l5o`000ooo003ooo]ZoookJP0EoookJPSo1Ol0oooonf[4
oookJP00;_oonfX5o`0002Cooo]Z1ol5o`0GoookJPOo1Ol0oooonf[5oookJP00;_oonfX5o`0002Co
oo]Z00?oo`00o`Go0?l5o`001?l5o`0FoookJPSo1Ol0oooonf[5oookJP00;_oonfX5o`0002Cooo]Z
00?oo`00o`Go0?l5o`001Ol5o`0DoookJPSo1Ol0oooonf[6oookJP00;_oonfX5o`0002?ooo]Z0_oo
0008o`Go01;ooo]Z2?l5o`3ooookJ/Oooo]Z000^oookJPGo00008ooonfX3ool000So1Ol04?oonfX9
o`Go0?oooo]ZaooonfX002kooo]Z1Ol0000SoookJP?oo`002?l5o`0@oookJPSo1Ol0oooonf[8oook
JP004OoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2OoonfX5o`0002?ooo]Z1?oo0008o`Go00ko
oo]Z2?l5o`3ooookJ/Wooo]Z000@oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l8oookJPGo0000
8_oonfX6ool000So1Ol03?oonfX8o`Go0?oooo]Zb_oonfX0013ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l8oookJPGo
00008_oonfX6ool00003oookJ_l5o`3o1Ol000Ko1Ol02_oonfX8o`Go0?oooo]ZbooonfX000oooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo00008_oonfX6ool00003oook
J_l5o`3o1Ol000Oo1Ol02?oonfX9o`Go0?oooo]ZbooonfX000oooo]Z0ol007l3oookJP?o001o3?oo
nfX3o`00O`Oooo]Z1ol0000OoookJPOoo`000_oonfX;o`Go00;ooo]Z2ol5o`3ooookJ/cooo]Z000?
oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo00008OoonfX6ool000Cooo]Z5_l5o`3o
oookJ/gooo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX5o`00
027ooo]Z1_oo0005oookJQCo1Ol0oooonf[>oookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo
001o2?oonfX5o`00027ooo]Z1_oo0006oookJQ;o1Ol0oooonf[?oookJP003ooonfX3o`00O`?ooo]Z
0ol007l7oookJPKo001o2OoonfX5o`00023ooo]Z1_oo0008oookJQ3o1Ol0oooonf[@oookJP003ooo
nfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3OoonfX5o`00023ooo]Z1_oo000;oookJP[o1Ol0oooo
nf[CoookJP004?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l=oookJPGo00008?oo
nfX6ool00?oooo]Zj?oonfX0013ooo]Z1ol007l9oookJPOo001o1ooonfX5o`0001oooo]Z1ooo003o
oookJ^Sooo]Z000AoookJPGo001o2_oonfX7o`00O`Oooo]Z1Ol0000OoookJPKoo`00oooonf[Yoook
JP00;_oonfX5o`0001oooo]Z1_oo003ooookJ^Wooo]Z000^oookJPGo00007ooonfX6ool00?oooo]Z
jOoonfX002kooo]Z1Ol0000NoookJPKoo`00oooonf[ZoookJP00;_oonfX5o`0001kooo]Z1_oo003o
oookJ^[ooo]Z000^oookJPGo00007_oonfX6ool00?oooo]Zj_oonfX002kooo]Z1Ol0000NoookJPKo
o`00oooonf[ZoookJP00;_oonfX5o`0001gooo]Z1_oo003ooookJ^_ooo]Z000^oookJPGo00007Ooo
nfX6ool00?oooo]ZjooonfX002kooo]Z1Ol0000MoookJPKoo`00oooonf[[oookJP00;_oonfX5o`00
01cooo]Z1ooo003ooookJ^_ooo]Z000^oookJPGo00007?oonfX6ool00?oooo]Zk?oonfX002kooo]Z
1Ol0000LoookJPKoo`00oooonf[/oookJP00;_oonfX5o`0001_ooo]Z1ooo003ooookJ^cooo]Z000^
oookJPGo00006ooonfX6ool00?oooo]ZkOoonfX002kooo]Z1Ol0000KoookJPKoo`00oooonf[]oook
JP00;_oonfX5o`0001[ooo]Z1ooo003ooookJ^gooo]Z000^oookJPGo00006_oonfX6ool00?oooo]Z
k_oonfX002kooo]Z1Ol0000JoookJPKoo`00oooonf[^oookJP00;_oonfX5o`0001Wooo]Z1ooo003o
oookJ^kooo]Z000^oookJPGo00006OoonfX6ool00?oooo]ZkooonfX002kooo]Z1Ol0000HoookJPOo
o`00oooonf[_oookJP00;_oonfX5o`0001Sooo]Z1ooo003ooookJ^oooo]Z000^oookJPGo00006?oo
nfX6ool00?oooo]Zl?oonfX002kooo]Z1Ol0000GoookJPOoo`00oooonf[`oookJP00;_oonfX5o`00
01Oooo]Z1_oo003ooookJ_7ooo]Z000^oookJPGo00005ooonfX6ool00?oooo]ZlOoonfX002kooo]Z
1Ol0000FoookJPOoo`00oooonf[aoookJP00;_oonfX5o`0001Kooo]Z1_oo003ooookJ_;ooo]Z000^
oookJPGo00005OoonfX7ool00?oooo]Zl_oonfX002kooo]Z1Ol0000EoookJPOoo`00oooonf[boook
JP00;_oonfX5o`0001Gooo]Z1_oo003ooookJ_?ooo]Z000^oookJPGo00005?oonfX7ool00?oooo]Z
looonfX002kooo]Z1Ol0000DoookJPKoo`00oooonf[doookJP00;_oonfX5o`0001Cooo]Z1_oo003o
oookJ_Cooo]Z000^oookJPGo00004ooonfX7ool00?oooo]Zm?oonfX002kooo]Z1Ol0000CoookJPKo
o`00oooonf[eoookJP00;_oonfX5o`0001;ooo]Z1ooo003ooookJ_Gooo]Z000^oookJPGo00004_oo
nfX7ool00?oooo]ZmOoonfX002kooo]Z1Ol0000BoookJPKoo`00oooonf[foookJP00;_oonfX5o`00
017ooo]Z1ooo003ooookJ_Kooo]Z000^oookJPGo00004OoonfX6ool00?oooo]ZmooonfX002kooo]Z
1Ol0000AoookJPKoo`00oooonf[goookJP00;_oonfX5o`00013ooo]Z1ooo003ooookJ_Oooo]Z000^
oookJPGo00004?oonfX6ool00?oooo]Zn?oonfX002kooo]Z1Ol0000?oookJPOoo`00oooonf[hoook
JP00;_oonfX5o`0000oooo]Z1ooo003ooookJ_Sooo]Z000^oookJPGo00003_oonfX7ool00?oooo]Z
nOoonfX002kooo]Z1Ol0000>oookJPOoo`00oooonf[ioookJP00;_oonfX5o`0000gooo]Z1ooo003o
oookJ_[ooo]Z000^oookJPGo00003OoonfX7ool00?oooo]Zn_oonfX002kooo]Z1Ol0000<oookJPOo
o`00oooonf[koookJP00;_oonfX5o`0000cooo]Z1ooo003ooookJ__ooo]Z000^oookJPGo00002ooo
nfX7ool00?oooo]Zo?oonfX002kooo]Z1Ol0000;oookJPOoo`00oooonf[loookJP00;_oonfX5o`00
00[ooo]Z1ooo003ooookJ_gooo]Z000^oookJPGo00002_oonfX7ool00?oooo]ZoOoonfX002kooo]Z
1Ol00009oookJPOoo`00oooonf[noookJP00;_oonfX5o`0000Sooo]Z2?oo003ooookJ_kooo]Z000^
oookJPGo00001ooonfX8ool00?oooo]ZoooonfX002kooo]Z1Ol00007oookJPSoo`00oooonf[ooook
JP00;_oonfX5o`0000Kooo]Z2?oo003ooookJ_oooo]Z0OoonfX002kooo]Z1Ol00005oookJPSoo`00
oooonf[ooookJP;ooo]Z000^oookJPGo00001OoonfX7ool00?oooo]ZoooonfX3oookJP00;_oonfX5
o`0000Cooo]Z2?oo003ooookJ_oooo]Z0ooonfX002kooo]Z1Ol00002oookJPWoo`00oooonf[ooook
JPCooo]Z000RoookJP?o001o2OoonfX5o`000003oookJ_oo003oo`0000Ooo`00oooonf[ooookJPGo
oo]Z000RoookJP?o001o2OoonfX4o`0000_oo`00oooonf[ooookJPGooo]Z000RoookJP?o001o2Ooo
nfX>ool00?oooo]ZoooonfX6oookJP008_oonfX3o`00O`Wooo]Z3Ooo003ooookJ_oooo]Z1ooonfX0
02;ooo]Z0ol007l9oookJP_oo`00oooonf[ooookJPWooo]Z000RoookJP?o001o2OoonfX:ool00?oo
oo]ZoooonfX:oookJP008_oonfX3o`00O`Wooo]Z2?oo003ooookJ_oooo]Z3?oonfX002;ooo]Z0ol0
07l9oookJPGo0000oooonf[ooookJPoooo]Z000RoookJP?o001o2OoonfX5o`000?oooo]ZoooonfX?
oookJP007ooonfX6o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z3ooonfX001oooo]Z1_l007l9oookJPGo
0000oooonf[ooookJPoooo]Z000QoookJPCo001o2OoonfX5o`000?oooo]ZoooonfX?oookJP008_oo
nfX3o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z3ooonfX002kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX0
02kooo]Z1Ol0003ooookJ_oooo]Z3ooonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.90432, -1.15595, \
0.0391469, 0.00642902}},
  CellTags->"mmtag:26:Bessels_function__visualizing"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellTags->"mmtag:26:Bessels_function__visualizing"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{BesselJ[5, x], \ BesselY[5, x]}, {x, 0, 20}, \ 
      PlotStyle \[Rule] MyPlotStyle[2]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.566652 0.0980164 [
[.2619 .55415 -7 -20 ]
[.2619 .55415 7 0 ]
[.5 .55415 -12 -20 ]
[.5 .55415 12 0 ]
[.7381 .55415 -12 -20 ]
[.7381 .55415 12 0 ]
[.97619 .55415 -12 -20 ]
[.97619 .55415 12 0 ]
[.01131 .07657 -26.9375 -10 ]
[.01131 .07657 0 10 ]
[.01131 .17459 -26.9375 -10 ]
[.01131 .17459 0 10 ]
[.01131 .2726 -26.9375 -10 ]
[.01131 .2726 0 10 ]
[.01131 .37062 -26.9375 -10 ]
[.01131 .37062 0 10 ]
[.01131 .46864 -26.9375 -10 ]
[.01131 .46864 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .56665 m
.2619 .5729 L
s
gsave
.2619 .55415 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .56665 m
.5 .5729 L
s
gsave
.5 .55415 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7381 .56665 m
.7381 .5729 L
s
gsave
.7381 .55415 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.97619 .56665 m
.97619 .5729 L
s
gsave
.97619 .55415 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .56665 m
.07143 .5704 L
s
.11905 .56665 m
.11905 .5704 L
s
.16667 .56665 m
.16667 .5704 L
s
.21429 .56665 m
.21429 .5704 L
s
.30952 .56665 m
.30952 .5704 L
s
.35714 .56665 m
.35714 .5704 L
s
.40476 .56665 m
.40476 .5704 L
s
.45238 .56665 m
.45238 .5704 L
s
.54762 .56665 m
.54762 .5704 L
s
.59524 .56665 m
.59524 .5704 L
s
.64286 .56665 m
.64286 .5704 L
s
.69048 .56665 m
.69048 .5704 L
s
.78571 .56665 m
.78571 .5704 L
s
.83333 .56665 m
.83333 .5704 L
s
.88095 .56665 m
.88095 .5704 L
s
.92857 .56665 m
.92857 .5704 L
s
.01 w
0 .56665 m
1 .56665 L
s
.25 Mabswid
.02381 .07657 m
.03006 .07657 L
s
gsave
.01131 .07657 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.02381 .17459 m
.03006 .17459 L
s
gsave
.01131 .17459 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.02381 .2726 m
.03006 .2726 L
s
gsave
.01131 .2726 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.02381 .37062 m
.03006 .37062 L
s
gsave
.01131 .37062 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.02381 .46864 m
.03006 .46864 L
s
gsave
.01131 .46864 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .09617 m
.02756 .09617 L
s
.02381 .11578 m
.02756 .11578 L
s
.02381 .13538 m
.02756 .13538 L
s
.02381 .15498 m
.02756 .15498 L
s
.02381 .19419 m
.02756 .19419 L
s
.02381 .21379 m
.02756 .21379 L
s
.02381 .2334 m
.02756 .2334 L
s
.02381 .253 m
.02756 .253 L
s
.02381 .29221 m
.02756 .29221 L
s
.02381 .31181 m
.02756 .31181 L
s
.02381 .33141 m
.02756 .33141 L
s
.02381 .35102 m
.02756 .35102 L
s
.02381 .39022 m
.02756 .39022 L
s
.02381 .40983 m
.02756 .40983 L
s
.02381 .42943 m
.02756 .42943 L
s
.02381 .44903 m
.02756 .44903 L
s
.02381 .48824 m
.02756 .48824 L
s
.02381 .50784 m
.02756 .50784 L
s
.02381 .52745 m
.02756 .52745 L
s
.02381 .54705 m
.02756 .54705 L
s
.02381 .05697 m
.02756 .05697 L
s
.02381 .03736 m
.02756 .03736 L
s
.02381 .01776 m
.02756 .01776 L
s
.02381 .58626 m
.02756 .58626 L
s
.02381 .60586 m
.02756 .60586 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02381 .56665 m
.02499 .56665 L
.02605 .56665 L
.02729 .56665 L
.02846 .56665 L
.02954 .56665 L
.03053 .56665 L
.03163 .56665 L
.03279 .56665 L
.03395 .56665 L
.0352 .56665 L
.03638 .56665 L
.03746 .56665 L
.03873 .56665 L
.03944 .56665 L
.04011 .56665 L
.04132 .56665 L
.04262 .56665 L
.04396 .56665 L
.04519 .56665 L
.04654 .56665 L
.04797 .56665 L
.05038 .56665 L
.05174 .56665 L
.05302 .56665 L
.0554 .56666 L
.05757 .56666 L
.06007 .56666 L
.06244 .56666 L
.06486 .56666 L
.06753 .56667 L
.07031 .56667 L
.07293 .56668 L
.0776 .5667 L
.08263 .56672 L
.08821 .56676 L
.09408 .56682 L
.09909 .56688 L
.10458 .56697 L
.10986 .56708 L
.11485 .56721 L
.12419 .56753 L
.13424 .56802 L
.14514 .56873 L
.15461 .56954 L
.16502 .57067 L
.18606 .57375 L
.20551 .57758 L
.2264 .58262 L
.26768 .59377 L
Mistroke
.28831 .59866 L
.29835 .60055 L
.30744 .60189 L
.31202 .60241 L
.31444 .60264 L
.31698 .60285 L
.31921 .603 L
.32166 .60314 L
.32274 .60318 L
.32389 .60323 L
.32489 .60326 L
.32596 .60328 L
.32728 .60331 L
.3285 .60332 L
.32982 .60332 L
.33056 .60331 L
.33126 .60331 L
.33253 .60329 L
.33368 .60326 L
.33495 .60322 L
.33628 .60316 L
.33861 .60304 L
.34077 .60289 L
.34568 .60244 L
.35075 .60181 L
.35623 .60092 L
.36618 .59879 L
.37586 .59609 L
.38478 .59309 L
.42423 .57543 L
.46217 .55668 L
.48166 .54886 L
.49259 .54549 L
.49743 .54428 L
.50257 .5432 L
.50727 .54239 L
.50977 .54204 L
.51246 .54172 L
.51493 .54148 L
.51719 .54131 L
.51935 .54119 L
.52044 .54114 L
.52163 .5411 L
.5223 .54109 L
.52303 .54107 L
.52435 .54106 L
.52563 .54106 L
.52682 .54108 L
.5281 .54111 L
.52883 .54113 L
Mistroke
.52952 .54116 L
.53098 .54123 L
.53237 .54131 L
.53489 .54151 L
.53719 .54173 L
.54238 .5424 L
.54741 .54326 L
.55198 .54421 L
.5622 .54688 L
.58059 .55331 L
.62068 .57077 L
.63907 .5782 L
.64951 .58174 L
.65925 .58443 L
.66888 .58644 L
.67428 .58725 L
.6792 .58778 L
.6819 .58799 L
.68439 .58813 L
.68569 .58818 L
.68644 .58821 L
.68712 .58822 L
.68784 .58824 L
.68862 .58825 L
.6893 .58825 L
.69003 .58825 L
.69125 .58825 L
.69256 .58822 L
.6938 .58819 L
.69492 .58815 L
.69624 .58809 L
.69767 .588 L
.70027 .58781 L
.70517 .58729 L
.70975 .58664 L
.72016 .58459 L
.73031 .5819 L
.74121 .57837 L
.78251 .56225 L
.80315 .55493 L
.8132 .55208 L
.82229 .55003 L
.82688 .54921 L
.83184 .5485 L
.83412 .54823 L
.83653 .54799 L
.83878 .54781 L
.84083 .54767 L
.84318 .54756 L
.84447 .54752 L
Mistroke
.8457 .54749 L
.84683 .54747 L
.84788 .54746 L
.84902 .54746 L
.85024 .54748 L
.85146 .5475 L
.85277 .54754 L
.85401 .54759 L
.85515 .54765 L
.85792 .54782 L
.86055 .54804 L
.86558 .54861 L
.87013 .54928 L
.88035 .55128 L
.89873 .55639 L
.93879 .57073 L
.97619 .58147 L
Mfstroke
.02 1 0 r
.13181 0 m
.13401 .04968 L
.14282 .19082 L
.1478 .24783 L
.15233 .28969 L
.1572 .32647 L
.1625 .35881 L
.17193 .40203 L
.18085 .43113 L
.19027 .45357 L
.20066 .47168 L
.21151 .48566 L
.22168 .49573 L
.24191 .51067 L
.26042 .52138 L
.3001 .54228 L
.33826 .56298 L
.35955 .5741 L
.37887 .58299 L
.38854 .58676 L
.399 .59021 L
.40887 .59276 L
.41363 .59372 L
.41797 .59445 L
.42266 .59506 L
.42524 .59532 L
.42769 .59551 L
.42878 .59558 L
.42995 .59564 L
.43095 .59569 L
.43204 .59572 L
.4332 .59575 L
.43429 .59577 L
.43558 .59578 L
.43677 .59578 L
.43797 .59576 L
.43926 .59573 L
.44047 .59568 L
.44157 .59563 L
.44428 .59547 L
.44683 .59525 L
.45191 .59466 L
.45743 .59379 L
.46687 .59173 L
.47728 .58871 L
.49831 .58066 L
.53862 .5619 L
.55717 .55401 L
.56697 .55051 L
.57741 .54745 L
Mistroke
.58317 .54611 L
.58838 .5451 L
.59362 .54432 L
.59856 .54379 L
.60101 .54361 L
.60234 .54353 L
.60359 .54347 L
.60466 .54343 L
.6058 .54339 L
.60706 .54337 L
.60822 .54336 L
.60886 .54336 L
.60955 .54336 L
.61079 .54338 L
.61147 .5434 L
.61211 .54341 L
.61358 .54347 L
.61485 .54353 L
.61602 .5436 L
.61866 .54379 L
.6234 .54429 L
.62847 .54502 L
.63759 .54683 L
.64845 .54975 L
.6583 .553 L
.6983 .56927 L
.71663 .57648 L
.72705 .57999 L
.73679 .58272 L
.74638 .58479 L
.75176 .58566 L
.75668 .58626 L
.75936 .58651 L
.76185 .58669 L
.76325 .58677 L
.76458 .58683 L
.76531 .58686 L
.7661 .58688 L
.76681 .5869 L
.76748 .58691 L
.76872 .58693 L
.76938 .58693 L
.77008 .58693 L
.77082 .58692 L
.77151 .58691 L
.77282 .58689 L
.77404 .58685 L
.77517 .5868 L
.77773 .58666 L
.78016 .58648 L
Mistroke
.78238 .58628 L
.78739 .58567 L
.79203 .58495 L
.79644 .58412 L
.81707 .57866 L
.85525 .56458 L
.87655 .55699 L
.88662 .55401 L
.89588 .55174 L
.90555 .54996 L
.91064 .54928 L
.91324 .549 L
.91602 .54876 L
.91846 .5486 L
.9207 .54849 L
.92177 .54845 L
.92294 .54841 L
.92404 .54839 L
.92506 .54838 L
.92624 .54837 L
.92735 .54838 L
.92857 .54839 L
.92988 .54842 L
.93118 .54847 L
.93255 .54852 L
.935 .54866 L
.93757 .54886 L
.93999 .54908 L
.94453 .54961 L
.94943 .55035 L
.95473 .55132 L
.97309 .55592 L
.97619 .55685 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX001oooo]Z1Ol0003ooookJ_oooo]Z7_oonfX001oooo]Z1Ol0003ooook
J_oooo]Z7_oonfX001oooo]Z1Ol0000goookJPGo1Ol0oooonf[QoookJP007ooonfX5o`0003Oooo]Z
1Ol5o`3ooookJ^7ooo]Z000OoookJPGo0000=ooonfX5o`Go0?oooo]ZhOoonfX001oooo]Z1Ol0000g
oookJPGo1Ol0oooonf[QoookJP007ooonfX5o`0003Oooo]Z1Ol5o`3ooookJ^7ooo]Z000OoookJPGo
0000=ooonfX5o`Go0?oooo]ZhOoonfX001oooo]Z1Ol0000goookJPGo1Ol0oooonf[QoookJP007ooo
nfX5o`0003Oooo]Z1Ol5o`3ooookJ^7ooo]Z000OoookJPGo0000=ooonfX5o`Go0?oooo]ZhOoonfX0
01oooo]Z1Ol0000goookJPGo1Ol0oooonf[QoookJP007ooonfX5o`0003Oooo]Z1Ol5o`3ooookJ^7o
oo]Z000OoookJPGo0000=ooonfX5o`Go0?oooo]ZhOoonfX001oooo]Z1Ol0000goookJPKo1Ol0oooo
nf[PoookJP007ooonfX5o`0003Oooo]Z1_l5o`3ooookJ^3ooo]Z000OoookJPGo0000=ooonfX6o`Go
0?oooo]Zh?oonfX001oooo]Z1Ol0000goookJPKo1Ol0oooonf[PoookJP007ooonfX5o`0003Sooo]Z
1Ol5o`3ooookJ^3ooo]Z000OoookJPGo0000>?oonfX5o`Go0?oooo]Zh?oonfX001oooo]Z1Ol0000h
oookJPGo1Ol0oooonf[PoookJP007ooonfX5o`0003Sooo]Z1Ol5o`3ooookJ^3ooo]Z000OoookJPGo
0000>?oonfX5o`Go0?oooo]Zh?oonfX001oooo]Z1Ol0000hoookJPGo1Ol0oooonf[PoookJP007ooo
nfX5o`0003Sooo]Z1Ol5o`3ooookJ^3ooo]Z000OoookJPGo0000>?oonfX5o`Go0?oooo]Zh?oonfX0
01oooo]Z1Ol0000hoookJPGo1Ol0oooonf[PoookJP007ooonfX5o`0003Sooo]Z1Ol5o`3ooookJ^3o
oo]Z000OoookJPGo0000>?oonfX5o`Go0?oooo]Zh?oonfX001oooo]Z1Ol0000hoookJPGo1Ol0oooo
nf[PoookJP007ooonfX5o`0003Sooo]Z1Ol5o`3ooookJ^3ooo]Z000OoookJPGo0000>?oonfX5o`Go
0?oooo]Zh?oonfX001oooo]Z1Ol0000hoookJPGo1Ol0oooonf[PoookJP007ooonfX5o`0003Sooo]Z
1Ol5o`3ooookJ^3ooo]Z000OoookJPGo0000>?oonfX5o`Go0?oooo]Zh?oonfX001oooo]Z1Ol0000h
oookJPGo1Ol0oooonf[PoookJP007ooonfX5o`0003Sooo]Z1_l5o`3ooookJ]oooo]Z000OoookJPGo
0000>?oonfX6o`Go0?oooo]ZgooonfX001oooo]Z1Ol0000hoookJPKo1Ol0oooonf[OoookJP007ooo
nfX5o`0003Sooo]Z1_l5o`3ooookJ]oooo]Z000AoookJPGo001o2OoonfX5o`0003Wooo]Z1Ol5o`3o
oookJ]oooo]Z000@oookJPOo001o2?oonfX5o`0003Wooo]Z1Ol5o`3ooookJ]oooo]Z000?oookJPCo
001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0003Wooo]Z1Ol5o`3ooookJ]oooo]Z0003oookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000>OoonfX5o`Go0?oooo]ZgooonfX000?ooo]Z
2_l007l8oookJP?o001o1ooonfX7o`0003Oooo]Z1Ol5o`3ooookJ]oooo]Z000EoookJP?o001o1ooo
nfX5o`0003Wooo]Z1Ol5o`3ooookJ]oooo]Z000@oookJP;o001o0_oonfX4o`00O`Oooo]Z1Ol0000i
oookJPGo1Ol0oooonf[OoookJP004?oonfX7o`00O`Sooo]Z1Ol0000ioookJPGo1Ol0oooonf[Ooook
JP004?oonfX6o`00O`Wooo]Z1Ol0000ioookJPGo1Ol0oooonf[OoookJP004?oonfX2o`00O`gooo]Z
1Ol0000ioookJPGo1Ol0oooonf[OoookJP004?oonfX2o`00O`gooo]Z1Ol0000ioookJPGo1Ol0oooo
nf[OoookJP004OoonfX7o`00O`Oooo]Z1Ol0000ioookJPKo1Ol0oooonf[NoookJP004OoonfX7o`00
O`Oooo]Z1Ol0000ioookJPKo1Ol0oooonf[NoookJP007ooonfX5o`0003Wooo]Z1_l5o`3ooookJ]ko
oo]Z000OoookJPGo0000>OoonfX6o`Go0?oooo]Zg_oonfX001oooo]Z1Ol0000joookJPGo1Ol0oooo
nf[NoookJP007ooonfX5o`0003[ooo]Z1Ol5o`3ooookJ]kooo]Z000OoookJPGo0000>_oonfX5o`Go
0?oooo]Zg_oonfX001oooo]Z1Ol0000joookJPGo1Ol0oooonf[NoookJP007ooonfX5o`0003[ooo]Z
1Ol5o`3ooookJ]kooo]Z000OoookJPGo0000>_oonfX5o`Go0?oooo]Zg_oonfX001oooo]Z1Ol0000j
oookJPGo1Ol0oooonf[NoookJP007ooonfX5o`0003[ooo]Z1Ol5o`3ooookJ]kooo]Z000OoookJPGo
0000>_oonfX5o`Go0?oooo]Zg_oonfX001oooo]Z1Ol0000joookJPGo1Ol0oooonf[NoookJP007ooo
nfX5o`0003[ooo]Z1Ol5o`3ooookJ]kooo]Z000OoookJPGo0000>_oonfX5o`Go0?oooo]Zg_oonfX0
01oooo]Z1Ol0000joookJPKo1Ol0oooonf[MoookJP007ooonfX5o`0003[ooo]Z1_l5o`3ooookJ]go
oo]Z000OoookJPGo0000>_oonfX6o`Go0?oooo]ZgOoonfX001oooo]Z1Ol0000joookJPKo1Ol0oooo
nf[MoookJP007ooonfX5o`0003_ooo]Z1Ol5o`3ooookJ]gooo]Z000OoookJPGo0000>ooonfX5o`Go
0?oooo]ZgOoonfX001oooo]Z1Ol0000koookJPGo1Ol0oooonf[MoookJP007ooonfX5o`0003_ooo]Z
1Ol5o`3ooookJ]gooo]Z000OoookJPGo0000>ooonfX5o`Go0?oooo]ZgOoonfX001oooo]Z1Ol0000k
oookJPGo1Ol0oooonf[MoookJP007ooonfX5o`0003_ooo]Z1Ol5o`3ooookJ]gooo]Z000OoookJPGo
0000>ooonfX5o`Go0?oooo]ZgOoonfX001oooo]Z1Ol0000koookJPGo1Ol0oooonf[MoookJP007ooo
nfX5o`0003_ooo]Z1Ol5o`3ooookJ]gooo]Z000OoookJPGo0000>ooonfX5o`Go0?oooo]ZgOoonfX0
01oooo]Z1Ol0000koookJPGo1Ol0oooonf[MoookJP007ooonfX5o`0003_ooo]Z1_l5o`3ooookJ]co
oo]Z000OoookJPGo0000>ooonfX6o`Go0?oooo]Zg?oonfX001oooo]Z1Ol0000koookJPKo1Ol0oooo
nf[LoookJP007ooonfX5o`0003_ooo]Z1_l5o`3ooookJ]cooo]Z000OoookJPGo0000??oonfX5o`Go
0?oooo]Zg?oonfX001oooo]Z1Ol0000loookJPGo1Ol0oooonf[LoookJP007ooonfX5o`0003cooo]Z
1Ol5o`3ooookJ]cooo]Z000OoookJPGo0000??oonfX5o`Go0?oooo]Zg?oonfX001oooo]Z1Ol0000l
oookJPGo1Ol0oooonf[LoookJP007ooonfX5o`0003cooo]Z1Ol5o`3ooookJ]cooo]Z000OoookJPGo
0000??oonfX5o`Go0?oooo]Zg?oonfX001Cooo]Z0ol007l8oookJPGo0000??oonfX5o`Go0?oooo]Z
g?oonfX001Cooo]Z0ol007l8oookJPGo0000??oonfX5o`Go0?oooo]Zg?oonfX001Cooo]Z0ol007l8
oookJPGo0000??oonfX5o`Go0?oooo]Zg?oonfX000?ooo]Z2_l007l2oookJPWo001o1ooonfX5o`00
03cooo]Z1Ol5o`3ooookJ]cooo]Z0003oookJP[o001o0_oonfX9o`00O`Oooo]Z1ol0000joookJPKo
1Ol0oooonf[KoookJP003ooonfX2o`00O`?ooo]Z0ol007l8oookJPGo0000??oonfX6o`Go0?oooo]Z
fooonfX0013ooo]Z0_l007l2oookJP?o001o2?oonfX5o`0003cooo]Z1_l5o`3ooookJ]_ooo]Z000@
oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0003cooo]Z1_l5o`3ooookJ]_ooo]Z000A
oookJP;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0003gooo]Z1Ol5o`3ooookJ]_ooo]Z000B
oookJPGo001o2?oonfX5o`0003gooo]Z1Ol5o`3ooookJ]_ooo]Z000BoookJPGo001o2?oonfX5o`00
03gooo]Z1Ol5o`3ooookJ]_ooo]Z000CoookJPCo001o2?oonfX5o`0003gooo]Z1Ol5o`3ooookJ]_o
oo]Z000DoookJP?o001o2?oonfX5o`0003gooo]Z1Ol5o`3ooookJ]_ooo]Z000OoookJPGo0000?Ooo
nfX5o`Go0?oooo]ZfooonfX001oooo]Z1Ol0000moookJPGo1Ol0oooonf[KoookJP007ooonfX5o`00
03gooo]Z1Ol5o`3ooookJ]_ooo]Z000OoookJPGo0000?OoonfX5o`Go0?oooo]ZfooonfX001oooo]Z
1Ol0000moookJPKo1Ol0oooonf[JoookJP007ooonfX5o`0003gooo]Z1_l5o`3ooookJ][ooo]Z000O
oookJPGo0000?OoonfX6o`Go0?oooo]Zf_oonfX001oooo]Z1Ol0000moookJPKo1Ol0oooonf[Joook
JP007ooonfX5o`0003kooo]Z1Ol5o`3ooookJ][ooo]Z000OoookJPGo0000?_oonfX5o`Go0?oooo]Z
f_oonfX001oooo]Z1Ol0000noookJPGo1Ol0oooonf[JoookJP007ooonfX5o`0003kooo]Z1Ol5o`3o
oookJ][ooo]Z000OoookJPGo0000?_oonfX5o`Go0?oooo]Zf_oonfX001oooo]Z1Ol0000noookJPGo
1Ol0oooonf[JoookJP007ooonfX5o`0003kooo]Z1_l5o`3ooookJ]Wooo]Z000OoookJPGo0000?_oo
nfX6o`Go0?oooo]ZfOoonfX001oooo]Z1Ol0000noookJPKo1Ol0oooonf[IoookJP007ooonfX5o`00
03kooo]Z1_l5o`3ooookJ]Wooo]Z000OoookJPGo0000?ooonfX5o`Go0?oooo]ZfOoonfX001oooo]Z
1Ol0000ooookJPGo1Ol0oooonf[IoookJP007ooonfX5o`0003oooo]Z1Ol5o`3ooookJ]Wooo]Z000O
oookJPGo0000?ooonfX5o`Go0?oooo]ZfOoonfX001oooo]Z1Ol0000ooookJPGo1Ol0oooonf[Ioook
JP007ooonfX5o`0003oooo]Z1Ol5o`3ooookJ]Wooo]Z000OoookJPGo0000?ooonfX5o`Go0?oooo]Z
fOoonfX001oooo]Z1Ol0000ooookJPKo1Ol0oooonf[HoookJP007ooonfX5o`0003oooo]Z1_l5o`3o
oookJ]Sooo]Z000OoookJPGo0000?ooonfX6o`Go0?oooo]Zf?oonfX001oooo]Z1Ol0000ooookJPKo
1Ol0oooonf[HoookJP007ooonfX5o`00043ooo]Z1Ol5o`3ooookJ]Sooo]Z000OoookJPGo0000@?oo
nfX5o`Go0?oooo]Zf?oonfX001oooo]Z1Ol00010oookJPGo1Ol0oooonf[HoookJP007ooonfX5o`00
043ooo]Z1Ol5o`3ooookJ]Sooo]Z000OoookJPGo0000@?oonfX5o`Go0?oooo]Zf?oonfX001oooo]Z
1Ol00010oookJPGo1Ol0oooonf[HoookJP007ooonfX5o`00043ooo]Z1Ol5o`3ooookJ]Sooo]Z000O
oookJPGo0000@?oonfX6o`Go0?oooo]ZeooonfX001oooo]Z1Ol00010oookJPKo1Ol0oooonf[Goook
JP007ooonfX5o`00043ooo]Z1_l5o`3ooookJ]Oooo]Z000OoookJPGo0000@?oonfX6o`Go0?oooo]Z
eooonfX001oooo]Z1Ol00011oookJPGo1Ol0oooonf[GoookJP004OoonfX5o`00O`Wooo]Z1Ol00011
oookJPGo1Ol0oooonf[GoookJP004?oonfX7o`00O`Sooo]Z1Ol00011oookJPGo1Ol0oooonf[Goook
JP003ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000@OoonfX5o`Go0?oooo]ZeooonfX000?ooo]Z
2_l007l2oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00011oookJPGo1Ol0oooonf[GoookJP000ooo
nfX:o`00O`Sooo]Z0ol007l7oookJPOo0000?ooonfX5o`Go0?oooo]ZeooonfX001Gooo]Z0ol007l7
oookJPGo0000@OoonfX5o`Go0?oooo]ZeooonfX001?ooo]Z1?l007l8oookJPGo0000@OoonfX6o`Go
0?oooo]Ze_oonfX001?ooo]Z0ol007l9oookJPGo0000@OoonfX6o`Go0?oooo]Ze_oonfX001Gooo]Z
0_l007l8oookJPGo0000@OoonfX6o`Go0?oooo]Ze_oonfX000oooo]Z0ol007l3oookJP?o001o1ooo
nfX5o`00047ooo]Z1_l5o`3ooookJ]Kooo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00012
oookJPGo1Ol0oooonf[FoookJP004?oonfX7o`00O`Sooo]Z1Ol00012oookJPGo1Ol0oooonf[Foook
JP004OoonfX5o`00O`Wooo]Z1Ol00012oookJPGo1Ol0oooonf[FoookJP007ooonfX5o`0004;ooo]Z
1Ol5o`3ooookJ]Kooo]Z000OoookJPGo0000@_oonfX5o`Go0?oooo]Ze_oonfX001oooo]Z1Ol00012
oookJPKo1Ol0oooonf[EoookJP007ooonfX5o`0004;ooo]Z1_l5o`3ooookJ]Gooo]Z000OoookJPGo
0000@_oonfX6o`Go0?oooo]ZeOoonfX001oooo]Z1Ol00012oookJPKo1Ol0oooonf[EoookJP007ooo
nfX5o`0004?ooo]Z1Ol5o`3ooookJ]Gooo]Z000OoookJPGo0000@ooonfX5o`Go0?oooo]ZeOoonfX0
01oooo]Z1Ol00013oookJPGo1Ol0oooonf[EoookJP007ooonfX5o`0004?ooo]Z1_l5o`3ooookJ]Co
oo]Z000OoookJPGo0000@ooonfX6o`Go0?oooo]Ze?oonfX001oooo]Z1Ol00013oookJPKo1Ol0oooo
nf[DoookJP007ooonfX5o`0004?ooo]Z1_l5o`3ooookJ]Cooo]Z000OoookJPGo0000A?oonfX5o`Go
0?oooo]Ze?oonfX001oooo]Z1Ol00014oookJPGo1Ol0oooonf[DoookJP007ooonfX5o`0004Cooo]Z
1Ol5o`3ooookJ]Cooo]Z000OoookJPGo0000A?oonfX6o`Go0?oooo]ZdooonfX001oooo]Z1Ol00014
oookJPKo1Ol0oooonf[CoookJP007ooonfX5o`0004Cooo]Z1_l5o`3ooookJ]?ooo]Z000OoookJPGo
0000A?oonfX6o`Go0?oooo]ZdooonfX001oooo]Z1Ol00015oookJPGo1Ol0oooonf[CoookJP007ooo
nfX5o`0004Gooo]Z1Ol5o`3ooookJ]?ooo]Z000OoookJPGo0000AOoonfX5o`Go0?oooo]ZdooonfX0
01oooo]Z1Ol00015oookJPKo1Ol0oooonf[BoookJP007ooonfX5o`0004Gooo]Z1_l5o`3ooookJ];o
oo]Z000OoookJPGo0000AOoonfX6o`Go0?oooo]Zd_oonfX001oooo]Z1Ol00015oookJPKo1Ol0oooo
nf[BoookJP007ooonfX5o`0004Kooo]Z1Ol5o`3ooookJ];ooo]Z000OoookJPGo0000A_oonfX6o`Go
0?oooo]ZdOoonfX001oooo]Z1Ol00016oookJPKo1Ol0oooonf[AoookJP007ooonfX5o`0004Kooo]Z
1_l5o`3ooookJ]7ooo]Z000OoookJPGo0000A_oonfX6o`Go0?oooo]ZdOoonfX001oooo]Z1Ol00017
oookJPGo1Ol0oooonf[AoookJP007ooonfX5o`0004Oooo]Z1Ol5o`3ooookJ]7ooo]Z000OoookJPGo
0000AooonfX6o`Go0?oooo]Zd?oonfX001oooo]Z1Ol00017oookJPKo1Ol0oooonf[@oookJP007ooo
nfX5o`0004Oooo]Z1_l5o`3ooookJ]3ooo]Z000OoookJPGo0000AooonfX6o`Go0?oooo]Zd?oonfX0
01oooo]Z1Ol00018oookJPGo1Ol0oooonf[@oookJP007ooonfX5o`0004Sooo]Z1_l5o`3ooookJ/oo
oo]Z000OoookJPGo0000B?oonfX6o`Go0?oooo]ZcooonfX000oooo]Z2Ol007l7oookJPGo0000B?oo
nfX6o`Go0?oooo]ZcooonfX000oooo]Z2Ol007l7oookJPGo0000B?oonfX6o`Go0?oooo]ZcooonfX0
00oooo]Z1?l007l<oookJPGo0000BOoonfX5o`Go0?oooo]ZcooonfX000?ooo]Z2_l007l3oookJPCo
001o2ooonfX5o`0004Wooo]Z1_l5o`3ooookJ/kooo]Z0003oookJP[o001o1?oonfX5o`00O`Wooo]Z
1ol00017oookJPKo1Ol0oooonf[>oookJP004ooonfX4o`00O`Sooo]Z1Ol00019oookJPKo1Ol0oooo
nf[>oookJP005?oonfX3o`00O`Sooo]Z1Ol00019oookJPKo1Ol0oooonf[>oookJP005OoonfX3o`00
O`Oooo]Z1Ol0001:oookJPGo1Ol0oooonf[>oookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo
0000B_oonfX6o`Go0?oooo]ZcOoonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX5o`0004[ooo]Z
1_l5o`3ooookJ/gooo]Z000?oookJPCo001o0_oonfX3o`00O`Oooo]Z1Ol0001:oookJPKo1Ol0oooo
nf[=oookJP004?oonfX7o`00O`Sooo]Z1Ol0001:oookJPKo1Ol0oooonf[=oookJP004OoonfX5o`00
O`Wooo]Z1Ol0001;oookJPGo1Ol0oooonf[=oookJP007ooonfX5o`0004_ooo]Z1_l5o`3ooookJ/co
oo]Z000OoookJPGo0000BooonfX6o`Go0?oooo]Zc?oonfX001oooo]Z1Ol0001;oookJPKo1Ol0oooo
nf[<oookJP007ooonfX5o`0004_ooo]Z1_l5o`3ooookJ/cooo]Z000OoookJPGo0000C?oonfX5o`Go
0?oooo]Zc?oonfX001oooo]Z1Ol0001<oookJPKo1Ol0oooonf[;oookJP007ooonfX5o`0004cooo]Z
1_l5o`3ooookJ/_ooo]Z000OoookJPGo0000C?oonfX6o`Go0?oooo]ZbooonfX001oooo]Z1Ol0001<
oookJPKo1Ol0oooonf[;oookJP007ooonfX5o`0004gooo]Z1_l5o`3ooookJ/[ooo]Z000OoookJPGo
0000COoonfX6o`Go0?oooo]Zb_oonfX001oooo]Z1Ol0001=oookJPKo1Ol0oooonf[:oookJP007ooo
nfX5o`0004gooo]Z1ol5o`3ooookJ/Wooo]Z000OoookJPGo0000C_oonfX6o`Go0?oooo]ZbOoonfX0
01oooo]Z1Ol0001>oookJPKo1Ol0oooonf[9oookJP007ooonfX5o`0004kooo]Z1ol5o`3ooookJ/So
oo]Z000OoookJPGo0000CooonfX6o`Go0?oooo]Zb?oonfX001oooo]Z1Ol0001?oookJPKo1Ol0oooo
nf[8oookJP007ooonfX5o`0004oooo]Z1ol5o`3ooookJ/Oooo]Z000OoookJPGo0000D?oonfX6o`Go
0?oooo]ZaooonfX001oooo]Z1Ol0001@oookJPKo1Ol0oooonf[7oookJP007ooonfX5o`00053ooo]Z
1ol5o`3ooookJ/Kooo]Z000OoookJPGo0000DOoonfX6o`Go0?oooo]Za_oonfX001oooo]Z1Ol0001A
oookJPKo1Ol0oooonf[6oookJP007ooonfX5o`00057ooo]Z1ol5o`3ooookJ/Gooo]Z000OoookJPGo
0000D_oonfX6o`Go0?oooo]ZaOoonfX001oooo]Z1Ol0001BoookJPKo1Ol0oooonf[5oookJP007ooo
nfX5o`0005;ooo]Z1ol5o`3ooookJ/Cooo]Z000OoookJPGo0000DooonfX6o`Go0?oooo]Za?oonfX0
01oooo]Z1Ol0001CoookJPOo1Ol0oooonf[3oookJP007ooonfX5o`0005?ooo]Z1ol5o`3ooookJ/?o
oo]Z000OoookJPGo0000E?oonfX6o`Go0?oooo]Z`ooonfX001oooo]Z1Ol0001DoookJPOo1Ol0oooo
nf[2oookJP007ooonfX5o`0005Gooo]Z1_l5o`3ooookJ/;ooo]Z000OoookJPGo0000EOoonfX6o`Go
0?oooo]Z`_oonfX001oooo]Z1Ol0001EoookJPOo1Ol0oooonf[1oookJP007ooonfX5o`0005Kooo]Z
1_l5o`3ooookJ/7ooo]Z000OoookJPGo0000E_oonfX7o`Go0?oooo]Z`?oonfX001oooo]Z1Ol0001F
oookJPSo1Ol0oooonfZooookJP007ooonfX5o`0005Oooo]Z1ol5o`3ooookJ[oooo]Z000OoookJPGo
0000EooonfX8o`Go0?oooo]Z__oonfX001?ooo]Z0ol007l9oookJPGo0000F?oonfX7o`Go0?oooo]Z
__oonfX001?ooo]Z0ol007l9oookJPGo0000FOoonfX7o`Go0?oooo]Z_OoonfX001?ooo]Z0ol007l9
oookJPGo0000FOoonfX8o`Go0?oooo]Z_?oonfX000?ooo]Z2_l007l6oookJP?o001o2OoonfX5o`00
05[ooo]Z1ol5o`3ooookJ[cooo]Z0003oookJP[o001o1_oonfX3o`00O`Wooo]Z1ol0001HoookJPSo
1Ol0oooonfZkoookJP004ooonfX3o`00O`Wooo]Z1Ol0001KoookJPOo1Ol0oooonfZkoookJP004ooo
nfX3o`00O`Wooo]Z1Ol0001LoookJPOo1Ol0oooonfZjoookJP004ooonfX3o`00O`Wooo]Z1Ol0001L
oookJPSo1Ol0oooonfZioookJP004ooonfX3o`00O`Wooo]Z1Ol0001MoookJPSo1Ol0oooonfZhoook
JP004?oonfX6o`00O`Wooo]Z1Ol0001MoookJPWo1Ol0oooonfZgoookJP004?oonfX6o`00O`Wooo]Z
1Ol0001NoookJPWo1Ol0oooonfZfoookJP004_oonfX4o`00O`Wooo]Z1Ol0001OoookJPWo1Ol0oooo
nfZeoookJP004ooonfX3o`00O`Wooo]Z1Ol0001PoookJPSo1Ol0oooonfZeoookJP007ooonfX5o`00
067ooo]Z2?l5o`3ooookJ[Cooo]Z000OoookJPGo0000H_oonfX8o`Go0?oooo]Z/ooonfX001oooo]Z
1Ol0001SoookJPSo1Ol0oooonfZboookJP007ooonfX5o`0006?ooo]Z2Ol5o`3ooookJ[7ooo]Z000O
oookJPGo0000I?oonfX:o`Go0?oooo]Z[ooonfX001oooo]Z1Ol0001UoookJP[o1Ol0oooonfZ^oook
JP007ooonfX5o`0006Kooo]Z2ol5o`3ooookJZcooo]Z000OoookJPGo0000IooonfX;o`Go0?oooo]Z
ZooonfX001oooo]Z1Ol0001XoookJPco1Ol0oooonfZYoookJP007ooonfX5o`0006[ooo]Z2ol5o`3o
oookJZSooo]Z000OoookJPGo0000JooonfX<o`Go0?oooo]ZY_oonfX001oooo]Z1Ol0001]oookJP_o
1Ol0oooonfZUoookJP007ooonfX5o`0006kooo]Z3?l5o`3ooookJZ?ooo]Z000OoookJPGo0000L?oo
nfX<o`Go0?oooo]ZXOoonfX001oooo]Z1Ol0001aoookJPco1Ol0oooonfZPoookJP007ooonfX5o`00
07?ooo]Z3?l5o`3ooookJYkooo]Z000OoookJPGo0000M?oonfX=o`Go0?oooo]ZW?oonfX001oooo]Z
1Ol0001foookJPco1Ol0oooonfZKoookJP007ooonfX5o`0007Sooo]Z3?l5o`3ooookJYWooo]Z000O
oookJPGo0000NOoonfX=o`Go0?oooo]ZUooonfX001oooo]Z1Ol0001koookJPgo1Ol0oooonfZEoook
JP007ooonfX5o`0007gooo]Z3?l5o`3ooookJYCooo]Z000OoookJPGo0000O_oonfX=o`Go0?oooo]Z
T_oonfX001oooo]Z1Ol00020oookJPgo1Ol0oooonfZ@oookJP007ooonfX5o`0007kooo]Z1?l007l=
o`Go06oooo]Z0ol007l5oookJPGo001oM_oonfX3o`00O`Gooo]Z1Ol007mcoookJPWo001o0ooonfX5
o`00O`[ooo]Z000OoookJPGo0000OOoonfX7o`00O`go1Ol0KOoonfX3o`00O`Cooo]Z1ol007meoook
JP?o001o1?oonfX7o`00Og;ooo]Z2Ol007l2oookJPOo001o2OoonfX001oooo]Z1Ol0001loookJPCo
001o00Gooo]Zo`00Ool007oo001ooookJP0>o`Go06_ooo]Z0ol007l4oookJP?o001o00Cooo]Zo`00
Ool007oo001oMOoonfX3o`00O`?ooo]Z1?l007l01?oonf[o001oo`00Ool007mboookJPCo001o1ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`Wooo]Z000OoookJPGo0000O?oonfX3o`00O`?ooo]Z0ol0
07l2oookJPgo1Ol0J_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001oM?oonfX3o`00O`?ooo]Z0ol0
07l3oookJP?o001oL_oonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o2?oonfX001oooo]Z1Ol00022
oookJP?o001o1?oonfX=o`Go06Sooo]Z0ol007l3oookJP?o001o0ooonfX3o`00OgCooo]Z0ol007l9
oookJP?o001oLooonfX5o`00O`?ooo]Z0ol007l3oookJP?o001o2?oonfX001oooo]Z1Ol00022oook
JP?o001o1_oonfX=o`Go06Kooo]Z0ol007l3oookJP?o001o00?ooo]Zool00?oo00004ooo001Toook
JP?o001o2OoonfX3o`00OgGooo]Z1?l007l2oookJP?o001o0ooonfX3o`00O`Sooo]Z000OoookJPGo
0000OOoonfX2o`00O`;ooo]Z1?l007l8oookJPgo1Ol0I?oonfX3o`00O`03oookJ_oo003oo`0001oo
o`005_oonfX>o`Go03[ooo]Z0ol007l4oookJP;o001o0_oonfX4o`00OgKooo]Z0ol007l2oookJP?o
001o0ooonfX3o`00O`Sooo]Z000OoookJPGo0000OOoonfX7o`00O`_ooo]Z3Ol5o`1QoookJR[oo`00
2ooonfXOo`Go033ooo]Z0ol007l4oookJPOo001oN?oonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l8oookJP007ooonfX5o`0007gooo]Z1_l007l=oookJPko1Ol0G?oonfX`ool000Gooo]Z
9_l5o`0/oookJP?o001o1?oonfX6o`00Og?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`Sooo]Z000OoookJPGo0000OOoonfX2o`00Oa?ooo]Z3_l5o`1GoookJS?oo`00
;_l5o`0VoookJPKo001o1?oonfX2o`00Obkooo]Z6_oo000CoookJQKo1Ol01_oonfX3o`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o2?oonfX001oooo]Z1Ol0001moookJP;o001o
5OoonfX>o`Go05?ooo]Z5ooo000=oookJPgoo`00=?l5o`0ToookJPKo001o1?oonfX2o`00ObSooo]Z
9?oo0009oookJR;o1Ol01?l007l2oookJP?o001o0_oonfX3o`00O`04oookJ_l007oo001oo`00O`Wo
oo]Z000OoookJPGo0000O_oonfX7o`00Oa7ooo]Z3_l5o`1>oookJQCoo`001_l007lCoookJPCoo`00
6_l5o`06oookJQ[o1Ol08ooonfX4o`00O`Gooo]Z1ol007lNoookJRcoo`00:ol5o`04o`00O`?ooo]Z
1ol007l9oookJP007ooonfX5o`0007kooo]Z1ol007lCoookJPgo1Ol0BooonfXAool000Gooo]Z1Ol0
07lFoookJQGo1Ol05ooonfXBo`Go02;ooo]Z0ol007l5oookJPOo001o6ooonfX[ool003Co1Ol00ooo
nfX5o`00O`[ooo]Z000OoookJPGo0000V_oonfX=o`Go04Oooo]Z4?oo000QoookJQCo1Ol01?oo000J
oookJQ7o1Ol0A_oonfX[ool003[o1Ol03ooonfX001oooo]Z1Ol0002LoookJPgo1Ol0@ooonfX?ool0
027ooo]Z4_l5o`0;ool001_ooo]Z4?l5o`11oookJQOoo`004_oonfX3ool001So1Ol03_oonfXGo`Go
00kooo]Z000OoookJPGo0000W_oonfX=o`Go03oooo]Z3ooo000QoookJQ3o1Ol000?ooo]Zool00?oo
00003ooo000JoookJQ7o1Ol0>ooonfXDool001Sooo]Z5Ol5o`07ool001?ooo]Z4Ol5o`0>oookJP00
7ooonfX5o`000:3ooo]Z3Ol5o`0koookJPkoo`008_oonfX?o`Go00Oooo]Z4Ooo000JoookJQ3o1Ol0
=_oonfXCool001Wooo]Z4ol5o`0?ool001Cooo]Z3Ol5o`0>oookJP007ooonfX5o`000:7ooo]Z3_l5
o`0goookJPkoo`008_oonfX?o`Go00_ooo]Z4Ooo000JoookJQ3o1Ol0<_oonfXBool001Wooo]Z4_l5
o`03oookJQ;oo`005ooonfX8o`Go00kooo]Z000OoookJPGo0000XooonfX>o`Go03?ooo]Z3_oo000R
oookJPoo1Ol04?oonfXAool001[ooo]Z4?l5o`0/oookJQ;oo`006OoonfXBo`Go00Wooo]Z4_oo000G
oookJPGo1Ol03_oonfX001;ooo]Z3Ol0000kool006oo00003_l5o`0^o`0000ooo`008Ol0000?o`Go
01Go00004Ooo000Jo`00013o1Ol0:?l0000Aool001Wo00004ol5o`0>o`0001;oo`009_l00001oook
JP004_oonfX=o`0004_oo`00HOl0000>o`Go02[o00003ooo000Qo`0000oo1Ol06_l0000Aool001[o
00004?l5o`0Ro`00017oo`006Ol0000Co`Go01Co00004_oo000So`00007ooo]Z000BoookJPgo0000
E_oo001Ho`0000ko1Ol09_l0000?ool0027o00003ol5o`0Oo`00013oo`006_l0000@o`Go01go0000
4Ooo000Jo`0001;o1Ol06_l0000Bool0023o00000OoonfX001;ooo]Z3Ol0001Lool005Co00003_l5
o`0Ro`0000ooo`008Ol0000?o`Go02?o00004Ooo000Io`00017o1Ol06?l0000Aool001Wo00004_l5
o`0Oo`0001?oo`007Ol00001oookJP004_oonfX=o`0006;oo`00D?l0000>o`Go01ko00003ooo000Q
o`0000oo1Ol0:?l0000@ool001[o00004?l5o`0Co`00017oo`006_l0000Ao`Go02Go00005?oo000I
o`00007ooo]Z000OoookJPGo0000<_oonfX`ool001oooo]Z00?o0000oookJ_oonfX0:ooonfX>o`Go
01[ooo]Z3_oo000OoookJP03o`000?oonf[o1Ol000ko1Ol0;OoonfXAool001Wooo]Z4Ol5o`0:oook
JP04o`000?oonf[ooo]ZoookJQ7oo`006OoonfXAo`Go02_ooo]Z5?oo0006oookJP03o`000?oonf[o
oo]Z00kooo]Z000OoookJPGo0000@_oonfXUool001[ooo]Z00?o0000oookJ_oonfX0;OoonfX>o`Go
01Kooo]Z3_oo000QoookJPoo1Ol0<_oonfX@ool001[ooo]Z4_l5o`06oookJP03o`000?oo003oo`00
00ooo`006OoonfXAo`Go037ooo]Z5Ooo0002oookJP03o`000?oonf[ooo]Z00kooo]Z000OoookJPGo
0000COoonfXNool004Sooo]Z3_l5o`0AoookJPooo`008OoonfX?o`Go03Kooo]Z4Ooo000IoookJQGo
1Ol04?oo000IoookJQ;o1Ol0=_oonfXEool0013ooo]Z000OoookJPGo0000DooonfXKool004Oooo]Z
3_l5o`0=oookJPooo`008OoonfX?o`Go03_ooo]Z4Ooo000IoookJQGo1Ol02ooo000GoookJQ?o1Ol0
??oonfXDool000kooo]Z000OoookJPGo0000FOoonfXIool004Gooo]Z3_l5o`09oookJPooo`008?oo
nfX@o`Go03oooo]Z4_oo000HoookJQOo1Ol01?oo000FoookJQGo1Ol0@_oonfX@ool000kooo]Z000O
oookJPGo0000G_oonfXHool004?ooo]Z3ol5o`04oookJPooo`007ooonfX@o`Go04Gooo]Z4ooo000G
oookJQSo1Ol04OoonfXGo`Go04Sooo]Z3Ooo000>oookJP007ooonfX5o`0006?ooo]Z5ooo0011oook
JQ3o1Ol03_oo000NoookJQ7o1Ol0BOoonfXHool000cooo]Z2?oo000io`Go04oooo]Z2Ooo000>oook
JP007ooonfX5o`0006Oooo]Z5_oo0010oookJQ7o1Ol02?oo000NoookJQ;o1Ol0C_oonfX^ool0037o
1Ol0EOoonfX6ool000kooo]Z000OoookJPGo0000J_oonfXGool003kooo]Z4_l5o`03ool001gooo]Z
4ol5o`1CoookJRkoo`00:_l5o`1]oookJP007ooonfX5o`0006kooo]Z5ooo000loookJQ?o1Ol06Ooo
nfXDo`Go05Wooo]Z:?oo0007oookJR;o1Ol0LOoonfX001oooo]Z1Ol0001boookJQOoo`00=ooonfX4
ool001Oo1Ol03_oonfXEo`Go063ooo]Z7ooo000@oookJQWo1Ol0M_oonfX001oooo]Z1Ol0001foook
JQOoo`00<?oonfX:ool003Co1Ol0J_oonfXDool00:?ooo]Z000OoookJPGo0000NOoonfXGool002[o
oo]Z4?oo000^o`Go0?oooo]Z9OoonfX001oooo]Z1Ol0001moookJQSoo`008OoonfXCool000Cooo]Z
:?l5o`3ooookJRSooo]Z000OoookJPGo0000POoonfXJool001Oooo]Z5Ooo0009oookJR7o1Ol0oooo
nfX/oookJP007ooonfX5o`0008Gooo]Z?ooo000CoookJQKo1Ol0oooonfX`oookJP007ooonfX5o`00
08Wooo]Z>?oo003ooookJUcooo]Z000OoookJPGo0000S?oonfXbool00?oooo]ZGooonfX001oooo]Z
1Ol0002AoookJRWoo`00oooonfYSoookJP007ooonfX5o`0009Oooo]Z7ooo003ooookJVOooo]Z000O
oookJPGo0000oooonf[ooookJQkooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000OoookJPGo
0000oooonf[ooookJQkooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000OoookJPGo0000oooo
nf[ooookJQkooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000OoookJPGo0000oooonf[ooook
JQkooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.28825, -5.91134, \
0.0380754, 0.0184981}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{BesselJ[1/2, x], \ BesselY[1/2, x]}, {x, 0, 20}, \ 
      PlotStyle \[Rule] MyPlotStyle[2]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.372589 0.33972 [
[.2619 .36009 -7 -20 ]
[.2619 .36009 7 0 ]
[.5 .36009 -12 -20 ]
[.5 .36009 12 0 ]
[.7381 .36009 -12 -20 ]
[.7381 .36009 12 0 ]
[.97619 .36009 -12 -20 ]
[.97619 .36009 12 0 ]
[.01131 .03287 -26.9375 -10 ]
[.01131 .03287 0 10 ]
[.01131 .1178 -51.9375 -10 ]
[.01131 .1178 0 10 ]
[.01131 .20273 -41.9375 -10 ]
[.01131 .20273 0 10 ]
[.01131 .28766 -51.9375 -10 ]
[.01131 .28766 0 10 ]
[.01131 .45752 -39 -10 ]
[.01131 .45752 0 10 ]
[.01131 .54245 -29 -10 ]
[.01131 .54245 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .37259 m
.2619 .37884 L
s
gsave
.2619 .36009 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .37259 m
.5 .37884 L
s
gsave
.5 .36009 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.7381 .37259 m
.7381 .37884 L
s
gsave
.7381 .36009 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.97619 .37259 m
.97619 .37884 L
s
gsave
.97619 .36009 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .37259 m
.07143 .37634 L
s
.11905 .37259 m
.11905 .37634 L
s
.16667 .37259 m
.16667 .37634 L
s
.21429 .37259 m
.21429 .37634 L
s
.30952 .37259 m
.30952 .37634 L
s
.35714 .37259 m
.35714 .37634 L
s
.40476 .37259 m
.40476 .37634 L
s
.45238 .37259 m
.45238 .37634 L
s
.54762 .37259 m
.54762 .37634 L
s
.59524 .37259 m
.59524 .37634 L
s
.64286 .37259 m
.64286 .37634 L
s
.69048 .37259 m
.69048 .37634 L
s
.78571 .37259 m
.78571 .37634 L
s
.83333 .37259 m
.83333 .37634 L
s
.88095 .37259 m
.88095 .37634 L
s
.92857 .37259 m
.92857 .37634 L
s
.01 w
0 .37259 m
1 .37259 L
s
.25 Mabswid
.02381 .03287 m
.03006 .03287 L
s
gsave
.01131 .03287 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .1178 m
.03006 .1178 L
s
gsave
.01131 .1178 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.02381 .20273 m
.03006 .20273 L
s
gsave
.01131 .20273 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .28766 m
.03006 .28766 L
s
gsave
.01131 .28766 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.02381 .45752 m
.03006 .45752 L
s
gsave
.01131 .45752 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.02381 .54245 m
.03006 .54245 L
s
gsave
.01131 .54245 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04985 m
.02756 .04985 L
s
.02381 .06684 m
.02756 .06684 L
s
.02381 .08383 m
.02756 .08383 L
s
.02381 .10081 m
.02756 .10081 L
s
.02381 .13478 m
.02756 .13478 L
s
.02381 .15177 m
.02756 .15177 L
s
.02381 .16876 m
.02756 .16876 L
s
.02381 .18574 m
.02756 .18574 L
s
.02381 .21971 m
.02756 .21971 L
s
.02381 .2367 m
.02756 .2367 L
s
.02381 .25369 m
.02756 .25369 L
s
.02381 .27067 m
.02756 .27067 L
s
.02381 .30464 m
.02756 .30464 L
s
.02381 .32163 m
.02756 .32163 L
s
.02381 .33862 m
.02756 .33862 L
s
.02381 .3556 m
.02756 .3556 L
s
.02381 .38957 m
.02756 .38957 L
s
.02381 .40656 m
.02756 .40656 L
s
.02381 .42355 m
.02756 .42355 L
s
.02381 .44053 m
.02756 .44053 L
s
.02381 .47451 m
.02756 .47451 L
s
.02381 .49149 m
.02756 .49149 L
s
.02381 .50848 m
.02756 .50848 L
s
.02381 .52546 m
.02756 .52546 L
s
.02381 .01588 m
.02756 .01588 L
s
.02381 .55944 m
.02756 .55944 L
s
.02381 .57642 m
.02756 .57642 L
s
.02381 .59341 m
.02756 .59341 L
s
.02381 .61039 m
.02756 .61039 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02381 .37284 m
.02499 .41517 L
.02605 .43142 L
.02846 .45713 L
.03068 .47521 L
.03279 .48958 L
.0379 .51788 L
.04262 .53854 L
.05212 .5695 L
.05713 .58128 L
.06244 .59082 L
.06743 .59723 L
.07023 .5998 L
.07156 .60077 L
.0728 .60152 L
.07404 .60215 L
.07517 .6026 L
.07643 .60298 L
.07712 .60312 L
.07777 .60322 L
.07895 .60332 L
.08004 .6033 L
.08123 .60317 L
.0825 .60291 L
.0832 .6027 L
.08387 .60248 L
.08512 .60195 L
.08794 .60032 L
.09037 .59843 L
.09302 .59587 L
.09903 .58825 L
.10458 .57908 L
.12324 .53562 L
.14385 .4719 L
.16482 .40085 L
.18405 .33985 L
.2029 .29147 L
.21237 .27316 L
.2177 .26489 L
.22274 .2585 L
.22767 .25359 L
.23026 .25155 L
.23301 .2498 L
.23532 .24866 L
.23655 .24817 L
.23787 .24775 L
.23908 .24744 L
.24018 .24723 L
.24129 .24709 L
.24235 .24702 L
Mistroke
.24367 .24701 L
.24487 .24709 L
.24553 .24717 L
.24625 .24728 L
.24755 .24755 L
.24877 .24789 L
.25006 .24833 L
.25237 .24934 L
.25507 .25086 L
.25758 .25262 L
.2633 .25774 L
.27378 .27093 L
.28369 .28731 L
.30226 .32527 L
.34064 .41061 L
.36045 .44474 L
.37045 .45693 L
.37614 .4621 L
.37891 .46413 L
.38147 .46573 L
.38394 .46701 L
.38619 .46794 L
.38868 .46872 L
.39004 .46903 L
.39133 .46926 L
.39259 .46941 L
.39323 .46946 L
.39392 .46949 L
.39516 .4695 L
.39631 .46946 L
.39701 .4694 L
.39767 .46933 L
.39891 .46914 L
.40024 .46887 L
.4017 .46849 L
.40391 .46774 L
.40636 .46669 L
.41131 .46381 L
.4159 .46031 L
.42021 .45633 L
.44037 .43 L
.45887 .39811 L
.47937 .36019 L
.49846 .32823 L
.50792 .31517 L
.51686 .3051 L
.5218 .3006 L
.52717 .29664 L
.52953 .29521 L
.53204 .2939 L
Mistroke
.53419 .29296 L
.53654 .29213 L
.53785 .29175 L
.53906 .29145 L
.54032 .2912 L
.54146 .29102 L
.54258 .29089 L
.54364 .29081 L
.54475 .29076 L
.54596 .29077 L
.54718 .29083 L
.54788 .29089 L
.54852 .29096 L
.54983 .29114 L
.55123 .29141 L
.55377 .29206 L
.55609 .29286 L
.56059 .29493 L
.56549 .29795 L
.57439 .30533 L
.5838 .31553 L
.59418 .32911 L
.61519 .3613 L
.63618 .39445 L
.64537 .40766 L
.65542 .42039 L
.66454 .42996 L
.67428 .43773 L
.67967 .44084 L
.68456 .44288 L
.68692 .4436 L
.68817 .44391 L
.68948 .44418 L
.69063 .44438 L
.6919 .44454 L
.69305 .44464 L
.69412 .4447 L
.69538 .44473 L
.69608 .44472 L
.69671 .44469 L
.69795 .44462 L
.69911 .4445 L
.70047 .4443 L
.70172 .44408 L
.70454 .44338 L
.70684 .44264 L
.70935 .44164 L
.71443 .43906 L
.72402 .4322 L
.73297 .42373 L
Mistroke
.77195 .37239 L
.79181 .34506 L
.80228 .33256 L
.81338 .32158 L
.82326 .31423 L
.82887 .31119 L
.83157 .31003 L
.83414 .30912 L
.83644 .30846 L
.83766 .30818 L
.83896 .30792 L
.84015 .30772 L
.84124 .30758 L
.84234 .30747 L
.84337 .3074 L
.84457 .30736 L
.84585 .30736 L
.84694 .3074 L
.84814 .30747 L
.84943 .30761 L
.85081 .3078 L
.8533 .30828 L
.85586 .30896 L
.85858 .30989 L
.86347 .31204 L
.86873 .31506 L
.87453 .31917 L
.89465 .33882 L
.93484 .38984 L
.95368 .41105 L
.96315 .41949 L
.97351 .42652 L
.97619 .42792 L
Mfstroke
.02 1 0 r
.04468 0 m
.04761 .03603 L
.05217 .08182 L
.06244 .16539 L
.08405 .30003 L
.10458 .39862 L
.11417 .43574 L
.12439 .46869 L
.13403 .49322 L
.14277 .5098 L
.14765 .51667 L
.15031 .51971 L
.1528 .52209 L
.1551 .52391 L
.15719 .52525 L
.15952 .52637 L
.1608 .52683 L
.16202 .52716 L
.16321 .52739 L
.16453 .52753 L
.16519 .52756 L
.16591 .52756 L
.1672 .52747 L
.16842 .52728 L
.1697 .52698 L
.17079 .52664 L
.17199 .52618 L
.17471 .5248 L
.17761 .52283 L
.18284 .51801 L
.18817 .51154 L
.19308 .50426 L
.20419 .48377 L
.22434 .43607 L
.24469 .38187 L
.26374 .3339 L
.28201 .29674 L
.29226 .28141 L
.29718 .2757 L
.30163 .27149 L
.30641 .26801 L
.30903 .26657 L
.3115 .26552 L
.31261 .26514 L
.31379 .2648 L
.31481 .26456 L
.3159 .26436 L
.31707 .26421 L
.31817 .26413 L
.31947 .26411 L
Mistroke
.32065 .26416 L
.32194 .26429 L
.32259 .26438 L
.32331 .26451 L
.32576 .26513 L
.32714 .26559 L
.32862 .2662 L
.33131 .26754 L
.33657 .27108 L
.34139 .27535 L
.35122 .28683 L
.36035 .3004 L
.38106 .3385 L
.42016 .41509 L
.43043 .43128 L
.44155 .44532 L
.44665 .45037 L
.45205 .45468 L
.45665 .45749 L
.45927 .45873 L
.46171 .45964 L
.46297 .46002 L
.46431 .46036 L
.46546 .46059 L
.46671 .46079 L
.4674 .46087 L
.46804 .46093 L
.46929 .461 L
.46996 .46101 L
.47068 .461 L
.47144 .46097 L
.47215 .46092 L
.47343 .46079 L
.47465 .4606 L
.47574 .46038 L
.47693 .4601 L
.47959 .45926 L
.48204 .45826 L
.48633 .45598 L
.49105 .45272 L
.50059 .44389 L
.51073 .43161 L
.52001 .41828 L
.5409 .3838 L
.5615 .34906 L
.57153 .33381 L
.58062 .32167 L
.58951 .31177 L
.59912 .30359 L
.60441 .30032 L
Mistroke
.60673 .29917 L
.60928 .29812 L
.61152 .29737 L
.61393 .29675 L
.61526 .2965 L
.61647 .29631 L
.61768 .29618 L
.61884 .2961 L
.61998 .29607 L
.62121 .29608 L
.62237 .29614 L
.62343 .29623 L
.62461 .29638 L
.6259 .29659 L
.6285 .29719 L
.63107 .298 L
.63382 .2991 L
.63876 .30167 L
.64842 .3088 L
.65719 .31743 L
.69719 .37286 L
.71552 .39955 L
.72594 .41288 L
.73567 .42346 L
.74527 .43169 L
.75065 .43523 L
.75557 .43775 L
.75807 .43876 L
.76073 .43964 L
.76227 .44004 L
.76366 .44035 L
.76507 .4406 L
.76637 .44078 L
.7676 .44091 L
.7689 .44099 L
.77021 .44102 L
.77096 .44101 L
.77165 .44099 L
.7729 .44091 L
.77405 .4408 L
.77537 .44063 L
.77661 .44041 L
.77899 .43988 L
.78122 .43923 L
.7863 .43721 L
.79125 .43456 L
.79658 .43098 L
.81502 .41354 L
.85623 .35958 L
.87681 .33464 L
Mistroke
.88683 .32498 L
.89592 .31811 L
.90049 .31541 L
.90544 .3131 L
.90771 .31226 L
.9101 .31152 L
.91235 .31097 L
.9144 .31059 L
.9156 .31042 L
.91674 .31029 L
.91795 .3102 L
.91926 .31015 L
.9204 .31014 L
.92161 .31016 L
.92265 .31022 L
.92379 .31032 L
.92513 .31048 L
.92635 .31066 L
.92911 .31123 L
.93154 .31191 L
.9341 .31278 L
.9391 .31498 L
.94364 .31752 L
.95384 .32494 L
.9722 .34325 L
.97619 .34785 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00>?oonfX5o`000?oooo]ZoooonfX5oookJP00>?oonfX5o`000?oooo]Z
oooonfX5oookJP00>?oonfX5o`0000Kooo]Z1Ol5o`3ooookJ_Wooo]Z000hoookJPGo00001_oonfX5
o`Go0?oooo]ZnOoonfX003Sooo]Z1Ol00006oookJPGo1Ol0oooonf[ioookJP00>?oonfX5o`0000Ko
oo]Z1Ol5o`3ooookJ_Wooo]Z000hoookJPGo00001_oonfX6o`Go0?oooo]Zn?oonfX003Sooo]Z1Ol0
0006oookJPKo1Ol0oooonf[hoookJP00>?oonfX5o`0000Kooo]Z1_l5o`3ooookJ_Sooo]Z000hoook
JPGo00001_oonfX6o`Go0?oooo]Zn?oonfX003Sooo]Z1Ol00007oookJPGo1Ol0oooonf[hoookJP00
>?oonfX5o`0000Oooo]Z1Ol5o`3ooookJ_Sooo]Z000hoookJPGo00001ooonfX5o`Go0?oooo]Zn?oo
nfX003Sooo]Z1Ol00007oookJPGo1Ol0oooonf[hoookJP00>?oonfX5o`0000Oooo]Z1Ol5o`3ooook
J_Sooo]Z000hoookJPGo00001ooonfX6o`Go0?oooo]ZmooonfX002cooo]Z0ol007l9oookJPGo0000
1ooonfX6o`Go0?oooo]ZmooonfX002cooo]Z0ol007l9oookJPGo00001ooonfX6o`Go0?oooo]Zmooo
nfX002cooo]Z0ol007l9oookJPGo00001ooonfX6o`Go0?oooo]ZmooonfX001cooo]Z2_l007l6oook
JP?o001o2OoonfX5o`0000Sooo]Z1Ol5o`3ooookJ_Oooo]Z000LoookJP[o001o1_oonfX3o`00O`Wo
oo]Z1_l00007oookJPGo1Ol0oooonf[goookJP00;?oonfX3o`00O`Wooo]Z1Ol00008oookJPGo1Ol0
oooonf[goookJP00;?oonfX3o`00O`Wooo]Z1Ol00008oookJPGo1Ol0oooonf[goookJP00;?oonfX3
o`00O`Wooo]Z1Ol00008oookJPGo1Ol0oooonf[goookJP00;?oonfX3o`00O`Wooo]Z1Ol00008oook
JPGo1Ol0oooonf[goookJP00:OoonfX6o`00O`Wooo]Z1Ol00008oookJPGo1Ol0oooonf[goookJP00
:OoonfX6o`00O`Wooo]Z1Ol00008oookJPKo1Ol0oooonf[foookJP00:ooonfX4o`00O`Wooo]Z1Ol0
0008oookJPKo1Ol0oooonf[foookJP00;?oonfX3o`00O`Wooo]Z1Ol00008oookJPKo1Ol0oooonf[f
oookJP00>?oonfX5o`0000Sooo]Z1_l5o`3ooookJ_Kooo]Z000hoookJPGo00002OoonfX5o`Go0?oo
oo]Zm_oonfX003Sooo]Z1Ol00009oookJPGo1Ol0oooonf[foookJP00>?oonfX5o`0000Wooo]Z1Ol5
o`3ooookJ_Kooo]Z000hoookJPGo00002OoonfX5o`Go0?oooo]Zm_oonfX003Sooo]Z1Ol00009oook
JPGo1Ol0oooonf[foookJP00>?oonfX5o`0000Wooo]Z1Ol5o`3ooookJ_Kooo]Z000hoookJPGo0000
2OoonfX5o`Go0?oooo]Zm_oonfX003Sooo]Z1Ol00009oookJPGo1Ol0oooonf[foookJP00>?oonfX5
o`0000Wooo]Z1_l5o`3ooookJ_Gooo]Z000hoookJPGo00002OoonfX6o`Go0?oooo]ZmOoonfX003So
oo]Z1Ol00009oookJPKo1Ol0oooonf[eoookJP00>?oonfX5o`0000Wooo]Z1_l5o`3ooookJ_Gooo]Z
000hoookJPGo00002_oonfX5o`Go0?oooo]ZmOoonfX003Sooo]Z1Ol0000:oookJPGo1Ol0oooonf[e
oookJP00>?oonfX5o`0000[ooo]Z1Ol5o`3ooookJ_Gooo]Z000hoookJPGo00002_oonfX5o`Go0?oo
oo]ZmOoonfX003Sooo]Z1Ol0000:oookJPGo1Ol0oooonf[eoookJP00>?oonfX5o`0000[ooo]Z1Ol5
o`3ooookJ_Gooo]Z000hoookJPGo00002_oonfX6o`Go0?oooo]Zm?oonfX003Sooo]Z1Ol0000:oook
JPKo1Ol0oooonf[doookJP00>?oonfX5o`0000[ooo]Z1_l5o`3ooookJ_Cooo]Z000hoookJPGo0000
2_oonfX6o`Go0?oooo]Zm?oonfX003Sooo]Z1Ol0000;oookJPGo1Ol0oooonf[doookJP00>?oonfX5
o`0000_ooo]Z1Ol5o`3ooookJ_Cooo]Z000hoookJPGo00002ooonfX5o`Go0?oooo]Zm?oonfX003So
oo]Z1Ol0000;oookJPGo1Ol0oooonf[doookJP00>?oonfX5o`0000_ooo]Z1Ol5o`3ooookJ_Cooo]Z
000hoookJPGo00002ooonfX6o`Go0?oooo]ZlooonfX003Sooo]Z1Ol0000;oookJPKo1Ol0oooonf[c
oookJP00>?oonfX5o`0000_ooo]Z1_l5o`3ooookJ_?ooo]Z000AoookJPGo001o1?oonfX3o`00O`?o
oo]Z0ol007l7oookJPGo001o2OoonfX5o`0000_ooo]Z1_l5o`3ooookJ_?ooo]Z000@oookJPOo001o
0ooonfX3o`00O`?ooo]Z0ol007l6oookJPOo001o2?oonfX5o`0000cooo]Z1Ol5o`3ooookJ_?ooo]Z
000@oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`?ooo]Z0ol007l5oookJPCo001o
00Cooo]Zo`00Ool007oo001o2?oonfX5o`0000cooo]Z1Ol5o`3ooookJ_?ooo]Z0003oookJP[o001o
0_oonfX3o`00O`?ooo]Z0ol007l9oookJP;o001o1OoonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000
3?oonfX5o`Go0?oooo]ZlooonfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Wooo]Z0ol0
07l:oookJP?o001o1ooonfX6o`0000_ooo]Z1Ol5o`3ooookJ_?ooo]Z000?oookJP?o001o0ooonfX3
o`00O`Wooo]Z0ol007l:oookJP?o001o1ooonfX5o`0000cooo]Z1Ol5o`3ooookJ_?ooo]Z000?oook
JP?o001o0ooonfX3o`00O`[ooo]Z0_l007l5oookJP;o001o0_oonfX4o`00O`Oooo]Z1Ol0000<oook
JPKo1Ol0oooonf[boookJP003ooonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o1?oonfX7o`00O`So
oo]Z1Ol0000<oookJPKo1Ol0oooonf[boookJP003ooonfX3o`00O`?ooo]Z0ol007l;oookJP;o001o
1?oonfX6o`00O`Wooo]Z1Ol0000<oookJPKo1Ol0oooonf[boookJP003ooonfX3o`00O`?ooo]Z0ol0
07l<oookJP;o001o0ooonfX2o`00O`gooo]Z1Ol0000<oookJPKo1Ol0oooonf[boookJP004?oonfX3
o`00O`04oookJ_l007oo001oo`00O`gooo]Z0_l007l3oookJP;o001o3OoonfX5o`0000gooo]Z1Ol5
o`3ooookJ_;ooo]Z000@oookJPOo001o1ooonfX9o`00O`?ooo]Z1ol007l7oookJPGo00003OoonfX5
o`Go0?oooo]Zl_oonfX0017ooo]Z1Ol007l8oookJPWo001o0ooonfX7o`00O`Oooo]Z1Ol0000=oook
JPGo1Ol0oooonf[boookJP00>?oonfX5o`0000gooo]Z1Ol5o`3ooookJ_;ooo]Z000hoookJPGo0000
3OoonfX5o`Go0?oooo]Zl_oonfX003Sooo]Z1Ol0000=oookJPKo1Ol0oooonf[aoookJP00>?oonfX5
o`0000gooo]Z1_l5o`3ooookJ_7ooo]Z000hoookJPGo00003OoonfX6o`Go0?oooo]ZlOoonfX003So
oo]Z1Ol0000=oookJPKo1Ol0oooonf[aoookJP00>?oonfX5o`0000kooo]Z1Ol5o`3ooookJ_7ooo]Z
000hoookJPGo00003_oonfX5o`Go0?oooo]ZlOoonfX003Sooo]Z1Ol0000>oookJPGo1Ol0oooonf[a
oookJP00>?oonfX5o`0000kooo]Z1Ol5o`3ooookJ_7ooo]Z000hoookJPGo00003_oonfX5o`Go0?oo
oo]ZlOoonfX003Sooo]Z1Ol0000>oookJPKo1Ol0oooonf[`oookJP00>?oonfX5o`0000kooo]Z1_l5
o`3ooookJ_3ooo]Z000hoookJPGo00003_oonfX6o`Go0?oooo]Zl?oonfX003Sooo]Z1Ol0000>oook
JPKo1Ol0oooonf[`oookJP00>?oonfX5o`0000oooo]Z1Ol5o`3ooookJ_3ooo]Z000hoookJPGo0000
3ooonfX5o`Go0?oooo]Zl?oonfX003Sooo]Z1Ol0000?oookJPGo1Ol0oooonf[`oookJP00>?oonfX5
o`0000oooo]Z1_l5o`3ooookJ^oooo]Z000hoookJPGo00003ooonfX6o`Go0?oooo]ZkooonfX003So
oo]Z1Ol0000?oookJPKo1Ol0oooonf[_oookJP00>?oonfX5o`0000oooo]Z1_l5o`3ooookJ^oooo]Z
000hoookJPGo00004?oonfX5o`Go0?oooo]ZkooonfX003Sooo]Z1Ol0000@oookJPGo1Ol0oooonf[_
oookJP00>?oonfX5o`00013ooo]Z1_l5o`3ooookJ^kooo]Z000hoookJPGo00004?oonfX6o`Go0?oo
oo]Zk_oonfX003Sooo]Z1Ol0000@oookJPKo1Ol0oooonf[^oookJP00>?oonfX5o`00013ooo]Z1_l5
o`3ooookJ^kooo]Z000hoookJPGo00004OoonfX5o`Go0?oooo]Zk_oonfX003Sooo]Z1Ol0000Aoook
JPGo1Ol0oooonf[^oookJP00>?oonfX5o`00017ooo]Z1_l5o`3ooookJ^gooo]Z000hoookJPGo0000
4OoonfX6o`Go0?oooo]ZkOoonfX001_ooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Wooo]Z1Ol0
000AoookJPKo1Ol0oooonf[]oookJP006_oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5
o`00017ooo]Z1_l5o`3ooookJ^gooo]Z000JoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0001;ooo]Z1Ol5
o`3ooookJ^gooo]Z000=oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3
o`00O`Oooo]Z1Ol0000BoookJPGo1Ol0oooonf[]oookJP003OoonfX:o`00O`;ooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00O`Oooo]Z1_l0000AoookJPKo1Ol0oooonf[/oookJP006OoonfX3o`00O`?o
oo]Z0ol007l<oookJP?o001o1ooonfX5o`0001;ooo]Z1_l5o`3ooookJ^cooo]Z000IoookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfX5o`0001;ooo]Z1_l5o`3ooookJ^cooo]Z
000IoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPGo00004_oonfX6o`Go0?oooo]Zk?oo
nfX001Wooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Wooo]Z1Ol0000CoookJPGo1Ol0oooonf[/
oookJP006OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3OoonfX5o`0001?ooo]Z1Ol5o`3ooook
J^cooo]Z000JoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00O`gooo]Z1Ol0000Coook
JPKo1Ol0oooonf[[oookJP006_oonfX7o`00O`Wooo]Z1ol007l7oookJPGo00004ooonfX6o`Go0?oo
oo]ZjooonfX001_ooo]Z1Ol007l:oookJPOo001o1ooonfX5o`0001?ooo]Z1_l5o`3ooookJ^_ooo]Z
000hoookJPGo00004ooonfX6o`Go0?oooo]ZjooonfX003Sooo]Z1Ol0000DoookJPGo1Ol0oooonf[[
oookJP00>?oonfX5o`0001Cooo]Z1Ol5o`3ooookJ^_ooo]Z000hoookJPGo00005?oonfX6o`Go0?oo
oo]Zj_oonfX003Sooo]Z1Ol0000DoookJPKo1Ol0oooonf[ZoookJP00>?oonfX5o`0001Cooo]Z1_l5
o`3ooookJ^[ooo]Z000hoookJPGo00005?oonfX6o`Go0?oooo]Zj_oonfX003Sooo]Z1Ol0000Eoook
JPGo1Ol0oooonf[ZoookJP00>?oonfX5o`0001Gooo]Z1_l5o`3ooookJ^Wooo]Z000hoookJPGo0000
5OoonfX6o`Go0?oooo]ZjOoonfX003Sooo]Z1Ol0000EoookJPKo1Ol0oooonf[YoookJP00>?oonfX5
o`0001Gooo]Z1_l5o`3ooookJ^Wooo]Z000hoookJPGo00005_oonfX5o`Go05;ooo]Z2?oo003ooook
JXoooo]Z000hoookJPGo00005_oonfX5o`Go04oooo]Z3Ooo003ooookJXgooo]Z000hoookJPGo0000
5_oonfX6o`Go04gooo]Z4Ooo003ooookJX[ooo]Z000hoookJPGo00005_oonfX6o`Go04_ooo]Z5?oo
003ooookJXWooo]Z000hoookJPGo00005_oonfX6o`Go04[ooo]Z5_oo003ooookJXSooo]Z000hoook
JPGo00005_oonfX6o`Go04Wooo]Z6?oo003ooookJXOooo]Z000hoookJPGo00005ooonfX5o`Go04So
oo]Z2_oo0005oookJP_oo`00oooonfZ6oookJP00>?oonfX5o`0001Oooo]Z1Ol5o`18oookJPWoo`00
2OoonfX8ool00?oooo]ZQ_oonfX003Sooo]Z1Ol0000GoookJPKo1Ol0A_oonfX8ool000cooo]Z2?oo
003ooookJXGooo]Z000hoookJPGo00005ooonfX6o`Go04Gooo]Z2?oo000>oookJPSoo`005OoonfX8
o`Go0?oooo]ZIooonfX003Sooo]Z1Ol0000GoookJPKo1Ol0A?oonfX8ool0013ooo]Z2?oo000Aoook
JPoo1Ol0oooonfYSoookJP00>?oonfX5o`0001Oooo]Z1_l5o`14oookJPSoo`004?oonfX9ool000go
oo]Z5?l5o`3ooookJV7ooo]Z000hoookJPGo00006?oonfX5o`Go04?ooo]Z2?oo000BoookJPWoo`00
2ooonfXFo`Go0?oooo]ZH?oonfX003Sooo]Z1Ol0000HoookJPGo1Ol0@_oonfX8ool001Cooo]Z2Ooo
0009oookJQSo1Ol0oooonfYOoookJP00>?oonfX5o`0001Sooo]Z1_l5o`10oookJPSoo`005_oonfX8
ool000Sooo]Z6_l5o`3ooookJUkooo]Z000hoookJPGo00006?oonfX6o`Go043ooo]Z2?oo000Goook
JPSoo`001_oonfX;o`Go00Oooo]Z2_l5o`3ooookJUgooo]Z000hoookJPGo00006?oonfX6o`Go03oo
oo]Z2?oo000IoookJPOoo`001OoonfX9o`Go00cooo]Z2?l5o`3ooookJUgooo]Z000hoookJPGo0000
6?oonfX6o`Go03oooo]Z1ooo000KoookJPOoo`000ooonfX9o`Go00kooo]Z2?l5o`3ooookJUcooo]Z
000hoookJPGo00006OoonfX5o`Go03kooo]Z1ooo000LoookJPSoo`0000?ooo]Zo`Go0?l5o`001ol5
o`0@oookJPSo1Ol0oooonfYKoookJP00>?oonfX5o`0001Wooo]Z1Ol5o`0noookJPOoo`007OoonfX7
ool00003oookJ_l5o`3o1Ol000Ko1Ol04_oonfX8o`Go0?oooo]ZF_oonfX0017ooo]Z1Ol007l4oook
JP?o001o00?ooo]Zo`00Ool007l01ol007l3oookJPGo001o2OoonfX5o`0001Wooo]Z1_l5o`0loook
JPOoo`007_oonfX7ool000So1Ol04ooonfX9o`Go0?oooo]ZFOoonfX0013ooo]Z1ol007l3oookJP?o
001o00?ooo]Zo`00Ool007l01ol007l2oookJPOo001o2?oonfX5o`0001Wooo]Z1_l5o`0loookJPOo
o`007ooonfX6ool000Oo1Ol05OoonfX9o`Go0?oooo]ZF?oonfX0013ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l6oookJPCo001o00Cooo]Zo`00Ool0
07oo001o2?oonfX5o`0001Wooo]Z1_l5o`0koookJPOoo`008OoonfX4ool000Oo1Ol05ooonfX8o`Go
0?oooo]ZF?oonfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l007l5oookJP?o
001o0ooonfX3o`00O`Oooo]Z1Ol0000IoookJPKo1Ol0>ooonfX7ool0027ooo]Z0ooo0008o`Go01So
oo]Z2?l5o`1OoookJPSoo`00kooonfX000?ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Sooo]Z
1Ol007l9oookJP?o001o1ooonfX6o`0001Wooo]Z1Ol5o`0joookJPOoo`008ooonfX2ool000Oo1Ol0
6_oonfX8o`Go05_ooo]Z3_oo003/oookJP003ooonfX3o`00O`?ooo]Z0ol007l:oookJPCo001o2?oo
nfX3o`00O`Oooo]Z1Ol0000JoookJPGo1Ol0>_oonfX7ool002?ooo]Z00?oo`00o`Go0?l5o`001_l5
o`0KoookJPSo1Ol0EooonfXDool00>Wooo]Z000?oookJP?o001o0ooonfX3o`00O`_ooo]Z0ol007l3
oookJP;o001o0_oonfX4o`00O`Oooo]Z1Ol0000JoookJPKo1Ol0>?oonfX7ool002Gooo]Z1ol5o`0L
oookJPSo1Ol0E_oonfXGool001Kooo]Z2ol5o`36oookJP003ooonfX3o`00O`?ooo]Z0ol007l<oook
JP?o001o0_oonfX7o`00O`Sooo]Z1Ol0000JoookJPKo1Ol0>?oonfX7ool002Cooo]Z1ol5o`000ooo
003ooo]ZoookJP0KoookJPSo1Ol0DooonfXKool0017ooo]Z4Ol5o`33oookJP003ooonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z1_l007l9oookJPGo00006_oonfX6o`Go03So
oo]Z1_oo000UoookJPOo1Ol00_oo000MoookJPSo1Ol0DOoonfXMool000gooo]Z5ol5o`30oookJP00
3ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z0_l007l=oookJPGo0000
6_oonfX6o`Go03Oooo]Z1ooo000ToookJPOo1Ol00ooo000NoookJPOo1Ol0D?oonfX<ool000Kooo]Z
3Ooo000;oookJQ[o1Ol0__oonfX0013ooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPCo001o
0_oonfX3o`00O`;ooo]Z0_l007l=oookJPGo00006ooonfX5o`Go03Oooo]Z1_oo000UoookJPOo1Ol0
1?oo000MoookJPSo1Ol0C_oonfX:ool000cooo]Z2ooo0008oookJQgo1Ol0_OoonfX0013ooo]Z1ol0
07l8oookJPOo001o1?oonfX7o`00O`Oooo]Z1Ol0000KoookJPKo1Ol0=OoonfX7ool002Cooo]Z1ol5
o`05ool001kooo]Z1ol5o`1=oookJP[oo`003ooonfX:ool000Kooo]Z3ol5o`02oookJPko1Ol0_?oo
nfX0017ooo]Z1Ol007l:oookJPGo001o1OoonfX7o`00O`Oooo]Z1Ol0000KoookJPKo1Ol0=OoonfX7
ool002Cooo]Z1ol5o`06ool001kooo]Z1ol5o`1;oookJPWoo`004ooonfX9ool000Cooo]Z3?l5o`09
oookJPco1Ol0H?oonfX<ool004oooo]Z000hoookJPGo00006ooonfX6o`Go03Gooo]Z1_oo000Toook
JPOo1Ol01ooo000NoookJPOo1Ol0B_oonfX9ool001Gooo]Z2Ooo0002oookJP[o1Ol03ooonfX:o`Go
05cooo]Z4ooo001;oookJP00>?oonfX5o`0001_ooo]Z1_l5o`0doookJPOoo`009?oonfX7o`Go0003
oookJ_oo003oo`0000Goo`007_oonfX7o`Go04Sooo]Z2Ooo000GoookJPWoo`002_l5o`0BoookJPWo
1Ol0F?oonfXGool001Cooo]Z4?l5o`0VoookJP00>?oonfX5o`0001cooo]Z1Ol5o`0doookJPKoo`00
9?oonfX7o`Go00;ooo]Z1ooo000NoookJPOo1Ol0AooonfX9ool001Wooo]Z2?oo0008o`Go01Gooo]Z
2Ol5o`1FoookJQ_oo`003_oonfXGo`Go02;ooo]Z000hoookJPGo00007?oonfX6o`Go03;ooo]Z1ooo
000ToookJPOo1Ol00ooonfX7ool001kooo]Z1ol5o`15oookJPWoo`006ooonfX6ool000So1Ol05ooo
nfX9o`Go05?ooo]Z7ooo000:oookJQ[o1Ol08OoonfX003Sooo]Z1Ol0000LoookJPKo1Ol0<_oonfX7
ool002?ooo]Z1ol5o`04oookJPOoo`007_oonfX7o`Go04Gooo]Z2?oo000MoookJPCoo`002?l5o`0I
oookJPWo1Ol0DOoonfX>ool000Cooo]Z3ooo0008oookJQco1Ol08?oonfX003Sooo]Z1Ol0000Loook
JPKo1Ol0<_oonfX6ool002?ooo]Z2?l5o`05oookJPOoo`007_oonfX7o`Go04?ooo]Z2?oo000Ooook
JP;oo`002?l5o`0KoookJPSo1Ol0D?oonfX<ool000_ooo]Z3?oo0005oookJR3o1Ol07_oonfX003So
oo]Z1Ol0000LoookJPKo1Ol0<OoonfX7ool002?ooo]Z1ol5o`06oookJPOoo`007_oonfX8o`Go047o
oo]Z2?oo000QoookJPWo1Ol07?oonfX8o`Go04kooo]Z2_oo000?oookJP_oo`000ooonfX>o`Go00So
oo]Z3_l5o`0LoookJP00>?oonfX5o`0001gooo]Z1Ol5o`0aoookJPKoo`008ooonfX8o`Go00Oooo]Z
1ooo000NoookJPOo1Ol0@?oonfX8ool0027ooo]Z2Ol5o`0NoookJPSo1Ol0BooonfX;ool001?ooo]Z
2Ooo00000ooonf[o1Ol0o`Go000:o`Go00oooo]Z3?l5o`0JoookJP00>?oonfX5o`0001gooo]Z1_l5
o`0_oookJPOoo`008ooonfX7o`Go00Sooo]Z1ooo000NoookJPSo1Ol0?ooonfX8ool0027ooo]Z2?l5
o`02ool001kooo]Z1ol5o`1:oookJP[oo`005ooonfX7ool000_o1Ol04_oonfX<o`Go01Wooo]Z000h
oookJPGo00007OoonfX6o`Go02oooo]Z1ooo000RoookJPOo1Ol02_oonfX7ool001kooo]Z1ol5o`0n
oookJPSoo`008OoonfX8o`Go00?oo`007_oonfX8o`Go04Sooo]Z2_oo000IoookJPKoo`002_l5o`0D
oookJP_o1Ol06OoonfX003Sooo]Z1Ol0000MoookJPKo1Ol0;ooonfX6ool002?ooo]Z1ol5o`0:oook
JPOoo`007ooonfX7o`Go03cooo]Z2?oo000QoookJPSo1Ol01Ooo000NoookJPSo1Ol0A_oonfX:ool0
01[ooo]Z1Ooo0009o`Go01Sooo]Z2_l5o`0HoookJP00>?oonfX5o`0001gooo]Z1_l5o`0^oookJPOo
o`008_oonfX7o`Go00cooo]Z1ooo000NoookJPOo1Ol0??oonfX7ool0027ooo]Z2?l5o`07ool001ko
oo]Z2?l5o`14oookJP[oo`007?oonfX3ool000So1Ol07?oonfX9o`Go01Oooo]Z000hoookJPGo0000
7_oonfX5o`Go02kooo]Z1_oo000SoookJPOo1Ol03?oonfX7ool001oooo]Z1ol5o`0joookJPSoo`00
8?oonfX9o`Go00Ooo`007_oonfX8o`Go04?ooo]Z2Ooo000OoookJP03ool00?l5o`3o1Ol000Ko1Ol0
7ooonfX8o`Go01Kooo]Z000hoookJPGo00007_oonfX6o`Go02cooo]Z1ooo000RoookJPOo1Ol03_oo
nfX7ool001kooo]Z1ol5o`0joookJPOoo`008?oonfX9o`Go0003oookJ_oo003oo`0000Koo`007_oo
nfX8o`Go04;ooo]Z2?oo000PoookJPWo1Ol000?oo`00oookJ_oonfX07?oonfX9o`Go01Gooo]Z000h
oookJPGo00007_oonfX6o`Go02cooo]Z1ooo000RoookJPOo1Ol03_oonfX7ool001oooo]Z1ol5o`0h
oookJPOoo`008OoonfX8o`Go00?ooo]Z2?oo000NoookJPSo1Ol0@?oonfX8ool0023ooo]Z2Ol5o`03
ool001kooo]Z2Ol5o`0DoookJP00>?oonfX5o`0001kooo]Z1_l5o`0/oookJPKoo`008OoonfX00ol0
07oo1Ol0o`Go0005o`Go013ooo]Z1_oo000OoookJPOo1Ol0=ooonfX8ool000Go001o6ooonfX8o`Go
00Gooo]Z1ooo000OoookJPOo1Ol06ooonfX3o`00O`Gooo]Z1Ol007lGoookJPSoo`008OoonfX8o`Go
00Goo`007_oonfX9o`Go0004o`00Oooonf[ooo]ZoookJPGo001o2_oonfX003Sooo]Z1Ol0000Noook
JPKo1Ol0:ooonfX7ool0023ooo]Z0_l007l7o`Go013ooo]Z1ooo000OoookJPOo1Ol0=_oonfX7ool0
00Oo001o6OoonfX8o`Go00Kooo]Z2?oo000NoookJPSo1Ol06_oonfX3o`00O`Cooo]Z1ol007lEoook
JPSoo`008OoonfX8o`Go00Ooo`007_oonfX9o`Go00;ooo]Z1ol007l9oookJP00>?oonfX5o`0001oo
oo]Z1_l5o`0ZoookJPKoo`008?oonfX3o`00O`Ko1Ol04_oonfX6ool001oooo]Z1ol5o`0eoookJPSo
o`000ol007l01?oonf[o001oo`00Ool007lIoookJPOo1Ol02?oonfX8ool001kooo]Z2?l5o`0Ioook
JP?o001o0ooonfX4o`00O`04oookJ_l007oo001oo`00OaCooo]Z2Ooo000PoookJPSo1Ol02?oo000N
oookJP03o`00Ool5o`3o1Ol000Oo1Ol000Gooo]Zo`00Ool007oo001ooookJP03o`00O`Wooo]Z000h
oookJPGo00007ooonfX6o`Go02[ooo]Z1_oo000PoookJP;o001o1ol5o`0BoookJPOoo`007ooonfX7
o`Go03Cooo]Z1ooo0003o`00O`?ooo]Z0ol007lGoookJPSo1Ol02OoonfX7ool001oooo]Z1ol5o`0I
oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007lBoookJPWoo`008?oonfX8o`Go00;ooo]Z2?oo000N
oookJP03o`00Ool5o`3o1Ol000Oo1Ol00_l007l3oookJP?o001o2?oonfX003Sooo]Z1Ol0000Ooook
JPKo1Ol0:OoonfX7ool002;ooo]Z1_l5o`000ol007oooo]ZoookJP0@oookJPOoo`007ooonfX7o`Go
03?ooo]Z1ooo00001?oonf[o001oo`00Ool007l3oookJP?o001o5ooonfX7o`Go00[ooo]Z2?oo000N
oookJPSo1Ol06?oonfX3o`00O`Wooo]Z0ol007lAoookJPWoo`008?oonfX9o`Go00?ooo]Z2?oo000N
oookJP03o`00Ool5o`3o1Ol000Oo1Ol000Co001ooookJ_oonf[ooo]Z0ol007l8oookJP00>?oonfX5
o`0001oooo]Z1_l5o`0YoookJPKoo`008_oonfX7o`Go0003o`00Oooonf[ooo]Z017ooo]Z1ooo000O
oookJPOo1Ol0<OoonfX8ool00004oookJ_l007oo001oo`00O`?ooo]Z0ol007lFoookJPOo1Ol03?oo
nfX8ool001kooo]Z2?l5o`0GoookJP?o001o2OoonfX3o`00Oa7ooo]Z2?oo000PoookJPWo1Ol01Ooo
nfX8ool001oooo]Z2Ol5o`03oookJP?o001o2?oonfX003Sooo]Z1Ol0000PoookJPGo1Ol0:OoonfX6
ool002;ooo]Z1ol5o`000ol007oooo]ZoookJP0AoookJPOoo`007ooonfX7o`Go037ooo]Z1ooo0002
oookJP?o001o0ooonfX3o`00OaGooo]Z2?l5o`0=oookJPOoo`007ooonfX8o`Go01Kooo]Z0ol007l4
oookJP;o001o0_oonfX4o`00Oa3ooo]Z2?oo000PoookJPWo1Ol01_oonfX9ool001oooo]Z2?l5o`03
oookJP?o001o2?oonfX003Sooo]Z1Ol0000PoookJPKo1Ol09ooonfX7ool002;ooo]Z1_l5o`000ol0
07oooo]ZoookJP0CoookJPOoo`007ooonfX7o`Go02oooo]Z2?oo0002oookJP?o001o0ooonfX3o`00
OaGooo]Z1ol5o`0>oookJPSoo`007_oonfX8o`Go01Kooo]Z0ol007l4oookJPOo001o4?oonfX8ool0
027ooo]Z2?l5o`08oookJPSoo`008?oonfX7o`Go00?ooo]Z0ol007l8oookJP00>?oonfX5o`00023o
oo]Z1_l5o`0WoookJPKoo`008_oonfX7o`Go01Kooo]Z1ooo000OoookJPOo1Ol0;ooonfX7ool000?o
oo]Z0ol007l3oookJP?o001o5?oonfX8o`Go00oooo]Z1ooo000OoookJPSo1Ol05OoonfX3o`00O`Co
oo]Z1_l007l@oookJPSoo`008OoonfX8o`Go00[ooo]Z2?oo000IoookJP?o001o0ooonfX00ol007oo
1Ol0o`Go0004o`Go00?ooo]Z0ol007l8oookJP00>?oonfX5o`00023ooo]Z1_l5o`0WoookJPKoo`00
8_oonfX6o`Go01Sooo]Z1_oo000PoookJPOo1Ol0;OoonfX7ool00004o`00Oooonf[ooo]ZoookJP?o
001o0ooonfX3o`00Oa?ooo]Z2?l5o`0AoookJPOoo`007ooonfX8o`Go017ooo]Z1_l007l4oookJP;o
001o5?oonfX8ool0023ooo]Z2?l5o`0<oookJPSoo`006?oonfX3o`00O`?ooo]Z0_l007l5o`Go00?o
oo]Z0ol007l8oookJP00>?oonfX5o`00023ooo]Z1_l5o`0VoookJPOoo`008OoonfX7o`Go01Sooo]Z
1ooo000OoookJPOo1Ol0;?oonfX8ool00003o`00Oooonf[ooo]Z00;ooo]Z0ol007l01?oonf[o001o
o`00Ool007lDoookJPOo1Ol04_oonfX8ool001oooo]Z1ol5o`0AoookJPKo001o1?oonfX2o`00Oa?o
oo]Z2?oo000PoookJPSo1Ol03_oonfX8ool001Oooo]Z1?l007l2oookJP?o001o0_oonfX3o`00O`04
oookJ_l007oo001oo`00O`Wooo]Z000hoookJPGo00008OoonfX5o`Go02Kooo]Z1_oo000RoookJPOo
1Ol00ol007lFoookJPKoo`008?oonfX7o`Go02_ooo]Z1ooo0002o`00O`Cooo]Z1ol007lCoookJPSo
1Ol04ooonfX7ool001oooo]Z2?l5o`0BoookJPCo001o1OoonfX7o`00O`cooo]Z2?oo000PoookJPWo
1Ol03_oonfX9ool001Oooo]Z1ol007l3oookJPOo001o2OoonfX003Sooo]Z1Ol0000QoookJPKo1Ol0
9OoonfX6ool002;ooo]Z1_l5o`04o`00OaKooo]Z1ooo000OoookJPSo1Ol0:OoonfX8ool000;o001o
1OoonfX5o`00OaCooo]Z1ol5o`0DoookJPSoo`007ooonfX8o`Go01;ooo]Z0ol007l5oookJPOo001o
3?oonfX7ool0023ooo]Z2Ol5o`0@oookJPWoo`005ooonfX5o`00O`Gooo]Z1Ol007l:oookJP00>?oo
nfX5o`00027ooo]Z1_l5o`0ToookJPOoo`008OoonfX7o`Go01[ooo]Z1ooo000PoookJPOo1Ol0:Ooo
nfX7ool0023ooo]Z1ol5o`0FoookJPSoo`007ooonfX7o`Go02cooo]Z2?oo000PoookJPSo1Ol04_oo
nfX8ool0033ooo]Z000hoookJPGo00008OoonfX6o`Go02Cooo]Z1_oo000RoookJPKo1Ol07?oonfX7
ool001oooo]Z2?l5o`0WoookJPOoo`008?oonfX8o`Go01Oooo]Z1ooo000OoookJPSo1Ol0:_oonfX8
ool0023ooo]Z2?l5o`0DoookJPSoo`00;ooonfX003Sooo]Z1Ol0000QoookJPKo1Ol09?oonfX6ool0
027ooo]Z1ol5o`0LoookJPOoo`008?oonfX7o`Go02Oooo]Z1ooo000PoookJPOo1Ol06?oonfX8ool0
01oooo]Z2?l5o`0XoookJPSoo`008?oonfX8o`Go01Kooo]Z2?oo000^oookJP00>?oonfX5o`0002;o
oo]Z1_l5o`0RoookJPOoo`008OoonfX7o`Go01gooo]Z1ooo000PoookJPOo1Ol09OoonfX7ool0023o
oo]Z2?l5o`0IoookJPSoo`007ooonfX8o`Go02Oooo]Z2?oo000OoookJPSo1Ol06?oonfX8ool002go
oo]Z000hoookJPGo00008_oonfX6o`Go02;ooo]Z1_oo000RoookJPKo1Ol07_oonfX7ool0023ooo]Z
1ol5o`0UoookJPOoo`008?oonfX7o`Go01_ooo]Z1ooo000OoookJPSo1Ol09_oonfX8ool001oooo]Z
2Ol5o`0HoookJPWoo`00;?oonfX002_ooo]Z=?l00006o`Go02;o00001_oo000Qo`0000Oo1Ol07ol0
0006ool0027o00001ol5o`0So`0000Ooo`008?l00007o`Go01co00002?oo000Oo`0000So1Ol09?l0
0008ool0023o00002?l5o`0Jo`0000Soo`00:ol00001oookJP00:ooonfX=o`0000Goo`008_l00006
o`Go02;o00001_oo000Qo`0000Ko1Ol08?l00007ool0023o00001ol5o`0Ro`0000Soo`007ol00008
o`Go01go00002?oo000Oo`0000So1Ol08ol00007ool0023o00002?l5o`0Lo`0000Soo`00:_l00001
oookJP00:ooonfX=o`0000Goo`008ol00005o`Go027o00001_oo000Qo`0000Oo1Ol08Ol00006ool0
027o00001ol5o`0Qo`0000Ooo`008?l00007o`Go01oo00001ooo000Po`0000Oo1Ol08_l00008ool0
01oo00002?l5o`0No`0000Soo`00:Ol00001oookJP00:ooonfX=o`0000Goo`008ol00006o`Go023o
00001_oo000Qo`0000Oo1Ol08Ol00007ool0023o00001ol5o`0Po`0000Soo`007ol00008o`Go01oo
00002?oo000Oo`0000So1Ol08?l00008ool001oo00002?l5o`0Po`0000Soo`00:?l00001oookJP00
:ooonfX=o`0000Goo`008ol00006o`Go023o00001_oo000Qo`0000Ko1Ol08_l00007ool0027o0000
1ol5o`0Oo`0000Ooo`008?l00007o`Go027o00002?oo000Oo`0000So1Ol07_l00008ool0023o0000
2?l5o`0Po`0000Woo`009ol00001oookJP00>?oonfX5ool002?ooo]Z1_l5o`0OoookJPOoo`008?oo
nfX7o`Go00Cooo]Z00?o0000oookJ_oonfX07?oonfX7ool0023ooo]Z1ol5o`0NoookJPOoo`003?oo
nfX00ol0003ooo]ZoookJP0AoookJPOo1Ol08ooonfX7ool0023ooo]Z2?l5o`0@oookJP03o`000?oo
nf[ooo]Z00Wooo]Z2Ooo000OoookJPSo1Ol08_oonfX9ool001Kooo]Z00?o0000oookJ_oonfX03_oo
nfX003Sooo]Z1Ooo000SoookJPKo1Ol07ooonfX6ool0027ooo]Z1_l5o`05oookJP03o`000?oonf[o
oo]Z01cooo]Z1ooo000QoookJPOo1Ol07OoonfX7ool000cooo]Z00?o0000oookJ_oonfX04?oonfX8
o`Go02?ooo]Z2?oo000OoookJPSo1Ol04?oonfX00ol0003ooo]ZoookJP09oookJPSoo`007ooonfX8
o`Go02Cooo]Z2?oo000FoookJP03o`000?oonf[ooo]Z00kooo]Z000hoookJPGoo`009?oonfX5o`Go
01oooo]Z1_oo000PoookJPOo1Ol09OoonfX7ool0023ooo]Z1ol5o`0LoookJPOoo`008?oonfX7o`Go
02Gooo]Z1ooo000PoookJPSo1Ol06_oonfX8ool001oooo]Z2?l5o`0VoookJPSoo`009_oonfX003So
oo]Z1Ooo000ToookJPKo1Ol07OoonfX7ool0023ooo]Z1ol5o`0UoookJPOoo`008OoonfX7o`Go01_o
oo]Z1ooo000OoookJPSo1Ol09_oonfX7ool0023ooo]Z2?l5o`0HoookJPSoo`007ooonfX9o`Go02Oo
oo]Z2?oo000UoookJP00>?oonfX5ool002Cooo]Z1_l5o`0MoookJPKoo`008OoonfX6o`Go02Oooo]Z
1_oo000QoookJPOo1Ol06_oonfX7ool0023ooo]Z1ol5o`0WoookJPSoo`008?oonfX7o`Go01Oooo]Z
2?oo000PoookJPSo1Ol0:OoonfX8ool002Cooo]Z000hoookJPGoo`009?oonfX6o`Go01gooo]Z1_oo
000PoookJPOo1Ol09ooonfX7ool0027ooo]Z1ol5o`0HoookJPSoo`007ooonfX7o`Go02Wooo]Z1ooo
000PoookJPSo1Ol05_oonfX8ool001oooo]Z2?l5o`0ZoookJPWoo`008ooonfX003Sooo]Z1Ooo000T
oookJPKo1Ol07?oonfX7ool0023ooo]Z1_l5o`0YoookJPKoo`008OoonfX7o`Go01Sooo]Z1ooo000O
oookJPSo1Ol0:OoonfX8ool0023ooo]Z2?l5o`0DoookJPSoo`007ooonfX8o`Go02cooo]Z2?oo000S
oookJP00>?oonfX5ool002Gooo]Z1Ol5o`0LoookJPKoo`008OoonfX6o`Go02Wooo]Z1ooo000Qoook
JPOo1Ol05_oonfX8ool001oooo]Z1ol5o`0[oookJPSoo`008?oonfX8o`Go01;ooo]Z2?oo000Ooook
JPSo1Ol0;_oonfX8ool002;ooo]Z000hoookJPKoo`009?oonfX6o`Go01_ooo]Z1_oo000PoookJPOo
1Ol0:OoonfX7ool0027ooo]Z1ol5o`0FoookJPOoo`007ooonfX8o`Go02cooo]Z1ooo000PoookJPSo
1Ol04OoonfX8ool001oooo]Z2Ol5o`0_oookJPSoo`008OoonfX003Sooo]Z1_oo000ToookJPKo1Ol0
6_oonfX7ool0023ooo]Z1_l5o`0[oookJPOoo`008OoonfX7o`Go01Cooo]Z1ooo000PoookJPOo1Ol0
;OoonfX8ool0023ooo]Z2?l5o`0?oookJPWoo`007ooonfX8o`Go037ooo]Z2?oo000PoookJP00>?oo
nfX6ool002Cooo]Z1_l5o`0JoookJPKoo`008OoonfX6o`Go02_ooo]Z1ooo000QoookJPSo1Ol04ooo
nfX7ool001oooo]Z1ol5o`0_oookJPSoo`008?oonfX8o`Go00kooo]Z2?oo000OoookJPSo1Ol0<_oo
nfX9ool001oooo]Z000hoookJPKoo`009?oonfX6o`Go01[ooo]Z1_oo000PoookJPOo1Ol0;?oonfX7
ool0027ooo]Z1ol5o`0BoookJPOoo`007ooonfX8o`Go033ooo]Z2?oo000PoookJPOo1Ol03OoonfX8
ool001oooo]Z2?l5o`0doookJPWoo`007_oonfX003Sooo]Z00?o0000ool00?oo00000ooo000Uoook
JPKo1Ol06OoonfX6ool0023ooo]Z1_l5o`0]oookJPOoo`008OoonfX8o`Go017ooo]Z1ooo000Ooook
JPOo1Ol0<OoonfX8ool0023ooo]Z2?l5o`0;oookJPSoo`007ooonfX8o`Go03Kooo]Z2?oo000Noook
JP00>?oonfX00ol0003oo`00ool00003ool002Gooo]Z1_l5o`0HoookJPKoo`008OoonfX6o`Go02ko
oo]Z1_oo000RoookJPOo1Ol04?oonfX7ool001oooo]Z2?l5o`0boookJPSoo`008?oonfX8o`Go00Wo
oo]Z2?oo000PoookJPSo1Ol0=ooonfX8ool001gooo]Z000hoookJP03o`000?oo003oo`0000?oo`00
9OoonfX6o`Go01Sooo]Z1_oo000PoookJPOo1Ol0;_oonfX7ool002;ooo]Z1ol5o`0>oookJPSoo`00
7ooonfX7o`Go03Cooo]Z2?oo000PoookJPSo1Ol02?oonfX8ool001oooo]Z2?l5o`0ioookJPSoo`00
7?oonfX003Sooo]Z00?o0000ool00?oo00000ooo000UoookJPKo1Ol06?oonfX6ool0023ooo]Z1_l5
o`0`oookJPKoo`008_oonfX7o`Go00kooo]Z1ooo000OoookJPOo1Ol0=_oonfX7ool0023ooo]Z2Ol5
o`06oookJPSoo`007ooonfX8o`Go03_ooo]Z2?oo000KoookJP00>?oonfX00ol0003oo`00ool00003
ool002Kooo]Z1_l5o`0FoookJPOoo`008?oonfX6o`Go033ooo]Z1ooo000RoookJPOo1Ol03?oonfX8
ool001oooo]Z1ol5o`0foookJPSoo`008?oonfX9o`Go00Cooo]Z2?oo000OoookJPSo1Ol0??oonfX:
ool001Wooo]Z000hoookJP03o`000?oo003oo`0000?oo`009_oonfX6o`Go01Kooo]Z1_oo000Poook
JPOo1Ol0<?oonfX7ool002;ooo]Z1ol5o`0<oookJPOoo`007ooonfX7o`Go03Sooo]Z2?oo000Poook
JPWo1Ol00_oonfX8ool001oooo]Z2Ol5o`0moookJP[oo`006?oonfX003Sooo]Z00?o0000ool00?oo
00000ooo000VoookJPKo1Ol05_oonfX6ool0023ooo]Z1_l5o`0boookJPOoo`008_oonfX7o`Go00[o
oo]Z1ooo000OoookJPSo1Ol0>OoonfX8ool0023ooo]Z2Ol5o`09ool001kooo]Z2Ol5o`0ooookJP[o
o`005ooonfX003Sooo]Z00?o0000ool00?oo00000ooo000VoookJPKo1Ol05_oonfX6ool0023ooo]Z
1_l5o`0boookJPOoo`008_oonfX7o`Go00Wooo]Z2?oo000OoookJPOo1Ol0>_oonfX8ool0027ooo]Z
2Ol5o`07ool001kooo]Z2Ol5o`11oookJP[oo`005_oonfX003Sooo]Z00?o0000ool00?oo00000ooo
000WoookJPKo1Ol05?oonfX6ool0023ooo]Z1ol5o`0coookJPOoo`008_oonfX7o`Go00Sooo]Z1ooo
000OoookJPSo1Ol0>ooonfX8ool0027ooo]Z2Ol5o`05ool001kooo]Z2Ol5o`13oookJP_oo`005?oo
nfX003Sooo]Z00?o0000ool00?oo00000ooo000WoookJPKo1Ol05?oonfX6ool0023ooo]Z1_l5o`0d
oookJPSoo`008OoonfX8o`Go00Kooo]Z2?oo000OoookJPOo1Ol0?OoonfX8ool0027ooo]Z2Ol5o`03
ool001kooo]Z2Ol5o`16oookJP[oo`004ooonfX003Sooo]Z00?o0000ool00?oo00000ooo000Woook
JPKo1Ol05?oonfX6ool0023ooo]Z1_l5o`0eoookJPOoo`008_oonfX7o`Go00Kooo]Z1ooo000Ooook
JPOo1Ol0?ooonfX8ool0027ooo]Z2Ol5o`000ooo003ooo]ZoookJP0LoookJPWo1Ol0B?oonfX;ool0
017ooo]Z000hoookJP03o`000?oo003oo`0000?oo`009ooonfX6o`Go01?ooo]Z1ooo000OoookJPOo
1Ol0=OoonfX8ool0027ooo]Z2?l5o`04oookJPOoo`007ooonfX8o`Go03oooo]Z2Ooo000QoookJPWo
1Ol07OoonfX9o`Go04[ooo]Z2ooo000@oookJP00>?oonfX00ol0003oo`00ool00003ool002Sooo]Z
1_l5o`0BoookJPKoo`008?oonfX6o`Go03Oooo]Z1ooo000RoookJPOo1Ol00ooonfX8ool001kooo]Z
2?l5o`11oookJPWoo`008?oonfX00ooo003o1Ol0o`Go0007o`Go01_ooo]Z2Ol5o`1<oookJP_oo`00
3ooonfX003Sooo]Z00?o0000ool00?oo00000ooo000XoookJPKo1Ol04_oonfX6ool0023ooo]Z1_l5
o`0hoookJPOoo`008_oonfX7o`Go00;ooo]Z1ooo000OoookJPSo1Ol0@_oonfX9ool001kooo]Z0ooo
0009o`Go01Wooo]Z2Ol5o`1?oookJP[oo`003_oonfX003Sooo]Z00?o0000ool00?oo00000ooo000X
oookJPKo1Ol04_oonfX6ool001oooo]Z1ol5o`0hoookJPSoo`008OoonfX8o`Go00Soo`007_oonfX8
o`Go04Cooo]Z2_oo000KoookJPGoo`002Ol5o`0FoookJP[o1Ol0DOoonfX9ool000kooo]Z000hoook
JP03o`000?oo003oo`0000?oo`00:?oonfX6o`Go017ooo]Z1_oo000PoookJPKo1Ol0>_oonfX7ool0
02;ooo]Z1ol5o`07ool001kooo]Z2?l5o`16oookJP[oo`006?oonfX8ool000_o1Ol04_oonfX:o`Go
05Cooo]Z1ooo000>oookJP00>?oonfX00ol0003oo`00ool00003ool002Wooo]Z1_l5o`0@oookJPKo
o`008?oonfX6o`Go03[ooo]Z2?oo000QoookJPSo1Ol01Ooo000OoookJPOo1Ol0B?oonfX:ool001Go
oo]Z2ooo000;o`Go00oooo]Z2ol5o`1FoookJPKoo`003_oonfX003Sooo]Z00?o0000ool00?oo0000
0ooo000YoookJPKo1Ol04?oonfX6ool001oooo]Z1ol5o`0koookJPOoo`008_oonfX8o`Go00Coo`00
7_oonfX8o`Go04Wooo]Z2_oo000CoookJP_oo`000_oonfX;o`Go00gooo]Z2ol5o`1HoookJPGoo`00
3_oonfX003Sooo]Z00?o0000ool00?oo00000ooo000YoookJPKo1Ol03ooonfX7ool001oooo]Z1_l5
o`0moookJPOoo`008_oonfX8o`Go00;oo`007_oonfX8o`Go04_ooo]Z3?oo000>oookJPcoo`001?oo
nfX=o`Go00Sooo]Z3?l5o`1/oookJP00>?oonfX00ol0003oo`00ool00003ool002Wooo]Z1_l5o`0?
oookJPKoo`007ooonfX7o`Go03gooo]Z2?oo000QoookJPSo1Ol00_oo000MoookJPSo1Ol0C_oonfX=
ool000[ooo]Z3?oo0006oookJQko1Ol0K_oonfX003Sooo]Z00?o0000ool00?oo00000ooo000Zoook
JPKo1Ol03_oonfX6ool001oooo]Z1ol5o`0noookJPOoo`008_oonfX8o`Go01gooo]Z2Ol5o`1?oook
JPgoo`001_oonfX=ool000_ooo]Z6_l5o`1_oookJP00>?oonfX00ol0003oo`00ool00003ool002[o
oo]Z1_l5o`0=oookJPOoo`007_oonfX7o`Go03oooo]Z2?oo000PoookJP;oo`002?l5o`0KoookJPWo
1Ol0DOoonfXMool000kooo]Z5ol5o`1aoookJP00>?oonfX00ol0003oo`00ool00004ool002Wooo]Z
1_l5o`0=oookJPKoo`007ooonfX7o`Go043ooo]Z1ooo000PoookJP?oo`002Ol5o`0HoookJPWo1Ol0
DooonfXKool0013ooo]Z5Ol5o`1boookJP00>?oonfX00ol0003oo`00ool00004ool002Wooo]Z1ol5
o`0<oookJPKoo`007ooonfX6o`Go04;ooo]Z1ooo000NoookJPCoo`002_l5o`0FoookJPWo1Ol0Eooo
nfXFool001Gooo]Z4?l5o`1doookJP00>?oonfX00ol0003oo`00ool00004ool002[ooo]Z1_l5o`0<
oookJPKoo`007_oonfX7o`Go04;ooo]Z2?oo000LoookJPKoo`002_l5o`0DoookJPWo1Ol0FooonfXB
ool001_ooo]Z1Ol5o`1joookJP00>?oonfX00ol0003oo`00ool00004ool002[ooo]Z1_l5o`0;oook
JPKoo`007ooonfX6o`Go04Cooo]Z2?oo000JoookJPSoo`002Ol5o`0CoookJPWo1Ol0GOoonfX>ool0
09gooo]Z000AoookJPGo001o1?oonfX3o`00O`03oookJ_l007oo001o00Oo001o0ooonfX5o`00O`Wo
oo]Z0_l00005ool002[ooo]Z1ol5o`0:oookJPKoo`007_oonfX7o`Go04Cooo]Z2?oo000JoookJPSo
o`0000?ooo]Zo`Go0?l5o`001ol5o`0@oookJP[o1Ol0oooonfX:oookJP004?oonfX7o`00O`?ooo]Z
0ol007l00ooonf[o001oo`00O`07o`00O`;ooo]Z1ol007l8oookJP;o00001Ooo000[oookJPKo1Ol0
2_oonfX6ool001kooo]Z1ol5o`15oookJPSoo`006?oonfX8ool000Cooo]Z2_l5o`0;oookJP_o1Ol0
oooonfX;oookJP004?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001o
o`00O`02o`00O`Kooo]Z1?l007l01?oonf[o001oo`00Ool007l8oookJP;o00001Ooo000[oookJPKo
1Ol02OoonfX7ool001gooo]Z1ol5o`17oookJPSoo`005OoonfX9ool000Kooo]Z2_l5o`09oookJP_o
1Ol0oooonfX<oookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJPCo001o1OoonfX3o`00O`?ooo]Z
0ol007l7oookJP;o00001Ooo000[oookJPKo1Ol02OoonfX6ool001kooo]Z1ol5o`18oookJPSoo`00
4ooonfX9ool000Oooo]Z3Ol5o`04oookJPco1Ol0oooonfX=oookJP003ooonfX3o`00O`?ooo]Z0ol0
07l8oookJPGo001o2OoonfX3o`00O`Oooo]Z0_l00005ool002cooo]Z1_l5o`08oookJPKoo`007Ooo
nfX7o`Go04Wooo]Z2Ooo000AoookJP[oo`002?oonfXKo`Go0?oooo]Z3_oonfX000oooo]Z0ol007l3
oookJP?o001o2_oonfX4o`00O`Sooo]Z0ol007l7oookJP;o00001_oo000[oookJPKo1Ol02?oonfX6
ool001gooo]Z1ol5o`1:oookJP[oo`003_oonfX:ool000[ooo]Z6?l5o`3ooookJQ3ooo]Z000?oook
JP?o001o0ooonfX3o`00O`_ooo]Z0ol007l3oookJP;o001o0_oonfX4o`00O`Oooo]Z0_l00006ool0
02_ooo]Z1_l5o`07oookJPKoo`007_oonfX6o`Go04cooo]Z2_oo000;oookJP_oo`003_oonfXCo`Go
0?oooo]Z4_oonfX000oooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`;ooo]Z1ol007l8oookJP;o
00001_oo000[oookJPOo1Ol01_oonfX6ool001gooo]Z1ol5o`1=oookJPcoo`001_oonfX;ool0017o
oo]Z4Ol5o`3ooookJQ?ooo]Z000?oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
0_oonfX6o`00O`Wooo]Z0_l00006ool002cooo]Z1_l5o`06oookJPKoo`007OoonfX6o`Go04oooo]Z
6ooo000DoookJPgo1Ol0oooonfXEoookJP003ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`;ooo]Z0_l007l=oookJP?o00001Ooo000/oookJPKo1Ol01OoonfX7ool001cooo]Z1ol5
o`1@oookJQWoo`00oooonfXgoookJP004?oonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0
07l2oookJP?o001o0_oonfX2o`00O`gooo]Z0ol00006ool002_ooo]Z1ol5o`04oookJPKoo`007Ooo
nfX7o`Go05;ooo]Z5_oo003ooookJSSooo]Z000@oookJPOo001o2?oonfX7o`00O`Cooo]Z1ol007l7
oookJP?o00001_oo000/oookJPKo1Ol01?oonfX6ool001cooo]Z1ol5o`1DoookJQ?oo`00oooonfXj
oookJP004OoonfX5o`00O`[ooo]Z1Ol007l5oookJPOo001o1ooonfX3o`0000Koo`00;?oonfX6o`Go
00?ooo]Z1ooo000LoookJPOo1Ol0EooonfX>ool00?oooo]Z??oonfX003Sooo]Z0ol00006ool002co
oo]Z1ol5o`02oookJPKoo`007OoonfX6o`Go05cooo]Z1Ooo003ooookJT7ooo]Z000hoookJPCo0000
1Ooo000]oookJPKo1Ol00_oonfX6ool001cooo]Z1ol5o`3ooookJZ;ooo]Z000hoookJPCo00001Ooo
000]oookJPOo1Ol01ooo000LoookJPKo1Ol0oooonfZSoookJP00>?oonfX4o`0000Koo`00;?oonfX7
o`Go00Koo`007?oonfX7o`Go0?oooo]ZXooonfX003Sooo]Z1?l00006ool002gooo]Z1_l5o`06ool0
01cooo]Z1ol5o`3ooookJZ?ooo]Z000hoookJPCo00001_oo000]oookJPOo1Ol01Ooo000KoookJPOo
1Ol0oooonfZToookJP00>?oonfX4o`0000Koo`00;_oonfX6o`Go00Coo`007?oonfX7o`Go0?oooo]Z
Y?oonfX003Sooo]Z1Ol00005ool002kooo]Z1_l5o`04ool001_ooo]Z1ol5o`3ooookJZGooo]Z000h
oookJPGo00001Ooo000^oookJPOo1Ol00ooo000KoookJPOo1Ol0oooonfZUoookJP00>?oonfX5o`00
00Goo`00;ooonfX6o`Go00;oo`006ooonfX7o`Go0?oooo]ZY_oonfX003Sooo]Z1Ol00005ool002oo
oo]Z1ol5o`000ooo003ooo]ZoookJP0HoookJPSo1Ol0oooonfZVoookJP00>?oonfX5o`0000Koo`00
;_oonfX7o`Go0003ool00?oonf[ooo]Z01Sooo]Z1ol5o`3ooookJZOooo]Z000hoookJPGo00001_oo
000_oookJPOo1Ol06OoonfX8o`Go0?oooo]ZYooonfX003Sooo]Z1Ol00006ool002oooo]Z2?l5o`0H
oookJPOo1Ol0oooonfZXoookJP00>?oonfX5o`0000Koo`00;_oonfX2ool000Oo1Ol05ooonfX7o`Go
0?oooo]ZZOoonfX003Sooo]Z1Ol000000ooonf[oo`00ool00003ool002kooo]Z0_oo0008o`Go01Ko
oo]Z1ol5o`3ooookJZWooo]Z000hoookJPGo000000?ooo]Zool00?oo00000ooo000^oookJP?oo`00
1ol5o`0EoookJPOo1Ol0oooonfZZoookJP00>?oonfX5o`000003oookJ_oo003oo`0000?oo`00;Ooo
nfX5ool000Oo1Ol05?oonfX7o`Go0?oooo]ZZ_oonfX003Sooo]Z1Ol000000ooonf[oo`00ool00004
ool002cooo]Z1Ooo0007o`Go01?ooo]Z1ol5o`3ooookJZ_ooo]Z000hoookJPGo000000?ooo]Zool0
0?oo00001?oo000/oookJPKoo`001ol5o`0AoookJPSo1Ol0oooonfZ[oookJP00>?oonfX5o`000003
oookJ_oo003oo`0000Coo`00:ooonfX7ool000So1Ol03ooonfX8o`Go0?oooo]Z[?oonfX003Sooo]Z
1Ol000000ooonf[oo`00ool00004ool002_ooo]Z1_oo0002oookJPSo1Ol03OoonfX9o`Go0?oooo]Z
[?oonfX003Sooo]Z1Ol00002oookJPGoo`00:ooonfX6ool000;ooo]Z2Ol5o`0;oookJPWo1Ol0oooo
nfZ]oookJP00>?oonfX5o`0000;ooo]Z1Ooo000ZoookJPOoo`000ooonfX9o`Go00Wooo]Z2Ol5o`3o
oookJZkooo]Z000hoookJPGo00000_oonfX6ool002Wooo]Z1_oo0005oookJPWo1Ol01_oonfX:o`Go
0?oooo]Z[ooonfX003Sooo]Z1Ol00002oookJPKoo`00:OoonfX6ool000Kooo]Z2_l5o`02oookJP_o
1Ol0oooonfZ`oookJP00>?oonfX5o`0000;ooo]Z1_oo000XoookJPOoo`001ooonfXEo`Go0?oooo]Z
/OoonfX003Sooo]Z1Ol00002oookJPOoo`009ooonfX6ool000Wooo]Z4ol5o`3ooookJ[;ooo]Z000h
oookJPGo00000ooonfX6ool002Oooo]Z1_oo000:oookJQ7o1Ol0oooonfZcoookJP00>?oonfX5o`00
00?ooo]Z1_oo000VoookJPOoo`002ooonfX>o`Go0?oooo]Z]OoonfX003Sooo]Z1Ol00003oookJPKo
o`009_oonfX6ool000kooo]Z2_l5o`3ooookJ[Oooo]Z000hoookJPGo00001?oonfX6ool002Gooo]Z
1_oo003ooookJ/oooo]Z000KoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l9oookJPGo00001?oo
nfX6ool002Cooo]Z1ooo003ooookJ/oooo]Z000JoookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007l8
oookJPGo00001?oonfX6ool002Cooo]Z1_oo003ooookJ]3ooo]Z000JoookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o2?oo
nfX5o`0000Cooo]Z1_oo000ToookJPKoo`00oooonf[@oookJP006OoonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol00005oookJPKoo`008_oonfX7ool00?oooo]Zd?oonfX0
01Wooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1_l00004oookJPKoo`008_oonfX6ool0
0?oooo]ZdOoonfX001Wooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oooo]Z1Ol00005oookJPKo
o`008OoonfX7ool00?oooo]ZdOoonfX001Wooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z
1?l007l7oookJPGo00001OoonfX7ool0023ooo]Z1ooo003ooookJ]7ooo]Z000IoookJP?o001o0ooo
nfX3o`00O`Oooo]Z1ol007l8oookJPGo00001_oonfX6ool0023ooo]Z1_oo003ooookJ];ooo]Z000I
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l9oookJPGo00001_oonfX6ool001oooo]Z1ooo003o
oookJ];ooo]Z000IoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l=oookJPGo00001_oonfX7ool0
01kooo]Z1_oo003ooookJ]?ooo]Z000JoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00
O`gooo]Z1Ol00007oookJPKoo`007OoonfX7ool00?oooo]ZdooonfX001[ooo]Z1ol007l9oookJPOo
001o1ooonfX5o`0000Oooo]Z1_oo000MoookJPOoo`00oooonf[CoookJP006ooonfX5o`00O`[ooo]Z
1ol007l7oookJPGo00001ooonfX7ool001cooo]Z1_oo003ooookJ]Cooo]Z000hoookJPGo00002?oo
nfX6ool001_ooo]Z1ooo003ooookJ]Cooo]Z000hoookJPGo00002?oonfX6ool001_ooo]Z1_oo003o
oookJ]Gooo]Z000hoookJPGo00002?oonfX7ool001[ooo]Z1_oo003ooookJ]Gooo]Z000hoookJPGo
00002OoonfX6ool001Wooo]Z1ooo003ooookJ]Gooo]Z000hoookJPGo00002OoonfX6ool001Wooo]Z
1_oo003ooookJ]Kooo]Z000hoookJPGo00002OoonfX7ool001Oooo]Z1ooo003ooookJ]Kooo]Z000h
oookJPGo00002_oonfX6ool001Oooo]Z1ooo003ooookJ]Kooo]Z000hoookJPGo00002_oonfX7ool0
01Kooo]Z1_oo003ooookJ]Oooo]Z000hoookJPGo00002_oonfX7ool001Gooo]Z1ooo003ooookJ]Oo
oo]Z000hoookJPGo00002ooonfX7ool001Cooo]Z1_oo003ooookJ]Sooo]Z000hoookJPGo00002ooo
nfX7ool001?ooo]Z1ooo003ooookJ]Sooo]Z000hoookJPGo00003?oonfX7ool0017ooo]Z2?oo003o
oookJ]Sooo]Z000hoookJPGo00003?oonfX7ool0017ooo]Z1ooo003ooookJ]Wooo]Z000hoookJPGo
00003OoonfX6ool0013ooo]Z2?oo003ooookJ]Wooo]Z000hoookJPGo00003OoonfX7ool000kooo]Z
2?oo003ooookJ][ooo]Z000hoookJPGo00003_oonfX6ool000gooo]Z2?oo003ooookJ]_ooo]Z000h
oookJPGo00003_oonfX7ool000_ooo]Z2Ooo003ooookJ]_ooo]Z000hoookJPGo00003_oonfX8ool0
00Wooo]Z2Ooo003ooookJ]cooo]Z000hoookJPGo00003ooonfX8ool000Oooo]Z2Ooo003ooookJ]go
oo]Z000hoookJPGo00003ooonfX9ool000Cooo]Z2_oo003ooookJ]kooo]Z000hoookJPGo00004?oo
nfX:ool00003oookJ_oo003oo`0000Soo`00oooonf[OoookJP00>?oonfX5o`00017ooo]Z4ooo003o
oookJ^3ooo]Z000hoookJPGo00004_oonfXAool00?oooo]ZhOoonfX003Sooo]Z1Ol0000CoookJPoo
o`00oooonf[RoookJP00>?oonfX5o`0001Cooo]Z3?oo003ooookJ^Cooo]Z000hoookJPGo00005_oo
nfX:ool00?oooo]Zi?oonfX003Sooo]Z1Ol0003ooookJ_oooo]Z1OoonfX003Sooo]Z1Ol0003ooook
J_oooo]Z1OoonfX003Sooo]Z1Ol0003ooookJ_oooo]Z1OoonfX003Sooo]Z1Ol0003ooookJ_oooo]Z
1OoonfX003Sooo]Z1Ol0003ooookJ_oooo]Z1OoonfX003Sooo]Z1Ol0003ooookJ_oooo]Z1OoonfX0
03Sooo]Z1Ol0003ooookJ_oooo]Z1OoonfX003Sooo]Z1Ol0003ooookJ_oooo]Z1OoonfX00?oooo]Z
oooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oook
JP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-2.33465, -1.17957, \
0.0398953, 0.00559217}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "As an example of an application where the Bessel functions arise, consider \
radially-symmetric heat flow in an infinitely long cylinder of radius ",
  StyleBox["a",
    FontSlant->"Italic"],
  " that has an initial temperature profile ",
  StyleBox["T =T",
    FontSlant->"Italic"],
  "(",
  StyleBox["r",
    FontSlant->"Italic"],
  ") and a surface temperature ",
  StyleBox["T",
    FontSlant->"Italic"],
  "(",
  StyleBox["r = a",
    FontSlant->"Italic"],
  ") = ",
  Cell[BoxData[
      \(TraditionalForm\`T\_r, 
      and\ \ substitute\ T = \ \(\[ExponentialE]\^\(\(-\[Kappa]\[Alpha]\^2\) 
                t\)\) \[Tau]\)]],
  " into the heat equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]T\/\[PartialD]t = \[Kappa] \[Del]\^2 
            T\ in\ cylindrical\ coordinates\)]],
  ". The function \[Tau] must obey",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\(d\^2\) \[Tau]\)\/\[PartialD]r\^2 + \ \
\(1\/r\) d\[Tau]\/dr + \ \(\[Alpha]\^2\) \[Tau] = \ 0\)\(,\)\)\)]],
  " which has the form of Bessel's equation of order \[Nu] = zero. The \
solution will have the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{"T", "=", " ", 
          RowBox[{"A", " ", 
            RowBox[{\(J\_0\), "(", 
              StyleBox["\[Alpha]r",
                FontSlant->"Italic"], 
              ")"}], \(\[ExponentialE]\^\(\(-\[Kappa]\[Alpha]\^2\) t\)\)}]}], 
        TraditionalForm]]],
  " where ",
  StyleBox["A",
    FontSlant->"Italic"],
  " is a constant and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(J\_0\), "(", 
          StyleBox["\[Alpha]r",
            FontSlant->"Italic"], ")"}], TraditionalForm]]],
  "is the Bessel function of order zero of the first kind. The parameter \
\[Alpha] must, from boundary conditions, be a solution to the equation ",
  StyleBox["J",
    FontSlant->"Italic"],
  "(",
  StyleBox["\[Alpha]a",
    FontSlant->"Italic"],
  ") = 0. The initial temperature distribution, ",
  StyleBox["f",
    FontSlant->"Italic"],
  "(",
  StyleBox["r",
    FontSlant->"Italic"],
  "), can be expanded as a series of Bessel functions of zero order, \
analogous to what we did with Fourier series. The general solution to the \
heat-flow problem will then be an infinite series of Bessel functions, each \
modified by an exponentially decaying amplitude, taking the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{"T", "=", " ", 
          RowBox[{\(\[Sum]\+\(n = 1\)\%\[Infinity]\), 
            RowBox[{\(A\_n\), " ", 
              RowBox[{\(J\_0\), "(", 
                StyleBox[\(\(\[Alpha]\_n\) r\),
                  FontSlant->"Italic"], 
                ")"}], \(\[ExponentialE]\^\(\(-\[Kappa]\[Alpha]\_n\^2\) 
                    t\)\)}]}]}], TraditionalForm]]],
  ".  For a more thorough discussion, see H.S. Carslaw and J.C. Jaeger, ",
  StyleBox["Conduction of Heat in Solids",
    FontSlant->"Italic"],
  ", Oxford University Press, Second Edition, pp. 194\[Dash]196 (1959)."
}], "Text",
  CellTags->{
  "mmtag:26:steady_state_diffusion_in_cylinder", 
    "mmtag:26:cyliner__steady_state_diffusion"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Legendre's equation", "Subsection",
  CellTags->"mmtag:26:Legendre_ODE"],

Cell[TextData[{
  "Legendre's equation is a second-order ODE having the following form, with \
the parameters m and n being integers such that ",
  StyleBox["n",
    FontSlant->"Italic"],
  " is positive and -",
  StyleBox["n ",
    FontSlant->"Italic"],
  "\[LessEqual] ",
  StyleBox["m ",
    FontSlant->"Italic"],
  "\[LessEqual] ",
  StyleBox["n",
    FontSlant->"Italic"],
  " (seems to suggest applications to quantum numbers!). Legendre's equation \
arises in physical problems with spherical symmetry. The simplest form of the \
equation has only one parameter, ",
  StyleBox["n",
    FontSlant->"Italic"],
  " and takes the form:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LegendreODE = \((1 - x\^2)\) \(y''\)[x]\  - 
          2\ x\ \(y'\)[x]\  + \((n \((n + 1)\))\) y[x]\  \[Equal] 
        0\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(n\ \((1 + n)\)\ y[x]\), "-", 
        RowBox[{"2", " ", "x", " ", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}], "+", 
        RowBox[{\((1 - x\^2)\), " ", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}]}], "\[Equal]", 
      "0"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Its solution is a linear combination of two special functions, ",
  StyleBox["Legendre",
    FontWeight->"Bold"],
  " and ",
  StyleBox["PLegendreQ",
    FontWeight->"Bold"],
  ":"
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[LegendreODE, \ y[x], x]\)], "Input",
  CellTags->{"mmtag:26:LegendreP[]", "mmtag:26:LegendreQ[]"}],

Cell[BoxData[
    \({{y[x] \[Rule] 
          C[1]\ LegendreP[n, x] + C[2]\ LegendreQ[n, x]}}\)], "Output",
  CellTags->{"mmtag:26:LegendreP[]", "mmtag:26:LegendreQ[]"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The two-parameter form of the Legendre equation is:", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AnotherFormLegendreODE = \((1 - x\^2)\) \(y''\)[x]\  - 
          2\ x\ \(y'\)[x]\  + \((n \((n + 1)\) - m\^2\/\(1 - x\^2\))\) 
            y[x]\  \[Equal] 0\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\((n\ \((1 + n)\) - m\^2\/\(1 - x\^2\))\)\ y[x]\), "-", 
        RowBox[{"2", " ", "x", " ", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}], "+", 
        RowBox[{\((1 - x\^2)\), " ", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}]}], "\[Equal]", 
      "0"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["which has a solution involving the same special functions:", \
"Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[AnotherFormLegendreODE, \ y[x], x]\)], "Input"],

Cell[BoxData[
    \({{y[x] \[Rule] 
          C[1]\ LegendreP[n, m, x] + C[2]\ LegendreQ[n, m, x]}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Of course, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can evaluate and plot Legendre functions\[Ellipsis]"
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{LegendreP[0, x], \ LegendreQ[0, x]}, {x, \(-1\), 1}, \ 
      PlotStyle \[Rule] MyPlotStyle[2]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.0346369 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 .04924 -41.9375 -10 ]
[.4875 .04924 0 10 ]
[.4875 .13583 -26.9375 -10 ]
[.4875 .13583 0 10 ]
[.4875 .22242 -41.9375 -10 ]
[.4875 .22242 0 10 ]
[.4875 .39561 -29 -10 ]
[.4875 .39561 0 10 ]
[.4875 .4822 -14 -10 ]
[.4875 .4822 0 10 ]
[.4875 .56879 -29 -10 ]
[.4875 .56879 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 .04924 m
.50625 .04924 L
s
gsave
.4875 .04924 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(7.5) show
1.000 setlinewidth
grestore
.5 .13583 m
.50625 .13583 L
s
gsave
.4875 .13583 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .22242 m
.50625 .22242 L
s
gsave
.4875 .22242 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.5 .39561 m
.50625 .39561 L
s
gsave
.4875 .39561 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
.5 .4822 m
.50625 .4822 L
s
gsave
.4875 .4822 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .56879 m
.50625 .56879 L
s
gsave
.4875 .56879 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(7.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .06656 m
.50375 .06656 L
s
.5 .08388 m
.50375 .08388 L
s
.5 .1012 m
.50375 .1012 L
s
.5 .11851 m
.50375 .11851 L
s
.5 .15315 m
.50375 .15315 L
s
.5 .17047 m
.50375 .17047 L
s
.5 .18779 m
.50375 .18779 L
s
.5 .20511 m
.50375 .20511 L
s
.5 .23974 m
.50375 .23974 L
s
.5 .25706 m
.50375 .25706 L
s
.5 .27438 m
.50375 .27438 L
s
.5 .2917 m
.50375 .2917 L
s
.5 .32634 m
.50375 .32634 L
s
.5 .34365 m
.50375 .34365 L
s
.5 .36097 m
.50375 .36097 L
s
.5 .37829 m
.50375 .37829 L
s
.5 .41293 m
.50375 .41293 L
s
.5 .43025 m
.50375 .43025 L
s
.5 .44756 m
.50375 .44756 L
s
.5 .46488 m
.50375 .46488 L
s
.5 .49952 m
.50375 .49952 L
s
.5 .51684 m
.50375 .51684 L
s
.5 .53416 m
.50375 .53416 L
s
.5 .55148 m
.50375 .55148 L
s
.5 .03192 m
.50375 .03192 L
s
.5 .0146 m
.50375 .0146 L
s
.5 .58611 m
.50375 .58611 L
s
.5 .60343 m
.50375 .60343 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02381 .34365 m
.06244 .34365 L
.10458 .34365 L
.14415 .34365 L
.18221 .34365 L
.22272 .34365 L
.26171 .34365 L
.30316 .34365 L
.34309 .34365 L
.3815 .34365 L
.42237 .34365 L
.46172 .34365 L
.49955 .34365 L
.53984 .34365 L
.57861 .34365 L
.61984 .34365 L
.65954 .34365 L
.69774 .34365 L
.73838 .34365 L
.77751 .34365 L
.81909 .34365 L
.85916 .34365 L
.89771 .34365 L
.93871 .34365 L
.97619 .34365 L
s
.02 1 0 r
.02381 .01472 m
.02499 .19305 L
.02605 .20428 L
.02729 .21189 L
.02846 .21692 L
.03053 .22335 L
.03279 .2284 L
.03527 .23267 L
.0379 .2363 L
.04262 .24139 L
.05205 .24861 L
.06244 .25423 L
.07293 .25859 L
.0842 .26238 L
.10458 .26782 L
.1458 .2758 L
.18551 .28153 L
.22371 .28606 L
.26435 .29023 L
.30348 .29382 L
.34506 .29732 L
.38513 .30049 L
.42368 .30342 L
.46468 .30644 L
.50417 .30932 L
.54214 .31209 L
.58257 .31508 L
.62148 .31805 L
.66284 .32136 L
.70268 .32476 L
.74101 .32833 L
.78179 .33258 L
.82106 .33737 L
.85881 .343 L
.87978 .34683 L
.89901 .35107 L
.91786 .35629 L
.92745 .35959 L
.9377 .36387 L
.94804 .36949 L
.95744 .3767 L
.96198 .38158 L
.96436 .3848 L
.96689 .38901 L
.9691 .39375 L
.97027 .3969 L
.97153 .40107 L
.97269 .40602 L
.97374 .41225 L
.9748 .4221 L
Mistroke
.97581 .44451 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP004?oo
nfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003o
oookJQoooo]Z000@oookJPGo1Ol0oooonfX9oookJPGo0000oooonfXOoookJP004?oonfX5o`Go0?oo
oo]Z2OoonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJQoooo]Z
000@oookJPGo1Ol0oooonfX9oookJPGo0000oooonfXOoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5
o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJQoooo]Z000@oookJPGo
1Ol0oooonfX9oookJPGo0000oooonfXOoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z
7ooonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJQoooo]Z000@oookJPGo1Ol0oooonfX9
oookJPGo0000oooonfXOoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z7ooonfX0013o
oo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJQoooo]Z000@oookJPGo1Ol0oooonfX9oookJPGo0000
oooonfXOoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3o
oookJPWooo]Z1Ol0003ooookJQoooo]Z000@oookJPGo1Ol0j_oonfX3o`00O`Kooo]Z0ol007l3oook
JPGo001o2_oonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3ZoookJP?o001o1_oonfX3o`00O`;o
oo]Z1ol007l9oookJPGo0000oooonfXOoookJP004?oonfX5o`Go0>[ooo]Z0ol007l6oookJP?o001o
00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oookJPGo0000oooonfXOoookJP00
4?oonfX5o`Go0=cooo]Z2_l007l5oookJP;o001o2_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000
oooonfXOoookJP004?oonfX5o`Go0=cooo]Z2_l007l5oookJP?o001o3ooonfX3o`00O`Sooo]Z1ol0
003ooookJQgooo]Z000@oookJPGo1Ol0jooonfX3o`00O`oooo]Z0ol007l8oookJPGo0000oooonfXO
oookJP004?oonfX5o`Go0>cooo]Z0_l007l:oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0003ooook
JQoooo]Z000@oookJPGo1Ol0k?oonfX3o`00O`Wooo]Z1ol007l9oookJPGo0000oooonfXOoookJP00
4?oonfX5o`Go0>gooo]Z0_l007l9oookJPKo001o2_oonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol5
o`3^oookJP;o001o2?oonfX2o`00O`kooo]Z1Ol0003ooookJQoooo]Z000@oookJPGo1Ol0k_oonfX2
o`00O`Sooo]Z0_l007l>oookJPGo0000oooonfXOoookJP004?oonfX5o`Go0>Sooo]Z2Ol007l8oook
JPOo001o2?oonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3XoookJPWo001o2?oonfX7o`00O`So
oo]Z1Ol0003ooookJQoooo]Z000@oookJPGo1Ol0oooonfX9oookJPGo0000oooonfXOoookJP004?oo
nfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003o
oookJQoooo]Z000@oookJPGo1Ol0oooonfX9oookJPGo0000oooonfXOoookJP004?oonfX5o`Go0?oo
oo]Z2OoonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJQoooo]Z
000@oookJPGo1Ol0oooonfX9oookJPGo0000oooonfXOoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5
o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJQoooo]Z000@oookJPGo
1Ol0oooonfX9oookJPGo0000oooonfXOoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z
7ooonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJQoooo]Z000@oookJPGo1Ol0oooonfX9
oookJPGo0000oooonfXOoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z7ooonfX0013o
oo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJQoooo]Z000@oookJPGo1Ol0oooonfX9oookJPGo0000
oooonfXOoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3o
oookJPWooo]Z1Ol0003ooookJQoooo]Z000@oookJPGo1Ol0oooonfX9oookJPGo0000oooonfXOoook
JP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z
1Ol0003ooookJQoooo]Z000@oookJPKo1Ol0oooonfX8oookJPGo0000oooonfXOoookJP004?oonfX6
o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0013ooo]Z1_l5o`3ooookJPSooo]Z1Ol0003ooook
JQoooo]Z000@oookJPKo1Ol0oooonfX8oookJPGo0000oooonfXOoookJP004OoonfX5o`Go0?oooo]Z
2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000A
oookJPGo1Ol0oooonfX8oookJPGo0000oooonfXOoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`00
0?oooo]Z7ooonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0
oooonfX8oookJPGo0000oooonfXOoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooo
nfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0oooonfX8oook
JPGo0000oooonfXOoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z
1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0n?oonfX5o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z000AoookJPGo1Ol0mooonfX7o`00O`Wooo]Z1Ol0003ooookJQoooo]Z000Aoook
JPGo1Ol0m_oonfX4o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJQoooo]Z000Aoook
JPGo1Ol0j_oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX0017o
oo]Z1Ol5o`3ZoookJP[o001o2?oonfX3o`00O`Sooo]Z1ol0003ooookJQgooo]Z000AoookJPGo1Ol0
o?oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0mooonfX2o`00O`;ooo]Z1?l0
07l8oookJPGo0000oooonfXOoookJP004OoonfX5o`Go0?Oooo]Z1ol007l9oookJPGo0000oooonfXO
oookJP004OoonfX5o`Go0?Oooo]Z1_l007l:oookJPGo0000oooonfXOoookJP004OoonfX5o`Go0?Oo
oo]Z0_l007l>oookJPGo0000oooonfXOoookJP004OoonfX5o`Go0?Oooo]Z0_l007l>oookJPGo0000
oooonfXOoookJP004OoonfX5o`Go0?Sooo]Z1ol007l8oookJPGo0000oooonfXOoookJP004OoonfX5
o`Go0?Sooo]Z1ol007l8oookJPGo0000oooonfXOoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`00
0?oooo]Z7ooonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0
oooonfX8oookJPGo0000oooonfXOoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooo
nfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0oooonfX8oook
JPGo0000oooonfXOoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z
1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooo
nfXOoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3ooook
JPSooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfXOoookJP00
4OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0
003ooookJQoooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfXOoookJP004OoonfX5o`Go
0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoo
oo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfXOoookJP004OoonfX5o`Go0?oooo]Z2?oo
nfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000Aoook
JPGo1Ol0oooonfX8oookJPGo0000oooonfXOoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oo
oo]Z7ooonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0oooo
nfX8oookJPGo0000oooonfXOoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0
017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo
0000oooonfXOoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5
o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfXO
oookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1_l5o`3ooookJPOo
oo]Z1Ol0003ooookJQoooo]Z000AoookJPKo1Ol0oooonfX7oookJPGo0000oooonfXOoookJP004Ooo
nfX6o`Go0?oooo]Z1ooonfX5o`000?oooo]Z7ooonfX0017ooo]Z1ol5o`3ooookJPKooo]Z1Ol0003o
oookJQoooo]Z000BoookJPKo1Ol0oooonfX6oookJPGo0000oooonfXOoookJP004_oonfX6o`Go0>Go
oo]Z2Ol007l2oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003ooookJQoooo]Z000BoookJPKo1Ol0
iOoonfX9o`00O`;ooo]Z0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX001?ooo]Z1_l5
o`3ToookJPCo001o1ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o
2OoonfX5o`000?oooo]Z7ooonfX001?ooo]Z1_l5o`3HoookJP[o001o0ooonfX4o`00O`[ooo]Z0ol0
07l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX001?ooo]Z1_l5o`3HoookJP[o001o1?oonfX5
o`00O`kooo]Z0ol007l8oookJPOo0000oooonfXMoookJP004ooonfX7o`Go0>Oooo]Z1?l007l=oook
JP?o001o2?oonfX5o`000?oooo]Z7ooonfX001Cooo]Z1_l5o`3XoookJP?o001o2?oonfX2o`00O`;o
oo]Z1?l007l8oookJPGo0000oooonfXOoookJP005?oonfX7o`Go0>Sooo]Z0ol007l7oookJPOo001o
2OoonfX5o`000?oooo]Z7ooonfX001Cooo]Z1ol5o`3RoookJP?o001o0ooonfX3o`00O`Oooo]Z1_l0
07l:oookJPGo0000oooonfXOoookJP005OoonfX7o`Go0>7ooo]Z0ol007l3oookJP?o001o1ooonfX2
o`00O`kooo]Z1Ol0003ooookJQoooo]Z000EoookJPSo1Ol0h?oonfX4o`00O`;ooo]Z0ol007l7oook
JP;o001o3_oonfX5o`000?oooo]Z7ooonfX001Kooo]Z2?l5o`3PoookJPOo001o2OoonfX7o`00O`So
oo]Z1Ol0003ooookJQoooo]Z000FoookJPWo1Ol0h?oonfX5o`00O`[ooo]Z1ol007l8oookJPGo0000
oooonfXOoookJP005ooonfX:o`Go0?cooo]Z1Ol0003ooookJQoooo]Z000HoookJP[o1Ol0nooonfX5
o`000?oooo]Z7ooonfX001Wooo]Z2_l5o`3joookJPGo0000oooonfXOoookJP006_oonfX:o`Go0?Wo
oo]Z1Ol0003ooookJQoooo]Z000KoookJP_o1Ol0mooonfX5o`000?oooo]Z7ooonfX001gooo]Z2ol5
o`3eoookJPGo0000oooonfXOoookJP007_oonfX<o`Go0??ooo]Z1Ol0003ooookJQoooo]Z000Ooook
JPgo1Ol0lOoonfX5o`000?oooo]Z7ooonfX0023ooo]Z3_l5o`3_oookJPGo0000oooonfXOoookJP00
8_oonfX>o`Go0>gooo]Z1Ol0003ooookJQoooo]Z000ToookJPoo1Ol0j_oonfX5o`000?oooo]Z7ooo
nfX002Kooo]Z4?l5o`3WoookJPGo0000oooonfXOoookJP00:?oonfXAo`Go0>Cooo]Z1Ol0003ooook
JQoooo]Z000ZoookJQ?o1Ol0h?oonfX5o`000?oooo]Z7ooonfX002cooo]Z5Ol5o`3LoookJPGo0000
oooonfXOoookJP00;ooonfXGo`Go0=Oooo]Z1Ol0003ooookJQoooo]Z000boookJQ[o1Ol0dOoonfX5
o`000?oooo]Z7ooonfX003Gooo]Z7?l5o`3<oookJPGo0000oooonfXOoookJP00>OoonfXNo`Go0<Ko
oo]Z1Ol0003ooookJQoooo]Z000GoookJP?o001o8ooonfXQo`Go03Kooo]Z1Ol007l4oookJP?o001o
0ooonfX5o`00OgGooo]Z1Ol0001ioookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007mloookJP?o001o
4_oonfX001Oooo]Z0ol007lXoookJR?o1Ol0;_oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001oM?oo
nfX5o`0007Sooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Og_ooo]Z0ol007lBoookJP005ooonfX3
o`00Obkooo]Z9?l5o`0WoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001oM?oonfX5o`0007Sooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007mkoook
JP?o001o4_oonfX000Oooo]Z2_l007l6oookJP?o001o<ooonfXWo`Go01;ooo]Z2_l007l2oookJP?o
001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001oLooonfX5o`0007Oooo]Z0ol007l3oookJP?o
001o1_oonfX3o`00O`?ooo]Z0ol007mjoookJP?o001o4_oonfX000Oooo]Z2_l007l6oookJP?o001o
>OoonfXXo`Go00_ooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007mcoookJPGo0000
MooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001oN_oonfX3o`00Oa;ooo]Z000GoookJP?o001o@?oo
nfXXo`Go013ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Og?ooo]Z1Ol0001goookJP?o001o0ooo
nfX3o`00O`cooo]Z0ol007mjoookJP?o001o4_oonfX001Oooo]Z0ol007m7oookJR_o1Ol01_oonfX3
o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00Og?ooo]Z1Ol0001goookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007l2oookJPCo001oN_oonfX3o`00Oa;ooo]Z000GoookJP?o001oC_oonfX_o`Go
0004oookJ_l007oo001oo`00O`Oooo]Z1ol007mdoookJPGo0000MooonfX3o`00O`?ooo]Z0ol007l7
oookJPOo001oNooonfX3o`00Oa;ooo]Z000GoookJP?o001oE_oonfXco`Go00Go001oMOoonfX5o`00
07Oooo]Z0ol007l3oookJP?o001o1ooonfX6o`00Ogcooo]Z0ol007lBoookJP005?oonfX6o`00Oego
oo]Z=ol5o`1_oookJPGo0000MooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001oOOoonfX6o`00Oa;o
oo]Z000DoookJPKo001oI?oonfXko`Go06Cooo]Z1Ol0001hoookJP?o001o00Cooo]Zo`00Ool007oo
001o2?oonfX2o`00Oggooo]Z1_l007lBoookJP005_oonfX4o`00Ofkooo]Z??l5o`1IoookJPGo0000
N?oonfX7o`00O`Wooo]Z1ol007mioookJPCo001o4_oonfX001Oooo]Z0ol007mioookJSgo1Ol0COoo
nfX5o`0007Wooo]Z1Ol007l:oookJPOo001oN_oonfX3o`00Oa;ooo]Z002OoookJSco1Ol0@_oonfX5
o`000?oooo]Z7ooonfX00:[ooo]Z?Ol5o`0foookJPGo0000oooonfXOoookJP00]OoonfXmo`Go02_o
oo]Z1Ol0003ooookJQoooo]Z0030oookJSgo1Ol08?oonfX5o`000?oooo]Z7ooonfX00<cooo]Z??l5
o`0EoookJPGo0000oooonfXOoookJP00eooonfY2o`Go00Cooo]Z1Ol0003ooookJQoooo]Z0002oook
J^7o0000Aol5o`3oo`0001Co00000ooonfX000;ooo]Zk?l00017o`Go0?oo00002Ol00003oookJP00
0_oonf[go`0004go1Ol0mol00003oookJP000_oonf[oo`0000?o0000Dol5o`3Vo`0000?ooo]Z0002
oookJ_oo00005?l0001=o`Go0=_o00000ooonfX001;ooo]Z00?o0000oookJ_oonfX0PooonfX00ol0
003ooo]ZoookJP22oookJPGo00001?oonfY7o`Go03Wooo]Z00?o0000oookJ_oonfX0PooonfX00ol0
003ooo]ZoookJP0AoookJP004_oonfX00ol0003ooo]ZoookJP23oookJP03o`000?oonf[ooo]Z08;o
oo]Z1Ol0000?oookJTOo1Ol0;_oonfX00ol0003ooo]ZoookJP23oookJP03o`000?oonf[ooo]Z017o
oo]Z003ooookJQkooo]Z1Ol0000PoookJT;o1Ol0_?oonfX00?oooo]Z7_oonfX5o`00037ooo]Z??l5
o`2aoookJP00oooonfXNoookJPGo0000??oonfXlo`Go0:Kooo]Z003ooookJQkooo]Z1Ol00017oook
JSco1Ol0VooonfX00?oooo]Z7_oonfX5o`0005;ooo]Z??l5o`2@oookJP00oooonfXNoookJPGo0000
G_oonfXko`Go08Gooo]Z003ooookJQkooo]Z1Ol0001YoookJS[o1Ol0NooonfX00?oooo]Z7_oonfX5
o`0007Cooo]Z=_l5o`1doookJP00oooonfXNoookJPGo0000OooonfXbo`Go06gooo]Z003ooookJQko
oo]Z1Ol0002:oookJRoo1Ol0IOoonfX00?oooo]Z7_oonfX5o`0009Gooo]Z:ol5o`1NoookJP00oooo
nfXNoookJPGo0000WooonfXXo`Go05Oooo]Z003ooookJQkooo]Z1Ol0002VoookJRSo1Ol0D?oonfX0
013ooo]Zoooo0030ool002Oo1Ol0>Ooo000AoookJP004?oonf[oool00<Soo`009?l5o`0dool0017o
oo]Z000@oookJ_ooo`00cooo000Qo`Go033oo`004OoonfX0013ooo]Zoooo003Fool001go1Ol0;Ooo
000AoookJP004?oonf[oool00=goo`006_l5o`0Yool0017ooo]Z003ooookJQkooo]Z1Ol0003@oook
JQOo1Ol0=ooonfX00?oooo]Z7_oonfX5o`000=Gooo]Z5Ol5o`0doookJP00oooonfXNoookJPGo0000
fOoonfXEo`Go033ooo]Z003ooookJQkooo]Z1Ol0003LoookJQGo1Ol0;OoonfX00?oooo]Z7_oonfX5
o`000>3ooo]Z4ol5o`0[oookJP00oooonfXNoookJPGo0000hooonfXCo`Go02Sooo]Z003ooookJQko
oo]Z1Ol0003VoookJQ;o1Ol09_oonfX00?oooo]Z7_oonfX5o`000>[ooo]Z4?l5o`0ToookJP00oooo
nfXNoookJPGo0000kOoonfX?o`Go02;ooo]Z003ooookJQkooo]Z1Ol0003_oookJPoo1Ol08?oonfX0
0?oooo]Z7_oonfX5o`000?;ooo]Z3Ol5o`0OoookJP00oooonfXNoookJPGo0000m?oonfX=o`Go01go
oo]Z003ooookJQkooo]Z1Ol0003foookJPco1Ol07?oonfX00?oooo]Z7_oonfX5o`000?Sooo]Z2ol5
o`0KoookJP00oooonfXNoookJPGo0000n_oonfX9o`Go01_ooo]Z003ooookJQkooo]Z1Ol0003koook
JPWo1Ol06_oonfX00?oooo]Z7_oonfX5o`000?gooo]Z2?l5o`0IoookJP00oooonfXNoookJPGo0000
o_oonfX7o`Go01Wooo]Z003ooookJQkooo]Z1Ol0003noookJPSo1Ol06?oonfX00?oooo]Z7_oonfX5
o`000?oooo]Z2?l5o`0GoookJP00oooonfXNoookJPGo0000oooonfX1oookJPSo1Ol05_oonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z0OoonfX8o`Go01Kooo]Z003moookJPWo001o0_oonfX3o`00O`?ooo]Z
1Ol007l:oookJPGo0000oooonfX2oookJPSo1Ol05OoonfX00?gooo]Z2Ol007l2oookJP?o001o0_oo
nfX7o`00O`Wooo]Z1Ol0003ooookJP?ooo]Z1ol5o`0EoookJP00oOoonfX4o`00O`Oooo]Z0ol007l0
0ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJPCooo]Z1_l5
o`0EoookJP00o_oonfX4o`00O`[ooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z1?oonfX7
o`Go01Cooo]Z003ooookJPGo001o3_oonfX3o`00O`Sooo]Z1ol0003ooookJP?ooo]Z1_l5o`0Doook
JP00oooonfX2oookJPCo001o3OoonfX3o`00O`Sooo]Z1Ol0003ooookJPGooo]Z1_l5o`0DoookJP00
oooonfX3oookJP?o001o2?oonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000oooonfX5oookJPKo1Ol0
5?oonfX00?oooo]Z1?oonfX3o`00O`Oooo]Z1ol007l9oookJPGo0000oooonfX6oookJPKo1Ol04ooo
nfX00?gooo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`[ooo]Z1Ol0003ooookJPKooo]Z1_l5o`0C
oookJP00oOoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3_oonfX5o`000?oooo]Z1_oonfX6o`Go
01?ooo]Z003moookJPCo001o0_oonfX3o`00O`Oooo]Z0_l007l>oookJPGo0000oooonfX6oookJPOo
1Ol04_oonfX00?kooo]Z1ol007l9oookJPOo001o2?oonfX5o`000?oooo]Z1ooonfX6o`Go01;ooo]Z
003ooookJPGo001o2_oonfX7o`00O`Sooo]Z1Ol0003ooookJPOooo]Z1_l5o`0BoookJP00oooonfXN
oookJPGo0000oooonfX7oookJPKo1Ol04_oonfX00?oooo]Z7_oonfX5o`000?oooo]Z2?oonfX5o`Go
01;ooo]Z003ooookJQkooo]Z1Ol0003ooookJPSooo]Z1Ol5o`0BoookJP00oooonfXNoookJPGo0000
oooonfX8oookJPGo1Ol04_oonfX00?oooo]Z7_oonfX5o`000?oooo]Z2?oonfX5o`Go01;ooo]Z003o
oookJQkooo]Z1Ol0003ooookJPSooo]Z1Ol5o`0BoookJP00oooonfXNoookJPGo0000oooonfX8oook
JPGo1Ol04_oonfX00?oooo]Z7_oonfX5o`000?oooo]Z2?oonfX5o`Go01;ooo]Z003ooookJQkooo]Z
1Ol0003ooookJPSooo]Z1Ol5o`0BoookJP00oooonfXNoookJPGo0000oooonfX8oookJPGo1Ol04_oo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z2?oonfX5o`Go01;ooo]Z003ooookJQkooo]Z1Ol0003ooook
JPSooo]Z1_l5o`0AoookJP00oooonfXNoookJPGo0000oooonfX8oookJPKo1Ol04OoonfX00?oooo]Z
7_oonfX5o`000?oooo]Z2?oonfX6o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPSooo]Z1_l5
o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00
oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2Ooo
nfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoook
JPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017o
oo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooo
nfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooook
JQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo
1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0
003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWo
oo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0A
oookJP00oooonfX?oookJPGo001o2_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJPko
oo]Z1ol007l9oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z3OoonfX4o`00O`04oook
J_l007oo001oo`00O`Wooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfX=oookJP?o001o
0ooonfX3o`00O`Sooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXCoookJP?o001o2?oo
nfX7o`000?oooo]Z1ooonfX5o`Go017ooo]Z003ooookJQ?ooo]Z0ol007l8oookJPGo0000oooonfX9
oookJPGo1Ol04OoonfX00?oooo]Z3_oonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000oooonfX9oook
JPGo1Ol04OoonfX00?oooo]Z3_oonfX7o`00O`Wooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00
oooonfX>oookJPKo001o2_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJPkooo]Z0_l0
07l>oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z3_oonfX2o`00O`kooo]Z1Ol0003o
oookJPWooo]Z1Ol5o`0AoookJP00oooonfX?oookJPOo001o2?oonfX5o`000?oooo]Z2OoonfX5o`Go
017ooo]Z003ooookJPoooo]Z1ol007l8oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z
7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5
o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00
oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2Ooo
nfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoook
JPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017o
oo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooo
nfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooook
JQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo
1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0
003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWo
oo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0A
oookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooo
nfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5
o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo
0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z
003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfX9
oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQko
oo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol0
4OoonfX00?oooo]Z0ol007l6oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003ooookJPWooo]Z1Ol5
o`0AoookJP00oooonfX3o`00O`Kooo]Z0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z2OoonfX5
o`Go017ooo]Z003ooookJP?o001o1_oonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00
Ool007oo001o2OoonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJP7ooo]Z0_l007l:oook
JP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfX1oookJP?o
001o3ooonfX3o`00O`Sooo]Z1ol0003ooookJPOooo]Z1Ol5o`0AoookJP00oooonfX1oookJP?o001o
3ooonfX3o`00O`Sooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfX2oookJP;o001o2_oo
nfX2o`00O`;ooo]Z1?l007l8oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z0_oonfX3
o`00O`Wooo]Z1ol007l9oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z0ooonfX2o`00
O`Wooo]Z1_l007l:oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z1?oonfX2o`00O`So
oo]Z0_l007l>oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z1?oonfX2o`00O`Sooo]Z
0_l007l>oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?gooo]Z2Ol007l8oookJPOo001o2?oo
nfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003moookJPWo001o2?oonfX7o`00O`Sooo]Z1Ol0003o
oookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z
1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5
o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0Aoook
JP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z
2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXN
oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go
017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000
oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5
o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z7ooonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z7ooonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.06829, -9.06606, \
0.00371579, 0.0510851}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{LegendreP[1, x], \ LegendreQ[1, x]}, {x, \(-1\), 1}, \ 
      PlotStyle \[Rule] MyPlotStyle[2]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.13247 0.117755 [
[.02381 .11997 -13.4688 -20 ]
[.02381 .11997 13.4688 0 ]
[.2619 .11997 -20.9688 -20 ]
[.2619 .11997 20.9688 0 ]
[.7381 .11997 -14.5 -20 ]
[.7381 .11997 14.5 0 ]
[.97619 .11997 -7 -20 ]
[.97619 .11997 7 0 ]
[.4875 .01472 -26.9375 -10 ]
[.4875 .01472 0 10 ]
[.4875 .25022 -14 -10 ]
[.4875 .25022 0 10 ]
[.4875 .36798 -14 -10 ]
[.4875 .36798 0 10 ]
[.4875 .48573 -14 -10 ]
[.4875 .48573 0 10 ]
[.4875 .60349 -14 -10 ]
[.4875 .60349 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .13247 m
.02381 .13872 L
s
gsave
.02381 .11997 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .13247 m
.2619 .13872 L
s
gsave
.2619 .11997 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .13247 m
.7381 .13872 L
s
gsave
.7381 .11997 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .13247 m
.97619 .13872 L
s
gsave
.97619 .11997 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .13247 m
.07143 .13622 L
s
.11905 .13247 m
.11905 .13622 L
s
.16667 .13247 m
.16667 .13622 L
s
.21429 .13247 m
.21429 .13622 L
s
.30952 .13247 m
.30952 .13622 L
s
.35714 .13247 m
.35714 .13622 L
s
.40476 .13247 m
.40476 .13622 L
s
.45238 .13247 m
.45238 .13622 L
s
.54762 .13247 m
.54762 .13622 L
s
.59524 .13247 m
.59524 .13622 L
s
.64286 .13247 m
.64286 .13622 L
s
.69048 .13247 m
.69048 .13622 L
s
.78571 .13247 m
.78571 .13622 L
s
.83333 .13247 m
.83333 .13622 L
s
.88095 .13247 m
.88095 .13622 L
s
.92857 .13247 m
.92857 .13622 L
s
.01 w
0 .13247 m
1 .13247 L
s
.25 Mabswid
.5 .01472 m
.50625 .01472 L
s
gsave
.4875 .01472 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .25022 m
.50625 .25022 L
s
gsave
.4875 .25022 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .36798 m
.50625 .36798 L
s
gsave
.4875 .36798 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .48573 m
.50625 .48573 L
s
gsave
.4875 .48573 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 .60349 m
.50625 .60349 L
s
gsave
.4875 .60349 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .03827 m
.50375 .03827 L
s
.5 .06182 m
.50375 .06182 L
s
.5 .08537 m
.50375 .08537 L
s
.5 .10892 m
.50375 .10892 L
s
.5 .15602 m
.50375 .15602 L
s
.5 .17957 m
.50375 .17957 L
s
.5 .20312 m
.50375 .20312 L
s
.5 .22667 m
.50375 .22667 L
s
.5 .27378 m
.50375 .27378 L
s
.5 .29733 m
.50375 .29733 L
s
.5 .32088 m
.50375 .32088 L
s
.5 .34443 m
.50375 .34443 L
s
.5 .39153 m
.50375 .39153 L
s
.5 .41508 m
.50375 .41508 L
s
.5 .43863 m
.50375 .43863 L
s
.5 .46218 m
.50375 .46218 L
s
.5 .50928 m
.50375 .50928 L
s
.5 .53284 m
.50375 .53284 L
s
.5 .55639 m
.50375 .55639 L
s
.5 .57994 m
.50375 .57994 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02381 .01472 m
.06244 .02427 L
.10458 .03469 L
.14415 .04447 L
.18221 .05388 L
.22272 .0639 L
.26171 .07354 L
.30316 .08379 L
.34309 .09367 L
.3815 .10317 L
.42237 .11327 L
.46172 .123 L
.49955 .13236 L
.53984 .14232 L
.57861 .15191 L
.61984 .1621 L
.65954 .17192 L
.69774 .18137 L
.73838 .19142 L
.77751 .20109 L
.81909 .21138 L
.85916 .22128 L
.89771 .23082 L
.93871 .24096 L
.97619 .25022 L
s
.02 1 0 r
.02458 .61803 m
.02499 .40798 L
.02605 .36911 L
.02729 .3425 L
.02846 .32476 L
.03053 .30183 L
.03279 .28362 L
.03527 .26801 L
.0379 .25461 L
.04262 .23554 L
.05205 .2079 L
.06244 .18586 L
.0842 .15314 L
.10458 .13101 L
.14335 .10031 L
.18458 .07689 L
.22428 .05978 L
.26248 .04688 L
.30312 .03612 L
.34225 .02814 L
.36223 .02486 L
.38383 .02187 L
.40294 .01968 L
.4239 .01775 L
.44384 .01636 L
.45473 .01578 L
.4649 .01536 L
.46991 .01519 L
.47536 .01503 L
.48016 .01492 L
.48526 .01483 L
.48984 .01477 L
.49245 .01474 L
.49364 .01474 L
.4949 .01473 L
.49596 .01472 L
.49713 .01472 L
.4982 .01472 L
.49919 .01472 L
.50036 .01472 L
.50142 .01472 L
.50265 .01472 L
.50381 .01472 L
.50497 .01473 L
.5062 .01474 L
.50844 .01475 L
.5111 .01478 L
.51353 .01481 L
.51881 .0149 L
.52383 .01501 L
Mistroke
.53266 .01527 L
.54228 .01565 L
.56199 .01672 L
.58298 .01833 L
.60443 .02047 L
.62461 .02297 L
.66321 .02913 L
.70427 .03788 L
.74381 .04881 L
.78183 .06214 L
.82231 .08033 L
.86127 .10343 L
.88112 .11835 L
.90268 .13825 L
.92342 .16319 L
.93331 .17836 L
.94258 .19575 L
.95028 .21384 L
.95857 .23987 L
.96305 .25916 L
.9655 .27244 L
.96777 .28765 L
.96971 .30417 L
.97179 .32815 L
.97298 .34741 L
.9741 .37338 L
.9751 .41263 L
Mfstroke
.9751 .41263 m
.97547 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z000@oookJPOoo`00jOoonfY0o`Go0?oooo]Z0OoonfX0013ooo]Z3?oo003C
oookJUco1Ol0mOoonfX0013ooo]Z4?oo0039oookJVko1Ol0jOoonfX0013ooo]Z5?oo002moookJX;o
1Ol0gOoonfX0013ooo]Z6Ooo002/oookJYKo1Ol0eOoonfX001?ooo]Z6_oo002OoookJSSo1Ol03?oo
nfX3o`00O`[ooo]Z1Ol0000JoookJSCo1Ol0d?oonfX001Sooo]Z6Ooo002FoookJRco1Ol07OoonfX3
o`00O`[ooo]Z1Ol0000UoookJRoo1Ol0b_oonfX001cooo]Z6Ooo002=oookJR_o1Ol08?oonfX6o`00
O`[ooo]Z1Ol0000aoookJRSo1Ol0aOoonfX0023ooo]Z6Ooo0024oookJRSo1Ol0:?oonfX6o`00O`[o
oo]Z1Ol0000moookJR7o1Ol0`?oonfX002Gooo]Z6?oo001loookJR3o1Ol0=_oonfX4o`00O`[ooo]Z
1Ol00015oookJQko1Ol0^ooonfX002Wooo]Z6?oo001doookJQ_o1Ol0@?oonfX3o`00O`[ooo]Z1Ol0
001:oookJQko1Ol0]_oonfX002gooo]Z6?oo001[oookJQ_o1Ol0D_oonfX5o`00053ooo]Z7?l5o`2b
oookJP00<OoonfXHool006?ooo]Z6_l5o`1GoookJPGo0000EOoonfXLo`Go0:gooo]Z000eoookJQOo
o`00G?oonfXIo`Go05cooo]Z1Ol0001JoookJQ_o1Ol0ZOoonfX003Wooo]Z5ooo001DoookJQWo1Ol0
H?oonfX5o`0005oooo]Z6_l5o`2UoookJP00?OoonfXGool004gooo]Z6?l5o`1ToookJPGo0000I?oo
nfXIo`Go0:7ooo]Z0011oookJQKoo`00A_oonfXGo`Go06Wooo]Z1Ol0001XoookJQSo1Ol0W_oonfX0
04Gooo]Z5_oo000noookJQOo1Ol0KOoonfX5o`0006gooo]Z5ol5o`2JoookJP00B?oonfXGool003Ko
oo]Z5ol5o`1aoookJPGo0000LOoonfXGo`Go09Kooo]Z001<oookJQSoo`00;_oonfXFo`Go07Gooo]Z
1Ol0001eoookJQKo1Ol0TooonfX0053ooo]Z6?oo000WoookJQKo1Ol0N?oonfX5o`0007Wooo]Z5Ol5
o`2@oookJP00DooonfXIool0023ooo]Z5Ol5o`1loookJPGo0000O?oonfXEo`Go08gooo]Z001Goook
JQWoo`006OoonfXDo`Go083ooo]Z1Ol00020oookJQ?o1Ol0RooonfX005_ooo]Z6Ooo000BoookJQ?o
1Ol0Q?oonfX5o`0008Cooo]Z4_l5o`28oookJP00H?oonfXHool000_ooo]Z4ol5o`27oookJPGo0000
QooonfXAo`Go08Kooo]Z001ToookJQOoo`001OoonfXCo`Go08[ooo]Z1Ol0002:oookJQ7o1Ol0Pooo
nfX006Sooo]Z5_oo000Bo`Go08gooo]Z1Ol0002=oookJQ7o1Ol0P?oonfX006cooo]Z3ooo000Bo`Go
093ooo]Z1Ol0002?oookJQ7o1Ol0O_oonfX0073ooo]Z2Ooo000Ao`Go09?ooo]Z1Ol0002BoookJQ3o
1Ol0O?oonfX007Cooo]Z0ooo000@o`Go00Goo`00TOoonfX5o`0009Cooo]Z4Ol5o`1ioookJP00MOoo
nfX?o`Go00coo`00SOoonfX5o`0009Oooo]Z4?l5o`1goookJP00LooonfX?o`Go01;oo`00ROoonfX5
o`0009[ooo]Z3ol5o`1eoookJP00L?oonfX?o`Go01[oo`00Q?oonfX5o`0009cooo]Z4?l5o`1boook
JP00K_oonfX?o`Go00Kooo]Z6_oo0020oookJPGo0000W_oonfX@o`Go073ooo]Z001/oookJPoo1Ol0
3OoonfXIool007cooo]Z1Ol0002QoookJPoo1Ol0K_oonfX006[ooo]Z3ol5o`0CoookJQWoo`00N?oo
nfX5o`000:?ooo]Z4?l5o`1[oookJP00J?oonfX?o`Go01Wooo]Z6Ooo001doookJPGo0000YOoonfX@
o`Go06Wooo]Z001VoookJPko1Ol08OoonfXHool0073ooo]Z1Ol0002XoookJPoo1Ol0IooonfX006Go
oo]Z3Ol5o`0WoookJQSoo`00K?oonfX5o`000:[ooo]Z3ol5o`1UoookJP00HooonfX=o`Go02gooo]Z
6?oo001XoookJPGo0000[?oonfX>o`Go06Cooo]Z001QoookJPgo1Ol0<ooonfXIool006?ooo]Z1Ol0
002_oookJPgo1Ol0H_oonfX005oooo]Z3Ol5o`0ioookJQWoo`00GooonfX5o`000;7ooo]Z3Ol5o`1P
oookJP00GOoonfX=o`Go03oooo]Z6Ooo001KoookJPGo0000/ooonfX<o`Go05oooo]Z001KoookJPko
1Ol0A?oonfXJool005Kooo]Z1Ol0002eoookJPco1Ol0GOoonfX005Wooo]Z3_l5o`1:oookJQ[oo`00
D_oonfX5o`000;Kooo]Z3Ol5o`1KoookJP00F?oonfX=o`Go057ooo]Z6Ooo001>oookJPGo0000^?oo
nfX<o`Go05[ooo]Z001FoookJPgo1Ol0EooonfXHool004_ooo]Z1Ol0002joookJPco1Ol0F?oonfX0
01Oooo]Z0ol007ljoookJPgo1Ol0<ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o5_oonfXHool0
04Oooo]Z1Ol0001ioookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l^oookJPgo1Ol0@OoonfX3o`00
Oa;ooo]Z000GoookJP?o001o>?oonfX=o`Go03Cooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Oa[o
oo]Z5ooo0013oookJPGo0000N?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o;ooonfX<o`Go043o
oo]Z0ol007lBoookJP005ooonfX3o`00OcOooo]Z3?l5o`0foookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o7_oonfXFool0
043ooo]Z1Ol0001hoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo
001o00;o001o00Cooo]Zo`00Ool007oo001o<OoonfX<o`Go03kooo]Z0ol007lBoookJP001ooonfX:
o`00O`Kooo]Z0ol007lfoookJPco1Ol0:_oonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`?ooo]Z0ol007lQoookJQKoo`00??oonfX5o`0007Oooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`?ooo]Z0ol007laoookJPgo1Ol0??oonfX3o`00Oa;ooo]Z0007oookJP[o001o1_oonfX3o`00
OcGooo]Z2ol5o`0/oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o9?oonfXHool0
03Oooo]Z1Ol0001goookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lcoookJPco1Ol0>ooonfX3o`00
Oa;ooo]Z000GoookJP?o001o<ooonfX;o`Go03[ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00ObSo
oo]Z6Ooo000boookJPGo0000MooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o=OoonfX;o`Go03[o
oo]Z0ol007lBoookJP005ooonfX3o`00Oc;ooo]Z2_l5o`0loookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l2oookJPCo001o;?oonfXIool002kooo]Z1Ol0001goookJP?o001o0ooonfX3o`00O`Oooo]Z
0_l007l2oookJPCo001o=_oonfX<o`Go03Sooo]Z0ol007lBoookJP005ooonfX3o`00Oc7ooo]Z2_l5
o`0moookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l`oookJQ_oo`00:OoonfX5o`0007Oooo]Z0ol0
07l3oookJP?o001o1ooonfX7o`00OcWooo]Z2ol5o`0goookJP?o001o4_oonfX001Oooo]Z0ol007l`
oookJP[o1Ol0?_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001o=OoonfXKool002Gooo]Z1Ol0001g
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lloookJP_o1Ol0=OoonfX3o`00Oa;ooo]Z000Doook
JPKo001o;_oonfX;o`Go03oooo]Z0ol007l3oookJP?o001o1ooonfX2o`00Ockooo]Z6_oo000Qoook
JPGo0000MooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o@OoonfX;o`Go037ooo]Z1_l007lBoook
JP005?oonfX6o`00Obgooo]Z2_l5o`12oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00
Od?ooo]Z6?oo000NoookJPGo0000N?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007m2
oookJP_o1Ol0<?oonfX6o`00Oa;ooo]Z000FoookJPCo001o;?oonfX:o`Go04?ooo]Z1ol007l9oook
JPOo001o@OoonfXHool001[ooo]Z1Ol0001hoookJPOo001o2OoonfX7o`00Ockooo]Z2ol5o`0`oook
JPCo001o4_oonfX001Oooo]Z0ol007l[oookJP[o1Ol0AOoonfX5o`00O`[ooo]Z1ol007m6oookJQOo
o`005_oonfX5o`0007Wooo]Z1Ol007l:oookJPOo001o?ooonfX;o`Go033ooo]Z0ol007lBoookJP00
A?oonfX:o`Go0:Kooo]Z5_oo000CoookJPGo0000d?oonfX:o`Go04Cooo]Z0012oookJP[o1Ol0[?oo
nfXFool000oooo]Z1Ol0003AoookJP[o1Ol0@ooonfX0047ooo]Z2_l5o`2`oookJQSoo`002_oonfX5
o`000=;ooo]Z2_l5o`12oookJP00@?oonfX:o`Go0;Gooo]Z6?oo0006oookJPGo0000e?oonfX9o`Go
047ooo]Z000ooookJP[o1Ol0^_oonfXHool000;ooo]Z1Ol0003EoookJPWo1Ol0@?oonfX003kooo]Z
2_l5o`2noookJQ[oo`000_l0003FoookJPWo1Ol0?ooonfX000;ooo]Z??l00008o`Go0<Co00006_oo
003Eo`0000Wo1Ol0>ol00003oookJP000_oonfXko`0000So1Ol0b_l0000Iool00=;o00002Ol5o`0j
o`0000?ooo]Z0002oookJS[o00002?l5o`3?o`0001Woo`00col00009o`Go03Wo00000ooonfX000;o
oo]Z>Ol00008o`Go0=Co00006?oo003=o`0000Wo1Ol0>?l00003oookJP000_oonfXho`0000Wo1Ol0
fOl0000Gool00<[o00002Ol5o`0go`0000?ooo]Z000BoookJP03o`000?oonf[ooo]Z02Cooo]Z2Ol5
o`1FoookJP03o`000?oonf[ooo]Z08;ooo]Z0ol0000Gool006oooo]Z00?o0000oookJ_oonfX0EOoo
nfX8o`Go02Kooo]Z00?o0000oookJ_oonfX04OoonfX001;ooo]Z00?o0000oookJ_oonfX08ooonfX9
o`Go05Oooo]Z00?o0000oookJ_oonfX0P_oonfX5o`0000;ooo]Z5ooo001[oookJP03o`000?oonf[o
oo]Z05Kooo]Z2?l5o`0UoookJP03o`000?oonf[ooo]Z017ooo]Z000goookJPWo1Ol0gOoonfX5o`00
00Kooo]Z5ooo0031oookJPSo1Ol0>?oonfX003Kooo]Z2Ol5o`3NoookJPGo00002OoonfXIool00;go
oo]Z2?l5o`0goookJP00=OoonfX9o`Go0=oooo]Z1Ol0000=oookJQWoo`00^OoonfX9o`Go03Kooo]Z
000doookJPWo1Ol0h?oonfX5o`00017ooo]Z6Ooo002foookJPSo1Ol0=_oonfX003?ooo]Z2Ol5o`3Q
oookJPGo00005OoonfXIool00;?ooo]Z2?l5o`0eoookJP00<_oonfX9o`Go0>;ooo]Z1Ol0000Ioook
JQWoo`00/?oonfX8o`Go03Cooo]Z000boookJPSo1Ol0hooonfX5o`0001kooo]Z6?oo002]oookJPSo
1Ol0<ooonfX0037ooo]Z2?l5o`3ToookJPGo00008_oonfXHool00:Wooo]Z2?l5o`0coookJP00<?oo
nfX8o`Go0>Gooo]Z1Ol0000VoookJQSoo`00Y_oonfX8o`Go03;ooo]Z000`oookJPOo1Ol0i_oonfX5
o`0002[ooo]Z6?oo002SoookJPSo1Ol0<OoonfX002oooo]Z2?l5o`3VoookJPGo0000;_oonfXHool0
0:3ooo]Z2?l5o`0`oookJP00;_oonfX8o`Go0>Oooo]Z1Ol0000boookJQSoo`00W?oonfX9o`Go02oo
oo]Z000^oookJPOo1Ol0j?oonfX5o`0003Kooo]Z5ooo002JoookJPSo1Ol0;ooonfX002gooo]Z2?l5
o`3XoookJPGo0000>_oonfXGool009Oooo]Z2?l5o`0^oookJP00;?oonfX8o`Go0>Wooo]Z1Ol0000n
oookJQOoo`00U?oonfX8o`Go02gooo]Z000/oookJPOo1Ol0j_oonfX5o`0004;ooo]Z5_oo002Boook
JPSo1Ol0;?oonfX002_ooo]Z2?l5o`3ZoookJPGo0000A_oonfXFool008kooo]Z2?l5o`0/oookJP00
:_oonfX8o`Go0>_ooo]Z1Ol00019oookJQSoo`00R_oonfX8o`Go02_ooo]Z000ZoookJPOo1Ol0k?oo
nfX5o`0004gooo]Z6?oo0027oookJPSo1Ol0:_oonfX002Wooo]Z2?l5o`3/oookJPGo0000DOoonfXH
ool008Cooo]Z2?l5o`0YoookJP00:?oonfX8o`Go0>gooo]Z1Ol0001DoookJQ[oo`00OooonfX8o`Go
02Wooo]Z000XoookJPOo1Ol0k_oonfX5o`0005Sooo]Z6_oo001loookJPSo1Ol0:?oonfX002Oooo]Z
2?l5o`3^oookJPGo0000GOoonfXIool007Wooo]Z1ol5o`0XoookJP009_oonfX8o`Go0>oooo]Z1Ol0
001QoookJQWoo`00M_oonfX7o`Go02Oooo]Z000VoookJPOo1Ol0l?oonfX5o`0006Gooo]Z6?oo001c
oookJPOo1Ol09ooonfX002Gooo]Z2?l5o`3`oookJPGo0000J_oonfXGool0073ooo]Z1ol5o`0Voook
JP009OoonfX7o`Go0?7ooo]Z1Ol0001^oookJQOoo`00K?oonfX7o`Go02Kooo]Z000ToookJPOo1Ol0
l_oonfX5o`0007;ooo]Z5ooo001YoookJPOo1Ol09OoonfX002Cooo]Z1ol5o`3boookJPGo0000M_oo
nfXHool006Cooo]Z1ol5o`0UoookJP008ooonfX7o`Go0??ooo]Z1Ol0001ioookJQWoo`00HOoonfX7
o`Go02Cooo]Z000SoookJPOo1Ol0looonfX5o`0007gooo]Z6Ooo001MoookJPOo1Ol09?oonfX002?o
oo]Z1_l5o`3doookJPGo0000POoonfXJool005Wooo]Z1ol5o`0SoookJP008_oonfX7o`Go0?Cooo]Z
1Ol00025oookJQ[oo`00EOoonfX7o`Go02?ooo]Z000RoookJPKo1Ol0mOoonfX5o`0008[ooo]Z6Ooo
001BoookJPKo1Ol08ooonfX0027ooo]Z1ol5o`3eoookJPGo0000S_oonfXIool004kooo]Z1ol5o`0R
oookJP008OoonfX7o`Go0?Gooo]Z1Ol0002BoookJQSoo`00C?oonfX6o`Go02;ooo]Z000PoookJPOo
1Ol0m_oonfX5o`0009Oooo]Z5ooo0018oookJPOo1Ol08OoonfX0023ooo]Z1ol5o`3foookJPGo0000
VooonfXGool004Cooo]Z1ol5o`0QoookJP008?oonfX6o`Go0?Oooo]Z1Ol0002OoookJQOoo`00@Ooo
nfX6o`Go027ooo]Z000OoookJPOo1Ol0mooonfX5o`000:?ooo]Z6?oo000loookJPOo1Ol08?oonfX0
01oooo]Z1_l5o`3hoookJPGo0000Y_oonfXJool003Sooo]Z1_l5o`0PoookJP007ooonfX6o`Go0?So
oo]Z1Ol0002ZoookJQ[oo`00=?oonfX7o`Go01oooo]Z000NoookJPOo1Ol0n?oonfX5o`000:kooo]Z
6ooo000_oookJPOo1Ol07ooonfX001kooo]Z1_l5o`3ioookJPGo0000/_oonfXKool002cooo]Z1_l5
o`0OoookJP007_oonfX6o`Go0?Wooo]Z1Ol0002goookJQ[oo`00:?oonfX7o`Go01kooo]Z000Moook
JPOo1Ol0nOoonfX5o`000;cooo]Z6?oo000VoookJPKo1Ol07_oonfX001gooo]Z1_l5o`3joookJPGo
0000`?oonfXHool002;ooo]Z1_l5o`0NoookJP007OoonfX6o`Go0?[ooo]Z1Ol00035oookJQOoo`00
7_oonfX7o`Go01gooo]Z000LoookJPOo1Ol0n_oonfX5o`000<Wooo]Z5_oo000LoookJPKo1Ol07Ooo
nfX001cooo]Z1_l5o`3koookJPGo0000cOoonfXFool001Sooo]Z1_l5o`0MoookJP007?oonfX6o`Go
0?_ooo]Z1Ol0003@oookJQOoo`005?oonfX7o`Go01cooo]Z000KoookJPOo1Ol0nooonfX5o`000=Co
oo]Z5ooo000AoookJPKo1Ol07?oonfX001_ooo]Z1_l5o`3loookJPGo0000f?oonfXFool000kooo]Z
1_l5o`0LoookJP006ooonfX6o`Go0?cooo]Z1Ol0003KoookJQOoo`002_oonfX7o`Go01_ooo]Z000K
oookJPKo1Ol0o?oonfX5o`000=oooo]Z5ooo0007oookJPKo1Ol06ooonfX001[ooo]Z1_l5o`3moook
JPGo0000hooonfXGool000?ooo]Z1_l5o`0KoookJP006_oonfX6o`Go0?gooo]Z1Ol0003WoookJQKo
o`001_l5o`0KoookJP006_oonfX6o`Go0?gooo]Z1Ol0003ZoookJQCoo`001_l5o`0JoookJP006Ooo
nfX7o`Go0?3ooo]Z0ol007l:oookJPGo0000k_oonfX@ool000Ko1Ol00ooo000GoookJP006OoonfX6
o`Go0?7ooo]Z0ol007l:oookJPGo0000l_oonfX<ool000Ko1Ol01ooo000CoookJP006OoonfX6o`Go
0?7ooo]Z0ol007l:oookJPGo0000m_oonfX8ool000Oo1Ol02?oo000AoookJP006?oonfX7o`Go0?7o
oo]Z0ol007l:oookJPGo0000n_oonfX5ool000Ko1Ol02?oo000AoookJP006?oonfX6o`Go0?;ooo]Z
0ol007l:oookJPOo0000oOoonfX6o`Go00Soo`004OoonfX001Sooo]Z1_l5o`3boookJP?o001o2_oo
nfX5o`000?oooo]Z1_l5o`08ool0017ooo]Z000HoookJPKo1Ol0l_oonfX3o`00O`[ooo]Z1Ol0003o
oookJP7ooo]Z1_l5o`000ooonf[oo`00ool00004ool0017ooo]Z000GoookJPKo1Ol0looonfX3o`00
O`[ooo]Z1Ol0003ooookJP7ooo]Z1_l5o`0HoookJP005ooonfX6o`Go0??ooo]Z0ol007l:oookJPGo
0000oooonfX1oookJPKo1Ol06?oonfX001Oooo]Z1_l5o`3`oookJPKo001o2_oonfX5o`000?oooo]Z
0OoonfX6o`Go01Sooo]Z000GoookJPKo1Ol0l?oonfX6o`00O`[ooo]Z1Ol0003ooookJP;ooo]Z1Ol5
o`0HoookJP005_oonfX6o`Go0??ooo]Z1?l007l:oookJPGo0000oooonfX2oookJPKo1Ol05ooonfX0
01Kooo]Z1_l5o`3doookJP?o001o2_oonfX5o`000?oooo]Z0_oonfX6o`Go01Oooo]Z000FoookJPKo
1Ol0oooonfX2oookJPGo0000oooonfX2oookJPKo1Ol05ooonfX001Kooo]Z1_l5o`3ooookJP;ooo]Z
1Ol0003ooookJP;ooo]Z1_l5o`0GoookJP005_oonfX5o`Go0?oooo]Z0ooonfX5o`000?oooo]Z0ooo
nfX5o`Go01Oooo]Z000FoookJPGo1Ol0oooonfX3oookJPGo0000oooonfX3oookJPGo1Ol05ooonfX0
01Gooo]Z1_l5o`3ooookJP?ooo]Z1Ol0003ooookJP?ooo]Z1Ol5o`0GoookJP005OoonfX6o`Go0?oo
oo]Z0ooonfX5o`000?oooo]Z0ooonfX5o`Go01Oooo]Z000EoookJPKo1Ol0oooonfX3oookJPGo0000
oooonfX3oookJPKo1Ol05_oonfX001Gooo]Z1_l5o`3ooookJP?ooo]Z1Ol0003ooookJP?ooo]Z1_l5
o`0FoookJP005OoonfX5o`Go0?oooo]Z1?oonfX5o`000?oooo]Z0ooonfX6o`Go01Kooo]Z000Eoook
JPGo1Ol0oooonfX4oookJPGo0000oooonfX3oookJPKo1Ol05_oonfX001Gooo]Z1Ol5o`3ooookJPCo
oo]Z1Ol0003ooookJPCooo]Z1Ol5o`0FoookJP005OoonfX5o`Go0?oooo]Z1?oonfX5o`000?oooo]Z
1?oonfX5o`Go01Kooo]Z000EoookJPGo1Ol0oooonfX4oookJPGo0000oooonfX4oookJPGo1Ol05_oo
nfX001Gooo]Z1Ol5o`3ooookJPCooo]Z1Ol0003ooookJPCooo]Z1Ol5o`0FoookJP005?oonfX6o`Go
0?oooo]Z1?oonfX5o`000?oooo]Z1?oonfX5o`Go01Kooo]Z000DoookJPKo1Ol0oooonfX4oookJPGo
0000oooonfX4oookJPKo1Ol05OoonfX001Cooo]Z1_l5o`3ooookJPCooo]Z1Ol0003ooookJPCooo]Z
1_l5o`0EoookJP005?oonfX6o`Go0?oooo]Z1?oonfX5o`000?oooo]Z1?oonfX6o`Go01Gooo]Z000D
oookJPGo1Ol0oooonfX5oookJPGo0000oooonfX4oookJPKo1Ol05OoonfX001Cooo]Z1Ol5o`3ooook
JPGooo]Z1Ol0003ooookJPGooo]Z1Ol5o`0EoookJP005?oonfX5o`Go0?oooo]Z1OoonfX5o`000?oo
oo]Z1OoonfX5o`Go01Gooo]Z000DoookJPGo1Ol0oooonfX5oookJPGo0000oooonfX5oookJPGo1Ol0
5OoonfX001Cooo]Z1Ol5o`3ooookJPGooo]Z1Ol0003ooookJPGooo]Z1Ol5o`0EoookJP005?oonfX5
o`Go0?oooo]Z1OoonfX5o`000?oooo]Z1OoonfX6o`Go01Cooo]Z000DoookJPGo1Ol0oooonfX5oook
JPGo0000oooonfX5oookJPKo1Ol05?oonfX001?ooo]Z1_l5o`3ooookJPGooo]Z1Ol0003ooookJPGo
oo]Z1_l5o`0DoookJP004ooonfX6o`Go0?oooo]Z1OoonfX5o`000?oooo]Z1OoonfX6o`Go01Cooo]Z
000CoookJPKo1Ol0oooonfX5oookJPGo0000oooonfX6oookJPGo1Ol05?oonfX001?ooo]Z1_l5o`3o
oookJPGooo]Z1Ol0003ooookJPKooo]Z1Ol5o`0DoookJP004ooonfX5o`Go0?oooo]Z1_oonfX5o`00
0?oooo]Z1_oonfX5o`Go01Cooo]Z000CoookJPGo1Ol0oooonfX6oookJPGo0000oooonfX6oookJPKo
1Ol04ooonfX001?ooo]Z1Ol5o`3ooookJPKooo]Z1Ol0003ooookJPKooo]Z1_l5o`0CoookJP004ooo
nfX5o`Go0?oooo]Z1_oonfX5o`000?oooo]Z1_oonfX6o`Go01?ooo]Z000CoookJPGo1Ol0oooonfX6
oookJPGo0000oooonfX6oookJPKo1Ol04ooonfX001?ooo]Z1Ol5o`3ooookJPKooo]Z1Ol0003ooook
JPOooo]Z1Ol5o`0CoookJP004ooonfX5o`Go0?oooo]Z1_oonfX5o`000?oooo]Z1ooonfX5o`Go01?o
oo]Z000CoookJPGo1Ol0oooonfX6oookJPGo0000oooonfX7oookJPGo1Ol04ooonfX001;ooo]Z1_l5
o`3ooookJPKooo]Z1Ol0003ooookJPOooo]Z1Ol5o`0CoookJP004_oonfX6o`Go0?oooo]Z1_oonfX5
o`000?oooo]Z1ooonfX5o`Go01?ooo]Z000BoookJPKo1Ol0oooonfX6oookJPGo0000oooonfX7oook
JPGo1Ol04ooonfX001;ooo]Z1_l5o`3ooookJPKooo]Z1Ol0003ooookJPOooo]Z1Ol5o`0CoookJP00
4_oonfX5o`Go0?oooo]Z1ooonfX5o`000?oooo]Z1ooonfX5o`Go01?ooo]Z000BoookJPGo1Ol0oooo
nfX7oookJPGo0000oooonfX7oookJPGo1Ol04ooonfX001;ooo]Z1Ol5o`3ooookJPOooo]Z1Ol0003o
oookJPOooo]Z1Ol5o`0CoookJP004_oonfX5o`Go0?oooo]Z1ooonfX5o`000?oooo]Z1ooonfX5o`Go
01?ooo]Z000BoookJPGo1Ol0oooonfX7oookJPGo0000oooonfX7oookJPGo1Ol04ooonfX001;ooo]Z
1Ol5o`3ooookJPOooo]Z1Ol0003ooookJPOooo]Z1Ol5o`0CoookJP004_oonfX5o`Go0?oooo]Z1ooo
nfX5o`000?oooo]Z1ooonfX5o`Go01?ooo]Z000BoookJPGo1Ol0oooonfX7oookJPGo0000oooonfX7
oookJPGo1Ol04ooonfX0017ooo]Z1_l5o`3ooookJPOooo]Z1Ol0003ooookJPOooo]Z1Ol5o`0Coook
JP004OoonfX6o`Go0?oooo]Z1ooonfX5o`000?oooo]Z1ooonfX5o`Go01?ooo]Z000AoookJPKo1Ol0
oooonfX7oookJPGo0000oooonfX7oookJPGo1Ol04ooonfX0017ooo]Z1_l5o`3ooookJPOooo]Z1Ol0
003ooookJPOooo]Z1_l5o`0BoookJP004OoonfX5o`Go0?Kooo]Z2Ol007l8oookJPGo0000oooonfX7
oookJPKo1Ol04_oonfX0017ooo]Z1Ol5o`3foookJPWo001o2?oonfX5o`000?oooo]Z1ooonfX6o`Go
01;ooo]Z000AoookJPGo1Ol0m_oonfX4o`00O`gooo]Z1Ol0003ooookJPOooo]Z1_l5o`0BoookJP00
4OoonfX5o`Go0?Oooo]Z1?l007l<oookJPGo0000oooonfX8oookJPGo1Ol04_oonfX0017ooo]Z1Ol5
o`3hoookJPGo001o2_oonfX7o`000?oooo]Z1_oonfX5o`Go01;ooo]Z000AoookJPGo1Ol0n_oonfX4
o`00O`Wooo]Z1Ol0003ooookJPSooo]Z1Ol5o`0BoookJP004OoonfX5o`Go0?_ooo]Z0ol007l9oook
JPGo0000oooonfX8oookJPGo1Ol04_oonfX0017ooo]Z1Ol5o`3loookJP?o001o2?oonfX5o`000?oo
oo]Z2?oonfX5o`Go01;ooo]Z000AoookJPGo1Ol0m_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000
oooonfX8oookJPGo1Ol04_oonfX0017ooo]Z1Ol5o`3foookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0
003ooookJPSooo]Z1Ol5o`0BoookJP004OoonfX5o`Go0?Kooo]Z1?l007l2oookJP?o001o2?oonfX5
o`000?oooo]Z2?oonfX5o`Go01;ooo]Z000AoookJPGo1Ol0mooonfX7o`00O`Wooo]Z1Ol0003ooook
JPSooo]Z1Ol5o`0BoookJP004OoonfX5o`Go0?Sooo]Z1Ol007l:oookJPGo0000oooonfX8oookJPGo
1Ol04_oonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJPSooo]Z1Ol5o`0BoookJP004Ooo
nfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z2?oonfX5o`Go01;ooo]Z000AoookJPGo1Ol0oooonfX8
oookJPGo0000oooonfX8oookJPGo1Ol04_oonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooook
JPSooo]Z1Ol5o`0BoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z2?oonfX6o`Go017o
oo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfX8oookJPKo1Ol04OoonfX0017ooo]Z1Ol5
o`3ooookJPSooo]Z1Ol0003ooookJPSooo]Z1_l5o`0AoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5
o`000?oooo]Z2?oonfX6o`Go017ooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfX9oook
JPGo1Ol04OoonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00
4OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000AoookJPGo1Ol0oooo
nfX8oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003o
oookJPWooo]Z1Ol5o`0AoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z2OoonfX5o`Go
017ooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0017ooo]Z
1Ol5o`3ooookJPSooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004OoonfX5o`Go0?oooo]Z2?oo
nfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfX9
oookJPGo1Ol04OoonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0Aoook
JP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000AoookJPGo1Ol0
oooonfX8oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0
003ooookJPWooo]Z1Ol5o`0AoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z2OoonfX5
o`Go017ooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0017o
oo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004OoonfX5o`Go0?oooo]Z
2?oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooo
nfX9oookJPGo1Ol04OoonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0A
oookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000AoookJPGo
1Ol0oooonfX8oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z
1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z2Ooo
nfX5o`Go017ooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0
017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004OoonfX5o`Go0?oo
oo]Z2?oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000
oooonfX9oookJPGo1Ol04OoonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJPWooo]Z1Ol5
o`0AoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000Aoook
JPGo1Ol0oooonfX8oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0017ooo]Z1Ol5o`3ooookJPSo
oo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z
2OoonfX5o`Go017ooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfX9oookJPGo1Ol04Ooo
nfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004OoonfX5o`Go
0?oooo]Z2?oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo
0000oooonfX9oookJPGo1Ol04OoonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJPWooo]Z
1Ol5o`0AoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000A
oookJPGo1Ol0oooonfX8oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0017ooo]Z1Ol5o`3ooook
JPSooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oo
oo]Z2OoonfX5o`Go017ooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfX9oookJPGo1Ol0
4OoonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004OoonfX5
o`Go0?oooo]Z2?oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000AoookJPGo1Ol0oooonfX8oook
JPGo0000oooonfX9oookJPGo1Ol04OoonfX0017ooo]Z1Ol5o`3hoookJPGo001o2_oonfX5o`000?oo
oo]Z2OoonfX5o`Go017ooo]Z000AoookJPGo1Ol0mooonfX7o`00O`Wooo]Z1Ol0003ooookJPWooo]Z
1Ol5o`0AoookJP004OoonfX5o`Go0?Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z2Ooo
nfX5o`Go017ooo]Z000AoookJPGo1Ol0m_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfX9
oookJPGo1Ol04OoonfX0017ooo]Z1Ol5o`3loookJP?o001o2?oonfX7o`000?oooo]Z1ooonfX5o`Go
017ooo]Z000AoookJPGo1Ol0o?oonfX3o`00O`Sooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00
4OoonfX5o`Go0?[ooo]Z1?l007l9oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0017ooo]Z1Ol5
o`3joookJP?o001o2_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000AoookJPGo1Ol0o?oonfX2
o`00O`Wooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004OoonfX5o`Go0?Kooo]Z0ol007l3oook
JP?o001o2?oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000AoookJPGo1Ol0m_oonfX3o`00O`?o
oo]Z0ol007l8oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0017ooo]Z1Ol5o`3goookJPOo001o
2OoonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000AoookJPGo1Ol0n?oonfX5o`00O`[ooo]Z1Ol0
003ooookJPWooo]Z1Ol5o`0AoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z2OoonfX5
o`Go017ooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0017o
oo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004OoonfX5o`Go0?oooo]Z
2?oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooo
nfX9oookJPGo1Ol04OoonfX0013ooo]Z1_l5o`3ooookJPSooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0A
oookJP004?oonfX6o`Go0?oooo]Z2?oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000@oookJPKo
1Ol0oooonfX8oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0013ooo]Z1_l5o`3ooookJPSooo]Z
1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z2Ooo
nfX5o`Go017ooo]Z000@oookJPGo1Ol0oooonfX9oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0
013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004?oonfX5o`Go0?oo
oo]Z2OoonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000@oookJPGo1Ol0oooonfX9oookJPGo0000
oooonfX9oookJPGo1Ol04OoonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJPWooo]Z1Ol5
o`0AoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000@oook
JPGo1Ol0oooonfX9oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0013ooo]Z1Ol5o`3ooookJPWo
oo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z
2OoonfX5o`Go017ooo]Z000@oookJPGo1Ol0oooonfX9oookJPGo0000oooonfX9oookJPGo1Ol04Ooo
nfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004?oonfX5o`Go
0?oooo]Z2OoonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000@oookJPGo1Ol0oooonfX9oookJPGo
0000oooonfX9oookJPGo1Ol04OoonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJPWooo]Z
1Ol5o`0AoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000@
oookJPGo1Ol0oooonfX9oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0013ooo]Z1Ol5o`3ooook
JPWooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oo
oo]Z2OoonfX5o`Go017ooo]Z000@oookJPGo1Ol0oooonfX9oookJPGo0000oooonfX9oookJPGo1Ol0
4OoonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004?oonfX5
o`Go0?oooo]Z2OoonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000@oookJPGo1Ol0oooonfX9oook
JPGo0000oooonfX9oookJPGo1Ol04OoonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJPWo
oo]Z1Ol5o`0AoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z
000@oookJPGo1Ol0oooonfX9oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0013ooo]Z1Ol5o`3o
oookJPWooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`00
0?oooo]Z2OoonfX5o`Go017ooo]Z000@oookJPGo1Ol0oooonfX9oookJPGo0000oooonfX9oookJPGo
1Ol04OoonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004?oo
nfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000@oookJPGo1Ol0oooonfX9
oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooook
JPWooo]Z1Ol5o`0AoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z2OoonfX5o`Go017o
oo]Z000@oookJPGo1Ol0oooonfX9oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0013ooo]Z1Ol5
o`3ooookJPWooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5
o`000?oooo]Z2OoonfX5o`Go017ooo]Z000@oookJPGo1Ol0oooonfX9oookJPGo0000oooonfX9oook
JPGo1Ol04OoonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00
4?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000@oookJPGo1Ol0oooo
nfX9oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003o
oookJPWooo]Z1Ol5o`0AoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z2OoonfX5o`Go
017ooo]Z000@oookJPGo1Ol0oooonfX9oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0013ooo]Z
1Ol5o`3loookJP?o001o2OoonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000@oookJPGo1Ol0o?oo
nfX3o`00O`Wooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004?oonfX5o`Go0?cooo]Z0ol007l9
oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0013ooo]Z1Ol5o`3goookJPWo001o2?oonfX5o`00
0?oooo]Z2OoonfX5o`Go017ooo]Z000@oookJPGo1Ol0mooonfX9o`00O`Sooo]Z1ol0003ooookJPOo
oo]Z1Ol5o`0AoookJP004?oonfX5o`Go0?Oooo]Z0_l007l3oookJP?o001o2OoonfX5o`000?oooo]Z
2OoonfX5o`Go017ooo]Z000@oookJPGo1Ol0n?oonfX2o`00O`;ooo]Z0ol007l9oookJPGo0000oooo
nfX9oookJPGo1Ol04OoonfX0013ooo]Z1Ol5o`3hoookJP?o001o00Cooo]Zo`00Ool007oo001o2Ooo
nfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z000@oookJPGo1Ol0nOoonfX2o`00O`04oookJ_l007oo
001oo`00O`Wooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP004?oonfX5o`Go0?[ooo]Z1Ol007l9
oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0013ooo]Z1Ol5o`3joookJPGo001o2OoonfX5o`00
0?oooo]Z2OoonfX5o`Go017ooo]Z000@oookJPGo1Ol0nooonfX4o`00O`Wooo]Z1Ol0003ooookJPWo
oo]Z1Ol5o`0AoookJP004?oonfX5o`Go0?cooo]Z0ol007l9oookJPGo0000oooonfX9oookJPGo1Ol0
4OoonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.06829, -1.16745, \
0.00371579, 0.0150263}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{LegendreP[2, x], \ LegendreQ[2, x]}, {x, \(-1\), 1}, \ 
      PlotStyle \[Rule] MyPlotStyle[2]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.308822 0.0851776 [
[.02381 .29632 -13.4688 -20 ]
[.02381 .29632 13.4688 0 ]
[.2619 .29632 -20.9688 -20 ]
[.2619 .29632 20.9688 0 ]
[.7381 .29632 -14.5 -20 ]
[.7381 .29632 14.5 0 ]
[.97619 .29632 -7 -20 ]
[.97619 .29632 7 0 ]
[.4875 .05329 -26.9375 -10 ]
[.4875 .05329 0 10 ]
[.4875 .13847 -26.9375 -10 ]
[.4875 .13847 0 10 ]
[.4875 .22364 -26.9375 -10 ]
[.4875 .22364 0 10 ]
[.4875 .394 -14 -10 ]
[.4875 .394 0 10 ]
[.4875 .47918 -14 -10 ]
[.4875 .47918 0 10 ]
[.4875 .56435 -14 -10 ]
[.4875 .56435 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30882 m
.02381 .31507 L
s
gsave
.02381 .29632 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30882 m
.2619 .31507 L
s
gsave
.2619 .29632 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30882 m
.7381 .31507 L
s
gsave
.7381 .29632 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30882 m
.97619 .31507 L
s
gsave
.97619 .29632 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30882 m
.07143 .31257 L
s
.11905 .30882 m
.11905 .31257 L
s
.16667 .30882 m
.16667 .31257 L
s
.21429 .30882 m
.21429 .31257 L
s
.30952 .30882 m
.30952 .31257 L
s
.35714 .30882 m
.35714 .31257 L
s
.40476 .30882 m
.40476 .31257 L
s
.45238 .30882 m
.45238 .31257 L
s
.54762 .30882 m
.54762 .31257 L
s
.59524 .30882 m
.59524 .31257 L
s
.64286 .30882 m
.64286 .31257 L
s
.69048 .30882 m
.69048 .31257 L
s
.78571 .30882 m
.78571 .31257 L
s
.83333 .30882 m
.83333 .31257 L
s
.88095 .30882 m
.88095 .31257 L
s
.92857 .30882 m
.92857 .31257 L
s
.01 w
0 .30882 m
1 .30882 L
s
.25 Mabswid
.5 .05329 m
.50625 .05329 L
s
gsave
.4875 .05329 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 .13847 m
.50625 .13847 L
s
gsave
.4875 .13847 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .22364 m
.50625 .22364 L
s
gsave
.4875 .22364 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .394 m
.50625 .394 L
s
gsave
.4875 .394 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .47918 m
.50625 .47918 L
s
gsave
.4875 .47918 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .56435 m
.50625 .56435 L
s
gsave
.4875 .56435 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .07032 m
.50375 .07032 L
s
.5 .08736 m
.50375 .08736 L
s
.5 .1044 m
.50375 .1044 L
s
.5 .12143 m
.50375 .12143 L
s
.5 .1555 m
.50375 .1555 L
s
.5 .17254 m
.50375 .17254 L
s
.5 .18957 m
.50375 .18957 L
s
.5 .20661 m
.50375 .20661 L
s
.5 .24068 m
.50375 .24068 L
s
.5 .25772 m
.50375 .25772 L
s
.5 .27475 m
.50375 .27475 L
s
.5 .29179 m
.50375 .29179 L
s
.5 .32586 m
.50375 .32586 L
s
.5 .34289 m
.50375 .34289 L
s
.5 .35993 m
.50375 .35993 L
s
.5 .37696 m
.50375 .37696 L
s
.5 .41104 m
.50375 .41104 L
s
.5 .42807 m
.50375 .42807 L
s
.5 .44511 m
.50375 .44511 L
s
.5 .46214 m
.50375 .46214 L
s
.5 .49621 m
.50375 .49621 L
s
.5 .51325 m
.50375 .51325 L
s
.5 .53028 m
.50375 .53028 L
s
.5 .54732 m
.50375 .54732 L
s
.5 .03625 m
.50375 .03625 L
s
.5 .01922 m
.50375 .01922 L
s
.5 .00218 m
.50375 .00218 L
s
.5 .58139 m
.50375 .58139 L
s
.5 .59843 m
.50375 .59843 L
s
.5 .61546 m
.50375 .61546 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02381 .394 m
.06244 .37411 L
.10458 .35433 L
.14415 .33758 L
.18221 .32314 L
.22272 .30955 L
.26171 .29823 L
.30316 .28807 L
.34309 .28011 L
.3815 .27415 L
.40095 .27176 L
.42237 .26963 L
.44268 .26808 L
.45178 .26754 L
.46172 .26706 L
.4671 .26684 L
.4721 .26667 L
.47727 .26652 L
.48196 .26642 L
.48658 .26633 L
.4887 .26631 L
.49093 .26628 L
.49332 .26626 L
.49438 .26625 L
.49552 .26624 L
.49675 .26624 L
.49789 .26624 L
.49859 .26623 L
.49925 .26623 L
.50049 .26623 L
.50163 .26623 L
.50286 .26624 L
.50401 .26624 L
.50508 .26625 L
.50754 .26627 L
.51014 .26629 L
.51268 .26632 L
.51504 .26636 L
.5204 .26647 L
.5293 .26672 L
.53882 .26708 L
.54906 .26759 L
.56016 .26827 L
.58032 .26987 L
.60019 .27189 L
.62123 .27451 L
.65912 .2805 L
.69946 .28865 L
.73829 .29823 L
.77956 .31027 L
Mistroke
.81932 .32369 L
.85757 .33827 L
.89827 .35561 L
.93745 .37406 L
.97619 .394 L
Mfstroke
.02 1 0 r
.02458 0 m
.02499 .15321 L
.02605 .18205 L
.02729 .20202 L
.02846 .21546 L
.03053 .23298 L
.03279 .24704 L
.0379 .26963 L
.04262 .28456 L
.05224 .30647 L
.06244 .32296 L
.0728 .33565 L
.0825 .3451 L
.09382 .35398 L
.10458 .36079 L
.11426 .36582 L
.12483 .37035 L
.14335 .37629 L
.15367 .37868 L
.16302 .38036 L
.16821 .38111 L
.17382 .38179 L
.17909 .3823 L
.184 .38268 L
.18858 .38295 L
.19094 .38306 L
.1935 .38315 L
.19496 .3832 L
.1963 .38323 L
.19757 .38326 L
.19896 .38328 L
.2002 .3833 L
.20137 .3833 L
.20261 .38331 L
.2033 .38331 L
.20394 .38331 L
.20516 .3833 L
.20647 .38329 L
.20771 .38328 L
.20884 .38326 L
.21159 .3832 L
.2142 .38312 L
.21938 .38291 L
.225 .38259 L
.23446 .38187 L
.24488 .38081 L
.26592 .37793 L
.28537 .37449 L
.30626 .37006 L
.34754 .35952 L
Mistroke
.3873 .34761 L
.42554 .33502 L
.46624 .32086 L
.50542 .30688 L
.54706 .2921 L
.58717 .27834 L
.62578 .26596 L
.66683 .25422 L
.70637 .24482 L
.72627 .24101 L
.7444 .23818 L
.75377 .23699 L
.76394 .23592 L
.76953 .23544 L
.7747 .23507 L
.7796 .23479 L
.78217 .23466 L
.78487 .23455 L
.78728 .23447 L
.78855 .23444 L
.78991 .23441 L
.79117 .23438 L
.7923 .23436 L
.79345 .23435 L
.79452 .23434 L
.79562 .23434 L
.79679 .23433 L
.79778 .23434 L
.79887 .23434 L
.80004 .23435 L
.8013 .23437 L
.80249 .23439 L
.80357 .23441 L
.80621 .23448 L
.80864 .23457 L
.81416 .23485 L
.81902 .23519 L
.82419 .23565 L
.83355 .23678 L
.84364 .23844 L
.85317 .24048 L
.86191 .24281 L
.88081 .24959 L
.89152 .25472 L
.9015 .26053 L
.91201 .26798 L
.92193 .27661 L
.93096 .28623 L
.94051 .29897 L
.94935 .31426 L
Mistroke
.95403 .32446 L
.95907 .33798 L
.96369 .35408 L
.96791 .37457 L
.96994 .38817 L
.97101 .39711 L
.97216 .40879 L
.97325 .42342 L
.97425 .44213 L
.97525 .4742 L
Mfstroke
.97525 .4742 m
.97556 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP004?oonfX5o`Go0?oo
oo]Z2OoonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJQoooo]Z
000@oookJPGo1Ol0oooonfX9oookJPGo0000oooonfXOoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5
o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJQoooo]Z000@oookJPGo
1Ol0oooonfX9oookJPGo0000oooonfXOoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z
7ooonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJQoooo]Z000@oookJPGo1Ol0oooonfX9
oookJPGo0000oooonfXOoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z7ooonfX0013o
oo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJQoooo]Z000@oookJPGo1Ol0oooonfX9oookJPGo0000
oooonfXOoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3o
oookJPWooo]Z1Ol0003ooookJQoooo]Z000@oookJPGo1Ol0oooonfX9oookJPGo0000oooonfXOoook
JP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z
1Ol0003ooookJQoooo]Z000@oookJPGo1Ol0oooonfX9oookJPGo0000oooonfXOoookJP004?oonfX5
o`Go0?oooo]Z2OoonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooook
JQoooo]Z000@oookJPGo1Ol0oooonfX9oookJPGo0000oooonfXOoookJP004?oonfX5o`Go0?oooo]Z
2OoonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJQoooo]Z000@
oookJPGo1Ol0oooonfX9oookJPGo0000oooonfXOoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`00
0?oooo]Z7ooonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJQoooo]Z000@oookJPGo1Ol0
oooonfX9oookJPGo0000oooonfXOoookJP004?oonfX5o`Go0?Wooo]Z1Ol007l:oookJPGo0000oooo
nfXOoookJP004?oonfX5o`Go0?Sooo]Z1ol007l9oookJPGo0000oooonfXOoookJP004?oonfX5o`Go
0?Oooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3[oookJP[o
001o0_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXOoookJP004?oonfX5o`Go0>_ooo]Z
2_l007l8oookJP?o001o2?oonfX7o`000?oooo]Z7OoonfX0013ooo]Z1Ol5o`3moookJP?o001o2?oo
nfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3koookJPCo001o2OoonfX5o`000?oooo]Z7ooonfX0
013ooo]Z1Ol5o`3koookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3moookJP;o
001o2OoonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol5o`3goookJP?o001o0ooonfX3o`00O`Sooo]Z
1Ol0003ooookJQoooo]Z000@oookJPGo1Ol0mooonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooo
nfXOoookJP004?oonfX5o`Go0?Sooo]Z1ol007l9oookJPGo0000oooonfXOoookJP004?oonfX5o`Go
0?Wooo]Z1Ol007l:oookJPGo0000oooonfXOoookJP004?oonfX5o`Go0?oooo]Z2OoonfX5o`000?oo
oo]Z7ooonfX0013ooo]Z1Ol5o`3ooookJPWooo]Z1Ol0003ooookJQoooo]Z000@oookJPKo1Ol0oooo
nfX8oookJPGo0000oooonfXOoookJP004?oonfX6o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0
013ooo]Z1_l5o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000@oookJPKo1Ol0oooonfX8oookJPGo
0000oooonfXOoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5
o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfXO
oookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3ooookJPSo
oo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfXOoookJP004Ooo
nfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003o
oookJQoooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfXOoookJP004OoonfX5o`Go0?oo
oo]Z2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z
000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfXOoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5
o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo
1Ol0oooonfX8oookJPGo0000oooonfXOoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z
7ooonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0oooonfX8
oookJPGo0000oooonfXOoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0017o
oo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000
oooonfXOoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3o
oookJPSooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfXOoook
JP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z
1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfXOoookJP004OoonfX5
o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooook
JQoooo]Z000AoookJPGo1Ol0m_oonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0
m_oonfX9o`00O`Sooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0m_oonfX4o`00O`gooo]Z1Ol0
003ooookJQoooo]Z000AoookJPGo1Ol0j_oonfX:o`00O`?ooo]Z1?l007l<oookJPGo0000oooonfXO
oookJP004OoonfX5o`Go0>[ooo]Z2_l007l4oookJPGo001o2_oonfX7o`000?oooo]Z7OoonfX0017o
oo]Z1Ol5o`3joookJPCo001o2OoonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3koookJP?o001o
2OoonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3loookJP?o001o2?oonfX5o`000?oooo]Z7ooo
nfX0017ooo]Z1Ol5o`3foookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z000Aoook
JPGo1Ol0m_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXOoookJP004OoonfX5o`Go0?Ko
oo]Z1?l007l2oookJP?o001o2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3goookJPOo001o
2OoonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3hoookJPGo001o2_oonfX5o`000?oooo]Z7ooo
nfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0oooonfX8oook
JPGo0000oooonfXOoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z
1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooo
nfXOoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3ooook
JPSooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfXOoookJP00
4OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0
003ooookJQoooo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfXOoookJP004OoonfX5o`Go
0?oooo]Z2?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoo
oo]Z000AoookJPGo1Ol0oooonfX8oookJPGo0000oooonfXOoookJP004OoonfX5o`Go0?oooo]Z2?oo
nfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000Aoook
JPGo1Ol0oooonfX8oookJPGo0000oooonfXOoookJP004OoonfX5o`Go0?oooo]Z2?oonfX5o`000?oo
oo]Z7ooonfX0017ooo]Z1Ol5o`3ooookJPSooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo1Ol0oooo
nfX8oookJPGo0000oooonfXOoookJP004OoonfX6o`Go0?oooo]Z1ooonfX5o`000?oooo]Z7ooonfX0
017ooo]Z1_l5o`3ooookJPOooo]Z1Ol0003ooookJQoooo]Z000AoookJPKo1Ol0oooonfX7oookJPGo
0000oooonfXOoookJP004OoonfX6o`Go0?oooo]Z1ooonfX5o`000?oooo]Z7ooonfX001;ooo]Z1Ol5
o`3ooookJPOooo]Z1Ol0003ooookJQoooo]Z000BoookJPGo1Ol0oooonfX7oookJPGo0000oooonfXO
oookJP004_oonfX5o`Go0?oooo]Z1ooonfX5o`000?oooo]Z7ooonfX001;ooo]Z1Ol5o`3ooookJPOo
oo]Z1Ol0003ooookJQoooo]Z000BoookJPGo1Ol0oooonfX7oookJPGo0000oooonfXOoookJP004_oo
nfX6o`Go0?oooo]Z1_oonfX5o`000?oooo]Z7ooonfX001;ooo]Z1_l5o`3ooookJPKooo]Z1Ol0003o
oookJQoooo]Z000BoookJPKo1Ol0oooonfX6oookJPGo0000oooonfXOoookJP004_oonfX6o`Go0?oo
oo]Z1_oonfX5o`000?oooo]Z7ooonfX001?ooo]Z1Ol5o`3ooookJPKooo]Z1Ol0003ooookJQoooo]Z
000CoookJPGo1Ol0oooonfX6oookJPGo0000oooonfXOoookJP004ooonfX5o`Go0?Sooo]Z0ol007l:
oookJPGo0000oooonfXOoookJP004ooonfX5o`Go0?Sooo]Z0ol007l:oookJPGo0000oooonfXOoook
JP004ooonfX5o`Go0?Sooo]Z0ol007l:oookJPGo0000oooonfXOoookJP004ooonfX6o`Go0>Oooo]Z
2_l007l6oookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX001?ooo]Z1_l5o`3WoookJP[o001o1_oo
nfX3o`00O`[ooo]Z1ol0003ooookJQgooo]Z000CoookJPKo1Ol0mooonfX3o`00O`[ooo]Z1Ol0003o
oookJQoooo]Z000CoookJPKo1Ol0mooonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z000DoookJPGo
1Ol0mooonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z000DoookJPGo1Ol0mooonfX3o`00O`[ooo]Z
1Ol0002BoookJRCo1Ol0J?oonfX001Cooo]Z1Ol5o`3doookJPKo001o2_oonfX5o`0008Sooo]Z>?l5
o`1NoookJP005?oonfX5o`Go0?Cooo]Z1_l007l:oookJPGo0000PooonfY2o`Go05Wooo]Z000Doook
JPGo1Ol0m_oonfX4o`00O`[ooo]Z1Ol0001noookJT_o1Ol0EOoonfX001Cooo]Z1_l5o`3foookJP?o
001o2_oonfX5o`0007Sooo]ZE?l5o`1BoookJP005?oonfX6o`Go0?oooo]Z1?oonfX5o`0007?ooo]Z
8ol5o`0LoookJQgo1Ol0CooonfX001Cooo]Z1_l5o`3ooookJPCooo]Z1Ol0001^oookJQko1Ol0<?oo
nfXFo`Go04cooo]Z000DoookJPKo1Ol0oooonfX4oookJPGo0000JOoonfXNo`Go03[ooo]Z5?l5o`19
oookJP005OoonfX5o`Go0?oooo]Z1?oonfX5o`0006Cooo]Z7_l5o`13oookJQ?o1Ol0A_oonfX001Go
oo]Z1Ol5o`3ooookJPCooo]Z1Ol0001PoookJQco1Ol0C?oonfXBo`Go04Cooo]Z000EoookJPKo1Ol0
oooonfX3oookJPGo0000FooonfXLo`Go05Cooo]Z4Ol5o`12oookJP005OoonfX6o`Go0?oooo]Z0ooo
nfX5o`0005Oooo]Z6ol5o`1LoookJQ3o1Ol0@?oonfX001Gooo]Z1_l5o`3ooookJP?ooo]Z1Ol0001D
oookJQWo1Ol0I?oonfX>o`Go03oooo]Z000EoookJPKo1Ol0oooonfX3oookJPGo0000DOoonfXGo`Go
06cooo]Z3Ol5o`0moookJP005_oonfX6o`Go0?oooo]Z0_oonfX5o`0004gooo]Z5ol5o`1boookJPco
1Ol0??oonfX001Kooo]Z1_l5o`3ooookJP;ooo]Z1Ol0001:oookJQGo1Ol0NOoonfX<o`Go03[ooo]Z
000FoookJPKo1Ol0oooonfX2oookJPGo0000AooonfXDo`Go07oooo]Z2ol5o`0ioookJP005_oonfX6
o`Go0?oooo]Z0_oonfX5o`0004Cooo]Z5?l5o`23oookJPco1Ol0=ooonfX001Oooo]Z1Ol5o`3Yoook
JSKoo`009ooonfXEo`Go08Sooo]Z2ol5o`0foookJP005ooonfX6o`Go0=[ooo]ZDooo000EoookJQCo
1Ol0SOoonfX;o`Go03Gooo]Z000GoookJPKo1Ol0c_oonfYZool000Oooo]Z5?l5o`2BoookJP[o1Ol0
=?oonfX001Oooo]Z1_l5o`33oookJWWoo`005?l5o`2FoookJP[o1Ol0<ooonfX001Oooo]Z1ol5o`2i
oookJWooo`005?l5o`2KoookJPWo1Ol0<_oonfX001Oooo]Z00?o001oo`Go0?l5o`001?l5o`1foook
JPGo001o1?oonfX3o`00O`?ooo]Z1Ol007lZoookJSOoo`005?oonfX5o`0001Gooo]Z7?oo000Co`Go
00Goo`00<?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001oEooonfX9o`Go01cooo]Z0ol007lBoook
JP005ooonfX00ol007oo1Ol0o`Go0004o`Go07Gooo]Z1ol007l3oookJP?o001o0_oonfX7o`00Ob?o
oo]Z;ooo000RoookJPGo00009?oonfX:ool001?o1Ol03ooo000XoookJPOo001o0ooonfX3o`00O`;o
oo]Z1ol007mGoookJP[o1Ol06_oonfX3o`00Oa;ooo]Z000GoookJP03o`00Ool5o`3o1Ol000Go1Ol0
M?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04
oookJ_l007oo001oo`00Oakooo]Z:?oo000^oookJPGo0000:_oonfXDo`Go01Woo`008OoonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo
001oo`00OeSooo]Z2_l5o`0IoookJP?o001o4_oonfX000Oooo]Z2_l007l6oookJP;o001o1_l5o`1W
oookJP[o001o0_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00OaOooo]Z8ooo000i
oookJPGo00009ooonfXDo`Go027oo`006ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3
o`00OeSooo]Z2_l5o`0HoookJP?o001o4_oonfX000Oooo]Z2_l007l6oookJP;o001o1_l5o`1Woook
JP[o001o0_oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o4_oonfXOool004;ooo]Z1Ol0000Toook
JQCo1Ol01_oonfXSool001Kooo]Z0ol007l3oookJP?o001o3?oonfX3o`00OeWooo]Z2_l5o`0Goook
JP?o001o4_oonfX001Oooo]Z0_l007l7o`Go07;ooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`co
oo]Z8?oo0017oookJPGo00008OoonfXDo`Go013ooo]Z8Ooo000AoookJP?o001o0ooonfX3o`00O`co
oo]Z0ol007mJoookJP[o1Ol05_oonfX3o`00Oa;ooo]Z000GoookJP?o001o1_l5o`1boookJP?o001o
0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo001o1ooonfXOool004gooo]Z1Ol0000NoookJQCo1Ol0
6_oonfXNool000gooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007mLoookJPWo1Ol0
5OoonfX3o`00Oa;ooo]Z000GoookJP?o001o1ol5o`1aoookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
07l3oookJQooo`00D_oonfX5o`0001_ooo]Z4ol5o`0UoookJQcoo`002?oonfX3o`00O`?ooo]Z0ol0
07l7oookJPOo001oG_oonfX8o`Go01Gooo]Z0ol007lBoookJP005ooonfX3o`00O`Oo1Ol0LOoonfX3
o`00O`?ooo]Z0ol007l7oookJPKo001o7Ooo001HoookJPGo00006?oonfXCo`Go02gooo]Z6ooo0004
oookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007mPoookJPSo1Ol05?oonfX3o`00Oa;ooo]Z000Doook
JPKo001o00?ooo]Zo`Go0?l5o`001?l5o`1aoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007lLool0
05gooo]Z1Ol0000EoookJQ?o1Ol0=OoonfXKool000;o001o0ooonfX3o`00O`Oooo]Z0_l007mUoook
JPSo1Ol04?oonfX6o`00Oa;ooo]Z000DoookJPKo001o00?ooo]Zo`Go0?l5o`001Ol5o`1aoookJP?o
001o00Cooo]Zo`00Ool007oo001o1_oonfXJool006?ooo]Z1Ol0000BoookJQ?o1Ol0?OoonfXJool0
00?o001o2?oonfX2o`00OfKooo]Z2?l5o`0?oookJPKo001o4_oonfX001Kooo]Z1?l007l2oookJPKo
1Ol0LOoonfX7o`00O`;ooo]Z6Ooo001XoookJPGo00003ooonfXCo`Go04Cooo]Z6_oo0008oookJPOo
001oH?oonfX8o`Go017ooo]Z1?l007lBoookJP005ooonfX3o`00O`;ooo]Z1ol5o`1aoookJPCo001o
6?oo001]oookJPGo00003OoonfXBo`Go04cooo]Z6_oo0003oookJPOo001oHOoonfX8o`Go017ooo]Z
0ol007lBoookJP007?oonfX7o`Go077ooo]Z6?oo001aoookJPGo00002_oonfXBo`Go05?ooo]Z6_oo
001XoookJPSo1Ol09OoonfX001gooo]Z1_l5o`1]oookJQSoo`00MOoonfX5o`0000Oooo]Z4_l5o`1K
oookJQSoo`00I_oonfX7o`Go02Gooo]Z000MoookJPOo1Ol0JOoonfXGool007Wooo]Z1Ol00005oook
JQ7o1Ol0H_oonfXGool006?ooo]Z2?l5o`0ToookJP007_oonfX6o`Go06Gooo]Z5ooo001moookJPGo
00000_oonfXAo`Go06Wooo]Z5ooo001PoookJPOo1Ol09?oonfX001kooo]Z1_l5o`1QoookJQOoo`00
POoonfX4o`0001;o1Ol0L?oonfXEool005kooo]Z1ol5o`0SoookJP007_oonfX7o`Go05gooo]Z5_oo
0025oookJP;o00004Ol5o`1goookJQCoo`00FooonfX8o`Go02;ooo]Z0002oookJQgo00001_l5o`1J
o`0001Goo`00R?l0000Ao`Go07go00005?oo001Io`0000Oo1Ol07ol00003oookJP000_oonfXMo`00
00Oo1Ol0E_l0000Eool008So00004_l5o`22o`0001Goo`00EOl00008o`Go01ko00000ooonfX000;o
oo]Z7Ol00008o`Go05;o00005?oo0029o`0001;o1Ol0ROl0000Dool005?o00001ol5o`0No`0000?o
oo]Z0002oookJQko00001ol5o`1?o`0001?oo`00Rol0000Ao`Go08oo00005?oo001Ao`0000Oo1Ol0
7Ol00003oookJP000_oonfXNo`0000So1Ol0Bol0000Cool008_o00004_l5o`2Do`0001Coo`00C_l0
0007o`Go01go00000ooonfX001;ooo]Z00?o0000oookJ_oonfX03?oonfX8o`Go04Oooo]Z4ooo000E
oookJP03o`000?oonf[ooo]Z07?ooo]Z4_l5o`02o`0008Cooo]Z00?o0000oookJ_oonfX04OoonfXD
ool004cooo]Z1ol5o`0;oookJP03o`000?oonf[ooo]Z017ooo]Z000RoookJPOo1Ol0A?oonfXCool0
08_ooo]Z4_l5o`05o`0009cooo]Z4ooo0019oookJPOo1Ol07ooonfX002;ooo]Z2?l5o`10oookJQ?o
o`00S?oonfXAo`Go00?ooo]Z1Ol0002OoookJQ?oo`00AooonfX7o`Go01kooo]Z000SoookJPSo1Ol0
?OoonfXBool008cooo]Z4_l5o`05oookJPGo0000X_oonfXCool004Cooo]Z1ol5o`0NoookJP009?oo
nfX7o`Go03[ooo]Z4_oo002<oookJQ;o1Ol02?oonfX5o`000:Gooo]Z4ooo0012oookJPOo1Ol07Ooo
nfX002Cooo]Z2?l5o`0foookJQ;oo`00S?oonfXBo`Go00_ooo]Z1Ol0002XoookJQ;oo`00@?oonfX7
o`Go01gooo]Z000UoookJPSo1Ol0<ooonfXAool008cooo]Z4_l5o`0>oookJPGo0000ZooonfXBool0
03kooo]Z1_l5o`0MoookJP009_oonfX8o`Go02oooo]Z4Ooo002<oookJQ?o1Ol04?oonfX5o`000:ko
oo]Z4Ooo000loookJPOo1Ol07?oonfX002Kooo]Z2Ol5o`0/oookJQ7oo`00RooonfXCo`Go01?ooo]Z
1Ol0002aoookJQ3oo`00>ooonfX6o`Go01cooo]Z000WoookJPWo1Ol0:?oonfXAool008_ooo]Z4ol5
o`0FoookJPGo0000]?oonfX@ool003Sooo]Z1_l5o`0LoookJP00:?oonfX9o`Go02Cooo]Z4Ooo002;
oookJQ?o1Ol06OoonfX5o`000;Kooo]Z4?oo000foookJPOo1Ol06ooonfX002Wooo]Z2Ol5o`0Qoook
JQ7oo`00R_oonfXCo`Go01cooo]Z1Ol0002ioookJQ3oo`00=?oonfX6o`Go01_ooo]Z000ZoookJPWo
1Ol07_oonfX@ool008[ooo]Z4ol5o`0OoookJPGo0000^ooonfX@ool003;ooo]Z1_l5o`0KoookJP00
:ooonfX9o`Go01[ooo]Z4Ooo0029oookJQ?o1Ol08_oonfX5o`000;gooo]Z4Ooo000_oookJPOo1Ol0
6_oonfX002cooo]Z2Ol5o`0GoookJQ3oo`00ROoonfXCo`Go02Gooo]Z1Ol00030oookJQ3oo`00;_oo
nfX6o`Go01[ooo]Z000]oookJP[o1Ol04ooonfX?ool008Wooo]Z4ol5o`0XoookJPGo0000`_oonfXA
ool002_ooo]Z1_l5o`0JoookJP00;_oonfX:o`Go013ooo]Z3ooo0028oookJQ?o1Ol0:ooonfX5o`00
0<Gooo]Z4Ooo000XoookJPOo1Ol06OoonfX002oooo]Z2_l5o`0=oookJPooo`00Q_oonfXDo`Go02ko
oo]Z1Ol00037oookJQ7oo`009ooonfX6o`Go01Wooo]Z000`oookJP[o1Ol02OoonfX?ool008Kooo]Z
5?l5o`0aoookJPGo0000b_oonfXAool002Cooo]Z1_l5o`0IoookJP00<OoonfX:o`Go00Kooo]Z3ooo
0025oookJQCo1Ol0=?oonfX5o`000<cooo]Z4Ooo000RoookJPOo1Ol06?oonfX003?ooo]Z2_l5o`02
oookJPooo`00Q?oonfXDo`Go03Oooo]Z1Ol0003?oookJQ7oo`008?oonfX6o`Go01Sooo]Z000doook
JP_o1Ol03Ooo0023oookJQCo1Ol0>_oonfX5o`000=;ooo]Z4?oo000NoookJPKo1Ol06?oonfX003Go
oo]Z2ol5o`0:ool008;ooo]Z4ol5o`0noookJPGo0000e?oonfX@ool001cooo]Z1_l5o`0HoookJP00
=_oonfX<o`Go00Goo`00P_oonfXCo`Go047ooo]Z1Ol0003GoookJPooo`006ooonfX5o`Go01Sooo]Z
000foookJP03ool00?l5o`3o1Ol000_o1Ol000?oo`00oookJ_oonfX0O_oonfXDo`Go04Cooo]Z1Ol0
003IoookJPooo`006OoonfX6o`Go01Oooo]Z000doookJPGoo`003Ol5o`1koookJQGo1Ol0AooonfX5
o`000=cooo]Z3_oo000GoookJPKo1Ol05ooonfX003;ooo]Z2Ooo000<o`Go07Kooo]Z5_l5o`1:oook
JPGo0000g_oonfX>ool001Gooo]Z1_l5o`0GoookJP00<?oonfX<ool000go1Ol0LOoonfXFo`Go04go
oo]Z1Ol0003PoookJPkoo`004ooonfX6o`Go01Oooo]Z000^oookJPooo`0000?ooo]Zo`Go0?l5o`00
2ol5o`1[oookJQOo1Ol0D?oonfX5o`000>;ooo]Z3_oo000BoookJPGo1Ol05ooonfX002_ooo]Z3ooo
0006oookJPgo1Ol0IOoonfXGo`Go05Cooo]Z1Ol0003ToookJPkoo`004?oonfX5o`Go01Oooo]Z000Y
oookJPooo`002_oonfX>o`Go05gooo]Z6?l5o`1HoookJPGo0000i_oonfX>ool000kooo]Z1_l5o`0F
oookJP009ooonfX?ool000gooo]Z4?l5o`1DoookJQ[o1Ol0G?oonfX5o`000>Sooo]Z3_oo000<oook
JPKo1Ol05_oonfX002Gooo]Z3ooo000AoookJQ7o1Ol0BooonfXMo`Go05oooo]Z1Ol0003ZoookJPko
o`002_oonfX6o`Go01Kooo]Z000SoookJPooo`005OoonfXDo`Go047ooo]Z7_l5o`1SoookJPGo0000
k?oonfX>ool000Sooo]Z1_l5o`0FoookJP008OoonfX>ool001[ooo]Z6?l5o`0eoookJR3o1Ol0Iooo
nfX5o`000>kooo]Z3_oo0007oookJPGo1Ol05_oonfX001oooo]Z3_oo000OoookJQWo1Ol0:ooonfXQ
o`Go06cooo]Z1Ol0003`oookJPkoo`001OoonfX6o`Go01Gooo]Z000MoookJPkoo`009?oonfXOo`Go
01Oooo]Z9_l5o`1boookJPGo0000l_oonfX>ool000?ooo]Z1_l5o`0EoookJP006ooonfX>ool002Wo
oo]ZDol5o`1hoookJPGo0000m?oonfX>ool00003oookJ_l5o`3o1Ol000Co1Ol05OoonfX001Wooo]Z
3_oo000`oookJTWo1Ol0OOoonfX5o`000?Kooo]Z3Ooo0006o`Go01Gooo]Z000GoookJPkoo`00>?oo
nfXmo`Go08?ooo]Z1Ol0003hoookJPcoo`001_l5o`0DoookJP005OoonfX>ool003kooo]Z<ol5o`29
oookJPGo0000n_oonfX:ool000Ko1Ol05?oonfX001?ooo]Z3_oo0019oookJQoo1Ol0QooonfX3o`00
O`[ooo]Z1Ol0003loookJPSoo`001_l5o`0DoookJP004OoonfX>ool00?7ooo]Z0ol007l:oookJPGo
0000o_oonfX6ool000Ko1Ol00_oo000BoookJP004?oonfX=ool00??ooo]Z0ol007l:oookJPGo0000
oooonfX1oookJPGoo`001Ol5o`03ool0017ooo]Z000@oookJP_oo`00mOoonfX3o`00O`[ooo]Z1Ol0
003ooookJP?ooo]Z0ooo0005o`Go00?oo`004OoonfX0013ooo]Z2Ooo003goookJP?o001o2_oonfX7
o`000?oooo]Z0ooonfX00ooo003o1Ol0o`Go0003o`Go00?oo`004OoonfX0013ooo]Z1ooo003ioook
JP?o001o2_oonfX5o`000?oooo]Z1_oonfX5o`Go00?oo`004OoonfX0013ooo]Z1Ooo003koookJP?o
001o2_oonfX5o`000?oooo]Z1_oonfX5o`Go00?oo`004OoonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJPKooo]Z1Ol5o`0DoookJP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z1_oo
nfX6o`Go01?ooo]Z003ooookJPkooo]Z1_l007l:oookJPGo0000oooonfX6oookJPKo1Ol04ooonfX0
0?oooo]Z3_oonfX6o`00O`[ooo]Z1Ol0003ooookJPKooo]Z1_l5o`0CoookJP00oooonfX@oookJPCo
001o2_oonfX5o`000?oooo]Z1_oonfX6o`Go01?ooo]Z003ooookJQ7ooo]Z0ol007l:oookJPGo0000
oooonfX7oookJPGo1Ol04ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z1ooonfX5o`Go01?ooo]Z003o
oookJQkooo]Z1Ol0003ooookJPOooo]Z1Ol5o`0CoookJP00oooonfXNoookJPGo0000oooonfX7oook
JPGo1Ol04ooonfX00?oooo]Z7_oonfX5o`000?oooo]Z1ooonfX5o`Go01?ooo]Z003ooookJQkooo]Z
1Ol0003ooookJPOooo]Z1Ol5o`0CoookJP00oooonfXNoookJPGo0000oooonfX7oookJPGo1Ol04ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z1ooonfX5o`Go01?ooo]Z003ooookJQkooo]Z1Ol0003ooook
JPOooo]Z1Ol5o`0CoookJP00oooonfXNoookJPGo0000oooonfX7oookJPGo1Ol04ooonfX00?oooo]Z
7_oonfX5o`000?oooo]Z1ooonfX5o`Go01?ooo]Z003ooookJQkooo]Z1Ol0003ooookJPOooo]Z1Ol5
o`0CoookJP00oooonfXNoookJPGo0000oooonfX7oookJPGo1Ol04ooonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z1ooonfX6o`Go01;ooo]Z003ooookJQkooo]Z1Ol0003ooookJPOooo]Z1_l5o`0BoookJP00
oooonfXNoookJPGo0000oooonfX7oookJPKo1Ol04_oonfX00?oooo]Z7_oonfX5o`000?oooo]Z1ooo
nfX6o`Go01;ooo]Z003ooookJQkooo]Z1Ol0003ooookJPSooo]Z1Ol5o`0BoookJP00oooonfXNoook
JPGo0000oooonfX8oookJPGo1Ol04_oonfX00?oooo]Z7_oonfX5o`000?oooo]Z2?oonfX5o`Go01;o
oo]Z003ooookJQkooo]Z1Ol0003ooookJPSooo]Z1Ol5o`0BoookJP00oooonfXNoookJPGo0000oooo
nfX8oookJPGo1Ol04_oonfX00?oooo]Z7_oonfX5o`000?oooo]Z2?oonfX5o`Go01;ooo]Z003ooook
JQkooo]Z1Ol0003ooookJPSooo]Z1Ol5o`0BoookJP00oooonfXNoookJPGo0000oooonfX8oookJPGo
1Ol04_oonfX00?oooo]Z7_oonfX5o`000?oooo]Z2?oonfX5o`Go01;ooo]Z003ooookJQkooo]Z1Ol0
003ooookJPSooo]Z1Ol5o`0BoookJP00oooonfXNoookJPGo0000oooonfX8oookJPKo1Ol04OoonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z2?oonfX6o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPSo
oo]Z1_l5o`0AoookJP00oooonfXNoookJPGo0000oooonfX8oookJPKo1Ol04OoonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0A
oookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooo
nfX=oookJPWo001o2?oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJPgooo]Z2Ol007l8
oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z3OoonfX4o`00O`gooo]Z1Ol0003ooook
JPWooo]Z1Ol5o`0AoookJP00oooonfX>oookJPCo001o3?oonfX5o`000?oooo]Z2OoonfX5o`Go017o
oo]Z003ooookJPoooo]Z1Ol007l:oookJPOo0000oooonfX7oookJPGo1Ol04OoonfX00?oooo]Z4Ooo
nfX4o`00O`Wooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXBoookJP?o001o2OoonfX5
o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQ?ooo]Z0ol007l8oookJPGo0000oooonfX9oook
JPGo1Ol04OoonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfX9oookJPGo
1Ol04OoonfX00?oooo]Z3OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfX9oookJPGo1Ol0
4OoonfX00?oooo]Z3OoonfX4o`00O`;ooo]Z0ol007l8oookJPGo0000oooonfX9oookJPGo1Ol04Ooo
nfX00?oooo]Z3_oonfX7o`00O`Wooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfX?oook
JPGo001o2_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWo
oo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oo
nfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0A
oookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oo
oo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooo
nfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5
o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo
0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z
003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfX9
oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQko
oo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol0
4OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003o
oookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oo
oo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z
1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5
o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0Aoook
JP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z
2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXN
oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go
017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000
oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003o
oookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oook
JPGo1Ol04OoonfX00?oooo]Z3ooonfX5o`00O`[ooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00
oooonfX>oookJPOo001o2OoonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJPgooo]Z0ol0
07l3oookJP?o001o2?oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJPgooo]Z0ol007l3
oookJP?o001o2?oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQ?ooo]Z0ol007l8oook
JPOo0000oooonfX7oookJPGo1Ol04OoonfX00?oooo]Z4ooonfX3o`00O`Sooo]Z1Ol0003ooookJPWo
oo]Z1Ol5o`0AoookJP00oooonfXAoookJPCo001o2OoonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z
003ooookJQ7ooo]Z0ol007l:oookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z4ooonfX2
o`00O`Wooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfX=oookJP?o001o0ooonfX3o`00
O`Sooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfX=oookJP?o001o0ooonfX3o`00O`So
oo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfX>oookJPOo001o2OoonfX5o`000?oooo]Z
2OoonfX5o`Go017ooo]Z003ooookJPoooo]Z1Ol007l:oookJPGo0000oooonfX9oookJPGo1Ol04Ooo
nfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooook
JPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z
7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5
o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`00
0?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00
oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2Ooo
nfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoook
JPGo0000oooonfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017o
oo]Z003ooookJQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooo
nfX9oookJPGo1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooook
JQkooo]Z1Ol0003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo
1Ol04OoonfX00?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0
003ooookJPWooo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfX9oookJPGo1Ol04OoonfX0
0?oooo]Z7_oonfX5o`000?oooo]Z2OoonfX5o`Go017ooo]Z003ooookJQkooo]Z1Ol0003ooookJPWo
oo]Z1Ol5o`0AoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.06829, -3.68436, \
0.00371579, 0.0207734}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Evaluate[Table[LegendreP[i, x], {i, 0, 10}]], {x, \(-1\), 1}, \ 
      PlotStyle \[Rule] MyPlotStyle[11]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.294302 [
[.02381 .29652 -13.4688 -20 ]
[.02381 .29652 13.4688 0 ]
[.2619 .29652 -20.9688 -20 ]
[.2619 .29652 20.9688 0 ]
[.7381 .29652 -14.5 -20 ]
[.7381 .29652 14.5 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.4875 .01472 -26.9375 -10 ]
[.4875 .01472 0 10 ]
[.4875 .16187 -41.9375 -10 ]
[.4875 .16187 0 10 ]
[.4875 .45617 -29 -10 ]
[.4875 .45617 0 10 ]
[.4875 .60332 -14 -10 ]
[.4875 .60332 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
gsave
.02381 .29652 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.5 .01472 m
.50625 .01472 L
s
gsave
.4875 .01472 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .16187 m
.50625 .16187 L
s
gsave
.4875 .16187 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .45617 m
.50625 .45617 L
s
gsave
.4875 .45617 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .60332 m
.50625 .60332 L
s
gsave
.4875 .60332 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02381 .60332 m
.06244 .60332 L
.10458 .60332 L
.14415 .60332 L
.18221 .60332 L
.22272 .60332 L
.26171 .60332 L
.30316 .60332 L
.34309 .60332 L
.3815 .60332 L
.42237 .60332 L
.46172 .60332 L
.49955 .60332 L
.53984 .60332 L
.57861 .60332 L
.61984 .60332 L
.65954 .60332 L
.69774 .60332 L
.73838 .60332 L
.77751 .60332 L
.81909 .60332 L
.85916 .60332 L
.89771 .60332 L
.93871 .60332 L
.97619 .60332 L
s
1 .36 0 r
.02381 .01472 m
.06244 .03859 L
.10458 .06463 L
.14415 .08909 L
.18221 .11261 L
.22272 .13765 L
.26171 .16175 L
.30316 .18736 L
.34309 .21204 L
.3815 .23578 L
.42237 .26104 L
.46172 .28536 L
.49955 .30874 L
.53984 .33364 L
.57861 .3576 L
.61984 .38308 L
.65954 .40762 L
.69774 .43123 L
.73838 .45635 L
.77751 .48053 L
.81909 .50623 L
.85916 .53099 L
.89771 .55482 L
.93871 .58016 L
.97619 .60332 L
s
1 .72 0 r
.02381 .60332 m
.06244 .53459 L
.10458 .46626 L
.14415 .40839 L
.18221 .35848 L
.22272 .31155 L
.26171 .27241 L
.30316 .2373 L
.34309 .2098 L
.3815 .1892 L
.40095 .18097 L
.42237 .1736 L
.44268 .16826 L
.45178 .16639 L
.46172 .16472 L
.4671 .16397 L
.4721 .16338 L
.47727 .16287 L
.48196 .1625 L
.48658 .16222 L
.4887 .16211 L
.49093 .16203 L
.49332 .16195 L
.49438 .16193 L
.49552 .16191 L
.49675 .16189 L
.49789 .16187 L
.49859 .16187 L
.49925 .16187 L
.50049 .16187 L
.50163 .16187 L
.50286 .16188 L
.50401 .1619 L
.50508 .16192 L
.50754 .16198 L
.51014 .16207 L
.51268 .16218 L
.51504 .16231 L
.5204 .16268 L
.5293 .16354 L
.53882 .1648 L
.54906 .16655 L
.56016 .16891 L
.58032 .17442 L
.60019 .18141 L
.62123 .19048 L
.65912 .21116 L
.69946 .23932 L
.73829 .27241 L
.77956 .31402 L
Mistroke
.81932 .36038 L
.85757 .41078 L
.89827 .47066 L
.93745 .53441 L
.97619 .60332 L
Mfstroke
.92 1 0 r
.02381 .01472 m
.06244 .14385 L
.10458 .25431 L
.14415 .33187 L
.18221 .38494 L
.20178 .40476 L
.22272 .42081 L
.23293 .42681 L
.24402 .43203 L
.25449 .43579 L
.26416 .43827 L
.26882 .43915 L
.27139 .43954 L
.27383 .43986 L
.27609 .4401 L
.27856 .44032 L
.27965 .44039 L
.2808 .44046 L
.28182 .44051 L
.28289 .44056 L
.28355 .44058 L
.28428 .4406 L
.28556 .44062 L
.28629 .44063 L
.28706 .44063 L
.28779 .44063 L
.28846 .44062 L
.28975 .4406 L
.29048 .44058 L
.29115 .44056 L
.29247 .44051 L
.29371 .44044 L
.29597 .44029 L
.29846 .44008 L
.30351 .43948 L
.30821 .43875 L
.31334 .43774 L
.3237 .43512 L
.3422 .42853 L
.36181 .41914 L
.38276 .40672 L
.42426 .37627 L
.46424 .34186 L
.50271 .30651 L
.54363 .26914 L
.58303 .23594 L
.62092 .20897 L
.642 .19689 L
.66126 .1881 L
.67079 .18463 L
Mistroke
.68117 .18158 L
.68592 .18045 L
.69098 .17943 L
.69541 .1787 L
.70008 .17811 L
.70264 .17786 L
.704 .17775 L
.70545 .17764 L
.70679 .17757 L
.70801 .17751 L
.70923 .17746 L
.71039 .17743 L
.71103 .17742 L
.71174 .17741 L
.71248 .1774 L
.71317 .1774 L
.7144 .17741 L
.7151 .17742 L
.71573 .17743 L
.71708 .17748 L
.71856 .17754 L
.7201 .17763 L
.72153 .17773 L
.72417 .17796 L
.72665 .17823 L
.7313 .17891 L
.7363 .17986 L
.74171 .18116 L
.7512 .18415 L
.76163 .1885 L
.78269 .20088 L
.80217 .21689 L
.82308 .23929 L
.86441 .30092 L
.90422 .38432 L
.94252 .48923 L
.97619 .60332 L
Mfstroke
.56 1 0 r
.02381 .60332 m
.04262 .4971 L
.06244 .40543 L
.08255 .33166 L
.10458 .27057 L
.12415 .23154 L
.13511 .21527 L
.14509 .20363 L
.15504 .1948 L
.16424 .18895 L
.16904 .18671 L
.17432 .18486 L
.17698 .18417 L
.17985 .1836 L
.18123 .18338 L
.18255 .18321 L
.18373 .18309 L
.18502 .18299 L
.18566 .18295 L
.18635 .18292 L
.18757 .18289 L
.18889 .18289 L
.18963 .18291 L
.19033 .18293 L
.19159 .18299 L
.19275 .18308 L
.19408 .18321 L
.19534 .18336 L
.19766 .18372 L
.19982 .18414 L
.20469 .18538 L
.20953 .18699 L
.21486 .1892 L
.22566 .19492 L
.24501 .20879 L
.26587 .22783 L
.30701 .27284 L
.34663 .31875 L
.38474 .35914 L
.40599 .37832 L
.4253 .393 L
.44538 .40509 L
.45441 .40937 L
.46435 .41323 L
.47407 .41612 L
.47938 .41732 L
.48436 .41819 L
.48674 .41853 L
.48901 .41879 L
.49106 .41899 L
Mistroke
.49326 .41916 L
.4945 .41923 L
.49563 .41929 L
.49676 .41933 L
.49783 .41936 L
.49908 .41938 L
.50022 .41938 L
.50148 .41937 L
.50212 .41936 L
.50281 .41934 L
.50412 .4193 L
.50533 .41924 L
.50807 .41906 L
.51048 .41885 L
.51304 .41855 L
.51747 .4179 L
.52236 .41695 L
.53316 .41406 L
.54329 .41035 L
.56351 .40016 L
.58203 .38777 L
.6217 .35278 L
.65986 .31135 L
.70048 .26422 L
.73958 .22252 L
.75953 .20517 L
.77003 .19764 L
.78113 .19114 L
.79106 .18678 L
.7967 .18499 L
.7994 .18431 L
.80197 .18379 L
.80429 .18342 L
.80551 .18326 L
.80681 .18312 L
.8079 .18303 L
.8091 .18295 L
.8102 .18291 L
.81123 .18289 L
.81244 .18289 L
.81372 .18293 L
.81481 .18298 L
.816 .18307 L
.81729 .18319 L
.81867 .18337 L
.82116 .18378 L
.82374 .18434 L
.82648 .1851 L
.83139 .18689 L
.83667 .18943 L
Mistroke
.84248 .19302 L
.85288 .20161 L
.86263 .21237 L
.87302 .22697 L
.88289 .24405 L
.90142 .28531 L
.92124 .34419 L
.93963 .41411 L
.97619 .60332 L
Mfstroke
.2 1 0 r
.02381 .01472 m
.04262 .16621 L
.06244 .28168 L
.07286 .32672 L
.08255 .36023 L
.0932 .38858 L
.09912 .40089 L
.10458 .41024 L
.10944 .41704 L
.1148 .42297 L
.12018 .42741 L
.12313 .42922 L
.12589 .43054 L
.12713 .43103 L
.12848 .43147 L
.12968 .4318 L
.13095 .43208 L
.13221 .43229 L
.13336 .43243 L
.13451 .43251 L
.13559 .43253 L
.13686 .43251 L
.1375 .43247 L
.1382 .43241 L
.13944 .43226 L
.1406 .43207 L
.14322 .43146 L
.14603 .43054 L
.15131 .4281 L
.1562 .42509 L
.16727 .41592 L
.18739 .39274 L
.22665 .33489 L
.2644 .27916 L
.28538 .25297 L
.30461 .23354 L
.32345 .21943 L
.33293 .21431 L
.33826 .21202 L
.34329 .21025 L
.34822 .20889 L
.35082 .20833 L
.35357 .20784 L
.35588 .20751 L
.35711 .20737 L
.35843 .20725 L
.35963 .20716 L
.36074 .20709 L
.36185 .20704 L
.3629 .20702 L
Mistroke
.36423 .207 L
.36542 .20702 L
.36609 .20703 L
.36681 .20705 L
.36811 .20712 L
.36933 .2072 L
.37062 .20731 L
.37293 .20756 L
.37563 .20796 L
.37814 .20842 L
.38385 .20979 L
.38888 .21137 L
.39433 .21346 L
.40425 .21823 L
.42282 .23028 L
.44263 .24698 L
.46365 .26803 L
.50145 .3107 L
.54171 .35563 L
.56022 .37367 L
.58045 .39014 L
.59016 .39658 L
.60053 .40225 L
.60626 .40482 L
.61147 .40679 L
.61641 .40832 L
.62164 .40957 L
.62394 .41 L
.62641 .41038 L
.62782 .41056 L
.62912 .4107 L
.63043 .41082 L
.63165 .4109 L
.63275 .41096 L
.63391 .411 L
.63508 .41103 L
.63638 .41103 L
.63749 .41101 L
.63869 .41097 L
.63982 .41091 L
.64086 .41084 L
.64337 .41061 L
.6457 .41031 L
.64826 .40988 L
.651 .40932 L
.65659 .40782 L
.66167 .40604 L
.67164 .40143 L
.68084 .39585 L
.70162 .37873 L
Mistroke
.72036 .35836 L
.74099 .33143 L
.7813 .27086 L
.79985 .24298 L
.82009 .21587 L
.83106 .20375 L
.8364 .19874 L
.84124 .19478 L
.84592 .19155 L
.85097 .18877 L
.85375 .18758 L
.85631 .18671 L
.85876 .18609 L
.85999 .18586 L
.86064 .18576 L
.86134 .18567 L
.86264 .18555 L
.86385 .1855 L
.86515 .18551 L
.86589 .18555 L
.86659 .1856 L
.86783 .18575 L
.86898 .18594 L
.87023 .18621 L
.87155 .18657 L
.87386 .18738 L
.876 .18836 L
.88086 .19137 L
.88616 .19601 L
.89098 .20153 L
.89623 .20906 L
.90178 .21886 L
.91177 .24166 L
.92098 .26913 L
.93089 .30639 L
.94178 .35756 L
.95838 .45873 L
.97619 .60332 L
Mfstroke
0 1 .16 r
.02381 .60332 m
.03279 .49739 L
.04262 .40375 L
.05288 .3279 L
.06244 .27471 L
.06792 .25093 L
.0731 .23248 L
.07781 .21883 L
.0828 .20734 L
.08539 .20251 L
.08823 .19803 L
.09085 .19463 L
.09324 .19211 L
.09606 .18982 L
.09762 .18885 L
.0991 .18813 L
.10046 .18762 L
.10172 .18728 L
.10244 .18714 L
.1031 .18704 L
.10386 .18698 L
.10458 .18696 L
.10574 .187 L
.10699 .18715 L
.10816 .18739 L
.10923 .18769 L
.11049 .18814 L
.11186 .18874 L
.11434 .19013 L
.1197 .1943 L
.12466 .19945 L
.13361 .21136 L
.14313 .22686 L
.18088 .30068 L
.20185 .33974 L
.22108 .36926 L
.23085 .38125 L
.23993 .39039 L
.24941 .39779 L
.25442 .4008 L
.25977 .40333 L
.26236 .40431 L
.2651 .40516 L
.26744 .40574 L
.27001 .40623 L
.27146 .40643 L
.27278 .40657 L
.27351 .40663 L
.2743 .40669 L
.27505 .40672 L
Mistroke
.27575 .40675 L
.27645 .40676 L
.27711 .40675 L
.27835 .40673 L
.27904 .40669 L
.27968 .40666 L
.28112 .40654 L
.28229 .4064 L
.28354 .40623 L
.2858 .40582 L
.28848 .40519 L
.29092 .40448 L
.29624 .40251 L
.30127 .40012 L
.31095 .39416 L
.32122 .38606 L
.33965 .36774 L
.37745 .32078 L
.41771 .26967 L
.43622 .24985 L
.44671 .24034 L
.45645 .2328 L
.46698 .2262 L
.47653 .22171 L
.48179 .21986 L
.48674 .21854 L
.48947 .21799 L
.49198 .2176 L
.4934 .21742 L
.49473 .21728 L
.49612 .21718 L
.49685 .21713 L
.49764 .2171 L
.49886 .21706 L
.49955 .21705 L
.5002 .21705 L
.5015 .21707 L
.50224 .21709 L
.50291 .21712 L
.50405 .21719 L
.50529 .21729 L
.5078 .21757 L
.51057 .218 L
.51352 .2186 L
.51886 .22006 L
.52427 .22203 L
.52939 .22432 L
.53897 .22972 L
.55896 .24531 L
.5774 .26411 L
Mistroke
.61677 .31316 L
.65463 .36126 L
.67568 .3833 L
.68567 .39168 L
.69494 .39799 L
.70445 .4028 L
.70948 .40461 L
.71228 .40539 L
.71483 .40594 L
.71601 .40615 L
.71727 .40634 L
.71835 .40648 L
.71951 .40659 L
.72075 .40668 L
.72192 .40674 L
.72263 .40675 L
.7233 .40676 L
.72456 .40674 L
.72567 .40669 L
.72684 .40661 L
.72785 .40651 L
.72895 .40638 L
.73142 .40597 L
.73373 .40546 L
.73843 .40403 L
.74357 .40184 L
.74894 .39885 L
.75393 .39544 L
.77244 .37746 L
.78297 .36366 L
.79291 .34848 L
.8115 .31548 L
.84999 .23938 L
.86027 .22105 L
.86988 .20636 L
.87512 .19971 L
.8799 .19467 L
.88522 .19041 L
.88662 .18955 L
.88815 .18874 L
.8896 .18811 L
.89093 .18764 L
.89218 .18731 L
.89349 .18708 L
.89481 .18697 L
.89556 .18696 L
.89626 .18699 L
.89753 .18713 L
.89869 .18737 L
.89933 .18755 L
Mistroke
.90002 .18778 L
.90128 .1883 L
.90365 .18962 L
.90615 .19156 L
.91065 .1965 L
.91314 .20008 L
.91581 .20466 L
.92064 .21495 L
.92639 .23086 L
.93164 .24925 L
.94148 .29467 L
.95062 .35145 L
.96065 .43243 L
.97134 .54351 L
.97619 .60332 L
Mfstroke
0 1 .52 r
.02381 .01472 m
.03279 .15129 L
.04262 .26243 L
.04758 .30538 L
.05288 .34282 L
.05785 .37074 L
.06244 .39098 L
.06788 .40884 L
.07075 .41583 L
.07379 .4216 L
.07642 .42532 L
.07889 .4278 L
.0803 .42881 L
.08159 .42948 L
.08231 .42976 L
.08309 .42998 L
.08382 .43011 L
.08451 .43017 L
.08577 .43013 L
.08648 .43003 L
.08713 .42988 L
.08833 .42947 L
.0896 .42886 L
.0918 .4274 L
.09422 .42525 L
.09958 .41862 L
.10458 .41049 L
.12493 .36502 L
.14349 .31749 L
.16419 .26978 L
.17329 .25263 L
.18333 .23713 L
.18795 .23131 L
.19292 .22596 L
.19722 .22213 L
.20192 .21878 L
.20694 .21616 L
.20967 .21514 L
.21098 .21476 L
.21222 .21446 L
.21337 .21422 L
.21461 .21403 L
.21574 .2139 L
.21679 .21383 L
.21791 .21379 L
.21915 .21381 L
.22045 .21388 L
.22166 .214 L
.22291 .21418 L
.22425 .21443 L
Mistroke
.22664 .21504 L
.22949 .21601 L
.23207 .21712 L
.23716 .21991 L
.24195 .22324 L
.25086 .23108 L
.26049 .24163 L
.30154 .30094 L
.322 .33203 L
.34108 .35764 L
.35945 .37706 L
.36974 .38514 L
.37911 .39056 L
.38393 .39259 L
.38657 .39349 L
.38905 .39419 L
.39133 .39471 L
.39341 .39508 L
.39452 .39524 L
.39573 .39538 L
.39695 .39549 L
.39823 .39557 L
.3989 .3956 L
.39964 .39561 L
.40033 .39562 L
.40096 .39561 L
.40217 .39558 L
.40344 .39551 L
.4041 .39546 L
.40481 .39539 L
.40609 .39525 L
.409 .39478 L
.41168 .39419 L
.41423 .39348 L
.419 .39179 L
.42864 .38694 L
.43889 .37983 L
.4573 .36264 L
.49502 .31574 L
.51597 .28765 L
.53519 .26375 L
.54486 .25311 L
.55521 .24314 L
.56479 .23543 L
.57385 .22966 L
.57859 .22728 L
.58374 .22521 L
.58602 .22447 L
.58843 .22382 L
.59068 .22331 L
Mistroke
.59275 .22295 L
.59392 .22278 L
.5952 .22264 L
.5959 .22257 L
.59655 .22252 L
.59783 .22245 L
.59904 .22242 L
.60014 .22242 L
.6014 .22245 L
.60259 .22251 L
.60391 .22262 L
.60531 .22277 L
.6078 .22316 L
.61049 .22373 L
.61344 .22455 L
.61868 .22648 L
.62365 .22887 L
.63296 .2348 L
.64298 .24319 L
.65388 .25449 L
.69468 .31122 L
.71495 .34257 L
.73397 .3695 L
.74283 .38026 L
.75215 .38983 L
.75703 .394 L
.76237 .39783 L
.76723 .40058 L
.77174 .40248 L
.77437 .40328 L
.7768 .4038 L
.77806 .404 L
.77878 .40408 L
.77946 .40415 L
.78017 .4042 L
.78082 .40423 L
.78156 .40424 L
.78227 .40424 L
.78347 .40419 L
.78474 .40408 L
.78594 .40392 L
.78703 .40374 L
.7897 .40308 L
.79221 .40222 L
.79687 .39997 L
.80115 .39716 L
.81081 .38816 L
.82058 .37532 L
.82968 .36012 L
.85037 .31571 L
Mistroke
.86905 .26838 L
.88935 .21943 L
.89472 .20881 L
.90042 .19941 L
.90528 .1933 L
.90805 .19075 L
.90939 .18978 L
.91064 .18904 L
.91188 .18848 L
.91254 .18825 L
.91324 .18807 L
.91453 .18787 L
.91571 .18787 L
.91685 .18804 L
.91809 .18842 L
.91926 .18897 L
.92034 .18965 L
.92276 .19179 L
.92413 .1934 L
.92542 .19519 L
.9282 .20002 L
.93078 .20573 L
.93578 .22053 L
.94122 .24283 L
.94602 .26849 L
.95112 .30269 L
.95994 .38102 L
.96968 .5006 L
.97619 .60332 L
Mfstroke
0 1 .88 r
.02381 .60332 m
.02846 .50845 L
.03279 .43435 L
.03793 .36224 L
.04262 .31002 L
.04754 .26721 L
.0522 .23673 L
.05711 .2137 L
.05988 .20435 L
.06244 .19782 L
.06487 .19334 L
.06623 .19149 L
.06747 .1902 L
.06862 .18934 L
.06988 .18873 L
.07107 .18847 L
.07218 .18848 L
.07285 .18861 L
.07358 .18885 L
.0749 .18953 L
.07618 .19048 L
.07737 .1916 L
.08006 .19494 L
.0829 .19957 L
.08824 .2108 L
.09323 .22362 L
.10458 .25783 L
.12322 .31683 L
.13305 .34432 L
.14349 .36846 L
.14873 .37828 L
.15452 .38721 L
.15979 .39355 L
.16473 .39796 L
.16719 .3996 L
.16978 .40094 L
.17199 .40177 L
.17325 .40212 L
.17441 .40236 L
.17506 .40246 L
.17577 .40255 L
.17706 .40262 L
.17831 .40261 L
.17946 .40253 L
.1807 .40236 L
.18141 .40222 L
.18208 .40207 L
.18342 .4017 L
.18485 .4012 L
.18743 .40004 L
Mistroke
.18983 .39868 L
.19526 .39461 L
.20514 .38414 L
.22367 .35638 L
.24369 .32021 L
.26531 .2816 L
.27548 .26561 L
.28622 .25115 L
.29627 .24029 L
.30543 .23292 L
.31031 .23002 L
.31493 .22796 L
.31746 .2271 L
.31981 .22649 L
.32113 .22622 L
.32238 .22602 L
.32367 .22586 L
.32436 .22579 L
.3251 .22574 L
.32626 .22569 L
.32734 .22568 L
.32851 .22571 L
.32977 .22579 L
.33041 .22585 L
.3311 .22592 L
.33235 .2261 L
.33468 .22655 L
.3369 .22713 L
.33925 .22789 L
.34345 .22966 L
.3484 .23235 L
.35291 .23537 L
.36306 .24396 L
.38139 .26471 L
.4212 .32155 L
.4394 .34663 L
.44976 .35918 L
.4595 .36936 L
.4698 .37809 L
.47925 .38405 L
.48417 .38631 L
.48935 .38805 L
.49205 .38868 L
.49455 .38911 L
.496 .38929 L
.49731 .3894 L
.49803 .38944 L
.49882 .38947 L
.49956 .38949 L
.50025 .38949 L
Mistroke
.5015 .38946 L
.50269 .3894 L
.50375 .38931 L
.50491 .38918 L
.50617 .389 L
.50751 .38877 L
.50993 .38823 L
.51468 .38675 L
.51899 .38492 L
.52962 .37852 L
.53962 .37019 L
.55971 .34777 L
.57819 .32243 L
.59863 .2924 L
.6177 .26588 L
.63604 .24483 L
.64632 .23593 L
.65078 .23286 L
.65569 .23008 L
.6605 .22798 L
.66314 .22712 L
.66561 .22648 L
.66674 .22626 L
.66792 .22606 L
.66894 .22592 L
.67003 .22581 L
.67121 .22572 L
.6723 .22569 L
.67361 .22569 L
.67479 .22573 L
.67609 .22583 L
.67674 .2259 L
.67746 .226 L
.67992 .22643 L
.6813 .22676 L
.68279 .22718 L
.68547 .22811 L
.69074 .23058 L
.69556 .23359 L
.70544 .24194 L
.71459 .25214 L
.73534 .28267 L
.77454 .35331 L
.78486 .37021 L
.79601 .38553 L
.80113 .39121 L
.80653 .39609 L
.81114 .39926 L
.81376 .40061 L
.81619 .40157 L
Mistroke
.81746 .40195 L
.81881 .40227 L
.81996 .40246 L
.82122 .40259 L
.82193 .40262 L
.82258 .40263 L
.82333 .40261 L
.82404 .40256 L
.8253 .40241 L
.82602 .40228 L
.82668 .40214 L
.82798 .40178 L
.8292 .40136 L
.83148 .40034 L
.83394 .39889 L
.8366 .39692 L
.8413 .39237 L
.84627 .3861 L
.85517 .37112 L
.86465 .35016 L
.8748 .32268 L
.89313 .26516 L
.9033 .2335 L
.90866 .21853 L
.91436 .20495 L
.91933 .19585 L
.92069 .19391 L
.92216 .19211 L
.92342 .19082 L
.92481 .18972 L
.92608 .18899 L
.92727 .18858 L
.92852 .18844 L
.92922 .1885 L
.92986 .18864 L
.931 .18912 L
.93224 .18995 L
.9334 .19107 L
.93448 .19239 L
.93692 .19649 L
.93915 .20166 L
.94173 .20947 L
.94417 .21887 L
.94851 .24077 L
.95324 .27322 L
.95842 .32058 L
.96394 .38663 L
.97387 .5539 L
.97619 .60332 L
Mfstroke
0 .76 1 r
.02381 .01472 m
.02846 .1307 L
.03279 .21694 L
.03754 .2906 L
.04262 .3486 L
.04518 .37076 L
.04795 .3901 L
.05058 .4043 L
.053 .41423 L
.05518 .42083 L
.05642 .42366 L
.05758 .42574 L
.05881 .42738 L
.05993 .4284 L
.06122 .42905 L
.06244 .42916 L
.0631 .42903 L
.06381 .42875 L
.0651 .42788 L
.06635 .42661 L
.0675 .4251 L
.07012 .42055 L
.07289 .41427 L
.08259 .38374 L
.10458 .29911 L
.11406 .26763 L
.11928 .25315 L
.12422 .24156 L
.12881 .23274 L
.13381 .22534 L
.13601 .2228 L
.13835 .22059 L
.14035 .21908 L
.14255 .21783 L
.14377 .21731 L
.1449 .21695 L
.14614 .21668 L
.14684 .21658 L
.14747 .21653 L
.14875 .21652 L
.14947 .21657 L
.15013 .21665 L
.15135 .2169 L
.15264 .21728 L
.15374 .21771 L
.15492 .21827 L
.15705 .21953 L
.1619 .22356 L
.16749 .23001 L
.1728 .23769 L
Mistroke
.18275 .25533 L
.221 .33616 L
.23116 .35458 L
.24071 .3689 L
.24601 .37537 L
.25172 .38109 L
.25692 .3851 L
.25942 .38662 L
.2617 .38777 L
.26412 .38875 L
.26641 .38944 L
.26767 .38973 L
.26883 .38993 L
.27011 .39009 L
.27075 .39014 L
.27146 .39018 L
.27264 .3902 L
.27372 .39016 L
.27491 .39007 L
.27616 .38991 L
.27725 .38972 L
.27826 .38949 L
.28056 .38884 L
.28326 .3878 L
.2858 .38657 L
.29056 .38362 L
.29569 .37955 L
.30124 .3742 L
.32115 .34841 L
.34221 .31462 L
.36205 .28267 L
.38015 .25792 L
.39015 .24728 L
.39963 .23966 L
.40483 .2366 L
.40964 .23449 L
.41215 .23367 L
.41492 .233 L
.41632 .23275 L
.41705 .23264 L
.41782 .23255 L
.4185 .23248 L
.41924 .23243 L
.42054 .23237 L
.42186 .23236 L
.42307 .23241 L
.4237 .23245 L
.4244 .23251 L
.42581 .23268 L
.42705 .23288 L
Mistroke
.42839 .23314 L
.4308 .23376 L
.4333 .23459 L
.43567 .23555 L
.44013 .23779 L
.45014 .24486 L
.46107 .25546 L
.48076 .28044 L
.50173 .31165 L
.52172 .34106 L
.53224 .35481 L
.54334 .36718 L
.55329 .3759 L
.55895 .3797 L
.56422 .38244 L
.56671 .38345 L
.56907 .38423 L
.57119 .3848 L
.57349 .38525 L
.57468 .38542 L
.57599 .38556 L
.57665 .38561 L
.57736 .38565 L
.57865 .38567 L
.57986 .38565 L
.58114 .38558 L
.58223 .38548 L
.58342 .38533 L
.58474 .3851 L
.58596 .38485 L
.58871 .38411 L
.59114 .38325 L
.59371 .38215 L
.60305 .37647 L
.60821 .37225 L
.61303 .36764 L
.624 .355 L
.66285 .29504 L
.68261 .26412 L
.69304 .25029 L
.69876 .24383 L
.70414 .23863 L
.70935 .23447 L
.71209 .23267 L
.71498 .23106 L
.71742 .22994 L
.72009 .22899 L
.72127 .22866 L
.72253 .22836 L
.72371 .22815 L
Mistroke
.72479 .228 L
.72598 .22789 L
.72724 .22784 L
.72832 .22785 L
.72951 .22791 L
.73078 .22805 L
.73149 .22816 L
.73215 .22827 L
.73463 .22888 L
.7369 .22967 L
.73939 .23079 L
.74392 .23351 L
.74923 .23781 L
.75424 .24294 L
.76359 .25518 L
.78456 .29305 L
.80293 .33277 L
.81336 .35495 L
.8231 .37351 L
.83271 .38829 L
.83811 .39448 L
.84049 .39666 L
.84303 .39855 L
.8443 .39934 L
.84572 .40008 L
.84701 .40063 L
.8482 .40102 L
.84889 .40119 L
.8496 .40134 L
.85032 .40144 L
.85111 .40151 L
.85179 .40153 L
.85252 .40151 L
.85384 .40136 L
.85453 .40122 L
.85516 .40106 L
.8566 .40058 L
.85787 .4 L
.85921 .39924 L
.86153 .39755 L
.86409 .39513 L
.8693 .38836 L
.87424 .37965 L
.88353 .35739 L
.89352 .32571 L
.90441 .28469 L
.91456 .24488 L
.92412 .21197 L
.92669 .20482 L
.92941 .19844 L
Mistroke
.93083 .19566 L
.93239 .19309 L
.93381 .19124 L
.93513 .18997 L
.93642 .18917 L
.93765 .18886 L
.93875 .18898 L
.93994 .18954 L
.94124 .19071 L
.9419 .19153 L
.94262 .19262 L
.94391 .19506 L
.9451 .19794 L
.94692 .20351 L
.94891 .21138 L
.95291 .23347 L
.95637 .26018 L
.96007 .29763 L
.96442 .35527 L
.96852 .42505 L
.97619 .60332 L
Mfstroke
0 .4 1 r
.02381 .60332 m
.02846 .46503 L
.03279 .36786 L
.03754 .2906 L
.0402 .25872 L
.04262 .23587 L
.04516 .2175 L
.0475 .20508 L
.04873 .20016 L
.05008 .19588 L
.05076 .19416 L
.05149 .19261 L
.05281 .19057 L
.05404 .18949 L
.05474 .18921 L
.05539 .18916 L
.05658 .18955 L
.05784 .19062 L
.05908 .19227 L
.06026 .19433 L
.06244 .19934 L
.06757 .21591 L
.07299 .23842 L
.08269 .28402 L
.09325 .33138 L
.09907 .35343 L
.10458 .37072 L
.1095 .38291 L
.11209 .38805 L
.11485 .39254 L
.11716 .39554 L
.11839 .39684 L
.11972 .39804 L
.12093 .39894 L
.12204 .3996 L
.1231 .40009 L
.12422 .40045 L
.12537 .40068 L
.12641 .40074 L
.12762 .40066 L
.12875 .40044 L
.12981 .4001 L
.13078 .39968 L
.13297 .39837 L
.13519 .39655 L
.13763 .39401 L
.14255 .3873 L
.15271 .36804 L
.162 .34612 L
.18289 .29305 L
Mistroke
.19211 .27211 L
.20191 .25359 L
.20756 .2451 L
.21268 .23894 L
.21515 .2365 L
.21782 .23426 L
.22035 .23252 L
.22265 .23127 L
.22503 .23031 L
.22634 .22992 L
.22758 .22964 L
.22873 .22947 L
.22979 .22937 L
.23095 .22934 L
.23218 .22939 L
.23342 .22953 L
.23411 .22964 L
.23475 .22977 L
.23715 .23045 L
.23843 .23094 L
.23982 .23157 L
.24263 .23315 L
.24792 .23718 L
.25356 .24288 L
.26371 .25625 L
.28366 .29037 L
.30526 .33021 L
.31539 .34696 L
.3261 .36193 L
.33525 .37187 L
.34044 .37619 L
.34529 .3793 L
.34789 .38059 L
.35029 .38155 L
.35292 .38234 L
.35426 .38263 L
.35497 .38276 L
.35573 .38287 L
.35701 .38302 L
.35818 .38309 L
.35944 .38311 L
.36016 .38309 L
.36083 .38305 L
.36204 .38294 L
.36314 .3828 L
.36442 .38257 L
.36562 .38229 L
.36787 .38163 L
.37025 .38072 L
.37452 .37857 L
Mistroke
.37911 .37554 L
.38417 .37137 L
.40359 .34865 L
.42448 .31655 L
.4442 .28504 L
.45462 .27 L
.46572 .25632 L
.47129 .25062 L
.47653 .24607 L
.48163 .24244 L
.48633 .23985 L
.4908 .23807 L
.49305 .23744 L
.49431 .23716 L
.49551 .23694 L
.49681 .23677 L
.498 .23666 L
.49927 .2366 L
.49999 .23659 L
.50065 .2366 L
.50176 .23665 L
.50298 .23675 L
.50425 .23691 L
.50545 .23711 L
.50788 .23768 L
.51015 .23839 L
.51529 .24066 L
.5203 .24372 L
.52565 .24786 L
.53535 .25751 L
.54416 .26835 L
.58416 .33037 L
.60249 .35676 L
.6129 .3686 L
.618 .37326 L
.62264 .37678 L
.62757 .3797 L
.62983 .38076 L
.63224 .38167 L
.63358 .38208 L
.63479 .38239 L
.63603 .38265 L
.63716 .38284 L
.6378 .38293 L
.6385 .383 L
.63919 .38305 L
.63993 .38309 L
.64058 .38311 L
.64128 .3831 L
.64253 .38305 L
Mistroke
.64322 .383 L
.64395 .38292 L
.64525 .38272 L
.64665 .38244 L
.6482 .38204 L
.65096 .38108 L
.65355 .37991 L
.65838 .37703 L
.66358 .37293 L
.67368 .36221 L
.68471 .34682 L
.70479 .31197 L
.7261 .27276 L
.73617 .25644 L
.74543 .24405 L
.75004 .23909 L
.7551 .23472 L
.75756 .23303 L
.76019 .23157 L
.76164 .23091 L
.76297 .23041 L
.76423 .23002 L
.76557 .2297 L
.76672 .22951 L
.76799 .22938 L
.76915 .22934 L
.77023 .22937 L
.77151 .2295 L
.77268 .22969 L
.77396 .23 L
.77531 .23043 L
.7776 .23139 L
.77972 .23256 L
.78455 .23622 L
.78959 .24149 L
.79506 .24883 L
.80499 .26617 L
.82358 .30914 L
.84305 .35841 L
.84839 .37042 L
.85412 .38172 L
.8595 .39034 L
.86448 .39624 L
.86693 .3983 L
.8683 .39919 L
.86953 .39983 L
.8702 .4001 L
.8709 .40034 L
.87167 .40054 L
.87237 .40066 L
Mistroke
.87364 .40074 L
.87437 .40071 L
.87504 .40062 L
.87634 .40029 L
.87757 .39979 L
.87868 .39919 L
.87988 .39836 L
.88257 .39583 L
.88506 .39266 L
.8894 .38519 L
.89419 .37406 L
.90388 .34271 L
.91411 .29906 L
.92488 .24815 L
.92933 .22835 L
.93407 .20997 L
.9368 .20139 L
.93928 .19527 L
.94047 .19299 L
.94177 .19107 L
.94299 .18984 L
.94412 .18925 L
.94509 .18918 L
.94597 .1895 L
.94699 .19034 L
.94796 .19163 L
.94885 .19329 L
.94967 .19523 L
.95154 .20117 L
.95342 .2095 L
.9555 .22173 L
.95767 .23827 L
.95971 .25768 L
.96384 .31012 L
.96763 .37608 L
.9718 .47168 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo
0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooo
nfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoook
JP00oooonfXAoookJP?o001o2_oonfX5o`000?oooo]Z7ooonfX00?oooo]Z4OoonfX3o`00O`[ooo]Z
1Ol0003ooookJQoooo]Z000@oookJPGo0<;o00?ooe`0oookJ_oonfX0n?oonfX3o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z000@oookJPGo0<;o0oooG03XoookJP[o001o1_oonfX3o`00O`[ooo]Z1Ol0003o
oookJQoooo]Z000@oookJPGo0<;o1?ooG03WoookJP[o001o1_oonfX3o`00O`[ooo]Z1ol0003ooook
JQgooo]Z000@oookJPGo0<;o00?ojol0oomL0?ooG0000oooG03eoookJP?o001o2_oonfX5o`000?oo
oo]Z7ooonfX0013ooo]Z1Ol0`_l00oo[o`3ooe`0oomL0005oomL0??ooo]Z0ol007l:oookJPGo0000
oooonfXOoookJP004?oonfX5o`32o`03oc?o0?ooG03ooe`000Kooe`0l_oonfX3o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z000@oookJPGo0<;o00?o<ol0on_o0?ooG0002?ooG03`oookJP?o001o2_oonfX5
o`000?oooo]Z7ooonfX0013ooo]Z1Ol0`_l00olco`3ojol0oomL000:oomL0>_ooo]Z1_l007l:oook
JPGo0000oooonfXOoookJP004?oonfX5o`32o`03oc?o0?o[o`3ooe`000_ooe`0j_oonfX6o`00O`[o
oo]Z1Ol0003ooookJQoooo]Z000@oookJPGo0<;o00Co0?n5on_o0?o[o`3ooo]Z3?ooG03ZoookJPCo
001o2_oonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol0`_l00ol0ohGojol0on_o0002oookJPgooe`0
jOoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z000@oookJPGo0<;o00?o0?n5on_o0?o[o`001?oo
nfX<oomL0?Gooo]Z1Ol0003ooookJQoooo]Z000@oookJPKo0<;o0_o[o`06oookJPcooe`0looonfX5
o`000?oooo]Z7ooonfX0013ooo]Z1_l0`_l00olco`3ojol0on_o0006oookJPgooe`0lOoonfX5o`00
0?oooo]Z7ooonfX0013ooo]Z1_l0`_l00olco`3ojol0on_o0008oookJPcooe`0l?oonfX5o`000?oo
oo]Z7ooonfX0013ooo]Z1_l0`_l00olco`3ojol0on_o000:oookJPcooe`0k_oonfX5o`000?oooo]Z
7ooonfX0017ooo]Z1Ol0`_l01?lco`3ojol0on_o0?o[o`0:oookJPgooe`0k?oonfX5o`000?oooo]Z
7ooonfX0017ooo]Z1Ol0`_l01?lco`3ojol0on_o0?o[o`0<oookJPcooe`0jooonfX5o`000?oooo]Z
7ooonfX0017ooo]Z1Ol0`_l01?lco`3ojol0on_o0?o[o`0>oookJPcooe`0jOoonfX5o`000?oooo]Z
7ooonfX0017ooo]Z1Ol0`_l00olco`3ojol0on_o0002on_o00kooo]Z3?ooG03XoookJPGo0000oooo
nfXOoookJP004OoonfX5o`32o`;o<ol00oo[o`0@oookJPcooe`0i_oonfX5o`000?oooo]Z7ooonfX0
017ooo]Z1Ol0`_l2oc?o00?ojol04_oonfX<oomL0>Cooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo
0<;o0_lco`03on_o01?ooo]Z3?ooG03SoookJPGo0000oooonfXOoookJP004OoonfX5o`32o`;o<ol0
1?o[o`0DoookJPcooe`0hOoonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol0`_l00ol0ohGo<ol0on_o
0003on_o01Gooo]Z3?ooG03PoookJPGo0000oooonfXOoookJP004OoonfX5o`32o`03o`3oQOlco`3o
jol000?ojol05ooonfX<oomL0=kooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo0<;o00?o0?n5oc?o
0?o[o`001?o[o`0HoookJPcooe`0g?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol0`_l00ol0ohGo
<ol0on_o0004on_o01Wooo]Z3?ooG03KoookJPGo0000oooonfXOoookJP004OoonfX5o`32o`03o`3o
QOlco`3o<ol000Cojol06ooonfX<oomL0=Wooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo0<;o00?o
0?n5oc?o0?lco`001Oo[o`0KoookJPcooe`0f?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol0`_l0
0ol0ohGo<ol0oc?o0005on_o01gooo]Z3?ooG03FoookJPGo0000oooonfXOoookJP004OoonfX5o`32
o`03o`3oQOlco`3o<ol000Gojol07ooonfX<oomL0=Cooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo
0<;o00?o0?n5oc?o0?lco`001Oo[o`0PoookJPcooe`0dooonfX5o`000?oooo]Z7ooonfX0017ooo]Z
1_l0`_l2oc?o00Kojol08OoonfX<oomL0=7ooo]Z1Ol0003ooookJQoooo]Z000AoookJPKo0<;o0_lc
o`06on_o02;ooo]Z3?ooG03@oookJPGo0000oooonfXOoookJP004OoonfX6o`32o`;o<ol01_o[o`0T
oookJPcooe`0c_oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1_l0`_l3oc?o00Kojol09OoonfX;oomL
0<gooo]Z1Ol0003ooookJQoooo]Z000BoookJPGo0<;o0olco`06on_o02Kooo]Z3?ooG03;oookJPGo
0000oooonfXOoookJP004_oonfX5o`32o`?o<ol01_o[o`0XoookJPcooe`0bOoonfX5o`000?oooo]Z
7ooonfX001;ooo]Z1Ol0`_l00ol0ohGo<ol0oc?o0007on_o02Sooo]Z3?ooG038oookJPGo0000oooo
nfXOoookJP004_oonfX5o`32o`04o`3oQOlco`3o<ol0oookJPKojol0:_oonfX<oomL0<Kooo]Z1Ol0
003ooookJQoooo]Z000BoookJPGo0<;o00Co0?n5oc?o0?lco`3ooo]Z1_o[o`0[oookJPcooe`0aOoo
nfX5o`000?oooo]Z7ooonfX001;ooo]Z1Ol0`_l01?l0ohGo<ol0oc?o0?oonfX7on_o02cooo]Z3?oo
G033oookJPGo0000oooonfXOoookJP004_oonfX5o`32o`05o`3oQOlco`3o<ol0oc?o0?oonfX01_o[
o`0^oookJP_ooe`0`_oonfX5o`000?oooo]Z7ooonfX001;ooo]Z1Ol0`_l01Ol0ohGo<ol0oc?o0?lc
o`3ooo]Z00Kojol0;ooonfX<oomL0<3ooo]Z1Ol0003ooookJQoooo]Z000BoookJPGo0<;o00Go0?n5
oc?o0?lco`3o<ol0oookJP06on_o037ooo]Z3?ooG02noookJPGo0000oooonfXOoookJP004_oonfX5
o`32o`04o`3oQOlco`3o<ol0oc?o00;ooo]Z1_o[o`0aoookJPcooe`0_OoonfX5o`000?oooo]Z7ooo
nfX001;ooo]Z1Ol0`_l01?l0ohGo<ol0oc?o0?lco`02oookJPKojol0<ooonfX<oomL0;_ooo]Z1Ol0
003ooookJQoooo]Z000BoookJPGo0<;o00Co0?n5oc?o0?lco`3o<ol00_oonfX6on_o03Cooo]Z3Ooo
G02ioookJPGo0000oooonfXOoookJP004_oonfX5o`32o`04o`3oQOlco`3o<ol0oc?o00;ooo]Z1oo[
o`0eoookJPcooe`0^?oonfX5o`000?oooo]Z7ooonfX001;ooo]Z1Ol0`_l01?l0ohGo<ol0oc?o0?lc
o`03oookJPKojol0=ooonfX<oomL0;Kooo]Z1Ol0003ooookJQoooo]Z000BoookJPGo0<;o00?o0?n5
oc?o0?lco`000_lco`02oookJPKojol0>?oonfX<oomL0;Gooo]Z1Ol0003ooookJQoooo]Z000Boook
JPGo0<;o00?o0?n5oc?o0?lco`000_lco`02oookJPOojol0>OoonfX<oomL0;?ooo]Z1Ol0003ooook
JQoooo]Z000BoookJPGo0<;o00?o0?n5oc?o0?lco`000_lco`03oookJPKojol0>ooonfX<oomL0;7o
oo]Z1Ol0003ooookJQoooo]Z000BoookJPGo0<;o00?o0?n5oc?o0?lco`000_lco`03oookJPKojol0
??oonfX<oomL0;3ooo]Z1Ol0003ooookJQoooo]Z000BoookJPKo0<;o00Co0?n5oc?o0?lco`3o<ol0
0ooonfX6on_o03kooo]Z3?ooG02^oookJPGo0000oooonfXOoookJP004_oonfX6o`32o`04o`3oQOlc
o`3o<ol0oc?o00Cooo]Z1_o[o`0noookJPcooe`0[OoonfX5o`000?oooo]Z7ooonfX001;ooo]Z1_l0
`_l01?l0ohGo<ol0oc?o0?lco`04oookJPKojol0@?oonfX<oomL0:_ooo]Z1Ol0003ooookJQoooo]Z
000BoookJPKo0<;o00Co0?n5oc?o0?lco`3o<ol01?oonfX6on_o04;ooo]Z3?ooG02YoookJPGo0000
oooonfXOoookJP004ooonfX5o`32o`03o`3oQOlco`3o<ol000;o<ol00ooonfX7on_o04;ooo]Z3?oo
G02XoookJPGo0000oooonfXOoookJP004ooonfX5o`32o`03o`3oQOlco`3o<ol000;o<ol01?oonfX6
on_o04Cooo]Z3?ooG02VoookJPGo0000oooonfXOoookJP004ooonfX5o`32o`03o`3oQOlco`3o<ol0
00;o<ol01?oonfX6on_o04Gooo]Z3OooG02ToookJPGo0000oooonfXOoookJP004ooonfX5o`32o`03
o`3oQOlco`3o<ol000;o<ol01?oonfX7on_o04Kooo]Z3?ooG02SoookJPGo0000oooonfXOoookJP00
4ooonfX5o`32o`03o`3oQOlco`3o<ol000;o<ol01OoonfX6on_o04Sooo]Z3?ooG02QoookJPGo0000
oooonfXOoookJP004ooonfX5o`32o`03o`3oQOlco`3o<ol000;o<ol01OoonfX6on_o04Wooo]Z3Ooo
G02OoookJPGo0000oooonfXOoookJP004ooonfX5o`32o`03o`3oQOlco`3o<ol000;o<ol01OoonfX6
on_o04_ooo]Z3?ooG02NoookJPGo0000oooonfXOoookJP004ooonfX5o`32o`03o`3oQOlco`3o<ol0
00;o<ol01_oonfX6on_o04cooo]Z3?ooG02LoookJPGo0000oooonfXOoookJP004ooonfX5o`32o`03
o`3oQOlco`3o<ol000?o<ol01OoonfX6on_o04gooo]Z3OooG02JoookJPGo0000oooonfXOoookJP00
4ooonfX5o`32o`03o`3oQOlco`3o<ol000?o<ol01OoonfX6on_o04oooo]Z3?ooG02IoookJPGo0000
oooonfXOoookJP004ooonfX5o`32o`03o`3oQOlco`3o<ol000?o<ol01OoonfX7on_o053ooo]Z3?oo
G02GoookJPGo0000oooonfXOoookJP004ooonfX5o`32o`;o0?n51?lco`06oookJPKojol0DOoonfX<
oomL09Kooo]Z1Ol0003ooookJQoooo]Z000CoookJPGo0<;o0_l0ohD4oc?o00Kooo]Z1_o[o`1Coook
JPcooe`0U?oonfX5o`000?oooo]Z7ooonfX001?ooo]Z1Ol0`_l2o`3oQ@Co<ol01_oonfX7on_o05Co
oo]Z3?ooG02BoookJPGo0000oooonfXOoookJP004ooonfX5o`32o`;o0?n51?lco`07oookJPKojol0
EOoonfX<oomL097ooo]Z1Ol0003ooookJQoooo]Z000CoookJPGo0<;o0_l0ohD5oc?o00Kooo]Z1_o[
o`1GoookJPcooe`0SooonfX5o`000?oooo]Z7ooonfX001?ooo]Z1Ol0`_l2o`3oQ@Go<ol01_oonfX7
on_o05Oooo]Z3?ooG02>oookJPGo0000oooonfXOoookJP004ooonfX5o`32o`;o0?n51Olco`07oook
JPKojol0FOoonfX<oomL08cooo]Z1Ol0003ooookJQoooo]Z000CoookJPGo0<;o0_l0ohD5oc?o00Oo
oo]Z1_o[o`1KoookJP_ooe`0RooonfX5o`000?oooo]Z7ooonfX001?ooo]Z1_l0`_l00ol0ohGo<ol0
oc?o0003oc?o00Oooo]Z1oo[o`1KoookJPcooe`0ROoonfX5o`000?oooo]Z7ooonfX001?ooo]Z1_l0
`_l00ol0ohGo<ol0oc?o0003oc?o00Sooo]Z1_o[o`1MoookJPcooe`0QooonfX5o`000?oooo]Z7ooo
nfX001?ooo]Z1_l0`_l00ol0ohGo<ol0oc?o0003oc?o00Sooo]Z1oo[o`1MoookJPcooe`0Q_oonfX5
o`000?oooo]Z7ooonfX001?ooo]Z1_l0`_l00ol0ohGo<ol0oc?o0003oc?o00Sooo]Z1oo[o`1Ooook
JPcooe`0I_oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Z7ooonfX001Co
oo]Z1Ol0`_l00ol0ohGo<ol0oc?o0004oc?o00Sooo]Z1_o[o`1PoookJPcooe`0I?oonfX7o`00O`?o
oo]Z0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z7ooonfX001Cooo]Z1Ol0`_l2o`3oQ@Go<ol0
2?oonfX7on_o067ooo]Z3?ooG01RoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00Ob;ookP0oooonfX@oookJP005?oonfX5o`32o`;o0?n51Olco`09oookJPKo
jol0HooonfX<oomL05?ooo]Z2_l007l2oookJP?o001o0ooonfX2o`00Oc7ookP0oooonfX;oookJP00
5?oonfX5o`32o`;o0?n51Olco`09oookJPKojol0I?oonfX<oomL05;ooo]Z2_l007l2oookJP?o001o
>ooo^03ooookJPKooo]Z000DoookJPGo0<;o0_l0ohD5oc?o00Wooo]Z1oo[o`1UoookJPcooe`0F_oo
nfY6oonh0?oooo]Z000DoookJPGo0<;o0_l0ohD5oc?o00[ooo]Z1_o[o`1VoookJPgooe`0E?oonfY?
oonh0?[ooo]Z000DoookJPGo0<;o0_l0ohD5oc?o00[ooo]Z1oo[o`1WoookJPcooe`0CooonfXPoonh
0003o`00Oooonf[ooo]Z00Oooo]Z1Ol0000;oookJQgookP0m_oonfX001Cooo]Z1Ol0`_l2o`3oQ@Ko
<ol02OoonfX7on_o06Wooo]Z3?ooG01:oookJQWookP01?oonfX6o`00O`[ooo]Z1Ol0000@oookJQ_o
okP0looonfX001Cooo]Z1Ol0`_l2o`3oQ@Ko<ol02_oonfX6on_o06[ooo]Z3OooG015oookJQOookP0
0_l007l7oookJP;o001o3_oonfX5o`0001Gooo]Z6_oo^03_oookJP005?oonfX5o`32o`;o0?n51_lc
o`0:oookJPOojol0JooonfX=oomL047ooo]Z5?oo^002o`00O`04oookJ_l007oo001oo`00O`Sooo]Z
0_l007l>oookJPGo00006ooonfXGoonh0>cooo]Z000DoookJPGo0<;o0_l0ohD6oc?o00_ooo]Z1_o[
o`1]oookJPcooe`0?_oonfXBoonh00?ooo]Z1ol007l9oookJPOo001o2?oonfX5o`00023ooo]Z5Ooo
^00coookJQgojol0VOoonfX001Cooo]Z1Ol0`_l2o`3oQ@03oookJ_lco`3o<ol000?o<ol02ooonfX7
on_o06gooo]Z3OooG00ioookJQ7ookP02?oonfX5o`00O`[ooo]Z1ol007l8oookJPGo00009?oonfXD
oonh02_ooo]Z9Oo[o`2FoookJP005?oonfX5o`32o`?o0?n51Olco`0;oookJPOojol0KooonfX=oomL
03Gooo]Z4?oo^00YoookJPGo00009ooonfXCoonh02Kooo]Z;?o[o`2BoookJP005?oonfX5o`32o`?o
0?n51_lco`0;oookJPKojol0<ooonfXDohoo02[ooo]Z3?ooG00aoookJQ3ookP0;?oonfX5o`0002_o
oo]Z4_oo^00PoookJS;ojol05_oonfXAohoo06Sooo]Z000DoookJPGo0<;o0ol0ohD6oc?o00_ooo]Z
1oo[o`0`oookJQWoSol0:OoonfX<oomL02cooo]Z4Ooo^00^oookJPGo0000;_oonfXAoonh01cooo]Z
=_o[o`0@oookJQWoSol03?oonfX;oc?o04gooo]Z000DoookJPGo0<;o0ol0ohD6oc?o00cooo]Z1_o[
o`07oookJP[o0?lX7?oonfXOohoo02Oooo]Z3OooG00WoookJQ;ookP0<?oonfX5o`00037ooo]Z4?oo
^00GoookJQCojol05OoonfXBon_o00_ooo]Z7on?o`05oookJQ;o<ol01?oonfX:o`3o:3cooo]Z000D
oookJPGo0<;o0ol0ohD5oc?o00Ko06Ko0_oonfX8o`3oh@?ojol01_oonfX=o`3o:1Oooo]Z9?n?o`0W
oookJPcooe`09?oonfXAoonh03?ooo]Z1Ol0000doookJQ3ookP04OoonfXBon_o01gooo]Z4Oo[o`06
oookJRCoSol00_oonfXDoc?o0003oookJ_l0obSo0?lX00_o0?lX2Ol0ohD6o`3oh@Co0<;o1_l0I_lR
oookJP005?oonfX5o`32o`?o0?n500Cooo]Zoc?o0?lco`3o<ol02?l0I_l00ooonf[o0?oQo`3oh@07
o`3oh@?ojol00ooonfXAo`3o:1?ooo]Z9on?o`0XoookJPcooe`08?oonfXAoonh03Gooo]Z1Ol0000f
oookJQ3ookP03OoonfXAon_o02Cooo]Z3oo[o`02oookJROoSol05?lco`0>o`3o:0So0?n51_l0on45
o`32o`So06Ko8OoonfX001Cooo]Z1Ol0`_l3o`3oQ@04oookJ_lco`3o<ol0oc?o00Wo06Ko2_l0on42
on_o00;ooo]Z4ol0obPAoookJPooSol03?oonfX?ohoo02Oooo]Z3OooG00LoookJQ3ookP0>?oonfX5
o`0003Wooo]Z3ooo^008oookJQ7ojol0:_oonfX=on_o017oSol02OoonfX<ohoo01Go<ol03_l0obP9
o`3oQ@Ko0?oQ1?l0`_l9o`1Vob7ooo]Z000DoookJPGo0<;o0ol0ohD00ooonf[o<ol0oc?o000:o`1V
o`_o0?oQ0_o[o`0Eo`3o:0kooo]Z3on?o`0AoookJPgoSol0:?oonfX<oomL01[ooo]Z3_oo^00koook
JPGo0000>ooonfX>oonh00Gooo]Z4Oo[o`0^oookJPWojol03on?o`0AoookJPKoSol03olco`000ooo
nf[o<ol0oc?o0004oc?o00ko0?lX2Ol0ohD6o`3oh@Go0<;o2_l0I_lPoookJP005?oonfX5o`32o`?o
0?n500?ooo]Zoc?o0?lco`002_l0I_l<o`3oh@[o0?lX0_oonfX;o`3o:0cooo]Z3On?o`0GoookJPco
Sol0:?oonfX<oomL01Kooo]Z3Ooo^00noookJPGo0000?OoonfX>oonh0003oookJ_o[o`3ojol000ko
jol0<ooonfX6on_o00goSol05ooonfX2ohoo00_o<ol02_oonfX00olco`3o0?lXo`3o:009o`3o:003
oookJ_l0obSo0?lX00Wo0?n51_l0on45o`32o`_o06Ko8?oonfX001Cooo]Z1_l0`_l2o`3oQ@03oook
J_lco`3o<ol000_o06Ko2ol0on49o`3o:0Gooo]Z2_l0obP:oookJP_oSol07?oonfX;ohoo02Sooo]Z
3?ooG00CoookJPgookP0@?oonfX5o`00043ooo]Z2_oo^00?on_o03Sooo]Z0_o[o`0<ohoo01_ooo]Z
2olco`0;oookJP_o0?lX0ooonfX9o`3oQ@03o`3o:?l0on7o0?oQ00Co0?oQ1Ol0`_l;o`1Vob3ooo]Z
000DoookJPKo0<;o0ol0ohD00olco`3o06Koo`1Vo`0;o`1Vo`;o0?oQ00?ooo]Zo`3ohOl0on401_l0
on46o`3o:0Wooo]Z2Ol0obP8oookJP[oSol07ooonfX<ohoo02Sooo]Z3?ooG00?oookJPgookP0@_oo
nfX5o`0004;ooo]Z1_oo^00?on_o03_ooo]Z2on?o`02on_o01[ooo]Z2olco`02ohoo00Wooo]Z2Ol0
obP4oc?o0003oookJ_l0ohGo0?n500Oo0?n500?o0?lXo`3ohOl0on401Ol0on44o`32o`go06Ko7ooo
nfX001Cooo]Z1_l0`_l3o`3oQ@03oookJ_l0I_oo06Ko00_o06Ko00Co0?oQoookJ_oonf[ooo]Z1ol0
on45o`3o:0_ooo]Z2?l0obP7oookJP[oSol08_oonfX<ohoo02Sooo]Z2oooG00<oookJPgookP0A?oo
nfX5o`0004Cooo]Z0_oo^00>on_o03cooo]Z3?n?o`05on_o01Oooo]Z2_lco`05ohoo00Sooo]Z2?l0
obP6oc?o00So0?n500?o0?lXo`3ohOl0on401_l0on44o`32o`go06Ko7ooonfX001Cooo]Z1_l0`_l3
o`3oQ@03oookJ_l0I_oo06Ko00co06Ko1?oonfX7o`3oh@?o0?lX3OoonfX8o`3o:0Gooo]Z2On?o`0U
oookJPcoSol0:?oonfX<oomL00Sooo]Z3_oo^015oookJPGo0000A?oonfX>on_o03gooo]Z2on?o`08
on_o01Gooo]Z2Olco`08ohoo00Kooo]Z2?l0obP6oc?o00So0?n50_l0obP7o`3oh@Go0<;o1_l0I_l0
0ol0`_oo06Koo`1Vo`04o`1Voaoooo]Z000EoookJPGo0<;o0ol0ohD7o`1Vo`03o`3ohOl0I_oo06Ko
00Go06Ko1?oonfX7o`3oh@;o0?lX3ooonfX8o`3o:0Cooo]Z2?n?o`0XoookJPcoSol0:?oonfX<oomL
00Gooo]Z3Ooo^017oookJPGo0000@_oonfX>on_o00CookP0>OoonfX<ohoo00[ojol04ooonfX9oc?o
0003oookJ_n?o`3oSol000OoSol01?oonfX8o`3o:003oookJ_lco`3o<ol000?o<ol02?l0ohD2o`3o
:0Oo0?oQ1Ol0`_l7o`1Vo`03o`32ool0I_oo06Ko00Co06Ko7ooonfX001Gooo]Z1Ol0`_l3o`3oQ@Ko
06Ko00?o<ol0o`3ohOl0on401_l0I_l5oookJPOo0?oQ00?o0?lXoookJ_oonfX03_oonfX8o`3o:0;o
oo]Z2?n?o`0ZoookJPcoSol0:?oonfX<oomL00;ooo]Z1ooo^00:oc?o04Gooo]Z1Ol00010oookJPko
jol02?oo^00foookJP_oSol00_oonfX;on_o017ooo]Z2Olco`03oookJPWoSol00_oonfX8o`3o:0?o
oo]Z1?lco`07o`3oQ@;ooo]Z00?o0?lXo`3ohOl0on401Ol0on45o`32o`Ko06Ko0ol0`_l6o`1Voako
oo]Z000EoookJPGo0<;o0ol0ohD6o`1Vo`03oc?o0?l0on7o0?oQ00Oo06Ko1?oonfX7o`3oh@03on_o
0?oonf[ooo]Z00kooo]Z2?l0obP00ooonf[oSol0ohoo0006ohoo02gooo]Z3?n?o`0XoookJP[ooe`0
00?ookP0oc?o0?lco`005olco`0noookJPGo0000?_oonfX>on_o00_ookP0=?oonfX;ohoo00Gooo]Z
2oo[o`0>oookJPWo<ol01OoonfX9ohoo0003oookJ_l0obSo0?lX00Ko0?lX1?oonfX2oc?o00So0?n5
0_oonfX7o`3oh@03o`3o:?l0`_oo0<;o00?o0<;o1_l0I_l00ol0on7o0<;oo`32o`06o`1Voakooo]Z
000EoookJPGo0<;o0ol0ohD6o`1Vo`Co0?oQ1_l0I_l4oookJP03o`3o:?l0on7o0?oQ00Co0?oQ00?o
jol0oookJ_oonfX03ooonfX8o`3o:0OoSol0<?oonfX;ohoo02Sooo]Z1oooG00Ooc?o03_ooo]Z1Ol0
000moookJPgojol00_oonfX=oonh037ooo]Z2_n?o`09oookJP[ojol03?oonfX9oc?o00Oooo]Z2?n?
o`08o`3o:0Gooo]Z0_lco`07o`3oQ@?ooo]Z1ol0on45o`32o`Oo06Ko00?o0?oQo`32ool0`_l01_l0
I_lNoookJP005OoonfX5o`32o`;o0?n51_l0I_l00olco`3o0?oQo`3oh@02o`3oh@Ko06Ko0ooonfX2
o`3o:0Oo0?oQ00?ojol0oookJ_oonfX03ooonfX8o`3o:0KoSol0<OoonfX;ohoo02Wooo]Z0oooG00T
oc?o03Sooo]Z1Ol0000loookJPcojol01_oonfX=oonh02kooo]Z2_n?o`0;oookJP[ojol02_oonfX9
oc?o00Wooo]Z1_n?o`08o`3o:0Oooo]Z1ol0ohD4oookJPKo0?oQ00?o0?lXo`32ool0`_l00ol0`_l6
o`1Vo`;o0?oQ0_l0`_l6o`1Voakooo]Z000EoookJPGo0<;o0_l0ohD6o`1Vo`03oc?o0?l0on7o0?oQ
00;o0?oQ1ol0I_l2oookJP?o0?lX1_l0on400oo[o`3ooo]ZoookJP0@oookJPOo0?lX1On?o`0Soook
JP[o0?n51ooonfX:ohoo02[ooo]Z9olco`0foookJPGo0000>_oonfX<on_o00[ooo]Z3?oo^00[oook
JP[oSol03_oonfX:on_o00Sooo]Z2Olco`0;oookJPGoSol01ol0obP8oookJPOo0?n500?o<ol0oook
J_oonfX01ol0on400ol0obSo0<;oo`32o`03o`32o`Ko06Ko0_l0on43o`32o`Go06Ko7_oonfX001Go
oo]Z1Ol0`_l2o`3oQ@Ko06Ko00?o<ol0o`3ohOl0on400ol0on46o`1Vo`03oookJ_l0obSo0?lX00;o
0?lX1ol0on4BoookJPSo0?lX0on?o`0QoookJQ;o0?n50ooonfX:ohoo02Oooo]Z5?lco`02oookJQGo
<ol0=?oonfX5o`0003Wooo]Z2oo[o`0>oookJPcookP0:?oonfX:ohoo013ooo]Z2_o[o`06oookJPWo
<ol03OoonfX3ohoo00So0?lX1ooonfX7o`3oQ@?o<ol000?ooo]Zo`3ohOl0on401?l0on42o`3o:0Co
0<;o1ol0I_l3o`3oh@;o0<;o1Ol0I_lNoookJP005OoonfX5o`32o`;o0?n51_l0I_l00olco`3o0?oQ
o`3oh@03o`3oh@Ko06Ko00?ooo]Zo`3o:?l0obP00_l0obP7o`3oh@03on_o0?oonf[ooo]Z013ooo]Z
1_l0obP;o`32oaSooo]Z5Ol0ohD4oookJPWoSol08ooonfX?oc?o00Gooe`03?oonfX@oc?o02gooo]Z
3ol0obPcoookJP[ojol04OoonfX<oonh02Kooo]Z2_n?o`0CoookJPWojol01OoonfX8oc?o00oooo]Z
0_n?o`07o`3o:0Sooo]Z1ol0ohD3oc?o0003oookJ_l0on7o0?oQ00Co0?oQ00?o0?lXo`32ool0`_l0
0ol0`_l6o`1Vo`Co0?oQ0_l0`_l6o`1Voagooo]Z000EoookJPGo0<;o0_l0ohD5o`1Vo`03oc?o0?l0
on7o0?oQ00Co0?oQ1_l0I_l6o`3o:0Oo0?oQ4ooonfX4o`3o:0ko0<;o5?oonfXHo`3oQ@Cooo]Z2On?
o`0OoookJPoo<ol02OooG00>oookJPoo<ol0:?oonfXGo`3o:2cooo]Z2oo[o`0DoookJP_ookP09?oo
nfX:ohoo01Gooo]Z2?o[o`04oookJPSo<ol04OoonfX7o`3o:0Sooo]Z1ol0ohD4oc?o00Oo0?oQ00?o
0?lXo`32ool0`_l00ol0`_l6o`1Vo`Co0?oQ0_l0`_l6o`1Voagooo]Z000EoookJPGo0<;o0_l0ohD5
o`1Vo`03oc?o0?l0on7o0?oQ00Co0?oQ00?ooo]Zo`1Vool0I_l01?l0I_l5o`3o:0Oo0?oQ4_oonfX0
0on?o`3o0?lXo`3o:00Ao`32oa;ooo]Z6ol0ohD3oookJPWoSol07OoonfX>oc?o0003oonh0?ooG03o
oe`000[ooe`03ooonfX=oc?o02Cooo]Z7Ol0obPXoookJP_ojol05ooonfX;oonh027ooo]Z2_n?o`0G
oookJPSojol00_oonfX8oc?o017ooo]Z2?l0obP00on?o`3ooo]ZoookJP05oookJPOo0?n51?lco`06
o`3oh@;o0?lX1Ol0`_l6o`1Vo`Co0?oQ0_l0`_l6o`1Voagooo]Z000EoookJPGo0<;o0_l0ohD5o`1V
o`03oc?o0?l0on7o0?oQ00Co0?oQ00?ooo]Zo`1Vool0I_l01?l0I_l5o`3o:003oookJ_l0on7o0?oQ
00Co0?oQ00?ojol0oookJ_oonfX03ooonfX2ohoo01?o0<;o3ooonfX>o`3oQ@;ooo]Z3_l0ohD3oook
JPWoSol06ooonfX>oc?o00?ooo]Z3?ooG00@oookJPgo<ol07ooonfXSo`3o:1oooo]Z3Ol0ohD2on_o
01[ooo]Z2ooo^00OoookJPWoSol06_oonfX8on_o00So<ol04_oonfX7o`3o:0?oSol01OoonfX7o`3o
Q@Co<ol01ol0on400ooonf[o0<;oo`32o`04o`32o`Go06Ko0_l0ohD3o`3oh@;o0<;o1_l0I_lMoook
JP005OoonfX5o`32o`;o0?n51Ol0I_l00olco`3o0?oQo`3oh@04o`3oh@03oookJ_l0I_oo06Ko00Co
06Ko1Ol0obP00ooonf[o0?oQo`3oh@05o`3ohA3ooo]Z0on?o`0Do`32o`gooo]Z3?l0ohD:oookJP_o
0?n50_oonfX9ohoo01Wooo]Z3Olco`000ooo^03ooo]ZoookJP04oookJPcooe`04?oonfX<oc?o01_o
oo]Z:?l0obPIoookJQOo0?n56?oonfX;oonh01gooo]Z2?n?o`0LoookJPOojol02?lco`0AoookJPSo
0?lX0on?o`05oookJPOo0?n51?lco`07o`3oh@03oookJ_l0`_oo0<;o00?o0<;o1_l0I_l2o`3oQ@?o
0?oQ0ol0`_l5o`1Voagooo]Z000EoookJPGo0<;o0_l0ohD5o`1Vo`Ko0?oQ0_oonfX6o`1Vo`Co0?lX
0ooonfX6o`3oh@03on_o0?oonf[ooo]Z00cooo]Z0on?o`09o`32o`?ooo]Z2_l0`_l;oookJP_o0?n5
3OoonfX;o`3oQ@;ooo]Z2On?o`0FoookJPCo<ol03_l0on46oookJP_ooe`04OoonfX;oc?o01Oooo]Z
4ol0obP00ooonf[o0000o`000003o`000003oookJ_l0obSo0?lX017o0?lX5OoonfXKo`3oQACooo]Z
3_l0on4KoookJPSoSol07OoonfX6on_o00So<ol04_oonfX7o`3o:0GoSol01?oonfX6o`3oQ@;ooo]Z
0olco`06o`3oh@;ooo]Z1Ol0`_l6o`1Vo`;o0?n51?l0on42o`32o`Go06Ko7OoonfX001Gooo]Z1Ol0
`_l00ol0ohGo06Koo`1Vo`04o`1Vo`Ko0?oQ0ooonfX6o`1Vo`?o0?lX0ooonfX7o`3oh@kooo]Z0on?
o`08o`32o`;o0?lX1?oonfX9o`32o`[ooo]Z2Ol0ohD@oookJP_o0?n50_oonfX9ohoo01Cooo]Z00?o
<ol0o`3ohOl0on405?l0on43oookJPcooe`04OoonfX;oc?o01Cooo]Z4Ol0obP4oookJPGo00001_oo
nfX?o`3o:17ooo]Z7ol0ohD@oookJQGo0?oQ3ooonfX;o`32o`CoSol07ooonfX4on_o00So<ol04_oo
nfX7o`3o:0OoSol00_oonfX7o`3oQ@;ooo]Z0_lco`07o`3oh@03oookJ_l0`_oo0<;o00Co0<;o1_l0
I_l2o`3oQ@Co0?oQ0_l0`_l6o`1Voacooo]Z000EoookJPGo0<;o00?o0?n5o`1Vool0I_l01?l0I_l6
o`3oh@?ooo]Z1_l0I_l3o`3o:0?ooo]Z1ol0on4=oookJP?oSol01ol0`_l4o`3o:0Gooo]Z2Ol0`_l8
oookJPWo0?n52ooonfX:o`1Vo`So0?n50_oonfX8ohoo01?ooo]Z6Ol0on44oookJPcooe`04?oonfX;
oc?o017ooo]Z4?l0obP7oookJPGo00002OoonfX>o`3o:0gooo]Z8ol0ohD;oookJQWo0?oQ2_oonfXA
o`32o`03ohoo0?oonf[ooo]Z00Oooo]Z2ol0I_l=oookJP;ojol02?lco`0CoookJPOo0?lX1on?o`02
oookJPKo0?n51?oonfX00olco`3o0?oQo`3oh@04o`3oh@;ooo]Z1_l0`_l6o`1Vo`;o0?n51?l0on42
o`32o`Ko06Ko7?oonfX001Gooo]Z1_l0`_l6o`1Vo`Ko0?oQ0ooonfX6o`1Vo`;o0?lX1OoonfX6o`3o
h@03on_o0?oonf[ooo]Z00Wooo]Z0on?o`08o`32o`Go0?lX1OoonfX8o`32o`Oooo]Z2?l0ohD;oook
JQ3o06Ko1Ol0ohD2oookJPSoSol04OoonfXKo`3oh@Cooo]Z3?ooG00AoookJP_o<ol03_oonfX>o`3o
:0[ooo]Z1Ol0000<oookJPco0?lX2_oonfXAo`3oQ@Gojol04Ol0ohD8oookJQgo0?oQ1_oonfXEo`32
o`Gooo]Z3ol0I_l<oookJP03on_o0?lco`3o<ol000Ko<ol04_oonfX7o`3o:003oookJ_n?o`3oSol0
00KoSol01ol0ohD4oookJP03oc?o0?l0on7o0?oQ00Co0?oQ0_oonfX6o`32o`Go06Ko0ol0ohD4o`3o
h@;o0<;o1_l0I_lLoookJP005OoonfX6o`32o`Ko06Ko1Ol0on44oookJPKo06Ko0_l0obP5oookJPOo
0?oQ2ooonfX2ohoo00So0<;o1_l0obP6oookJPSo0<;o1OoonfX8o`3oQ@_ooo]Z4ol0I_l4o`3oQ@;o
oo]Z2?n?o`0>oookJR3o0?oQ0ooonfX<oomL00kooo]Z4?l0`_l8oookJPgo0?lX3OoonfX5o`0000ko
oo]Z2ol0obP8oookJPko0?n52?o[o`07oookJPco0?n51_oonfXOo`3oh@?ooo]Z6?l0`_l2oookJQ?o
06Ko2_oonfX8oc?o00;ojol04?oonfX8o`3o:0;ooo]Z1on?o`07o`3oQ@Cooo]Z1ol0on400ooonf[o
0<;oo`32o`04o`32o`Ko06Ko1?l0ohD3o`3oh@;o0<;o1_l0I_lLoookJP005OoonfX6o`32o`Go06Ko
1_l0on45oookJPGo06Ko0_l0obP6oookJPKo0?oQ00?ojol0oookJ_oonfX01ooonfX3ohoo00So0<;o
1ol0obP6oookJPSo0<;o0ooonfX9o`3oQ@Wooo]Z5_l0I_l4o`3oQ@;ooo]Z2?n?o`0<oookJPko0?oQ
1_oonfX?o`3oh@;ooo]Z3?ooG00;oookJQCo0<;o1OoonfX;o`3o:13ooo]Z1Ol0000@oookJP[o0?lX
1OoonfX>o`3oQ@Sojol02ooonfX<o`3oQ@?ooo]Z3Ol0on45oookJPoo0?oQ6ol0`_lEo`1Vo`Sooo]Z
2?lco`04on_o00oooo]Z1ol0obP4oookJPKoSol01_l0ohD5oookJPKo0?oQ0_lco`06o`32o`Ko06Ko
1?l0ohD3o`3oh@?o0<;o1Ol0I_lLoookJP005OoonfX6o`32o`Go06Ko1_l0on400olco`3ooo]Zoook
JP02oookJPKo06Ko00?o0?lXoookJ_oonfX01?oonfX6o`3oh@03on_o0?oonf[ooo]Z00Oooo]Z0_n?
o`08o`32o`03oookJ_l0obSo0?lX00Go0?lX1ooonfX7o`32o`;ooo]Z2Ol0ohD9oookJQSo06Ko1?l0
ohD00ooonf[oSol0ohoo0007ohoo00[ooo]Z2ol0on42oonh00cooo]Z3?l0on43oookJPcooe`01_oo
nfXIo`32o`;ooo]Z2ol0obP>oookJP_o06Ko3_oonfX;o`3o:0;ooo]Z3?l0ohD:on_o00gooo]Z3?l0
ohD<o`3oh@_ooo]Z0_oo^009o`3oh@ko0<;o0on?o`0:o`32oaOo06Ko1_oonfX8oc?o00Kojol03Ooo
nfX8o`3o:0Cooo]Z1On?o`07o`3oQ@Cooo]Z1ol0on42oc?o00Ko0<;o1_l0I_l4o`3oQ@Co0?oQ0_l0
`_l6o`1Voa_ooo]Z000FoookJPGo0<;o1Ol0I_l6o`3oh@03oc?o0?oonf[ooo]Z00;ooo]Z1_l0I_l7
oookJPOo0?oQ2?oonfX3ohoo00Oo0<;o0ooonfX7o`3o:0Kooo]Z2?l0`_l00ooonf[o0?n5o`3oQ@06
o`3oQ@Wooo]Z3?l0I_l00ooonf[o06Koo`1Vo`0:o`1Vo`Go0?n500?ooo]Zohoo0?n?o`001on?o`08
oookJP[o0?oQ0_oo^00?oookJPco0?oQ1?oonfX;oomL00Cooo]Z7?l0`_l9o`3o:0gooo]Z4ol0I_l;
oookJP[o0?lX2ol0ohD;on_o013ooo]Z2Ol0ohD:o`3oh@oooo]Z0_oo^007o`3oh@_o0<;o00?ooo]Z
ohoo0?n?o`001_n?o`07o`32o`co06Ko0_oonfX;o`1Vo`Gooo]Z2?lco`07on_o00cooo]Z1ol0obP6
oookJPCoSol01_l0ohD5oookJPOo0?oQ00?o<ol0o`32ool0`_l01Ol0`_l6o`1Vo`Co0?n51?l0on42
o`32o`Ko06Ko6ooonfX001Kooo]Z1Ol0`_l5o`1Vo`Ko0?oQ00?o<ol0oookJ_oonfX00_oonfX6o`1V
o`Sooo]Z1_l0on400oo[o`3ooo]ZoookJP05oookJP?oSol01_l0`_l4oookJPOo0?lX1ooonfX7o`32
o`So0?n52_oonfX9o`1Vo`Sooo]Z2Ol0I_l5o`3oQ@03oookJ_n?o`3oSol000OoSol01_oonfX:o`3o
h@;ookP04OoonfX<o`3oh@Cooo]Z3?ooG00Oo`32o`Oo0?lX2ooonfXGo`1Vo`_ooo]Z2?l0obP:o`3o
Q@03oookJ_o[o`3ojol000Sojol05?oonfX6o`3oQ@[o0?oQ4_oonfX3oonh00?o0?oQ2ol0`_l00ooo
nf[oSol0ohoo0007ohoo00?ooo]Z0ol0`_l:o`1Vo`Oooo]Z2_l0I_l3oookJPSo<ol02Oo[o`0:oook
JPOo0?lX1ooonfX3ohoo00Oo0?n51OoonfX6o`3oh@;o<ol01_l0`_l6o`1Vo`03oookJ_l0ohGo0?n5
00;o0?n51?l0on42o`32o`Ko06Ko6ooonfX001Kooo]Z1Ol0`_l5o`1Vo`Go0?oQ0_lco`04oookJPKo
06Ko2?oonfX7o`3oh@Kooo]Z0on?o`07o`32o`Gooo]Z1ol0obP7oookJPOo0<;o1_l0ohD:oookJPWo
06Ko2ooonfX8o`1Vo`Go0?n500?ooo]Zohoo0?n?o`001on?o`04oookJPWo0?oQ00?o<ol0oonh0?oo
nfX05OoonfX:o`3oh@Gooo]Z2OooG00=o`32o`Gooo]Z0olco`0=o`32o`?o0?lX2ooonfXJo`1Vo`_o
oo]Z1_l0obP:o`3oQ@03oookJ_o[o`3ojol000Sojol05_oonfX4o`3oQ@[o0?oQ5?oonfX3oonh0003
o`3ohOl0`_oo0<;o00So0<;o0_oonfX9ohoo00Gooo]Z00?o0<;oo`1Vool0I_l01ol0I_l;oookJPWo
06Ko00?ooo]Zoc?o0?lco`001_lco`02oookJPSojol02_oonfX7o`3o:0Sooo]Z0_n?o`07o`3oQ@Co
oo]Z1ol0on42oc?o00Ko0<;o1_l0I_l00ol0obSo0?n5o`3oQ@02o`3oQ@Co0?oQ0_l0`_l6o`1Voa_o
oo]Z000FoookJPCo0<;o1_l0I_l5o`3oh@;o<ol00ooonfX2o`3o:0Go06Ko2?oonfX7o`3oh@Kooo]Z
0on?o`06o`32o`Kooo]Z2?l0obP6oookJPSo0<;o1?l0ohD:oookJPSo06Ko3_oonfX8o`1Vo`Co0?n5
0_oonfX9ohoo00;ooo]Z2Ol0on400olco`3ookP0oookJP0HoookJPWo0?oQ1OoonfX7oomL00co0<;o
2?oonfX4oc?o00co0<;o00?o0?lXoookJ_oonfX02OoonfXMo`1Vo`[ooo]Z0ol0obP:o`3oQ@03oook
J_o[o`3ojol000Wojol06OoonfX00ol0ohGo0?oQo`3oh@08o`3ohAKooo]Z0_oo^009o`32o`?ooo]Z
2On?o`06oookJPWo06Ko00?o0<;ooookJ_oonfX02_oonfX8o`1Vo`So<ol01?oonfX8on_o00Sooo]Z
1ol0obP:oookJP03ohoo0?l0ohGo0?n500Co0?n51OoonfX6o`3oh@;o<ol01ol0`_l6o`1Vo`03o`3o
:?l0ohGo0?n500?o0?n50ol0on43o`32o`Go06Ko6ooonfX001Kooo]Z1?l0`_l6o`1Vo`Go0?oQ0_lc
o`03oookJP;o0?lX1_l0I_l8oookJPKo0?oQ00?ojol0oookJ_oonfX00_oonfX3ohoo00Oo0<;o1ooo
nfX7o`3o:0Oooo]Z1ol0`_l4o`3oQ@Wooo]Z2?l0I_l?oookJPSo06Ko1Ol0ohD2oookJPSoSol000?o
oo]Zo`3ohOl0on401ol0on400olco`3ooo]ZoookJP0JoookJPSo0?oQ1ooonfX4oomL00[o0<;o3Ooo
nfX4oc?o00_o0<;o2_oonfX>o`1Vo`?o00003_l0I_l;oookJP[o0?n500?ooo]Zon_o0?o[o`002?o[
o`0KoookJPWo0?oQ00?o0?n5oookJ_oonfX05ooonfX8o`32o`;o0?oQ0_oonfX8ohoo00Oooo]Z2?l0
I_l2o`32o`gooo]Z2?l0I_l7oc?o00Gooo]Z2?o[o`07oookJPOo0?lX2_oonfX7o`3oQ@Gooo]Z1_l0
on42oc?o00Ko0<;o00?ooo]Zo`1Vool0I_l01?l0I_l00ol0obSo0?n5o`3oQ@03o`3oQ@?o0?oQ0ol0
`_l5o`1Voa_ooo]Z000FoookJPCo0<;o1_l0I_l5o`3oh@?o<ol00_oonfX2o`3o:0Ko06Ko2?oonfX7
o`3oh@Cooo]Z0on?o`07o`32o`Oooo]Z2?l0obP6oookJPSo0<;o0_l0ohD:oookJPSo06Ko4?oonfX8
o`1Vo`Go0?n50_oonfX7ohoo00Wo0?oQ00?o<ol0oookJ_oonfX07?oonfX8o`3oh@Oooo]Z0_ooG00:
o`32o`03oomL0?oonf[ooo]Z00cooo]Z0olco`02o`3o:0[o0<;o2?oonfX<o`1Vo`;ooo]Z1Ol00004
oookJP[o06Ko2OoonfX:o`3oQ@03o`3o:?o[o`3ojol000Sojol07?oonfX8o`3oh@?o0?n55ooonfX8
o`32o`Co0?oQ2?n?o`07oookJPSo06Ko1?l0`_l=oookJPSo06Ko1Olco`07oookJPOojol01_oonfX7
o`3o:0_ooo]Z1_l0ohD2ohoo00?ooo]Z1ol0on42oc?o00Ko0<;o1_l0I_l2o`3o:0Go0?n50ol0on43
o`32o`Go06Ko6ooonfX001Kooo]Z1?l0`_l6o`1Vo`Go0?oQ0olco`001?oonf[o0?lXo`3o:?l0obP6
o`1Vo`Wooo]Z1_l0on400oo[o`3ooo]ZoookJP03ohoo00Oo0<;o2OoonfX7o`3o:0Oooo]Z1ol0`_l0
0ol0ohGooo]ZoookJP08oookJPSo06Ko4_oonfX8o`1Vo`Co0?n50ooonfX5ohoo00Wo0?oQ00?o<ol0
oookJ_oonfX07_oonfX8o`3oh@Oooo]Z2Ol0`_l4oomL00kooo]Z00?o<ol0o`3o:?l0obP00_l0obP:
o`32o`Kooo]Z2_l0I_l5oookJPGo00001OoonfX:o`1Vo`Oooo]Z2_l0ohD3o`3o:0Sojol07?oonfX8
o`3oh@Go0?n55OoonfX8o`32o`Ko0?oQ1_n?o`07oookJPSo06Ko1_l0`_l=oookJPSo06Ko0olco`08
oookJPSojol01OoonfX7o`3o:0_ooo]Z1_l0ohD2ohoo00?ooo]Z1_l0on42oookJP03oc?o0?l0`_oo
0<;o00Co0<;o1_l0I_l3o`3o:0Co0?n51?l0on42o`32o`Ko06Ko6_oonfX001Kooo]Z1?l0`_l5o`1V
o`Go0?oQ1?lco`001?oonf[o0?lXo`3o:?l0obP6o`1Vo`Wooo]Z1_l0on400oo[o`3ooo]ZoookJP03
ohoo00Oo0<;o2_oonfX7o`3o:0Kooo]Z00?o0?n5o`32ool0`_l01Ol0`_l9oookJPSo06Ko5?oonfX8
o`1Vo`Co0?n50ooonfX3ohoo00Wo0?oQ00?o<ol0oookJ_oonfX08?oonfX8o`3oh@Gooo]Z2Ol0`_l7
oomL00cooo]Z1ol0obP9o`32o`Cooo]Z2Ol0I_l7oookJPGo00001_oonfX:o`1Vo`Gooo]Z2_l0ohD5
o`3o:0Kojol07?oonfX8o`3oh@Oo0?n54ooonfX8o`32o`So0?oQ1?n?o`07oookJPSo06Ko2?l0`_l<
oookJPSo06Ko0_lco`0:oookJPSojol00ooonfX7o`3o:0_ooo]Z1ol0ohD3ohoo00;ooo]Z1_l0on42
oookJPKo0<;o00?o<ol0o`1Vool0I_l01?l0I_l3o`3o:0Co0?n51?l0on42o`32o`Ko06Ko6_oonfX0
01Kooo]Z1?l0`_l5o`1Vo`Go0?oQ1?lco`000ooonf[o0?lXo`3o:002o`3o:0Go06Ko2OoonfX7o`3o
h@04oookJ_n?o`3oSol0ohoo00Oo0<;o2ooonfX7o`3o:0Gooo]Z0_l0ohD8o`32o`Sooo]Z1ol0I_lE
oookJPSo06Ko1Ol0ohD2oookJP?oSol02?l0on400olco`3ooo]ZoookJP0QoookJPWo0?oQ0ooonfX9
o`32o`[ooe`02OoonfX9o`3o:0Wo0<;o0_oonfX9o`1Vo`Sooo]Z1Ol00008oookJPWo06Ko0ooonfX9
o`3oQ@So0?lX0oo[o`0MoookJPSo0?oQ2Ol0ohDBoookJPSo0<;o2Ol0on43ohoo00Kooo]Z2Ol0I_l8
o`32o`gooo]Z2?l0I_l00olco`3ooo]ZoookJP09oookJPOojol00ooonfX7o`3o:0_ooo]Z1_l0ohD4
ohoo0003oookJ_l0on7o0?oQ00Go0?oQ0_oonfX6o`32o`03oc?o0?l0I_oo06Ko00Co06Ko0ol0obP4
o`3oQ@Co0?oQ0_l0`_l6o`1Voa[ooo]Z000FoookJPCo0<;o1Ol0I_l5o`3oh@Co<ol000?ooo]Zo`3o
:?l0obP00_l0obP6o`1Vo`Wooo]Z1_l0on401?o[o`3oSol0ohoo0?n?o`07o`32o`cooo]Z1ol0obP4
oookJP?o0?n51ol0`_l7oookJPSo06Ko5_oonfX8o`1Vo`Go0?n500?ooo]Zoonh0?n?o`002?l0on40
0olco`3ooo]ZoookJP0SoookJPWo0?oQ00?ooo]Zo`32ool0`_l01ol0`_l<oomL00Oooo]Z2Ol0obP2
oc?o00Wo0<;o2Ol0I_l9oookJPGo00002OoonfX9o`1Vo`;ooo]Z2?l0ohD00ooonf[o0?lXo`3o:007
o`3o:003on_o0?oonf[ooo]Z01_ooo]Z2Ol0on400ooonf[o0?n5o`3oQ@07o`3oQA3ooo]Z2?l0`_l2
oookJPSo0?oQ0_n?o`06oookJPWo06Ko0_oonfX8o`32o`cooo]Z00?o<ol0o`1Vool0I_l01Ol0I_l<
oookJPSojol000?ooo]Zo`3o:?l0obP01Ol0obP;oookJPOo0?n51On?o`06o`3oh@?ooo]Z1_l0`_l6
o`1Vo`Co0?lX1Ol0ohD3o`3oh@;o0<;o1_l0I_lJoookJP005_oonfX3o`32o`Ko06Ko1Ol0on44oc?o
00Go0?lX1_l0I_l9oookJPKo0?oQ0on?o`07o`32o`gooo]Z1ol0obP3oookJPCo0?n52?l0`_l6oook
JPOo06Ko6?oonfX8o`1Vo`Co0?n50_oo^008o`3oh@03oc?o0?n?o`3ooo]Z02Gooo]Z2?l0on49o`32
o`?ooo]Z3?ooG004oookJPWo0?lX1?lco`07o`32o`Wo06Ko2_oonfX5o`0000[ooo]Z2Ol0I_l8o`3o
Q@03oookJ_o[o`3ojol000Wo0?lX7?oonfX9o`3oh@?ooo]Z2?l0ohD?oookJPSo0<;o0ooonfX00on?
o`3o0?oQo`3oh@06o`3oh@?ookP00ooonfX9o`1Vo`Cooo]Z2?l0`_l;oookJP;o<ol01ol0I_l<oook
JPSojol01ol0obP;oookJPOo0?n51On?o`06o`3oh@?ooo]Z1_l0`_l6o`1Vo`Go0?lX1?l0ohD3o`3o
h@?o0<;o1Ol0I_lJoookJP005_oonfX3o`32o`Ko06Ko1Ol0on44oc?o00Go0?lX1_l0I_l9oookJPOo
0?oQ0_n?o`07o`32o`kooo]Z1ol0obP2oookJPGo0?n51ol0`_l5oookJPOo06Ko6_oonfX7o`1Vo`Go
0?n52?l0on401?lco`3oSol0ohoo0?n?o`0VoookJPKo0?oQ2Ol0`_l5oookJPgooe`000?ooo]Zo`3o
:?l0obP01ol0obP6oc?o00Ko0<;o2?l0I_l;oookJPGo00002ooonfX9o`1Vo`Ko0?n500?ooo]Zon_o
0?o[o`000_o[o`09o`3o:1_ooo]Z2?l0on45oookJPSo0?n53OoonfX8o`32o`?ooo]Z0on?o`08o`3o
h@?ookP00_oonfX8o`1Vo`Kooo]Z1ol0`_l:oookJP?o<ol01ol0I_l=oookJPKojol01ol0obP<oook
JPKo0?n51On?o`07o`3oh@?ooo]Z1Ol0`_l00olco`3o06Koo`1Vo`04o`1Vo`Go0?lX1?l0ohD3o`3o
h@?o0<;o1Ol0I_lJoookJP005_oonfX3o`32o`Ko06Ko1?l0on45oc?o00Go0?lX1_l0I_l:oookJPKo
0?oQ0_n?o`06o`32o`oooo]Z1ol0obP00ooonf[o0?n5o`3oQ@05o`3oQ@Oo0<;o0ooonfX8o`1Voa[o
oo]Z2?l0I_l4o`3oQ@So0?oQ1?n?o`0WoookJPGo0?oQ2?l0`_l8oookJP_ooe`02Ol0obP2oookJPKo
<ol01?l0`_l8o`1Vo`cooo]Z1Ol0000<oookJPSo06Ko1Ol0ohD7on_o00Wo0?lX6OoonfX8o`3oh@Oo
oo]Z2?l0ohD<oookJPSo0<;o0_oonfX5ohoo00Oo0?oQ1?oo^008o`1Vo`Oooo]Z2?l0`_l8oookJPGo
<ol01ol0I_l<oookJPKojol01ol0obP;oookJPOo0?n51On?o`06o`3oh@?ooo]Z1_l0`_l00olco`3o
06Koo`1Vo`04o`1Vo`Go0?lX1?l0ohD3o`3oh@?o0<;o1Ol0I_lJoookJP005_oonfX3o`32o`Ko06Ko
1?l0on45oc?o00Ko0?lX1Ol0I_l:oookJPKo0?oQ00?oSol0o`32ool0`_l01Ol0`_l@oookJPOo0?lX
1ol0ohD7o`32o`?ooo]Z1ol0I_lLoookJPSo06Ko0_l0ohD8o`3oh@03oc?o0?n?o`3oSol000?oSol0
9ooonfX3o`3oh@So0<;o2ooonfX8oomL00Wo0?lX1?oonfX6oc?o00;o0<;o2?l0I_l=oookJPGo0000
3OoonfX8o`1Vo`Co0?n52?o[o`09o`3o:1Oooo]Z2?l0on49oookJPSo0?n52_oonfX8o`32o`;ooo]Z
1_n?o`08o`3oh@?ookP01ol0I_l9oookJPOo0<;o2?oonfX5oc?o00Oo06Ko3OoonfX4on_o00Oo0?lX
3?oonfX6o`3oQ@;ooo]Z1?n?o`06o`3oh@?ooo]Z1_l0`_l00olco`3o06Koo`1Vo`03o`1Vo`03oook
J_l0obSo0?lX00?o0?lX1?l0ohD4o`3oh@;o0<;o1Ol0I_lJoookJP005ooonfX2o`32o`Go06Ko1Ol0
on45oc?o00Go0?lX00?ooo]Zo`1Vool0I_l01?l0I_l9oookJPOo0?oQ1_l0`_lAoookJPKo0?lX1ol0
ohD2oookJPOo0<;o00?ooo]Zo`1Vool0I_l01_l0I_lMoookJPOo06Ko00?o0?n5o`3ohOl0on401_l0
on400olco`3oSol0ohoo0005ohoo02Kooo]Z0_l0on48o`32o`gooo]Z1_ooG009o`3o:0Kooo]Z1_lc
o`08o`1Vo`kooo]Z1Ol0000>oookJPSo06Ko0_l0ohD9on_o0003oookJ_l0obSo0?lX00Oo0?lX5Ooo
nfX8o`3oh@[ooo]Z2?l0ohD9oookJPSo0<;o0_oonfX8ohoo00So0?oQ00?ookP0o`1Vool0I_l01Ol0
I_l;oookJPOo0<;o1_oonfX7oc?o00Oo06Ko3OoonfX3on_o00Oo0?lX2ooonfX7o`3oQ@;ooo]Z0on?
o`07o`3oh@?ooo]Z1_l0`_l6o`1Vo`03oookJ_l0obSo0?lX00?o0?lX1?l0ohD4o`3oh@;o0<;o1Ol0
I_lJoookJP005ooonfX2o`32o`Go06Ko1Ol0on401?oonf[o<ol0oc?o0?lco`06o`3o:003oookJ_l0
I_oo06Ko00Co06Ko2_oonfX6o`3oh@Ko0<;o4_oonfX5o`3o:0Oo0?n50_oonfX7o`32o`03oookJ_l0
I_oo06Ko00Go06Ko7_oonfX8o`1Vo`Oo0?oQ00?o<ol0oookJ_n?o`001on?o`0VoookJPSo0<;o00?o
0?oQoookJ_oonfX03OoonfX3oomL00Wo0?lX2?oonfX4oc?o00Wo06Ko00?o0<;ooookJ_oonfX02ooo
nfX5o`0000oooo]Z2?l0I_l9on_o00?ooo]Z2Ol0obPCoookJPWo0?oQ2ooonfX8o`3oQ@Oooo]Z2?l0
`_l2oookJPWoSol000?ooo]Zo`3ohOl0on401_l0on47o`1Vo`_ooo]Z2?l0`_l4oookJPSo<ol01ol0
I_l=oookJP;ojol01ol0obP<oookJPOo0?n50_oonfX3ohoo00Ko0?oQ1?oonfX6o`32o`Ko06Ko00?o
oo]Zo`3o:?l0obP01?l0obP4o`3oQ@?o0?oQ0_l0`_l5o`1Voa[ooo]Z000GoookJP;o0<;o1Ol0I_l5
o`3oh@04oookJ_lco`3o<ol0oc?o00Ko0?lX00?ooo]Zo`1Vool0I_l01?l0I_l:oookJPGo0?oQ1ol0
`_lBoookJPCo0?lX1ol0ohD4oookJPKo0<;o1ol0I_lPoookJPOo06Ko1ol0on42oookJPWoSol09Ooo
nfX8o`32o`03o`3ohOoonf[ooo]Z00oooo]Z2Ol0obP3oomL00Oooo]Z0_lco`09o`1Vo`;o0<;o3Ooo
nfX5o`0000kooo]Z00?o0?n5o`1Vool0I_l01ol0I_l7on_o00Gooo]Z2?l0obPBoookJPWo0?oQ3Ooo
nfX8o`3oQ@Kooo]Z2?l0`_l2oookJPSoSol00_oonfX7o`3oh@Oo06Ko3OoonfX7o`32o`Cooo]Z1olc
o`02oookJPOo06Ko3OoonfX00oo[o`3o0?lXo`3o:005o`3o:0cooo]Z1_l0ohD4oookJP;oSol01_l0
on43oookJPKo0<;o00?o<ol0o`1Vool0I_l01?l0I_l00ooonf[o0?lXo`3o:004o`3o:0Co0?n50ol0
on42o`32o`Go06Ko6_oonfX001Oooo]Z0_l0`_l5o`1Vo`Go0?oQ00Cooo]Zoc?o0?lco`3o<ol01_l0
obP00ooonf[o06Koo`1Vo`04o`1Vo`[ooo]Z1Ol0on46o`32oaCooo]Z0ol0obP7o`3oQ@Cooo]Z1Ol0
`_l8o`1Vob3ooo]Z00?ookP0o`1Vool0I_l01Ol0I_l5o`3oh@Cooo]Z2On?o`0SoookJPSo0<;o0ol0
on4?oookJPWo0?lX1OooG007oookJPWo06Ko1?l0`_l<oookJPGo00003OoonfX3o`3oQ@Wo06Ko1?o[
o`08oookJPSo0?lX4OoonfX8o`3oh@oooo]Z1ol0ohD5oookJPSo0<;o0_oonfX8ohoo00Cooo]Z1_l0
on47o`1Vo`03oonh0?oonf[ooo]Z00[ooo]Z2?l0`_l2oookJPSo<ol00_oonfX7o`1Vo`gooo]Z1ol0
obP00oo[o`3ooo]ZoookJP09oookJPOo0?n51?oonfX2ohoo00Ko0?oQ0ooonfX6o`32o`03oc?o0?l0
I_oo06Ko00Co06Ko0_oonfX5o`3o:0Co0?n50ol0on42o`32o`Go06Ko6_oonfX001Oooo]Z0_l0`_l5
o`1Vo`Co0?oQ0_oonfX3oc?o00Ko0?lX0_oonfX5o`1Vo`[ooo]Z00?oSol0o`3ohOl0on400_l0on46
o`32oaCooo]Z0_l0obP7o`3oQ@Kooo]Z1?l0`_l7o`1Vob3ooo]Z0_oo^008o`1Vo`?o0?oQ0_l0ohD4
oookJPWoSol08OoonfX8o`32o`Go0?oQ3OoonfX9o`3o:0Sooe`01?oonfX9o`1Vo`Ko0<;o2ooonfX5
o`0000cooo]Z1Ol0ohD8o`1Vo`?ojol02_oonfX8o`3o:0oooo]Z2?l0on4@oookJPSo0?n50ooonfX8
o`32o`;ooo]Z2?n?o`06oookJPCo0?oQ1ol0I_l3oonh00cooo]Z1ol0`_l00ooonf[o<ol0oc?o0006
oc?o00Cooo]Z1ol0I_l<oookJPOo0?lX0_o[o`0:oookJPKo0?n51_oonfX6o`3oh@04ohoo0?oonf[o
oo]ZoookJPKo0<;o00?o<ol0o`1Vool0I_l00ol0I_l3oookJPGo0?lX1?l0ohD3o`3oh@;o0<;o1Ol0
I_lJoookJP005ooonfX2o`32o`Go06Ko1?l0on42oookJP?o<ol01Ol0obP3oookJPKo06Ko2OoonfX0
0on?o`3o0?oQo`3oh@02o`3oh@Ko0<;o5OoonfX00ol0obSo0?n5o`3oQ@05o`3oQ@Kooo]Z0ol0`_l8
o`1Voaoooo]Z1?oo^007o`1Vo`;o0?oQ1?l0ohD4oookJPWoSol08?oonfX7o`32o`Ko0?oQ3OoonfX8
o`3o:0[ooe`00ooonfX8o`1Vo`So0<;o2_oonfX5o`0000_ooo]Z1ol0ohD8o`1Vo`03on_o0?oonf[o
oo]Z00[ooo]Z2?l0obP=oookJPSo0?oQ4_oonfX8o`3oQ@;ooo]Z1ol0`_l2oookJPSoSol02?oonfX3
o`3oh@Oo06Ko1?oo^00<oookJPOo0<;o1olco`05oookJPOo06Ko2ooonfX7o`3o:0Cojol02?oonfX7
o`3oQ@Kooo]Z1_l0on401?n?o`3ooo]ZoookJ_oonfX6o`32o`Ko06Ko0ooonfX5o`3o:0Co0?n50ol0
on42o`32o`Ko06Ko6OoonfX001Oooo]Z0_l0`_l5o`1Vo`Co0?oQ0_oonfX2oc?o00Ko0?lX0ooonfX6
o`1Vo`Sooo]Z0_n?o`03o`3oh@Ko0<;o5_oonfX7o`3oQ@03o`3o:?oonf[ooo]Z00Gooo]Z0_l0`_l7
o`1Voaoooo]Z1Ooo^008o`1Vo`03o`3ohOl0ohGo0?n500;o0?n51OoonfX9ohoo01kooo]Z2?l0`_l7
o`3oh@_ooo]Z2?l0obP00ooonf[ooe`0oomL000:oomL00So06Ko00?o<ol0o`32ool0`_l01_l0`_l:
oookJPGo00002ooonfX8o`3oQ@So06Ko3?oonfX9o`3o:0_ooo]Z2?l0on4DoookJPSo0?n52?l0`_l0
0ooonf[oSol0ohoo0007ohoo00Sooo]Z0_l0on47o`1Vo`GookP03?oonfX7o`32o`Oo<ol01_oonfX7
o`1Vo`[ooo]Z1ol0obP5on_o00Oooo]Z1ol0ohD6oookJPKo0?oQ0_n?o`000ooonf[o0<;oo`32o`04
o`32o`03oookJ_l0I_oo06Ko00Co06Ko00?o<ol0oookJ_oonfX01_l0obP3o`3oQ@?o0?oQ0_l0`_l6
o`1VoaWooo]Z000GoookJP;o0<;o1Ol0I_l4o`3oh@?ooo]Z00?o<ol0o`3o:?l0obP01?l0obP3oook
JPKo06Ko2?oonfX3ohoo00;o0?oQ1_l0`_l00oo[o`3ooo]ZoookJP0CoookJPOo0?n500?o0?lXoook
J_oonfX01OoonfX00ol0`_oo06Koo`1Vo`05o`1Voaoooo]Z1_oo^0000olco`3o06Koo`1Vo`06o`1V
o`Go0?n51OoonfX8ohoo01gooo]Z2?l0`_l00ooonf[o0?oQo`3oh@06o`3oh@Wooo]Z2?l0obP4oook
JPWooe`02?l0I_l3oc?o00So0<;o2OoonfX5o`0000[ooo]Z2?l0ohD2on_o00Oo06Ko3OoonfX8o`3o
:0_ooo]Z2?l0on4DoookJPOo0?n52?l0`_l00ooonf[oSol0ohoo0007ohoo00Wooo]Z00?o001oo`3o
hOl0I_l01_l0I_l6oonh00Go001o1ooonfX7o`32o`Go<ol01ooonfX7o`1Vo`Wooo]Z1ol0obP6on_o
00Oooo]Z1_l0ohD6oookJPOo0?oQ0_n?o`000ooonf[o0<;oo`32o`04o`32o`03oookJ_l0I_oo06Ko
00Co06Ko00?o<ol0oookJ_oonfX01_l0obP3o`3oQ@?o0?oQ0_l0`_l6o`1Vo`Cooo]Z0ol007lBoook
JP005ooonfX00ol0`_oo06Koo`1Vo`04o`1Vo`Co0?oQ0ooonfX00olco`3o0?lXo`3o:004o`3o:0?o
oo]Z1_l0I_l8oookJP?oSol00_l0on46o`32o`03on_o0?oonf[ooo]Z01?ooo]Z1_l0ohD3o`3o:0Oo
oo]Z1ol0I_lNoookJPKookP000?o<ol0o`3ohOl0on401ol0I_l6o`3oQ@Gooo]Z2?n?o`0KoookJPSo
0<;o0ooonfX7o`3oh@Sooo]Z2?l0obP6oookJPOooe`02?l0I_l5oc?o00So0<;o2?oonfX5o`0000Wo
oo]Z2?l0ohD3on_o00So06Ko3OoonfX8o`3o:0Wooo]Z2?l0on4FoookJPKo0?n51ol0`_l00ooonf[o
Sol0ohoo0007ohoo00Wooo]Z0_l007l7o`1Vo`;o0?oQ1_oo^005o`00O`Kooo]Z2?l0`_l3oc?o00Wo
oo]Z1ol0I_l8oookJPOo0?lX1oo[o`05oookJPOo0?n51_oonfX6o`3oh@?oSol000?ooo]Zo`32ool0
`_l01?l0`_l00ooonf[o06Koo`1Vo`04o`1Vo`04oc?o0?oonf[ooo]ZoookJPGo0?lX1?l0ohD3o`3o
h@03o`32ool0I_oo06Ko00Co06Ko1?oonfX3o`00Oa;ooo]Z000GoookJP03o`32ool0I_oo06Ko00Co
06Ko1?l0on43oookJP03oc?o0?l0obSo0?lX00Co0?lX1?oonfX5o`1Vo`Oooo]Z1?n?o`000ol0on7o
0<;oo`32o`05o`32o`;ojol04ooonfX7o`3oQ@?o0?lX1ooonfX6o`1Vo`03o`32oooonf[ooo]Z01_o
oo]Z1_oo^0001?lco`3o0?oQo`3ohOl0on48o`1Vo`Go0?n51_oonfX8ohoo01[ooo]Z2?l0`_l3oook
JPSo0?oQ1ooonfX8o`3o:0Sooo]Z1OooG008o`1Vo`03oookJ_lco`3o<ol000?o<ol02?l0`_l7oook
JPGo00002?oonfX8o`3oQ@Gojol02?l0I_l=oookJPSo0?lX1ooonfX8o`3ohASooo]Z1?l0ohD8o`32
o`WoSol02_oonfX2o`00O`Oo06Ko0_l0on47oonh0004oookJ_l007oo001oo`00O`Oooo]Z1ol0`_l3
oc?o00Wooo]Z1ol0I_l7oookJPOo0?lX00?ooo]Zon_o0?o[o`001_o[o`04oookJPKo0?n51ooonfX6
o`3oh@CoSol01_l0`_l6o`1Vo`?o<ol00_oonfX5o`3o:0Co0?n50ol0on42o`32o`Go06Ko1?oonfX3
o`00Oa;ooo]Z0007oookJP[o001o1_oonfX00ol0`_oo06Koo`1Vo`04o`1Vo`Co0?oQ0ooonfX6o`3o
:0Gooo]Z1_l0I_l6oookJPGoSol01_l0`_l3on_o01?ooo]Z1_l0ohD5o`3o:0Gooo]Z1ol0I_l00ol0
`_oooo]ZoookJP0?oookJP[o001o00?ooo]Zoonh0?oo^0001Ooo^0000olco`3o0?oQo`3oh@02o`3o
h@So06Ko1Ol0ohD6oookJPSoSol06?oonfX8o`32o`Gooo]Z2?l0on45oookJPSo0?lX2_oonfX3oomL
00So06Ko00?ooe`0oookJ_oonfX01?lco`09o`32o`Kooo]Z1Ol00008oookJPSo0?n51Oo[o`000ooo
nf[o06Koo`1Vo`05o`1Vo`kooo]Z2?l0obP5oookJPSo0?oQ6_oonfX2o`3oQ@So0<;o2On?o`0:oook
JP;o001o1ol0I_l4o`3oh@OookP000Cooo]Zo`00Ool007oo001o1_oonfX8o`32o`03oc?o0?oonf[o
oo]Z00Wooo]Z1_l0I_l6oookJPSo0?lX0_oonfX7on_o00?ooo]Z1ol0ohD6oookJPOo0?oQ1?n?o`05
o`32o`03oookJ_l0I_oo06Ko00Co06Ko0olco`02oookJPGo0?lX1?l0ohD3o`3oh@;o0<;o1Ol0I_l4
oookJP?o001o4_oonfX000Oooo]Z2_l007l6oookJP03o`32ool0I_oo06Ko00Co06Ko1?l0on43oook
JPKo0?lX1OoonfX6o`1Vo`Kooo]Z1On?o`06o`32o`Cojol04OoonfX7o`3oQ@Go0?lX1OoonfX6o`1V
o`?o0<;o4?oonfX:o`00O`OookP000?o<ol0o`3ohOl0on401?l0on47o`1Vo`Ko0?n51OoonfX9ohoo
01Kooo]Z2?l0`_l7oookJPSo0?oQ0ooonfX8o`3o:0gooo]Z2?l0I_l4oomL0003oookJ_lco`3o<ol0
00;o<ol02?l0`_l6oookJPGo00001ooonfX8o`3oQ@Gojol00_oonfX8o`1Vo`gooo]Z2Ol0obP4oook
JPSo0?oQ6_oonfX2o`3oQ@Oo0<;o00?ooo]Zohoo0?n?o`001_n?o`0;oookJP;o001o1ol0I_l5o`3o
h@OookP00ol007l7oookJPOo0<;o3?oonfX7o`1Vo`Gooo]Z1ol0obP3oookJPSojol00_oonfX7o`3o
Q@Kooo]Z1_l0on44ohoo00Ko0<;o00?ooo]Zo`1Vool0I_l01?l0I_l3oc?o00;ooo]Z1_l0obP3o`3o
Q@?o0?oQ0_l0`_l5o`1Vo`Cooo]Z0ol007lBoookJP005ooonfX00ol0`_oo06Koo`1Vo`03o`1Vo`Go
0?oQ0ooonfX6o`3o:0Gooo]Z1_l0I_l5oookJPGoSol01ol0`_l4on_o017ooo]Z1ol0ohD6o`3o:0?o
oo]Z1ol0I_l3o`32oaWooo]Z1ooo^002oc?o00Ko0?oQ2?l0I_l5o`3oQ@Kooo]Z2On?o`0EoookJPOo
0<;o2?oonfX8o`3oh@;ooo]Z2?l0obP=oookJPSo06Ko1_ooG0000ooonf[o<ol0oc?o0002oc?o00So
0<;o1OoonfX5o`0000Kooo]Z2?l0ohD5on_o00Cooo]Z2?l0I_l=oookJPWo0?lX0_oonfX8o`3ohAco
oo]Z2?l0`_l8ohoo00cooo]Z00?o001oo`1Vool0I_l01Ol0I_l6o`3oh@SookP00_l007l6oookJP;o
<ol01ol0`_l<oookJPKo06Ko1?oonfX8o`3o:0Cooo]Z2?o[o`000ooonf[o0?n5o`3oQ@04o`3oQ@Oo
oo]Z1_l0on44ohoo00Ko0<;o00?ooo]Zo`1Vool0I_l01?l0I_l3oc?o00?ooo]Z1Ol0obP3o`3oQ@?o
0?oQ0_l0`_l5o`1Vo`Cooo]Z0ol007lBoookJP005ooonfX00ol0`_oo06Koo`1Vo`03o`1Vo`Co0?oQ
1?oonfX6o`3o:0Gooo]Z1_l0I_l5oookJPGoSol01_l0`_l2o`3oh@Cojol04?oonfX6o`3oQ@Oo0?lX
0ooonfX7o`1Vo`Co0<;o5ooonfX8oonh0003oc?o0?l0on7o0?oQ00Go0?oQ00?ooo]Zo`1Vool0I_l0
1Ol0I_l6o`3oQ@Kooo]Z2On?o`0CoookJPSo0<;o2OoonfX8o`3oh@03oookJ_l0obSo0?lX00Ko0?lX
3OoonfX8o`1Vo`Sooe`01?lco`08o`32o`Cooo]Z1Ol00005oookJPSo0?n51Oo[o`06oookJPOo06Ko
3_oonfX8o`3o:003oookJ_l0on7o0?oQ00Ko0?oQ7OoonfX7o`32o`;o0?n51_n?o`0=oookJPSo06Ko
1ol0on48oonh0003o`00Oooonf[ooo]Z00?ooo]Z0olco`07o`32o`cooo]Z1ol0I_l3oookJPOo0?lX
1_oonfX7on_o00Oo0?n51ooonfX6o`3oh@CoSol01_l0`_l00ooonf[o06Koo`1Vo`03o`1Vo`Go<ol0
0_oonfX5o`3o:0?o0?n50ol0on42o`32o`Go06Ko1?oonfX3o`00Oa;ooo]Z000GoookJP03o`00Ool0
I_oo06Ko00?o06Ko1?l0on44oookJPGo0?lX0_lco`05oookJPGo06Ko1?oonfX6ohoo00Ko0<;o0_l0
on44on_o00oooo]Z1ol0ohD00ooonf[o0?lXo`3o:005o`3o:003oookJ_l0I_oo06Ko00Go06Ko1Ol0
`_lFoookJPSookP00_lco`07o`3oh@;ooo]Z1ol0I_l6o`3oQ@Kooo]Z2?n?o`0BoookJPSo0<;o2ooo
nfX8o`3oh@Oo0?lX3OoonfX8o`1Vo`[ooe`01?lco`07o`32o`Cooo]Z1Ol00004oookJPWo0?n51?o[
o`07oookJPSo06Ko3_oonfX8o`3o:0Oo0?oQ7OoonfX7o`32o`?o0?n51On?o`0>oookJPOo06Ko00?o
001oo`3ohOl0on401Ol0on49oonh00Gooo]Z1?lco`07o`32o`_ooo]Z1ol0I_l2oookJPOo0?lX1ooo
nfX7on_o00Ko0?n51ooonfX6o`3oh@03oookJ_n?o`3oSol000;oSol01_l0`_l6o`1Vo`Go<ol00_oo
nfX5o`3o:0?o0?n50ol0on42o`32o`Go06Ko1?oonfX3o`00Oa;ooo]Z000GoookJP03o`00Ool0I_oo
06Ko00?o06Ko1?l0on43oookJPKo0?lX0_lco`05oookJPKo06Ko0ooonfX6ohoo00Ko0<;o0_l0on45
on_o00kooo]Z1_l0ohD2oookJPSo0?lX1ol0I_l6o`32oaCooo]Z2?oo^002oc?o00Oo0?oQ0ooonfX8
o`1Vo`Go0?n51ooonfX8ohoo017ooo]Z1ol0`_l=oookJPOo0?oQ1_l0obP=oookJPSo06Ko00?ooo]Z
oomL0?ooG0002OooG003oc?o00So0<;o0ooonfX5o`0000Cooo]Z2?l0ohD4on_o00Wooo]Z2?l0I_l>
oookJPKo0?lX2?l0on4LoookJPSo0<;o1?l0ohD4ohoo00gooo]Z2?l0I_l2o`00O`Oo0?oQ2Ooo^003
oookJPGo<ol02?l0`_l;oookJPOo06Ko00?ooo]Zo`3o:?l0obP01Ol0obP8oookJPGojol01ol0ohD7
oookJPKo0?oQ0_oonfX2ohoo00Ko0<;o00?ooo]Zo`1Vool0I_l01?l0I_l5oc?o00;ooo]Z1Ol0obP4
o`3oQ@;o0?oQ0_l0`_l5o`1Vo`Cooo]Z0ol007lBoookJP005?oonfX4o`00O`Go06Ko1?l0on43oook
JPKo0?lX0_lco`05oookJPKo06Ko0ooonfX5ohoo00Ko0<;o1?l0on44on_o00gooo]Z1ol0ohD3oook
JPOo0?lX1_l0I_l7o`32oa?ooo]Z2Ooo^0000olco`3o0?oQo`3oh@06o`3oh@Cooo]Z1ol0I_l6o`3o
Q@Oooo]Z2?n?o`0?oookJPSo0<;o3OoonfX8o`3oh@Co0?lX3_oonfX7o`1Vo`Cooo]Z2_ooG003oc?o
00So0<;o0_oonfX5o`0000?ooo]Z2?l0ohD4on_o00_ooo]Z1ol0I_l?oookJPCo0?lX2?l0on4Moook
JPOo0<;o1_l0ohD2ohoo00kooo]Z1ol0I_l3o`00O`Oo0?oQ00?o001ooonh0?oo^0001ooo^0000ooo
nf[o<ol0oc?o0005oc?o00Oo0<;o2ooonfX7o`1Vo`Oo0?lX2_oonfX4on_o00Oo0?n51ooonfX6o`3o
h@;ooo]Z0_n?o`06o`32o`03oookJ_l0I_oo06Ko00Co06Ko1Olco`03oookJPCo0?lX1?l0ohD2o`3o
h@;o0<;o1Ol0I_l00ooonf[o001oo`00O`04o`00Oa;ooo]Z000DoookJPCo001o1Ol0I_l4o`3oh@?o
oo]Z1_l0obP2oc?o00Gooo]Z1_l0I_l2oookJPKoSol01_l0`_l4o`3oh@Gojol03?oonfX7o`3oQ@?o
oo]Z1_l0obP7o`1Vo`03oookJ_l0`_oo0<;o00Go0<;o4OoonfX9oonh00;o<ol01ol0on45oookJPSo
06Ko1_l0ohD7oookJPSoSol03_oonfX7o`32o`oooo]Z2?l0on43o`3o:0gooo]Z2?l0I_l5oookJP[o
oe`00olco`07o`32o`;ooo]Z1Ol00002oookJPSo0?n51?o[o`0<oookJPSo06Ko3_oonfX3o`3o:0So
0?oQ7OoonfX8o`32o`Ko0?n500?oSol0oookJ_oonfX03?oonfX7o`1Vo`?o001o0_oonfX7o`3oh@03
o`00Oooo^03ookP000OookP01olco`08o`32o`_ooo]Z1ol0I_l6o`3o:0[ooo]Z0oo[o`07o`3oQ@Oo
oo]Z1ol0on43oookJP03ohoo0?l0`_oo0<;o00Co0<;o00?ooo]Zo`1Vool0I_l01?l0I_l6oc?o00;o
oo]Z1Ol0obP3o`3oQ@;o0?oQ0_l0`_l5o`1Vo`03oookJ_l007oo001o00Co001o4_oonfX001Kooo]Z
0_l007l5o`1Vo`Co0?oQ0ooonfX6o`3o:0?o<ol01?oonfX6o`1Vo`;ooo]Z1_n?o`06o`32o`Co0?oQ
1Oo[o`0;oookJPOo0?n51OoonfX5o`3o:0Ko06Ko0_oonfX7o`32oa3ooo]Z2Ooo^002oc?o00So0?oQ
1_oonfX7o`1Vo`Oo0?n51_oonfX9ohoo00cooo]Z1ol0`_lAoookJPOo0?oQ0_l0obP>oookJPOo06Ko
2?oonfX9oomL00;o<ol02?l0`_l00ooonf[o0000o`000003o`000003oookJ_l0ohGo0?n500Ko0?n5
1?o[o`0>oookJPSo06Ko3_oonfX2o`3o:0So0?oQ7?oonfX8o`32o`So0?n53_oonfX7o`1Vo`?o001o
0_oonfX8o`3oh@03o`00Oooo^03ookP000GookP02?lco`000ooonf[o0<;oo`32o`05o`32o`_ooo]Z
1ol0I_l5o`3o:0cooo]Z0_o[o`07o`3oQ@Oooo]Z1_l0on44oookJPOo0<;o00?ooo]Zo`1Vool0I_l0
0ol0I_l00ooonf[o<ol0oc?o0004oc?o00;ooo]Z1Ol0obP3o`3oQ@;o0?oQ0_l0`_l5o`1Vo`?ooo]Z
1?l007lBoookJP005ooonfX00ol007oo06Koo`1Vo`03o`1Vo`Co0?oQ00?o0?n5oookJ_oonfX01Ol0
obP4oc?o00Gooo]Z1Ol0I_l2oookJPGoSol01ol0`_l5o`3oh@Gojol02_oonfX7o`3oQ@Kooo]Z0ol0
obP7o`1Vo`?ooo]Z1ol0`_l>oookJPWookP000?ooo]Zoc?o0?lco`001ol0on48oookJPOo06Ko1_l0
ohD7oookJPWoSol02_oonfX8o`32oa7ooo]Z2?l0on4>oookJPOo06Ko2ooonfX8oomL00;o<ol02?l0
`_l5o`000003oookJ_l0ohGo0?n500Ko0?n50oo[o`0@oookJPOo06Ko3ooonfX8o`3ohAgooo]Z1ol0
`_l2ohoo00So0?n53?oonfX7o`1Vo`?o001o1?oonfX7o`3oh@;o001o1Ooo^008oc?o00?ooo]Z1ol0
`_l;oookJPOo06Ko1?l0obP=oookJP03on_o0?l0ohGo0?n500Co0?n52?oonfX6o`3oh@Cooo]Z1_l0
`_l00on?o`3o06Koo`1Vo`04o`1Vo`03oookJ_lco`3o<ol000Co<ol00_oonfX5o`3o:0?o0?n50ol0
on400ol0`_oo06Koo`1Vo`03o`1Vo`Cooo]Z0ol007lBoookJP006?oonfX5o`1Vo`Co0?oQ00?o0?n5
oookJ_l0obP01Ol0obP4oc?o00Gooo]Z1_l0I_l6ohoo00Ko0<;o1_l0on45on_o00[ooo]Z1_l0ohD7
oookJP?o0?lX1ol0I_l3oookJPOo0<;o3OoonfX9oonh0003oookJ_lco`3o<ol000Oo0?oQ2OoonfX7
o`1Vo`Oo0?n51ooonfX8ohoo00[ooo]Z1ol0`_lAoookJP;o0?lX2?l0on4<oookJPSo06Ko3?oonfX7
oomL00?o<ol01ol0`_l5o`0000So0?n50oo[o`0AoookJPSo06Ko3OoonfX8o`3oh@;o0?lX6ooonfX8
o`32o`?oSol02?l0ohD;oookJPOo06Ko1ooonfX8o`3oh@;ooo]Z1?oo^007oc?o00Cooo]Z1ol0`_l;
oookJPOo06Ko0ol0obP>oookJPOo0?n500?ojol0oookJ_oonfX01?oonfX7o`3oh@Cooo]Z1_l0`_l0
0on?o`3o06Koo`1Vo`04o`1Vo`03oookJ_lco`3o<ol000Go<ol000?ooo]Zo`3o:?l0obP00ol0obP3
o`3oQ@?o0?oQ00?o0<;oo`1Vool0I_l01?l0I_lHoookJP006?oonfX5o`1Vo`Co0?oQ00?o0?n5oook
J_l0obP01Ol0obP4oc?o00Gooo]Z1_l0I_l6ohoo00Ko0<;o1_l0on46on_o00Sooo]Z1ol0ohD8oook
JP;o0?lX1_l0I_l5oookJPKo0<;o3?oonfX9oonh0004oookJ_lco`3o<ol0oc?o00Oo0?oQ2_oonfX7
o`1Vo`Oo0?n51ooonfX8ohoo00Sooo]Z2?l0`_l@oookJPCo0?lX1ol0on4<oookJPOo06Ko3ooonfX6
oomL00;o<ol02?l0`_l3o`0000So0?n50oo[o`0CoookJPSo06Ko3?oonfX7o`3oh@Co0?lX6OoonfX8
o`32o`CoSol02?l0ohD:oookJPOo06Ko2OoonfX7o`3oh@?ooo]Z0_oo^008oc?o00Gooo]Z1ol0`_l;
oookJPKo06Ko0ol0obP>oookJPKo0?n50oo[o`05oookJPKo0?oQ1?oonfX7o`32o`03ohoo0?l0I_oo
06Ko00Co06Ko0_oonfX6oc?o00;ooo]Z1?l0obP3o`3oQ@?o0?oQ00?o0<;oo`1Vool0I_l01?l0I_lH
oookJP006?oonfX5o`1Vo`06o`32ool0on7o0?oQo`3ohOl0ohGooo]Z1_l0obP5oc?o00Cooo]Z1_l0
I_l6ohoo00Ko0<;o1_l0on46on_o00Sooo]Z1_l0ohD9oookJP03o`3o:?l0I_oo06Ko00Go06Ko1Ooo
nfX7o`32o`[ooo]Z2Ooo^002oookJP;o<ol01ol0on4;oookJPOo06Ko1ol0ohD8oookJPSoSol01ooo
nfX7o`32oa7ooo]Z1?l0obP8o`3oh@[ooo]Z2?l0I_lAoookJPGooe`00_lco`08o`32o`03o`000?l0
ohGo0?n500Ko0?n50oo[o`0EoookJPOo06Ko2ooonfX8o`3oh@Go0?lX6?oonfX7o`32o`KoSol02?l0
ohD9oookJPOo06Ko2_oonfX7o`3oh@?ooo]Z2?lco`000ooo^03ooo]ZoookJP03oookJPOo0<;o2ooo
nfX7o`1Vo`03o`3o:?oonf[ooo]Z00cooo]Z1ol0ohD3on_o00Gooo]Z1_l0on44oookJPKo0<;o0_n?
o`06o`1Vo`;ooo]Z1_lco`02oookJPCo0?lX0ol0ohD3o`3oh@03o`32ool0I_oo06Ko00Co06Ko6?oo
nfX001Sooo]Z1Ol0I_l01_l0`_oo0?oQo`3ohOl0on7o0?n5oookJPKo0?lX1Olco`04oookJPKo06Ko
1On?o`06o`32o`;ooo]Z1_l0on46on_o00Kooo]Z1ol0ohD:oookJPKo06Ko00?o0?lXoookJ_oonfX0
1?oonfX6o`32o`Wooo]Z2Ooo^002oookJP;o<ol02?l0on4<oookJPOo06Ko1ol0ohD8oookJPSoSol0
1OoonfX7o`32oa7ooo]Z1_l0obP8o`3oh@Wooo]Z1ol0I_lCoookJPGooe`00_lco`07o`32o`03o`00
0?l0ohGo0?n500Ko0?n50_o[o`0FoookJPSo06Ko2OoonfX8o`3oh@Oo0?lX5_oonfX8o`32o`KoSol0
00?ooo]Zo`3oQOl0ohD01_l0ohD7oookJPOo06Ko2ooonfX7o`3oh@?ooo]Z1olco`03oonh00Gooo]Z
1ol0`_l;oookJPKo06Ko00?o0?lXoookJ_oonfX03?oonfX7o`3oQ@Cojol00ooonfX7o`3oh@Cooo]Z
1_l0`_l00on?o`3o06Koo`1Vo`04o`1Vo`?ooo]Z1_lco`02oookJPCo0?lX0ol0ohD3o`3oh@03o`32
ool0I_oo06Ko00Co06Ko6?oonfX001Oooo]Z1_l0I_l01_l0`_oo0?oQo`3ohOl0on7o0?n5oookJPGo
0?lX1_lco`05oookJPKo06Ko1?n?o`06o`32o`;ooo]Z1_l0on46on_o00Kooo]Z1ol0ohD9oookJPOo
06Ko00?o0?lXoookJ_oonfX01?oonfX7o`32o`Oooo]Z2Ooo^002oookJP?o<ol01ol0on4=oookJPOo
06Ko2?l0ohD7oookJPWoSol00ooonfX8o`32oa3ooo]Z2?l0obP7o`3oh@Sooo]Z1ol0I_lFoookJPCo
oe`000?o<ol0o`32ool0`_l01_l0`_l7o`3oQ@;ojol06?oonfX7o`1Vo`Sooo]Z2?l0on48o`3o:1Go
oo]Z2?l0`_l6ohoo00?ooo]Z1ol0ohD6oookJPSo06Ko3?oonfX7o`3oh@03oookJ_lco`3o<ol000Ko
<ol01?oo^004oookJPOo0<;o2_oonfX00ol0obSo06Koo`1Vo`05o`1Vo`kooo]Z1_l0ohD5on_o00?o
oo]Z1_l0on44oookJPOo0<;o00?oSol0o`1Vool0I_l01?l0I_l4oookJPKo<ol000?ooo]Zo`3o:?l0
obP00ol0obP3o`3oQ@;o0?oQ0_l0`_l5o`1VoaSooo]Z000GoookJPKo06Ko00Go0<;oo`3ohOl0on7o
0?oQo`3oQ@06o`3o:0Ko<ol01OoonfX6o`1Vo`CoSol01_l0`_l2oookJPKo0?oQ1oo[o`05oookJPKo
0?n52_oonfX7o`1Vo`;o0?lX1OoonfX7o`32o`Kooo]Z2Ooo^003oookJP;o<ol02?l0on4>oookJPOo
06Ko1ol0ohD8oookJPWoSol00_oonfX7o`32oa3ooo]Z2?l0obP00ooonf[o0?oQo`3oh@06o`3oh@Ko
oo]Z2?l0I_lHoookJP?ooe`000?o<ol0o`32ool0`_l01_l0`_l5o`3oQ@;ojol06_oonfX7o`1Vo`Oo
oo]Z2?l0on400ooonf[o0?lXo`3o:006o`3o:1Cooo]Z1ol0`_l6ohoo00Cooo]Z2?l0ohD5oookJPOo
06Ko3OoonfX7o`3oh@03oookJ_lco`3o<ol000Go<ol01_oo^004oookJPKo0<;o2_oonfX00ol0obSo
06Koo`1Vo`05o`1Vo`gooo]Z1ol0ohD6on_o00;ooo]Z1_l0on44oookJPKo0<;o0_n?o`06o`1Vo`Co
oo]Z1_lco`000ooonf[o0?lXo`3o:003o`3o:0?o0?n50_l0on42o`32o`Go06Ko6?oonfX000;ooo]Z
5Ol00006o`1Vo`03o`32ool0on7o0?oQ00;o0?n51_l0obP00ol0003o<ol0oc?o0003oc?o00Go0000
1_l0I_l3ohoo0003o`000?l0`_oo0<;o00Co0<;o0_l00007o`3oh@Kojol01?l00007o`3oQ@[o0000
1_l0I_l3o`3o:0Ko00001ol0`_l4o`0000WookP00ol00003oc?o00Oo0?oQ3ol00007o`1Vo`So0?n5
2?l00009ohoo00So0<;o4?l00008o`3o:0;o00002?l0on45o`0000Oo06Ko6_l00003oomL0003oc?o
0?l0`_oo0<;o00Go0<;o1?l0ohD2on_o01_o00002?l0I_l5o`0000So0?oQ0ol00008o`3o:1;o0000
2?l0`_l5ohoo00Ko00002?l0ohD3o`0000So06Ko3_l00007o`3oh@Ko<ol02?oo^003o`0000Oo0<;o
2?l00003o`3o:0Oo06Ko3?l00006o`3oQ@Oojol00_l00006o`3oh@Co00001_l0`_l2ohoo00Ko06Ko
1?l00006oc?o00;o00001?l0obP3o`3oQ@;o0?oQ0_l0`_l5o`1VoaGo00000ooonfX000;ooo]Z5Ol0
0006o`1Vo`03o`32ool0on7o0?oQ00;o0?n51_l0obP00ol0003o<ol0oc?o0004oc?o00Co00001_l0
I_l3ohoo00Ko0<;o1?l00006o`3oh@Oojol00ol00006o`3oQ@[o00001ol0I_l4o`3o:0Go00001ol0
`_l3o`0000WookP01?l00002oc?o00Oo0?oQ4Ol00007o`1Vo`Oo0?n52Ol00008ohoo00Oo0<;o4?l0
0008o`3o:0Co00002?l0on43o`0000So06Ko7?l00002oomL00So0<;o0ol0ohD00oo[o`3o0000o`00
000Ko`0000Oo06Ko1?l00008o`3oh@Go00002?l0obP@o`0000So0<;o1On?o`08o`0000So0?n50_l0
0007o`1Vo`oo00002?l0on45oc?o00WookP00ol00006o`32o`So00000ol0obP7o`1Vo`_o00001ol0
ohD00ol0003ojol0on_o0005on_o00Ko0?oQ1Ol00006o`32o`03ohoo0?l0I_oo06Ko00Co06Ko1Ol0
0006oc?o00;o00001?l0obP3o`3oQ@;o0?oQ0_l0`_l5o`1VoaGo00000ooonfX000;ooo]Z5Ol00005
o`1Vo`;o0<;o0_l0on43o`3oQ@Go0?lX00?o0000oc?o0?lco`001?lco`05o`0000Go06Ko0on?o`06
o`32o`Co00001_l0on47on_o00;o00001ol0ohD:o`0000Ko06Ko1_l0obP5o`0000Oo0<;o0_l00008
oonh00Co00000olco`07o`3ohA7o00002?l0I_l7o`3oQ@Wo00001_n?o`07o`32oa3o00002?l0obP5
o`0000So0?oQ0ol00007o`1Voaoo000000?ooe`0o`32ool0`_l01_l0`_l00ol0ohGojol0oomL000M
o`0000So06Ko0ol00007o`3oh@Ko00002Ol0obP?o`0000Oo0<;o1On?o`09o`0000So0?n500?o0000
o`1Vool0I_l01Ol0I_lAo`0000Oo0?oQ1?lco`02o`0000WookP00_l00007o`32o`Ko00001Ol0obP7
o`1Vo`[o00001ol0ohD00ol0003ojol0on_o0005on_o00Ko0?oQ1?l00006o`32o`03o`000?n?o`3o
06Ko00Go06Ko1_l00006oc?o0003o`000?l0obSo0?lX00;o0?lX0ol0ohD2o`3oh@;o0<;o1Ol0I_lE
o`0000?ooo]Z0002oookJQGo00001Ol0I_l2o`32o`;o0?oQ0ol0ohD4o`3o:0;o00001_lco`05o`00
00Ko06Ko00?oSol0o`000?l0`_l01Ol0`_l4o`0000Oo0?oQ1oo[o`000ol0003o0?n5o`3oQ@05o`3o
Q@Wo00001ol0I_l6o`3o:0Go00001ol0`_l00ol0003ookP0oonh0006oonh00Co00000olco`07o`3o
hA?o00001ol0I_l8o`3oQ@Wo00001?n?o`08o`32o`oo00002?l0obP7o`0000So0?oQ00?o0000o`1V
ool0I_l01Ol0I_lPo`000003on_o0?l0ohGo0<;o00Ko0<;o00?o<ol0oomL0?ooG0000_ooG00Lo`00
00So06Ko00?o0000o`3ohOl0on401_l0on47o`0000So0?lX3_l00008o`32o`CoSol02ol00008o`3o
Q@Oo06Ko4Ol00008o`3oh@?o<ol00ol00009oonh0003o`000?l0`_oo0<;o00Go0<;o1_l00005o`3o
:0Oo06Ko2_l00006o`3oQ@?o00001_o[o`06o`3oh@Co00001_l0`_l00ol0003oSol0o`1Vo`05o`1V
o`Ko00001_lco`000ol0003o0?lXo`3o:002o`3o:0?o0?n50_l0on42o`32o`Go06Ko5Ol00003oook
JP000_oonfXEo`0000Go06Ko0_l0`_l2o`3oh@?o0?n51?l0obP2o`0000Ko<ol01Ol00006o`1Vo`03
ohoo0?l0`_oo0<;o00Go0<;o1Ol00006o`3oh@Oojol000?o0000o`3oQOl0ohD01?l0ohD:o`0000Oo
06Ko1ol0obP5o`0000Oo0<;o1ooo^005o`0000;o<ol02?l0on4Co`0000So06Ko1ol0ohD:o`0000?o
Sol01ol0`_l@o`0000So0?lX2?l00007o`3oh@So06Ko7ol000000oo[o`3o0?n5o`3oQ@08o`32o`03
oc?o0?ooG03ooe`000;ooe`07?l00007o`1Vo`So0?oQ2Ol00008o`3o:0go00001ol0`_l4ohoo00go
00001_l0ohD7o`1Voa?o00001ol0on42oc?o00Go00002?oo^002o`0000Oo0<;o1?l00007o`3o:0Ko
06Ko2Ol00007o`3oQ@?o00001Oo[o`07o`3oh@Co00001_l0`_l00ol0003oSol0o`1Vo`05o`1Vo`Ko
00001_lco`000ol0003o0?lXo`3o:002o`3o:0?o0?n50_l0on42o`32o`Go06Ko5Ol00003oookJP00
4_oonfX00ol0003ooo]ZoookJP02oookJPGo06Ko0_l0`_l2o`3oh@?o0?n51?l0obP3oookJPKo<ol0
1?oonfX6o`1Vo`03ohoo0?l0`_oo0<;o00Co0<;o1_oonfX6o`3oh@03oookJ_o[o`3ojol000Cojol0
1ol0ohD:oookJPKo06Ko00?ooo]Zo`3o:?l0obP01Ol0obP5oookJPOo0<;o1_oo^005oookJP?o<ol0
1ol0on44oookJP03o`000?oonf[ooo]Z00kooo]Z1ol0I_l8o`3oQ@Wooo]Z0_n?o`08o`32o`oooo]Z
2?l0obP:oookJPKo0?oQ1ol0I_lOoookJP;ojol00ol0ohD8o`32o`03oc?o0?ooG03ooe`000?ooe`0
6_oonfX8o`1Vo`Ko0?oQ2ooonfX8o`3o:0_ooo]Z1ol0`_l4ohoo00oooo]Z1?l0ohD8o`1Vo`oooo]Z
00?o0000oookJ_oonfX00_oonfX7o`3oh@Oooo]Z2?oo^0000ooonf[o0<;oo`32o`05o`32o`Cooo]Z
1ol0obP7o`1Vo`Sooo]Z1_l0ohD5oookJPCojol01_l0on44oookJPOo0<;o00?ooo]Zo`1Vool0I_l0
1?l0I_l00on?o`3ooo]ZoookJP04oookJPKo<ol000?ooo]Zo`3o:?l0obP00ol0obP2o`3oQ@;o0?oQ
0_l0`_l5o`1Vo`Cooo]Z00?o0000oookJ_oonfX04OoonfX001;ooo]Z00?o0000oookJ_oonfX00_oo
nfX5o`1Vo`;o0<;o0_l0on43o`3oQ@Co0?lX0ooonfX6oc?o00Cooo]Z1_l0I_l00ooonf[o0<;oo`32
o`04o`32o`Kooo]Z1ol0on46on_o00Ko0?n52_oonfX7o`1Vo`;ooo]Z1ol0obP5oookJPOo0<;o1Ooo
^004oookJP?o<ol02?l0on44oookJP03o`000?oonf[ooo]Z00oooo]Z1ol0I_l7o`3oQ@[ooo]Z2?l0
`_l00on?o`3ooo]ZoookJP0<oookJPSo0?lX2ooonfX5o`3oh@So06Ko7_oonfX2on_o00Go0?n51ol0
`_l2oc?o00Kooe`06OoonfX8o`1Vo`Go0?oQ3?oonfX8o`3o:0Wooo]Z2?l0`_l4ohoo00oooo]Z1?l0
ohD7o`1Voa3ooo]Z00Go0000oookJ_oonf[ooo]Zoc?o0007o`3oh@Sooo]Z2?oo^0000ooonf[o0<;o
o`32o`05o`32o`;ooo]Z1ol0obP2oookJPKo06Ko1ooonfX7o`3oQ@Gooo]Z1?o[o`06o`3oh@Cooo]Z
1_l0`_l2oookJPKo06Ko00?oSol0oookJ_oonfX01OoonfX5oc?o0003oookJ_l0obSo0?lX00?o0?lX
0_l0ohD2o`3oh@;o0<;o1Ol0I_l4oookJP03o`000?oonf[ooo]Z017ooo]Z000GoookJPGo06Ko0ol0
`_l01?l0on7o0?n5o`3oQOl0ohD4o`3o:0?ooo]Z1_lco`03oookJP;oSol01_l0I_l6o`32o`Oooo]Z
1_l0on400ooonf[ojol0on_o0002on_o00Oo0?n52_oonfX6o`1Vo`?ooo]Z1ol0obP5oookJPOo0<;o
1?oo^005oookJP?o<ol01ol0on4GoookJPOo06Ko00?ooo]Zo`3oQOl0ohD01Ol0ohD9oookJPOo0<;o
0on?o`0<oookJPSo0?lX3OoonfX3o`3oh@So06Ko7_oonfX2on_o00Ko0?n52?l0`_l2oc?o00Kooe`0
6OoonfX7o`1Vo`Co0?oQ3OoonfX8o`3o:0Wooo]Z1ol0`_l4ohoo017ooo]Z0_l0ohD8o`1Voa?ooo]Z
0olco`07o`3oh@Sooo]Z2?oo^007o`32o`;ooo]Z1ol0obP2oookJPOo06Ko1_oonfX7o`3oQ@Gooo]Z
0oo[o`07o`3oh@Cooo]Z1_l0`_l2oookJPKo06Ko0_n?o`06oookJPKo<ol000?ooo]Zo`3o:?l0obP0
0_l0obP3o`3oQ@;o0?oQ00?o0<;oo`1Vool0I_l00ol0I_lHoookJP005ooonfX5o`1Vo`?o0<;o00Co
0?oQo`3oQOl0ohGo0?n50ol0obP4oookJPKo<ol00ooonfX2ohoo00Ko06Ko1Ol0`_l8oookJPKo0?oQ
00?ooo]Zon_o0?o[o`000_o[o`07o`3oQ@Wooo]Z1ol0I_l4oookJPOo0?lX1OoonfX7o`32o`;ookP0
1OoonfX3oc?o00Oo0?oQ6OoonfX7o`1Vo`So0?n51ooonfX8o`32o`CoSol02ooonfX8o`3o:0kooo]Z
0_l0on47o`1Voakooo]Z0_o[o`08o`3oQ@So0<;o0_lco`07oomL01Oooo]Z2?l0I_l2o`3oh@oooo]Z
2?l0obP7oookJPSo0<;o0on?o`0CoookJP03o`3oQOl0I_oo06Ko00Go06Ko5?oonfX3oc?o00Oo0?oQ
2?oonfX9oonh00Oo0<;o1ol0obP3oookJPOo06Ko1OoonfX7o`3oQ@Oooo]Z0_o[o`06o`3oh@Cooo]Z
1ol0`_l2oookJPKo06Ko0_n?o`06oookJPKo<ol000?ooo]Zo`3o:?l0obP00_l0obP3o`3oQ@;o0?oQ
00?o0<;oo`1Vool0I_l00ol0I_lHoookJP005ooonfX5o`1Vo`?o0<;o00?o0?oQo`3oQOl0ohD00_l0
ohD2o`3o:0Gooo]Z1_lco`02oookJP;oSol01_l0I_l5o`32o`Sooo]Z1ol0on401?oonf[ojol0on_o
0?o[o`06o`3oQ@[ooo]Z1ol0I_l4oookJPOo0?lX1OoonfX7o`32o`03oonh0?oonf[ooo]Z00?ooo]Z
1?lco`07o`3ohAWooo]Z1ol0I_l00ooonf[o0?n5o`3oQ@05o`3oQ@Oooo]Z1ol0`_l6ohoo00Wooo]Z
2?l0obP?oookJP03o`3ohOl0I_oo06Ko00Ko06Ko7?oonfX3on_o00Wo0?n500?o0000o`32ool0`_l0
1Ol0`_l3oc?o00Sooe`05_oonfX8o`1Voa7ooo]Z2?l0obP5oookJPSo0<;o0on?o`0DoookJPOo06Ko
00?o0?n5oookJ_oonfX04OoonfX5oc?o00Oo0?oQ2?oonfX8oonh00Oo0<;o1ol0obP4oookJPKo06Ko
1OoonfX7o`3oQ@Oooo]Z0_o[o`06o`3oh@Cooo]Z1_l0`_l3oookJPGo06Ko0on?o`06oookJPKo<ol0
00?ooo]Zo`3o:?l0obP00_l0obP3o`3oQ@;o0?oQ00?o0<;oo`1Vool0I_l00ol0I_lHoookJP005ooo
nfX5o`1Vo`?o0<;o00?o0?oQo`3oQOl0ohD00_l0ohD2o`3o:0Gooo]Z1_lco`001?oonf[oSol0ohoo
0?n?o`06o`1Vo`Go0<;o2OoonfX6o`3oh@03oookJ_o[o`3ojol000Oo0?n52_oonfX6o`1Vo`Kooo]Z
1ol0obP3oookJP;ookP01_l0`_l6oookJP?o<ol01ol0on4KoookJPOo06Ko2?l0ohD5oookJPOo0<;o
2?n?o`07oookJPSo0?lX4OoonfX7o`1Vo`03o`3ohOoonf[ooo]Z01Wooo]Z1?o[o`08o`3oQ@;o0000
2?l0`_l3oc?o00Sooe`05OoonfX00ol0on7o06Koo`1Vo`05o`1Voa;ooo]Z2?l0obP4oookJPOo0<;o
0on?o`0DoookJPSo06Ko00?o0?n5oookJ_oonfX04?oonfX6oc?o00Oo0?oQ2OoonfX8oonh00Ko0<;o
1_l0obP5oookJPOo06Ko0ooonfX7o`3oQ@Wooo]Z1ol0on44oookJPKo0<;o0_oonfX6o`1Vo`CoSol0
1OoonfX6oc?o0003oookJ_l0obSo0?lX00;o0?lX0ol0ohD2o`3oh@03o`32ool0I_oo06Ko00?o06Ko
6?oonfX001Oooo]Z1Ol0I_l3o`32o`Go0?n50_l0obP5oookJPKo<ol000?ooo]Zohoo0?n?o`000_n?
o`05o`1Vo`Go0<;o2OoonfX6o`3oh@;ooo]Z00?ojol0o`3oQOl0ohD01?l0ohD:oookJPOo06Ko1_oo
nfX7o`3o:0;ooo]Z0ooo^007o`32o`Cooo]Z1?lco`07o`3ohA_ooo]Z1ol0I_l00ooonf[o0?n5o`3o
Q@05o`3oQ@Cooo]Z2?l0`_l9ohoo00Gooo]Z2?l0obPAoookJPOo06Ko0ol0on4IoookJPCojol02?l0
ohD4o`0000So0<;o0olco`09oomL01;ooo]Z0_l0on48o`1Voa7ooo]Z2?l0obP3oookJPSo0<;o0_n?
o`0EoookJPOo06Ko0ol0ohDAoookJPOo<ol01ol0on49oookJPOookP01ol0`_l5o`3o:0Kooo]Z1_l0
I_l3oookJPOo0?n52OoonfX6o`3oh@03on_o0?oonf[ooo]Z00;ooo]Z1_l0`_l2oookJPKo06Ko1?n?
o`06oookJPGo<ol000?ooo]Zo`3o:?l0obP00_l0obP3o`3oQ@;o0?oQ00?o0<;oo`1Vool0I_l01?l0
I_lGoookJP005_oonfX6o`1Vo`?o0<;o1Ol0ohD2o`3o:0Gooo]Z1_lco`000ooonf[oSol0ohoo0002
ohoo00Ko06Ko0ol0`_l:oookJPOo0?oQ00?ooo]Zo`3oQOl0ohD01Ol0ohD:oookJPKo06Ko2?oonfX7
o`3o:0GookP01_l0`_l3oookJPCo<ol01ol0on4MoookJPOo06Ko00?ooo]Zo`3oQOl0ohD01Ol0ohD3
oookJPOo0<;o0_oonfX9ohoo00?ooo]Z2Ol0obP@oookJPSo06Ko1?l0on4GoookJPCojol02?l0ohD0
0ooonf[o0000o`000003o`0000So0<;o0olco`0:oomL00oooo]Z1?l0on48o`1Voa7ooo]Z2?l0obP0
0ooonf[o0<;oo`32o`06o`32o`;oSol05OoonfX8o`1Vo`?o0?n54?oonfX8oc?o00So0?oQ2OoonfX7
oonh00Ko0<;o1?l0obP7oookJPOo06Ko00?ooo]Zo`3oQOl0ohD01Ol0ohD:oookJPKo0?oQ0_o[o`02
oookJPKo0<;o0ooonfX6o`1Vo`CoSol01_oonfX6oc?o00Co0?lX0ol0ohD2o`3oh@03o`32ool0I_oo
06Ko00Co06Ko5ooonfX001Kooo]Z1_l0I_l3o`32o`Go0?n500?o0?lXoookJ_oonfX01OoonfX6oc?o
00CoSol01_l0I_l3o`32o`_ooo]Z1_l0on400ooonf[o0?n5o`3oQ@05o`3oQ@03on_o0?oonf[ooo]Z
00Kooo]Z1ol0I_l8oookJPSo0?lX1?oo^007o`32o`;ooo]Z1?lco`07o`3ohAgooo]Z1ol0I_l00ooo
nf[o0?n5o`3oQ@06o`3oQ@03oookJ_l0`_oo0<;o00Ko0<;o0ooonfX9ohoo0003oookJ_l0obSo0?lX
00Oo0?lX4OoonfX7o`1Vo`Go0?oQ5_oonfX4on_o00So0?n50_oonfX5o`0000So0<;o1?lco`0:oomL
00kooo]Z1Ol0on47o`1Voa;ooo]Z2?l0obP7o`32o`;oSol05OoonfX8o`1Vo`Go0?n53_oonfX8oc?o
00;ooo]Z1ol0on4:oookJPKookP01ol0`_l2o`3o:0Sooo]Z1ol0I_l00ooonf[o0?n5o`3oQ@05o`3o
Q@Wooo]Z1ol0on42on_o00;ooo]Z1_l0`_l3oookJPKo06Ko1On?o`05oookJPKo<ol000Cooo]Zo`3o
:?l0obSo0?lX0ol0ohD2o`3oh@03o`32ool0I_oo06Ko00Co06Ko5ooonfX001Kooo]Z1_l0I_l3o`32
o`Go0?n500?o0?lXoookJ_oonfX01OoonfX6oc?o00CoSol01_l0I_l3o`32o`_ooo]Z1ol0on46o`3o
Q@;ojol02?oonfX7o`1Vo`Wooo]Z1ol0obP4oonh00Oo0<;o00?ooo]Zoc?o0?lco`000_lco`07o`3o
hAoooo]Z1ol0I_l00ooonf[o0?n5o`3oQ@05o`3oQ@So0<;o1OoonfX8ohoo00Wo0?lX4OoonfX8o`1V
o`Ko0?oQ5?oonfX4on_o00Wo0?n50_oonfX5o`000003oookJ_l0`_oo0<;o00Ko0<;o1?lco`0;oomL
00_ooo]Z1_l0on48o`1Voa;ooo]Z1_l0obP8o`32o`;oSol05OoonfX7o`1Vo`Oo0?n53OoonfX7oc?o
00?ooo]Z2?l0on4:oookJPGookP01ol0`_l2o`3o:0Wooo]Z1_l0I_l7o`3oQ@[ooo]Z1_l0on43on_o
00;ooo]Z1_l0`_l2oookJPKo06Ko1_n?o`05oookJPKo<ol000?ooo]Zo`3o:?l0obP00_l0obP2o`3o
Q@;o0?oQ00?o0<;oo`1Vool0I_l01?l0I_lGoookJP005_oonfX6o`1Vo`?o0<;o1Ol0ohD00ol0obSo
oo]ZoookJP05oookJPKo<ol01?n?o`06o`1Vo`?o0<;o2ooonfX7o`3oh@Ko0?n50oo[o`07oookJPKo
06Ko2_oonfX8o`3o:0CookP01ol0`_l4oc?o00Oo0?oQ7ooonfX8o`1Vo`Oo0?n51ol0`_l7oookJPOo
Sol02?l0obPBoookJPOo06Ko2?l0on4BoookJPGojol02?l0ohD3oookJPGo00000_oonfX8o`32o`?o
<ol03?ooG009oookJPSo0?oQ2?l0I_lAoookJPGo0?lX2?l0`_l2ohoo01Gooo]Z2?l0I_l7o`3oQ@co
oo]Z2?lco`04oookJPOo0?oQ2_oonfX6oonh00Oo0<;o2_oonfX7o`1Vo`Ko0?n52OoonfX7o`3oh@Co
jol01ol0`_l2oookJPKo06Ko1_n?o`05oookJPKo<ol000?ooo]Zo`3o:?l0obP00_l0obP2o`3oQ@;o
0?oQ0_l0`_l5o`1VoaOooo]Z000FoookJPGo06Ko1?l0`_l6o`3oQ@Oooo]Z1_lco`05ohoo00Ko06Ko
00?o0<;ooookJ_oonfX02ooonfX6o`3oh@Go0?n51Oo[o`05oookJPOo06Ko2ooonfX7o`3o:0?ookP0
00?ooo]Zo`32ool0`_l01Ol0`_l3oc?o00Oo0?oQ8OoonfX7o`1Vo`03oookJ_l0ohGo0?n500?o0?n5
2?l0`_l8oookJPGoSol02?l0obPBoookJPOo06Ko0_oonfX8o`3ohA3ooo]Z1Oo[o`08o`3oQ@Cooo]Z
1Ol00003oookJPOo0<;o1?lco`000ooonf[ooe`0oomL000:oomL00Oooo]Z1ol0on42oookJPOo06Ko
4_oonfX4o`3o:0Oo0<;o0_n?o`0EoookJPSo06Ko00?ooo]Zo`3oQOl0ohD01_l0ohD:oookJPSo<ol0
1_oonfX7o`3oh@[ooo]Z1Ooo^007o`32o`_ooo]Z1_l0I_l5o`3oQ@[ooo]Z1ol0on44on_o00Ko0<;o
0ooonfX6o`1Vo`OoSol01OoonfX6oc?o00Co0?lX0_l0ohD2o`3oh@;o0<;o1Ol0I_lGoookJP005_oo
nfX5o`1Vo`Co0<;o1_l0ohD8oookJPKo<ol00on?o`000ooonf[o06Koo`1Vo`04o`1Vo`03o`32oooo
nf[ooo]Z00_ooo]Z1ol0on44o`3oQ@Gojol01OoonfX6o`1Vo`gooo]Z1ol0obP01?oo^03ooo]Zoook
J_oonfX7o`32o`03oc?o0?l0on7o0?oQ00Ko0?oQ8OoonfX8o`1Vo`04oookJ_l0ohGo0?n5o`3oQ@So
0<;o2_oonfX3ohoo00So0?lX4_oonfX8o`1Vo`;ooo]Z2?l0on4?oookJPGojol02?l0ohD5oookJPGo
00000ooonfX8o`32o`Co<ol00_oonfX<oomL00Cooo]Z2?l0on42oookJPSo06Ko4_oonfX2o`3o:0So
0<;o00?oSol0oookJ_oonfX05?oonfX7o`1Vo`?ooo]Z1ol0ohD9oookJPSo<ol01ooonfX7o`3oh@_o
oo]Z0ooo^002o`3o:0Oo0<;o2_oonfX6o`1Vo`Go0?n52_oonfX6o`3oh@Gojol01_l0`_l3oookJPKo
06Ko00?ooo]Zohoo0?n?o`001?n?o`05oookJPKo<ol01?l0obP2o`3oQ@;o0?oQ0_l0`_l5o`1VoaOo
oo]Z000FoookJPGo06Ko1Ol0`_l5o`3oQ@Sooo]Z1_lco`03ohoo0003oookJ_l0I_oo06Ko00Co06Ko
00?o0<;ooookJ_oonfX03?oonfX6o`3oh@Co0?n51_o[o`03oookJPOo06Ko3?oonfX00ooo^03o0?lX
o`3o:005o`3o:0Cooo]Z1ol0`_l00olco`3o0?oQo`3oh@05o`3ohB?ooo]Z2?l0I_l3o`3oQ@Oo0<;o
3?oonfX00on?o`3o0?lXo`3o:006o`3o:1?ooo]Z1ol0I_l4oookJPSo0?oQ3OoonfX5on_o00So0?n5
1_oonfX5o`0000Cooo]Z2?l0`_l4oc?o00;ooo]Z3?ooG002oookJPSo0?oQ1?oonfX8o`1Voa;ooo]Z
2?l0`_l00on?o`3ooo]ZoookJP0DoookJPSo06Ko1?oonfX7o`3oQ@Sooo]Z2?lco`08oookJPOo0?oQ
2ooonfX01?oo^03o0?lXo`3o:?l0obP7o`32o`[ooo]Z1ol0I_l3o`3oQ@[ooo]Z1ol0on45on_o00Ko
0<;o0_oonfX6o`1Vo`;ooo]Z1_n?o`05oookJPKo<ol01?l0obP3o`3oQ@03o`3ohOl0`_oo0<;o00Go
06Ko5ooonfX001Kooo]Z1Ol0I_l5o`32o`Go0?n52?oonfX6oc?o00?oSol000?ooo]Zo`1Vool0I_l0
1?l0I_l?oookJPKo0?oQ0ol0ohD8on_o00;ooo]Z1ol0I_l;oookJP?ookP01ol0obP4oookJPOo0<;o
1ol0on4ToookJPOo06Ko00?ooo]Zo`3oQOl0`_l01ol0`_l<oookJPWo0?lX00?oSol0oookJ_oonfX0
3ooonfX8o`1Vo`Gooo]Z2?l0on4:oookJPKojol02Ol0ohD6oookJPGo00001OoonfX7o`32o`Go<ol0
0ooonfX;oomL00So0?oQ1_oonfX7o`1Voa;ooo]Z1ol0`_l00ol0obSooo]ZoookJP0EoookJPOo06Ko
1OoonfX8o`3oQ@Kooo]Z2?lco`09oookJPOo0?oQ3?oonfX4o`3o:0Oo0<;o2_oonfX6o`1Vo`?o0?n5
2_oonfX6o`3oh@03oookJ_o[o`3ojol000;ojol01_l0`_l3oookJPKo06Ko0_oonfX7ohoo00Cooo]Z
1_lco`001?oonf[o0?lXo`3o:?l0obP3o`3oQ@03o`3ohOl0`_oo0<;o00Go06Ko5ooonfX001Kooo]Z
1Ol0I_l5o`32o`Go0?n52?oonfX7oc?o0004ohoo0?oonf[ooo]Zo`32o`Ko06Ko3_oonfX7o`3oh@;o
0?n500?ooo]Zon_o0?o[o`001_o[o`000ooonf[o06Koo`1Vo`04o`1Vo`_ooo]Z1?oo^007o`3o:0Co
oo]Z1ol0`_l6o`3ohBGooo]Z2?l0I_l00ooonf[o0<;oo`32o`05o`32o`03o`3oQOoonf[ooo]Z00Wo
oo]Z2Ol0obP3ohoo013ooo]Z1ol0I_l7oookJPSo0?oQ2?oonfX6on_o00Wo0?n51ooonfX5o`0000Go
oo]Z2?l0`_l5oc?o00?ooo]Z2_ooG008o`3oh@Kooo]Z2?l0I_l@oookJPSo0<;o0_l0obPEoookJPOo
06Ko1ooonfX7o`3oQ@Gooo]Z2?lco`0;oookJPOo0?oQ2_oonfX5o`3o:0Oo0<;o2_oonfX7o`1Vo`03
o`3oQOoonf[ooo]Z00Sooo]Z1ol0on400ooonf[ojol0on_o0002on_o00Ko0<;o0ooonfX6o`1Vo`?o
oo]Z1_n?o`05oookJPGo<ol000Cooo]Zo`3o:?l0obSo0?lX0ol0ohD00ol0on7o0<;oo`32o`05o`1V
oaOooo]Z000FoookJPGo06Ko1Ol0`_l5o`3oQ@Wooo]Z1_lco`001?n?o`3ooo]ZoookJ_l0`_l6o`1V
o`oooo]Z1_l0on400ol0ohGooo]ZoookJP08on_o00Oo06Ko2_oonfX6oonh00Oo0?lX0ooonfX00olc
o`3o0<;oo`32o`05o`32o`Co0?oQ9ooonfX8o`1Vo`Ko0<;o0ol0ohD:oookJPSo0?lX1On?o`0>oook
JPOo06Ko2?oonfX9o`3oh@Kooo]Z1oo[o`08o`3oQ@Sooo]Z1Ol00006oookJPSo0<;o1Olco`04oook
JPOooe`02?l0on48oookJPSo06Ko3_oonfX00on?o`3o0<;oo`32o`05o`32o`Co0?lX4ooonfX8o`1V
o`Oooo]Z2?l0ohD3oookJPSo<ol03?oonfX8o`3oh@Wooo]Z1_l0obP6o`32o`[ooo]Z1ol0I_l00ol0
ohGooo]ZoookJP08oookJPOo0?oQ0_oonfX3on_o00Ko0<;o0ooonfX6o`1Vo`?ooo]Z1_n?o`05oook
JPKo<ol00ol0obP3o`3oQ@03o`3ohOl0`_oo0<;o00Go06Ko5ooonfX001Kooo]Z1Ol0I_l5o`32o`Go
0?n52OoonfX6oc?o0004ohoo0?oonf[ooo]Zo`32o`Ko06Ko3ooonfX7o`3oh@?ooo]Z1oo[o`06o`1V
o`_ooo]Z1_oo^008o`3o:003oookJ_lco`3o<ol000So0<;o0ol0on4XoookJPOo06Ko1_l0`_l3o`3o
Q@Wooo]Z2?l0obP7ohoo00cooo]Z2?l0I_l9oookJPSo0?oQ1OoonfX7on_o00So0?n52OoonfX5o`00
00Oooo]Z2?l0`_l5oc?o00Gooo]Z1?ooG008o`3oh@[ooo]Z1ol0I_l=oookJP03ohoo0?l0`_oo0<;o
00Go0<;o1_l0obPBoookJPOo06Ko2OoonfX8o`3oQ@;ooo]Z2?lco`0=oookJPOo0?oQ2?oonfX7o`3o
:0Oo0<;o2_oonfX6o`1Vo`03o`3oQOoonf[ooo]Z00Sooo]Z1_l0on43oookJP?ojol01_l0`_l2oook
JPKo06Ko1?oonfX6ohoo00Gooo]Z1_lco`03o`3o:0?o0?n500?o0?oQo`32ool0`_l01Ol0I_lGoook
JP005_oonfX5o`1Vo`Go0<;o1_l0ohD8oookJPKo<ol000CoSol0oookJ_l0`_oo0<;o1_l0I_l?oook
JPOo0?oQ1?oonfX5on_o00Oo06Ko2_oonfX8oonh00Oo0?lX00Cooo]Zoc?o0?lco`3o<ol01ol0`_l2
o`3ohBWooo]Z2?l0I_l4o`32o`Go0?n51ooonfX8o`3o:0WoSol02ooonfX7o`1Vo`_ooo]Z2?l0on43
oookJPOojol02?l0ohD:oookJPGo00001ooonfX8o`32o`Ko<ol01OoonfX3oomL00Oo0?oQ0_ooG009
oookJPSo06Ko2ooonfX00on?o`3o0<;oo`32o`06o`32o`Ko0?lX4OoonfX8o`1Vo`[ooo]Z2?l0ohD8
oc?o00kooo]Z2?l0on47oookJPOo0?lX00?ookP0o`32ool0`_l01?l0`_l9oookJP03o`3oQOl0I_oo
06Ko00Go06Ko2OoonfX7o`3oh@Cooo]Z00?ojol0o`32ool0`_l01?l0`_l3oookJPKo06Ko1OoonfX6
ohoo00Cooo]Z1_lco`04o`3o:0;o0?n50_l0on400ol0`_oo06Koo`1Vo`03o`1VoaOooo]Z000Foook
JPGo06Ko1Ol0`_l6o`3oQ@Sooo]Z00?oSol0oc?o0?lco`001?lco`001?oonf[o0<;oo`32ool0`_l6
o`1Vo`gooo]Z0_l0ohD7o`3oh@Cooo]Z1?o[o`07o`1Vo`Wooo]Z2?oo^0000ooonf[o0?lXo`3o:006
o`3o:0?o<ol02?l0`_l00ol0on7ooo]ZoookJP0XoookJPSo06Ko0ol0`_l6o`3oQ@Gooo]Z2?l0obP2
oookJPWoSol02OoonfX8o`1Vo`cooo]Z2?l0on48on_o00So0?n52ooonfX5o`0000Sooo]Z2?l0`_l6
oc?o00Kooo]Z2?l0on44oomL00Sooo]Z2?l0I_l9oookJP;oSol01ol0`_l8o`3o:0oooo]Z2?l0I_l;
oookJPSo0?n51olco`0@oookJPOo0?oQ1_oonfX7o`3o:0;ookP01ol0`_l8oookJP;o0?n51_l0I_l9
oookJPKo0?oQ1OoonfX00oo[o`3o0<;oo`32o`04o`32o`?ooo]Z1_l0I_l5oookJPKoSol01?oonfX6
oc?o00Co0?lX0_l0ohD2o`3oh@03o`32ool0I_oo06Ko00?o06Ko5ooonfX001Kooo]Z1Ol0I_l5o`32
o`Ko0?n52?oonfX00on?o`3o<ol0oc?o0004oc?o0004oookJ_l0`_oo0<;oo`32o`Ko06Ko3OoonfX2
o`3oQ@Oo0?oQ1?oonfX4on_o00Ko06Ko2OoonfX8oonh00?ooo]Z1ol0obP4oc?o00Oo0<;o;?oonfX7
o`1Vo`;o0<;o1ol0ohD4oookJPWo0?lX0ooonfX9ohoo00Oooo]Z2?l0I_l>oookJPSo0?oQ1_o[o`09
o`3oQ@_ooo]Z1Ol00009oookJPSo0<;o1_lco`04oookJPSo0?oQ1oooG007oookJPOo06Ko1ooonfX3
ohoo00So0<;o00?ooo]Zo`3o:?l0obP01_l0obP>oookJPOo06Ko3OoonfX8o`3oQ@Go<ol04_oonfX7
o`3oh@Cooo]Z2?l0obP00ooonf[ookP0o`32o`06o`32o`Oooo]Z0ol0ohD7o`1Vo`Oooo]Z1ol0on46
oookJPKo0<;o00?ojol0oookJ_l0I_l01_l0I_l5oookJPKoSol01OoonfX5oc?o00Co0?lX0_l0ohD2
o`3oh@03o`32ool0I_oo06Ko00?o06Ko5ooonfX001Kooo]Z1Ol0I_l5o`32o`Ko0?n52?oonfX00on?
o`3o<ol0oc?o0004oc?o00Co0<;o1_l0I_l=oookJP?o0?n51_l0on45oookJP;ojol01ol0I_l8oook
JPWookP01?oonfX7o`3o:0?o<ol000?o0?oQo`32ool0`_l01Ol0`_l[oookJPSo06Ko00?ooo]Zo`3o
QOl0ohD01_l0ohD2oookJPWo0?lX1OoonfX9ohoo00Gooo]Z2?l0I_l?oookJPWo0?oQ1Oo[o`08o`3o
Q@cooo]Z1Ol0000:oookJPSo0<;o1_lco`02oookJPSo0?oQ2OooG006oookJPSo06Ko1OoonfX3ohoo
00So0<;o0ooonfX8o`3o:0cooo]Z2?l0I_l>oookJPSo0?n51?lco`0BoookJPOo0?oQ1?oonfX7o`3o
:0?ooo]Z00?ookP0o`32ool0`_l01Ol0`_l6oookJP?o0?n51ol0I_l7oookJPOo0?oQ1OoonfX7o`32
o`03on_o0?oonf[o06Ko00Go06Ko1_oonfX6ohoo00Gooo]Z1_lco`03o`3o:0;o0?n50_l0on400ol0
`_oo06Koo`1Vo`03o`1VoaOooo]Z000EoookJPKo06Ko1Ol0`_l00ol0obSo0?n5o`3oQ@03o`3oQ@Oo
oo]Z0_n?o`06oc?o00Co0<;o1ol0I_l;oookJPCo0?n51ol0on45oookJP03on_o0?l0I_oo06Ko00Co
06Ko2?oonfX9oonh00Gooo]Z2?l0obP00olco`3o0?oQo`3oh@07o`32ob_ooo]Z00?o0<;oo`1Vool0
I_l01_l0I_l00ooonf[o0?n5o`3oQ@06o`3oQ@Wo0?lX1ooonfX9ohoo00?ooo]Z2Ol0I_l@oookJPWo
0?oQ0oo[o`08o`3oQ@gooo]Z1Ol0000:oookJPSo0<;o1_lco`000ooonf[o0?oQo`3oh@07o`3oh@_o
oe`01OoonfX8o`1Vo`?ooo]Z1?n?o`07o`32o`Cooo]Z2?l0obP;oookJPSo06Ko4?oonfX8o`3oQ@;o
<ol05?oonfX7o`3oh@;ooo]Z2?l0obP4oookJPOo0<;o00?ookP0oookJ_oonfX00_oonfX5o`3oQ@Ko
06Ko1ooonfX6o`3oh@Kooo]Z1_l0`_l2on_o0003oookJ_l0I_oo06Ko00Co06Ko1ooonfX6ohoo00Co
oo]Z1_lco`03o`3o:0;o0?n50_l0on400ol0`_oo06Koo`1Vo`03o`1VoaOooo]Z000EoookJPKo06Ko
1Ol0`_l00ol0obSo0?n5o`3oQ@04o`3oQ@Kooo]Z0on?o`05oc?o00Go0<;o1_l0I_l;oookJPGo0?n5
1_l0on45oookJPOo06Ko00?ojol0oookJ_oonfX01?oonfX9oonh00Oooo]Z1ol0obP01?lco`3o0?oQ
o`3ohOl0on47o`32obWooo]Z0ol0`_l7o`1Vo`;ooo]Z2Ol0ohD6o`3o:0Wooo]Z2_n?o`09o`1Voa;o
oo]Z2Ol0on400oo[o`3o0?n5o`3oQ@06o`3oQ@kooo]Z1Ol0000;oookJPSo0<;o1Olco`09o`3oh@03
oookJ_ooG03ooe`000[ooe`01OoonfX7o`1Vo`;ooo]Z1?n?o`08o`32o`Gooo]Z2?l0obP:oookJPOo
06Ko4OoonfX8o`3oQ@03oc?o0?oonf[ooo]Z01?ooo]Z2?l0on48o`3o:0Gooo]Z00?ookP0o`32ool0
`_l01Ol0`_l01?oo^03ooo]ZoookJ_oonfX5o`3oQ@Oo06Ko1OoonfX7o`3oh@Kooo]Z1_l0`_l3on_o
00Ko06Ko1ooonfX6ohoo00Cooo]Z1_lco`03o`3o:0;o0?n50_l0on400ol0`_oo06Koo`1Vo`03o`1V
oaOooo]Z000EoookJPKo06Ko1_l0`_l6o`3oQ@Kooo]Z0on?o`05oc?o00Go0<;o1_l0I_l:oookJPKo
0?n51ol0on44oookJPOo06Ko0_o[o`05oookJPSookP02?oonfX7o`3o:0Co0?oQ2?l0`_lWoookJPCo
0<;o2?l0I_l00ooonf[o0?n5o`3oQ@08o`3oQ@Co0?lX2ooonfX8ohoo00Wo06Ko4_oonfX2on_o00So
0?oQ2?l0ohD?oookJPGo00003?oonfX8o`32o`?o<ol02Ol0on44oookJPcooe`00ooonfX8o`1Vo`Co
Sol02?l0`_l7oookJPSo0?lX2?oonfX8o`1Voa7ooo]Z00?o<ol0o`3oQOl0ohD01_l0ohDFoookJPOo
0?oQ1ol0obP7oookJPSo0<;o00?ookP0oookJ_l0ohD01_l0ohD6o`1Vo`Gooo]Z1_l0on46oookJPOo
0<;o0_o[o`06o`1Vo`Sooo]Z1_n?o`04oookJPKo<ol00ol0obP2o`3oQ@;o0?oQ00?o0<;oo`1Vool0
I_l00ol0I_lGoookJP005OoonfX6o`1Vo`Ko0<;o1_l0ohD6oookJP?oSol01?lco`06o`32o`Oo06Ko
2OoonfX6o`3oQ@Oo0?oQ0ooonfX7o`1Vo`Cojol00ooonfX8oonh00Wooo]Z00?o<ol0o`3o:?l0obP0
0ol0obP6o`3oh@Oo0<;o9_oonfX6o`32o`So06Ko00?ooo]Zo`3oQOl0ohD02?l0ohD2o`3o:0gooo]Z
1on?o`08o`1Voa;ooo]Z1?o[o`08o`3oh@Oo0?n53ooonfX5o`0000gooo]Z2?l0`_l00olco`3o0?oQ
o`3oh@07o`3oh@Oooo]Z3?ooG002oookJPSo06Ko0_n?o`08o`32o`Wooo]Z2?l0obP6oookJPSo06Ko
4OoonfX3oc?o00So0?n55OoonfX8o`3oh@Ko0?lX2?oonfX7o`32o`03oonh0?oonf[o0?n500Ko0?n5
1ol0I_l3oookJPOo0?oQ1_oonfX6o`32o`?ojol01_l0I_l8oookJPKoSol01OoonfX5oc?o00?o0?lX
0ol0ohD00ol0on7o0<;oo`1Vo`05o`1VoaKooo]Z000EoookJPGo06Ko00?o0?oQo`32ool0`_l01?l0
`_l6o`3oQ@Gooo]Z1?n?o`04oc?o00Ko0<;o00?ooo]Zo`1Vool0I_l01?l0I_l9oookJPKo0?n500?o
oo]Zo`3ohOl0on401Ol0on42oookJPOo06Ko1?o[o`02oookJPSookP02OoonfX3oc?o00?o0?lX1ol0
on48o`32obGooo]Z1ol0`_l7o`1Vo`;ooo]Z2_l0ohD?oookJPGoSol02?l0I_lBoookJPKojol02?l0
on45o`3oQA3ooo]Z1Ol0000=oookJPWo0<;o2?l0on49oookJPcooe`00_oonfX8o`1Vo`Wo0<;o2Ooo
nfX9o`3o:0Cooo]Z2?l0I_lAoookJPGo<ol01ol0ohDFoookJPOo0?oQ1Ol0obP9oookJPSo0<;o1ol0
ohD00ooonf[o06Koo`1Vo`05o`1Vo`?ooo]Z1ol0on46oookJPKo0<;o0oo[o`06o`1Vo`Wooo]Z1_n?
o`04oookJPGo<ol00ol0obP3o`3oQ@03o`3ohOl0`_oo06Ko00Go06Ko5_oonfX001Gooo]Z1Ol0I_l0
0ol0on7o0<;oo`32o`04o`32o`03o`3o:?l0ohGo0?n500?o0?n51OoonfX5ohoo00?o<ol01_l0`_l0
0ooonf[o06Koo`1Vo`05o`1Vo`Oooo]Z1ol0ohD00ooonf[o0?oQo`3oh@05o`3oh@;ooo]Z1_l0I_l6
on_o00SookP02OoonfX4oc?o00?o0?lX2?l0on47o`32obCooo]Z2?l0`_l8o`1Vo`;ooo]Z2_l0ohD?
oookJP?oSol02?l0I_lBoookJPSojol02?l0on43o`3oQA7ooo]Z1Ol0000>oookJPWo0<;o1_l0on4<
oookJPcooe`02Ol0I_l7o`32o`_ooo]Z2Ol0obP2oookJPWo06Ko4?oonfX6oc?o00So0?n55_oonfX7
o`3oh@?o0?lX2ooonfX7o`32o`Oo0?n50_oonfX7o`1Vo`03oookJ_l0on7o0?oQ00Go0?oQ1_oonfX7
o`32o`?ojol01_l0I_l9oookJPKoSol01?oonfX5oc?o00Co0?lX0_l0ohD00ol0on7o0<;oo`1Vo`05
o`1VoaKooo]Z000EoookJPGo06Ko0_l0on45o`32o`03o`3o:?l0ohGo0?n500Co0?n51?oonfX5ohoo
00?o<ol01_l0`_l00ooonf[o06Koo`1Vo`05o`1Vo`Oooo]Z1_l0ohD3oookJPKo0?oQ00?ooo]Zo`1V
ool0I_l01Ol0I_l7on_o00OookP02?oonfX6oc?o0003o`3o:?l0on7o0?oQ00Ko0?oQ0_oonfX7o`32
ob;ooo]Z2?l0`_l2oookJPSo06Ko0ol0obP9o`3oQA3ooo]Z2?l0I_l00on?o`3ooo]ZoookJP0>oook
JP[ojol02Ol0on400ol0ohGooo]ZoookJP0@oookJPGo00003ooonfX:o`32o`?o0?oQ0_lco`0<oook
JPcooe`02Ol0I_l5o`32o`gooo]Z2Ol0obP9o`1Voa3ooo]Z2?lco`08o`3oQAGooo]Z2?l0on42o`3o
:0cooo]Z1ol0`_l5o`3oQ@?ooo]Z1ol0I_l00ooonf[o0?oQo`3oh@05o`3oh@Kooo]Z1_l0`_l3on_o
00Ko06Ko2_oonfX6ohoo00Cooo]Z1Olco`04o`3o:0;o0?n500?o0?oQo`32ool0I_l01Ol0I_lFoook
JP005OoonfX5o`1Vo`;o0?oQ1Ol0`_l00ol0obSo0?n5o`3oQ@04o`3oQ@Cooo]Z1On?o`02oc?o00Ko
0<;o0ooonfX6o`1Vo`Kooo]Z1ol0ohD3oookJPOo0?oQ1_l0I_l00ooonf[ojol0on_o0005on_o00Ko
okP02OoonfX6oc?o00So0?oQ0ooonfX8o`32ob7ooo]Z1ol0`_l4oookJPSo06Ko0ol0obP9o`3oQ@ko
oo]Z2Ol0I_l2ohoo00kooo]Z2_o[o`02o`3oQ@[o0?oQ4OoonfX5o`00013ooo]Z2_l0`_l00ol0on7o
<ol0oc?o0002oc?o00gooo]Z2OooG002ohoo00[o06Ko0_l0`_l?oookJPOo0?lX2Ol0I_l@oookJPWo
<ol000?ooo]Zo`3oQOl0ohD01_l0ohDEoookJPOo0?oQ00?o0?lXoookJ_oonfX02ooonfX8o`32o`Co
0?n51?oonfX6o`1Vo`03oookJ_l0on7o0?oQ00Co0?oQ1_oonfX7o`32o`03oookJ_o[o`3ojol000Ko
06Ko2_oonfX6ohoo00Cooo]Z1_lco`03o`3o:0;o0?n500?o0?oQo`32ool0`_l01Ol0I_lFoookJP00
5OoonfX5o`1Vo`;o0?oQ1Ol0`_l00ol0obSo0?n5o`3oQ@04o`3oQ@?ooo]Z1_n?o`000ooonf[o<ol0
o`32o`05o`32o`?ooo]Z1ol0I_l5oookJPOo0?n51?oonfX5o`3oh@Oo06Ko00?ooo]Zon_o0?o[o`00
1_o[o`04oonh00Wooo]Z1_lco`08o`3oh@03o`3o:?oonf[ooo]Z00;ooo]Z1ol0`_lPoookJPSo0<;o
1?oonfX9o`1Vo`?o0?lX2Ol0ohD<oookJPWo06Ko1?n?o`0<oookJP[ojol01?l0ohD:o`3ohA3ooo]Z
1Ol0000@oookJP03o`3ohOl0`_oo0<;o00So0<;o1Olco`0>oookJPKooe`01?n?o`0:o`1Voa7ooo]Z
1Ol0obP9o`1Voa3ooo]Z2Olco`02oookJPSo0?n55?oonfX00ol0obSo0?oQo`3oh@06o`3oh@kooo]Z
1ol0`_l3o`3oQ@Gooo]Z1ol0I_l6o`3oh@Kooo]Z1ol0`_l00ooonf[ojol0on_o0006o`1Vo`_ooo]Z
1_n?o`04oookJPGo<ol00ol0obP2o`3oQ@03o`3ohOl0`_oo0<;o00Go06Ko5_oonfX001Gooo]Z1Ol0
I_l2o`3oh@Go0<;o00?o0?lXo`3oQOl0ohD01?l0ohD3oookJPKoSol000?ooo]Zoc?o0?l0`_l01Ol0
`_l4oookJPKo06Ko1?oonfX7o`3oQ@Gooo]Z1Ol0on47o`1Vo`;ooo]Z2?o[o`02oonh00Wooo]Z1olc
o`08o`3oh@;o0?lX0ooonfX8o`32oakooo]Z2?l0`_l6oookJP[o06Ko0_l0obP9o`3oQ@[ooo]Z2Ol0
I_l6ohoo00[ooo]Z2_o[o`06o`3oQ@[o0?oQ3ooonfX5o`0000oooo]Z0ol0on4:o`32o`Go<ol03_oo
nfX4oomL00CoSol00_l0`_l:o`1Voa7ooo]Z0ol0obP9o`1Voa3ooo]Z2Olco`04oookJPSo0?n54ooo
nfX2o`3o:0Oo0?oQ3_oonfX8o`32o`;o0?n51_oonfX6o`1Vo`Go0?oQ1ooonfX6o`32o`?ooo]Z1ol0
I_l;oookJPKoSol01?oonfX5oc?o00?o0?lX0_l0ohD00ol0on7o0<;oo`32o`05o`1VoaKooo]Z000E
oookJPGo06Ko0_l0on45o`32o`03o`3o:?oonf[o0?n500Co0?n50ooonfX6ohoo0003oookJ_l0`_oo
0<;o00Go0<;o1?oonfX6o`1Vo`Cooo]Z1ol0ohD5oookJPCo0?oQ1ol0I_l4oookJPOojol00_oo^009
oookJPKo<ol02?l0on44o`3o:0?ooo]Z2?l0`_lLoookJPSo0<;o2?oonfX:o`1Vo`;ooo]Z2Ol0ohD8
oookJPWo06Ko2?n?o`08oookJP[ojol02?l0ohD:o`3oh@kooo]Z1Ol0000>oookJPGo0?oQ2_l0`_l6
oc?o00kooo]Z00?ooe`0ohoo0?n?o`000_n?o`04o`32o`[o06Ko4OoonfX00ol0obSo06Koo`1Vo`07
o`1Voa3ooo]Z2Olco`06oookJPSo0?n54OoonfX4o`3o:0Oo0?oQ3_oonfX7o`32o`03o`3oQOoo^03o
okP000Gooo]Z1ol0I_l4o`3oh@Kooo]Z1ol0`_l3oookJPKo06Ko00?ojol0oookJ_oonfX02OoonfX6
ohoo00Cooo]Z1Olco`03o`3o:0;o0?n500?o0?oQo`32ool0`_l01Ol0I_lFoookJP005OoonfX5o`1V
o`;o0?oQ1Ol0`_l00ol0obSooo]Zo`3oQ@05o`3oQ@;ooo]Z1_n?o`000ooonf[o0<;oo`32o`04o`32
o`03oc?o0?oonf[ooo]Z00;ooo]Z1ol0I_l3oookJPKo0?n51ooonfX3o`3oh@Oo06Ko1?oonfX8on_o
00Wooo]Z1_lco`08o`3oh@Ko0?lX0ooonfX9o`32oaWooo]Z2Ol0`_l9oookJP_o06Ko00?ooo]Zo`3o
QOl0ohD01ol0ohD5oookJP[o06Ko00?ooo]Zohoo0?n?o`001on?o`05oookJP[ojol000?ooo]Zo`3o
QOl0ohD01ol0ohD00ooonf[o0?oQo`3oh@08o`3oh@gooo]Z1Ol0000=oookJPSo0?oQ2_l0`_l5oc?o
00cooo]Z1?n?o`07o`32o`_o06Ko3_oonfX:o`1Vo`03o`3o:?oonf[ooo]Z00gooo]Z2Olco`08oook
JPSo0?n53ooonfX5o`3o:0So0?oQ3OoonfX00ol0ohGo0<;oo`32o`05o`32o`;ookP01OoonfX7o`1V
o`Co0?oQ1_oonfX6o`32o`Cooo]Z1_l0I_l00oo[o`3ooo]ZoookJP09oookJPKoSol01?oonfX5oc?o
00?o0?lX0_l0ohD2o`3oh@03o`32ool0I_oo06Ko00?o06Ko5_oonfX001Gooo]Z1Ol0I_l2o`3oh@Ko
0<;o00?ooo]Zo`3oQOl0ohD01?l0ohD00ooonf[oSol0ohoo0004ohoo00;ooo]Z1_l0`_l2oc?o00Co
oo]Z1_l0I_l2oookJPOo0?n51ooonfX2o`3oh@Oo06Ko1?oonfX2oonh00Sojol01ooonfX7oc?o00Oo
0?oQ2?l0obP2oookJP[o0<;o5ooonfX9o`32o`Wooo]Z0_l0obP;o`1Vo`03oookJ_l0ohGo0?n500Oo
0?n50_oonfX;o`1Vo`?ooo]Z2_n?o`02oookJP[ojol000?ooo]Zo`3oQOl0ohD01ol0ohD4oookJP[o
0?oQ2ooonfX5o`0000_ooo]Z2ol0on4:o`32o`Go<ol02_oonfX3ohoo00_o0<;o2_l0I_l<oookJP[o
06Ko0ol0obP<oookJP[o<ol02OoonfX9o`3oQ@gooo]Z1ol0obP8o`3oh@cooo]Z00?o0?n5o`32ool0
`_l01Ol0`_l3oonh00Gooo]Z1ol0I_l2o`3oh@Oooo]Z1_l0`_l3oookJPOo06Ko0_o[o`0;oookJPKo
Sol00ooonfX5oc?o00?o0?lX0_l0ohD2o`3oh@03o`32ool0I_oo06Ko00?o06Ko5_oonfX001Gooo]Z
1Ol0I_l2o`3oh@Ko0<;o00?ooo]Zo`3oQOl0ohD01?l0ohD00ooonf[oSol0ohoo0004ohoo00;ooo]Z
1_l0`_l2oc?o00Cooo]Z1_l0I_l2oookJPKo0?n52OoonfX8o`1Vo`?ooo]Z1?oo^008on_o00Gooo]Z
1olco`08o`3oh@Wo0?lX0_oonfX:o`32oaCooo]Z2_l0`_l9oookJPCo0?lX3?l0I_l9o`3oQ@_o06Ko
1OoonfX:ohoo00[ojol02_l0ohD6oookJP_o0?oQ2OoonfX5o`0000[ooo]Z2_l0on43oookJP_o0<;o
1?lco`08oookJP?oSol03?l0`_l00oooG03o06Koo`1Vo`08o`1Vo`Wooo]Z2ol0I_l5o`3o:0[ooo]Z
2_lco`0;oookJPWo0?n52ooonfX8o`3o:0So0?oQ2ooonfX3o`3oQ@Oo0<;o0ooo^004oookJPOo06Ko
0_l0on46oookJPOo0<;o0ooonfX6o`1Vo`?ojol02ooonfX6ohoo00?ooo]Z1Olco`03o`3o:0;o0?n5
0_l0on400ol0`_oo06Koo`1Vo`03o`1VoaKooo]Z000EoookJPGo06Ko0_l0on46o`32o`03oookJ_l0
ohGo0?n500Go0?n51_n?o`000ooonf[o0<;oo`32o`04o`32o`?o<ol01?oonfX7o`1Vo`Oo0?n52Ooo
nfX7o`1Vo`Cooo]Z1?oo^008on_o00Gooo]Z1_lco`08o`3oh@;ooo]Z2Ol0obP2oookJP_o0<;o4Ooo
nfX:o`32o`Wooo]Z1ol0obP=o`1Vo`;o0?n53_l0I_l7oookJP[oSol02?o[o`0:o`3oQ@Sooo]Z2ol0
on48oookJPGo00002?oonfX;o`3oh@Gooo]Z2ol0`_l5oc?o00Gooo]Z0on?o`0;o`32o`Cooe`03Ol0
I_l3oookJPco06Ko1ol0obP8oookJP[o<ol03OoonfX9o`3oQ@Wooo]Z2Ol0obP00ooonf[o0?oQo`3o
h@06o`3oh@Wooo]Z1?l0ohD8o`32o`?ookP01?oonfX7o`1Vo`Oooo]Z1_l0`_l3oookJPOo06Ko1?o[
o`0:oookJPKoSol00ooonfX5oc?o00Co0?lX00Co0?n5o`3ohOl0on7o0<;o1Ol0I_lFoookJP005Ooo
nfX5o`1Vo`;o0?oQ1_l0`_l2oookJPKo0?n51_n?o`000ooonf[o0<;oo`32o`04o`32o`Co<ol01?oo
nfX6o`1Vo`Oo0?n52?oonfX8o`1Vo`03o`3ohOoonf[ooo]Z00KookP02?o[o`03oookJPKo<ol02?l0
on44oookJPWo0?lX0_oonfX;o`32o`kooo]Z2ol0`_l9oookJPWo0?lX6ol0I_l9oookJP_oSol01Oo[
o`0:o`3oQ@[ooo]Z3?l0on46oookJPGo00001ooonfX;o`3oh@Oooo]Z3Ol0`_l3oc?o00?ooo]Z00?o
Sol0o`32ool0`_l02ol0`_l6oomL01[o06Ko2_l0obP5oookJP[o<ol03ooonfX9o`3oQ@Oooo]Z2Ol0
obP3oookJPSo0?oQ1ooonfX6o`3oQ@Oo0<;o0ooo^003oookJP03o`3ohOl0I_oo06Ko00Go06Ko1_oo
nfX7o`32o`?ooo]Z1ol0I_l4on_o00[ooo]Z1on?o`03oookJPCo<ol01?l0obP01?l0ohGo0?oQo`3o
hOl0`_l5o`1VoaKooo]Z000EoookJPGo06Ko0_l0on400ol0obSo0<;oo`32o`03o`32o`;ooo]Z1_l0
ohD5ohoo00;ooo]Z1_l0`_l4oc?o00Cooo]Z1_l0I_l6o`3oQ@Wooo]Z1ol0I_l3o`3oh@SookP02?o[
o`000ooonf[o<ol0oc?o0005oc?o00So0?oQ1OoonfX9o`3o:0?ooo]Z2_l0`_l<oookJP_o0<;o2Ooo
nfX9o`3o:0?ooo]Z5ol0I_l<oookJP_oSol00_o[o`000ooonf[o0?n5o`3oQ@08o`3oQ@cooo]Z3?l0
on45oookJPGo00001OoonfX<o`3oh@[ooo]Z7Ol0`_l2oookJPSooe`05_l0I_l3oookJP[o0?lX0ooo
nfX:oc?o017ooo]Z2Ol0ohD5oookJPWo0?lX1OoonfX8o`3oh@Kooo]Z1_l0ohD8o`32o`?ookP00_oo
nfX2o`3oh@Oo06Ko1?oonfX8o`32o`;ooo]Z1ol0I_l6on_o00[ooo]Z1_n?o`03oookJPGo<ol00ol0
obP2o`3oQ@03o`3ohOl0`_oo06Ko00Co06Ko5_oonfX001Gooo]Z1Ol0I_l2o`3oh@03o`3o:?l0`_oo
0<;o00Co0<;o00?ooo]Zo`3oQOl0ohD01?l0ohD5ohoo00;ooo]Z1_l0`_l4oc?o00Cooo]Z1ol0I_l5
o`3oQ@Sooo]Z1ol0I_l5o`3oh@KookP00_oonfX8on_o00Ko<ol02?l0on47oookJPWo0?lX0ooonfX:
o`32o`[ooo]Z2ol0`_l8oookJP[o0?lX1OoonfXDo`1Vo`03o`3oQOoonf[ooo]Z00cooo]Z00?ojol0
ohoo0?n?o`002?n?o`0;o`3oQ@oooo]Z3Ol0on42oookJPGo00000_oonfX=o`3oh@gooo]Z6_l0`_l6
oookJPOooe`05?l0I_l5oookJP[o0?lX2_lco`0DoookJPWo0?n50ooonfX9o`3o:0Kooo]Z2Ol0on44
oookJPSo0?n51ol0`_l4oonh00?o0?oQ2?l0I_l3oookJPOo0<;o0ooonfX7o`1Vo`Kojol02_oonfX6
ohoo00?ooo]Z1Olco`03o`3o:0;o0?n500?o0?oQo`32ool0I_l01?l0I_lFoookJP005OoonfX5o`1V
o`;o0?oQ00?o0?lXo`32ool0`_l01?l0`_l2oookJPKo0?n51?n?o`000ooonf[o0<;oo`32o`04o`32
o`Ko<ol01?oonfX7o`1Vo`?o0?n52OoonfX7o`1Vo`Go0?oQ1_oo^002oookJPOojol01_lco`08o`3o
h@Wooo]Z2Ol0obP3oookJPgo0<;o0ooonfX<o`32o`Wooo]Z2_l0obP8oookJQ7o06Ko1?l0ohD;oook
JP?ojol01on?o`0;o`3oQA?ooo]Z8?l0on4@oookJQOo0<;o2OoonfX6oomL017o06Ko2?oonfX:o`3o
:0So<ol05_oonfX9o`3oQ@03oookJ_l0obSo0?lX00Oo0?lX2?oonfX9o`3oh@03oookJ_l0ohGo0?n5
00Oo0?n50_oonfX7o`32o`;ookP01Ol0on47o`1Vo`;ooo]Z2?l0`_l2oookJPOo06Ko00?ooo]Zon_o
0?o[o`001Oo[o`09oookJPKoSol00ooonfX5oc?o00?o0?lX0_l0ohD00ol0on7o0<;oo`1Vo`04o`1V
oaKooo]Z000EoookJPGo06Ko0_l0on400ol0obSo0<;oo`32o`04o`32o`;ooo]Z1_l0ohD4ohoo0003
oookJ_l0`_oo0<;o00Co0<;o1_lco`04oookJPOo06Ko0ol0ohD8oookJPOo06Ko1ol0on44oonh00Co
oo]Z1Oo[o`06oc?o00So0?oQ2ooonfX:o`3o:0?ooo]Z6Ol0`_l8oookJP_o0?lX3?oonfX:o`1Vo`[o
0?n51ooonfX6on_o00CoSol03?l0ohDEoookJQgo0?oQ4ooonfXEo`32o`_ooo]Z2OooG00;o`1Vo`_o
oo]Z2_l0obP6oc?o01Sooo]Z2Ol0ohD8o`3o:0[ooo]Z2Ol0on48o`3oQ@?ooo]Z2?l0`_l6o`3oh@So
06Ko00?ooo]Zo`32ool0`_l01Ol0`_l3oookJPOo06Ko00?ooo]Zon_o0?o[o`001Oo[o`0:oookJPKo
Sol00_oonfX5oc?o00?o0?lX0_l0ohD00ol0on7o0<;oo`1Vo`04o`1VoaKooo]Z000EoookJPGo06Ko
0_l0on400ol0obSo0<;oo`32o`04o`32o`;ooo]Z1_l0ohD3ohoo00;ooo]Z1_l0`_l7oc?o00?ooo]Z
2?l0I_l00ol0ohGooo]ZoookJP06oookJPSo06Ko2?l0on42oonh00Kooo]Z0oo[o`06oc?o00Wo0?oQ
3?oonfX:o`3o:0?ooo]Z5_l0`_l9oookJP_o0?lX5OoonfX>o`3oQ@Cooo]Z2Oo[o`0=o`3oQASooo]Z
6_l0on4GoookJPoo0<;o4?oonfX<oomL01?ooo]Z2_l0obP3oc?o01[ooo]Z2Ol0ohD6o`3o:0cooo]Z
2Ol0on47o`3oQ@Cooo]Z2?l0`_l6o`3oh@So06Ko1_l0`_l3oookJPOo06Ko0ooonfX6on_o00[ooo]Z
1_n?o`02oookJPGo<ol00ol0obP2o`3oQ@03o`3ohOl0`_oo06Ko00Co06Ko5_oonfX001Cooo]Z1_l0
I_l2o`3oh@;o0?lX1Ol0`_l2oookJPKo0?n50on?o`000ooonf[o0<;oo`32o`05o`32o`Oo<ol01?oo
nfX8o`1Vo`Oooo]Z2?l0I_l2oookJPWo0?oQ1ooonfX2on_o00Go<ol02Ol0on4>oookJP[o0?lX0ooo
nfXDo`32o`Sooo]Z3?l0obPHoookJQ3o0?n51?o[o`0Ao`3oQA[ooo]Z5ol0on4KoookJP;oSol02olc
o`0AoookJPcooe`04ooonfX;o`3o:1cooo]Z2_l0ohD3o`3o:0kooo]Z2Ol0on45o`3oQ@Gooo]Z2Ol0
`_l5o`3oh@03oookJ_l0I_oo06Ko00Ko06Ko1Ol0`_l2oookJPSo06Ko0ooonfX7on_o00Wooo]Z1_n?
o`03oookJPCo<ol00ol0obP2o`3oQ@03o`3ohOl0`_oo06Ko00Go06Ko5OoonfX001Cooo]Z1_l0I_l2
o`3oh@;o0?lX1Ol0`_l3oookJPKo0?n50_n?o`000ooonf[o0<;oo`32o`04o`32o`;ooo]Z1olco`04
oookJPSo06Ko1_oonfX8o`1Vo`;ooo]Z2_l0on47oookJPGo<ol02Ol0on4@oookJP[o0?lX0ooonfXB
o`32o`Sooo]Z2ol0obPLoookJR7o0?n51?n?o`0KoookJQ7o0?oQ7OoonfX4ohoo00_o<ol04_oonfX<
oomL013ooo]Z0_lco`0;o`3o:1cooo]Z2_l0ohD00ol0obSooo]ZoookJP0>oookJP[o0?oQ0_l0ohD7
oookJPSo0<;o1?l0on42oookJPWo06Ko0ol0`_l2oookJPSo06Ko1OoonfX6on_o00Wooo]Z1_n?o`03
oookJPCo<ol00ol0obP2o`3oQ@03o`3ohOl0`_oo06Ko00Go06Ko5OoonfX001Cooo]Z1_l0I_l2o`3o
h@;o0?lX1Ol0`_l3oookJPKo0?n500?oSol0oookJ_oonfX01_l0`_l2oookJPOo<ol00ooonfX00ol0
ohGo06Koo`1Vo`07o`1Vo`Cooo]Z2?l0I_l2oookJP;ookP02_l0on45oookJPGo<ol02Ol0on4Boook
JP_o0?lX1OoonfX;o`32o`[ooo]Z2ol0obPOoookJQgo0?n52?n?o`0OoookJPGo0?oQ8OoonfX7ohoo
00co<ol04_oonfX;oomL00gooo]Z1Olco`0<o`3o:1[ooo]Z00?o0?lXo`3oQOl0ohD02Ol0ohD?oook
JP03o`3oQOl0on7o0?oQ00So0?oQ2OoonfX9o`32o`03o`3ohOoo^03ookP000;ooo]Z2Ol0I_l2o`32
o`;ooo]Z2?l0I_l5oookJPKojol02_oonfX6ohoo00;ooo]Z1?lco`03o`3o:0;o0?n500?o0?oQo`32
ool0I_l01Ol0I_lEoookJP005?oonfX6o`1Vo`;o0?oQ0_l0obP6o`32o`;ooo]Z1_l0ohD00on?o`3o
oo]ZoookJP06o`32o`?ooo]Z1_lco`03oookJP;o0?n54ol0I_l2oookJPCookP02_l0on43oookJP?o
<ol02ol0on4EoookJP[o0?lX6?oonfX:o`3o:2?ooo]Z6Ol0ohD;ohoo01kooo]Z1Ol0000PoookJP[o
Sol03?lco`0AoookJPcooe`02_oonfX7oc?o00go0?lX5_oonfX4o`3o:0_o0?n53?oonfX4o`3oQ@[o
0?oQ1ooonfX2o`3oh@[o0<;o00CookP0oookJ_l0`_oo0<;o4ol0I_l6oookJPOojol02OoonfX6ohoo
00;ooo]Z1?lco`03o`3o:0;o0?n50_l0on46o`1VoaGooo]Z000DoookJPGo06Ko0ol0on42o`3o:0Ko
0<;o0_oonfX7o`3oQ@03oookJ_l0`_oo0<;o00Co0<;o1?oonfX7oc?o0003oookJ_l0ohGo0?n500;o
0?n54Ol0I_l2oookJPKookP03?l0on400olco`3o0?oQo`3oh@0:o`3oh@03on_o0?oonf[ooo]Z01Co
oo]Z3?l0obPCoookJP_o0?lX9_oonfXEo`3oQ@?ooo]Z3?n?o`0LoookJPGo00007_oonfX;ohoo00;o
oo]Z3Olco`0AoookJPcooe`01_oonfX;oc?o00go0?lX4OoonfX8o`3o:0go0?n52?oonfX6o`3oQ@co
0?oQ00?ooo]Zo`3ohOl0on401?l0on4>o`32oa7o06Ko2?oonfX6on_o00Wooo]Z1_n?o`02oookJPGo
<ol00_l0obP2o`3oQ@;o0?oQ00?o0<;oo`1Vool0I_l00ol0I_lEoookJP005?oonfX5o`1Vo`?o0?oQ
0_l0obP6o`32o`?ooo]Z1_l0ohD00ooonf[o0<;oo`32o`04o`32o`Gooo]Z1_lco`000ooonf[o0?n5
o`3oQ@03o`3oQA3o06Ko0_oonfX8oonh01Ko0?oQ0oo[o`0FoookJPgo0?lX3_oonfX<o`3o:2Sooo]Z
1?o[o`0<o`3oQ@Wooo]Z3?n?o`0KoookJPGo00006ooonfX=ohoo00Gooo]Z3_lco`0?oookJPcooe`0
0ooonfX=oc?o00;ooo]Z3Ol0obP>oookJP_o0?lX3Ol0ohD3oookJP[o0?n54_l0on4?o`32o`oo06Ko
2OoonfX7on_o00Sooo]Z1_n?o`02oookJPGo<ol00ol0obP01?l0ohGo0?oQo`3ohOl0`_l5o`1VoaGo
oo]Z000DoookJPGo06Ko0ol0on42o`3o:0Ko0<;o0_oonfX00on?o`3o0?n5o`3oQ@04o`3oQ@03oook
J_l0`_oo0<;o00Co0<;o1OoonfX7oc?o00Go0?n53ol0I_l2oookJPSookP00_oonfXDo`3oh@Kojol0
5OoonfX?o`3o:0Oooo]Z3ol0obPXoookJP[ojol04_oonfX<ohoo01Wooo]Z1Ol0000IoookJPkoSol0
1ooonfX@oc?o00kooo]Z2oooG00=oc?o00Gooo]Z3ol0obP9oookJPgo0?lX00?ooo]Zo`3oQOl0ohD0
6Ol0ohDAo`3oh@oo0<;o3_l0I_l9oookJPOojol02OoonfX6ohoo0003oookJ_lco`3o<ol000?o<ol0
0ol0obP01?l0ohGo0?oQo`3ohOl0`_l5o`1VoaGooo]Z000DoookJPGo06Ko0_l0on44o`3o:0Go0<;o
0_oonfX00on?o`3o0?n5o`3oQ@05o`3oQ@Ko0<;o1OoonfX6oc?o00Oo0?n500?ooo]Zo`1Vool0I_l0
2_l0I_l2oookJPSookP01?oonfXBo`3oh@Sojol05_oonfXRo`3o:2Oooo]Z2oo[o`0EoookJPcoSol0
5ooonfX5o`0001Oooo]Z3_n?o`0;oookJQ7o<ol03?oonfX8oomL00go<ol02OoonfXRo`3o:0Cooo]Z
5ol0ohD3oookJQ;o0?oQ3_l0`_l<o`1Vo`_ooo]Z1_o[o`09oookJPKoSol00_oonfX4oc?o00?o0?lX
00Co0?n5o`3ohOl0on7o0<;o1Ol0I_lEoookJP005?oonfX5o`1Vo`;o0?oQ1?l0obP5o`32o`;ooo]Z
0_n?o`05o`3oQ@Ko0<;o1ooonfX5oc?o00Ko0?n50ooonfX9o`1Vo`?ooo]Z2?oo^006oookJPko0?oQ
0_oonfX:on_o01Kooo]Z8?l0obPVoookJPcojol05ooonfX<ohoo01Kooo]Z1Ol0000DoookJQ3oSol0
3_oonfXBoc?o00_ooo]Z0oooG00?oc?o00cooo]Z7_l0obP7oookJQCo0?n51_oonfX?o`3oh@Cooo]Z
2ol0`_l2oookJPWo06Ko3OoonfX7on_o00Sooo]Z1_n?o`02oookJPCo<ol00ol0obP01?l0ohGo0?oQ
o`3ohOl0`_l5o`1VoaGooo]Z000DoookJPGo06Ko0_l0on44o`3o:0Ko0<;o00?ooo]Zohoo0?n?o`00
1Ol0ohD6o`32o`Oooo]Z1?lco`07o`3oQ@oooo]Z2?oo^008oookJP[o0?oQ1OoonfX;on_o01Oooo]Z
6ol0obPWoookJP_ojol06ooonfX=ohoo01?ooo]Z1Ol0000BoookJQ3oSol04_oonfXEoc?o00?ooo]Z
4olco`0@oookJQWo0?lX3OoonfX@o`3oQ@Wooo]Z2ol0on48oookJPSookP06_oonfX6on_o00Sooo]Z
1_n?o`02oookJPCo<ol00ol0obP2o`3oQ@03o`3ohOl0`_oo06Ko00Co06Ko5OoonfX001Cooo]Z1Ol0
I_l2o`3oh@Co0?lX1_l0`_l3ohoo00Go0?n51_l0`_l8oookJP?o<ol01ol0ohD>oookJPSookP02?oo
nfX8oc?o00Wooo]Z2oo[o`0HoookJQKo0?lX:?oonfX<on_o01gooo]Z3on?o`0@oookJPGo00003ooo
nfX@ohoo01Sooo]Z9_lco`000oooG03ooo]ZoookJP0AoookJQKo0?lX4?oonfX;o`3oQB3ooo]Z2?oo
^00IoookJPKojol02OoonfX6ohoo0003oookJ_lco`3o<ol000;o<ol00ol0obP2o`3oQ@03o`3ohOl0
`_oo06Ko00Co06Ko5OoonfX001Cooo]Z1Ol0I_l2o`3oh@Co0?lX1_l0`_l4ohoo00?o0?n51ol0`_l9
oookJP03oc?o0?l0ohGo0?n500Go0?n53_oonfX8oonh00Sooo]Z2Olco`0;oookJP[ojol06_oonfX?
o`3o:2[ooo]Z3Oo[o`0PoookJPooSol03_oonfX5o`0000gooo]Z4?n?o`0MoookJR7o<ol01OooG00D
oookJQ7o0?lX?OoonfX8oonh01Wooo]Z1oo[o`08oookJPKoSol000?ooo]Zoc?o0?lco`000_lco`03
o`3o:0;o0?n500?o0?oQo`32ool0I_l01?l0I_lEoookJP005?oonfX5o`1Vo`;o0?oQ1?l0obP6o`32
o`CoSol00ol0ohD6o`32o`[ooo]Z2?l0ohD>oookJPOookP02?oonfX9oc?o00gooo]Z2oo[o`1@oook
JPcojol09?oonfX@ohoo00_ooo]Z1Ol0000:oookJQ7oSol08_oonfXLoc?o00Wooe`0HOoonfX8oonh
01Wooo]Z1_o[o`08oookJPKoSol000?ooo]Zoc?o0?lco`000_lco`03o`3o:0;o0?n500?o0?oQo`32
ool0I_l01?l0I_lEoookJP005?oonfX5o`1Vo`;o0?oQ1Ol0obP6o`32o`?oSol00ol0ohD6o`32o`[o
oo]Z1ol0ohD2oc?o00cooo]Z2?oo^007oookJPWo<ol03ooonfX;on_o04gooo]Z3?o[o`0WoookJQGo
Sol01OoonfX5o`0000Oooo]Z4On?o`0XoookJQKo<ol000?ooo]ZoomL0?ooG0002_ooG01QoookJPSo
okP06?oonfX7on_o00Oooo]Z1_n?o`02oookJPCo<ol00_l0obP2o`3oQ@03o`3ohOl0`_oo06Ko00Co
06Ko5OoonfX001Cooo]Z1Ol0I_l2o`3oh@Go0?lX1_l0`_l3ohoo00;o0?n51ol0`_l9oookJPSo0?n5
0olco`0:oookJPSookP01ooonfX9oc?o01;ooo]Z2_o[o`1:oookJPgojol0:ooonfXbohoo02oooo]Z
2olco`09oookJPcooe`0H?oonfX7oonh01Sooo]Z1oo[o`08oookJPGoSol00_oonfX4oc?o00;o0?lX
0_l0ohD00ol0on7o0<;oo`1Vo`04o`1VoaGooo]Z000DoookJPGo06Ko0_l0on44o`3o:003oookJ_l0
`_oo0<;o00Go0<;o0on?o`07o`32o`[ooo]Z1ol0ohD5oc?o00Wooo]Z1ooo^007oookJPWo<ol05?oo
nfX;on_o04Kooo]Z3Oo[o`0`oookJRcoSol0AooonfX=oomL05kooo]Z2?oo^00HoookJPKojol02?oo
nfX6ohoo0003oookJ_lco`3o<ol000;o<ol00_l0obP2o`3oQ@03o`3ohOl0`_oo06Ko00Co06Ko5Ooo
nfX001Cooo]Z1Ol0I_l2o`3oh@Co0?lX00?ooo]Zo`32ool0`_l01Ol0`_l3ohoo00Oo0<;o2OoonfX7
o`3oQ@Oo<ol01ooonfX8oonh00Kooo]Z2Olco`0FoookJP_ojol0@ooonfX=on_o03Cooo]Z:?n?o`1;
oookJPcooe`0G_oonfX8oonh01Oooo]Z1oo[o`07oookJPKoSol000?ooo]Zoc?o0?lco`000_lco`02
o`3o:0;o0?n50_l0on45o`1VoaGooo]Z000DoookJPGo06Ko0_l0on44o`3o:0;ooo]Z1_l0`_l2ohoo
00So0<;o00?o0?n5oookJ_oonfX01OoonfX8o`3oQ@So<ol01OoonfX8oonh00Kooo]Z2Olco`0Ioook
JP_ojol0@?oonfX=on_o03Sooo]Z8_n?o`1@oookJPcooe`0GOoonfX8oonh01Oooo]Z1_o[o`07oook
JPKoSol000?ooo]Zoc?o0?lco`000_lco`02o`3o:0;o0?n50_l0on45o`1VoaGooo]Z000DoookJPGo
06Ko0_l0on44o`3o:0;ooo]Z3ol0`_l3o`3oQ@Cooo]Z2Ol0ohD00ooonf[o<ol0oc?o0007oc?o00Co
oo]Z1ooo^005oookJP[o<ol06ooonfX;on_o03gooo]Z3Oo[o`10oookJQWoSol0E?oonfX=oomL05_o
oo]Z2?oo^00GoookJPKojol01ooonfX6ohoo0003oookJ_lco`3o<ol000;o<ol00ol0obP00ol0ohGo
0?oQo`3oh@06o`1VoaCooo]Z000DoookJPGo06Ko0_l0on44o`3o:0?ooo]Z3Ol0`_l5o`3oQ@;ooo]Z
2_l0ohD2oookJP[o<ol000?ooo]Zoonh0?oo^0001_oo^002oookJPco<ol07OoonfX<on_o03Wooo]Z
3Oo[o`1;oookJPGo0000HOoonfX<oomL05_ooo]Z2?oo^00FoookJPOojol01ooonfX5ohoo00;ooo]Z
0olco`03o`3o:003o`3oQOl0on7o0?oQ00Ko06Ko5?oonfX001Cooo]Z1Ol0I_l2o`3oh@Co0?lX0ooo
nfX=o`32oa3o0?n51?oonfX;oc?o00KookP00_oonfX<oc?o023ooo]Z3?o[o`0doookJPkojol0COoo
nfX5o`0006?ooo]Z3?ooG01JoookJPSookP05_oonfX6on_o00Oooo]Z1_n?o`001?oonf[o<ol0oc?o
0?lco`03o`3o:003o`3oQOl0on7o0?oQ00Ko06Ko5?oonfX001Cooo]Z1Ol0I_l00ol0on7o0?lXo`3o
:003o`3o:0?ooo]Z3?l0`_l@o`3oQ@Kooo]Z3Olco`02oonh00ko<ol08_oonfX=on_o02kooo]Z4?o[
o`1?oookJPGo0000I?oonfX=oomL05Wooo]Z1ooo^00FoookJPOojol01_oonfX6ohoo0004oookJ_lc
o`3o<ol0oc?o00?o0?lX00?o0?n5o`3ohOl0on401_l0I_lDoookJP005?oonfX5o`1Vo`03o`3ohOl0
obSo0?lX00?o0?lX1?oonfX;o`32o`oo0?n52?oonfXKoc?o02Gooo]Z3_o[o`0XoookJQ;ojol0D?oo
nfX5o`0006Kooo]Z3?ooG01HoookJPSookP05OoonfX7on_o00Kooo]Z1_n?o`000ooonf[o<ol0oc?o
0002oc?o00;o0?lX00Co0?n5o`3ohOl0on7o0<;o1Ol0I_lDoookJP005?oonfX5o`1Vo`03o`3ohOl0
obSo0?lX00?o0?lX1?oonfX00on?o`3o0<;oo`32o`06o`32o`?ooo]Z3?l0ohD;oookJQSo<ol0:?oo
nfX@on_o02;ooo]Z4oo[o`1BoookJPGo0000J?oonfX<oomL05Oooo]Z2?oo^00EoookJPKojol01_oo
nfX6ohoo0003oookJ_lco`3o<ol000;o<ol00_l0obP01?l0ohGo0?oQo`3ohOl0`_l5o`1VoaCooo]Z
000DoookJPGo06Ko00?o0?oQo`3o:?l0obP00_l0obP4oookJP;oSol01ol0`_l5oookJP[o0?n53_oo
nfXCoc?o02gooo]Z4_o[o`0KoookJQCojol0E?oonfX5o`0006Wooo]Z3OooG01FoookJPOookP05Ooo
nfX7on_o00Kooo]Z1On?o`000ooonf[o<ol0oc?o0002oc?o00;o0?lX0_l0ohD00ol0on7o0<;oo`1V
o`04o`1VoaCooo]Z000DoookJPGo06Ko00?o0?oQo`3o:?l0obP00_l0obP4oookJPKoSol02_oonfX5
o`3oQA;ooo]Z00?ookP0oc?o0?lco`003_lco`0`oookJQCojol04_oonfXFon_o05Oooo]Z1Ol0001[
oookJPcooe`0EOoonfX8oonh01Gooo]Z1_o[o`06oookJPKoSol01?lco`02o`3o:0;o0?n500?o0?oQ
o`32ool0I_l01?l0I_lDoookJP005?oonfX5o`1Vo`03o`3ohOl0obSo0?lX00;o0?lX1?oonfX6ohoo
023ooo]Z1?oo^00;oc?o03Gooo]Z=_o[o`1KoookJPGo0000KOoonfX<oomL05Cooo]Z2?oo^00Doook
JPKojol01_oonfX6ohoo0004oookJ_lco`3o<ol0oc?o00;o0?lX0_l0ohD00ol0on7o0<;oo`1Vo`04
o`1VoaCooo]Z000CoookJPKo06Ko00?o0?oQo`3o:?l0obP00_l0obP4oookJPKoSol08?oonfX7oonh
043ooo]Z<?o[o`1NoookJPGo0000K_oonfX=oomL05?ooo]Z2?oo^00CoookJPOojol01OoonfX6ohoo
0004oookJ_lco`3o<ol0oc?o00;o0?lX0_l0ohD00ol0on7o0<;oo`1Vo`04o`1VoaCooo]Z000Coook
JPKo06Ko00?o0?oQo`3o:?l0obP00_l0obP4oookJPGoSol08?oonfX8oonh04?ooo]Z:_o[o`1Qoook
JPGo0000L?oonfX<oomL05;ooo]Z2?oo^00DoookJPKojol01OoonfX6ohoo0004oookJ_lco`3o<ol0
oc?o00;o0?lX0_l0ohD00ol0on7o0<;oo`1Vo`04o`1VoaCooo]Z000CoookJPKo06Ko00?o0?oQo`3o
:?l0obP00_l0obP3oookJPKoSol07ooonfX8oonh04Sooo]Z8oo[o`1ToookJPGo0000L_oonfX<oomL
057ooo]Z2?oo^00CoookJPKojol01_oonfX5ohoo0004oookJ_lco`3o<ol0oc?o00;o0?lX0_l0ohD0
0ol0on7o0<;oo`1Vo`04o`1VoaCooo]Z000CoookJPKo06Ko00?o0?oQo`3o:?l0obP00_l0obP3oook
JPKoSol07ooonfX7oonh04gooo]Z6_o[o`1YoookJPGo0000LooonfX=oomL053ooo]Z2?oo^00Boook
JPOojol01OoonfX6ohoo00?o<ol00_l0obP2o`3oQ@03o`3ohOl0`_oo06Ko00Co06Ko5?oonfX001?o
oo]Z1Ol0I_l2o`3oh@Co0?lX0ooonfX6ohoo01kooo]Z2?oo^03@oookJPGo0000MOoonfX<oomL053o
oo]Z1ooo^00CoookJPKojol01OoonfX6ohoo00?o<ol00ol0obP00ol0ohGo0?oQo`32o`05o`1VoaCo
oo]Z000CoookJPGo06Ko0_l0on44o`3o:0?ooo]Z1_n?o`0MoookJPSookP0dOoonfX5o`0007Oooo]Z
3?ooG01>oookJPSookP04_oonfX7on_o00Cooo]Z1_n?o`001?oonf[o<ol0oc?o0?lco`02o`3o:003
o`3oQOl0on7o0<;o00Go06Ko5?oonfX001?ooo]Z1Ol0I_l2o`3oh@?o0?lX0ooonfX6ohoo01kooo]Z
1ooo^02doookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000N?oonfX=oomL04gooo]Z
2?oo^00AoookJPOojol01?oonfX6ohoo0004oookJ_lco`3o<ol0oc?o00;o0?lX00?o0?n5o`3ohOl0
`_l01Ol0I_lDoookJP004ooonfX5o`1Vo`;o0?oQ0ol0obP3oookJPKoSol07OoonfX8oonh0;?ooo]Z
1ol007l3oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0001joookJPcooe`0COoonfX7oonh01;ooo]Z
1_o[o`05oookJPGoSol000Cooo]Zoc?o0?lco`3o<ol00_l0obP00ol0ohGo0?oQo`32o`05o`1VoaCo
oo]Z000CoookJPGo06Ko0_l0on43o`3o:0?ooo]Z1_n?o`0LoookJPSookP0]?oonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001oo`00
O`Wooo]Z1Ol0001loookJPcooe`0BooonfX8oonh017ooo]Z1oo[o`04oookJPKoSol00olco`02o`3o
:003o`3oQOl0on7o0?oQ00Go06Ko5?oonfX001?ooo]Z1Ol0I_l2o`3oh@?o0?lX0ooonfX6ohoo01co
oo]Z1ooo^02doookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o2?oonfX5o`0007go
oo]Z3?ooG01;oookJPSookP04OoonfX6on_o00Cooo]Z1_n?o`03oc?o00;o0?lX00?o0?n5o`3ohOl0
on401_l0I_lCoookJP004ooonfX5o`1Vo`;o0?oQ0ol0obP3oookJPGoSol07?oonfX8oonh0;Cooo]Z
0ol007l3oookJP?o001o3?oonfX3o`00O`Sooo]Z1ol0001moookJPcooe`0B_oonfX7oonh017ooo]Z
1_o[o`04oookJPKoSol00olco`02o`3o:003o`3oQOl0on7o0?oQ00Ko06Ko4ooonfX001?ooo]Z1Ol0
I_l00ol0on7o0?lXo`3o:002o`3o:0;ooo]Z1_n?o`0KoookJPSookP0]OoonfX3o`00O`?ooo]Z0ol0
07l<oookJP?o001o2?oonfX5o`00087ooo]Z3?ooG018oookJPSookP04?oonfX7on_o00?ooo]Z1_n?
o`03oc?o00;o0?lX00?o0?n5o`3ohOl0on401_l0I_lCoookJP004ooonfX5o`1Vo`03o`3ohOl0obSo
0?lX00;o0?lX0_oonfX6ohoo01_ooo]Z1ooo^02foookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2
oookJPCo001o2?oonfX5o`0008;ooo]Z3?ooG018oookJPSookP04?oonfX6on_o00Cooo]Z1On?o`00
0ooonf[o<ol0oc?o0002o`3o:003o`3oQOl0on7o0?oQ00Ko06Ko4ooonfX001?ooo]Z1Ol0I_l00ol0
on7o0?lXo`3o:002o`3o:0;ooo]Z1_n?o`0JoookJPSookP0]_oonfX3o`00O`?ooo]Z0ol007l7oook
JPOo001o2OoonfX5o`0008Cooo]Z3?ooG017oookJPSookP03ooonfX7on_o00?ooo]Z1_n?o`02oc?o
00;o0?lX0_l0ohD00ol0on7o0<;oo`1Vo`04o`1Voa?ooo]Z000CoookJPGo06Ko00Co0?oQo`3o:?l0
obSo0?lX0ooonfX6ohoo01Wooo]Z2?oo^02goookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007l:oook
JPGo0000QOoonfX<oomL04Kooo]Z2?oo^00?oookJPOojol00ooonfX6ohoo00;o<ol00_l0obP2o`3o
Q@03o`3ohOl0`_oo06Ko00Co06Ko4ooonfX001?ooo]Z1Ol0I_l01?l0on7o0?lXo`3o:?l0obP3oook
JPGoSol06_oonfX7oonh0;Sooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`kooo]Z1Ol00027oook
JPcooe`0AOoonfX8oonh00oooo]Z1_o[o`03oookJPKoSol00_lco`02o`3o:0;o0?n500?o0?oQo`32
ool0I_l01?l0I_lCoookJP004ooonfX5o`1Vo`04o`3ohOl0obSo0?lXo`3o:0;ooo]Z1_n?o`0Ioook
JPSookP0^OoonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l>oookJPGo0000ROoonfX;
oomL04Gooo]Z2?oo^00>oookJPOojol00_oonfX6ohoo00?o<ol000Go0?lXo`3oQOl0ohGo0?oQo`32
o`05o`1Voa?ooo]Z000CoookJPGo06Ko00Co0?oQo`3o:?l0obSo0?lX0_oonfX6ohoo01Sooo]Z2?oo
^02joookJPOo001o2OoonfX7o`00O`Sooo]Z1Ol0002:oookJPcooe`0A?oonfX7oonh00oooo]Z1_o[
o`03oookJPGoSol00olco`001Ol0obSo0?n5o`3oQOl0on7o0<;o00Go06Ko4ooonfX001?ooo]Z1Ol0
I_l01?l0on7o0?lXo`3o:?l0obP2oookJPKoSol06?oonfX7oonh0;cooo]Z1Ol007l:oookJPOo001o
2?oonfX5o`0008cooo]Z3?ooG012oookJPSookP03_oonfX6on_o00?ooo]Z1On?o`03oc?o00;o0?lX
00?o0?n5o`3ohOl0`_l01Ol0I_lCoookJP004ooonfX5o`1Vo`04o`3ohOl0obSo0?lXo`3o:0;ooo]Z
1_n?o`0GoookJPSookP0f_oonfX5o`0008gooo]Z3?ooG012oookJPSookP03OoonfX7on_o00;ooo]Z
1_n?o`02oc?o00;o0?lX00?o0?n5o`3ohOl0`_l01Ol0I_lCoookJP004ooonfX5o`1Vo`05o`3ohOl0
obSo0?lXo`3o:?oonfX01_n?o`0HoookJPOookP0fooonfX5o`0008oooo]Z3?ooG011oookJPOookP0
3_oonfX6on_o00;ooo]Z1_n?o`02oc?o00;o0?lX00?o0?n5o`3ohOl0`_l01Ol0I_lCoookJP004ooo
nfX5o`1Vo`05o`3ohOl0obSo0?lXo`3o:?oonfX01_n?o`0GoookJPOookP0g?oonfX5o`00093ooo]Z
3?ooG010oookJPSookP03OoonfX7on_o0003oookJ_n?o`3oSol000CoSol00_lco`02o`3o:003o`3o
QOl0on7o0<;o00Go06Ko4ooonfX001?ooo]Z1Ol0I_l01Ol0on7o0?lXo`3o:?l0obSooo]Z00KoSol0
5_oonfX8oonh0=cooo]Z1Ol0002BoookJPcooe`0?ooonfX7oonh00gooo]Z1oo[o`02oookJPGoSol0
0_lco`02o`3o:003o`3oQOl0on7o0<;o00Go06Ko4ooonfX001?ooo]Z1Ol0I_l00ol0on7o0?lXo`3o
:002oookJPKoSol05_oonfX7oonh0=gooo]Z1Ol0002DoookJP_ooe`0?ooonfX7oonh00gooo]Z1_o[
o`02oookJPGoSol00_lco`02o`3o:003o`3oQOl0on7o0<;o00Go06Ko4ooonfX001?ooo]Z1Ol0I_l0
0ol0on7o0?lXo`3o:002oookJPGoSol05_oonfX8oonh0=gooo]Z1Ol0002EoookJPcooe`0?OoonfX8
oonh00cooo]Z1oo[o`000ooonf[oSol0ohoo0003ohoo00;o<ol00_l0obP00ol0ohGo0?oQo`32o`05
o`1Voa?ooo]Z000CoookJPGo06Ko00Co0?oQo`3o:?l0obSooo]Z1_n?o`0FoookJPOookP0g_oonfX5
o`0009Oooo]Z3?ooG00loookJPOookP03OoonfX6on_o0003oookJ_n?o`3oSol000?oSol00_lco`02
o`3o:003o`3oQOl0on7o0<;o00Go06Ko4ooonfX001?ooo]Z1Ol0I_l01?l0on7o0?lXo`3o:?oonfX6
ohoo01Gooo]Z1ooo^03OoookJPGo0000V?oonfX<oomL03_ooo]Z2?oo^00<oookJPKojol000?ooo]Z
ohoo0?n?o`000on?o`03oc?o0004o`3o:?l0ohGo0?oQo`32o`Go06Ko4ooonfX001;ooo]Z1_l0I_l0
1?l0on7o0?lXo`3o:?oonfX6ohoo01Cooo]Z2?oo^03OoookJPGo0000V_oonfX<oomL03[ooo]Z1ooo
^00<oookJPOojol000?ooo]Zohoo0?n?o`000on?o`02oc?o0004o`3o:?l0ohGo0?oQo`32o`Go06Ko
4ooonfX001;ooo]Z1_l0I_l01?l0on7o0?lXo`3o:?oonfX6ohoo01Cooo]Z1ooo^03PoookJPGo0000
VooonfX=oomL03Wooo]Z1ooo^00<oookJPKojol000?ooo]Zohoo0?n?o`000on?o`02oc?o0004o`3o
:?l0ohGo0?oQo`32o`Go06Ko4ooonfX001;ooo]Z1_l0I_l01?l0on7o0?lXo`3o:?oonfX5ohoo01Co
oo]Z2?oo^03PoookJPGo0000WOoonfX<oomL03Sooo]Z2?oo^00;oookJPKojol000?ooo]Zohoo0?n?
o`000on?o`02oc?o0004o`3o:?l0ohGo0?n5o`32o`Go06Ko4ooonfX001;ooo]Z1_l0I_l00ol0on7o
0?lXo`3o:006ohoo01?ooo]Z2?oo^03QoookJPGo0000WooonfX<oomL03Oooo]Z1ooo^00;oookJPOo
jol01On?o`02oc?o0004o`3o:?l0ohGo0?n5o`32o`Go06Ko4ooonfX001;ooo]Z1Ol0I_l2o`3oh@;o
0?lX1_n?o`0CoookJPOookP0h_oonfX5o`000:3ooo]Z3OooG00eoookJPSookP02ooonfX6on_o00Go
Sol00_lco`02o`3o:003o`3oQOl0`_oo06Ko00Co06Ko4ooonfX001;ooo]Z1Ol0I_l01?l0on7o0?lX
o`3o:?oonfX6ohoo01;ooo]Z2?oo^03RoookJPGo0000X_oonfX<oomL03Gooo]Z1ooo^00;oookJPKo
jol000?ooo]Zohoo0?n?o`000_n?o`02oc?o00;o0?lX00?o0?n5o`32ool0I_l01?l0I_lCoookJP00
4_oonfX5o`1Vo`04o`3ohOl0obSo0?lXoookJPKoSol04_oonfX7oonh0>?ooo]Z1Ol0002ToookJPco
oe`0=?oonfX7oonh00[ooo]Z1oo[o`04ohoo00;o<ol00_l0obP00ol0ohGo0?oQo`1Vo`04o`1Voa?o
oo]Z000BoookJPGo06Ko00Co0?oQo`3o:?l0obSooo]Z1On?o`0BoookJPOookP0i?oonfX5o`000:Go
oo]Z3OooG00boookJPSookP02_oonfX6on_o00CoSol00_lco`02o`3o:003o`3oQOl0on7o06Ko00Co
06Ko4ooonfX001;ooo]Z1Ol0I_l00ol0on7o0?lXo`3o:006ohoo017ooo]Z2?oo^03ToookJPGo0000
YooonfX<oomL03;ooo]Z1ooo^00:oookJPKojol01On?o`001Olco`3o0?lXo`3o:?l0ohGo0?oQ00Go
06Ko4ooonfX001;ooo]Z1Ol0I_l00ol0on7o0?lXo`3o:006ohoo017ooo]Z1ooo^03UoookJPGo0000
ZOoonfX<oomL033ooo]Z2?oo^009oookJPKojol01On?o`001Olco`3o0?lXo`3o:?l0ohGo0?oQ00Ko
06Ko4_oonfX001;ooo]Z1Ol0I_l00ol0on7o0?lXo`3o:006ohoo013ooo]Z2?oo^03UoookJPGo0000
Z_oonfX<oomL033ooo]Z2?oo^009oookJPKojol01?n?o`02oc?o0003o`3o:?l0ohGo0?oQ00Ko06Ko
4_oonfX001;ooo]Z1Ol0I_l00ol0on7o0?lXo`3o:006ohoo013ooo]Z1ooo^03VoookJPGo0000[?oo
nfX<oomL02oooo]Z1ooo^009oookJPKojol01?n?o`02oc?o0003o`3o:?l0ohGo0?oQ00Ko06Ko4_oo
nfX001;ooo]Z1Ol0I_l00ol0on7o0?lXo`3o:005ohoo013ooo]Z1ooo^03WoookJPGo0000[_oonfX<
oomL02gooo]Z2?oo^008oookJPKojol01?n?o`02oc?o0003o`3o:?l0ohGo0?oQ00Ko06Ko4_oonfX0
01;ooo]Z1Ol0I_l00ol0on7o0?lXo`3o:005ohoo00oooo]Z2?oo^03WoookJPGo0000[ooonfX<oomL
02gooo]Z1ooo^009oookJPGojol01?n?o`02oc?o0004o`3o:?l0ohGo0?oQo`32o`Go06Ko4_oonfX0
01;ooo]Z1Ol0I_l00ol0on7o0?lXo`3o:005ohoo00oooo]Z1ooo^03XoookJPGo0000/OoonfX<oomL
02cooo]Z1ooo^008oookJPGojol01?n?o`02oc?o0004o`3o:?l0ohGo0?oQo`32o`Go06Ko4_oonfX0
01;ooo]Z1Ol0I_l00ol0on7o0?lXohoo0005ohoo00kooo]Z2?oo^03XoookJPGo0000/_oonfX=oomL
02[ooo]Z2?oo^007oookJPKojol00on?o`02oc?o0004o`3o:?l0ohGo0?oQo`32o`Go06Ko4_oonfX0
01;ooo]Z1Ol0I_l00ol0on7o0?lXohoo0005ohoo00gooo]Z2?oo^03YoookJPGo0000]?oonfX<oomL
02[ooo]Z1ooo^007oookJPKojol01?n?o`001Olco`3o0?lXo`3oQOl0on7o0<;o00Go06Ko4_oonfX0
01;ooo]Z1Ol0I_l00ol0on7o0?lXohoo0004ohoo00kooo]Z1ooo^03ZoookJPGo0000]_oonfX<oomL
02Sooo]Z2?oo^007oookJPGojol01?n?o`001Olco`3o0?lXo`3oQOl0ohGo0<;o00Go06Ko4_oonfX0
01;ooo]Z1Ol0I_l00ol0on7o0?lXohoo0004ohoo00gooo]Z2?oo^03ZoookJPGo0000]ooonfX=oomL
02Oooo]Z1ooo^007oookJPGojol01?n?o`001Olco`3o0?lXo`3o:?l0ohGo0<;o00Go06Ko4_oonfX0
01;ooo]Z1Ol0I_l00ol0on7o0?lXohoo0004ohoo00gooo]Z1ooo^03[oookJPGo0000^OoonfX<oomL
02Oooo]Z1ooo^006oookJPGojol01?n?o`001Olco`3o0?lXo`3o:?l0ohGo0<;o00Go06Ko4_oonfX0
01;ooo]Z1Ol0I_l00ol0on7o0?lXohoo0004ohoo00cooo]Z1ooo^03/oookJPGo0000^ooonfX<oomL
02Gooo]Z2?oo^006oookJPCojol01?n?o`02oc?o0003o`3o:?l0ohGo0<;o00Go06Ko4_oonfX001;o
oo]Z1Ol0I_l00ol0on7o0?lXohoo0004ohoo00_ooo]Z2?oo^03/oookJPGo0000_?oonfX=oomL02Co
oo]Z1ooo^006oookJPGojol00on?o`02oc?o0003o`3o:?l0ohGo0<;o00Go06Ko4_oonfX001;ooo]Z
1Ol0I_l00ol0on7o0?lXohoo0004ohoo00_ooo]Z1ooo^03]oookJPGo0000__oonfX<oomL02?ooo]Z
2?oo^005oookJPGojol00on?o`02oc?o0003o`3o:?l0ohGo0<;o00Go06Ko4_oonfX001;ooo]Z1Ol0
I_l00ol0on7o0?lXohoo0003ohoo00_ooo]Z2?oo^03]oookJPGo0000`?oonfX<oomL02;ooo]Z1ooo
^005oookJPGojol00on?o`02oc?o0003o`3o:?l0ohGo0<;o00Go06Ko4_oonfX001;ooo]Z1Ol0I_l0
0ol0on7o0?lXohoo0003ohoo00_ooo]Z1ooo^03^oookJPGo0000`OoonfX<oomL02;ooo]Z1ooo^005
oookJPCojol01?n?o`001?lco`3o0?lXo`3oQOl0`_l5o`1Voa;ooo]Z000BoookJPGo06Ko0_l0obP4
ohoo00[ooo]Z1ooo^03_oookJPGo0000`ooonfX<oomL023ooo]Z2?oo^004oookJPCojol01?n?o`00
1?lco`3o0?lXo`3oQOl0`_l5o`1Voa;ooo]Z000AoookJPKo06Ko0_l0obP4ohoo00Wooo]Z2?oo^03_
oookJPGo0000aOoonfX<oomL01oooo]Z1ooo^004oookJPGojol00on?o`001?lco`3o0?lXo`3oQOl0
`_l5o`1Voa;ooo]Z000AoookJPKo06Ko00?o0?lXohoo0?n?o`000on?o`09oookJPOookP0l?oonfX5
o`000<Kooo]Z3?ooG00NoookJPSookP01?oonfX4on_o00?oSol000Co<ol0o`3o:?l0ohGo0<;o1Ol0
I_lBoookJP004OoonfX6o`1Vo`03o`3o:?n?o`3oSol000;oSol02OoonfX8oonh0?3ooo]Z1Ol00038
oookJPcooe`07OoonfX7oonh00Cooo]Z1?o[o`03ohoo0004oc?o0?l0obSo0?n5o`32o`Go06Ko4_oo
nfX0017ooo]Z1_l0I_l00ol0obSoSol0ohoo0002ohoo00Wooo]Z1ooo^03aoookJPGo0000bOoonfX<
oomL01gooo]Z1ooo^003oookJPCojol00on?o`001?lco`3o0?lXo`3oQOl0`_l5o`1Voa;ooo]Z000A
oookJPGo06Ko00?o0?oQo`3o:?n?o`000on?o`08oookJPOookP0l_oonfX5o`000<_ooo]Z3?ooG00K
oookJPSookP00ooonfX3on_o00?oSol000Co<ol0o`3o:?l0ohGo0<;o1Ol0I_lBoookJP004OoonfX5
o`1Vo`03o`3ohOl0obSoSol000?oSol01ooonfX8oonh0?;ooo]Z1Ol0003=oookJP_ooe`06ooonfX7
oonh00?ooo]Z1?o[o`02ohoo00;o<ol000?o0?n5o`3ohOl0I_l01?l0I_lBoookJP004OoonfX5o`1V
o`03o`3ohOl0obSoSol000?oSol01ooonfX7oonh0??ooo]Z1Ol0003>oookJPcooe`06OoonfX8oonh
00;ooo]Z1?o[o`02ohoo00;o<ol000?o0?n5o`3ohOl0I_l01?l0I_lBoookJP004OoonfX5o`1Vo`03
o`3ohOl0obSoSol000?oSol01_oonfX8oonh0??ooo]Z1Ol0003@oookJPcooe`06?oonfX7oonh00;o
oo]Z1?o[o`03ohoo0003oc?o0?l0obSo0?n500Go06Ko4_oonfX0017ooo]Z1Ol0I_l00ol0on7o0?lX
ohoo0002ohoo00Oooo]Z1ooo^03doookJPGo0000dOoonfX<oomL01Sooo]Z1ooo^002oookJP?ojol0
0on?o`000olco`3o0?lXo`3oQ@05o`1Voa;ooo]Z000AoookJPGo06Ko00?o0?oQo`3o:?n?o`000_n?
o`06oookJPOookP0mOoonfX5o`000=?ooo]Z3?ooG00FoookJPOookP00_oonfX3on_o00?oSol000?o
<ol0o`3o:?l0ohD01Ol0I_lBoookJP004OoonfX5o`1Vo`03o`3ohOl0obSoSol000;oSol01OoonfX8
oonh0?Gooo]Z1Ol0003DoookJPcooe`05_oonfX7oonh0003oookJ_o[o`3ojol000;ojol00_n?o`00
0olco`3o0?lXo`3oQ@05o`1Voa;ooo]Z000AoookJPGo06Ko00?o0?oQo`3o:?n?o`000_n?o`05oook
JPOookP0m_oonfX5o`000=Kooo]Z3?ooG00DoookJPOookP00_oonfX3on_o00;oSol000?o<ol0o`3o
:?l0ohD01Ol0I_lBoookJP004OoonfX5o`1Vo`03o`3ohOl0obSoSol000;oSol01?oonfX8oonh0?Ko
oo]Z1Ol0003HoookJP_ooe`05?oonfX7oonh0004oookJ_o[o`3ojol0on_o00;oSol000?o<ol0o`3o
:?l0ohD01Ol0I_lBoookJP004OoonfX5o`1Vo`04o`3ohOn?o`3oSol0ohoo00Gooo]Z1ooo^03goook
JPGo0000fOoonfX<oomL01;ooo]Z2?oo^003on_o00;oSol000?o<ol0o`3o:?l0ohD01Ol0I_lBoook
JP004OoonfX5o`1Vo`04o`3ohOn?o`3oSol0ohoo00Cooo]Z1ooo^03hoookJPGo0000fooonfX<oomL
017ooo]Z1ooo^0000ooonf[ojol0on_o0002ohoo0003oc?o0?l0obSo0?n500Go06Ko4_oonfX0017o
oo]Z1Ol0I_l01?l0on7oSol0ohoo0?n?o`04oookJPOookP0n?oonfX5o`000=cooo]Z3?ooG00@oook
JPSookP00oo[o`02ohoo0003oc?o0?l0ohGo06Ko00Co06Ko4_oonfX0017ooo]Z1Ol0I_l01?l0obSo
Sol0ohoo0?n?o`03oookJPOookP0nOoonfX5o`000=kooo]Z3?ooG00?oookJPOookP00oo[o`02ohoo
0003oc?o0?l0ohGo06Ko00Co06Ko4_oonfX0017ooo]Z1Ol0I_l01?l0obSoSol0ohoo0?n?o`02oook
JPSookP0nOoonfX5o`000=oooo]Z3OooG00>oookJPKookP00oo[o`02ohoo0003oc?o0?l0ohGo06Ko
00Co06Ko4_oonfX0017ooo]Z1Ol0I_l00ol0obSoSol0ohoo0003oookJPOookP0n_oonfX5o`000>7o
oo]Z3?ooG00=oookJPOookP00_o[o`02ohoo0003oc?o0?l0ohGo06Ko00Co06Ko4_oonfX0017ooo]Z
1Ol0I_l00ol0obSoSol0ohoo0002oookJPSookP0n_oonfX5o`000>?ooo]Z3?ooG00<oookJPKookP0
0_o[o`02ohoo0003oc?o0?l0ohGo06Ko00Co06Ko4_oonfX0017ooo]Z1Ol0I_l00ol0obSoSol0ohoo
0002oookJPOookP0nooonfX5o`000>Cooo]Z3OooG00:oookJPKookP00oo[o`000on?o`3o<ol0o`3o
Q@06o`1Voa7ooo]Z000AoookJPGo06Ko00Co0?lXohoo0?n?o`3ooo]Z1ooo^03loookJPGo0000i_oo
nfX<oomL00[ooo]Z1_oo^002on_o0003ohoo0?lco`3o0?lX00Ko06Ko4OoonfX0017ooo]Z1Ol0I_l0
1?l0obSoSol0ohoo0?oonfX7oonh0?cooo]Z1Ol0003XoookJPcooe`02?oonfX6oonh00;ojol000?o
Sol0oc?o0?l0obP01_l0I_lAoookJP004OoonfX5o`1Vo`03o`3o:?n?o`3oSol000OookP0oOoonfX5
o`000>Wooo]Z3OooG007oookJPGookP00_o[o`02ohoo0003o`3o:?l0I_oo06Ko00Co06Ko4OoonfX0
017ooo]Z1Ol0I_l00ol0obSoSol0oonh0007oonh0?gooo]Z1Ol0003[oookJPcooe`01ooonfX5oonh
0005on_o0?n?o`3oSol0o`3o:?l0`_l01Ol0I_lAoookJP004OoonfX5o`1Vo`;oSol01ooo^03noook
JPGo0000kOoonfX<oomL00Gooo]Z1Ooo^002on_o0003ohoo0?l0obSo0<;o00Go06Ko4OoonfX0013o
oo]Z1_l0I_l2ohoo00OookP0o_oonfX5o`000>kooo]Z3?ooG005oookJPCookP00_o[o`000on?o`3o
<ol0o`32o`05o`1Voa7ooo]Z000@oookJPKo06Ko0_n?o`06oonh0?oooo]Z1Ol0003`oookJPcooe`0
0ooonfX4oonh00;ojol000?oSol0oc?o0?l0`_l01Ol0I_lAoookJP004?oonfX6o`1Vo`;oSol01Ooo
^03ooookJP7ooo]Z1Ol0003boookJPcooe`00_oonfX4oonh0004on_o0?n?o`3o<ol0o`32o`Go06Ko
4OoonfX0013ooo]Z1_l0I_l00on?o`3ookP0oonh0004oonh0?oooo]Z0OoonfX5o`000??ooo]Z3?oo
G0000ooonf[ookP0oonh0002oonh0004on_o0?n?o`3o<ol0o`32o`Go06Ko4OoonfX0013ooo]Z1Ol0
I_l00ol0on7oSol0oonh0004oonh0?oooo]Z0_oonfX5o`000?Gooo]Z3?ooG003oonh00;ojol000?o
<ol0o`3oQOl0I_l01?l0I_lAoookJP004?oonfX5o`1Vo`03o`3ohOn?o`3ookP000CookP0oooonfX2
oookJPGo0000m_oonfX<oomL00?ookP000?ojol0ohoo0?l0ohD01Ol0I_lAoookJP004?oonfX5o`1V
o`03o`3ohOn?o`3ookP000?ookP0oooonfX3oookJPGo0000n?oonfX:oomL00?ookP000?ojol0ohoo
0?l0ohD01Ol0I_lAoookJP004?oonfX5o`1Vo`03o`3ohOn?o`3ookP000;ookP0oooonfX4oookJPGo
0000n_oonfX9oomL00;ookP000?ojol0ohoo0?l0ohD01Ol0I_lAoookJP004?oonfX5o`1Vo`03o`3o
:?n?o`3ookP000;ookP0oooonfX4oookJPGo0000nooonfX8oomL00;ookP000?ojol0ohoo0?l0ohD0
1Ol0I_lAoookJP004?oonfX5o`1Vo`04o`3o:?oo^03ookP0oonh0?oooo]Z1OoonfX5o`000?gooo]Z
1oooG002oonh0003on_o0?l0ohGo06Ko00Co06Ko4OoonfX0013ooo]Z1Ol0I_l01?l0obSookP0oonh
0?oo^03goookJP?o001o2_oonfX5o`000?oooo]Z1OooG002oonh0003on_o0?l0obSo06Ko00Co06Ko
4OoonfX0013ooo]Z1Ol0I_l00on?o`3ookP0oonh003hoookJP?o001o2_oonfX5o`000?oooo]Z0Ooo
nfX5oomL0003oonh0?o[o`3o<ol000Go06Ko4OoonfX0013ooo]Z1Ol0I_l00on?o`3ookP0oonh003o
ool00?ooo`003_oo0003oomL00;ookP000?o<ol0o`1Vool0I_l00ol0I_lAoookJP004?oonfX5o`1V
o`03ohoo0?oo^03oo`000?ooo`00oooo000?ool000?ooe`000?ookP0ohoo0?l0I_l01?l0I_lAoook
JP004?oonfX5o`1Vo`03oonh0?oo003oo`000?ooo`00oooo000Aool000;ooe`000?ojol0o`1Vool0
I_l00ol0I_lAoookJP004?oonfX5o`1Vo`03oonh0?oo003oo`000?ooo`00oooo000Cool00003oonh
0?l0I_oo06Ko00?o06Ko4OoonfX0013ooo]Z1Ol0I_ooool00?ooo`005ooo0005o`1Voa7ooo]Z003o
oookJQ7ooo]Z0ol007l:oookJPGo0000oooonfXOoookJP00oooonfXAoookJP?o001o2_oonfX5o`00
0?oooo]Z7ooonfX00?oooo]Z3_oonfX6o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJPkooo]Z
1_l007l:oookJPGo0000oooonfXOoookJP00oooonfX@oookJPCo001o2_oonfX5o`000?oooo]Z7ooo
nfX00?oooo]Z4OoonfX3o`00O`[ooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooook
JQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z003ooookJQkooo]Z1Ol0003ooookJQoooo]Z
0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.06829, -1.067, \
0.00371579, 0.00601229}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Evaluate[Table[LegendreQ[i, x], {i, 0, 10}]], {x, \(-1\), 1}, \ 
      PlotStyle \[Rule] MyPlotStyle[11]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.317805 0.116035 [
[.02381 .3053 -13.4688 -20 ]
[.02381 .3053 13.4688 0 ]
[.2619 .3053 -20.9688 -20 ]
[.2619 .3053 20.9688 0 ]
[.7381 .3053 -14.5 -20 ]
[.7381 .3053 14.5 0 ]
[.97619 .3053 -7 -20 ]
[.97619 .3053 7 0 ]
[.4875 .08573 -26.9375 -10 ]
[.4875 .08573 0 10 ]
[.4875 .20177 -26.9375 -10 ]
[.4875 .20177 0 10 ]
[.4875 .43384 -14 -10 ]
[.4875 .43384 0 10 ]
[.4875 .54987 -14 -10 ]
[.4875 .54987 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .3178 m
.02381 .32405 L
s
gsave
.02381 .3053 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.2619 .3178 m
.2619 .32405 L
s
gsave
.2619 .3053 -81.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.7381 .3178 m
.7381 .32405 L
s
gsave
.7381 .3053 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.97619 .3178 m
.97619 .32405 L
s
gsave
.97619 .3053 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .3178 m
.07143 .32155 L
s
.11905 .3178 m
.11905 .32155 L
s
.16667 .3178 m
.16667 .32155 L
s
.21429 .3178 m
.21429 .32155 L
s
.30952 .3178 m
.30952 .32155 L
s
.35714 .3178 m
.35714 .32155 L
s
.40476 .3178 m
.40476 .32155 L
s
.45238 .3178 m
.45238 .32155 L
s
.54762 .3178 m
.54762 .32155 L
s
.59524 .3178 m
.59524 .32155 L
s
.64286 .3178 m
.64286 .32155 L
s
.69048 .3178 m
.69048 .32155 L
s
.78571 .3178 m
.78571 .32155 L
s
.83333 .3178 m
.83333 .32155 L
s
.88095 .3178 m
.88095 .32155 L
s
.92857 .3178 m
.92857 .32155 L
s
.01 w
0 .3178 m
1 .3178 L
s
.25 Mabswid
.5 .08573 m
.50625 .08573 L
s
gsave
.4875 .08573 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .20177 m
.50625 .20177 L
s
gsave
.4875 .20177 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .43384 m
.50625 .43384 L
s
gsave
.4875 .43384 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .54987 m
.50625 .54987 L
s
gsave
.4875 .54987 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .10894 m
.50375 .10894 L
s
.5 .13215 m
.50375 .13215 L
s
.5 .15536 m
.50375 .15536 L
s
.5 .17856 m
.50375 .17856 L
s
.5 .22498 m
.50375 .22498 L
s
.5 .24818 m
.50375 .24818 L
s
.5 .27139 m
.50375 .27139 L
s
.5 .2946 m
.50375 .2946 L
s
.5 .34101 m
.50375 .34101 L
s
.5 .36422 m
.50375 .36422 L
s
.5 .38743 m
.50375 .38743 L
s
.5 .41063 m
.50375 .41063 L
s
.5 .45705 m
.50375 .45705 L
s
.5 .48025 m
.50375 .48025 L
s
.5 .50346 m
.50375 .50346 L
s
.5 .52667 m
.50375 .52667 L
s
.5 .06253 m
.50375 .06253 L
s
.5 .03932 m
.50375 .03932 L
s
.5 .01611 m
.50375 .01611 L
s
.5 .57308 m
.50375 .57308 L
s
.5 .59629 m
.50375 .59629 L
s
.01 w
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02781 0 m
.02846 .00928 L
.03053 .03083 L
.03279 .04774 L
.03527 .06205 L
.0379 .07421 L
.04262 .09126 L
.05205 .11544 L
.06244 .13427 L
.07293 .14887 L
.0842 .16158 L
.10458 .1798 L
.1458 .20653 L
.18551 .22572 L
.22371 .2409 L
.26435 .25486 L
.30348 .26688 L
.34506 .27863 L
.38513 .28925 L
.42368 .29905 L
.46468 .30918 L
.50417 .31882 L
.54214 .3281 L
.58257 .33813 L
.62148 .34807 L
.66284 .35915 L
.70268 .37055 L
.74101 .38249 L
.78179 .39675 L
.82106 .41277 L
.85881 .43164 L
.87978 .4445 L
.89901 .45869 L
.91786 .47617 L
.92745 .48721 L
.9377 .50156 L
.94804 .52038 L
.95744 .54454 L
.96198 .56088 L
.96436 .57169 L
.96689 .58579 L
.9691 .60167 L
.97027 .61222 L
s
.97027 .61222 m
.9708 .61803 L
s
1 .36 0 r
.02493 .61803 m
.02499 .58929 L
.02605 .55099 L
.02729 .52477 L
.02846 .50729 L
.03053 .48469 L
.03279 .46675 L
.03527 .45137 L
.0379 .43816 L
.04262 .41937 L
.05205 .39213 L
.06244 .37041 L
.0842 .33818 L
.10458 .31637 L
.14335 .28612 L
.18458 .26303 L
.22428 .24618 L
.26248 .23347 L
.30312 .22287 L
.34225 .215 L
.36223 .21177 L
.38383 .20882 L
.40294 .20666 L
.4239 .20476 L
.44384 .20339 L
.45473 .20282 L
.4649 .2024 L
.46991 .20223 L
.47536 .20208 L
.48016 .20197 L
.48526 .20188 L
.48984 .20182 L
.49245 .2018 L
.49364 .20179 L
.4949 .20178 L
.49596 .20178 L
.49713 .20177 L
.4982 .20177 L
.49919 .20177 L
.50036 .20177 L
.50142 .20177 L
.50265 .20177 L
.50381 .20178 L
.50497 .20178 L
.5062 .20179 L
.50844 .20181 L
.5111 .20183 L
.51353 .20186 L
.51881 .20195 L
.52383 .20206 L
Mistroke
.53266 .20232 L
.54228 .20269 L
.56199 .20375 L
.58298 .20533 L
.60443 .20744 L
.62461 .2099 L
.66321 .21598 L
.70427 .2246 L
.74381 .23536 L
.78183 .2485 L
.82231 .26643 L
.86127 .28919 L
.88112 .30389 L
.90268 .3235 L
.92342 .34808 L
.93331 .36302 L
.94258 .38016 L
.95028 .39799 L
.95857 .42364 L
.96305 .44264 L
.9655 .45573 L
.96777 .47071 L
.96971 .487 L
.97179 .51063 L
.97298 .5296 L
.9741 .55519 L
.9751 .59387 L
Mfstroke
.9751 .59387 m
.97515 .61803 L
s
1 .72 0 r
.02478 0 m
.02499 .10582 L
.02605 .14511 L
.02729 .17231 L
.02846 .19062 L
.03053 .21449 L
.03279 .23364 L
.0379 .26441 L
.04262 .28475 L
.05224 .31459 L
.06244 .33706 L
.0728 .35436 L
.0825 .36723 L
.09382 .37933 L
.10458 .3886 L
.11426 .39546 L
.12483 .40162 L
.14335 .40971 L
.15367 .41297 L
.16302 .41526 L
.16821 .41628 L
.17382 .4172 L
.17909 .4179 L
.184 .41842 L
.18858 .41879 L
.19094 .41893 L
.1935 .41906 L
.19496 .41912 L
.1963 .41917 L
.19757 .41921 L
.19896 .41924 L
.2002 .41926 L
.20137 .41927 L
.20261 .41928 L
.2033 .41928 L
.20394 .41928 L
.20516 .41927 L
.20647 .41926 L
.20771 .41923 L
.20884 .41921 L
.21159 .41913 L
.2142 .41902 L
.21938 .41873 L
.225 .4183 L
.23446 .41731 L
.24488 .41587 L
.26592 .41195 L
.28537 .40726 L
.30626 .40123 L
.34754 .38686 L
Mistroke
.3873 .37064 L
.42554 .3535 L
.46624 .3342 L
.50542 .31516 L
.54706 .29502 L
.58717 .27628 L
.62578 .25942 L
.66683 .24342 L
.70637 .23062 L
.72627 .22543 L
.7444 .22157 L
.75377 .21995 L
.76394 .21849 L
.76953 .21784 L
.7747 .21734 L
.7796 .21695 L
.78217 .21678 L
.78487 .21663 L
.78728 .21652 L
.78855 .21648 L
.78991 .21643 L
.79117 .2164 L
.7923 .21637 L
.79345 .21635 L
.79452 .21634 L
.79562 .21633 L
.79679 .21633 L
.79778 .21633 L
.79887 .21634 L
.80004 .21636 L
.8013 .21638 L
.80249 .2164 L
.80357 .21644 L
.80621 .21653 L
.80864 .21665 L
.81416 .21703 L
.81902 .21749 L
.82419 .21813 L
.83355 .21966 L
.84364 .22192 L
.85317 .22471 L
.86191 .22788 L
.88081 .23712 L
.89152 .2441 L
.9015 .25201 L
.91201 .26216 L
.92193 .27393 L
.93096 .28703 L
.94051 .30439 L
.94935 .32521 L
Mistroke
.95403 .33911 L
.95907 .35752 L
.96369 .37946 L
.96791 .40737 L
.96994 .42589 L
.97101 .43808 L
.97216 .45399 L
.97325 .47391 L
.97425 .4994 L
.97525 .54309 L
Mfstroke
.97525 .54309 m
.97537 .61803 L
s
.92 1 0 r
.02473 .61803 m
.02499 .48925 L
.02605 .44881 L
.02729 .42054 L
.02846 .40139 L
.03053 .3763 L
.03279 .35614 L
.03527 .3388 L
.0379 .32393 L
.04262 .30301 L
.04749 .28645 L
.05205 .27405 L
.06244 .25324 L
.06788 .24528 L
.07305 .2391 L
.08274 .23041 L
.08816 .22691 L
.09318 .22437 L
.0987 .22229 L
.10178 .22142 L
.10458 .22079 L
.1069 .22038 L
.10945 .22004 L
.11074 .21991 L
.11212 .2198 L
.11342 .21973 L
.1146 .21968 L
.11578 .21966 L
.11687 .21966 L
.11807 .21967 L
.11934 .21971 L
.12044 .21977 L
.12147 .21983 L
.12383 .22004 L
.12637 .22034 L
.12905 .22074 L
.13385 .22166 L
.14465 .22462 L
.15419 .22809 L
.16439 .23256 L
.18275 .24215 L
.22425 .2685 L
.26423 .29639 L
.3027 .32267 L
.34362 .34789 L
.38302 .36801 L
.42091 .38254 L
.44036 .38794 L
.4512 .39031 L
.46125 .3921 L
Mistroke
.47138 .39349 L
.47673 .39405 L
.48242 .39453 L
.48504 .3947 L
.48786 .39486 L
.49035 .39497 L
.49171 .39502 L
.49297 .39506 L
.49422 .39509 L
.49535 .39512 L
.49661 .39514 L
.4973 .39515 L
.49795 .39515 L
.49909 .39516 L
.50014 .39516 L
.5013 .39516 L
.50253 .39515 L
.50367 .39513 L
.50492 .39511 L
.50622 .39508 L
.50743 .39505 L
.51192 .39487 L
.51449 .39473 L
.51682 .39458 L
.52204 .39417 L
.53145 .39314 L
.54033 .39184 L
.56038 .38776 L
.57885 .38261 L
.6183 .36741 L
.65624 .34797 L
.69663 .32311 L
.73551 .29656 L
.77684 .26775 L
.81665 .24248 L
.83485 .23292 L
.84521 .22833 L
.85495 .22475 L
.86445 .22205 L
.8698 .22094 L
.87234 .22052 L
.8747 .2202 L
.87706 .21995 L
.87838 .21984 L
.87958 .21977 L
.8809 .21971 L
.88164 .21968 L
.88233 .21967 L
.88359 .21966 L
.88423 .21966 L
Mistroke
.88493 .21967 L
.88564 .21969 L
.88633 .21971 L
.88761 .21978 L
.88899 .21988 L
.89049 .22003 L
.89319 .22039 L
.8957 .22084 L
.90078 .22213 L
.90364 .22309 L
.90628 .22414 L
.91103 .22645 L
.91624 .22968 L
.92529 .23736 L
.93023 .24288 L
.93485 .24907 L
.93986 .25715 L
.94531 .26792 L
.95012 .27963 L
.95522 .29514 L
.9598 .31298 L
.96224 .32462 L
.96486 .3396 L
.96726 .35651 L
.96946 .37623 L
.97156 .40169 L
.97262 .41888 L
.97378 .44422 L
.97494 .48567 L
Mfstroke
.97494 .48567 m
.97522 .61803 L
s
.56 1 0 r
.02464 0 m
.02499 .17751 L
.02605 .21914 L
.02729 .24845 L
.02846 .26835 L
.03053 .29437 L
.03279 .3151 L
.03527 .33269 L
.0379 .34746 L
.04262 .36746 L
.04749 .38233 L
.05205 .39261 L
.05706 .40091 L
.05987 .40449 L
.06244 .40718 L
.06504 .4094 L
.0678 .41127 L
.07041 .41261 L
.07277 .41352 L
.07422 .41393 L
.07556 .41423 L
.07632 .41436 L
.07703 .41446 L
.07777 .41454 L
.07858 .4146 L
.07929 .41464 L
.07996 .41465 L
.08122 .41463 L
.08192 .41459 L
.08257 .41454 L
.08329 .41447 L
.08405 .41437 L
.08647 .41393 L
.08783 .41361 L
.08908 .41326 L
.09381 .41155 L
.09905 .409 L
.10458 .40569 L
.12432 .39005 L
.14269 .37223 L
.18173 .33168 L
.22323 .29318 L
.24403 .27764 L
.26321 .26602 L
.2819 .25737 L
.29132 .25402 L
.30168 .25113 L
.30689 .24998 L
.31184 .24909 L
.31634 .24843 L
Mistroke
.32113 .2479 L
.32385 .24767 L
.32631 .24751 L
.3275 .24745 L
.32879 .24739 L
.33001 .24735 L
.33112 .24732 L
.33243 .2473 L
.33365 .24729 L
.33435 .24729 L
.33499 .2473 L
.33573 .2473 L
.33642 .24731 L
.3371 .24732 L
.33782 .24734 L
.33911 .24738 L
.34049 .24744 L
.34202 .24751 L
.34438 .24766 L
.34695 .24787 L
.35214 .24842 L
.35694 .24909 L
.3614 .24984 L
.3715 .25201 L
.38227 .25499 L
.40366 .26276 L
.42382 .27207 L
.46234 .29379 L
.50331 .31996 L
.54277 .34493 L
.58071 .36578 L
.60183 .37506 L
.6211 .38163 L
.63066 .38412 L
.6357 .38521 L
.64106 .3862 L
.64572 .38691 L
.65088 .38753 L
.65314 .38775 L
.65557 .38794 L
.65788 .38809 L
.65998 .38819 L
.66121 .38824 L
.66237 .38827 L
.66359 .3883 L
.66429 .38831 L
.66493 .38831 L
.66599 .38832 L
.66716 .38831 L
.66839 .38829 L
Mistroke
.66953 .38827 L
.67088 .38823 L
.67217 .38818 L
.67457 .38805 L
.67717 .38786 L
.67999 .3876 L
.68529 .38696 L
.69093 .38604 L
.70108 .38379 L
.71138 .3807 L
.72251 .37644 L
.74269 .3663 L
.76264 .3533 L
.78371 .33662 L
.8217 .30042 L
.86215 .2585 L
.8808 .24105 L
.89063 .23322 L
.90107 .22654 L
.90632 .22401 L
.90911 .22293 L
.91212 .22201 L
.91346 .22169 L
.91487 .22141 L
.91607 .22122 L
.91739 .22107 L
.91862 .22099 L
.91932 .22096 L
.91995 .22096 L
.92117 .22099 L
.92233 .22108 L
.92349 .22122 L
.92477 .22145 L
.92611 .22176 L
.92736 .22213 L
.92959 .22299 L
.93199 .22422 L
.9348 .22609 L
.93746 .22834 L
.94246 .23403 L
.94691 .24105 L
.95094 .2494 L
.95559 .26212 L
.95996 .27824 L
.96403 .29866 L
.96777 .32508 L
.96972 .344 L
.97187 .37226 L
.97295 .39195 L
.9741 .4213 L
Mistroke
.9752 .46865 L
Mfstroke
.9752 .46865 m
.97545 .61803 L
s
.2 1 0 r
.02463 .61803 m
.02499 .43256 L
.02605 .38975 L
.02729 .35954 L
.02846 .33909 L
.03053 .3126 L
.03279 .29191 L
.03527 .27487 L
.0379 .26111 L
.04014 .25189 L
.04262 .24379 L
.04519 .23716 L
.04755 .23241 L
.05027 .22824 L
.05152 .22672 L
.05285 .22536 L
.0541 .2243 L
.05523 .22351 L
.05638 .22286 L
.05744 .22238 L
.05868 .22198 L
.05933 .22183 L
.06002 .22171 L
.06117 .22161 L
.06244 .22163 L
.06315 .2217 L
.0638 .22179 L
.06451 .22194 L
.06527 .22213 L
.06654 .22254 L
.06795 .22311 L
.07053 .22448 L
.07296 .2261 L
.07839 .23068 L
.08424 .23684 L
.10458 .26405 L
.14572 .32334 L
.16625 .34758 L
.17625 .35736 L
.18534 .36498 L
.19418 .37122 L
.20377 .37667 L
.20904 .37908 L
.21389 .38094 L
.21889 .3825 L
.22345 .38362 L
.22813 .38446 L
.2307 .38479 L
.23189 .38492 L
.23315 .38503 L
Mistroke
.23433 .38512 L
.2354 .38518 L
.23647 .38523 L
.23749 .38526 L
.23867 .38528 L
.23976 .38528 L
.24095 .38527 L
.24222 .38523 L
.2435 .38517 L
.24468 .3851 L
.24731 .38489 L
.24975 .38461 L
.25206 .38428 L
.25724 .38333 L
.26286 .38196 L
.27228 .37892 L
.28267 .3746 L
.30369 .36322 L
.34394 .33499 L
.38268 .30556 L
.40237 .2917 L
.42388 .27844 L
.44444 .26821 L
.45362 .26456 L
.46355 .26129 L
.46905 .25981 L
.4741 .25865 L
.47884 .25774 L
.48405 .25696 L
.48631 .25669 L
.48872 .25644 L
.49082 .25626 L
.49309 .25611 L
.49442 .25605 L
.49566 .256 L
.49684 .25596 L
.49809 .25593 L
.49921 .25592 L
.50026 .25592 L
.50141 .25593 L
.50265 .25595 L
.5039 .25598 L
.50504 .25602 L
.5076 .25616 L
.50997 .25633 L
.51221 .25653 L
.51722 .25713 L
.52267 .25801 L
.53364 .2605 L
.54376 .26363 L
Mistroke
.5625 .27136 L
.58313 .2825 L
.62344 .3101 L
.66223 .33964 L
.68195 .35386 L
.70347 .36744 L
.71345 .37274 L
.72408 .37752 L
.73411 .38108 L
.73845 .38231 L
.7432 .38342 L
.74808 .38431 L
.75075 .38467 L
.75324 .38494 L
.75443 .38504 L
.75557 .38512 L
.7566 .38518 L
.75769 .38523 L
.75888 .38526 L
.75998 .38528 L
.76116 .38528 L
.76246 .38526 L
.76378 .38522 L
.76444 .38519 L
.76516 .38515 L
.76763 .38496 L
.76903 .38482 L
.77052 .38465 L
.77321 .38425 L
.77849 .38318 L
.78329 .38186 L
.79328 .37807 L
.80249 .37327 L
.81259 .36654 L
.82329 .35777 L
.8612 .31408 L
.88229 .28357 L
.90156 .25523 L
.9111 .24245 L
.91613 .23642 L
.92149 .2308 L
.92664 .22639 L
.92907 .22472 L
.9313 .22347 L
.93356 .2225 L
.93474 .22212 L
.93599 .22183 L
.93708 .22167 L
.9381 .22161 L
.93921 .22163 L
Mistroke
.9404 .22178 L
.94146 .22202 L
.94263 .22241 L
.94384 .22297 L
.94499 .22365 L
.94703 .22525 L
.94922 .22759 L
.95178 .23127 L
.95422 .23587 L
.95641 .24108 L
.9588 .24818 L
.96316 .26621 L
.9656 .2803 L
.96781 .29684 L
.96989 .31722 L
.97105 .33192 L
.97213 .34862 L
.97307 .36712 L
.9741 .39466 L
.97518 .44244 L
Mfstroke
.97518 .44244 m
.97548 .61803 L
s
0 1 .16 r
.02455 0 m
.02499 .22485 L
.02605 .26874 L
.02729 .29964 L
.02846 .32037 L
.03053 .34674 L
.0317 .35793 L
.03279 .36664 L
.03506 .3811 L
.03756 .39266 L
.03882 .39716 L
.04017 .40121 L
.04262 .40676 L
.04393 .40895 L
.04516 .41056 L
.0465 .41189 L
.04725 .41246 L
.04793 .41287 L
.04917 .41339 L
.04988 .41355 L
.05052 .41363 L
.05171 .41359 L
.05297 .41332 L
.0541 .41288 L
.05531 .41224 L
.05749 .41065 L
.06008 .40814 L
.06244 .40534 L
.07281 .38905 L
.08408 .36726 L
.10458 .32639 L
.12396 .29345 L
.13426 .27958 L
.14536 .26781 L
.15051 .26348 L
.15593 .2597 L
.16095 .25689 L
.16561 .25486 L
.17 .25346 L
.17246 .25288 L
.1747 .25248 L
.17597 .2523 L
.17715 .25217 L
.17844 .25206 L
.17909 .25202 L
.1798 .25199 L
.18101 .25197 L
.1823 .25197 L
.18352 .25201 L
.18463 .25208 L
Mistroke
.18592 .25218 L
.18714 .25232 L
.18941 .25265 L
.19186 .25312 L
.1945 .25376 L
.19927 .25525 L
.20365 .25698 L
.21374 .26212 L
.22439 .26907 L
.26241 .30181 L
.30289 .33877 L
.32156 .353 L
.34185 .36496 L
.35291 .3697 L
.35777 .37135 L
.36313 .37286 L
.36817 .37398 L
.3729 .37477 L
.3755 .37509 L
.37789 .37532 L
.37914 .37541 L
.38051 .37549 L
.3812 .37553 L
.38194 .37555 L
.38263 .37558 L
.38326 .37559 L
.38446 .37561 L
.38558 .37561 L
.38681 .37559 L
.38813 .37555 L
.38879 .37553 L
.38951 .3755 L
.39082 .37542 L
.39327 .37523 L
.39559 .37498 L
.39806 .37466 L
.40249 .37391 L
.40758 .37278 L
.41237 .37148 L
.4233 .36767 L
.44346 .35784 L
.46195 .34622 L
.50154 .3166 L
.53962 .28832 L
.56085 .2754 L
.58015 .26661 L
.58977 .26352 L
.5952 .26218 L
.60021 .26122 L
.60459 .26061 L
Mistroke
.60708 .26035 L
.60941 .26017 L
.61067 .2601 L
.61187 .26005 L
.61294 .26002 L
.61411 .26 L
.61538 .26 L
.61609 .26001 L
.61673 .26002 L
.61798 .26005 L
.61916 .2601 L
.62033 .26016 L
.62157 .26025 L
.62382 .26045 L
.6265 .26076 L
.62894 .26112 L
.63424 .26213 L
.63926 .26338 L
.64811 .26629 L
.65773 .27044 L
.67752 .28199 L
.69854 .29803 L
.73631 .33259 L
.75729 .35186 L
.77653 .36719 L
.7863 .37351 L
.79539 .37821 L
.80036 .38022 L
.80487 .38167 L
.80728 .38229 L
.80988 .38284 L
.81132 .38308 L
.81264 .38326 L
.81397 .38342 L
.81524 .38352 L
.81641 .38359 L
.81768 .38364 L
.81884 .38364 L
.81992 .38363 L
.82119 .38357 L
.82235 .38349 L
.82368 .38335 L
.82494 .38319 L
.82721 .3828 L
.8293 .38233 L
.83401 .38088 L
.83881 .37884 L
.84406 .37591 L
.85466 .36778 L
.8649 .35703 L
Mistroke
.87422 .3448 L
.89516 .30971 L
.91591 .26837 L
.92503 .25053 L
.92987 .24187 L
.93507 .23365 L
.93765 .23015 L
.9401 .22728 L
.94248 .22498 L
.94364 .22407 L
.94469 .22337 L
.9457 .22282 L
.94678 .22237 L
.94793 .22207 L
.949 .22197 L
.9502 .22207 L
.95146 .22245 L
.95253 .22301 L
.95371 .2239 L
.95504 .22528 L
.95629 .22699 L
.95864 .23144 L
.95996 .23475 L
.96117 .23842 L
.96393 .24936 L
.96613 .2615 L
.96856 .28 L
.96978 .29221 L
.97109 .3086 L
.97234 .32865 L
.97347 .35356 L
.97477 .39822 L
.97551 .44593 L
Mfstroke
.97551 .44593 m
.97571 .61803 L
s
0 1 .52 r
.02455 .61803 m
.02499 .39164 L
.02605 .34683 L
.02729 .31552 L
.02846 .29484 L
.02954 .28019 L
.03053 .26928 L
.03279 .25102 L
.03396 .24406 L
.03506 .23875 L
.03636 .23367 L
.03756 .23004 L
.03881 .22712 L
.04 .22506 L
.04125 .22354 L
.04196 .22295 L
.04262 .22256 L
.04386 .22221 L
.04456 .22222 L
.04521 .22234 L
.0464 .22284 L
.04765 .22372 L
.04878 .22478 L
.04983 .22598 L
.05221 .22938 L
.05715 .23866 L
.06244 .25087 L
.08408 .30713 L
.09473 .33178 L
.10458 .35063 L
.11419 .36482 L
.11904 .37037 L
.12439 .37525 L
.12974 .37885 L
.13275 .38034 L
.13551 .38137 L
.13793 .38202 L
.13931 .38229 L
.14059 .38247 L
.14129 .38254 L
.14194 .3826 L
.14318 .38265 L
.14387 .38266 L
.1445 .38265 L
.1452 .38262 L
.14594 .38257 L
.14715 .38245 L
.14847 .38226 L
.14972 .38203 L
.15087 .38177 L
Mistroke
.15538 .38035 L
.15795 .37926 L
.16029 .3781 L
.16551 .375 L
.17495 .36779 L
.18383 .35949 L
.22243 .31584 L
.24202 .29487 L
.25239 .28536 L
.26349 .27679 L
.2742 .2703 L
.28395 .26604 L
.28865 .26455 L
.29112 .26392 L
.29375 .26337 L
.29604 .26298 L
.29726 .26281 L
.29857 .26265 L
.29977 .26253 L
.30087 .26245 L
.30192 .26239 L
.30303 .26234 L
.30427 .26231 L
.30497 .26231 L
.30561 .26231 L
.30679 .26233 L
.30804 .26238 L
.30917 .26245 L
.31021 .26253 L
.3126 .26277 L
.31517 .26314 L
.31752 .26357 L
.32281 .26483 L
.32732 .26624 L
.33224 .26809 L
.34119 .27228 L
.36094 .28469 L
.38194 .30124 L
.41966 .33341 L
.4406 .34921 L
.44978 .35509 L
.45983 .36059 L
.46892 .36463 L
.47865 .36789 L
.48403 .36919 L
.48892 .37005 L
.49128 .37035 L
.49252 .37048 L
.49384 .3706 L
.49499 .37068 L
Mistroke
.49625 .37076 L
.4974 .3708 L
.49848 .37083 L
.49973 .37085 L
.50043 .37085 L
.50106 .37084 L
.50229 .37081 L
.50345 .37077 L
.50411 .37074 L
.50481 .3707 L
.50606 .37061 L
.50887 .37033 L
.51131 .37001 L
.51358 .36965 L
.51874 .36856 L
.52769 .3659 L
.53727 .36198 L
.55853 .3498 L
.57865 .33478 L
.617 .30213 L
.6364 .28663 L
.64671 .27943 L
.65781 .27282 L
.66838 .26784 L
.67301 .26612 L
.67807 .26459 L
.6804 .26401 L
.68288 .26349 L
.68502 .26311 L
.68734 .26278 L
.68871 .26263 L
.68997 .26251 L
.69118 .26242 L
.69245 .26236 L
.69359 .26232 L
.69466 .26231 L
.69583 .26231 L
.69709 .26234 L
.69778 .26237 L
.69843 .2624 L
.69964 .26249 L
.70095 .2626 L
.70236 .26276 L
.7049 .26313 L
.70723 .26356 L
.71261 .26491 L
.71828 .26687 L
.72788 .27141 L
.73839 .27811 L
.75795 .29484 L
Mistroke
.77888 .31734 L
.79875 .34048 L
.80922 .35223 L
.82032 .36352 L
.83019 .37195 L
.83543 .37561 L
.84107 .37879 L
.84372 .37999 L
.84624 .38093 L
.8485 .38161 L
.84979 .38193 L
.85096 .38217 L
.85208 .38235 L
.85329 .3825 L
.85457 .38261 L
.85577 .38265 L
.8569 .38265 L
.8581 .38259 L
.85912 .3825 L
.86024 .38236 L
.86154 .38213 L
.86274 .38186 L
.86547 .38104 L
.86788 .38006 L
.87043 .37875 L
.87485 .37583 L
.87974 .3716 L
.89052 .3584 L
.90065 .34115 L
.92082 .29464 L
.9304 .26927 L
.93932 .2466 L
.9437 .23688 L
.94783 .2293 L
.95012 .22605 L
.95132 .22468 L
.9526 .22352 L
.95367 .2228 L
.95485 .22233 L
.95592 .2222 L
.95693 .22238 L
.95812 .22301 L
.95942 .22426 L
.96064 .22608 L
.96178 .22838 L
.9629 .23134 L
.96393 .23469 L
.96621 .24499 L
.9675 .25294 L
.96868 .26206 L
Mistroke
.96998 .27464 L
.97135 .29199 L
.97255 .31221 L
.97366 .33834 L
.97488 .38437 L
Mfstroke
.97488 .38437 m
.97538 .61803 L
s
0 1 .88 r
.02449 0 m
.02499 .26103 L
.02605 .30658 L
.02729 .33795 L
.02846 .35821 L
.02954 .37214 L
.03053 .38218 L
.03163 .39084 L
.03279 .39794 L
.03395 .40333 L
.0352 .40757 L
.03638 .41035 L
.03746 .412 L
.03873 .41304 L
.03944 .41324 L
.04011 .41322 L
.04132 .41268 L
.04262 .41149 L
.04327 .41068 L
.04396 .40968 L
.04519 .40758 L
.04797 .40157 L
.05302 .38755 L
.06244 .35654 L
.07214 .3248 L
.08253 .29575 L
.0885 .28233 L
.09393 .27237 L
.0994 .26457 L
.10207 .26155 L
.10458 .25918 L
.10697 .25732 L
.10917 .25596 L
.11161 .25482 L
.11289 .25438 L
.11423 .25402 L
.11546 .25379 L
.11677 .25364 L
.11801 .2536 L
.11913 .25363 L
.12045 .25376 L
.1212 .25388 L
.12189 .25401 L
.12315 .25432 L
.12449 .25474 L
.12667 .25562 L
.12902 .25681 L
.13326 .25957 L
.14291 .26836 L
.16408 .29548 L
Mistroke
.18419 .32395 L
.19453 .33737 L
.20426 .34844 L
.21373 .35739 L
.22243 .3638 L
.22704 .36646 L
.23191 .36868 L
.23679 .37032 L
.23956 .37099 L
.24214 .37144 L
.24345 .37161 L
.24414 .37168 L
.24487 .37174 L
.24551 .37178 L
.24621 .37182 L
.24745 .37185 L
.24865 .37185 L
.24994 .37181 L
.25116 .37174 L
.25228 .37164 L
.25359 .37149 L
.25481 .37132 L
.25757 .37079 L
.26026 .37012 L
.26313 .36924 L
.26847 .36713 L
.2734 .36471 L
.28452 .3577 L
.30468 .34085 L
.34413 .30255 L
.36397 .286 L
.37264 .28013 L
.38207 .27491 L
.38727 .2726 L
.39208 .27083 L
.39667 .26949 L
.40156 .26845 L
.40402 .26807 L
.40532 .26791 L
.40668 .26777 L
.40788 .26768 L
.40919 .2676 L
.41038 .26756 L
.41149 .26754 L
.41218 .26754 L
.41292 .26754 L
.41362 .26756 L
.41427 .26758 L
.4155 .26763 L
.4168 .26772 L
Mistroke
.41819 .26785 L
.41949 .26799 L
.42247 .26843 L
.42504 .26892 L
.42743 .26947 L
.43286 .27104 L
.44273 .27501 L
.4517 .27977 L
.46126 .28589 L
.50286 .32035 L
.52374 .33835 L
.54295 .35253 L
.55265 .35827 L
.56171 .36255 L
.56665 .36441 L
.57115 .36578 L
.57616 .36693 L
.57891 .3674 L
.58016 .36757 L
.58152 .36773 L
.58275 .36785 L
.58389 .36794 L
.58497 .368 L
.58611 .36804 L
.58737 .36807 L
.58853 .36807 L
.58981 .36804 L
.59053 .36802 L
.59118 .36799 L
.5925 .3679 L
.59371 .3678 L
.59646 .36747 L
.59888 .36708 L
.60144 .36657 L
.60598 .36539 L
.61022 .36398 L
.61987 .35973 L
.63028 .35361 L
.64017 .34648 L
.65871 .33041 L
.69697 .29323 L
.7167 .27705 L
.72238 .27333 L
.72772 .27031 L
.73248 .26806 L
.73769 .2661 L
.74014 .26538 L
.74276 .26474 L
.74524 .26429 L
.74633 .26413 L
Mistroke
.74749 .26399 L
.74812 .26393 L
.74882 .26387 L
.75004 .2638 L
.75073 .26377 L
.75147 .26376 L
.75216 .26375 L
.7528 .26376 L
.75403 .2638 L
.75473 .26384 L
.75538 .26389 L
.75656 .26401 L
.75783 .26416 L
.76022 .26457 L
.76282 .26518 L
.76752 .2667 L
.7721 .26872 L
.77632 .27103 L
.78604 .27803 L
.79513 .28653 L
.81579 .31163 L
.83442 .338 L
.85469 .36461 L
.86003 .37026 L
.86571 .37526 L
.87056 .37857 L
.87332 .37999 L
.87456 .38052 L
.87592 .381 L
.87711 .38136 L
.87838 .38165 L
.87908 .38178 L
.87972 .38187 L
.88097 .38198 L
.88211 .38201 L
.88335 .38196 L
.88452 .38182 L
.8856 .38163 L
.88684 .38131 L
.88801 .38093 L
.89067 .37974 L
.89325 .37813 L
.89604 .37589 L
.90129 .37018 L
.90616 .36308 L
.9172 .34052 L
.92693 .31366 L
.9373 .27994 L
.94693 .24822 L
.94957 .24048 L
Mistroke
.95235 .23326 L
.95473 .22818 L
.95607 .22589 L
.95734 .22418 L
.95852 .22305 L
.9598 .22241 L
.96097 .22245 L
.96205 .2231 L
.96321 .22455 L
.96449 .22722 L
.96514 .22905 L
.96583 .23144 L
.96709 .23703 L
.9682 .24356 L
.96941 .25288 L
.97067 .26582 L
.97184 .28195 L
.97294 .30259 L
.97394 .32901 L
.9751 .37977 L
Mfstroke
.9751 .37977 m
.97553 .61803 L
s
0 .76 1 r
.02449 .61803 m
.02499 .35914 L
.02605 .31311 L
.02729 .28205 L
.02846 .26265 L
.02954 .24984 L
.03053 .24106 L
.03163 .23395 L
.03279 .22866 L
.03395 .2252 L
.0352 .22313 L
.03638 .22246 L
.03746 .22276 L
.03873 .22402 L
.03944 .22511 L
.04011 .22633 L
.04262 .23249 L
.04765 .24975 L
.05221 .26821 L
.06244 .31008 L
.07287 .34516 L
.07874 .35986 L
.08153 .36548 L
.08414 .36994 L
.08662 .37346 L
.08888 .3761 L
.09139 .37839 L
.09279 .37939 L
.09408 .38014 L
.09533 .38071 L
.09666 .38116 L
.09735 .38132 L
.098 .38144 L
.09871 .38152 L
.09947 .38156 L
.10077 .38152 L
.10142 .38144 L
.10214 .38131 L
.1034 .38099 L
.10458 .38058 L
.10721 .37929 L
.10963 .37766 L
.1151 .37265 L
.12504 .3598 L
.14362 .32896 L
.16398 .29603 L
.17393 .28325 L
.18303 .2743 L
.18751 .27095 L
.1924 .26811 L
Mistroke
.19463 .2671 L
.19701 .26623 L
.19926 .26558 L
.20129 .26516 L
.20253 .26497 L
.20383 .26483 L
.20494 .26476 L
.20615 .26473 L
.20747 .26475 L
.2082 .26479 L
.20887 .26484 L
.21017 .26498 L
.2114 .26516 L
.21377 .26565 L
.21596 .26626 L
.22092 .26818 L
.22556 .27061 L
.23057 .27385 L
.23962 .28113 L
.26023 .30243 L
.27992 .32486 L
.29032 .336 L
.30143 .34654 L
.31221 .35494 L
.32199 .36069 L
.32672 .36276 L
.3292 .36367 L
.33183 .36448 L
.33413 .36507 L
.33666 .36558 L
.33777 .36576 L
.33896 .36593 L
.34006 .36605 L
.3411 .36614 L
.34232 .36622 L
.34296 .36625 L
.34366 .36627 L
.34435 .36629 L
.34508 .36629 L
.34638 .36626 L
.34758 .3662 L
.34871 .36612 L
.34994 .366 L
.35126 .36583 L
.35424 .36533 L
.35705 .36468 L
.36232 .36305 L
.36733 .36101 L
.37196 .35872 L
.38243 .35225 L
Mistroke
.4218 .31773 L
.44158 .29934 L
.45966 .28513 L
.46962 .27905 L
.47908 .27469 L
.48426 .27295 L
.48907 .27177 L
.49184 .27128 L
.49434 .27095 L
.49573 .27082 L
.49647 .27077 L
.49724 .27073 L
.49792 .27069 L
.49866 .27067 L
.49996 .27065 L
.50127 .27067 L
.50248 .27071 L
.50311 .27074 L
.5038 .27079 L
.50521 .27091 L
.50645 .27104 L
.50777 .27122 L
.51018 .27162 L
.51504 .27275 L
.51949 .27417 L
.52968 .27868 L
.54041 .28518 L
.56017 .30088 L
.57854 .31806 L
.59729 .33577 L
.6176 .35227 L
.62872 .35908 L
.6336 .36142 L
.63896 .3635 L
.6414 .36426 L
.64402 .36495 L
.64629 .36543 L
.64876 .36584 L
.6502 .36601 L
.65154 .36614 L
.65281 .36622 L
.65353 .36625 L
.65417 .36627 L
.6554 .36629 L
.65609 .36628 L
.65672 .36626 L
.65789 .36621 L
.65912 .36613 L
.66035 .36601 L
.66168 .36584 L
Mistroke
.6641 .36544 L
.66646 .36493 L
.66863 .36435 L
.67357 .36265 L
.67881 .36029 L
.68754 .35511 L
.69716 .34775 L
.73744 .30507 L
.75597 .28524 L
.76576 .2766 L
.77113 .27268 L
.7762 .26962 L
.77896 .26824 L
.78194 .26699 L
.78443 .26614 L
.78584 .26575 L
.78715 .26544 L
.7885 .26518 L
.78973 .26499 L
.79104 .26485 L
.79176 .26479 L
.79245 .26475 L
.79366 .26473 L
.79478 .26475 L
.79601 .26482 L
.79732 .26495 L
.79856 .26513 L
.79969 .26535 L
.80225 .26599 L
.8045 .26676 L
.80687 .26776 L
.8119 .27056 L
.81741 .27467 L
.82768 .28512 L
.83701 .29746 L
.85796 .33171 L
.86806 .34894 L
.87875 .36517 L
.88315 .37071 L
.88788 .3756 L
.89059 .37783 L
.89307 .37945 L
.89426 .38007 L
.89556 .38064 L
.89679 .38105 L
.89793 .38133 L
.89919 .38151 L
.90035 .38157 L
.90162 .38149 L
.90226 .3814 L
Mistroke
.90296 .38125 L
.90415 .38091 L
.90541 .38039 L
.90661 .37976 L
.9077 .37907 L
.90988 .37732 L
.91225 .37485 L
.91655 .36883 L
.92155 .35923 L
.92686 .34594 L
.93638 .31453 L
.94577 .27665 L
.9507 .25625 L
.95339 .24583 L
.95588 .23709 L
.95828 .23006 L
.95932 .22755 L
.96045 .2253 L
.96169 .22351 L
.96286 .22259 L
.96351 .22246 L
.9642 .22265 L
.96543 .22398 L
.96647 .22625 L
.96758 .23012 L
.96864 .23544 L
.9696 .24205 L
.97072 .25253 L
.97195 .26856 L
.9731 .29039 L
.97417 .3208 L
.97513 .36644 L
Mfstroke
.97513 .36644 m
.97557 .61803 L
s
0 .4 1 r
.02443 0 m
.02499 .29055 L
.02605 .33678 L
.02729 .3671 L
.02846 .38521 L
.02954 .39648 L
.03053 .40363 L
.03163 .40878 L
.03279 .41187 L
.03395 .41303 L
.0352 .41259 L
.03638 .41088 L
.03746 .40843 L
.03873 .4047 L
.04011 .39978 L
.04262 .38918 L
.05302 .33749 L
.06244 .29643 L
.06789 .27875 L
.07302 .2666 L
.07584 .26177 L
.07844 .25844 L
.07979 .25711 L
.08128 .25596 L
.08204 .2555 L
.08284 .2551 L
.0836 .2548 L
.08429 .2546 L
.08555 .25439 L
.08619 .25436 L
.08689 .25439 L
.08812 .25459 L
.08928 .25494 L
.08995 .25521 L
.09065 .25554 L
.0919 .25628 L
.09471 .25851 L
.09715 .26104 L
.09942 .26384 L
.10458 .27153 L
.12332 .30801 L
.13318 .32771 L
.14362 .34574 L
.14891 .35323 L
.15473 .35997 L
.16002 .36464 L
.16239 .36627 L
.16497 .36773 L
.16632 .36835 L
.16758 .36885 L
Mistroke
.16887 .36928 L
.17005 .3696 L
.1712 .36985 L
.17229 .37002 L
.17344 .37014 L
.17469 .37019 L
.17595 .37017 L
.17666 .37013 L
.17733 .37007 L
.17804 .36998 L
.17868 .36988 L
.18013 .36958 L
.18136 .36926 L
.18269 .36883 L
.18512 .36786 L
.18999 .36521 L
.19455 .36192 L
.20494 .35205 L
.22596 .32589 L
.24447 .30206 L
.25496 .29044 L
.2647 .28168 L
.2697 .2781 L
.27441 .27533 L
.27702 .27406 L
.27985 .27291 L
.28239 .27206 L
.28478 .27144 L
.28732 .27096 L
.28867 .27078 L
.28943 .2707 L
.29012 .27064 L
.29084 .2706 L
.29151 .27057 L
.29224 .27055 L
.29302 .27055 L
.29432 .27059 L
.29507 .27063 L
.29577 .27068 L
.297 .27081 L
.29831 .27099 L
.30064 .27143 L
.30314 .27206 L
.30589 .27295 L
.31116 .27517 L
.31615 .27788 L
.32548 .28435 L
.34642 .30372 L
.36471 .32298 L
.38485 .34254 L
Mistroke
.39442 .35011 L
.4047 .3565 L
.41038 .35914 L
.41557 .36096 L
.41806 .36162 L
.42078 .36219 L
.42203 .3624 L
.42335 .36258 L
.4246 .36272 L
.42574 .36281 L
.42694 .36287 L
.42807 .36291 L
.4293 .36291 L
.43062 .36287 L
.43128 .36284 L
.432 .3628 L
.43331 .36268 L
.43459 .36254 L
.43577 .36237 L
.4379 .36199 L
.44025 .36146 L
.445 .36002 L
.45017 .35793 L
.45574 .3551 L
.46582 .34859 L
.50698 .31092 L
.52753 .29216 L
.53754 .28467 L
.54663 .27924 L
.55118 .27708 L
.55612 .27521 L
.55838 .27452 L
.56077 .27391 L
.56302 .27344 L
.56507 .27312 L
.56627 .27297 L
.5674 .27286 L
.56861 .27277 L
.56991 .27272 L
.57105 .2727 L
.57227 .27271 L
.57341 .27275 L
.57445 .27281 L
.57509 .27287 L
.57578 .27293 L
.577 .27307 L
.57976 .27352 L
.58214 .27403 L
.58476 .27475 L
.59002 .27663 L
Mistroke
.595 .27895 L
.60432 .28461 L
.62525 .30242 L
.66365 .34186 L
.67389 .35076 L
.68348 .35751 L
.6883 .36017 L
.69349 .36243 L
.69644 .36342 L
.69924 .36415 L
.70176 .36463 L
.70319 .36482 L
.70382 .36489 L
.70451 .36495 L
.70579 .36503 L
.7065 .36505 L
.70715 .36506 L
.70832 .36505 L
.70958 .36499 L
.71029 .36493 L
.71106 .36486 L
.71245 .36468 L
.71381 .36446 L
.71507 .3642 L
.71736 .36362 L
.71989 .3628 L
.72502 .36057 L
.72964 .35794 L
.73462 .35446 L
.74363 .34658 L
.76327 .32391 L
.78475 .29575 L
.79467 .28399 L
.80012 .27838 L
.80527 .27383 L
.81007 .27037 L
.8126 .26888 L
.81527 .26757 L
.81753 .2667 L
.81872 .26633 L
.82 .266 L
.82118 .26576 L
.82226 .26559 L
.82334 .26548 L
.82437 .26542 L
.82561 .26542 L
.82632 .26546 L
.82696 .26551 L
.82815 .26565 L
.82941 .26588 L
Mistroke
.83053 .26616 L
.83158 .26647 L
.83397 .26738 L
.83656 .2687 L
.83891 .2702 L
.8442 .27459 L
.84873 .27946 L
.85365 .28586 L
.8626 .30016 L
.88201 .3386 L
.89232 .35874 L
.89773 .36774 L
.90068 .37191 L
.90342 .37521 L
.90607 .3778 L
.90848 .37957 L
.90986 .38031 L
.91115 .38082 L
.91187 .38102 L
.91252 .38115 L
.91324 .38123 L
.91401 .38124 L
.91516 .38112 L
.9164 .38081 L
.91756 .38032 L
.91863 .3797 L
.91987 .37878 L
.92123 .37752 L
.9237 .3745 L
.92598 .37087 L
.92849 .36589 L
.93358 .35257 L
.9383 .3364 L
.94273 .31808 L
.95122 .27681 L
.95586 .25358 L
.95812 .24315 L
.96017 .23476 L
.96109 .23153 L
.96207 .22844 L
.96293 .2262 L
.96387 .22427 L
.96487 .22296 L
.96592 .22255 L
.9669 .22326 L
.96782 .22508 L
.9689 .229 L
.96993 .23494 L
.97085 .24265 L
.97185 .25449 L
Mistroke
.97294 .2731 L
.9741 .304 L
.9752 .35696 L
Mfstroke
.9752 .35696 m
.97562 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonfXN
oookJPGo0000oooonfXOoookJP00oooonfXNoookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`;o
o`00oooonfX7oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`;oo`00oooonfX7oookJPGo0000
oooonfXOoookJP004?oonfX5o`1Vo`?oo`00oooonfX6oookJPGo0000oooonfXOoookJP004?oonfX5
o`1Vo`?oo`00oooonfX6oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`?oo`00oooonfX6oook
JPGo0000oooonfXOoookJP004?oonfX5o`1Vo`?oo`00oooonfX6oookJPGo0000oooonfXOoookJP00
4?oonfX5o`1Vo`?oo`00oooonfX6oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`?oo`00oooo
nfX6oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`?oo`00oooonfX6oookJPGo0000oooonfXO
oookJP004?oonfX5o`1Vo`?oo`00oooonfX6oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`?o
o`00oooonfX6oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`Coo`00oooonfX5oookJPGo0000
oooonfXOoookJP004?oonfX5o`1Vo`Coo`00oooonfX5oookJPGo0000oooonfXOoookJP004?oonfX5
o`1Vo`Coo`00oooonfX5oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`Coo`00oooonfX5oook
JPGo0000oooonfXOoookJP004?oonfX5o`1Vo`Coo`00oooonfX5oookJPGo0000oooonfXOoookJP00
4?oonfX5o`1Vo`Coo`00oooonfX5oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`Coo`00oooo
nfX5oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`Coo`00oooonfX5oookJPGo0000oooonfXO
oookJP004?oonfX5o`1Vo`Coo`00oooonfX5oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`Co
o`00oooonfX5oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`Goo`00oooonfX4oookJPGo0000
oooonfXOoookJP004?oonfX5o`1Vo`Goo`00oooonfX4oookJPGo0000oooonfXOoookJP004?oonfX5
o`1Vo`Goo`00oooonfX4oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`Goo`00oooonfX4oook
JPGo0000oooonfXOoookJP004?oonfX5o`1Vo`Goo`00oooonfX4oookJPGo0000oooonfXOoookJP00
4?oonfX5o`1Vo`Goo`00oooonfX4oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`Goo`00oooo
nfX4oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`Goo`00oooonfX4oookJPGo0000oooonfXO
oookJP004?oonfX5o`1Vo`03oonh0?oo003oo`0000;oo`00oooonfX4oookJPGo0000oooonfXOoook
JP004?oonfX5o`1Vo`03oonh0?oo003oo`0000?oo`00oooonfX3oookJPGo0000oooonfXOoookJP00
4?oonfX5o`1Vo`03oonh0?oo003oo`0000?oo`00oooonfX3oookJPGo0000oooonfXOoookJP004?oo
nfX5o`1Vo`03oonh0?oo003oo`0000?oo`00oooonfX3oookJPGo0000oooonfXOoookJP004?oonfX5
o`1Vo`03oonh0?oo003oo`0000?oo`00oooonfX3oookJPGo0000oooonfXOoookJP004?oonfX5o`1V
o`03oonh0?oo003oo`0000?oo`00oooonfX3oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`03
oonh0?oo003oo`0000?oo`00oooonfX3oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`03oonh
0?oo003oo`0000Coo`00oooonfX2oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`03oonh0?oo
003oo`0000Coo`00oooonfX2oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`03oonh0?oo003o
o`0000Coo`00oooonfX2oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`03oonh0?oo003oo`00
00Goo`00oooonfX1oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`03oonh0?oonf[oo`0000Go
o`00oooonfX1oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`03oonh0?oonf[oo`0000Goo`00
oooonfX1oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`03oonh0?oonf[oo`0000Goo`00oooo
nfX1oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`03oonh0?oonf[ooo]Z00Koo`00oooonfX5
o`000?oooo]Z7ooonfX0013ooo]Z1Ol0I_l00ooo^03ooo]ZoookJP06ool00?oooo]Z1Ol0003ooook
JQoooo]Z000@oookJPGo06Ko00?ookP0oookJ_oonfX01_oo003^oookJPWo001o2?oonfX5o`000?oo
oo]Z7ooonfX0013ooo]Z1Ol0I_l00ooo^03ooo]ZoookJP07ool00>gooo]Z2Ol007l8oookJPGo0000
oooonfXOoookJP004?oonfX5o`1Vo`04oonh0?oonf[ooo]ZoookJPKoo`00kOoonfX4o`00O`gooo]Z
1Ol0003ooookJQoooo]Z000@oookJPGo06Ko00CookP0oookJ_oonf[ooo]Z1_oo003QoookJP[o001o
0ooonfX4o`00O`cooo]Z1Ol0003ooookJQoooo]Z000@oookJPGo06Ko00CoSol0oookJ_oonf[ooo]Z
1ooo003PoookJP[o001o1?oonfX5o`00O`[ooo]Z1ol0003ooookJQgooo]Z000@oookJPGo06Ko00?o
Sol0oookJ_oonfX00_oonfX6ool00?3ooo]Z1?l007l9oookJPGo0000oooonfXOoookJP004?oonfX5
o`1Vo`03ohoo0?oonf[ooo]Z00;ooo]Z1_oo003aoookJP?o001o2OoonfX5o`000?oooo]Z7ooonfX0
013ooo]Z1Ol0I_l00on?o`3ooo]ZoookJP02oookJPOoo`00lOoonfX3o`00O`Sooo]Z1Ol0003ooook
JQoooo]Z000@oookJPGo06Ko00?oSol0oookJ_oonfX00ooonfX6ool00>_ooo]Z0ol007l3oookJP?o
001o2?oonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol0I_l00on?o`3ooo]ZoookJP03oookJPKoo`00
jooonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXOoookJP004?oonfX5o`1Vo`03ohoo0?oo
nf[ooo]Z00?ooo]Z1ooo003ZoookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJQoooo]Z000@
oookJPGo06Ko00?oSol0oookJ_oonfX01?oonfX6ool00>_ooo]Z1ol007l9oookJPGo0000oooonfXO
oookJP004?oonfX5o`1Vo`03ohoo0?oonf[ooo]Z00Cooo]Z1_oo003/oookJPGo001o2_oonfX5o`00
0?oooo]Z7ooonfX0013ooo]Z1Ol0I_l00on?o`3ooo]ZoookJP04oookJPOoo`00n_oonfX5o`000?oo
oo]Z7ooonfX0013ooo]Z1Ol0I_l00on?o`3ooo]ZoookJP05oookJPKoo`00n_oonfX5o`000?oooo]Z
7ooonfX0013ooo]Z1Ol0I_l00on?o`3ooo]ZoookJP05oookJPKoo`00n_oonfX5o`000?oooo]Z7ooo
nfX0013ooo]Z1Ol0I_l00on?o`3ooo]ZoookJP05oookJPOoo`00nOoonfX5o`000?oooo]Z7ooonfX0
013ooo]Z1Ol0I_l00ol0obSooo]ZoookJP06oookJPKoo`00nOoonfX5o`000?oooo]Z7ooonfX0013o
oo]Z1Ol0I_l00ol0obSooo]ZoookJP06oookJPKoo`00nOoonfX5o`000?oooo]Z7ooonfX0013ooo]Z
1Ol0I_l00ol0obSooo]ZoookJP06oookJPOoo`00n?oonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol0
I_l00ol0obSooo]ZoookJP07oookJPKoo`00n?oonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol0I_l0
0ol0obSooo]ZoookJP07oookJPOoo`00mooonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol0I_l00ol0
obSooo]ZoookJP07oookJPSoo`00m_oonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol0I_l00ol0obSo
oo]ZoookJP08oookJPOoo`00m_oonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol0I_l00ol0obSooo]Z
oookJP08oookJPSoo`00mOoonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol0I_l00ol0obSooo]Zoook
JP09oookJPOoo`00mOoonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol0I_l00ol0obSooo]ZoookJP0:
oookJPOoo`00m?oonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol0I_l00ol0obSooo]ZoookJP0:oook
JPSoo`00looonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol0I_l00ol0on7ooo]ZoookJP0;oookJPOo
o`00looonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol0I_l00ol0on7ooo]ZoookJP0;oookJPSoo`00
l_oonfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol0I_l00ol0on7ooo]ZoookJP0<oookJPOoo`00l_oo
nfX5o`000?oooo]Z7ooonfX0013ooo]Z1Ol0I_l00ol0on7ooo]ZoookJP0=oookJPOoo`00lOoonfX5
o`000?oooo]Z7ooonfX0013ooo]Z1Ol0I_l00ol0on7ooo]ZoookJP0=oookJPSoo`00l?oonfX5o`00
0?oooo]Z7ooonfX0013ooo]Z1Ol0I_l00ol0on7ooo]ZoookJP0>oookJPOoo`00l?oonfX5o`000?oo
oo]Z7ooonfX0013ooo]Z1Ol0I_l00ol0on7ooo]ZoookJP0>oookJPSoo`00kooonfX5o`000?oooo]Z
7ooonfX0013ooo]Z1Ol0I_l00ol0on7ooo]ZoookJP0?oookJPSoo`00k_oonfX5o`000?oooo]Z7ooo
nfX0013ooo]Z1_l0I_lBoookJPOoo`00k_oonfX5o`000?oooo]Z7ooonfX0013ooo]Z1_l0I_lBoook
JPSoo`00kOoonfX5o`000?oooo]Z7ooonfX0013ooo]Z1_l0I_lCoookJPSoo`00k?oonfX5o`000?oo
oo]Z7ooonfX0013ooo]Z1_l0I_lDoookJPOoo`00k?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol0
I_lDoookJPSoo`00jooonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol0I_lEoookJPSoo`00j_oonfX5
o`000?oooo]Z7ooonfX0017ooo]Z1Ol0I_lFoookJPSoo`00jOoonfX5o`000?oooo]Z7ooonfX0017o
oo]Z1Ol0I_lFoookJPWoo`00j?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol0I_l00ooo^03ooo]Z
oookJP0DoookJPWoo`00iooonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol0I_l00ooo^03ooo]Zoook
JP0EoookJP[oo`00iOoonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol0I_l00ooo^03ooo]ZoookJP0F
oookJP[oo`00i?oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol0I_l00ooo^03ooo]ZoookJP0Goook
JP[oo`00hooonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol0I_l00ooo^03ooo]ZoookJP0HoookJP[o
o`00h_oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol0I_l00ooo^03ooo]ZoookJP0IoookJP[oo`00
hOoonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol0I_l00ooo^03ooo]ZoookJP0KoookJP[oo`00gooo
nfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol0I_l00ooo^03ooo]ZoookJP0LoookJP[oo`00g_oonfX5
o`000?oooo]Z7ooonfX0017ooo]Z1Ol0I_l00ooo^03ooo]ZoookJP0MoookJP[oo`00gOoonfX5o`00
0?oooo]Z7ooonfX0017ooo]Z1Ol0I_l00ooo^03ooo]ZoookJP0NoookJP[oo`00g?oonfX5o`000?oo
oo]Z7ooonfX0017ooo]Z1Ol0I_l00ooo^03ooo]ZoookJP0OoookJP[oo`00fooonfX5o`000?oooo]Z
7ooonfX0017ooo]Z1Ol0I_l00ooo^03ooo]ZoookJP0QoookJP[oo`00fOoonfX5o`000?oooo]Z7ooo
nfX0017ooo]Z1Ol0I_l00ooo^03ooo]ZoookJP0RoookJP[oo`00f?oonfX5o`000?oooo]Z7ooonfX0
017ooo]Z1Ol0I_l2oonh02Cooo]Z2ooo003FoookJPGo0000oooonfXOoookJP004OoonfX5o`1Vo`;o
okP09OoonfX;ool00=Gooo]Z1Ol0003ooookJQoooo]Z000AoookJPGo06Ko0_oo^00VoookJPcoo`00
dooonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol0I_l2oonh02Sooo]Z2ooo003BoookJPGo0000oooo
nfXOoookJP004OoonfX5o`1Vo`;ookP0:OoonfX<ool00=3ooo]Z1Ol0003ooookJQoooo]Z000Aoook
JPGo06Ko0_oo^00[oookJPcoo`00c_oonfX5o`000?oooo]Z7ooonfX0017ooo]Z1Ol0I_l2oonh02co
oo]Z3?oo003=oookJPGo0000oooonfXOoookJP004OoonfX5o`1Vo`;ookP0;_oonfX<ool00<_ooo]Z
1Ol0003ooookJQoooo]Z000AoookJPGo06Ko0_oo^00_oookJPcoo`00_OoonfX3o`00O`[ooo]Z1Ol0
003ooookJQoooo]Z000AoookJPGo06Ko0_oo^00aoookJPcoo`00^ooonfX3o`00O`[ooo]Z1Ol0003o
oookJQoooo]Z000AoookJPGo06Ko0_oo^00coookJP_oo`00^_oonfX3o`00O`03oookJ_ooG03ooe`0
01Kooe`0oooonfXEoookJP004OoonfX5o`1Vo`;ookP0=?oonfX<ool00:3ooo]ZB?ooG03ooookJP7o
oo]Z000AoookJPGo06Ko0ooo^00eoookJP_oo`00TooonfYXoomL0>cooo]Z000AoookJPGo06Ko0ooo
^00foookJPcoo`00Q_oonfYioomL0>Kooo]Z000AoookJPGo06Ko0ooo^00hoookJPcoo`00NooonfZ;
oomL0=gooo]Z000AoookJPGo06Ko0ooo^00ioookJPgoo`00LooonfY6oomL00Gooo]Z1Ol00006oook
JTCooe`0e?oonfX0017ooo]Z1Ol0I_l3oonh03_ooo]Z3Ooo001[oookJS3ooe`05?oonfX3o`00O`[o
oo]Z1Ol0000JoookJSOooe`0cOoonfX0017ooo]Z1Ol0I_l3oonh03cooo]Z3_oo001ToookJRWooe`0
7OoonfX6o`00O`[ooo]Z1Ol0000^oookJR[ooe`0a_oonfX0017ooo]Z1Ol0I_l3oonh03kooo]Z3_oo
001LoookJRCooe`0:?oonfX6o`00O`[ooo]Z1Ol0000doookJR[ooe`0`?oonfX0017ooo]Z1Ol0I_l3
oonh043ooo]Z3_oo001EoookJR3ooe`0<ooonfX4o`00O`[ooo]Z1Ol0000moookJRKooe`0<_oonfXQ
oonh06Sooo]Z000AoookJPGo06Ko0ooo^012oookJPkoo`00COoonfXPoomL03[ooo]Z0ol007l:oook
JPGo0000A_oonfXRoomL02Gooo]Z;Ooo^01ToookJP004OoonfX5o`1Vo`?ookP09?oonfXEon_o00_o
oo]Z3_oo0016oookJQoooe`0COoonfX5o`0004gooo]Z7oooG00LoookJSSookP02ooonfXGon_o00Co
oo]Z2On?o`0_oookJP004OoonfX5o`1Vo`Oo0<;o1Ol0ohD<oc?o00_ooo]Z7Oo[o`09oookJPkoo`00
?ooonfXOoomL05;ooo]Z1Ol0001DoookJQgooe`04_oonfY2oonh00;ooo]Z6oo[o`0>ohoo00Oo<ol0
1?l0obP3o`3oQ@?o0?oQ00?o0<;oo`1Vool0I_l00ol0I_lGoookJP004OoonfX5o`1Vo`Oo0<;o1_l0
ohD=oc?o00Kooo]Z9Oo[o`06oookJPkoo`00>OoonfXMoomL05Sooo]Z1Ol0001JoookJQ_ooe`02Ooo
nfY5oonh01gojol03On?o`09oc?o00Co0?lX0ol0ohD3o`3oh@03o`32ool0I_oo06Ko00Go06Ko5_oo
nfX0017ooo]Z1Ol0I_l8o`32o`Ko0?n53Olco`04oookJRWojol01OoonfX>ool003?ooo]Z7?ooG01M
oookJPGo0000GooonfXJoomL023ookP06OoonfX>oonh01gojol03on?o`09oc?o00Co0?lX1?l0ohD2
o`3oh@;o0<;o1ol0I_lFoookJP004OoonfX5o`1Vo`So0<;o1_l0ohD>oc?o0003oookJ_o[o`3ojol0
02_ojol01OoonfX?ool002gooo]Z6OooG01SoookJPGo0000I?oonfXAoomL01cookP09OoonfX7oonh
01oojol03on?o`08oc?o00Ko0?lX0ol0ohD3o`3oh@03o`32ool0I_oo06Ko00Ko06Ko5_oonfX0017o
oo]Z1Ol0I_l9o`32o`Ko0?n53_lco`0>on_o00gooo]Z5?o[o`05oookJPooo`009ooonfXHoomL06So
oo]Z1Ol0001XoookJP[ooe`06_oo^00_oookJQCojol000?ookP0oookJ_oonfX02?oonfX@ohoo00So
<ol01_l0obP4o`3oQ@;o0?oQ0_l0`_l9o`1VoaGooo]Z000AoookJPGo06Ko2Ol0`_l6o`3oQ@;o<ol0
0ooonfX:oc?o00Wojol05OoonfXAon_o00Kooo]Z4?oo000PoookJQOooe`0KOoonfX5o`0006gooo]Z
00?ooe`0oonh0?oo^0005ooo^00boookJQ;ojol01ooo^007oookJPgoSol00oo[o`09oc?o00Ko0?lX
0ol0ohD3o`3oh@;o0<;o2Ol0I_lEoookJP004OoonfX5o`1Vo`[o0<;o1_l0ohD6oookJPWo<ol01Oo[
o`0MoookJPkojol01_oonfX@ool001_ooo]Z5_ooG01aoookJPGo0000JooonfXGoonh00Kooe`0;ooo
nfX@on_o00gookP00ooonfX=ohoo00Cojol02Olco`06o`3o:0Co0?n50ol0on42o`32o`[o06Ko5?oo
nfX0017ooo]Z1Ol0I_l:o`32o`Oo0?n51_oonfX9oc?o00?ojol08OoonfX=on_o00Kooo]Z4?oo000F
oookJQGooe`0MOoonfX5o`0006Sooo]Z5Ooo^00>oomL02[ooo]Z3oo[o`04oookJPkookP02on?o`04
oookJP;ojol02Olco`000ooonf[o0?lXo`3o:004o`3o:0Co0?n50_l0on42o`32o`_o06Ko5?oonfX0
017ooo]Z1Ol0I_l:o`32o`Oo0?n51ooonfX9oc?o02Gooo]Z3_o[o`06oookJQ3oo`004?oonfXEoomL
07Sooo]Z1Ol0001ToookJQGookP05OooG00UoookJPkojol02OoonfX;oonh00_oSol01_oonfX9oc?o
0003oookJ_l0obSo0?lX00Co0?lX1?l0ohD3o`3oh@;o0<;o2ol0I_lDoookJP004OoonfX5o`1Vo`_o
0<;o1ol0ohD5oookJP;ojol02?lco`0WoookJPkojol01_oonfX@ool000_ooo]Z5?ooG01loookJPGo
0000HOoonfXEoonh00Kooo]Z5OooG00PoookJPkojol03OoonfX8oonh00[oSol01ooonfX9oc?o0003
on_o0?l0obSo0?lX00Go0?lX1?l0ohD3o`3oh@;o0<;o2ol0I_lDoookJP004OoonfX5o`1Vo`?o0<;o
0_l0ohD6o`32o`Oo0?n51?oonfX4on_o00So<ol09ooonfX?on_o00Oooo]Z4?oo0006oookJQ;ooe`0
P?oonfX5o`0005kooo]Z5?oo^00>oookJQ?ooe`07?oonfX>on_o017ooo]Z1Ooo^00:ohoo00Oooo]Z
2Olco`02on_o00Ko0?lX1?l0ohD3o`3oh@;o0<;o3?l0I_lDoookJP004OoonfX5o`1Vo`?o0<;o0_l0
ohD6o`32o`03oc?o0?l0ohGo0?n500Go0?n50_oonfX6on_o00So<ol0:?oonfX?on_o00Oooo]Z4Ooo
000BoomL08?ooo]Z1Ol0001KoookJQCookP05OoonfXBoomL01Oooo]Z3_o[o`0EoookJP03oonh0?n?
o`3oSol000SoSol000?ookP0oookJ_oonfX01OoonfX9oc?o00;ojol01ol0obP4o`3oQ@?o0?oQ0_l0
`_l6o`1Vo`03o`32ool0I_oo06Ko00?o06Ko5?oonfX0017ooo]Z1Ol0I_l3o`32o`;o0?n51_l0`_l0
0ooonf[o0?n5o`3oQ@05o`3oQ@03oookJ_o[o`3ojol000Kojol02?lco`0YoookJPkojol02?oonfX<
ool001;ooe`0Q_oonfX5o`0005Sooo]Z5?oo^00KoookJQ7ooe`05?oonfX=on_o01Oooo]Z2_n?o`04
oonh00Gooo]Z2?lco`03on_o00Ko0?lX1Ol0ohD3o`3oh@;o0<;o1_l0I_l00ol0`_oo06Koo`1Vo`03
o`1VoaCooo]Z000AoookJPGo06Ko0ol0`_l2o`3oQ@03oc?o0?l0`_oo0<;o00?o0<;o0_oonfX7o`3o
Q@Sojol02?lco`0/oookJPgojol02OoonfX6ool001;ooe`0ROoonfX5o`0005Gooo]Z4ooo^00Roook
JQ7ooe`03ooonfX=on_o01Sooo]Z2_n?o`06oonh00?ooo]Z2?lco`000ooonf[ojol0on_o0007o`3o
:0Co0?n50ol0on43o`32o`Ko06Ko00?o0<;oo`1Vool0I_l00ol0I_lDoookJP004OoonfX5o`1Vo`?o
0<;o0_l0ohD00olco`3o0<;oo`32o`04o`32o`03oookJ_l0ohGo0?n500Go0?n51oo[o`02oookJPSo
<ol0;OoonfX<on_o00[ooo]Z0_oo000AoomL0003ool00?oonf[ooo]Z02?ooo]Z5_n?o`1@oookJPGo
0000DooonfXBoonh02Sooo]Z4OooG00;oookJPcojol06OoonfX:ohoo00SookP000?ooo]Zoc?o0?lc
o`001_lco`03oookJPOo0?lX1Ol0ohD3o`3oh@?o0<;o1Ol0I_l00ol0on7o0<;oo`1Vo`04o`1VoaCo
oo]Z000AoookJPGo06Ko0ol0`_l2o`3oQ@03oc?o0?l0`_oo0<;o00Co0<;o0_oonfX6o`3oQ@Kojol0
1?oonfX8oc?o02kooo]Z3?o[o`07oookJQ;ooe`01_oo000MoookJR7oSol0B_oonfX5o`00053ooo]Z
4_oo^00]oookJQ7ooe`01ooonfX<on_o01[ooo]Z2_n?o`0:oonh00Oo<ol01?oonfX7o`3o:0Go0?n5
0ol0on43o`32o`Go06Ko00?o0?n5o`32ool0I_l01?l0I_lDoookJP004OoonfX5o`1Vo`?o0<;o0_l0
ohD00olco`3o0<;oo`32o`04o`32o`;ooo]Z1ol0ohD4on_o00Kooo]Z2?lco`0_oookJP_ojol01?oo
nfXAoomL00coo`005?oonfX[ohoo04Kooo]Z1Ol0001=oookJQ;ookP0<ooonfX@oomL00Cooo]Z2oo[
o`0KoookJPWoSol00ooonfX8oonh00So<ol00ooonfX7o`3o:0Ko0?n50ol0on42o`32o`Ko06Ko00?o
0?n5o`32ool0I_l01Ol0I_lCoookJP004OoonfX5o`1Vo`?o0<;o0_l0ohD00olco`3o0<;oo`32o`04
o`32o`?ooo]Z1_l0ohD3on_o00Oooo]Z2?lco`0WoookJQ3o0?lX1Oo[o`0@oomL01;oo`003_oonfXc
ohoo047ooo]Z1Ol0001;oookJQ7ookP0>?oonfX@oomL00cojol06ooonfX9ohoo00Kooo]Z1_oo^007
oc?o00Cooo]Z1ol0obP5o`3oQ@?o0?oQ0ol0`_l6o`1Vo`03o`3oQOl0`_oo06Ko00Go06Ko4ooonfX0
017ooo]Z1Ol0I_l2o`32o`?o0?n50_lco`05o`32o`?ooo]Z1ol0ohD2on_o00Cooo]Z2?l0I_l4oc?o
00?ooo]Z3Ol0on4AoookJQSo0?lX1?o[o`0;oomL00Cooo]Z5Ooo0007oookJS[oSol0?OoonfX5o`00
04Sooo]Z4Ooo^00noookJP_ooe`03?o[o`0LoookJPWoSol02?oonfX4oonh00Oo<ol01?oonfX7o`3o
:003on_o0?l0ohGo0?n500?o0?n50ol0on43o`32o`Ko06Ko00?o0?n5o`32ool0I_l01Ol0I_lCoook
JP004OoonfX5o`1Vo`;o0<;o0_l0ohD3oc?o00Ko0<;o0_oonfX7o`3oQ@04on_o0?oonf[ooo]Zoook
JPco06Ko0olco`000ooonf[o0?oQo`3oh@0=o`3oh@oooo]Z7?l0obP2on_o00Sooe`02_oonfXDool0
0003oookJ_n?o`3oSol001KoSol03_oonfXJohoo03;ooo]Z5_lco`0moookJQ7ookP0@ooonfX7oomL
00cojol07?oonfX9ohoo00[ooo]Z0_oo^008oc?o00Cooo]Z1ol0obP6o`3oQ@?o0?oQ0ol0`_l6o`1V
o`03o`3oQOl0on7o06Ko00Go06Ko4ooonfX0017ooo]Z1Ol0I_l2o`32o`;o0?n50olco`06o`32o`;o
oo]Z00?ojol0o`3oQOl0ohD01?l0ohD3oookJPko06Ko0_lco`0Co`3oh@[ooo]Z8?l0obP2on_o00?o
oe`04?oonfX@ool001GoSol06OoonfXGohoo02[ooo]Z8Olco`0doookJQ7ookP0B?oonfX3oomL00co
jol000?ooe`0oookJ_oonfX06_oonfX9ohoo00cooo]Z00?ookP0oc?o0?lco`001Olco`001?oo^03o
oo]ZoookJ_oonfX7o`3o:003oookJ_l0ohGo0?n500?o0?n51?l0on43o`32o`Go06Ko00Co0?lXo`3o
QOl0on7o0<;o1Ol0I_lCoookJP004OoonfX5o`1Vo`;o0<;o0_l0ohD3oc?o00Ko0<;o0_oonfX00oo[
o`3o0?n5o`3oQ@05o`3oQ@03oookJ_l0I_oo06Ko00go06Ko5_l0on47oookJRCo0?lX00?ojol0oook
J_oonfX04ooonfX;ool0017oSol08ooonfXEohoo02;ooo]Z:_lco`0WoookJPco0?lX3?oo^01=oook
JPcojol01?ooG00JoookJPSoSol03OoonfX8oc?o00;ookP00_oonfX7o`3o:0Ko0?n51?l0on42o`32
o`Ko06Ko00Co0?lXo`3oQOl0on7o0<;o1Ol0I_lCoookJP004OoonfX5o`1Vo`;o0<;o0_l0ohD3oc?o
00Oo0<;o0oo[o`06o`3oQA;o06Ko5Ol0on44oookJQ3o0?lX1?oonfX4oomL00oo0?lX0_o[o`0Foook
JPGoo`004On?o`0[oookJQ?oSol07?oonfXaoc?o01gooo]Z6?l0obP4oonh04gooo]Z3?o[o`08oomL
01Oooo]Z2?n?o`0=oookJPSo<ol01?oo^007o`3o:003oookJ_l0ohGo0?n500Co0?n50ol0on43o`32
o`Ko06Ko00Co0?lXo`3oQOl0on7o0<;o1Ol0I_lCoookJP004OoonfX5o`1Vo`;o0<;o0_l0ohD4oc?o
00Ko0<;o0oo[o`06o`3oQA?o06Ko1Ol0on45oookJP_o0?oQ0_oonfX<o`3o:0Oooo]Z2OooG00>o`3o
:003on_o0?oonf[ooo]Z01Kooo]Z3_n?o`0Eo`3oQAoooo]Z4On?o`0GoookJSSo<ol04ooonfXSo`3o
:1;ooo]Z5Ol0ohDAoookJPSo0?oQ2ooonfX;on_o00gooe`04ooonfX8ohoo00kooo]Z1olco`05oonh
00Oo0?lX00?ooo]Zo`3oQOl0ohD00ol0ohD4o`3oh@?o0<;o1_l0I_l01?l0obSo0?n5o`3ohOl0`_l5
o`1Voa?ooo]Z000AoookJPGo06Ko0_l0`_l2o`3oQ@?o<ol000?ooo]Zo`32ool0`_l01?l0`_l3on_o
00Go0?n52Ol0I_l3oookJPSo06Ko1?l0on47oookJP_o0?oQ00?ooo]Zo`3o:?l0obP02Ol0obP6oook
JP_ooe`03?l0`_l4o`3o:003on_o0?oonf[ooo]Z01;ooo]Z3On?o`0Jo`3oQB3ooo]Z4?n?o`0Coook
JQOo<ol01?oonfX5o`0000Gooo]Z5olco`0>oookJRWo0?lX3?oonfXKo`3oQ@Sooo]Z5?l0on43oook
JPCojol03Ol0`_l7oomL00So06Ko3?oonfX8ohoo00kooo]Z2?lco`04oonh00Oo0?lX00?ooo]Zo`3o
QOl0ohD01?l0ohD4o`3oh@?o0<;o1_l0I_l2o`3o:003o`3ohOl0`_oo06Ko00Co06Ko4ooonfX0017o
oo]Z1Ol0I_l2o`32o`;o0?n50olco`000ooonf[o0<;oo`32o`05o`32o`?ojol01?l0ohD7o`1Vo`Go
oo]Z2Ol0I_l2o`3oh@_ooo]Z2Ol0on49o`3o:0Kooo]Z2_ooG00Co`32o`;o0?lX4OoonfX<ohoo023o
0?n58?oonfX@ohoo00gooo]Z5Olco`09oookJPGo00002ooonfXCoc?o00Wooo]Z;_l0obP7oookJR3o
0?n51?oonfXIo`3oh@03on_o0?l0`_oo0<;o013o0<;o0_ooG00?o`1Vo`Oooo]Z2On?o`0=oookJPSo
<ol01Ooo^007o`3o:003oookJ_l0ohGo0?n500Co0?n51?l0on42o`32o`Ko06Ko00Go<ol0o`3o:?l0
obSo0?oQo`32o`05o`1Voa?ooo]Z000AoookJPGo06Ko0_l0`_l00ol0ohGo<ol0oc?o0002oc?o00;o
oo]Z1_l0`_l3on_o00Co0?n51_l0I_l7oookJPWo06Ko0_lco`0;oookJPWo0?oQ1_l0obP7oookJPWo
oe`06?l0`_l00ol0obSooo]ZoookJP0;oookJP_oSol09Ol0ohDPoookJQCo0?oQ1OoonfXAoc?o00oo
oo]Z1Ol0000>oookJQ;o<ol01OoonfXHo`3o:0CookP05ol0obP00ooonf[o0?n5o`3oQ@0Ro`3oQA_o
0?oQ4ol0`_lDo`1Vo`Cooo]Z2On?o`0>oookJPOo<ol00_oonfX3oonh00Oo0?lX0_oonfX5o`3oQ@Co
0?oQ0ol0`_l6o`1Vo`05oc?o0?l0obSo0?lXo`3oQOl0on401Ol0I_lCoookJP004OoonfX5o`1Vo`;o
0<;o00?o0?n5oc?o0?lco`000_lco`000ooo^03ooo]Zo`32o`05o`32o`?ojol00ol0ohD7o`1Vo`Oo
oo]Z0_l0on47o`1Vo`?o<ol02ooonfX8o`3oh@Co0?lX1ooonfX:oomL01_o0<;o2_oonfX:ohoo00[o
0?n52Ol0I_lHo`3oQASooo]Z7?l0on4@oc?o013ooo]Z2_l0`_l?oookJQ3o<ol05Ol0obP<oonh00Co
oo]Z4?l0obPTo`3oQA_o0?oQ5?l0`_lFo`1Vo`;ooo]Z2On?o`0>oookJPSo<ol00ooonfX2oonh00Oo
0?lX00?ooo]Zo`3oQOl0ohD01?l0ohD4o`3oh@?o0<;o1_l0I_l01Olco`3o0?lXo`3o:?l0ohGo0?oQ
00Go06Ko4ooonfX0017ooo]Z1Ol0I_l2o`32o`03o`3oQOlco`3o<ol000;o<ol000?ookP0oookJ_l0
`_l01Ol0`_l3on_o0003oookJ_l0ohGo0?n500Ko06Ko1ooonfX3o`3oh@So06Ko0_lco`0<oookJPSo
0?oQ0ol0obP5oookJP[ooe`07_l0`_l00oo[o`3ooo]ZoookJP05oookJP[oSol01ol0ohDAo`1Vo`Ko
o`004?l0ohDCoookJR;o0?oQ2_lco`0>oookJQCo0<;o3_oonfX:oc?o017o0?lX3ooo^00<oookJPWo
0?lX4Ol0ohD=oookJPOo0?n56_l0on4Eo`32oaSo06Ko2On?o`0>oookJPSo<ol01?oonfX00ooo^03o
0?lXo`3o:005o`3o:003oonh0?oonf[o0?n500Go0?n51?l0on43o`32o`Ko06Ko00Go<ol0o`3o:?l0
obSo0?n5o`3oh@05o`1Voa?ooo]Z000AoookJPGo06Ko0_l0`_l01?l0ohGo<ol0oc?o0?lco`02oonh
00;ooo]Z1_l0`_l01?o[o`3ooo]ZoookJ_l0ohD7o`1Vo`Oooo]Z1?l0on47o`1Vo`?o<ol02ooonfX0
0ol0obSo0?oQo`3oh@06o`3oh@03o`3o:?oonf[ooo]Z00;ooo]Z2oooG00=o`32o`Cooo]Z4?l0`_l4
oookJP[oSol01_l0ohDGo`1Vo`Goo`003ol0ohDAoookJRKo0?oQ1Olco`0=oookJQ_o0<;o3?oonfX5
oc?o01;o06Ko3ooo^00AoookJPCo0?lX4?l0ohDCoookJP;o0?n53_l0on4<oookJP03o`3ohOl0`_oo
0<;o00go0<;o1?oonfX2o`32oa[o06Ko1on?o`0>oookJPSo<ol01_oonfX7o`3o:003oonh0?l0ohGo
0?n500Co0?n51Ol0on43o`32o`Go06Ko00KoSol0oc?o0?l0obSo0?lXo`3oQOl0on45o`1Voa?ooo]Z
000AoookJPGo06Ko0_l0`_l01?l0ohGo<ol0oc?o0?lco`03oonh0003oookJ_l0`_oo0<;o00Co0<;o
00Cojol0oookJ_oonf[ooo]Z1ol0I_l6oookJPKo0?oQ1ol0I_l3oc?o00Wooo]Z0ol0obP8o`3oh@;o
oo]Z3?ooG00;o`32o`_ooo]Z3Ol0`_l00ooonf[oSol0ohoo0009ohoo00Go0?n57?l0I_l5ool000ko
0?n53OoonfXZo`3oh@gooo]Z8?l0`_l<oookJQSo06Ko2_oo^00EoookJPoo0?n55_oonfX>o`3oh@03
o`3oQOoonf[ooo]Z00[ooo]Z00?ojol0o`32ool0`_l02_l0`_l2o`3oh@Oooo]Z2ol0I_l00ol0`_oo
oe`0oomL0004oomL00[o06Ko1On?o`0?oookJPSo<ol01OoonfX7o`3o:0;ookP01_l0ohD4o`3oh@?o
0<;o1_l0I_l01_n?o`3o<ol0oc?o0?l0obSo0?n5o`3oh@Go06Ko4ooonfX0017ooo]Z1Ol0I_l2o`32
o`04o`3oQOlco`3o<ol0oc?o00?ookP000?ojol0o`32ool0`_l01?l0`_l4oookJPKo06Ko1_oonfX7
o`3oh@Oo06Ko1?lco`07oookJPCo0?lX2Ol0on4<oomL00[o0<;o4?oonfX;o`32o`WoSol01_l0ohDO
o`1Vo`Goo`003_l0ohD9oookJQ7o0?oQ2?oonfX3ohoo0003oc?o0?l0on7o0?oQ00oo0?oQ2?oonfXU
o`32o`Oooo]Z7_l0I_l5oonh01Gooo]Z3_l0ohD3o`3o:1Cooo]Z3Ol0on45o`3oQ@Wooo]Z0_o[o`0;
o`32o`Go0?oQ1OoonfX9o`1Vo`Go0<;o00?ooo]ZoomL0?ooG0001?ooG009o`1Vo`?oSol03ooonfX8
oc?o00Kooo]Z1ol0obP2oonh00Ko0?n51?l0on43o`32o`Ko06Ko00?oSol0oc?o0?lco`000_l0obP0
0ol0on7o06Koo`1Vo`03o`1Voa?ooo]Z000AoookJPGo06Ko0_l0`_l01?l0ohGo<ol0oc?o0?lco`03
oonh0003on_o0?l0`_oo0<;o00Co0<;o0ooonfX7o`1Vo`03o`3oQOoonf[ooo]Z00?ooo]Z1ol0on40
0ooonf[o06Koo`1Vo`05o`1Vo`?o<ol01_oonfX6o`3o:0So0?oQ2oooG00:o`32oa?ooo]Z2_l0`_l7
ohoo00Go0?n54?l0I_l00ooonf[o06Koo`1Vo`0?o`1Vo`Ooo`003?l0ohD7oookJPgo0?oQ3_oonfX6
oc?o00oo0?oQ1OoonfXDo`32o`;o00004ol0`_l2oookJR?o06Ko00?ookP0oookJ_oonfX04ooonfX>
o`3oQ@Oo0?lX4OoonfX<o`3oh@Wo0?n51_oonfX2on_o00[o0<;o2Ol0on42oookJPWo06Ko1ol0`_l0
0ooonf[ooe`0oomL0004oomL00Wo06Ko00?oSol0oookJ_oonfX03OoonfX8oc?o00Kooo]Z1ol0obP2
oonh00Ko0?n51Ol0on43o`32o`Ko06Ko00?oSol0oc?o0?lco`000_l0obP00ol0on7o06Koo`1Vo`03
o`1Voa?ooo]Z000AoookJPGo06Ko00?o0<;oo`3oQOl0ohD00_lco`03oonh00?ojol01_l0`_l2oook
JPKo06Ko0_l0ohD4oookJPSo0?oQ00?ooo]Zo`1Vool0I_l01Ol0I_l4oc?o00Gooo]Z1ol0obP8o`3o
h@Sooe`000?ooo]Zo`32ool0`_l01ol0`_lFoookJP[o0<;o1On?o`05o`3oQ@go06Ko2OoonfX>o`1V
o`Soo`003?l0ohD3oookJPco0?oQ3ooonfX;oc?o00ko0?oQ0_oonfX@o`32o`?ooo]Z1Ol00004oook
JPko0<;o9ol0I_lCoookJPgo0?n52_l0obP?oookJPco0?oQ2ol0ohD3oookJP?ojol02Ol0`_l00ooo
nf[o0?oQo`3oh@09o`3oh@Wo06Ko2Ol0`_l2oookJPCooe`000?oSol0o`1Vool0I_l01_l0I_l@oook
JPOo<ol01ooonfX7o`3o:0;ookP01_l0ohD5o`3oh@?o0<;o1_l0I_l00on?o`3o<ol0oc?o0002o`3o
:003o`3ohOl0I_oo06Ko00?o06Ko4ooonfX0017ooo]Z1Ol0I_l00ol0`_oo0?n5o`3oQ@02oc?o00?o
okP00oo[o`06o`32o`;ooo]Z1_l0I_l3o`3oQ@;ooo]Z2?l0on43oookJPOo06Ko1?lco`03oookJPSo
0?lX00?ooo]Zo`3ohOl0on401_l0on45oomL00;ooo]Z2Ol0`_lHoookJP03o`3o:?l0`_oo0<;o00Ko
0<;o00Co0?lXohoo0?n?o`3oSol01Ol0ohD;o`1Vo`oooo]Z3?l0I_l8ool000co0?n53Ol0on4?oook
JPgo<ol00_n?o`0;o`3oh@oo0<;o1_oonfX5o`0000Sooo]Z2Ol0`_l@o`1Vo`03o`3o:?lco`3o<ol0
00Oo<ol03ol0I_l@oookJPgo0?n50_oonfX<o`3o:0cooo]Z2ol0on43oookJP_o0?n500Cooo]Zon_o
0?o[o`3ojol02Ol0`_l3oookJPWo0?oQ2Ol0I_l2oookJPWo0<;o0ooonfX01?ooG03oSol0ohoo0?n?
o`08o`1Vo`kooo]Z2?lco`06oookJPOo0?lX0ooo^006o`3oQ@Co0?oQ0ol0`_l6o`1Vo`?oSol000Co
<ol0o`3o:?l0obSo0?n51Ol0I_lCoookJP004OoonfX5o`1Vo`03o`32ool0ohGo<ol000;o<ol00ooo
^003on_o00Ko0<;o00?ooo]Zo`1Vool0I_l01Ol0I_l3o`3oQ@;ooo]Z1ol0on44oookJPOo06Ko1?lc
o`02oookJPSo0?lX0oooG008o`3oh@;ooe`01?oonfX8o`32oaWooo]Z00?oSol0o`3o:?l0`_l01ol0
`_l00ol0obSojol0o`3oQ@04o`3oQ@[o06Ko0_oonfX5o`00O`gooo]Z2ol0I_l00ooonf[oo`00ool0
0005ool000Wo0?n53?l0on4?oookJPgo<ol01_n?o`08o`3oh@go0<;o2OoonfX5o`0000[ooo]Z1_l0
`_l>o`1Vo`;o0?lX0_oonfX2oonh00[o<ol03_l0I_l=oookJPco0?n51_oonfX;o`3o:0Wooo]Z2ol0
on44o`00O`?ooo]Z2_l0ohD2on_o00Wo0<;o1_oonfX6o`3oh@Wo06Ko1?oonfX9o`32o`;ooo]Z1On?
o`08o`1Vo`03oomL0?oonf[ooo]Z00Wooo]Z2?lco`07oookJPOo0?lX00?ooo]Zoonh0?l0ohD01_l0
ohD4o`3oh@?o0<;o1_l0I_l3ohoo00;o<ol000?o0?lXo`3oQOl0I_l01?l0I_l00ol007oooo]Zoook
JP0@oookJP004OoonfX5o`1Vo`03o`32ool0ohGo<ol000;o<ol00_oo^004on_o00Ko0<;o00?ooo]Z
o`1Vool0I_l01?l0I_l4o`3oQ@03oookJ_l0on7o0?oQ00Ko0?oQ1OoonfX7o`1Vo`Co<ol02?l0obP4
oomL00Wo0?oQ1?oonfX8o`32oaWooo]Z0on?o`000ol0obSo0<;oo`32o`06o`32o`Go0?n52_l0I_l2
oookJPOo001o3_oonfX:o`1Vo`?ooo]Z1_oo0005o`3oQ@co0?oQ3ooonfX=oc?o00;ooo]Z2?n?o`04
o`3oh@co0<;o3?oonfX5o`0000cooo]Z0ol0`_l<o`1Vo`?o0?lX0_oonfX6oonh00_o<ol03?l0I_l:
oookJPco0?n52OoonfX;o`3o:0Oooo]Z2_l0on47o`00O`?ooo]Z2_l0ohD9o`32o`Sooo]Z1Ol0on48
o`1Vo`Kooo]Z2Ol0`_l7ohoo00So06Ko00?ooe`0oookJ_oonfX02?oonfX7oc?o00Oooo]Z1ol0obP3
oookJPKo0?n51Ol0on43o`32o`Ko06Ko0on?o`02oc?o0003o`3o:?l0ohGo06Ko00Co06Ko00?o001o
oookJ_oonfX04?oonfX0017ooo]Z1Ol0I_l00ol0`_oo0?n5oc?o0002oc?o00;ookP01Oo[o`06o`32
o`Ko06Ko1Ol0ohD7o`3oh@Kooo]Z1ol0I_l4oc?o00So0?lX1OooG008o`3oh@?ooo]Z2?l0`_lIoook
JPKoSol02?l0`_l3o`3oQ@Wo06Ko0_l007l00ooonf[o001oo`00O`02o`00O`04oookJ_l007oo001o
o`00O`oooo]Z2_l0I_l6oookJP?oo`000ol0ohD<o`3oh@Goo`002_oonfX<oc?o00Kooo]Z1on?o`02
o`3oh@_o0<;o3_oonfX5o`0000kooo]Z2_l0I_l00ol0`_oo0?lXo`3o:002o`3o:003oookJ_oo^03o
okP000SookP02olco`0;o`1Vo`Sooo]Z2ol0ohD=oookJP_o0?lX1?oonfX:o`3oh@05oookJ_l007oo
001oo`00OooonfX00ol007l3oookJP;o001o1ol0ohD9o`32o`_ooo]Z0_l0on48o`1Vo`Sooo]Z2?l0
`_l7ohoo00So06Ko0oooG007oookJPSo<ol01ooonfX7o`3o:0?ooo]Z1_l0ohD5o`3oh@?o0<;o1_l0
I_l3ohoo00;o<ol000?o0?lXo`3oQOl0I_l01?l0I_l00ol007oooo]ZoookJP0@oookJP001ooonfX:
o`00O`Go06Ko00?o0<;oo`3oQOlco`000_lco`02oonh00Gojol01Ol0`_l7o`1Vo`Go0?n51_l0on48
oookJPOo06Ko0_lco`08o`3o:0Oooe`02?l0on400ooonf[o0<;oo`32o`06o`32oaWooo]Z1on?o`09
o`32o`03o`3oQOl0I_oo06Ko00Oo06Ko1?oonfX3o`00O`?ooo]Z0ol007l?oookJP[o06Ko2OoonfX0
0ooo003o0?oQo`3oh@09o`3oh@_oo`001?oonfX<oc?o00[ooo]Z1_n?o`0;o`32o`03o`3ohOoonf[o
oo]Z00cooo]Z1Ol0000=oookJPWo06Ko1?l0`_l00ol0obSookP0oonh000=oonh00_o<ol02_l0I_l6
oookJP_o0?n53ooonfX;o`3o:0;ooo]Z2_l0on401?oonf[o001oo`00Ool007l3oookJP?o001o1Ooo
nfX5o`3oQ@Wo0<;o3OoonfX8o`1Vo`[ooo]Z2?l0`_l6ohoo0003oomL0?l0I_oo06Ko00Ko06Ko1?oo
G004oookJPSo<ol01ooonfX7o`3o:0?ooo]Z1ol0ohD4o`3oh@Co0<;o1Ol0I_l01?o[o`3oSol0ohoo
0?n?o`02oc?o0003o`3o:?l0ohGo06Ko00Go06Ko4_oonfX000Oooo]Z2_l007l5o`1Vo`06o`32ool0
ohGo<ol0oc?o0?oonf[ookP01_o[o`05o`32o`Ko06Ko1Ol0ohD7o`3oh@Sooo]Z1ol0I_l00olco`3o
0?lXo`3o:006o`3o:0Wooe`02?l0on48o`32oaSooo]Z2On?o`08o`32o`Wo06Ko2ooonfX3o`00Oa3o
oo]Z2_l0I_l8oookJP[o0?oQ0_l0ohD=ool000go<ol03OoonfX3ohoo00[o0<;o1?l0on4=oookJPGo
00003?oonfX9o`1Vo`Oo0<;o3?oo^004oookJP[o<ol02_l0I_l4oookJP[o0?n54ooonfX:o`3o:0[o
0?oQ0_oonfX3o`00O`?ooo]Z0ol007l4oookJP;ojol00ol0ohD9o`32o`gooo]Z2?l0I_l2o`3oh@[o
oo]Z2?l0`_l4ohoo00?ooo]Z2?l0I_l4oomL00?ooo]Z1olco`07oookJPSo0?lX0ooonfX6o`3oQ@Go
0?oQ0ol0`_l6o`1Vo`04on_o0?n?o`3oSol0ohoo00;o<ol000?o0?lXo`3oQOl0I_l01Ol0I_lBoook
JP004OoonfX5o`1Vo`06o`32ool0ohGo<ol0oc?o0?oonf[ookP01_o[o`05o`32o`Ko06Ko1Ol0ohD6
o`3oh@[ooo]Z1ol0I_l7o`3o:0Sooe`00ooonfX6o`3oh@So0<;o5ooonfX:ohoo00;ooo]Z1_l0`_l9
o`1Vo`cooo]Z0ol007lBoookJPWo06Ko1OoonfX;o`3oh@Go0?n52_oo000<oc?o013ooo]Z2ol0`_l7
o`3oh@_ooo]Z1Ol0000:oookJP[o06Ko2Ol0`_l9oonh00Oooo]Z2olco`0:o`1Vo`_o0?n55OoonfX8
o`3o:0Wo0?oQ1?oonfX3o`00O`?ooo]Z0ol007l2oookJPGojol000?o0?n5o`32ool0`_l01ol0`_l=
oookJPWo06Ko0ol0on4:oookJPSo0<;o0_n?o`05oookJPOo06Ko1OooG0000ooonf[o<ol0oc?o0006
oc?o00Oooo]Z1ol0obP4oookJPKo0?n51Ol0on43o`32o`Ko06Ko0_o[o`02ohoo00;o<ol000?o0?lX
o`3oQOl0I_l01Ol0I_lBoookJP004OoonfX5o`1Vo`06o`32ool0ohGo<ol0oc?o0?oonf[ookP01_o[
o`001?oonf[o0<;oo`32ool0`_l7o`1Vo`03oookJ_l0ohGo0?n500;o0?n51_l0on4:oookJPOo06Ko
1ol0obP6oomL00Gooo]Z1Ol0on48o`32oaOooo]Z2_n?o`02oookJP;o0?n51?l0`_l9o`1Vo`;ojol0
1_oonfX2o`00O`;ooo]Z1?l007lCoookJPWo06Ko0ooonfX:o`3oh@So0?n52?oo000;oc?o00;oo`00
3ooonfX:o`32o`[o0?oQ2_oonfX5o`0000Wooo]Z2_l0I_l00ol0obSo0<;oo`32o`09o`32o`GookP0
2ooonfX:oc?o00[o06Ko2?l0ohDHoookJPKo0?lX2Ol0on45oookJP?o001o0ooonfX3o`00O`03oook
J_o[o`3ojol000Cojol02Ol0`_l2o`3oQ@_ooo]Z2Ol0I_l4o`3oh@[ooo]Z2Ol0`_l6oookJPSo06Ko
1?ooG008oc?o00Oooo]Z2?l0obP3oookJPOo0?n51Ol0on43o`32o`Ko06Ko0_o[o`02ohoo00?o<ol0
00?o0?n5o`1Vool0I_l01?l0I_lBoookJP004OoonfX5o`1Vo`04o`32ool0ohGo<ol0oc?o00;ooo]Z
1_o[o`001?oonf[o0<;oo`32ool0`_l6o`1Vo`;ooo]Z0ol0ohD7o`3oh@_ooo]Z1ol0I_l5o`3o:0Ko
oe`01ooonfX3o`3oh@So0<;o5ooonfX:ohoo00?ooo]Z0ol0ohD2o`32o`Wo06Ko1Oo[o`04oookJPOo
001o5OoonfX9o`1Vo`03oookJ_l0on7o0?oQ00So0?oQ2_l0ohD5ool000co<ol02?oo0009oookJP[o
0<;o0_n?o`0:o`3oh@Wooo]Z1Ol00008oookJP[o06Ko0_l0obP00ooo^03o0<;oo`32o`09o`32o`;o
okP03_oonfX:oc?o00[o06Ko1_l0ohDKoookJP?o0?lX2Ol0on46oookJP?o001o0ooonfX2o`00O`Oo
jol02Ol0`_l3o`3oQ@[ooo]Z2Ol0I_l6o`3oh@Sooo]Z0_n?o`09o`32o`Kooo]Z1ol0I_l3oomL00So
<ol02?oonfX7o`3o:0Cooo]Z1_l0ohD5o`3oh@Co0<;o1_l0I_l2on_o00?oSol00_lco`000ol0ohGo
0<;oo`1Vo`04o`1Voa;ooo]Z000AoookJPGo06Ko00Co0<;oo`3oQOlco`3o<ol00_oonfX5on_o0003
oonh0?oonf[o0<;o00;o0<;o1_l0I_l2oookJP?o0?n51_l0on4<oookJPOo06Ko1?l0obP2oc?o00Co
oe`02OoonfX2o`3oh@So0<;o5_oonfX:ohoo00?ooo]Z1Ol0ohD9o`1Vo`;o0?lX1Oo[o`03oookJPKo
001o5ooonfX9o`1Vo`Wo0?oQ0_oonfX:o`3oQ@;ooo]Z00?oo`00oc?o0?lco`002Olco`0>ool000Co
oo]Z2_l0`_l4ohoo00[o0?oQ2?oonfX5o`0000Oooo]Z2_l0I_l2o`3o:0?ookP02ol0`_l@oookJP[o
<ol02_l0I_l4o`3oQAgooo]Z00?o0?lXo`3ohOl0on401ol0on400ol0obSooo]ZoookJP04oookJP?o
001o0ooonfX00ol007oojol0on_o0005on_o00Wo0<;o1Ol0ohD9oookJPSo06Ko2?l0on46oookJPCo
Sol02?l0`_l7oookJPOo06Ko0_ooG008oc?o00Oooo]Z1ol0obP4oookJPOo0?n51Ol0on43o`32o`Ko
06Ko0oo[o`03ohoo00;o<ol000?o0?n5o`32ool0I_l01?l0I_lBoookJP004OoonfX5o`1Vo`05o`32
ool0ohGo<ol0oc?o0?oonfX01_o[o`02oonh00?o0<;o1_l0I_l3oookJP03o`3oQOl0on7o0?oQ00Go
0?oQ3OoonfX7o`1Vo`;o0?lX1?lco`02oomL00_ooo]Z2?l0`_lFoookJP[oSol00ooonfX5o`3oQ@Wo
06Ko0_l0`_l2o`3o:0Kojol000?ooo]Zo`00Ool007l07?oonfX9o`1Vo`Oo0?oQ1?oonfX:o`3oQ@_o
<ol04_oo000;o`32o`;ooo]Z1?n?o`0;o`3oh@Kooo]Z1Ol00006oookJP[o06Ko0_l0obP6oonh00[o
0<;o4OoonfX9oc?o00[o06Ko0_l0ohDNoookJPWo0?oQ0ol0obP5oookJP?o001o0_oonfX8on_o00Wo
0<;o1ol0ohD7oookJPSo06Ko0_oonfX8o`3oh@?ooo]Z1on?o`08o`32o`Kooo]Z2?l0I_l8oc?o00So
oo]Z1ol0obP4oookJPOo0?n51Ol0on43o`32o`Ko06Ko0oo[o`03ohoo00;o<ol000?o0?n5o`32ool0
I_l01?l0I_lBoookJP004OoonfX5o`1Vo`05o`32ool0ohGo<ol0oc?o0?oonfX01_o[o`02oonh0003
oookJ_l0`_oo06Ko00Go06Ko1?oonfX00ol0ohGo0?oQo`3oh@05o`3oh@gooo]Z1ol0I_l2o`3o:0Co
<ol03?oonfX8o`32o`;o0?oQ5?oonfX9ohoo00Cooo]Z1Ol0ohD9o`1Vo`Co0<;o0ol0obP5on_o00;o
001o7OoonfX9o`1Vo`Co0?oQ2?oonfX:o`3oQ@So<ol04_oo000:o`32o`Kooo]Z1?n?o`0:o`3oh@Go
oo]Z1Ol00004oookJP[o06Ko0_l0obP9oonh00[o0<;o4OoonfX8oc?o00;o0?n52Ol0I_lNoookJPWo
0?oQ1Ol0obP5oookJP?o001o2?o[o`09o`32o`03oookJ_l0ohGo0?n500Ko0?n51OoonfX8o`1Vo`?o
oo]Z2?l0on42oookJPWoSol02?l0`_l6oookJPOo06Ko1olco`02oomL00Kooo]Z1ol0obP4oookJPOo
0?n51_l0on43o`32o`Ko06Ko1?o[o`02ohoo00;o<ol000?o0?n5o`32ool0I_l01?l0I_lBoookJP00
4OoonfX5o`1Vo`05o`32ool0ohGo<ol0oc?o0?oonfX01_o[o`02oonh0003oookJ_l0`_oo06Ko00Go
06Ko1OoonfX6o`3oh@oooo]Z1ol0I_l6oc?o00_ooo]Z1ol0`_l3o`3ohA?ooo]Z2On?o`04oookJPKo
0?n52?l0I_l5o`32o`Co0?lX1Oo[o`07o`00OaSooo]Z2Ol0I_l2o`3oh@[ooo]Z2_l0ohD6oc?o00Go
oo]Z3Ooo000:o`32o`03ool00?oonf[ooo]Z00Gooo]Z1?n?o`0:o`3oh@Cooo]Z1Ol00003oookJP[o
06Ko0_l0obP:oonh00;ooo]Z2Ol0`_lBoookJPGo<ol01?l0ohD8o`1Voagooo]Z2Ol0on47o`3o:0Co
oo]Z00?o001oon_o0?o[o`001oo[o`09o`32o`;o001o2Ol0ohD3oookJPSo06Ko1OoonfX8o`3oh@[o
Sol000?ooo]Zo`32ool0`_l01Ol0`_l6oookJPSo06Ko1Olco`05oomL00Cooo]Z1ol0obP4oookJPOo
0?n51_l0on43o`32o`Ko06Ko1?o[o`02ohoo00;o<ol000?o0?n5o`32ool0I_l01?l0I_lBoookJP00
4OoonfX5o`1Vo`;o0?n50_lco`000ooonf[ojol0on_o0004on_o00;ookP000?ooo]Zo`32ool0I_l0
1Ol0I_l4oookJPOo0?oQ3ooonfX7o`1Vo`Oo<ol02OoonfX8o`32o`Co0?oQ4OoonfX9ohoo00Cooo]Z
1_l0ohD8o`1Vo`Oo0<;o1?l0obP6on_o00Go001o6OoonfX9o`1Vo`cooo]Z2_l0ohD3oc?o00cooo]Z
1ooo000:o`32o`Koo`001OoonfX3ohoo00_o0?oQ0_oonfX5o`0000;ooo]Z2_l0I_l2o`3o:0WookP0
1OoonfX9o`32oa;ooo]Z0olco`06o`3oQ@So06Ko6ooonfX9o`3oh@Wo0?lX0ooonfX9on_o00Wo0<;o
1?l007l9o`3oQ@03oookJ_l0I_oo06Ko00Oo06Ko1_oonfX8o`3oh@SoSol00_oonfX8o`32o`Kooo]Z
1ol0I_l5oc?o00Kooe`00_oonfX7o`3o:0Cooo]Z1ol0ohD00ooonf[o0?oQo`3oh@03o`3oh@Co0<;o
1Ol0I_l5on_o00;oSol00_lco`000ol0ohGo0<;oo`1Vo`04o`1Voa;ooo]Z000AoookJPGo06Ko0_l0
ohD2oc?o0003oookJ_o[o`3ojol000?ojol01?oo^0000ol0`_oo06Koo`1Vo`04o`1Vo`Cooo]Z1_l0
on42o`3oQ@gooo]Z0_l0obP7o`1Vo`Ko<ol02OoonfX7o`32o`Ko0?oQ3ooonfX9ohoo00Cooo]Z1_l0
ohD8o`1Vo`03oookJ_l0`_oo0<;o00Ko0<;o1?l0obP6on_o01cooo]Z0_l0on49o`1Vo`cooo]Z2_l0
ohD00olco`3ooo]ZoookJP0?oookJP;oo`002_l0`_l;ool000;ooo]Z0on?o`0;o`3oh@03oookJ_l0
003o000000?o000000?ooo]Zo`1Vool0I_l02?l0I_l00ol0obSookP0oonh0007oonh00Sooo]Z2Ol0
`_lCoookJPSo0?n52?l0I_lIoookJPWo0?oQ0_oonfX9o`3o:0_ojol02?l0`_l6oookJPWo0?n52?l0
I_l8oookJPOo0?oQ1on?o`04oookJPOo0<;o1ooonfX7o`1Vo`?o<ol02?ooG0000ooonf[o0?lXo`3o
:005o`3o:0Cooo]Z1ol0ohD6o`3oh@?o0<;o1_l0I_l00ooonf[ojol0on_o0002on_o00;oSol00_lc
o`000ol0ohGo0<;oo`1Vo`04o`1Voa;ooo]Z000AoookJPGo06Ko0_l0ohD2oc?o00Kojol01?oo^006
o`1Vo`03o`32oooonf[ooo]Z00;ooo]Z1_l0on42o`3oQ@_ooo]Z0_ooG002o`3o:0Oo06Ko1olco`07
oookJPOo0<;o2?l0on4=oookJPWoSol01?oonfX6o`3oQ@So06Ko0ooonfX8o`32o`Co0?lX1oo[o`0I
oookJPCo0?oQ2Ol0I_l:oookJP;o<ol02ol0ohDAoookJPWo0<;o4Ooo0003ohoo00[o0?oQ1Ol0000:
o`1Vo`03o`3o:?oo^03ookP000KookP02ooonfX9o`32oa7ooo]Z2_l0ohD8o`1VoaOooo]Z2Ol0on44
oookJP[o0?lX2?o[o`08o`32o`Sooo]Z1ol0ohD8o`1Vo`Wooo]Z2?l0on44ohoo00Oooo]Z1ol0`_l6
oookJPOo06Ko0_lco`09oomL00Oo0?lX1OoonfX6o`3oQ@03oookJ_l0on7o0?oQ00Co0?oQ0ol0`_l6
o`1Vo`03oookJ_o[o`3ojol000;ojol00_n?o`02oc?o0003o`3oQOl0`_oo06Ko00Co06Ko4_oonfX0
017ooo]Z1Ol0I_l2o`3oQ@03oc?o0?n?o`3ojol000Gojol01?oo^006o`1Vo`04o`32oooonf[ooo]Z
oookJPOo0?oQ0ol0ohD9oookJP;ooe`01?l0obP7o`1Vo`Oo<ol01OoonfX8o`32o`So0?oQ3?oonfX9
ohoo00Cooo]Z1_l0ohD9o`1Vo`?ooo]Z2Ol0`_l4o`3o:0Oojol05ooonfX6o`3oh@Wo06Ko1ooonfX6
oc?o00[o0?n53ooonfX9o`32oa?oo`000on?o`0:o`3oh@;o00002_l0I_l2o`3o:0OookP03_oonfX9
o`32o`oooo]Z2Ol0ohD2oc?o00Wo06Ko5OoonfX9o`3oh@Kooo]Z2_l0obP6on_o00So0<;o2_oonfX5
o`3oQ@So06Ko2ooonfX8o`3oh@;oSol02?oonfX8o`32o`Kooo]Z1ol0I_l00olco`3ooo]ZoomL0007
oomL00Oo0?lX1?oonfX7o`3oQ@03oookJ_l0on7o0?oQ00Co0?oQ0ol0`_l6o`1Vo`03oookJ_o[o`3o
jol000;ojol00on?o`000olco`3o0?lXo`32o`05o`1Voa;ooo]Z000AoookJPGo06Ko0_l0ohD00olc
o`3oSol0on_o0005on_o00CookP01_l0I_l01?l0`_oooo]ZoookJ_oonfX6o`3oh@Co0?n52?oonfX2
oomL00Go0?lX1ol0I_l7oc?o00Gooo]Z1ol0`_l2oookJPSo0?oQ2OoonfX:ohoo00Cooo]Z1ol0ohD8
o`1Vo`Gooo]Z2Ol0`_l4o`3o:0Oojol05OoonfX8o`3oh@Wo06Ko1OoonfX8oc?o00[o0?n53OoonfX9
o`32o`?ooo]Z4ooo0002ohoo00[o0?oQ2_l0I_l2o`3o:0KookP04OoonfX9o`32o`cooo]Z2_l0ohD4
oc?o00Wo06Ko4ooonfX9o`3oh@Sooo]Z2_l0obP3on_o0003oookJ_l0`_oo0<;o00Ko0<;o3?oonfX3
o`3oQ@So06Ko3?oonfX00on?o`3o0?oQo`3oh@06o`3oh@[ooo]Z1ol0`_l5oookJP03oc?o0?l0I_oo
06Ko00Go06Ko1?oonfX5oomL00Oo0?lX1OoonfX6o`3oQ@03oookJ_l0on7o0?oQ00Co0?oQ1?l0`_l6
o`1Vo`;ooo]Z0oo[o`03ohoo0003oc?o0?l0obSo0<;o00Go06Ko4_oonfX0017ooo]Z1Ol0I_l01?l0
ohGo0?lXoc?o0?n?o`06on_o00CookP01_l0I_l00ol0`_oooo]ZoookJP07o`3oh@Go0?n51_oonfX3
oomL00Ko0?lX1ol0I_l7oc?o00?ooo]Z2?l0`_l3oookJPSo0?oQ1ooonfX:ohoo00Cooo]Z1ol0ohD8
o`1Vo`Oooo]Z2Ol0`_l4o`3o:0Sojol04_oonfX9o`3oh@03oookJ_l0I_oo06Ko00Oo06Ko0ooonfX:
oc?o00[o0?n52ooonfX9o`32o`Sooo]Z4Ooo0002ohoo00Oo0?oQ2_l0I_l00ol0obSookP0oonh0004
oonh01Cooo]Z2Ol0`_l:oookJP[o0?n51_lco`09o`1Voa7ooo]Z2Ol0on4:oookJP[o0?lX00?ojol0
oookJ_l0`_l02?l0`_l=oookJP03o`3oQOl0I_oo06Ko00Oo06Ko2ooonfX2ohoo00So0?oQ2_oonfX8
o`32o`?ooo]Z0olco`07o`1Vo`Cooo]Z0oooG008o`3o:0Cooo]Z1ol0ohD00ooonf[o0?oQo`3oh@04
o`3oh@Co0<;o1Ol0I_l3oookJPCojol00_n?o`000olco`3o0?lXo`3oh@05o`1Voa;ooo]Z000Aoook
JPGo06Ko00Co0?n5o`3o:?lco`3oSol01Oo[o`04oonh00Ko06Ko0ol0`_l00ooonf[o0?oQo`3oh@05
o`3oh@Go0?n51OoonfX3oomL00Oo0?lX1ol0I_l8oc?o00;ooo]Z1ol0`_l5oookJPSo0?oQ1OoonfX:
ohoo00Cooo]Z1ol0ohD8o`1Vo`Wooo]Z2Ol0`_l4o`3o:0Sojol04?oonfX9o`3oh@?ooo]Z2Ol0I_l0
0ooonf[o<ol0oc?o0008oc?o00;ooo]Z2_l0ohD9oookJPWo0<;o3OoonfX>ool000;oSol01Ol0on4:
o`1Vo`03o`3o:?oo^03ookP000?ookP05ooonfX9o`32o`Sooo]Z2_l0ohD3oookJPGo<ol02Ol0I_l?
oookJPWo0?oQ2OoonfX3on_o00[o0?lX2Ol0`_l?oookJPSo06Ko00?o0?n5oookJ_oonfX02?oonfX4
ohoo00So0?oQ2_oonfX7o`32o`?ooo]Z0olco`07o`1Vo`Gooo]Z0_ooG007o`3o:003oomL0?oonf[o
oo]Z00;ooo]Z1ol0ohD00ooonf[o0?oQo`3oh@04o`3oh@?o0<;o1_l0I_l00ooo^03ooo]ZoookJP04
on_o00;oSol000?o<ol0o`3o:?l0on401Ol0I_lBoookJP000_oonfX?o`0000Go06Ko00Co0?n5o`3o
:?lco`3oSol01Oo[o`04oonh00Ko06Ko0ol0`_l00ol0003o0?oQo`3oh@04o`3oh@Ko0?n51Ol00003
oomL00Oo0?lX00?o0000o`1Vool0I_l01Ol0I_l8oc?o00Oo0<;o1_l00008o`3oh@Co00002_n?o`05
o`0000Ko0?n52?l0I_l;o`0000Wo0<;o1?l0obP9on_o00go00002Ol0on45o`0000Wo06Ko2Olco`05
o`0000[o0?n51Ol0000:o`32oa;o00003?oo00001?n?o`3o0?oQo`3ohOl0on4:o`1Vo`03o`3o:?oo
^03ookP000;ookP06_l0000:o`32o`Go00002_l0ohD5o`0000Go<ol02Ol0I_l=o`0000Wo0?oQ2Ol0
0006on_o00Oo0?lX2Ol0`_l?o`0000So06Ko0ol0ohD8o`0000KoSol02?l0on4:o`0000Oo0<;o00?o
0000oc?o0?lco`000olco`07o`1Vo`Go00002?l0obP2oomL00;o00001ol0ohD00ol0003o0?oQo`3o
h@04o`3oh@Co0<;o1_l0I_l01?oo^03o0000o`000?l00003on_o00;oSol000?o<ol0o`3o:?l0on40
1Ol0I_l?o`0000?ooo]Z0002oookJPoo00001Ol0I_l01?l0ohGo0?lXoc?o0?n?o`05on_o0004o`00
0?oo^03ookP0oonh00Ko06Ko0ol0`_l7o`3oh@Oo0?n50ol00003oomL00Oo0?lX0_l00007o`1Vo`Oo
<ol02?l0`_l7o`0000So0?oQ0_l0000:ohoo00Go00001ol0ohD8o`1Vo`co00002Ol0`_l5o`3o:0So
jol02ol00009o`3oh@Oo00002Ol0I_l6oc?o00So00002_l0ohD3o`0000[o0<;o5ol00009ool00003
ohoo0?l0on7o06Ko00So06Ko00?o0?lXoonh0?oo^0000_oo^00Mo`0000[o0<;o0ol0000:o`3oQ@So
00001?lco`09o`1Vo`_o00002Ol0on48o`0000Wojol01Ol0obP9o`32o`oo00002?l0I_l4o`3oQ@Oo
00002?n?o`08o`3oh@Wo00002?l0`_l5oc?o00Oo06Ko1Ol00007o`3o:0Cooe`000?o0000o`3oQOl0
ohD01Ol0ohD00ol0003o0?oQo`3oh@04o`3oh@Co0<;o1_l0I_l2oonh00;o00000oo[o`02ohoo0003
oc?o0?l0obSo0?oQ00Go06Ko3ol00003oookJP000_oonfX?o`0000Go06Ko00Co0?n5o`3o:?lco`3o
Sol01?o[o`02o`0000;ookP01ol0I_l4o`32o`Go0?oQ0_l00006o`3oQ@;o00001?ooG007o`3o:0?o
00001ol0I_l6oc?o00Oo0<;o2Ol00008o`3oh@WoSol01_l00007o`3oQ@So06Ko3_l00009o`32o`Go
0?lX2?o[o`09o`0000Wo0?oQ2Ol00009o`1Vo`Co<ol02_l0000:o`3oQ@03o`000?l0`_oo0<;o00So
0<;o6ol00005ool00003oonh0?l0obSo06Ko00So06Ko0_l0on400on?o`3ookP0ool00003ool001co
00002_l0`_l00ol0003o0?n5o`3oQ@07o`3oQ@_o00001?lco`09o`1Vo`Wo00002Ol0on48o`0000_o
jol00ol0obP9o`32o`oo00002?l0I_l6o`3oQ@Go00002On?o`09o`3oh@Wo00001ol0`_l6oc?o00Oo
06Ko0ol00007o`3o:0Gooe`01ol0ohD2o`0000Ko0?oQ1?l0`_l6o`1Vo`;ookP00_l00003on_o00?o
Sol000?o0?lXo`3ohOl0I_l01?l0I_l?o`0000?ooo]Z0002oookJPoo00001Ol0I_l01?l0on7o0?lX
oc?o0?n?o`04on_o00;o00000_oo^006o`1Vo`Go0<;o1Ol0on42o`0000Oo0?n51?ooG007o`3o:0Co
00001ol0I_l00ol0003o<ol0oc?o0002oc?o00So0<;o2_l00008o`3oh@OoSol01_l00007o`3oQ@So
06Ko4?l00009o`32o`Go0?lX2Oo[o`06o`0000Wo0?oQ2ol00009o`1Vo`;o<ol03?l00009o`3oQ@[o
0<;o7ol00002oonh0003o`3o:?l0I_oo06Ko00Oo06Ko1?l0on42ohoo00Ooo`006Ol0000:o`32o`So
0?n53Ol00004oc?o00Wo06Ko1ol00009o`3oh@Oo00003?o[o`02o`000003o`3o:?l0`_oo0<;o00Oo
0<;o3ol00009o`1Vo`Oo0?n50ol00009ohoo00;o00002?l0on49o`0000So0<;o1Olco`07o`1Vo`;o
00002?l0obP5oomL00Oo0?n500?o0000o`3ohOl0on401?l0on45o`32o`Go06Ko0ooo^002o`0000?o
jol00on?o`000ol0obSo0?n5o`1Vo`04o`1Vo`oo00000ooonfX000;ooo]Z3ol00005o`1Vo`03o`3o
hOl0obSo<ol000;oSol00oo[o`03o`000003oonh0?l0I_oo06Ko00Co06Ko1Ol0`_l5o`3oh@;o0000
1ol0ohD4oomL00Oo0?lX1Ol00007o`1Vo`04o`000?lco`3o<ol0oc?o00Oo0<;o2ol00008o`3oh@Ko
Sol01_l00007o`3oQ@So06Ko4_l00009o`32o`Go0?lX2_o[o`03o`0000Wo0?oQ2ol00002oc?o00Wo
06Ko3_l00007o`3oQ@[o0<;o7_l00003oonh0003o`3o:?l0I_oo06Ko00Oo06Ko1_l0on43ohoo00Wo
o`005_l0000:o`32o`Ko0?n54?l00003oc?o00So06Ko1_l00009o`3oh@Oo00002oo[o`04o`0000Wo
0<;o0_l0obP>o`0000So06Ko00?o0000o`3oQOl0ohD01_l0ohD00ol0003oSol0ohoo0007ohoo00Co
00002?l0on49o`0000Oo0<;o1?lco`02o`0000Oo06Ko00?o0000o`3o:?l0obP01Ol0obP5oomL00Oo
0?n50_l00006o`3oh@Co0<;o1_l0I_l4oonh0004o`000?o[o`3ojol0on_o00?oSol000?o0?lXo`3o
QOl0I_l01?l0I_l?o`0000?ooo]Z000AoookJPGo06Ko00?o0?oQo`3o:?lco`000_n?o`03on_o00?o
oo]Z00?ookP0o`1Vool0I_l01?l0I_l6o`32o`?o0?oQ1?oonfX7o`3oQ@;ooe`01ol0obP6oookJPOo
06Ko00?ooo]Zoc?o0?lco`001ol0`_l=oookJPSo0?oQ1?n?o`06oookJPOo0?n52Ol0I_l=oookJP03
o`000?oonf[ooo]Z00?ooo]Z2Ol0`_l5o`3o:0[ojol000?ooo]Zo`3ohOl0on401ol0on4;oookJPCo
<ol02Ol0I_l?oookJPCo0?n52Ol0`_lNoookJP?ookP00_l0obP9o`1Vo`So0?oQ0on?o`0=ool001?o
oo]Z2Ol0`_l4o`3oQA;ooo]Z0olco`08o`1Vo`Cooo]Z2Ol0on46oookJPcojol01?oonfX9o`32o`Co
0?lX00?ooo]Zo`000?oonfX02OoonfX8o`1Vo`;ooo]Z2Ol0ohD8ohoo00Kooo]Z2?l0on49oookJPOo
0<;o0_lco`03oookJPOo06Ko2?l0obP00ooonf[ooe`0oomL0002oomL00Oo0?n50_oonfX6o`3oh@Co
0<;o1_l0I_l4oonh00;ooo]Z0oo[o`02ohoo0003oc?o0?l0ohGo06Ko00Co06Ko4_oonfX0017ooo]Z
1Ol0I_l00ol0on7o0?lXoc?o0002ohoo00;ojol01?oonfX6o`1Vo`03oonh0?l0`_oo0<;o00Co0<;o
0ol0on44oookJPOo0?n50_ooG007o`3o:0Oooo]Z1ol0I_l00ooonf[o0<;oo`32o`06o`32o`kooo]Z
2?l0on42ohoo00Kooo]Z2?l0ohD8o`1Vo`kooo]Z00?o0000oookJ_oonfX01?oonfX9o`32o`Go0?lX
2Oo[o`09o`3oh@_ooo]Z1_lco`09o`1Vo`oooo]Z00?o0?n5o`32ool0`_l02?l0`_lLoookJPGookP0
00?o0?lXo`1Vool0I_l02?l0I_l00ol0003o0?oQo`3oh@07o`3oh@CoSol03ooo000@oookJPWo0<;o
0_l0ohDEoookJP;o<ol02?l0I_l2oookJPWo0?oQ1OoonfX<on_o00Gooo]Z2Ol0`_l6o`3o:003o`00
0?oonf[ooo]Z00Oooo]Z2?l0I_l4oookJPWo0?n51_n?o`08oookJPSo0?oQ2?oonfX8o`32o`Gooo]Z
1ol0I_l6o`3o:0?ooo]Z0_ooG007o`3oQ@;ooo]Z1_l0on45o`32o`Ko06Ko1Ooo^0001?oonf[ojol0
on_o0?o[o`02ohoo0003oc?o0?l0ohGo06Ko00Co06Ko4_oonfX0017ooo]Z1Ol0I_l00ol0on7o0?lX
oc?o0002ohoo00;ojol01?oonfX6o`1Vo`03oonh0?l0`_oo0<;o00Co0<;o0ol0on45oookJPKo0?n5
00?ooe`0o`3o:?l0obP01Ol0obP8oookJPOo06Ko00?ooo]Zo`32ool0`_l01Ol0`_l2oc?o00gooo]Z
00?oSol0o`3ohOl0on401Ol0on400on?o`3ooo]ZoookJP04oookJPSo0?n52?l0I_lGoookJPWo0<;o
1Ol0obP7on_o00Wo0?oQ2_oonfX9oc?o00Wo06Ko3_oonfX:o`32o`03o`3oQOoonf[ooo]Z01Sooo]Z
1Ooo^002o`3o:0[o06Ko0ol00009o`3oh@CoSol04ooo000;oookJP03o`3oQOl0`_oo0<;o00Oo0<;o
5ooonfX2oc?o00So06Ko2Ol0on45oookJPcojol01OoonfX9o`32o`So0?lX2?oonfX8o`1Vo`Kooo]Z
2Ol0ohD4ohoo00Wooo]Z2?l0on47oookJP;o<ol01ol0`_l5oookJPOo06Ko1Ol0obP5oookJP03oomL
0?l0ohGo0?n500Go0?n50_oonfX6o`3oh@Go0<;o1_l0I_l5oonh0004oookJ_o[o`3ojol0on_o00;o
Sol000?o<ol0o`3oQOl0I_l01?l0I_lBoookJP004OoonfX5o`1Vo`03o`3ohOl0obSo<ol000;oSol0
0_o[o`04oookJPKo06Ko00?ookP0o`32ool0`_l01Ol0`_l00ol0on7ooo]ZoookJP04oookJPOo0?n5
1ol0obP9oookJPOo06Ko1ol0`_l3oc?o00_ooo]Z0_n?o`08o`3oh@Kooo]Z1ol0ohD8o`1VoaWooo]Z
2Ol0`_l5o`3o:0Gojol02Ol0on4:oookJP[o<ol000?ooo]Zo`1Vool0I_l01ol0I_l<oookJP[o0<;o
0ol0ohDGoookJPKookP00_l0obP:o`1Vo`Go00002Ol0on45ohoo01Koo`001OoonfX3o`3oQ@Wo0<;o
5ooonfX00olco`3o06Koo`1Vo`07o`1Vo`Oo0?oQ1?oonfX<on_o00Kooo]Z2Ol0`_l00ooonf[o0?lX
o`3o:007o`3o:0Kooo]Z2Ol0I_l7oookJPSo0?n50on?o`0;oookJPSo0?oQ1OoonfX3oc?o00So0<;o
1OoonfX7o`1Vo`Co0?lX1OoonfX00oooG03o0?n5o`3oQ@04o`3oQ@;ooe`000?ooo]Zo`3ohOl0on40
1?l0on45o`32o`Go06Ko1_oo^0001?oonf[ojol0on_o0?o[o`02ohoo0003oc?o0?l0ohGo06Ko00Go
06Ko4OoonfX0017ooo]Z1Ol0I_l00ol0on7o0?lXo`3o:002ohoo00;ojol01?oonfX6o`1Vo`;ookP0
1_l0`_l00ol0on7ooo]ZoookJP03oookJP;ooe`01_l0ohD6o`3o:0[ooo]Z2?l0I_l5o`32o`Co<ol0
2ooonfX3ohoo00Oo0?oQ1OoonfX7o`3oQ@So06Ko6ooonfX9o`32o`Go0?lX00?ooo]Zon_o0?o[o`00
2Ol0on400oo[o`3ooo]ZoookJP07oookJP[o<ol00ooonfX9o`1Vo`[ooo]Z2_l0`_l6o`3oQA?ooo]Z
1ooo^002o`3o:0[o06Ko00?ooo]Zo`000?l000000ol000000ooonf[o0?oQo`3oh@07o`3oh@GoSol0
6Ooo0005o`3oQ@Wo0<;o6?oonfX9o`1Vo`Go0?oQ0ooonfX=on_o00Kooo]Z2Ol0`_l3oookJPWo0?lX
1?oonfX9o`1Vo`Wooo]Z2?l0ohD00on?o`3ooo]ZoookJP0;oookJPSo0?oQ0ooonfX5oc?o00Oo0<;o
1OoonfX7o`1Vo`?o0?lX1_oonfX7o`3oQ@;ooe`01_l0on45o`32o`Ko06Ko1ooo^003on_o00;oSol0
00?o<ol0o`3o:?l0I_l01Ol0I_lAoookJP004OoonfX5o`1Vo`03o`3ohOl0obSo0?lX00;oSol000?o
jol0oookJ_oonfX00_oonfX6o`1Vo`?ookP01_l0`_l00ol0on7ooo]ZoookJP02oookJP?ooe`01ol0
ohD5o`3o:0_ooo]Z1ol0I_l4o`32o`Ko<ol02OoonfX5ohoo00Oo0?oQ0ooonfX7o`3oQ@Wo06Ko7?oo
nfX9o`32o`Go0?lX00?ooo]Zo`3ohOl0on401ol0on44on_o00Gooo]Z2olco`05oookJPWo06Ko2?oo
nfX:o`32o`So0?n54?oonfX7oonh00?o0?lX2_l0I_l2oookJPGo00000_oonfX9o`3oh@KoSol000?o
oo]Zool00?oo00004_oo0008o`3oQ@[o0<;o5ooonfX9o`1Vo`?o0?oQ0ooonfX<on_o00Oooo]Z2Ol0
`_l5oookJPWo0?lX0_oonfX9o`1Vo`Wooo]Z0_n?o`08o`3oQ@kooo]Z2?l0on400ooonf[o<ol0oc?o
0005oc?o00Oo0<;o1OoonfX7o`1Vo`;o0?lX1_oonfX6o`3oQ@?ooe`01_l0on45o`32o`Ko06Ko00?o
oo]Zoonh0?oo^0001?oo^003on_o00;oSol000?o<ol0o`3o:?l0I_l01Ol0I_lAoookJP004OoonfX5
o`1Vo`03o`3ohOl0obSo0?lX00?oSol01?oonfX6o`1Vo`?ookP01ol0`_l3oookJPCooe`01ol0ohD4
o`3o:0cooo]Z2?l0I_l3o`32o`Oo<ol01ooonfX6ohoo00So0?oQ00?ooo]Zo`3oQOl0ohD01Ol0ohD9
o`1Voakooo]Z2Ol0`_l4o`3o:0Wo0?oQ1oo[o`02oookJP_o<ol01ooonfX9o`1Vo`Kooo]Z2Ol0`_l0
0ooonf[o0?n5o`3oQ@08o`3oQ@gooo]Z2?oo^003o`3o:0Wo06Ko1?oonfX5o`0000?ooo]Z2Ol0on47
ohoo00?ooo]Z3ooo000:o`3oQ@[o0<;o5_oonfX00ol0on7o06Koo`1Vo`07o`1Vo`03o`3ohOlco`3o
oo]Z00cojol02?oonfX9o`32o`Oooo]Z2Ol0obP00ooonf[o06Koo`1Vo`06o`1Vo`Sooo]Z1On?o`08
o`3oQ@gooo]Z2Ol0on47oc?o00So0<;o1?oonfX7o`1Vo`03o`3o:?oonf[ooo]Z00Cooo]Z1ol0ohD3
oomL00Ko0?oQ1Ol0`_l6o`1Vo`03oookJ_oo^03ookP000CookP000?ooo]Zon_o0?o[o`000_n?o`00
0olco`3o0?lXo`1Vo`05o`1Voa7ooo]Z000AoookJPGo06Ko00?o0?oQo`3o:?l0obP00on?o`04oook
JPKo06Ko0ooo^0000ol0on7o0<;oo`32o`04o`32o`;ooo]Z1_ooG007o`3oQ@?o0?lX3OoonfX7o`1V
o`;o0<;o00?ooo]Zoc?o0?lco`001_lco`05oookJPSoSol02?l0on46o`3oQ@Wo06Ko8?oonfX9o`32
o`;o0?lX2Ol0on48on_o00_o<ol02_oonfX9o`1Vo`Cooo]Z2Ol0`_l3oookJP[o0?n52_oonfX9oonh
00?o0?lX2Ol0I_l5oookJPGo00001?oonfX:o`3oh@KoSol01ooonfX9ool000[o0?n50_oo000:o`32
oaCooo]Z0ol0on49o`1Vo`?o<ol02_o[o`08oookJPWo0<;o2OoonfX8o`3o:0So06Ko2?oonfX6ohoo
00Wo0?n53OoonfX8o`3oh@Oo<ol000?ooo]Zo`32ool0`_l01Ol0`_l4oookJP03o`3o:?l0I_oo06Ko
00Go06Ko1_oonfX7o`3oQ@;ooe`01_l0on46o`32o`Ko06Ko00?ooo]Zoonh0?oo^0001Ooo^002on_o
00;oSol000?o<ol0o`3o:?l0`_l01Ol0I_lAoookJP004OoonfX5o`1Vo`03o`3ohOl0obSo0?lX00?o
Sol01?oonfX6o`1Vo`?ookP000?o0?oQo`32ool0`_l01?l0`_l2oookJPKooe`01ol0ohD2o`3o:0oo
oo]Z1ol0I_l2oookJPSo<ol01?oonfX9ohoo00Wo0?oQ1Ol0ohD8o`1Vob;ooo]Z2Ol0`_l9o`3oh@So
jol02olco`0<oookJPWo06Ko00?ooo]Zo`32ool0`_l02?l0`_l5oookJP_o0?n51_oonfX9oonh00Co
0?lX2Ol0I_l6oookJPGo00001OoonfX:o`3oh@OoSol02_oonfX2ool000_o0?n51?oo000:o`32oa;o
oo]Z1Ol0on49o`1Vo`?o<ol01oo[o`09oookJPWo0<;o2ooonfX6o`3o:0So06Ko2?oonfX8ohoo00Wo
0?n53OoonfX8o`3oh@Go<ol00_oonfX8o`32o`;ooo]Z0_l0obP7o`1Vo`Gooo]Z1ol0ohD3oomL00Ko
0?oQ1Ol0`_l6o`1Vo`?ooo]Z1_oo^002on_o00;oSol000?o<ol0o`3o:?l0`_l01Ol0I_lAoookJP00
4OoonfX5o`1Vo`03o`3ohOl0obSo0?lX00?oSol01?oonfX5o`1Vo`?ookP00_l0on47o`32o`Sooe`0
1ol0ohD00ol0obSooo]ZoookJP0<oookJP03o`32ool0I_oo06Ko00Ko06Ko0_oonfX8oc?o00;ooo]Z
2On?o`02oookJPWo0?oQ0ol0ohD8o`1VobCooo]Z2Ol0`_l7o`3oh@;ooo]Z1_o[o`0;oc?o00kooo]Z
2_l0I_l8o`32o`Sooo]Z2_l0ohD2oookJP_ookP01?l0obP9o`1Vo`Oooo]Z1Ol00006oookJP[o0?oQ
1on?o`0:oookJP_o0?n51_oo000;o`32o`oooo]Z1ol0on4:o`1Vo`;o<ol01?o[o`0:oookJPWo0<;o
3OoonfX4o`3o:0So06Ko1ooonfX;ohoo00Wo0?n53OoonfX8o`3oh@?o<ol01?oonfX7o`32o`;ooo]Z
0ol0obP7o`1Vo`Cooo]Z1ol0ohD3oomL00Ko0?oQ1Ol0`_l6o`1Vo`?ooo]Z1_oo^003on_o0004ohoo
0?lco`3o0?lXo`32o`Go06Ko4OoonfX0017ooo]Z1Ol0I_l00ol0on7o0?lXo`3o:003ohoo00?ooo]Z
1_l0I_l00ooonf[ookP0oonh0003o`3oh@Ko0<;o1oooG0000ooonf[o0?n5o`3oQ@06o`3oQ@kooo]Z
0_l0`_l7o`1Vo`?ooo]Z2?lco`09ohoo00Cooo]Z2Ol0on400ol0ohGo06Koo`1Vo`06o`1VobKooo]Z
2Ol0`_l5o`3oh@03o`3o:?oonf[ooo]Z00;ooo]Z0_o[o`0;oc?o017ooo]Z2_l0I_l6o`32o`[ooo]Z
2_l0ohD;oonh00Co0?lX2Ol0I_l8oookJPGo00001ooonfX;o`3oh@OoSol01_oonfX;o`3oQ@[oo`00
2_l0`_l2ool000_ooo]Z2Ol0on4:o`1Vo`?o<ol000?ojol0oookJ_oonfX02?oonfX9o`32o`oooo]Z
0_l0obP9o`1Vo`Kooo]Z2on?o`02oookJPWo0?n53OoonfX8o`3oh@03oc?o0?oonf[ooo]Z00Cooo]Z
1ol0`_l4o`3o:0Oo06Ko0ooonfX7o`3oQ@;ooo]Z00?ooe`0o`3ohOl0on401?l0on46o`32o`Ko06Ko
0ooonfX7oonh00;ojol000CoSol0oc?o0?l0obSo0<;o1Ol0I_lAoookJP004OoonfX5o`1Vo`03o`3o
hOl0obSo0?lX00CoSol00_oonfX6o`1Vo`03oookJ_oo^03ookP000?o0?oQ1_l0`_l6oomL00;ooo]Z
00?o0?lXo`3oQOl0ohD01Ol0ohD=oookJP?o0<;o2?l0I_l3oookJPSo<ol01on?o`06oookJPSo0?oQ
2?l0I_lXoookJP[o0<;o0_l0on44o`3o:0?ooo]Z2olco`02on_o017ooo]Z2_l0I_l4o`32o`cooo]Z
2_l0ohD8oonh00Go0?lX2Ol0I_l9oookJPGo00002?oonfX;o`3oh@SoSol00ooonfX;o`3oQ@Cooo]Z
2?oo000:o`32o`Coo`001_oonfX:o`3oh@03oookJ_o[o`3o06Ko00Wo06Ko0olco`09oookJPWo0<;o
4OoonfX9o`1Vo`Kooo]Z2_n?o`05oookJPWo0?n53?oonfX8o`3oh@03oc?o0?oonf[ooo]Z00Cooo]Z
2?l0`_l4o`3o:0Oo06Ko0_oonfX7o`3oQ@?ooo]Z1_l0on45o`32o`Oo06Ko1?oonfX6oonh00;ojol0
00CoSol0oc?o0?l0obSo0<;o1Ol0I_lAoookJP004OoonfX5o`1Vo`03o`3ohOl0obSo0?lX00CoSol0
0_oonfX6o`1Vo`;ooo]Z00CookP0o`3ohOl0on7o0?oQ1ol0`_l5oomL0003oookJ_l0obSo0?lX00So
0?n53?oonfX4o`32o`Oo06Ko0ooonfX:oc?o00CoSol01ooonfX00ol0ohGo0?oQo`3oh@04o`3oh@Wo
06Ko:OoonfX:o`32o`Ko0?lX2olco`06on_o013ooo]Z2_l0I_l2o`32o`kooo]Z2_l0ohD6oonh00Co
0?lX2_l0I_l:oookJPGo00002_oonfX;o`3oh@SoSol02ol0ohD9oookJPGoo`002_l0`_l7ool00003
oookJ_l0on7o0?oQ00So0?oQ1?o[o`0:o`1Vo`Co<ol01OoonfX:o`32oa7ooo]Z2Ol0I_l2o`3o:0?o
oo]Z2on?o`07oookJPWo0?n52_oonfX2oc?o00So0?oQ1ooonfX7o`32o`Co0?lX1ol0I_l00ooonf[o
0?n5o`3oQ@05o`3oQ@?ooo]Z1ol0on45o`32o`Ko06Ko1OoonfX6oonh00;ojol00_n?o`000ol0obSo
0<;oo`1Vo`04o`1Voa7ooo]Z000AoookJPGo06Ko0_l0on400ol0obSoSol0ohoo0002ohoo00;ooo]Z
1_l0I_l2oookJPGo0?oQ1_l0`_l4oomL0003oookJ_l0obSo0?lX00;o0?lX1ol0ohD;oookJPKo0<;o
1ol0I_l3oookJP[o<ol00_n?o`07oookJP?o0?n51?l0on49o`1VobSooo]Z0ol0on4:o`32o`Ko0?lX
2Olco`09on_o00oooo]Z2ol0I_l?oookJP03oonh0?l0ohGo0?n500So0?n50_oo^005o`3o:0[o06Ko
2ooonfX5o`0000_ooo]Z2ol0on45ohoo00_o0?n53_oonfX3ool000[o0<;o1_oo000:o`3oh@Kojol0
2_l0I_l4oc?o00?ooo]Z2_l0`_lAoookJPWo06Ko1?l0obP00ooonf[oSol0ohoo0009ohoo00Wooo]Z
2Ol0ohD9oookJP?o<ol02?l0on46oookJPSo0<;o1?l0obP7o`1Vo`Oo0?n50ooonfX6o`3oh@Ko0<;o
1_l0I_l5oookJPKookP00_o[o`02ohoo0003oc?o0?l0`_oo06Ko00Co06Ko4OoonfX0017ooo]Z1Ol0
I_l2o`3oh@03o`3o:?n?o`3oSol000;oSol00_oonfX5o`1Vo`?ooo]Z1Ol0on46o`32o`?ooe`00_oo
nfX5o`3o:0Oo0?n52OoonfX7o`32o`So06Ko0ooonfX:oc?o00Oooo]Z1Ol0ohD2o`3oh@Wo06Ko:?oo
nfX5o`3oh@[o0<;o1_l0obP7oc?o00cojol02ooonfX4o`32o`[o06Ko3?oonfX4oonh00_o0?n50ol0
obP;o`1Vo`cooo]Z1Ol0000<oookJP_o0?oQ0_n?o`0<o`3oQA?ooo]Z00?oo`00o`32ool0`_l02?l0
`_l3ool000[o0?oQ2Oo[o`0:o`1Vo`?o<ol000?ooo]Zo`32ool0`_l02?l0`_lAoookJPWo06Ko1ol0
obP8ohoo00cooo]Z2Ol0ohD7oookJPGo<ol02?l0on46oookJPOo0<;o0ol0obP00ooonf[o06Koo`1V
o`06o`1Vo`Go0?n50ooonfX7o`3oh@Go0<;o1ol0I_l6oookJPGookP00_o[o`02ohoo0003oc?o0?l0
on7o06Ko00Co06Ko4OoonfX0017ooo]Z1_l0I_l00ol0on7o0?lXohoo0004ohoo0003oookJ_l0I_oo
06Ko00?o06Ko0ooonfX5o`3oh@Oo0<;o0_ooG0000ooonf[o0?lXo`3o:004o`3o:0Oo0?n52OoonfX7
o`32o`03oookJ_l0I_oo06Ko00Ko06Ko0_oonfX00on?o`3o<ol0oc?o0008oc?o00Gooo]Z1ol0ohD9
o`1VobSooo]Z1ol0on4:o`32o`Oo0?lX0olco`02oookJPkojol02?oonfX6o`32o`_o06Ko2?oonfX7
oonh00co0?n52ol0I_l=oookJPGo00003_oonfX;o`3oh@[o0?n55ooonfX;o`32o`[o0?oQ2_o[o`00
0ooonf[o06Koo`1Vo`09o`1Vo`03oc?o0?l0`_oo0<;o00So0<;o4OoonfX9o`1Vo`Wo0?lX1_n?o`0>
oookJPSo0?n51_oonfX6oc?o00So0?oQ1ooonfX7o`32o`;o0?lX0_oonfX7o`1Vo`Go0?n50ooonfX6
o`3oh@Ko0<;o1_l0I_l7oookJPGookP00_o[o`02ohoo0003oc?o0?l0on7o06Ko00Co06Ko4OoonfX0
017ooo]Z1_l0I_l00ol0on7o0?lXohoo0004ohoo00Ko06Ko0_oonfX7o`3oh@Ko0<;o00?ooe`0oook
J_oonfX01ol0obP7o`3oQ@Oooo]Z2?l0`_l00ooonf[o06Koo`1Vo`06o`1Vo`04oookJ_n?o`3oSol0
ohoo00[o<ol00ooonfX7o`3oQ@Wo06Ko0_l0on4VoookJP[o0?oQ2_l0`_l7o`3o:0Gooo]Z3_o[o`04
oookJPWo0<;o2ol0I_l5oookJP[ookP02Ol0ohD<o`1Vo`kooo]Z1Ol0000?oookJPco0?oQ1ol0ohD2
ohoo01Oooo]Z2ol0`_l7o`3oh@_ojol00ooonfX<o`1Vo`So0<;o4?oonfX:o`1Vo`03oookJ_l0obSo
0?lX00So0?lX1?n?o`0@oookJPSo0?n51?oonfX8oc?o00So0?oQ1_oonfX8o`32o`?ooo]Z2?l0I_l3
o`3oQ@Cooo]Z1_l0on46o`32o`Ko06Ko1ooonfX5oonh00;ojol00_n?o`000olco`3o0?oQo`1Vo`04
o`1Voa7ooo]Z000AoookJPKo06Ko00?o0?oQo`3o:?n?o`001?n?o`06o`1Vo`;ooo]Z1_l0on400ooo
^03o0<;oo`32o`04o`32o`;ooo]Z1ol0obP00ooonf[o0?n5o`3oQ@06o`3oQ@Kooo]Z1ol0`_l3oook
JPSo06Ko1On?o`09oc?o0003oookJ_l0ohGo0?n500Go0?n52Ol0I_l5o`3ohB?ooo]Z2_l0on42oook
JP_o0<;o1_l0obP6oookJPkojol000?ooo]Zo`32ool0`_l02Ol0`_l=o`1Vo`gookP01ol0ohD;o`1V
oa3ooo]Z1Ol0000AoookJPco0?oQ1?l0ohD5ohoo01Kooo]Z3?l0`_l4o`3oh@[ojol01?oo0002oook
JPco06Ko1Ol0`_lAoookJP[o06Ko0ooonfX:o`3o:003ohoo0?oonf[ooo]Z017ooo]Z2?l0ohD2oook
JPWo<ol000?ooo]Zo`3ohOl0on401_l0on44oookJP;o0?lX1ol0`_l4oookJPOo06Ko0ol0ohD3oook
JPOo0?oQ1Ol0`_l7o`1Vo`Oooo]Z1_oo^0001Oo[o`3oSol0ohoo0?lco`3o0?oQ00Go06Ko4OoonfX0
017ooo]Z1_l0I_l00ol0on7o0?lXohoo0004ohoo00Ko06Ko0_oonfX6o`3oh@03oonh0?l0`_oo0<;o
00Go0<;o00?ooo]Zo`3o:?l0obP01Ol0obP2oookJPOo0?n51OoonfX7o`32o`Gooo]Z2?l0I_l5ohoo
00So<ol01ol0ohD9o`1Vo`Oo0?oQ8?oonfX:o`3oh@Gooo]Z2ol0`_l7o`3o:0Kooo]Z2oo[o`0<o`32
o`?ooo]Z3_l0I_l9oonh00;ooo]Z00Co0?lXo`3oQOl0ohGo0?n53?l0I_lAoookJPGo00004_oonfX=
o`3oh@WoSol05OoonfX=o`32o`03o`3ohOo[o`3ojol000Oojol02Ooo000<o`1Vo`?o0<;o4?oonfX;
o`1Vo`;ooo]Z0on?o`0;o`3o:1?ooo]Z2?l0ohD9oc?o00?ooo]Z1ol0on43oookJP?o0?lX2?l0`_l4
oookJPOo06Ko00?o0?n5oookJ_oonfX00_oonfX6o`3oh@Ko0<;o1_l0I_l8oookJPKookP000Gojol0
ohoo0?n?o`3o<ol0o`3oh@05o`1Voa7ooo]Z000AoookJP03o`32ool0I_oo06Ko00?o06Ko00?o0?oQ
o`3o:?n?o`001?n?o`06o`1Vo`03oookJ_l0on7o0?oQ00Go0?oQ0_oo^006o`32o`Oo0?lX0ooonfX8
o`3oQ@?ooo]Z2?l0`_l6oookJPWo06Ko0on?o`000ooonf[o<ol0oc?o0003oc?o00So0?n52Ol0I_l9
o`3ohAkooo]Z2_l0on45oookJP;o<ol03Ol0`_l6o`3o:0Kooo]Z1_o[o`0=o`32o`Kooo]Z3ol0I_l5
oonh00;ooo]Z0ol0obP=o`1Vo`;o0?n54OoonfX5o`00017ooo]Z0_l0ohD?o`3oh@OoSol05OoonfX0
0ol0on7o0<;oo`32o`0:o`32o`Oojol03Ooo000=o`1Vo`;o<ol02ooonfX=o`1Vo`;ooo]Z1_n?o`0:
o`3o:1;ooo]Z2Ol0ohD7oc?o00Cooo]Z2?l0on400ooonf[o0?lXo`3o:003o`3o:0So0<;o0ooonfX7
o`1Vo`04o`3oQOoonf[ooo]ZoookJPOo0?oQ1Ol0`_l7o`1Vo`Wooo]Z1Ooo^002on_o0003ohoo0?lc
o`3o0?oQ00Go06Ko4OoonfX0017ooo]Z00?o0<;oo`1Vool0I_l00ol0I_l00ol0on7o0?lXohoo0004
ohoo00Go06Ko0_oonfX6o`3oh@03oomL0?oo^03ookP000Ko0<;o1ol0obP4oookJPOo0?n50ooonfX7
o`32o`Oooo]Z2_l0I_l01?n?o`3ooo]ZoookJ_oonfX3oc?o00So0?n52Ol0I_l00ooonf[o0?oQo`3o
h@08o`3ohA_ooo]Z2ol0on45oookJPCo<ol03Ol0`_l6o`3o:0Oooo]Z0oo[o`0=o`32o`Wooo]Z8ol0
I_l6o`3oQ@kooo]Z1Ol0000?oookJPKo0?n54?l0on46ohoo013ooo]Z1_l0on4=o`32o`;ojol03?oo
0005o`32o`go06Ko00?o<ol0oookJ_oonfX01_oonfX>o`1Vo`03oookJ_n?o`3oSol000OoSol02_l0
obPBoookJPWo0?n51Olco`06oookJPSo0?oQ1_l0obP7o`32o`?ooo]Z00?o0?n5o`1Vool0I_l01Ol0
I_l3oookJPKo0?oQ1_l0`_l7o`1Vo`Wooo]Z1Ooo^002on_o0003ohoo0?lco`3o0?n500Go06Ko4Ooo
nfX0017ooo]Z00?o0<;oo`1Vool0I_l00ol0I_l00ol0on7o0?lXo`3o:003ohoo00Ko06Ko0_oonfX6
o`3oh@03oomL0?oo^03ookP000Oo0<;o1Ol0obP6oookJPOo0?n500?ooo]Zo`32ool0`_l01_l0`_l8
oookJP[o06Ko1?oonfX00olco`3o0?n5o`3oQ@06o`3oQ@Wo06Ko0ooonfX<o`3ohAOooo]Z2ol0on44
oookJPSo<ol03_l0`_l5o`3o:0Cooo]Z3ol0`_l2on_o00Sooo]Z0_oo^00Po`1Vo`_o0?n52ooonfX5
o`0000cooo]Z2ol0ohD@o`3oh@KoSol02ooonfX:o`3oh@ko0<;o0_oonfX8ool000Wo0<;o3ol0I_l0
0ooonf[o06Koo`1Vo`0>o`1Vo`;ooo]Z2on?o`0:o`3o:1;ooo]Z2_l0ohD2oc?o00Sooo]Z2?l0on45
o`3o:0So0<;o00?ooo]Zo`3oQOl0ohD02?l0I_l00ooonf[o0?oQo`3oh@05o`3oh@Ko0<;o1_l0I_l0
0oooG03ooo]ZoookJP07oookJPGookP00_o[o`000on?o`3o<ol0o`3oQ@05o`1Voa7ooo]Z000Aoook
JP03o`32ool0I_oo06Ko00?o06Ko00?o0?oQo`3o:?l0obP00on?o`06o`1Vo`03oookJ_l0on7o0?oQ
00Go0?oQ0_ooG002oonh00Oo0<;o1?l0obP6oookJPOo0?n52?l0`_l8oookJP;oSol02ol0I_l2oook
JPOo0?n52_l0I_l6oookJP_o0?oQ5?oonfX<o`3oh@?ooo]Z3?lco`0So`32o`Gojol00ooonfX8oonh
01co06Ko3ol0ohD8oookJPGo00002_oonfX>o`3oQ@03oookJ_l0on7o0?oQ00oo0?oQ1On?o`07oook
JPko0?oQ8?l0`_lNo`1Vo`03oookJ_n?o`3oSol000[oSol00_oonfX:o`3o:1;ooo]Z2_l0ohD9oook
JPSo0?oQ1Ol0obP00ooonf[o0<;oo`32o`06o`32o`?o0?n51ol0I_l00ooonf[o0?oQo`3oh@04o`3o
h@Ko0<;o1ol0I_l00oooG03ooo]ZoookJP07oookJPGookP00_o[o`000on?o`3o<ol0o`3oQ@05o`1V
oa7ooo]Z000AoookJP03o`32ool0I_oo06Ko00?o06Ko00?o0?oQo`3o:?l0obP00on?o`06o`1Vo`03
oookJ_l0on7o0?oQ00Co0?oQ1?ooG0000ooo^03o0<;oo`32o`05o`32o`?o0?lX2?oonfX5o`3oQ@So
0<;o2?oonfX4ohoo00_o06Ko1_l0ohD;o`1Vo`Sooo]Z2ol0on4@oookJPgo0?oQ0ooonfX=oc?o00;o
oo]Z8?l0`_l9on_o00cookP05ol0I_l2oookJQ;o0?n51OoonfX5o`0000Oooo]Z4?l0ohD4oookJRWo
0?oQ0_o[o`0Oo`32oa_o06Ko00?ooo]Zohoo0?n?o`002_n?o`06oookJP[o0?lX3_oonfX3oc?o00[o
0?n52OoonfX8o`3oh@?o0?lX0ooonfX8o`32o`;o0?n52?l0I_l6o`3oh@Ko0<;o1_l0I_l3oomL00So
oo]Z1Ooo^002on_o0003ohoo0?lco`3o0?n500Go06Ko4OoonfX0017ooo]Z00?o0<;oo`1Vool0I_l0
0ol0I_l00ol0on7o0?lXo`3o:003ohoo00Ko06Ko00?ooo]Zo`3ohOl0on401?l0on45oomL00So0<;o
0_l0obP8oookJPCo0?n52Ol0`_l7oookJPOoSol06Ol0I_l:oookJPgo0?oQ2ooonfX>o`3oh@;ooo]Z
3Olco`07oookJQ[o0<;o3oo[o`09oonh00;o0?lX4_l0I_l7oookJQ?o0?n50_oonfX5o`0000;ooo]Z
4ol0ohD9oookJRCo0?oQ1Oo[o`0Lo`32o`Goo`005Ol0I_l2oookJPgoSol02?oonfX;o`3o:0[ooo]Z
1_lco`0:o`3oQ@Sooo]Z00?o0?lXo`3ohOl0on401_l0on400ol0obSooo]ZoookJP02oookJPWo0<;o
0_l0ohD7o`1Vo`Go0?oQ1_l0`_l7o`1Vo`?ooe`02OoonfX4oonh00;ojol000?oSol0oc?o0?l0ohD0
1Ol0I_lAoookJP004OoonfX00ol0`_oo06Koo`1Vo`03o`1Vo`03o`3ohOl0obSo0?lX00?oSol01Ol0
I_l00ooonf[o0?oQo`3oh@05o`3oh@Cooe`000?ooo]Zoonh0?l0`_l01_l0`_l00ol0obSooo]Zoook
JP08oookJP;o0?n52Ol0`_l7oookJPWoSol05ol0I_l2oc?o00[ooo]Z8ol0on42oookJPko<ol02Ooo
nfXHo`32o`?ooo]Z3oo[o`04oonh017o0?lX4?oonfXZo`3oQ@kooo]Z7_l0on48on_o00?ooo]Z5_l0
`_l:ool0017o06Ko0ooonfX<ohoo00_ooo]Z3?l0obP6oookJPWo<ol02_l0ohD6oookJP?o0?lX2Ol0
on44oookJPWo0<;o0_l0ohD7o`1Vo`Co0?oQ1_l0`_l7o`1Vo`Cooe`02?oonfX4oonh00;ojol000?o
Sol0oc?o0?l0ohD01Ol0I_lAoookJP004OoonfX00ol0`_oo06Koo`1Vo`03o`1Vo`04o`3ohOl0obSo
0?lXoookJP;oSol01Ol0I_l00ooonf[o0?oQo`3oh@04o`3oh@Cooe`00ooonfX00ooo^03o0<;oo`32
o`05o`32o`_ooo]Z2Ol0`_l00ol0ohGooo]ZoookJP04oookJPWoSol00_oonfXEo`1Vo`Go<ol02ooo
nfXOo`3oh@03oookJ_lco`3o<ol000co<ol03_oonfXAo`32o`Ko0?lX0ooonfX?on_o017o0?lX5Ooo
nfXTo`3oQA?ooo]Z6Ol0on49on_o00Oooo]Z4_l0`_l6oookJPWoo`0000?o<ol0o`1Vool0I_l01ol0
I_l3oc?o00;ooo]Z3On?o`0=oookJPgo0?lX0_oonfX=oc?o00[o0?n50ooonfX4o`3o:0_o0?oQ0ooo
nfX8o`32o`03o`3oQOoonf[o06Ko00Oo06Ko0_l0on46o`32o`Oo06Ko1_ooG007oookJPCookP00_o[
o`000on?o`3o<ol0o`3oQ@05o`1Voa7ooo]Z000AoookJP03o`32ool0I_oo06Ko00?o06Ko00Go0?oQ
o`3o:?l0obSooo]Zohoo0006o`1Vo`03oookJ_l0on7o0?oQ00Co0?oQ1?ooG003oookJP03o`3o:?l0
`_oo0<;o00Ko0<;o2OoonfX9o`32o`Co0?n50ooonfX9ohoo00Cooo]Z00?o0?n5o`1Vool0I_l03ol0
I_l9oc?o00[ooo]Z7?l0on400ooonf[o<ol0oc?o000<oc?o01Sooo]Z5Ol0obP4on_o01Oo0?lX6_oo
nfXOo`3oQASooo]Z5?l0on400on?o`3ojol0on_o0006on_o02Cooo]Z1ooo000>oc?o00_oSol04?oo
nfX>o`3o:0co<ol00_oonfX:o`3oQ@03oookJ_l0obSo0?lX00Co0?lX2ol0on400ooonf[o0?n5o`3o
Q@08o`32o`;ooo]Z2?l0I_l6o`32o`So06Ko1_ooG007oookJPGookP00_o[o`000olco`3o0?n5o`1V
o`04o`1Voa7ooo]Z000AoookJP03o`32ool0I_oo06Ko00?o06Ko00Go0?oQo`3o:?l0obSo0?lXohoo
0006o`1Vo`Oo0?oQ0oooG004oookJP;o0?lX2?l0`_l7oookJPWo0<;o1_l0ohD00ooonf[oSol0ohoo
0007ohoo00Cooo]Z0_l0ohD?o`1Vo`go<ol02OoonfXHo`3oh@;ooo]Z3_lco`0MoookJR[o0?lX8?oo
nfXIo`3oQB?ooo]Z4?n?o`03on_o02Wooo]Z1_oo000>oc?o00OoSol05?oonfX=o`3o:0Wo<ol01Ooo
nfX<o`3oQ@Go0?lX2ol0on43o`3oQ@Wo0<;o2?l0I_l6o`32o`Oo06Ko2?ooG007oookJPCookP00_o[
o`000olco`3o0?n5o`1Vo`04o`1Voa7ooo]Z000AoookJP03o`32ool0I_oo06Ko00Co06Ko00Co0?oQ
o`3o:?l0obSoSol01_l0I_l6o`3oh@?ooe`01?oonfX3o`3o:0Wo0<;o1OoonfX9o`32o`So0?n52?n?
o`04oookJPOo0?n52?l0I_l4oookJPgo<ol02ooonfXCo`3oh@;ooo]Z3_lco`0RoookJRCo0?lX9_oo
nfXAo`3oQBSooo]Z0_o[o`0@ohoo02gooo]Z1Ooo000>oc?o00?oSol06?oonfX>o`3o:0Co<ol02?oo
nfX<o`3oQ@Co0?lX00?ooo]Zo`3ohOl0on402_l0on42o`3oQ@Wo0<;o2Ol0I_l2o`32o`Wo06Ko00?o
oo]ZoomL0?ooG0001OooG007oookJPCookP00_o[o`000olco`3o0?n5o`1Vo`04o`1Voa7ooo]Z000A
oookJP03o`32ool0I_oo06Ko00Co06Ko00Co0?oQo`3o:?l0obSooo]Z1_l0I_l6o`3oh@?ooe`01?oo
nfX4o`3o:0[o0<;o00?ooo]Zo`32ool0`_l02?l0`_l;o`3oQ@GoSol000?ooo]Zo`3oQOl0ohD02ol0
ohD<oookJPgo<ol03_oonfX8o`3oh@Gooo]Z3olco`0WoookJQko0?lX1?o[o`0[oookJPGo0000;?oo
nfX6on_o017oSol0;_oonfX2ool00003ohoo0?lco`3o<ol000go<ol000?oo`00oookJ_oonfX05ooo
nfX>o`3o:0_ooo]Z3Ol0ohD00ol0obSooo]ZoookJP02oookJPco0?oQ2Ol0`_lCo`1Vo`?ooo]Z1ooo
G006oookJPCookP00_o[o`000olco`3o0?n5o`1Vo`04o`1Voa7ooo]Z000AoookJP03o`32ool0I_oo
06Ko00Co06Ko00Co0?oQo`3o:?l0obSooo]Z1Ol0I_l7o`3oh@;ooe`01?oonfX6o`3o:1?o0<;o0_oo
nfXLo`3oQ@oooo]Z3_lco`0DoookJQ7o<ol09_oonfX5oonh01[o0?lX2?o[o`0YoookJPGo0000:Ooo
nfX<on_o01;oSol0:OoonfX6ohoo01;o<ol04_oonfX5oc?o00oo0?lX1ooonfX3o`3o:1;o0?n52ol0
on4:o`32oa3o06Ko1?oonfX7oomL00Kooo]Z1?oo^002on_o0003oc?o0?l0ohGo06Ko00Co06Ko4Ooo
nfX0017ooo]Z00?o0<;oo`1Vool0I_l01?l0I_l01?l0on7o0?lXo`3o:?oonfX5o`1Vo`Ko0?oQ0ooo
G004oookJPOo0?lX4Ol0`_l5oookJQSo0?n54ooonfXAoc?o00cooo]Z4_lco`0VoookJPgookP03?l0
obP3oookJQ3ojol09_oonfX5o`0002Kooo]Z4Oo[o`0Eohoo023ooo]Z3?n?o`0Coc?o00cooo]Z2_lc
o`0Ho`3o:1;o0?n52ol0on49o`32oa3o06Ko1OoonfX7oomL00Gooo]Z1?oo^002on_o0003oc?o0?l0
ohGo06Ko00Co06Ko4OoonfX0017ooo]Z0_l0`_l5o`1Vo`03o`3ohOl0obSo0?lX00Ko06Ko1_l0on42
oomL00Cooo]Z1ol0obP2oookJPoo0<;o1ooonfXFo`3oQAKooo]Z:olco`0UoookJQ3ookP04OoonfXB
on_o02;ooo]Z1Ol0000RoookJQ?ojol01OoonfXEohoo01[ooo]Z4On?o`0Xoc?o01[o0?lX4?l0ohD<
o`3oh@So0<;o3_l0I_l6oookJPOooe`01_oonfX3oonh00;ojol000?o<ol0o`3oQOl0I_l01?l0I_lA
oookJP004OoonfX2o`32o`Go06Ko00?o0?oQo`3o:?l0obP01_l0I_l6o`3oh@;ooe`01?oonfX7o`3o
:0?ooo]Z3Ol0`_l7oookJP;oSol05?l0ohDHoookJRSo<ol09OoonfX@oonh01Gooo]Z4oo[o`0Ooook
JPGo00007ooonfXCon_o00[ooo]Z6_n?o`0:oookJQWoSol00ooonfXXoc?o0003oookJ_l0obSo0?lX
01Ko0?lX4Ol0ohD;o`3oh@Wo0<;o2ol0I_l8oookJPKooe`01_oonfX3oonh00;ojol000?o<ol0o`3o
QOl0I_l01?l0I_lAoookJP004OoonfX2o`32o`Go06Ko00?o0?oQo`3o:?l0obP01_l0I_l5o`3oh@;o
oe`01?oonfX7o`3o:0Gooo]Z2_l0`_l2oonh00Kooo]Z1On?o`0>o`3oQAkooo]Z8olco`0UoookJQ7o
okP06_oonfXEon_o01[ooo]Z1Ol0000JoookJQKojol03ooonfXhohoo00Sooo]Z8_lco`06oookJQKo
0?lX0_oonfX@o`3oQ@co0?oQ2?l0`_l8o`1Vo`[ooo]Z1oooG005oookJP?ookP00_o[o`000on?o`3o
0?n5o`1Vo`04o`1Voa7ooo]Z000AoookJP;o0<;o1Ol0I_l00ol0on7o0?lXo`3o:006o`1Vo`Go0?oQ
0_ooG004oookJPOo0?lX1ooonfX;oonh00?ooo]Z2_n?o`09o`3oQB?ooo]Z7?lco`0VoookJQ7ookP0
7ooonfXIon_o01Cooo]Z1Ol0000EoookJQSojol05_oonfXaohoo00oooo]Z00?oo`00oc?o0?lco`00
6?lco`0<oookJPoo0?lX2_oonfX8o`3oQB_ooo]Z1_ooG005oookJPCookP000?ojol0ohoo0?l0ohD0
1Ol0I_lAoookJP004OoonfX2o`32o`Go06Ko00?o0?oQo`3o:?l0I_l01Ol0I_l6o`3oh@03oomL0?oo
nf[ooo]Z00;ooo]Z1ol0obP:oookJP[ookP000?ooo]Zohoo0?n?o`002?n?o`0boookJQCo<ol09_oo
nfXBoonh02Cooo]Z7?o[o`0>oookJPGo00004?oonfXJon_o01kooo]Z:?n?o`0EoookJP;oo`005?lc
o`1KoookJPOooe`01?oonfX4oonh0003on_o0?n?o`3o0?n500Go06Ko4OoonfX0017ooo]Z0_l0`_l5
o`1Vo`03o`3ohOl0obSo06Ko00Go06Ko1Ol0on42oomL00?ooo]Z2?l0obP;oookJPWookP02_n?o`1Z
oookJQ;ookP0:ooonfXSon_o00?ooo]Z1Ol00003oookJR?ojol09OoonfXRohoo01_ooo]Z4ooo001K
oookJPOooe`01?oonfX4oonh0003on_o0?n?o`3o0?n500Go06Ko4OoonfX0017ooo]Z0_l0`_l5o`1V
o`;o0?oQ1_l0I_l5o`3oh@03ohoo0?oonf[ooo]Z00;ooo]Z1ol0obP=oookJPOookP02_n?o`1Xoook
JQ?ookP0<?oonfY;on_o02oooo]Z4_n?o`0WoookJQ?oo`00FOoonfX6oomL00Gooo]Z0ooo^0000oo[
o`3oSol0o`3oQ@05o`1Voa7ooo]Z000AoookJP;o0<;o1Ol0I_l00ol0on7o06Koo`1Vo`05o`1Vo`Go
0?oQ0_n?o`02oookJPSo0?lX3ooonfX3oonh00_oSol0I_oonfXCoonh03Sooo]Z@Oo[o`1`oookJQ;o
o`00EooonfX7oomL00Cooo]Z0ooo^0000oo[o`3oSol0o`3oQ@05o`1Voa7ooo]Z000AoookJP;o0<;o
1Ol0I_l00ol0on7o06Koo`1Vo`04o`1Vo`Go0?oQ0on?o`000ooonf[o0?lXo`3o:006o`3o:17ooo]Z
00?ookP0ohoo0?n?o`002?n?o`000ooo^03ooo]ZoookJP1RoookJQ?ookP0@OoonfXfon_o07Sooo]Z
4_oo001EoookJPKooe`01?oonfX3oonh0003on_o0?n?o`3o0?n500Go06Ko4OoonfX0017ooo]Z0_l0
`_l<o`1Vo`Go0?oQ1?n?o`07o`3o:1;ooo]Z2_n?o`04oonh063ooo]Z4_oo^01:oookJR_ojol0P?oo
nfXAool005?ooo]Z1oooG003oookJP?ookP000?ojol0ohoo0?l0ohD01Ol0I_lAoookJP004OoonfX2
o`32o`co06Ko1Ol0on43ohoo00So0?lX4OoonfX:ohoo00OookP0FooonfXBoonh05Sooo]Z4oo[o`2@
oookJQ7oo`00D?oonfX7oomL00?ooo]Z1?oo^0000on?o`3o0?n5o`1Vo`04o`1Voa7ooo]Z000Aoook
JP;o0<;o2ol0I_l6o`3oh@;oSol02?l0obPAoookJP[oSol02_oo^01FoookJQ;ookP0H_oonfX5o`00
09[ooo]Z4?oo001?oookJPKooe`00ooonfX4oonh0003ohoo0?l0ohGo06Ko00Co06Ko4OoonfX0017o
oo]Z0_l0`_l;o`1Vo`Go0?oQ0_n?o`08o`3o:13ooo]Z2_n?o`0>oonh057ooo]Z4_oo^01UoookJPGo
0000W?oonfX@ool004gooo]Z1oooG002oookJPCookP000?oSol0o`3oQOl0I_l01?l0I_lAoookJP00
4OoonfX3o`32o`[o06Ko1Ol0on400on?o`3o0?lXo`3o:007o`3o:0kooo]Z2on?o`03oookJPkookP0
B_oonfXDoonh06Sooo]Z1Ol0002OoookJQ3oo`00BooonfX6oomL00;ooo]Z1?oo^0000on?o`3o0?n5
o`1Vo`04o`1Voa7ooo]Z000AoookJP?o0<;o2Ol0I_l6o`3oh@Wo0?lX00?oSol0oookJ_oonfX02_oo
nfX<ohoo00Kooo]Z3ooo^012oookJQOookP0J_oonfX5o`000:7ooo]Z4?oo0019oookJPKooe`00ooo
nfX3oonh0003ohoo0?l0ohGo06Ko00Co06Ko4OoonfX0017ooo]Z0ol0`_l9o`1Vo`Go0?oQ2Ol0obP3
ohoo00Sooo]Z3_n?o`09oookJQ3ookP0>OoonfXJoonh06gooo]Z1Ol0002ToookJQ3oo`00A_oonfX7
oomL00;ooo]Z0ooo^0000on?o`3o0?n5o`1Vo`04o`1Voa7ooo]Z000AoookJP?o0<;o2Ol0I_l5o`3o
h@So0?lX2?n?o`000ooonf[oSol0ohoo000>ohoo00cooo]Z4_oo^00_oookJQgookP0L?oonfX5o`00
0:Kooo]Z4?oo0015oookJPKooe`00_oonfX3oonh0003ohoo0?l0ohGo06Ko00Co06Ko4OoonfX0017o
oo]Z0ol0`_l9o`1Vo`Co0?oQ2?l0obPHohoo013ooo]Z5?oo^00UoookJR3ookP0LooonfX5o`000:So
oo]Z4?oo0013oookJPKooe`00_oonfX3oonh0003on_o0?l0ohGo06Ko00Co06Ko4OoonfX0017ooo]Z
0ol0`_l9o`1Vo`?o0?oQ2?l0obPGohoo01Cooo]Z6Ooo^00IoookJR3ookP0N?oonfX5o`000:_ooo]Z
4?oo0010oookJPOooe`000Kooo]Zoonh0?oo^03ookP0on_o0?l0ohD5o`1Voa7ooo]Z000AoookJPCo
0<;o1ol0I_l4o`3oh@Oo0?lX0_oonfXDohoo01Wooo]ZB_oo^01moookJPGo0000[OoonfX@ool003oo
oo]Z1_ooG0001_oonf[ookP0oonh0?oo^03ojol0o`3oQ@Go06Ko4OoonfX0017ooo]Z1Ol0`_l5o`1V
o`Co0?oQ1ol0obP4oookJQ3oSol07ooonfY1oonh08?ooo]Z1Ol0002`oookJPooo`00?OoonfX6oomL
00;ooo]Z0_oo^0000oo[o`3o0?n5o`1Vo`04o`1Voa7ooo]Z000AoookJPGo0<;o00?ojol0oookJ_oo
nfX00_oonfX6oomL00gooo]Z2On?o`0VoookJSOookP0ROoonfX5o`000;;ooo]Z3ooo000koookJPOo
oe`000Gooo]Zoonh0?oo^03ojol0o`3oQ@05o`1Voa7ooo]Z000AoookJPGo0<;o00Cojol0oookJ_oo
nf[ooo]Z1_ooG011oookJRgookP0SooonfX5o`000;Cooo]Z3ooo000joookJPKooe`000Gooo]Zoonh
0?oo^03ojol0o`3oQ@05o`1Voa7ooo]Z000AoookJPGo0<;o00Cojol0oookJ_oonf[ooo]Z1_ooG018
oookJR7ookP0U?oonfX5o`000;Oooo]Z3ooo000goookJPKooe`000Gooo]Zoonh0?oo^03ojol0o`3o
Q@05o`1Voa7ooo]Z000AoookJPGo0<;o00Cojol0oookJ_oonf[ooo]Z1_ooG03moookJPGo0000^Ooo
nfX?ool003Gooo]Z1_ooG0001Ooonf[ookP0oonh0?o[o`3o0?n500Go06Ko4OoonfX0017ooo]Z1Ol0
`_l00oo[o`3ooo]ZoookJP07oomL0?gooo]Z1Ol0002koookJPooo`00=?oonfX6oomL0004oookJ_oo
^03ojol0o`3oQ@Go06Ko4OoonfX0017ooo]Z1Ol0`_l00oo[o`3ooo]ZoookJP06oomL0?7ooo]Z0ol0
07l:oookJPGo0000_OoonfX?ool003;ooo]Z1_ooG0001?oonf[ookP0on_o0?l0ohD5o`1Voa7ooo]Z
000AoookJPGo0<;o00?ojol0oookJ_oonfX01_ooG03aoookJP?o001o2_oonfX5o`000;oooo]Z3_oo
000aoookJPKooe`000Cooo]Zoonh0?o[o`3o0?n51Ol0I_lAoookJP004OoonfX5o`32o`03on_o0?oo
nf[ooo]Z00Kooe`0lOoonfX3o`00O`[ooo]Z1Ol00032oookJPgoo`00;ooonfX7oomL0003oonh0?o[
o`3o0?n500Go06Ko4OoonfX0017ooo]Z1Ol0`_l00oo[o`3ooo]ZoomL0005oomL0?;ooo]Z0ol007l:
oookJPGo0000a?oonfX<ool002oooo]Z1_ooG0000ooo^03ojol0o`3oQ@05o`1Voa7ooo]Z000Aoook
JPGo0<;o00?ojol0oookJ_ooG0001OooG03boookJP?o001o2_oonfX7o`000<Cooo]Z3?oo000]oook
JPKooe`000?ookP0on_o0?l0ohD01Ol0I_lAoookJP004OoonfX5o`32o`03on_o0?oonf[ooe`000Go
oe`0l_oonfX3o`00O`[ooo]Z1Ol00038oookJP_oo`00;?oonfX6oomL00;ookP000?o0?n5o`1Vool0
I_l00ol0I_lAoookJP004OoonfX5o`32o`03on_o0?oonf[ooe`000Gooe`0l_oonfX3o`00O`[ooo]Z
1Ol00039oookJPcoo`00:ooonfX5oomL00;ookP000?o0?n5o`1Vool0I_l00ol0I_lAoookJP004Ooo
nfX5o`32o`03oookJ_ooG03ooe`000Cooe`0looonfX3o`00O`[ooo]Z1Ol0003;oookJP_oo`00:_oo
nfX5oomL00;ookP000?o0?n5o`1Vool0I_l00ol0I_lAoookJP004OoonfX5o`32o`03oookJ_ooG03o
oe`000Cooe`0looonfX3o`00O`[ooo]Z1Ol0003<oookJPcoo`00:?oonfX5oomL00;ookP000?o0?n5
o`1Vool0I_l00ol0I_lAoookJP004OoonfX5o`32o`03oookJ_ooG03ooe`000Cooe`0l?oonfX6o`00
O`[ooo]Z1Ol0003>oookJP_oo`009ooonfX5oomL00;ookP000?o0?n5o`1Vool0I_l00ol0I_lAoook
JP004OoonfX5o`32o`Oooe`0l?oonfX6o`00O`[ooo]Z1Ol0003?oookJP_oo`009ooonfX4oomL00;o
okP000?o0?n5o`1Vool0I_l00ol0I_lAoookJP004OoonfX5o`32o`Kooe`0looonfX4o`00O`[ooo]Z
1Ol0003AoookJP_oo`009OoonfX4oomL00;ookP000?o0?n5o`1Vool0I_l00ol0I_lAoookJP004Ooo
nfX5o`32o`Kooe`0m?oonfX3o`00O`[ooo]Z1Ol0003BoookJP_oo`009?oonfX4oomL00;ookP000?o
0?n5o`1Vool0I_l00ol0I_lAoookJP004OoonfX5o`32o`Kooe`0oooonfX2oookJPGo0000e?oonfX;
ool002;ooo]Z1OooG0000ooo^03o0?n5o`1Vo`04o`1Voa7ooo]Z000AoookJPGo0<;o1OooG03ooook
JP?ooo]Z1Ol0003EoookJP_oo`008OoonfX5oomL0003oonh0?l0ohGo06Ko00Co06Ko4OoonfX0017o
oo]Z1Ol0`_l5oomL0?oooo]Z0ooonfX5o`000=Kooo]Z2ooo000QoookJPCooe`000?ookP0o`3oQOl0
I_l01?l0I_lAoookJP004OoonfX5o`32o`Gooe`0oooonfX3oookJPGo0000f?oonfX;ool001oooo]Z
1?ooG0000ooo^03o0?n5o`1Vo`04o`1Voa7ooo]Z000AoookJPGo0<;o1OooG03ooookJP?ooo]Z1Ol0
003IoookJP_oo`007_oonfX4oomL0003oonh0?l0ohGo06Ko00Co06Ko4OoonfX0017ooo]Z1Ol0`_l5
oomL0?oooo]Z0ooonfX5o`000=_ooo]Z2_oo000MoookJPCooe`000?ookP0o`3oQOl0I_l01?l0I_lA
oookJP004OoonfX5o`32o`Gooe`0oooonfX3oookJPGo0000g?oonfX:ool001cooo]Z1?ooG0000ooo
^03o0?n5o`1Vo`04o`1Voa7ooo]Z000AoookJPGo0<;o1?ooG03ooookJPCooo]Z1Ol0003MoookJP[o
o`006ooonfX4oomL0003oonh0?l0ohGo06Ko00Co06Ko4OoonfX0017ooo]Z1Ol0`_l4oomL0?oooo]Z
1?oonfX5o`000=oooo]Z2Ooo000JoookJPCooe`000?ookP0o`3oQOl0I_l01?l0I_lAoookJP004Ooo
nfX5o`32o`Cooe`0oooonfX4oookJPGo0000h?oonfX9ool001Wooo]Z1?ooG0000ooo^03o0?n5o`1V
o`04o`1Voa7ooo]Z000AoookJPGo0<;o1?ooG03ooookJPCooo]Z1Ol0003QoookJPWoo`006OoonfX3
oomL0003oonh0?l0ohGo06Ko00Co06Ko4OoonfX0017ooo]Z1Ol0`_l4oomL0?oooo]Z1?oonfX5o`00
0>;ooo]Z2Ooo000HoookJP?ooe`000?ookP0o`3oQOl0I_l01?l0I_lAoookJP004OoonfX5o`32o`Co
oe`0oooonfX4oookJPGo0000hooonfX9ool001Oooo]Z0oooG0000ooo^03o0?n5o`1Vo`04o`1Voa7o
oo]Z000AoookJPGo0<;o1?ooG03ooookJPCooo]Z1Ol0003ToookJPSoo`005ooonfX3oomL0003oonh
0?l0ohGo06Ko00Co06Ko4OoonfX0017ooo]Z1Ol0`_l4oomL0?oooo]Z1?oonfX5o`000>Gooo]Z2?oo
000FoookJP?ooe`000?ookP0o`3oQOl0I_l01?l0I_lAoookJP004OoonfX5o`32o`Cooe`0oooonfX4
oookJPGo0000i_oonfX8ool001Gooo]Z0oooG0000ooo^03o0?n5o`1Vo`04o`1Voa7ooo]Z000Aoook
JPGo0<;o1?ooG03ooookJPCooo]Z1Ol0003WoookJPSoo`005?oonfX3oomL0003oonh0?l0ohGo06Ko
00Co06Ko4OoonfX0017ooo]Z1Ol0`_l3oomL0?oooo]Z1OoonfX5o`000>Oooo]Z2Ooo000CoookJP?o
oe`000?ookP0o`3oQOl0I_l01?l0I_lAoookJP004OoonfX5o`32o`?ooe`0oooonfX5oookJPGo0000
j?oonfX9ool001;ooo]Z0oooG0000ooo^03o0?n5o`1Vo`04o`1Voa7ooo]Z000AoookJPGo0<;o0ooo
G03ooookJPGooo]Z1Ol0003YoookJPWoo`004_oonfX2oomL0003oonh0?l0ohGo06Ko00Co06Ko4Ooo
nfX0013ooo]Z1_l0`_l3oomL0?oooo]Z1OoonfX5o`000>[ooo]Z2?oo000BoookJP;ooe`000?ookP0
o`3oQOl0I_l01?l0I_lAoookJP004?oonfX6o`32o`?ooe`0oooonfX5oookJPGo0000jooonfX8ool0
017ooo]Z0_ooG0000ooo^03o0?n5o`1Vo`04o`1Voa7ooo]Z000@oookJPKo0<;o0oooG03ooookJPGo
oo]Z1Ol0003/oookJPSoo`004?oonfX2oomL0003oonh0?l0ohGo06Ko00Co06Ko4OoonfX0013ooo]Z
1_l0`_l3oomL0?oooo]Z1OoonfX5o`000>gooo]Z1ooo000@oookJP?ooe`000?o0?n5o`1Vool0I_l0
0ol0I_lAoookJP004?oonfX5o`32o`04o`3oQOooG03ooe`0oomL0?oooo]Z1OoonfX5o`000>gooo]Z
2?oo000?oookJP?ooe`000?o0?n5o`1Vool0I_l00ol0I_lAoookJP004?oonfX5o`32o`04o`3oQOoo
G03ooe`0oomL0?oooo]Z1OoonfX5o`000>kooo]Z1ooo000?oookJP?ooe`000?o0?n5o`1Vool0I_l0
0ol0I_lAoookJP004?oonfX5o`32o`04o`3oQOooG03ooe`0oomL0?oooo]Z1OoonfX5o`000>oooo]Z
1ooo000>oookJP?ooe`000?o0?n5o`1Vool0I_l00ol0I_lAoookJP004?oonfX5o`32o`04o`3oQOoo
G03ooe`0oomL0?oooo]Z1OoonfX5o`000>oooo]Z2?oo000>oookJP;ooe`000?o0?n5o`1Vool0I_l0
0ol0I_lAoookJP004?oonfX5o`32o`03o`3oQOooG03ooe`00?oooo]Z1_oonfX5o`000?3ooo]Z1ooo
000>oookJP;ooe`000?o0?n5o`1Vool0I_l00ol0I_lAoookJP004?oonfX5o`32o`03o`3oQOooG03o
oe`00?oooo]Z1_oonfX5o`000?3ooo]Z2?oo000=oookJP;ooe`000?o0?n5o`1Vool0I_l00ol0I_lA
oookJP004?oonfX5o`32o`03o`3oQOooG03ooe`00?oooo]Z1_oonfX5o`000?7ooo]Z2?oo000<oook
JP;ooe`000?o0?n5o`1Vool0I_l00ol0I_lAoookJP004?oonfX5o`32o`03o`3oQOooG03ooe`00?oo
oo]Z1_oonfX5o`000?;ooo]Z1ooo000<oookJP;ooe`000?o0?n5o`1Vool0I_l00ol0I_lAoookJP00
4?oonfX5o`32o`03o`3oQOooG03ooe`00?oooo]Z1_oonfX5o`000?;ooo]Z2?oo000;oookJP;ooe`0
00?ojol0o`1Vool0I_l00ol0I_lAoookJP004?oonfX5o`32o`03o`3oQOooG03ooe`00?oooo]Z1_oo
nfX5o`000??ooo]Z1ooo000;oookJP;ooe`000?ojol0o`1Vool0I_l00ol0I_lAoookJP004?oonfX5
o`32o`03oc?o0?ooG03ooe`00?oooo]Z1_oonfX5o`000?Cooo]Z1ooo000;oookJP03oomL0?o[o`3o
06Ko00Co06Ko4OoonfX0013ooo]Z1Ol0`_l00olco`3ooe`0oomL003ooookJPKooo]Z1Ol0003doook
JPSoo`002_oonfX00oooG03ojol0o`1Vo`04o`1Voa7ooo]Z000@oookJPGo0<;o00?o<ol0oomL0?oo
G000oooonfX6oookJPGo0000mOoonfX7ool000[ooo]Z00?ooe`0on_o0?l0I_l01?l0I_lAoookJP00
4?oonfX5o`32o`03oc?o0?ooG03ooe`00?oooo]Z1_oonfX5o`000?Gooo]Z2?oo0009oookJP03oomL
0?o[o`3o06Ko00Co06Ko4OoonfX0013ooo]Z1Ol0`_l00olco`3ooe`0oomL003ooookJPKooo]Z1Ol0
003foookJPOoo`002OoonfX00oooG03ojol0o`1Vo`04o`1Voa7ooo]Z000@oookJPGo0<;o00?o<ol0
oomL0?ooG000oooonfX6oookJPGo0000mooonfX7ool000Sooo]Z00?ooe`0on_o0?l0I_l01?l0I_lA
oookJP004?oonfX5o`32o`03oc?o0?ooG03ooo]Z0?oooo]Z1_oonfX5o`000?Oooo]Z1ooo0008oook
JP03oomL0?o[o`3o06Ko00Co06Ko4OoonfX0013ooo]Z1Ol0`_l00olco`3ooe`0oookJP3ooookJPKo
oo]Z1Ol0003hoookJPOoo`001ooonfX00oooG03ojol0o`1Vo`04o`1Voa7ooo]Z000@oookJPGo0<;o
00?o<ol0oomL0?oonfX0oooonfX6oookJPGo0000n?oonfX7ool000Oooo]Z00?ooe`0on_o0?l0I_l0
1?l0I_lAoookJP004?oonfX5o`32o`03oc?o0?ooG03ooo]Z0?oooo]Z1_oonfX5o`000?Wooo]Z1_oo
0007oookJP03oomL0?o[o`3o06Ko00Co06Ko4OoonfX0013ooo]Z1Ol0`_l00olco`3ooe`0oookJP3o
oookJPKooo]Z1Ol0003ioookJPOoo`001_oonfX00oooG03ojol0o`1Vo`04o`1Voa7ooo]Z000@oook
JPGo0<;o00?ojol0oomL0?oonfX0oooonfX6oookJPGo0000n_oonfX6ool000Kooo]Z00?ooe`0on_o
0?l0I_l01?l0I_lAoookJP004?oonfX5o`32o`03on_o0?ooG03ooo]Z0?oooo]Z1_oonfX5o`000?[o
oo]Z1ooo0005oookJP03oomL0?o[o`3o06Ko00Co06Ko4OoonfX0013ooo]Z1Ol0`_l00oo[o`3ooe`0
oookJP3ooookJPKooo]Z1Ol0003joookJPOoo`001OoonfX00oooG03ojol0o`1Vo`04o`1Voa7ooo]Z
000@oookJPGo0<;o00?ojol0oomL0?oonfX0oooonfX6oookJPGo0000nooonfX7ool000Cooo]Z00?o
oe`0on_o0?l0I_l01?l0I_lAoookJP004?oonfX5o`32o`03on_o0?ooG03ooo]Z0?oooo]Z1_oonfX5
o`000?_ooo]Z1ooo0004oookJP03oomL0?o[o`3o06Ko00Co06Ko4OoonfX0013ooo]Z1Ol0`_l00oo[
o`3ooe`0oookJP3ooookJPKooo]Z1Ol0003loookJPKoo`001?oonfX00oooG03ojol0o`1Vo`04o`1V
oa7ooo]Z000@oookJPGo0<;o00?ojol0oomL0?oonfX0oooonfX6oookJPGo0000o?oonfX7ool000?o
oo]Z00?ooe`0on_o0?l0I_l01?l0I_lAoookJP004?oonfX5o`32o`03on_o0?oonf[ooo]Z0?Cooo]Z
2Ol007l8oookJPGo0000oOoonfX6ool000?ooo]Z00?ooe`0on_o0?l0I_l01?l0I_lAoookJP004?oo
nfX5o`32o`03on_o0?oonf[ooo]Z0?Cooo]Z2Ol007l8oookJPGo0000oOoonfX6ool000?ooo]Z00?o
oe`0on_o0?l0I_l01?l0I_lAoookJP004?oonfX5o`32o`03on_o0?oonf[ooo]Z0?Cooo]Z1?l007l=
oookJPGo0000oOoonfX7ool000;ooo]Z00?ooe`0on_o0?l0I_l01?l0I_lAoookJP004?oonfX5o`32
o`03on_o0?oonf[ooo]Z0?Gooo]Z1?l007l<oookJPGo0000o_oonfX6ool000?ooo]Z00?ojol0o`1V
ool0I_l00ol0I_lAoookJP004?oonfX5o`32o`03on_o0?oonf[ooo]Z0?Kooo]Z1Ol007l:oookJPOo
0000o?oonfX6ool000?ooo]Z00?ojol0o`1Vool0I_l00ol0I_lAoookJP004?oonfX5o`32o`03on_o
0?oonf[ooo]Z0?Sooo]Z1?l007l9oookJPGo0000o_oonfX6ool000?ooo]Z00?ojol0o`1Vool0I_l0
0ol0I_lAoookJP004?oonfX5o`32o`03on_o0?oonf[ooo]Z0?Wooo]Z0ol007l9oookJPGo0000oooo
nfX5ool000?ooo]Z00?ojol0o`1Vool0I_l00ol0I_lAoookJP004?oonfX5o`32o`03on_o0?oonf[o
oo]Z0?[ooo]Z0ol007l8oookJPGo0000oooonfX6ool000;ooo]Z00?ojol0o`1Vool0I_l00ol0I_lA
oookJP004?oonfX5o`32o`03on_o0?oonf[ooo]Z0?Cooo]Z0ol007l3oookJP?o001o2?oonfX5o`00
0?oooo]Z1_oo0002oookJP03oomL0?l0I_oo06Ko00?o06Ko4OoonfX0013ooo]Z1Ol0`_l00oooG03o
oo]ZoookJP3doookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJPKoo`000_oonfX00oooG03o
06Koo`1Vo`03o`1Voa7ooo]Z000@oookJPGo0<;o00?ooe`0oookJ_oonfX0m?oonfX4o`00O`;ooo]Z
0ol007l8oookJPGo0000oooonfX6ool000;ooo]Z00?ooe`0o`1Vool0I_l00ol0I_lAoookJP004?oo
nfX5o`32o`03oomL0?oonf[ooo]Z0?Gooo]Z1ol007l9oookJPGo0000oooonfX1oookJPGoo`000_oo
nfX00oooG03o06Koo`1Vo`03o`1Voa7ooo]Z000@oookJPGo0<;o00?ooe`0oookJ_oonfX0m_oonfX5
o`00O`[ooo]Z1Ol0003ooookJP7ooo]Z1_oo00000ooonf[ooe`0o`1Vo`04o`1Voa7ooo]Z000@oook
JPGo0<;o00?ooe`0oookJ_oonfX0oooonfX6oookJPGo0000oooonfX1oookJPKoo`0000?ooo]ZoomL
0?l0I_l01?l0I_lAoookJP004?oonfX5o`32o`03oomL0?oonf[ooo]Z0?oooo]Z1_oonfX5o`000?oo
oo]Z0OoonfX6ool00003oookJ_ooG03o06Ko00Co06Ko4OoonfX0013ooo]Z1Ol0`_l00oooG03ooo]Z
oookJP3ooookJPKooo]Z1Ol0003ooookJP7ooo]Z1_oo00000ooonf[ooe`0o`1Vo`04o`1Voa7ooo]Z
000@oookJPGo0<;o00?ooe`0oookJ_oonfX0oooonfX6oookJPGo0000oooonfX2oookJPGoo`0000?o
oo]ZoomL0?l0I_l01?l0I_lAoookJP004?oonfX5o`32o`03oomL0?oonf[ooo]Z0?oooo]Z1_oonfX5
o`000?oooo]Z0_oonfX6ool00003oomL0?l0I_oo06Ko00?o06Ko4OoonfX0013ooo]Z1Ol0`_l00ooo
G03ooo]ZoookJP3ooookJPKooo]Z1Ol0003ooookJP;ooo]Z1_oo00000oooG03o06Koo`1Vo`03o`1V
oa7ooo]Z000@oookJPGo0<;o00?ooe`0oookJ_oonfX0oooonfX6oookJPGo0000oooonfX2oookJPKo
o`0000?ooe`0o`1Vool0I_l00ol0I_lAoookJP004?oonfX5o`32o`03oomL0?oonf[ooo]Z0?oooo]Z
1_oonfX5o`000?oooo]Z0_oonfX6ool00003oomL0?l0I_oo06Ko00?o06Ko4OoonfX0013ooo]Z1Ol0
`_l00oooG03ooo]ZoookJP3ooookJPKooo]Z1Ol0003ooookJP?ooo]Z1_oo0005o`1Voa7ooo]Z000@
oookJPGo0<;o00?ooe`0oookJ_oonfX0oooonfX6oookJPGo0000oooonfX3oookJPKoo`001Ol0I_lA
oookJP004?oonfX5o`32o`03oomL0?oonf[ooo]Z0?oooo]Z1_oonfX5o`000?oooo]Z0ooonfX6ool0
00Go06Ko4OoonfX0013ooo]Z1Ol0`_l00oooG03ooo]ZoookJP3ooookJPKooo]Z1Ol0003ooookJP?o
oo]Z1_oo0005o`1Voa7ooo]Z000@oookJPGo0<;o00?ooe`0oookJ_oonfX0oooonfX6oookJPGo0000
oooonfX4oookJPGoo`001Ol0I_lAoookJP004?oonfX5o`32o`03oomL0?oonf[ooo]Z0?oooo]Z1_oo
nfX5o`000?oooo]Z1?oonfX5ool000Go06Ko4OoonfX0013ooo]Z1Ol0`_l00oooG03ooo]ZoookJP3o
oookJPKooo]Z1Ol0003ooookJPCooo]Z1Ooo0005o`1Voa7ooo]Z000@oookJPGo0<;o00?ooe`0oook
J_oonfX0oooonfX6oookJPGo0000oooonfX4oookJPGoo`001Ol0I_lAoookJP004?oonfX5o`32o`03
oomL0?oonf[ooo]Z0?oooo]Z1_oonfX5o`000?oooo]Z1?oonfX5ool000Go06Ko4OoonfX0013ooo]Z
1Ol0`_l00oooG03ooo]ZoookJP3ooookJPKooo]Z1Ol0003ooookJPCooo]Z1Ooo0005o`1Voa7ooo]Z
000@oookJPGo0<;o00?ooe`0oookJ_oonfX0oooonfX6oookJPGo0000oooonfX5oookJPCoo`001Ol0
I_lAoookJP004?oonfX5o`32o`03oomL0?oonf[ooo]Z0?oooo]Z1_oonfX5o`000?oooo]Z1OoonfX4
ool000Go06Ko4OoonfX0013ooo]Z1Ol0`_l00oooG03ooo]ZoookJP3ooookJPKooo]Z1Ol0003ooook
JPGooo]Z1?oo0005o`1Voa7ooo]Z000@oookJPGo0<;o00?ooe`0oookJ_oonfX0oooonfX6oookJPGo
0000oooonfX5oookJPCoo`001Ol0I_lAoookJP004?oonfX5o`32o`03oomL0?oonf[ooo]Z0?oooo]Z
1_oonfX5o`000?oooo]Z1OoonfX4ool000Go06Ko4OoonfX0013ooo]Z1Ol0`_l00oooG03ooo]Zoook
JP3ooookJPKooo]Z1Ol0003ooookJPGooo]Z1?oo0005o`1Voa7ooo]Z000@oookJPGo0<;o00?ooe`0
oookJ_oonfX0oooonfX6oookJPGo0000oooonfX5oookJPCoo`001Ol0I_lAoookJP004?oonfX5o`32
o`03oomL0?oonf[ooo]Z0?oooo]Z1_oonfX5o`000?oooo]Z1OoonfX4ool000Go06Ko4OoonfX0013o
oo]Z1Ol0`_l00oooG03ooo]ZoookJP3ooookJPKooo]Z1Ol0003ooookJPKooo]Z0ooo0005o`1Voa7o
oo]Z000@oookJPGo0<;o00?ooe`0oookJ_oonfX0oooonfX6oookJPGo0000oooonfX6oookJP?oo`00
1Ol0I_lAoookJP004?oonfX5o`32o`03oomL0?oonf[ooo]Z0?oooo]Z1_oonfX5o`000?oooo]Z1_oo
nfX3ool000Go06Ko4OoonfX0013ooo]Z1Ol0`_l00oooG03ooo]ZoookJP3ooookJPKooo]Z1Ol0003o
oookJPKooo]Z0ooo0005o`1Voa7ooo]Z000@oookJPGo0<;o00?ooe`0oookJ_oonfX0oooonfX6oook
JPGo0000oooonfX6oookJP?oo`001Ol0I_lAoookJP00oooonfXNoookJPGo0000oooonfXOoookJP00
oooonfXNoookJPGo0000oooonfXOoookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-1.06829, -2.78199, \
0.00371579, 0.0152491}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Note how some of the Legendre functions are even and some are odd.  \
Recall that by summing even and odd functions, functions that are neither \
even or odd can be produced.\
\>", "Subsubsection",
  CellTags->{"mmtag:26:HypergeometricU[]", "mmtag:26:LaguerreL[]"}],

Cell["Hypergeometric and Laguerre special functions", "Subtitle",
  CellTags->{"mmtag:26:HypergeometricU[]", "mmtag:26:LaguerreL[]"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here is another differential equation whose solution involves \
special functions.  Many special functions are defined and analyzed precisely \
because they are solutions to simple ODEs\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[
      x\ \(y''\)[x]\  + \ \((q\ \  + \ 1\  - \ x)\)\ \(y'\)[x]\  + \ 
          p\ \ y[x]\  \[Equal] 0, \ y[x], x]\)], "Input"],

Cell[BoxData[
    \({{y[x] \[Rule] 
          C[1]\ HypergeometricU[\(-p\), 1 + q, x] + 
            C[2]\ LaguerreL[p, q, x]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[LaguerreL[4, 1, x], {x, \(-5\), 15}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.0476191 0.214964 0.0140899 [
[.02381 .20246 -13.4688 -20 ]
[.02381 .20246 13.4688 0 ]
[.5 .20246 -7 -20 ]
[.5 .20246 7 0 ]
[.7381 .20246 -12 -20 ]
[.7381 .20246 12 0 ]
[.97619 .20246 -12 -20 ]
[.97619 .20246 12 0 ]
[.2494 .07406 -36.9375 -10 ]
[.2494 .07406 0 10 ]
[.2494 .35586 -24 -10 ]
[.2494 .35586 0 10 ]
[.2494 .49676 -24 -10 ]
[.2494 .49676 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .21496 m
.02381 .22121 L
s
gsave
.02381 .20246 -74.4688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.5 .21496 m
.5 .22121 L
s
gsave
.5 .20246 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.7381 .21496 m
.7381 .22121 L
s
gsave
.7381 .20246 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.97619 .21496 m
.97619 .22121 L
s
gsave
.97619 .20246 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .21496 m
.07143 .21871 L
s
.11905 .21496 m
.11905 .21871 L
s
.16667 .21496 m
.16667 .21871 L
s
.21429 .21496 m
.21429 .21871 L
s
.30952 .21496 m
.30952 .21871 L
s
.35714 .21496 m
.35714 .21871 L
s
.40476 .21496 m
.40476 .21871 L
s
.45238 .21496 m
.45238 .21871 L
s
.54762 .21496 m
.54762 .21871 L
s
.59524 .21496 m
.59524 .21871 L
s
.64286 .21496 m
.64286 .21871 L
s
.69048 .21496 m
.69048 .21871 L
s
.78571 .21496 m
.78571 .21871 L
s
.83333 .21496 m
.83333 .21871 L
s
.88095 .21496 m
.88095 .21871 L
s
.92857 .21496 m
.92857 .21871 L
s
.01 w
0 .21496 m
1 .21496 L
s
.25 Mabswid
.2619 .07406 m
.26815 .07406 L
s
gsave
.2494 .07406 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.2619 .35586 m
.26815 .35586 L
s
gsave
.2494 .35586 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.2619 .49676 m
.26815 .49676 L
s
gsave
.2494 .49676 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
.2619 .10224 m
.26565 .10224 L
s
.2619 .13042 m
.26565 .13042 L
s
.2619 .1586 m
.26565 .1586 L
s
.2619 .18678 m
.26565 .18678 L
s
.2619 .24314 m
.26565 .24314 L
s
.2619 .27132 m
.26565 .27132 L
s
.2619 .2995 m
.26565 .2995 L
s
.2619 .32768 m
.26565 .32768 L
s
.2619 .38404 m
.26565 .38404 L
s
.2619 .41222 m
.26565 .41222 L
s
.2619 .4404 m
.26565 .4404 L
s
.2619 .46858 m
.26565 .46858 L
s
.2619 .04589 m
.26565 .04589 L
s
.2619 .01771 m
.26565 .01771 L
s
.2619 .52494 m
.26565 .52494 L
s
.2619 .55312 m
.26565 .55312 L
s
.2619 .5813 m
.26565 .5813 L
s
.2619 .60948 m
.26565 .60948 L
s
.01 w
.2619 0 m
.2619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.20025 .61803 m
.20597 .5683 L
.22611 .43633 L
.24608 .34046 L
.26452 .27789 L
.27419 .25356 L
.28325 .23539 L
.29318 .22004 L
.29872 .21337 L
.30387 .20827 L
.30917 .20406 L
.31398 .20107 L
.31931 .19861 L
.32224 .19762 L
.32501 .1969 L
.32745 .19644 L
.32868 .19626 L
.33003 .19611 L
.33119 .19601 L
.33242 .19595 L
.33359 .19592 L
.33466 .19592 L
.3353 .19593 L
.33599 .19595 L
.33722 .19601 L
.33791 .19606 L
.33855 .19612 L
.34002 .19628 L
.34246 .19663 L
.3451 .19714 L
.35005 .19841 L
.35467 .19994 L
.36514 .20439 L
.38624 .21609 L
.40497 .22742 L
.42528 .23843 L
.43639 .24319 L
.44126 .24491 L
.44663 .2465 L
.45168 .2477 L
.45641 .24853 L
.45903 .24887 L
.46141 .2491 L
.46273 .24919 L
.46342 .24923 L
.46416 .24927 L
.46488 .2493 L
.46552 .24931 L
.46678 .24933 L
.46799 .24933 L
Mistroke
.46911 .24931 L
.47035 .24926 L
.47167 .24919 L
.47306 .24909 L
.47437 .24897 L
.47683 .24867 L
.47913 .24831 L
.48125 .24791 L
.48606 .24675 L
.49087 .24524 L
.49617 .24316 L
.5069 .23761 L
.51702 .23075 L
.52628 .22311 L
.54715 .20143 L
.58683 .1465 L
.62499 .08627 L
.64628 .05532 L
.6656 .03258 L
.67527 .0241 L
.68071 .02038 L
.68573 .01773 L
.68785 .01684 L
.69012 .01605 L
.69143 .01568 L
.69262 .01539 L
.69375 .01516 L
.69495 .01497 L
.69619 .01483 L
.69735 .01475 L
.69858 .01472 L
.69929 .01472 L
.69995 .01475 L
.70114 .01484 L
.70224 .01497 L
.70344 .01517 L
.7047 .01545 L
.70727 .01621 L
.70969 .0172 L
.71423 .01976 L
.71912 .02361 L
.72442 .02914 L
.73397 .04296 L
.74278 .06051 L
.75245 .08564 L
.76152 .11525 L
.7721 .15799 L
.78215 .20749 L
.80241 .33683 L
.82094 .49442 L
Mistroke
Mfstroke
.82094 .49442 m
.83226 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003oU_oonfX5
o`000?oooo]ZY_oonfX009Kooo]Z1Ol0003ooookJZKooo]Z002FoookJPGo0000oooonfZVoookJP00
U_oonfX5o`000?oooo]ZY_oonfX009Kooo]Z1Ol0003ooookJZKooo]Z002FoookJPGo0000oooonfZV
oookJP00U_oonfX5o`000?oooo]ZY_oonfX009Kooo]Z1Ol0003ooookJZKooo]Z002FoookJPGo0000
oooonfZVoookJP00U_oonfX5o`000?oooo]ZY_oonfX009Kooo]Z1Ol0003]oookJPgo0000ZooonfX0
09Kooo]Z1Ol0003ZoookJQ?o0000Z?oonfX009Kooo]Z1_l0003XoookJQGo0000YooonfX009Kooo]Z
1Ol0003WoookJQWo0000YOoonfX009Kooo]Z1Ol0003VoookJP[o00001ooonfX:o`000:Cooo]Z002F
oookJPGo0000iOoonfX8o`0000gooo]Z2?l0002SoookJP00U_oonfX5o`000>Cooo]Z2?l0000?oook
JPSo0000X_oonfX009Kooo]Z1Ol0003SoookJPOo00004ooonfX7o`000:7ooo]Z002FoookJPGo0000
h_oonfX7o`0001Gooo]Z1ol0002PoookJP00U_oonfX5o`000>7ooo]Z1ol0000GoookJPKo0000X?oo
nfX009Kooo]Z1Ol0003PoookJPOo00006OoonfX6o`0009oooo]Z002FoookJPGo0000h?oonfX6o`00
01_ooo]Z1_l0002NoookJP00U_oonfX5o`000=oooo]Z1_l0000LoookJPKo0000W_oonfX009Kooo]Z
1Ol0003NoookJPKo00007_oonfX6o`0009gooo]Z002FoookJPGo0000gOoonfX7o`0001oooo]Z1Ol0
002MoookJP00U_oonfX5o`000=cooo]Z1ol0000PoookJPKo0000W?oonfX009Kooo]Z1Ol0003Koook
JPOo00008_oonfX6o`0009_ooo]Z002FoookJPGo0000f_oonfX7o`0002?ooo]Z1_l0002KoookJP00
U_oonfX6o`000=Wooo]Z1_l0000UoookJPKo0000V_oonfX009Kooo]Z1Ol0003IoookJPKo00009ooo
nfX5o`0009[ooo]Z002FoookJPGo0000f?oonfX6o`0002Sooo]Z1_l0002IoookJP00U_oonfX5o`00
0=Oooo]Z1ol0000YoookJPGo0000VOoonfX009Kooo]Z1Ol0003FoookJPOo0000:_oonfX6o`0009So
oo]Z002FoookJPGo0000eOoonfX7o`0002cooo]Z1Ol0002HoookJP00U_oonfX5o`000=Gooo]Z1_l0
000]oookJPKo0000UooonfX009Kooo]Z1Ol0003DoookJPKo0000;ooonfX5o`0009Oooo]Z002Foook
JPGo0000dooonfX6o`00033ooo]Z1_l0002FoookJP00U_oonfX5o`000=?ooo]Z1_l0000aoookJPGo
0000U_oonfX009Kooo]Z1Ol0003BoookJPKo0000<_oonfX6o`0009Gooo]Z002FoookJPGo0000dOoo
nfX6o`0003Cooo]Z1Ol0002EoookJP00OooonfX3o`00O`Gooo]Z1Ol007l:oookJPGo0000d?oonfX7
o`0003Cooo]Z1_l0002DoookJP00OooonfX3o`00O`Cooo]Z1ol007l9oookJPGo0000d?oonfX6o`00
03Kooo]Z1Ol0002DoookJP00OooonfX3o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007l9oook
JPGo0000cooonfX6o`0003Oooo]Z1Ol0002DoookJP00KooonfX:o`00O`Kooo]Z0ol007l3oookJP?o
001o0ooonfX3o`00O`Sooo]Z1Ol0003>oookJPKo0000>OoonfX5o`0009?ooo]Z001_oookJP[o001o
1_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o2?oonfX7o`000<cooo]Z1_l0000ioookJPGo0000
TooonfX007oooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003=oookJPKo0000>_oo
nfX6o`0009;ooo]Z001ooookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000c?oonfX6
o`0003cooo]Z1Ol0002BoookJP00OooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o2?oonfX5o`00
0<_ooo]Z1ol0000loookJPKo0000TOoonfX007oooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`So
oo]Z1Ol0003;oookJPKo0000?_oonfX5o`00097ooo]Z001loookJPKo001o0ooonfX3o`00O`?ooo]Z
0ol007l8oookJPGo0000b_oonfX6o`0003oooo]Z1Ol0002AoookJP00O?oonfX6o`00O`Cooo]Z0ol0
07l01?oonf[o001oo`00Ool007l9oookJPGo0000bOoonfX6o`00047ooo]Z1Ol0002@oookJP00O_oo
nfX4o`00O`Cooo]Z1ol007l9oookJPGo0000bOoonfX6o`00047ooo]Z1Ol0002@oookJP00OooonfX3
o`00O`Gooo]Z1Ol007l:oookJPGo0000b?oonfX6o`0004;ooo]Z1Ol0002@oookJP00U_oonfX5o`00
0<Oooo]Z1_l00014oookJPGo0000SooonfX009Kooo]Z1Ol00037oookJPKo0000A?oonfX5o`0008oo
oo]Z002FoookJPGo0000a_oonfX6o`0004Gooo]Z1Ol0002?oookJP00U_oonfX5o`000<Gooo]Z1_l0
0017oookJPGo0000S_oonfX009Kooo]Z1Ol00035oookJPKo0000AooonfX5o`0008kooo]Z002Foook
JPGo0000a?oonfX6o`0004Sooo]Z1Ol0002>oookJP00U_oonfX5o`000<?ooo]Z1_l0001:oookJPGo
0000SOoonfX009Kooo]Z1_l00032oookJPKo0000B_oonfX5o`0008gooo]Z002FoookJPGo0000`_oo
nfX6o`0004_ooo]Z1Ol0002=oookJP00U_oonfX5o`000<;ooo]Z1Ol0001=oookJPCo0000SOoonfX0
09Kooo]Z1Ol00031oookJPKo0000COoonfX5o`0008cooo]Z002FoookJPGo0000`?oonfX6o`0004ko
oo]Z1Ol0002<oookJP00U_oonfX5o`000<3ooo]Z1_l0001>oookJPGo0000S?oonfX009Kooo]Z1Ol0
002ooookJPKo0000D?oonfX5o`0008_ooo]Z002FoookJPGo0000__oonfX6o`00057ooo]Z1Ol0002;
oookJP00U_oonfX5o`000;kooo]Z1_l0001AoookJPGo0000RooonfX009Kooo]Z1Ol0002moookJPKo
0000DooonfX4o`0008_ooo]Z002FoookJPGo0000_?oonfX6o`0005Cooo]Z1Ol0002:oookJP00U_oo
nfX5o`000;cooo]Z1_l0001DoookJPGo0000R_oonfX009Kooo]Z1Ol0002koookJPKo0000EOoonfX5
o`0008[ooo]Z002FoookJPGo0000^_oonfX6o`0005Oooo]Z1?l0002:oookJP00U_oonfX5o`000;[o
oo]Z1_l0001GoookJPGo0000ROoonfX009Kooo]Z1Ol0002ioookJPKo0000F?oonfX5o`0008Wooo]Z
002FoookJPKo0000]ooonfX6o`0005Wooo]Z1Ol00029oookJP00U_oonfX5o`000;Sooo]Z1_l0001J
oookJPCo0000ROoonfX009Kooo]Z1Ol0002goookJPKo0000FooonfX5o`0008Sooo]Z002FoookJPGo
0000]ooonfX5o`0005cooo]Z1Ol00028oookJP00U_oonfX5o`000;Kooo]Z1_l0001LoookJPGo0000
R?oonfX009Kooo]Z1Ol0002eoookJPKo0000G_oonfX4o`0008Sooo]Z002FoookJPGo0000]OoonfX6
o`0005kooo]Z1Ol00027oookJP00U_oonfX5o`000;Cooo]Z1_l0001OoookJPGo0000QooonfX009Ko
oo]Z1Ol0002coookJPKo0000H?oonfX5o`0008Oooo]Z002FoookJPGo0000/ooonfX6o`00067ooo]Z
1?l00027oookJP00U_oonfX5o`000;;ooo]Z1_l0001RoookJPGo0000Q_oonfX009Kooo]Z1Ol0002a
oookJPKo0000HooonfX5o`0008Kooo]Z002FoookJPGo0000/OoonfX6o`0006?ooo]Z1Ol00026oook
JP00U_oonfX5o`000;3ooo]Z1_l0001UoookJPCo0000Q_oonfX009Kooo]Z1Ol0002_oookJPKo0000
I_oonfX5o`0008Gooo]Z002FoookJPGo0000[_oonfX7o`0006Kooo]Z1Ol00025oookJP00U_oonfX6
o`000:gooo]Z1_l0001WoookJPGo0000QOoonfX009Kooo]Z1Ol0002]oookJPKo0000JOoonfX4o`00
08Gooo]Z002FoookJPGo0000[?oonfX6o`0006[ooo]Z1?l00025oookJP00U_oonfX5o`000:cooo]Z
1_l0001ZoookJPGo0000Q?oonfX009Kooo]Z1Ol0002[oookJPKo0000JooonfX5o`0008Cooo]Z002F
oookJPGo0000Z_oonfX6o`0006cooo]Z1Ol00024oookJP00U_oonfX5o`000:Wooo]Z1ol0001]oook
JPCo0000Q?oonfX009Kooo]Z1Ol0002YoookJPKo0000K_oonfX4o`0008Cooo]Z002FoookJPGo0000
Z?oonfX6o`0006oooo]Z1Ol00023oookJP00U_oonfX5o`000:Oooo]Z1_l0001`oookJPGo0000Pooo
nfX009Kooo]Z1Ol0002WoookJPKo0000L?oonfX5o`0008?ooo]Z000EoookJPGo001oO?oonfX5o`00
087ooo]Z1Ol007lPoookJPKo0000FOoonfX3o`00O`Gooo]Z1Ol007l<oookJPCo0000JOoonfX3o`00
O`Gooo]Z1Ol007l=oookJP005?oonfX7o`00Og_ooo]Z1Ol00020oookJPOo001o7_oonfX6o`0005[o
oo]Z0ol007l4oookJPOo001o2ooonfX4o`0006Wooo]Z0ol007l4oookJPOo001o3?oonfX001?ooo]Z
1?l007l01?oonf[o001oo`00Ool007mkoookJPGo0000OooonfX4o`00O`04oookJ_l007oo001oo`00
Oagooo]Z1ol0001JoookJP?o001o1?oonfX3o`00O`04oookJ_l007oo001oo`00O`_ooo]Z1?l0001Y
oookJP?o001o0ooonfX4o`00O`04oookJ_l007oo001oo`00O`cooo]Z0007oookJP[o001o0_oonfX3
o`00O`?ooo]Z0ol007mjoookJPGo0000OooonfX3o`00O`?ooo]Z0ol007lLoookJPKo0000FooonfX3
o`00O`?ooo]Z0ol007l3oookJP?o001o2_oonfX5o`0006Sooo]Z0ol007l3oookJP?o001o0ooonfX3
o`00O`_ooo]Z0007oookJP[o001o2?oonfX3o`00Og[ooo]Z1Ol00025oookJP?o001o6ooonfX6o`00
05cooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`[ooo]Z1Ol0001XoookJP?o001o2OoonfX3o`00
O`_ooo]Z000IoookJP?o001oN_oonfX6o`0008Cooo]Z0ol007lJoookJPKo0000GOoonfX3o`00O`?o
oo]Z0ol007l3oookJP?o001o2_oonfX5o`0006Sooo]Z0ol007l9oookJP?o001o2ooonfX001Cooo]Z
0_l007l2oookJPCo001oN_oonfX5o`00083ooo]Z0_l007l2oookJPCo001o6_oonfX6o`0005gooo]Z
0ol007l3oookJP?o001o0ooonfX3o`00O`_ooo]Z1?l0001XoookJP?o001o1?oonfX2o`00O`;ooo]Z
1?l007l;oookJP005?oonfX7o`00Og_ooo]Z1Ol00020oookJPOo001o6_oonfX6o`0005kooo]Z0ol0
07l3oookJP?o001o0ooonfX3o`00O`_ooo]Z1?l0001XoookJP?o001o1?oonfX7o`00O`cooo]Z000D
oookJPKo001oO?oonfX5o`00083ooo]Z1_l007lJoookJPKo0000GooonfX3o`00O`?ooo]Z0ol007l3
oookJP?o001o2ooonfX4o`0006Sooo]Z0ol007l4oookJPKo001o3OoonfX001Cooo]Z0_l007n0oook
JPGo00008?oonfX<o`0005Cooo]Z0_l007lMoookJPOo0000G?oonfX6o`00O`?ooo]Z0ol007l3oook
JP?o001o2ooonfX5o`0006Cooo]Z1_l007l4oookJP;o001o4OoonfX001Cooo]Z0_l007n0oookJPGo
00007OoonfXCo`00053ooo]Z0_l007lMoookJPKo0000GOoonfX6o`00O`Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l<oookJPGo0000I?oonfX6o`00O`Cooo]Z0_l007lAoookJP005OoonfX7o`00Og[o
oo]Z1Ol0000KoookJQ[o0000C?oonfX7o`00OaKooo]Z1_l0001PoookJPCo001o1?oonfX7o`00O`co
oo]Z1Ol0001VoookJPCo001o1OoonfX7o`00O`_ooo]Z000EoookJPOo001oN_oonfX5o`0001Sooo]Z
7ol0001:oookJPOo001o5OoonfX6o`0006;ooo]Z0ol007l5oookJPGo001o3_oonfX4o`0006Oooo]Z
0ol007l5oookJPOo001o2ooonfX009Kooo]Z1Ol0000GoookJPco00001_oonfX@o`0006?ooo]Z1ol0
001moookJPCo0000POoonfX009Kooo]Z1Ol0000EoookJP_o00003OoonfX>o`00063ooo]Z1ol0001n
oookJPGo0000P?oonfX009Kooo]Z1Ol0000DoookJP[o00005?oonfX;o`0005gooo]Z1ol0001ooook
JPGo0000P?oonfX009Kooo]Z1Ol0000CoookJPSo00006OoonfX:o`0005_ooo]Z1ol00020oookJPGo
0000P?oonfX009Kooo]Z1Ol0000BoookJPSo00007?oonfX:o`0005Sooo]Z1ol00022oookJPCo0000
P?oonfX009Kooo]Z1Ol0000AoookJPOo00008?oonfX:o`0005Gooo]Z1ol00023oookJPCo0000P?oo
nfX000;ooo]Zool0003oo`0003go00000ooonfX000;ooo]Zool0003oo`0003go00000ooonfX000;o
oo]Zool0003oo`0003go00000ooonfX000;ooo]Zool0003oo`0003go00000ooonfX000;ooo]Zool0
003oo`0003go00000ooonfX001;ooo]Z00?o0000oookJ_oonfX0POoonfX5o`0000gooo]Z1_l0000_
oookJP[o0000>?oonfX00ol0003ooo]ZoookJP0:oookJPOo0000LooonfX00ol0003ooo]ZoookJP0D
oookJPCo0000JooonfX00ol0003ooo]ZoookJP0AoookJP00U_oonfX5o`0000cooo]Z1_l0000boook
JP[o0000@_oonfX7o`0008_ooo]Z1?l0001ooookJP00U_oonfX5o`0000_ooo]Z1_l0000eoookJPWo
0000@?oonfX7o`0008cooo]Z1Ol0001noookJP00U_oonfX5o`0000_ooo]Z1_l0000foookJP[o0000
?OoonfX7o`0008gooo]Z1Ol0001noookJP00U_oonfX5o`0000[ooo]Z1_l0000ioookJP[o0000>_oo
nfX7o`0008kooo]Z1Ol0001noookJP00U_oonfX5o`0000[ooo]Z1Ol0000loookJP[o0000=_oonfX8
o`00093ooo]Z1?l0001noookJP00U_oonfX5o`0000Wooo]Z1_l0000moookJP_o0000<ooonfX8o`00
097ooo]Z1?l0001noookJP00U_oonfX5o`0000Sooo]Z1_l00010oookJP_o0000;ooonfX9o`0009;o
oo]Z1?l0001noookJP00U_oonfX5o`0000Sooo]Z1_l00012oookJP_o0000;?oonfX9o`0009?ooo]Z
1Ol0001moookJP00U_oonfX5o`0000Oooo]Z1_l00015oookJP_o0000:?oonfX9o`0009Gooo]Z1Ol0
001moookJP00U_oonfX5o`0000Oooo]Z1Ol00018oookJP_o00009?oonfX:o`0009Kooo]Z1Ol0001m
oookJP00U_oonfX5o`0000Kooo]Z1_l0001:oookJP_o00008?oonfX:o`0009Wooo]Z1?l0001moook
JP00U_oonfX5o`0000Kooo]Z1Ol0001=oookJPco00006ooonfX;o`0009[ooo]Z1?l0001moookJP00
U_oonfX6o`0000Cooo]Z1_l0001?oookJPgo00005OoonfX<o`0009cooo]Z1?l0001moookJP00U_oo
nfX5o`0000Cooo]Z1_l0001BoookJQ3o00002ooonfX?o`0009kooo]Z1Ol0001loookJP00U_oonfX5
o`0000Cooo]Z1_l0001DoookJRKo0000X?oonfX5o`0007cooo]Z002FoookJPGo00000ooonfX6o`00
05Sooo]Z8Ol0002RoookJPGo0000O?oonfX009Kooo]Z1Ol00003oookJPGo0000G?oonfXKo`000:Ko
oo]Z1?l0001loookJP00U_oonfX5o`0000;ooo]Z1_l0001QoookJQ7o0000ZooonfX4o`0007cooo]Z
002FoookJPGo00000_oonfX5o`000?oooo]Z7ooonfX4o`0007cooo]Z002FoookJPGo000000?ooo]Z
o`000?l000001?l0003ooookJQoooo]Z1Ol0001koookJP00U_oonfX5o`000003oookJ_l0003o0000
00?o0000oooonfXPoookJPGo0000NooonfX009Kooo]Z1Ol000000ooonf[o0000o`000003o`000?oo
oo]Z8?oonfX5o`0007_ooo]Z002FoookJP[o0000oooonfXRoookJPCo0000NooonfX009Kooo]Z2_l0
003ooookJR;ooo]Z1?l0001koookJP00U_oonfX:o`000?oooo]Z8_oonfX4o`0007_ooo]Z002Foook
JPWo0000oooonfXSoookJPGo0000N_oonfX009Kooo]Z2Ol0003ooookJR?ooo]Z1Ol0001joookJP00
U_oonfX8o`000?oooo]Z9?oonfX5o`0007[ooo]Z002FoookJPSo0000oooonfXUoookJPCo0000N_oo
nfX009Kooo]Z2?l0003ooookJRGooo]Z1?l0001joookJP00U_oonfX7o`000?oooo]Z9_oonfX4o`00
07[ooo]Z002FoookJPOo0000oooonfXVoookJPCo0000N_oonfX009Kooo]Z1ol0003ooookJRKooo]Z
1Ol0001ioookJP00U_oonfX6o`000?oooo]Z9ooonfX5o`0007Wooo]Z002FoookJPKo0000oooonfXW
oookJPGo0000NOoonfX009Kooo]Z1_l0003ooookJRSooo]Z1?l0001ioookJP00U_oonfX5o`000?oo
oo]Z:OoonfX4o`0007Wooo]Z002FoookJPGo0000oooonfXYoookJPCo0000NOoonfX009Kooo]Z1Ol0
003ooookJRWooo]Z1Ol0001hoookJP00UOoonfX6o`000?oooo]Z:OoonfX5o`0007Sooo]Z002Eoook
JPKo0000oooonfXYoookJPGo0000N?oonfX009Gooo]Z1_l0003ooookJR[ooo]Z1?l0001hoookJP00
U?oonfX7o`000?oooo]Z:_oonfX4o`0007Sooo]Z002DoookJPOo0000oooonfXZoookJPCo0000N?oo
nfX009Cooo]Z2?l0003ooookJRWooo]Z1Ol0001goookJP00U?oonfX7o`000?oooo]Z:_oonfX5o`00
07Oooo]Z002CoookJPSo0000oooonfXZoookJPGo0000MooonfX009?ooo]Z2?l0003ooookJR_ooo]Z
1?l0001goookJP00TooonfX8o`000?oooo]Z:ooonfX4o`0007Oooo]Z002BoookJPWo0000oooonfX[
oookJPCo0000MooonfX009;ooo]Z2Ol0003ooookJR_ooo]Z1Ol0001foookJP00T_oonfX9o`000?oo
oo]Z:ooonfX5o`0007Kooo]Z002AoookJP[o0000oooonfX[oookJPGo0000M_oonfX0097ooo]Z2_l0
003ooookJRcooo]Z1?l0001foookJP00TOoonfX:o`000?oooo]Z;?oonfX4o`0007Kooo]Z002Aoook
JPCo000000?ooo]Zo`000?l000000ol0003ooookJRcooo]Z1?l0001foookJP00T?oonfX5o`000003
oookJ_l0003o000000?o0000oooonfX/oookJPGo0000MOoonfX0093ooo]Z1Ol000000ooonf[o0000
o`000003o`000?oooo]Z;?oonfX5o`0007Gooo]Z002@oookJPGo000000?ooo]Zo`000?l000000ol0
003ooookJRcooo]Z1Ol0001eoookJP00SooonfX5o`0000;ooo]Z1Ol0003ooookJRgooo]Z1?l0001e
oookJP00SooonfX5o`0000;ooo]Z1_l0003ooookJRcooo]Z1?l0001eoookJP00SooonfX5o`0000;o
oo]Z1Ol0003ooookJRgooo]Z1?l0001eoookJP00S_oonfX5o`0000?ooo]Z1Ol0003ooookJRgooo]Z
1Ol0001doookJP00S_oonfX5o`0000?ooo]Z1Ol0003ooookJRgooo]Z1Ol0001doookJP00S_oonfX5
o`0000?ooo]Z1Ol0003ooookJRgooo]Z1Ol0001doookJP00SOoonfX5o`0000Cooo]Z1Ol0003ooook
JRkooo]Z1?l0001doookJP00SOoonfX5o`0000Cooo]Z1Ol0003ooookJRkooo]Z1?l0001doookJP00
SOoonfX5o`0000Cooo]Z1Ol0003ooookJRkooo]Z1?l0001doookJP00SOoonfX4o`0000Gooo]Z1Ol0
003ooookJRkooo]Z1?l0001doookJP00S?oonfX5o`0000Gooo]Z1Ol0003ooookJRkooo]Z1Ol0001c
oookJP00S?oonfX5o`0000Gooo]Z1Ol0003ooookJRkooo]Z1Ol0001coookJP00S?oonfX5o`0000Go
oo]Z1Ol0003ooookJRkooo]Z1Ol0001coookJP00OooonfX3o`00O`Gooo]Z1Ol007l4o`0000Kooo]Z
1Ol0003ooookJRoooo]Z1?l0001coookJP00OooonfX3o`00O`Cooo]Z1_l007l4o`0000Kooo]Z1Ol0
003ooookJRoooo]Z1?l0001coookJP00OooonfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`000004
o`0000Kooo]Z1Ol0003ooookJRoooo]Z1?l0001coookJP00OooonfX3o`00O`?ooo]Z0ol007l3oook
JPGo00001_oonfX5o`000?oooo]Z;ooonfX4o`0007?ooo]Z001ooookJP?o001o0ooonfX3o`00O`?o
oo]Z1Ol00006oookJPOo0000oooonfX]oookJPCo0000LooonfX007oooo]Z0ol007l3oookJP?o001o
0ooonfX4o`0000Oooo]Z1Ol0003ooookJRoooo]Z1?l0001coookJP00OooonfX3o`00O`?ooo]Z0ol0
07l3oookJPCo00001ooonfX5o`000?oooo]Z;ooonfX5o`0007;ooo]Z001ooookJP?o001o0ooonfX3
o`00O`;ooo]Z1Ol00007oookJPGo0000oooonfX_oookJPGo0000L_oonfX007oooo]Z0ol007l3oook
JP?o001o0_oonfX5o`0000Oooo]Z1Ol0003ooookJRoooo]Z1Ol0001boookJP00O?oonfX6o`00O`?o
oo]Z0ol007l2oookJPGo00001ooonfX5o`000?oooo]Z<?oonfX4o`0007;ooo]Z001loookJPKo001o
1?oonfX3o`00O`03oookJ_l0003o000000;o00002?oonfX5o`000?oooo]Z<?oonfX4o`0007;ooo]Z
001noookJPCo001o1?oonfX4o`00O`Co00002?oonfX5o`000?oooo]Z<?oonfX4o`0007;ooo]Z001o
oookJP?o001o1OoonfX2o`00O`Go00002?oonfX5o`000?oooo]Z<?oonfX4o`0007;ooo]Z0029oook
JPGo00002?oonfX5o`000?oooo]Z<?oonfX4o`0007;ooo]Z0029oookJPGo00002?oonfX5o`000?oo
oo]Z<?oonfX4o`0007;ooo]Z0029oookJPCo00002OoonfX5o`000?oooo]Z<?oonfX5o`00077ooo]Z
0029oookJPCo00002OoonfX5o`000?oooo]Z<?oonfX5o`00077ooo]Z0028oookJPGo00002OoonfX5
o`000?oooo]Z<?oonfX5o`00077ooo]Z0028oookJPGo00002OoonfX5o`000?oooo]Z<OoonfX4o`00
077ooo]Z0028oookJPGo00002OoonfX6o`000?oooo]Z<?oonfX4o`00077ooo]Z0028oookJPCo0000
2_oonfX5o`000?oooo]Z<OoonfX4o`00077ooo]Z0028oookJPCo00002_oonfX5o`000?oooo]Z<Ooo
nfX4o`00077ooo]Z0027oookJPGo00002_oonfX5o`000?oooo]Z<OoonfX4o`00077ooo]Z0027oook
JPGo00002_oonfX5o`000?oooo]Z<OoonfX4o`00077ooo]Z0027oookJPGo00002_oonfX5o`000?oo
oo]Z<OoonfX5o`00073ooo]Z0027oookJPCo00002ooonfX5o`000?oooo]Z<OoonfX5o`00073ooo]Z
0027oookJPCo00002ooonfX5o`000?oooo]Z<OoonfX5o`00073ooo]Z0026oookJPGo00002ooonfX5
o`000?oooo]Z<_oonfX4o`00073ooo]Z0026oookJPGo00002ooonfX5o`000?oooo]Z<_oonfX4o`00
073ooo]Z0026oookJPGo00002ooonfX5o`000?oooo]Z<_oonfX4o`00073ooo]Z0026oookJPCo0000
3?oonfX5o`000?oooo]Z<_oonfX4o`00073ooo]Z0026oookJPCo00003?oonfX5o`000?oooo]Z<_oo
nfX4o`00073ooo]Z0025oookJPGo00003?oonfX5o`000?oooo]Z<_oonfX4o`00073ooo]Z0025oook
JPGo00003?oonfX5o`000?oooo]Z<_oonfX5o`0006oooo]Z0025oookJPGo00003?oonfX5o`000?oo
oo]Z<_oonfX5o`0006oooo]Z0025oookJPCo00003OoonfX6o`000?oooo]Z<OoonfX5o`0006oooo]Z
0025oookJPCo00003OoonfX5o`000?oooo]Z<ooonfX4o`0006oooo]Z0024oookJPGo00003OoonfX5
o`000?oooo]Z<ooonfX4o`0006oooo]Z0024oookJPGo00003OoonfX5o`000?oooo]Z<ooonfX4o`00
06oooo]Z0024oookJPGo00003OoonfX5o`000?oooo]Z<ooonfX4o`0006oooo]Z0024oookJPCo0000
3_oonfX5o`000?oooo]Z<ooonfX4o`0006oooo]Z0024oookJPCo00003_oonfX5o`000?oooo]Z<ooo
nfX4o`0006oooo]Z0023oookJPGo00003_oonfX5o`000?oooo]Z<ooonfX5o`0006kooo]Z0023oook
JPGo00003_oonfX5o`000?oooo]Z<ooonfX5o`0006kooo]Z0023oookJPGo00003_oonfX5o`000?oo
oo]Z<ooonfX5o`0006kooo]Z0023oookJPCo00003ooonfX5o`000?oooo]Z=?oonfX4o`0006kooo]Z
0023oookJPCo00003ooonfX5o`000?oooo]Z=?oonfX4o`0006kooo]Z0022oookJPGo00003ooonfX5
o`000?oooo]Z=?oonfX4o`0006kooo]Z0022oookJPGo00003ooonfX5o`000?oooo]Z=?oonfX4o`00
06kooo]Z0022oookJPGo00003ooonfX5o`000?oooo]Z=?oonfX4o`0006kooo]Z0022oookJPCo0000
4?oonfX5o`000?oooo]Z=?oonfX4o`0006kooo]Z0022oookJPCo00004?oonfX6o`000?oooo]Z<ooo
nfX5o`0006gooo]Z0021oookJPGo00004?oonfX5o`000?oooo]Z=?oonfX5o`0006gooo]Z0021oook
JPGo00004?oonfX5o`000?oooo]Z=?oonfX5o`0006gooo]Z0021oookJPGo00004?oonfX5o`000?oo
oo]Z=OoonfX4o`0006gooo]Z0021oookJPCo00004OoonfX5o`000?oooo]Z=OoonfX4o`0006gooo]Z
0021oookJPCo00004OoonfX5o`000?oooo]Z=OoonfX4o`0006gooo]Z0021oookJPCo00004OoonfX5
o`000?oooo]Z=OoonfX4o`0006gooo]Z0021oookJPCo00004OoonfX5o`000?oooo]Z=OoonfX4o`00
06gooo]Z0020oookJPGo00004OoonfX5o`000?oooo]Z=OoonfX4o`0006gooo]Z0020oookJPGo0000
4OoonfX5o`000?oooo]Z=OoonfX5o`0006cooo]Z0020oookJPGo00004OoonfX5o`000?oooo]Z=Ooo
nfX5o`0006cooo]Z0020oookJPCo00004_oonfX5o`000?oooo]Z=OoonfX5o`0006cooo]Z0020oook
JPCo00004_oonfX5o`000?oooo]Z=_oonfX4o`0006cooo]Z0020oookJPCo00004_oonfX5o`000?oo
oo]Z=_oonfX4o`0006cooo]Z0020oookJPCo00004_oonfX5o`000?oooo]Z=_oonfX4o`0006cooo]Z
001ooookJPGo00004_oonfX5o`000?oooo]Z=_oonfX4o`0006cooo]Z001ooookJPGo00004_oonfX6
o`000?oooo]Z=OoonfX4o`0006cooo]Z001ooookJPGo00004_oonfX5o`000?oooo]Z=_oonfX4o`00
06cooo]Z001ooookJPCo00004ooonfX5o`000?oooo]Z=_oonfX5o`0006_ooo]Z001ooookJPCo0000
4ooonfX5o`000?oooo]Z=_oonfX5o`0006_ooo]Z001ooookJPCo00004ooonfX5o`000?oooo]Z=_oo
nfX5o`0006_ooo]Z001ooookJPCo00004ooonfX5o`000?oooo]Z=ooonfX4o`0006_ooo]Z001noook
JPGo00004ooonfX5o`000?oooo]Z=ooonfX4o`0006_ooo]Z001noookJPGo00004ooonfX5o`000?oo
oo]Z=ooonfX4o`0006_ooo]Z001noookJPGo00004ooonfX5o`000?oooo]Z=ooonfX4o`0006_ooo]Z
001noookJPCo00005?oonfX5o`000?oooo]Z=ooonfX4o`0006_ooo]Z001noookJPCo00005?oonfX5
o`000?oooo]Z=ooonfX4o`0006_ooo]Z001noookJPCo00005?oonfX5o`000?oooo]Z=ooonfX5o`00
06[ooo]Z001koookJP?o001o1?l00002o`00O`?ooo]Z1Ol007l:oookJPGo0000oooonfXgoookJPGo
0000J_oonfX007_ooo]Z0_l007l5o`0000;o001o0_oonfX7o`00O`Wooo]Z1Ol0003ooookJSOooo]Z
1Ol0001ZoookJP00NooonfX2o`00O`Go00001?oonfX3o`00O`04oookJ_l007oo001oo`00O`Wooo]Z
1Ol0003ooookJSSooo]Z1?l0001ZoookJP00O?oonfX00ol007oo0000o`000003o`0000?ooo]Z0ol0
07l3oookJP?o001o2?oonfX5o`000?oooo]Z>?oonfX4o`0006[ooo]Z001moookJPCo000000Co001o
oookJ_oonf[ooo]Z0ol007l3oookJP?o001o2?oonfX7o`000?oooo]Z=_oonfX4o`0006[ooo]Z001m
oookJPCo00000_l007l2oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJSSooo]Z1?l0001Z
oookJP00OOoonfX4o`0000;o001o0_oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXhoook
JPCo0000J_oonfX007cooo]Z1Ol00003o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l8oook
JPGo0000oooonfXhoookJPCo0000J_oonfX007_ooo]Z00?o001oo`000?l000000ol00003o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l8oookJPGo0000oooonfXhoookJPGo0000JOoonfX007_o
oo]Z00?o001oo`000?l000000ol00003o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l8oook
JPGo0000oooonfXhoookJPGo0000JOoonfX007_ooo]Z00?o001oo`000?l000000_l000001?oonf[o
001oo`00Ool007l2oookJP?o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`000?oooo]Z>?oonfX5
o`0006Wooo]Z001loookJPCo00000ol007l3oookJPOo001o2OoonfX5o`000?oooo]Z>OoonfX4o`00
06Wooo]Z001loookJPCo00000_l007l5oookJPGo001o2_oonfX5o`000?oooo]Z>OoonfX4o`0006Wo
oo]Z001loookJPCo00005_oonfX5o`000?oooo]Z>OoonfX4o`0006Wooo]Z001koookJPGo00005_oo
nfX5o`000?oooo]Z>OoonfX4o`0006Wooo]Z001koookJPGo00005_oonfX5o`000?oooo]Z>OoonfX4
o`0006Wooo]Z001koookJPGo00005_oonfX5o`000?oooo]Z>OoonfX4o`0006Wooo]Z001koookJPCo
00005ooonfX5o`000?oooo]Z>OoonfX4o`0006Wooo]Z001koookJPCo00005ooonfX5o`000?oooo]Z
>OoonfX5o`0006Sooo]Z001koookJPCo00005ooonfX5o`000?oooo]Z>OoonfX5o`0006Sooo]Z001k
oookJPCo00005ooonfX6o`000?oooo]Z>?oonfX5o`0006Sooo]Z001joookJPGo00005ooonfX5o`00
0?oooo]Z>_oonfX4o`0006Sooo]Z001joookJPGo00005ooonfX5o`000?oooo]Z>_oonfX4o`0006So
oo]Z001joookJPGo00005ooonfX5o`000?oooo]Z>_oonfX4o`0006Sooo]Z001joookJPCo00006?oo
nfX5o`000?oooo]Z>_oonfX4o`0006Sooo]Z001joookJPCo00006?oonfX5o`000?oooo]Z>_oonfX4
o`0006Sooo]Z001joookJPCo00006?oonfX5o`000?oooo]Z>_oonfX4o`0006Sooo]Z001joookJPCo
00006?oonfX5o`000?oooo]Z>_oonfX4o`0006Sooo]Z001ioookJPGo00006?oonfX5o`000?oooo]Z
>_oonfX5o`0006Oooo]Z001ioookJPGo00006?oonfX5o`000?oooo]Z>_oonfX5o`0006Oooo]Z001i
oookJPGo00006?oonfX5o`000?oooo]Z>_oonfX5o`0006Oooo]Z001ioookJPCo00006OoonfX5o`00
0?oooo]Z>ooonfX4o`0006Oooo]Z001ioookJPCo00006OoonfX5o`000?oooo]Z>ooonfX4o`0006Oo
oo]Z001ioookJPCo00006OoonfX5o`000?oooo]Z>ooonfX4o`0006Oooo]Z001ioookJPCo00006Ooo
nfX5o`000?oooo]Z>ooonfX4o`0006Oooo]Z001hoookJPGo00006OoonfX5o`000?oooo]Z>ooonfX4
o`0006Oooo]Z001hoookJPGo00006OoonfX6o`000?oooo]Z>_oonfX4o`0006Oooo]Z001hoookJPGo
00006OoonfX5o`000?oooo]Z>ooonfX4o`0006Oooo]Z001hoookJPCo00006_oonfX5o`000?oooo]Z
>ooonfX5o`0006Kooo]Z001hoookJPCo00006_oonfX5o`000?oooo]Z>ooonfX5o`0006Kooo]Z001h
oookJPCo00006_oonfX5o`000?oooo]Z>ooonfX5o`0006Kooo]Z001hoookJPCo00006_oonfX5o`00
0?oooo]Z??oonfX4o`0006Kooo]Z001goookJPGo00006_oonfX5o`000?oooo]Z??oonfX4o`0006Ko
oo]Z001goookJPGo00006_oonfX5o`000?oooo]Z??oonfX4o`0006Kooo]Z001goookJPGo00006_oo
nfX5o`000?oooo]Z??oonfX4o`0006Kooo]Z001goookJPCo00006ooonfX5o`000?oooo]Z??oonfX4
o`0006Kooo]Z001goookJPCo00006ooonfX5o`000?oooo]Z??oonfX4o`0006Kooo]Z001goookJPCo
00006ooonfX5o`000?oooo]Z??oonfX4o`0006Kooo]Z001goookJPCo00006ooonfX5o`000?oooo]Z
??oonfX5o`0006Gooo]Z001goookJPCo00006ooonfX5o`000?oooo]Z??oonfX5o`0006Gooo]Z001f
oookJPGo00006ooonfX5o`000?oooo]Z??oonfX5o`0006Gooo]Z001foookJPGo00006ooonfX5o`00
0?oooo]Z?OoonfX4o`0006Gooo]Z001foookJPGo00006ooonfX6o`000?oooo]Z??oonfX4o`0006Go
oo]Z001foookJPCo00007?oonfX5o`000?oooo]Z?OoonfX4o`0006Gooo]Z001foookJPCo00007?oo
nfX5o`000?oooo]Z?OoonfX4o`0006Gooo]Z001foookJPCo00007?oonfX5o`000?oooo]Z?OoonfX4
o`0006Gooo]Z001foookJPCo00007?oonfX5o`000?oooo]Z?OoonfX4o`0006Gooo]Z001foookJPCo
00007?oonfX5o`000?oooo]Z?OoonfX4o`0006Gooo]Z001foookJPCo00007?oonfX5o`000?oooo]Z
?OoonfX5o`0006Cooo]Z001eoookJPGo00007?oonfX5o`000?oooo]Z?OoonfX5o`0006Cooo]Z001e
oookJPGo00007?oonfX5o`000?oooo]Z?OoonfX5o`0006Cooo]Z001eoookJPGo00007?oonfX5o`00
0?oooo]Z?_oonfX4o`0006Cooo]Z001eoookJPCo00007OoonfX5o`000?oooo]Z?_oonfX4o`0006Co
oo]Z001eoookJPCo00007OoonfX5o`000?oooo]Z?_oonfX4o`0006Cooo]Z001eoookJPCo00007Ooo
nfX5o`000?oooo]Z?_oonfX4o`0006Cooo]Z001eoookJPCo00007OoonfX5o`000?oooo]Z?_oonfX4
o`0006Cooo]Z001eoookJPCo00007OoonfX5o`000?oooo]Z?_oonfX4o`0006Cooo]Z001eoookJPCo
00007OoonfX5o`000?oooo]Z?_oonfX4o`0006Cooo]Z001doookJPGo00007OoonfX6o`000?oooo]Z
?OoonfX5o`0006?ooo]Z001doookJPGo00007OoonfX5o`000?oooo]Z?_oonfX5o`0006?ooo]Z001d
oookJPGo00007OoonfX5o`000?oooo]Z?_oonfX5o`0006?ooo]Z001doookJPCo00007_oonfX5o`00
0?oooo]Z?ooonfX4o`0006?ooo]Z001doookJPCo00007_oonfX5o`000?oooo]Z?ooonfX4o`0006?o
oo]Z001doookJPCo00007_oonfX5o`000?oooo]Z?ooonfX4o`0006?ooo]Z002FoookJPGo0000oooo
nfZVoookJP00U_oonfX5o`000?oooo]ZY_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-5.68292, -15.6117, \
0.0371579, 0.125581}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Using Special Functions to visualize the eigensolutions for an \
electron bound to a fixed proton--The Hydrogen Atom\
\>", "Subtitle",
  CellTags->"mmtag:26:hydrogen_atom__visualizatio_of_orbitals"],

Cell["Eigenfunctions for Hydrogen:", "Text"],

Cell["\<\
Preliminary Definitions:
n will be the first quantum number n =1,2,3
L will be the second quantum number L=0,1,2,... (n-1)
m will be the third quantum number m = -L,-L+1,... 0,1,2, +L
These rules come from restrictions on the special functions that make up the \
eigenfunctions for the H-atom\
\>", "Text"],

Cell[BoxData[{
    \(Z = 1; \ a0\  = \ 1;\), "\[IndentingNewLine]", 
    \(\[Kappa][
        n_]\  := \ \(\[Kappa][
          n]\  = \ \ \(\(\ \)\(Z\)\)\/\(a0\ \ n\)\)\), "\[IndentingNewLine]", \

    \(\(\(\[Rho][n_, \ r_]\  := \ 2\ \[Kappa][n]\ r\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(A[n_\ , \ 
        L_]\  := \(A[n\ , \ 
          L] = \ \@\(Factorial[n - L\  - \ 1]\/\(2\ n \((Factorial[n\  + \ \
L])\)\^3\)\)\)\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Prefact[n_, 
        L_]\  := \ \(Prefact[n, 
          L]\  = \ \ \((2\ \[Kappa][n])\)\^\(3\/\(\(2\)\(\ \)\)\)\ A[n, 
            L]\)\), "\[IndentingNewLine]", 
    \(\(\(R[n_\ , \ L_, \ r_]\  := \ 
      Prefact[n, L]\ \[Rho][n, r]\ Exp[\(-\[Rho][n, r]\)\/2]\ LaguerreL[
          n - L - 1, 2\ L\  + \ 1, \[Rho][n, r]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
The eigenfunctions for the Hydrogen Atom can now be written down.  \
The eigenfunctions will relate to the above definitions and involve the \
Spherical Harmonics which are related to Legendre functions and its \
derivatives.\
\>", "Text"],

Cell[BoxData[
    \(HAtom[n_\ , \ L_\ , \ m_\ , {r_\ , \ \[Theta]_, \ \[Phi]_}]\  := \ 
      R[n, L, r]\ SphericalHarmonicY[L, m, \[Theta], \[Phi]]\)], "Input",
  CellTags->"mmtag:26:SphericalHarmonicYJ[]"],

Cell[BoxData[
    \(<< Calculus`VectorAnalysis`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoordinatesFromCartesian[{x, y, z}, Spherical]\)], "Input"],

Cell[BoxData[
    \({\@\(x\^2 + y\^2 + z\^2\), ArcCos[z\/\@\(x\^2 + y\^2 + z\^2\)], 
      ArcTan[x, y]}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(SphericalCoords[x_, \ y_, \ z_]\  := \ 
      Module[{rsq = \ x^2\  + \ y^2\  + \ z^2, r, phi = ArcTan[x, y]}, 
        r = Sqrt[rsq]; Return[{r, ArcCos[z/r], phi}]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2,1,1 corresponds to a 2p spin up electron", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(HAtom[2, 1, 1, SphericalCoords[1, 2, 1]]\)], "Input"],

Cell[BoxData[
    \(\(-\(1\/48\)\)\ \[ExponentialE]\^\(\(-\@\(3\/2\)\) + \[ImaginaryI]\ \
ArcTan[2]\)\ \@\(5\/\[Pi]\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[HAtom[2, 1, 1, SphericalCoords[1, 2, 1]]]\)], "Input"],

Cell[BoxData[
    \(\(-0.0034536942448454423`\) - 
      0.006907388489690884`\ \[ImaginaryI]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(<< Graphics`ContourPlot3D`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Abs[
      HAtom[2, 1, 1, 
        CoordinatesFromCartesian[{0, 1,  .5}, Spherical]]]\)], "Input"],

Cell[BoxData[
    \(0.006720565688138128`\)], "Output"]
}, Open  ]],

Cell["\<\
Plot a surface of constant probability density. Only an octant can \
be plotted, the numerical methods do not behave well on the coordinate \"zero \
value\" planes.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(p1 = 
      ContourPlot3D[
        Abs[HAtom[2, 1, 1, SphericalCoords[x, y, z]]], {x, \(-5\), 5}, {y, 
          0.001, 5}, {z, 0.002, 5}, MaxRecursion\  -> 2, 
        Contours\  -> \ {0.006, \ 0.007, \ 0.008}]\)], "Input",
  CellTags->"mmtag:26:ContourPlot3D[]__example_of_hydrogen_orbitals"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .64373 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00446416 1.00446 -0.151752 1.00446 [
[ 0 0 0 0 ]
[ 1 .64373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01968 .27973 m
0 .44347 L
s
0 .44347 m
.23963 .64373 L
s
.23963 .64373 m
.24889 .488 L
s
.24889 .488 m
.01968 .27973 L
s
.80629 0 m
.97998 .2604 L
s
.97998 .2604 m
1 .4248 L
s
1 .4248 m
.82064 .17208 L
s
.82064 .17208 m
.80629 0 L
s
.01968 .27973 m
0 .44347 L
s
0 .44347 m
.82064 .17208 L
s
.82064 .17208 m
.80629 0 L
s
.80629 0 m
.01968 .27973 L
s
.24889 .488 m
.97998 .2604 L
s
.97998 .2604 m
1 .4248 L
s
1 .4248 m
.23963 .64373 L
s
.23963 .64373 m
.24889 .488 L
s
0 0 m
1 0 L
1 .64373 L
0 .64373 L
closepath
clip
newpath
.5 Mabswid
.69 .443 .545 r
.41245 .40608 m .42022 .40604 L .41972 .41742 L p F P
0 g
s
.69 .443 .545 r
.41972 .41742 m .41315 .41746 L .41245 .40608 L p F P
0 g
s
.694 .447 .545 r
.38772 .40594 m .41245 .40608 L .41315 .41746 L p F P
0 g
s
.673 .43 .544 r
.42022 .40604 m .44606 .40491 L .44703 .41624 L p F P
0 g
s
.673 .43 .544 r
.44703 .41624 m .41972 .41742 L .42022 .40604 L p F P
0 g
s
.694 .447 .545 r
.41315 .41746 m .38711 .41731 L .38772 .40594 L p F P
0 g
s
.708 .459 .545 r
.38351 .40577 m .38772 .40594 L .38711 .41731 L p F P
0 g
s
.708 .459 .545 r
.38711 .41731 m .384 .41719 L .38351 .40577 L p F P
0 g
s
.713 .463 .545 r
.35785 .40442 m .38351 .40577 L .384 .41719 L p F P
0 g
s
.67 .427 .544 r
.44606 .40491 m .45129 .40465 L .45089 .41605 L p F P
0 g
s
.67 .427 .544 r
.45089 .41605 m .44703 .41624 L .44606 .40491 L p F P
0 g
s
.653 .413 .543 r
.45089 .41605 m .45129 .40465 L .48113 .40192 L p F P
0 g
s
.719 .467 .545 r
.35349 .40413 m .35785 .40442 L .35823 .41585 L p F P
0 g
s
.713 .463 .545 r
.384 .41719 m .35823 .41585 L .35785 .40442 L p F P
0 g
s
.719 .467 .545 r
.35823 .41585 m .35275 .41549 L .35349 .40413 L p F P
0 g
s
.731 .478 .546 r
.33456 .40229 m .35349 .40413 L .35275 .41549 L p F P
0 g
s
.731 .478 .546 r
.35275 .41549 m .33479 .41376 L .33456 .40229 L p F P
0 g
s
.738 .484 .545 r
.3171 .40025 m .33456 .40229 L .33479 .41376 L p F P
0 g
s
.633 .397 .542 r
.48113 .40192 m .48893 .40086 L .49065 .41201 L p F P
0 g
s
.633 .397 .542 r
.49065 .41201 m .48083 .41333 L .48113 .40192 L p F P
0 g
s
.653 .413 .543 r
.48113 .40192 m .48083 .41333 L .45089 .41605 L p F P
0 g
s
.632 .396 .542 r
.48893 .40086 m .5099 .39795 L .50969 .40938 L p F P
0 g
s
.632 .396 .542 r
.50969 .40938 m .49065 .41201 L .48893 .40086 L p F P
0 g
s
.738 .484 .545 r
.33479 .41376 m .31622 .4116 L .3171 .40025 L p F P
0 g
s
.748 .492 .545 r
.31282 .39965 m .3171 .40025 L .31622 .4116 L p F P
0 g
s
.685 .422 .52 r
.41315 .41746 m .41972 .41742 L .41865 .42831 L p F P
0 g
s
.685 .422 .52 r
.41865 .42831 m .41571 .42833 L .41315 .41746 L p F P
0 g
s
.689 .426 .52 r
.38711 .41731 m .41315 .41746 L .41571 .42833 L p F P
0 g
s
.668 .407 .517 r
.41865 .42831 m .41972 .41742 L .44703 .41624 L p F P
0 g
s
.748 .492 .545 r
.31622 .4116 m .31294 .41114 L .31282 .39965 L p F P
0 g
s
.754 .498 .545 r
.29271 .39645 m .31282 .39965 L .31294 .41114 L p F P
0 g
s
.689 .426 .52 r
.38597 .42745 m .38711 .41731 L p .41571 .42833 L F P
0 g
s
.704 .439 .52 r
.38597 .42745 m .384 .41719 L .38711 .41731 L closepath p F P
0 g
s
.709 .443 .52 r
.384 .41719 m .38597 .42745 L .38589 .42816 L p F P
0 g
s
.709 .443 .52 r
.35823 .41585 m .384 .41719 L p .38589 .42816 L F P
0 g
s
.665 .405 .519 r
.45001 .42627 m .44703 .41624 L .45089 .41605 L closepath p F P
0 g
s
.668 .407 .517 r
.44703 .41624 m .45001 .42627 L p .41865 .42831 L F P
0 g
s
.647 .39 .517 r
.45089 .41605 m .48083 .41333 L .48001 .42428 L p F P
0 g
s
.647 .39 .517 r
.45001 .42627 m .45089 .41605 L p .48001 .42428 L F P
0 g
s
.715 .447 .519 r
.35275 .41549 m .35823 .41585 L .36018 .42686 L p F P
0 g
s
.709 .443 .52 r
.38589 .42816 m .36018 .42686 L .35823 .41585 L p F P
0 g
s
.611 .379 .54 r
.50969 .40938 m .5099 .39795 L .53771 .39279 L p F P
0 g
s
.715 .447 .519 r
.36018 .42686 m .35136 .42628 L .35275 .41549 L p F P
0 g
s
.728 .459 .52 r
.33479 .41376 m .35275 .41549 L .35136 .42628 L p F P
0 g
s
.754 .498 .545 r
.31294 .41114 m .29274 .40796 L .29271 .39645 L p F P
0 g
s
.763 .505 .544 r
.27785 .39374 m .29271 .39645 L .29274 .40796 L p F P
0 g
s
.728 .459 .52 r
.35136 .42628 m .33642 .42485 L .33479 .41376 L p F P
0 g
s
.735 .464 .518 r
.31622 .4116 m .33479 .41376 L .33642 .42485 L p F P
0 g
s
.626 .373 .515 r
.48083 .41333 m .49065 .41201 L .49582 .42216 L p F P
0 g
s
.626 .373 .515 r
.49582 .42216 m .48001 .42428 L .48083 .41333 L p F P
0 g
s
.624 .372 .515 r
.49065 .41201 m .50969 .40938 L .50897 .42035 L p F P
0 g
s
.624 .372 .515 r
.50897 .42035 m .49582 .42216 L .49065 .41201 L p F P
0 g
s
.735 .464 .518 r
.33642 .42485 m .31464 .42233 L .31622 .4116 L p F P
0 g
s
.745 .474 .52 r
.31294 .41114 m .31622 .4116 L .31464 .42233 L p F P
0 g
s
.763 .505 .544 r
.29274 .40796 m .27681 .40507 L .27785 .39374 L p F P
0 g
s
.77 .512 .545 r
.27363 .39289 m .27785 .39374 L .27681 .40507 L p F P
0 g
s
.745 .474 .52 r
.31464 .42233 m .31433 .42229 L .31294 .41114 L p F P
0 g
s
.751 .479 .519 r
.29274 .40796 m .31294 .41114 L .31433 .42229 L p F P
0 g
s
.689 .426 .52 r
.41571 .42833 m .38613 .42817 L .38597 .42745 L p F P
0 g
s
.694 .429 .518 r
.38613 .42817 m .38589 .42816 L .38597 .42745 L closepath p F P
0 g
s
.77 .512 .545 r
.27681 .40507 m .27357 .40442 L .27363 .39289 L p F P
0 g
s
.776 .517 .544 r
.25571 .38892 m .27363 .39289 L .27357 .40442 L p F P
0 g
s
.679 .399 .491 r
.41786 .43331 m .41571 .42833 L .41865 .42831 L closepath p F P
0 g
s
.683 .403 .491 r
.41571 .42833 m .41786 .43331 L .41699 .43869 L p F P
0 g
s
.683 .403 .491 r
.38613 .42817 m .41571 .42833 L p .41699 .43869 L F P
0 g
s
.589 .361 .538 r
.53758 .40424 m .53771 .39279 L .56464 .38649 L p F P
0 g
s
.611 .379 .54 r
.53771 .39279 m .53758 .40424 L .50969 .40938 L p F P
0 g
s
.661 .384 .489 r
.41865 .42831 m .44995 .42697 L .44845 .4374 L p F P
0 g
s
.661 .384 .489 r
.41786 .43331 m .41865 .42831 L p .44845 .4374 L F P
0 g
s
.668 .407 .517 r
.45001 .42627 m .44995 .42697 L .41865 .42831 L p F P
0 g
s
.683 .403 .491 r
.41699 .43869 m .39035 .43856 L .38613 .42817 L p F P
0 g
s
.688 .405 .488 r
.38589 .42816 m .38613 .42817 L .39035 .43856 L p F P
0 g
s
.688 .405 .488 r
.39035 .43856 m .38404 .43846 L .38589 .42816 L p F P
0 g
s
.704 .42 .491 r
.36018 .42686 m .38589 .42816 L .38404 .43846 L p F P
0 g
s
.647 .39 .517 r
.48001 .42428 m .45025 .42694 L .45001 .42627 L p F P
0 g
s
.649 .392 .516 r
.45025 .42694 m .44995 .42697 L .45001 .42627 L closepath p F P
0 g
s
.602 .353 .512 r
.50897 .42035 m .50969 .40938 L .53758 .40424 L p F P
0 g
s
.641 .365 .486 r
.44995 .42697 m .45025 .42694 L .45679 .4367 L p F P
0 g
s
.641 .365 .486 r
.45679 .4367 m .44845 .4374 L .44995 .42697 L p F P
0 g
s
.639 .365 .488 r
.45025 .42694 m .48001 .42428 L .47865 .43475 L p F P
0 g
s
.639 .365 .488 r
.47865 .43475 m .45679 .4367 L .45025 .42694 L p F P
0 g
s
.71 .423 .488 r
.35136 .42628 m .36018 .42686 L .36374 .43744 L p F P
0 g
s
.704 .42 .491 r
.38404 .43846 m .36374 .43744 L .36018 .42686 L p F P
0 g
s
.71 .423 .488 r
.36374 .43744 m .34929 .43649 L .35136 .42628 L p F P
0 g
s
.724 .436 .491 r
.33642 .42485 m .35136 .42628 L .34929 .43649 L p F P
0 g
s
.751 .479 .519 r
.31433 .42229 m .29401 .41913 L .29274 .40796 L p F P
0 g
s
.761 .486 .517 r
.27681 .40507 m .29274 .40796 L .29401 .41913 L p F P
0 g
s
.724 .436 .491 r
.34929 .43649 m .3395 .43556 L .33642 .42485 L p F P
0 g
s
.731 .442 .49 r
.31464 .42233 m .33642 .42485 L .3395 .43556 L p F P
0 g
s
.665 .385 .487 r
.42055 .43857 m .41699 .43869 L .41786 .43331 L closepath p F P
0 g
s
.661 .384 .489 r
.44845 .4374 m .42055 .43857 L .41786 .43331 L p F P
0 g
s
.776 .517 .544 r
.27357 .40442 m .25559 .40046 L .25571 .38892 L p F P
0 g
s
.786 .526 .544 r
.23859 .38466 m .25571 .38892 L .25559 .40046 L p F P
0 g
s
.616 .345 .483 r
.48001 .42428 m .49582 .42216 L .5046 .43128 L p F P
0 g
s
.616 .345 .483 r
.5046 .43128 m .47865 .43475 L .48001 .42428 L p F P
0 g
s
.761 .486 .517 r
.29401 .41913 m .27498 .4157 L .27681 .40507 L p F P
0 g
s
.768 .493 .518 r
.27357 .40442 m .27681 .40507 L .27498 .4157 L p F P
0 g
s
.731 .442 .49 r
.31449 .42297 m .31464 .42233 L p .3395 .43556 L F P
0 g
s
.742 .453 .491 r
.31449 .42297 m .31433 .42229 L .31464 .42233 L closepath p F P
0 g
s
.748 .457 .49 r
.31433 .42229 m .31449 .42297 L .31228 .4324 L p F P
0 g
s
.748 .457 .49 r
.29401 .41913 m .31433 .42229 L p .31228 .4324 L F P
0 g
s
.768 .493 .518 r
.27498 .4157 m .27467 .41564 L .27357 .40442 L p F P
0 g
s
.775 .499 .518 r
.25559 .40046 m .27357 .40442 L .27467 .41564 L p F P
0 g
s
.615 .345 .485 r
.49582 .42216 m .50897 .42035 L .50774 .43085 L p F P
0 g
s
.615 .345 .485 r
.50774 .43085 m .5046 .43128 L .49582 .42216 L p F P
0 g
s
.566 .343 .536 r
.56464 .38649 m .56883 .38529 L .58153 .39315 L p F P
0 g
s
.566 .343 .536 r
.58153 .39315 m .56459 .39795 L .56464 .38649 L p F P
0 g
s
.589 .361 .538 r
.56464 .38649 m .56459 .39795 L .53758 .40424 L p F P
0 g
s
.579 .334 .51 r
.53697 .41524 m .53758 .40424 L .56459 .39795 L p F P
0 g
s
.602 .353 .512 r
.53758 .40424 m .53697 .41524 L .50897 .42035 L p F P
0 g
s
.731 .442 .49 r
.3395 .43556 m .31721 .43304 L .31449 .42297 L p F P
0 g
s
.737 .446 .488 r
.31721 .43304 m .31228 .4324 L .31449 .42297 L closepath p F P
0 g
s
.566 .343 .536 r
.56883 .38529 m .59075 .37905 L .59078 .39053 L p F P
0 g
s
.566 .343 .536 r
.59078 .39053 m .58153 .39315 L .56883 .38529 L p F P
0 g
s
.656 .356 .452 r
.41699 .43869 m .42055 .43857 L .42805 .44807 L p F P
0 g
s
.656 .356 .452 r
.42805 .44807 m .4147 .44851 L .41699 .43869 L p F P
0 g
s
.675 .375 .457 r
.39035 .43856 m .41699 .43869 L .4147 .44851 L p F P
0 g
s
.652 .355 .455 r
.42055 .43857 m .44845 .4374 L .44636 .4473 L p F P
0 g
s
.652 .355 .455 r
.44636 .4473 m .42805 .44807 L .42055 .43857 L p F P
0 g
s
.675 .375 .457 r
.4147 .44851 m .39656 .44843 L .39035 .43856 L p F P
0 g
s
.68 .376 .453 r
.38404 .43846 m .39035 .43856 L .39656 .44843 L p F P
0 g
s
.68 .376 .453 r
.39656 .44843 m .38152 .44819 L .38404 .43846 L p F P
0 g
s
.697 .393 .457 r
.36374 .43744 m .38404 .43846 L .38152 .44819 L p F P
0 g
s
.591 .324 .48 r
.50774 .43085 m .50897 .42035 L .53697 .41524 L p F P
0 g
s
.786 .526 .544 r
.25559 .40046 m .23839 .39621 L .23859 .38466 L p F P
0 g
s
.793 .532 .543 r
.23452 .38356 m .23859 .38466 L .23839 .39621 L p F P
0 g
s
.697 .393 .457 r
.38152 .44819 m .36903 .44756 L .36374 .43744 L p F P
0 g
s
.703 .395 .453 r
.34929 .43649 m .36374 .43744 L .36903 .44756 L p F P
0 g
s
.63 .334 .45 r
.44845 .4374 m .45679 .4367 L .46624 .44565 L p F P
0 g
s
.63 .334 .45 r
.46624 .44565 m .44636 .4473 L .44845 .4374 L p F P
0 g
s
.793 .532 .543 r
.23839 .39621 m .23328 .39484 L .23452 .38356 L p F P
0 g
s
.798 .537 .543 r
.2223 .38008 m .23452 .38356 L .23328 .39484 L p F P
0 g
s
.748 .457 .49 r
.31228 .4324 m .29657 .42998 L .29401 .41913 L p F P
0 g
s
.757 .464 .488 r
.27498 .4157 m .29401 .41913 L .29657 .42998 L p F P
0 g
s
.628 .335 .453 r
.45679 .4367 m .47865 .43475 L .47672 .44472 L p F P
0 g
s
.628 .335 .453 r
.47672 .44472 m .46624 .44565 L .45679 .4367 L p F P
0 g
s
.703 .395 .453 r
.36903 .44756 m .3465 .44609 L .34929 .43649 L p F P
0 g
s
.718 .41 .457 r
.3395 .43556 m .34929 .43649 L .3465 .44609 L p F P
0 g
s
.775 .499 .518 r
.27467 .41564 m .25658 .41171 L .25559 .40046 L p F P
0 g
s
.785 .507 .517 r
.23839 .39621 m .25559 .40046 L .25658 .41171 L p F P
0 g
s
.718 .41 .457 r
.3465 .44609 m .34412 .44586 L .3395 .43556 L p F P
0 g
s
.724 .416 .457 r
.31721 .43304 m .3395 .43556 L .34412 .44586 L p F P
0 g
s
.604 .312 .446 r
.47672 .44472 m .47865 .43475 L .5046 .43128 L p F P
0 g
s
.554 .314 .506 r
.56407 .40897 m .56459 .39795 L .58153 .39315 L p F P
0 g
s
.579 .334 .51 r
.56459 .39795 m .56407 .40897 L .53697 .41524 L p F P
0 g
s
.798 .537 .543 r
.23328 .39484 m .22204 .39165 L .2223 .38008 L p F P
0 g
s
.807 .544 .542 r
.20673 .37521 m .2223 .38008 L .22204 .39165 L p F P
0 g
s
.757 .464 .488 r
.27481 .41632 m .27498 .4157 L p .29657 .42998 L F P
0 g
s
.766 .473 .489 r
.27481 .41632 m .27467 .41564 L .27498 .4157 L closepath p F P
0 g
s
.772 .478 .487 r
.27467 .41564 m .27481 .41632 L .27225 .42558 L p F P
0 g
s
.772 .478 .487 r
.25658 .41171 m .27467 .41564 L p .27225 .42558 L F P
0 g
s
.566 .303 .477 r
.53585 .42577 m .53697 .41524 L .56407 .40897 L p F P
0 g
s
.591 .324 .48 r
.53697 .41524 m .53585 .42577 L .50774 .43085 L p F P
0 g
s
.757 .464 .488 r
.29657 .42998 m .27706 .42652 L .27481 .41632 L p F P
0 g
s
.764 .469 .485 r
.27706 .42652 m .27225 .42558 L .27481 .41632 L closepath p F P
0 g
s
.724 .416 .457 r
.34412 .44586 m .32159 .4434 L .31721 .43304 L p F P
0 g
s
.732 .419 .451 r
.31228 .4324 m .31721 .43304 L .32159 .4434 L p F P
0 g
s
.541 .323 .533 r
.61199 .37184 m .59075 .37905 L .59078 .39053 L p F P
0 g
s
.732 .419 .451 r
.32159 .4434 m .30912 .44179 L .31228 .4324 L p F P
0 g
s
.743 .432 .455 r
.29657 .42998 m .31228 .4324 L .30912 .44179 L p F P
0 g
s
.785 .507 .517 r
.25658 .41171 m .23929 .40748 L .23839 .39621 L p F P
0 g
s
.793 .514 .514 r
.23328 .39484 m .23839 .39621 L .23929 .40748 L p F P
0 g
s
.604 .314 .451 r
.50735 .43308 m .5046 .43128 L .50774 .43085 L closepath p F P
0 g
s
.604 .312 .446 r
.5046 .43128 m .50735 .43308 L p .47672 .44472 L F P
0 g
s
.579 .291 .444 r
.50774 .43085 m .53585 .42577 L .5342 .43581 L p F P
0 g
s
.579 .291 .444 r
.50735 .43308 m .50774 .43085 L p .5342 .43581 L F P
0 g
s
.793 .514 .514 r
.23929 .40748 m .23106 .40528 L .23328 .39484 L p F P
0 g
s
.798 .519 .515 r
.22204 .39165 m .23328 .39484 L .23106 .40528 L p F P
0 g
s
.643 .319 .408 r
.4147 .44851 m .42805 .44807 L .43812 .45687 L p F P
0 g
s
.643 .319 .408 r
.43812 .45687 m .41172 .45775 L .4147 .44851 L p F P
0 g
s
.665 .341 .416 r
.39656 .44843 m .4147 .44851 L .41172 .45775 L p F P
0 g
s
.665 .341 .416 r
.41172 .45775 m .40492 .45772 L .39656 .44843 L p F P
0 g
s
.669 .341 .409 r
.38152 .44819 m .39656 .44843 L .40492 .45772 L p F P
0 g
s
.669 .341 .409 r
.40492 .45772 m .37827 .4573 L .38152 .44819 L p F P
0 g
s
.688 .361 .416 r
.36903 .44756 m .38152 .44819 L .37827 .4573 L p F P
0 g
s
.64 .32 .414 r
.42805 .44807 m .44636 .4473 L .44361 .45665 L p F P
0 g
s
.64 .32 .414 r
.44361 .45665 m .43812 .45687 L .42805 .44807 L p F P
0 g
s
.743 .432 .455 r
.30912 .44179 m .30048 .44047 L .29657 .42998 L p F P
0 g
s
.752 .438 .454 r
.27706 .42652 m .29657 .42998 L .30048 .44047 L p F P
0 g
s
.688 .361 .416 r
.37827 .4573 m .37618 .45719 L .36903 .44756 L p F P
0 g
s
.694 .365 .415 r
.3465 .44609 m .36903 .44756 L .37618 .45719 L p F P
0 g
s
.772 .478 .487 r
.27225 .42558 m .25874 .42265 L .25658 .41171 L p F P
0 g
s
.782 .485 .486 r
.23929 .40748 m .25658 .41171 L .25874 .42265 L p F P
0 g
s
.616 .296 .405 r
.44361 .45665 m .44636 .4473 L .46624 .44565 L p F P
0 g
s
.579 .291 .444 r
.5342 .43581 m .52093 .4382 L .50735 .43308 L p F P
0 g
s
.579 .29 .442 r
.52093 .4382 m .50596 .44086 L .50735 .43308 L closepath p F P
0 g
s
.604 .312 .446 r
.50735 .43308 m .50596 .44086 L .47672 .44472 L p F P
0 g
s
.554 .314 .507 r
.59068 .39323 m .58153 .39315 L .59078 .39053 L closepath p F P
0 g
s
.554 .314 .506 r
.58153 .39315 m .59068 .39323 L p .56407 .40897 L F P
0 g
s
.807 .544 .542 r
.22204 .39165 m .20641 .3868 L .20673 .37521 L p F P
0 g
s
.816 .553 .541 r
.19179 .3701 m .20673 .37521 L .20641 .3868 L p F P
0 g
s
.694 .365 .415 r
.34563 .4483 m .3465 .44609 L p .37618 .45719 L F P
0 g
s
.71 .381 .419 r
.34563 .4483 m .34412 .44586 L .3465 .44609 L closepath p F P
0 g
s
.716 .384 .415 r
.34412 .44586 m .34563 .4483 L .34288 .45499 L p F P
0 g
s
.716 .384 .415 r
.32159 .4434 m .34412 .44586 L p .34288 .45499 L F P
0 g
s
.615 .299 .412 r
.47497 .4513 m .46624 .44565 L .47672 .44472 L closepath p F P
0 g
s
.616 .296 .405 r
.46624 .44565 m .47497 .4513 L p .44361 .45665 L F P
0 g
s
.798 .519 .515 r
.23106 .40528 m .22281 .40295 L .22204 .39165 L p F P
0 g
s
.806 .526 .514 r
.20641 .3868 m .22204 .39165 L .22281 .40295 L p F P
0 g
s
.539 .281 .472 r
.56306 .41952 m .56407 .40897 L .59035 .40156 L p F P
0 g
s
.554 .314 .506 r
.59068 .39323 m .59035 .40156 L .56407 .40897 L p F P
0 g
s
.566 .303 .477 r
.56407 .40897 m .56306 .41952 L .53585 .42577 L p F P
0 g
s
.589 .274 .402 r
.47672 .44472 m .50596 .44086 L .50358 .45034 L p F P
0 g
s
.589 .274 .402 r
.47497 .4513 m .47672 .44472 L p .50358 .45034 L F P
0 g
s
.752 .438 .454 r
.30048 .44047 m .28079 .43706 L .27706 .42652 L p F P
0 g
s
.76 .442 .448 r
.27225 .42558 m .27706 .42652 L .28079 .43706 L p F P
0 g
s
.527 .292 .502 r
.59068 .39323 m .59972 .38751 L .59078 .39053 L closepath p F P
0 g
s
.541 .323 .533 r
.59078 .39053 m .59972 .38751 L .61199 .37184 L p F P
0 g
s
.689 .436 .536 r
.39787 .37229 m .42012 .37223 L .41949 .38358 L p F P
0 g
s
.689 .436 .536 r
.41949 .38358 m .3989 .38363 L .39787 .37229 L p F P
0 g
s
.694 .44 .535 r
.38714 .37218 m .39787 .37229 L .3989 .38363 L p F P
0 g
s
.669 .419 .534 r
.42012 .37223 m .42992 .37175 L .43135 .383 L p F P
0 g
s
.669 .419 .534 r
.43135 .383 m .41949 .38358 L .42012 .37223 L p F P
0 g
s
.694 .44 .535 r
.3989 .38363 m .38639 .3835 L .38714 .37218 L p F P
0 g
s
.712 .456 .536 r
.37053 .3713 m .38714 .37218 L .38639 .3835 L p F P
0 g
s
.694 .365 .415 r
.37618 .45719 m .35082 .45561 L .34563 .4483 L p F P
0 g
s
.7 .365 .407 r
.35082 .45561 m .34288 .45499 L .34563 .4483 L closepath p F P
0 g
s
.551 .267 .438 r
.5342 .43581 m .53585 .42577 L .56306 .41952 L p F P
0 g
s
.541 .323 .533 r
.61609 .37045 m .61199 .37184 L .59972 .38751 L p F P
0 g
s
.76 .442 .448 r
.28079 .43706 m .26859 .43468 L .27225 .42558 L p F P
0 g
s
.769 .453 .451 r
.25874 .42265 m .27225 .42558 L .26859 .43468 L p F P
0 g
s
.665 .417 .535 r
.42992 .37175 m .4514 .3705 L .45088 .38187 L p F P
0 g
s
.665 .417 .535 r
.45088 .38187 m .43135 .383 L .42992 .37175 L p F P
0 g
s
.716 .384 .415 r
.34288 .45499 m .3276 .45334 L .32159 .4434 L p F P
0 g
s
.723 .386 .408 r
.30912 .44179 m .32159 .4434 L .3276 .45334 L p F P
0 g
s
.782 .485 .486 r
.25874 .42265 m .24132 .41846 L .23929 .40748 L p F P
0 g
s
.791 .492 .482 r
.23106 .40528 m .23929 .40748 L .24132 .41846 L p F P
0 g
s
.712 .456 .536 r
.38639 .3835 m .37128 .38271 L .37053 .3713 L p F P
0 g
s
.718 .461 .535 r
.35209 .37003 m .37053 .3713 L .37128 .38271 L p F P
0 g
s
.527 .292 .502 r
.59035 .40156 m .59068 .39323 L .59972 .38751 L p F P
0 g
s
.643 .398 .533 r
.4514 .3705 m .47088 .36838 L .47292 .37949 L p F P
0 g
s
.643 .398 .533 r
.47292 .37949 m .45088 .38187 L .4514 .3705 L p F P
0 g
s
.514 .302 .53 r
.6162 .38195 m .61609 .37045 L .64067 .36066 L p F P
0 g
s
.541 .323 .533 r
.59972 .38751 m .6162 .38195 L .61609 .37045 L p F P
0 g
s
.816 .553 .541 r
.20641 .3868 m .19141 .3817 L .19179 .3701 L p F P
0 g
s
.825 .561 .54 r
.18451 .36741 m .19179 .3701 L .19141 .3817 L p F P
0 g
s
.718 .461 .535 r
.37128 .38271 m .3512 .38134 L .35209 .37003 L p F P
0 g
s
.733 .474 .536 r
.34605 .36939 m .35209 .37003 L .3512 .38134 L p F P
0 g
s
.723 .386 .408 r
.30541 .44975 m .30912 .44179 L p .3276 .45334 L F P
0 g
s
.736 .401 .413 r
.30541 .44975 m .30048 .44047 L .30912 .44179 L closepath p F P
0 g
s
.527 .292 .502 r
.59972 .38751 m .6162 .38195 L p .59035 .40156 L F P
0 g
s
.733 .474 .536 r
.3512 .38134 m .34658 .38085 L .34605 .36939 L p F P
0 g
s
.74 .48 .536 r
.32405 .36664 m .34605 .36939 L .34658 .38085 L p F P
0 g
s
.791 .492 .482 r
.24132 .41846 m .22784 .41487 L .23106 .40528 L p F P
0 g
s
.796 .498 .483 r
.22281 .40295 m .23106 .40528 L .22784 .41487 L p F P
0 g
s
.561 .249 .396 r
.50358 .45034 m .50596 .44086 L .52093 .4382 L p F P
0 g
s
.806 .526 .514 r
.22281 .40295 m .2071 .39813 L .20641 .3868 L p F P
0 g
s
.816 .535 .512 r
.19141 .3817 m .20641 .3868 L .2071 .39813 L p F P
0 g
s
.769 .453 .451 r
.26859 .43468 m .26213 .43328 L .25874 .42265 L p F P
0 g
s
.777 .459 .449 r
.24132 .41846 m .25874 .42265 L .26213 .43328 L p F P
0 g
s
.743 .406 .412 r
.30048 .44047 m .30541 .44975 L .30507 .45045 L p F P
0 g
s
.743 .406 .412 r
.28079 .43706 m .30048 .44047 L p .30507 .45045 L F P
0 g
s
.64 .396 .533 r
.47088 .36838 m .48126 .36719 L .48085 .37858 L p F P
0 g
s
.64 .396 .533 r
.48085 .37858 m .47292 .37949 L .47088 .36838 L p F P
0 g
s
.628 .277 .357 r
.41172 .45775 m .43812 .45687 L p .44013 .46535 L F P
0 g
s
.628 .277 .357 r
.40997 .46189 m .41172 .45775 L p .44013 .46535 L F P
0 g
s
.652 .303 .369 r
.40997 .46189 m .40492 .45772 L .41172 .45775 L closepath p F P
0 g
s
.655 .303 .363 r
.40492 .45772 m .40997 .46189 L .40797 .46632 L p F P
0 g
s
.655 .303 .363 r
.37827 .4573 m .40492 .45772 L p .40797 .46632 L F P
0 g
s
.655 .303 .363 r
.37763 .45867 m .37827 .4573 L p .40797 .46632 L F P
0 g
s
.677 .326 .372 r
.37763 .45867 m .37618 .45719 L .37827 .4573 L closepath p F P
0 g
s
.825 .561 .54 r
.19141 .3817 m .18298 .37861 L .18451 .36741 L p F P
0 g
s
.827 .563 .54 r
.17744 .36474 m .18451 .36741 L .18298 .37861 L p F P
0 g
s
.681 .325 .365 r
.37618 .45719 m .37763 .45867 L .37416 .46567 L p F P
0 g
s
.681 .325 .365 r
.35082 .45561 m .37618 .45719 L p .37416 .46567 L F P
0 g
s
.616 .376 .531 r
.48085 .37858 m .48126 .36719 L .50988 .3624 L p F P
0 g
s
.796 .498 .483 r
.22784 .41487 m .22466 .41398 L .22281 .40295 L p F P
0 g
s
.804 .504 .482 r
.2071 .39813 m .22281 .40295 L .22466 .41398 L p F P
0 g
s
.626 .282 .367 r
.44245 .45967 m .43812 .45687 L .44361 .45665 L closepath p F P
0 g
s
.628 .277 .357 r
.43812 .45687 m .44245 .45967 L .44013 .46535 L p F P
0 g
s
.589 .274 .402 r
.50358 .45034 m .47987 .45342 L .47497 .4513 L p F P
0 g
s
.59 .272 .398 r
.47987 .45342 m .47418 .45414 L .47497 .4513 L closepath p F P
0 g
s
.616 .296 .405 r
.47497 .4513 m .47418 .45414 L .44361 .45665 L p F P
0 g
s
.599 .253 .354 r
.44361 .45665 m .47418 .45414 L .47093 .46294 L p F P
0 g
s
.599 .253 .354 r
.44245 .45967 m .44361 .45665 L p .47093 .46294 L F P
0 g
s
.74 .48 .536 r
.34658 .38085 m .3245 .37811 L .32405 .36664 L p F P
0 g
s
.748 .486 .535 r
.3143 .36523 m .32405 .36664 L .3245 .37811 L p F P
0 g
s
.562 .253 .402 r
.53303 .44086 m .52093 .4382 L .5342 .43581 L closepath p F P
0 g
s
.561 .249 .396 r
.52093 .4382 m .53303 .44086 L p .50358 .45034 L F P
0 g
s
.655 .303 .363 r
.40797 .46632 m .38631 .466 L .37763 .45867 L p F P
0 g
s
.659 .3 .353 r
.38631 .466 m .37416 .46567 L .37763 .45867 L closepath p F P
0 g
s
.681 .325 .365 r
.37416 .46567 m .35967 .46478 L .35082 .45561 L p F P
0 g
s
.686 .323 .354 r
.34288 .45499 m .35082 .45561 L .35967 .46478 L p F P
0 g
s
.681 .405 .497 r
.3989 .38363 m .41949 .38358 L .41805 .39417 L p F P
0 g
s
.681 .405 .497 r
.41805 .39417 m .40256 .39421 L .3989 .38363 L p F P
0 g
s
.686 .408 .495 r
.38639 .3835 m .3989 .38363 L .40256 .39421 L p F P
0 g
s
.659 .385 .493 r
.41949 .38358 m .43135 .383 L .43601 .39331 L p F P
0 g
s
.659 .385 .493 r
.43601 .39331 m .41805 .39417 L .41949 .38358 L p F P
0 g
s
.51 .257 .467 r
.58943 .41213 m .59035 .40156 L .61584 .393 L p F P
0 g
s
.527 .292 .502 r
.6162 .38195 m .61584 .393 L .59035 .40156 L p F P
0 g
s
.539 .281 .472 r
.59035 .40156 m .58943 .41213 L .56306 .41952 L p F P
0 g
s
.521 .242 .431 r
.56152 .42959 m .56306 .41952 L .58943 .41213 L p F P
0 g
s
.551 .267 .438 r
.56306 .41952 m .56152 .42959 L .5342 .43581 L p F P
0 g
s
.686 .408 .495 r
.40256 .39421 m .38477 .39403 L .38639 .3835 L p F P
0 g
s
.706 .426 .498 r
.37128 .38271 m .38639 .3835 L .38477 .39403 L p F P
0 g
s
.748 .486 .535 r
.3245 .37811 m .31323 .37649 L .3143 .36523 L p F P
0 g
s
.761 .497 .535 r
.30367 .36334 m .3143 .36523 L .31323 .37649 L p F P
0 g
s
.743 .406 .412 r
.30507 .45045 m .28596 .44722 L .28079 .43706 L p F P
0 g
s
.753 .41 .404 r
.26859 .43468 m .28079 .43706 L .28596 .44722 L p F P
0 g
s
.656 .383 .496 r
.43135 .383 m .45088 .38187 L .4496 .39252 L p F P
0 g
s
.656 .383 .496 r
.4496 .39252 m .43601 .39331 L .43135 .383 L p F P
0 g
s
.686 .323 .354 r
.35967 .46478 m .33835 .46313 L .34288 .45499 L p F P
0 g
s
.704 .344 .364 r
.3276 .45334 m .34288 .45499 L .33835 .46313 L p F P
0 g
s
.827 .563 .54 r
.18298 .37861 m .177 .37636 L .17744 .36474 L p F P
0 g
s
.835 .571 .539 r
.16365 .35913 m .17744 .36474 L .177 .37636 L p F P
0 g
s
.706 .426 .498 r
.38477 .39403 m .37426 .39348 L .37128 .38271 L p F P
0 g
s
.712 .429 .495 r
.3512 .38134 m .37128 .38271 L .37426 .39348 L p F P
0 g
s
.777 .459 .449 r
.26213 .43328 m .24455 .42913 L .24132 .41846 L p F P
0 g
s
.787 .466 .445 r
.22784 .41487 m .24132 .41846 L .24455 .42913 L p F P
0 g
s
.57 .225 .345 r
.47418 .45414 m .47987 .45342 L .50023 .45927 L p F P
0 g
s
.57 .225 .345 r
.50023 .45927 m .47093 .46294 L .47418 .45414 L p F P
0 g
s
.497 .269 .497 r
.61584 .393 m .6162 .38195 L .64085 .37218 L p F P
0 g
s
.514 .302 .53 r
.64067 .36066 m .64085 .37218 L .6162 .38195 L p F P
0 g
s
.631 .362 .491 r
.45088 .38187 m .47292 .37949 L .47916 .38935 L p F P
0 g
s
.631 .362 .491 r
.47916 .38935 m .4496 .39252 L .45088 .38187 L p F P
0 g
s
.531 .222 .389 r
.5342 .43581 m .56152 .42959 L .55942 .43913 L p F P
0 g
s
.531 .222 .389 r
.53303 .44086 m .5342 .43581 L p .55942 .43913 L F P
0 g
s
.816 .535 .512 r
.2071 .39813 m .19202 .39305 L .19141 .3817 L p F P
0 g
s
.825 .542 .51 r
.18298 .37861 m .19141 .3817 L .19202 .39305 L p F P
0 g
s
.6 .249 .347 r
.45267 .46442 m .44013 .46535 L .44245 .45967 L closepath p F P
0 g
s
.599 .253 .354 r
.47093 .46294 m .45267 .46442 L .44245 .45967 L p F P
0 g
s
.57 .229 .351 r
.47987 .45342 m .50358 .45034 L .50054 .45923 L p F P
0 g
s
.57 .229 .351 r
.50054 .45923 m .50023 .45927 L .47987 .45342 L p F P
0 g
s
.761 .497 .535 r
.31323 .37649 m .30396 .37485 L .30367 .36334 L p F P
0 g
s
.769 .504 .535 r
.28473 .35953 m .30367 .36334 L .30396 .37485 L p F P
0 g
s
.712 .429 .495 r
.37426 .39348 m .34938 .39179 L .3512 .38134 L p F P
0 g
s
.729 .445 .498 r
.34658 .38085 m .3512 .38134 L .34938 .39179 L p F P
0 g
s
.704 .344 .364 r
.33835 .46313 m .3354 .46281 L .3276 .45334 L p F P
0 g
s
.711 .349 .361 r
.3059 .45057 m .3276 .45334 L .3354 .46281 L p F P
0 g
s
.723 .386 .408 r
.3276 .45334 m .3059 .45057 L .30541 .44975 L p F P
0 g
s
.628 .277 .357 r
.44013 .46535 m .4165 .46612 L .40997 .46189 L p F P
0 g
s
.63 .274 .348 r
.4165 .46612 m .40797 .46632 L .40997 .46189 L closepath p F P
0 g
s
.729 .445 .498 r
.34938 .39179 m .34906 .39175 L .34658 .38085 L p F P
0 g
s
.735 .45 .497 r
.3245 .37811 m .34658 .38085 L .34906 .39175 L p F P
0 g
s
.753 .41 .404 r
.26538 .44044 m .26859 .43468 L p .28596 .44722 L F P
0 g
s
.763 .423 .409 r
.26538 .44044 m .26213 .43328 L .26859 .43468 L closepath p F P
0 g
s
.59 .355 .528 r
.50956 .37381 m .50988 .3624 L .53739 .35623 L p F P
0 g
s
.616 .376 .531 r
.50988 .3624 m .50956 .37381 L .48085 .37858 L p F P
0 g
s
.804 .504 .482 r
.22466 .41398 m .20885 .40918 L .2071 .39813 L p F P
0 g
s
.814 .513 .479 r
.19202 .39305 m .2071 .39813 L .20885 .40918 L p F P
0 g
s
.629 .361 .493 r
.47292 .37949 m .48085 .37858 L .47972 .38928 L p F P
0 g
s
.629 .361 .493 r
.47972 .38928 m .47916 .38935 L .47292 .37949 L p F P
0 g
s
.77 .428 .406 r
.26213 .43328 m .26538 .44044 L .2639 .44291 L p F P
0 g
s
.77 .428 .406 r
.24455 .42913 m .26213 .43328 L p .2639 .44291 L F P
0 g
s
.729 .388 .401 r
.3059 .45057 m .30507 .45045 L .30541 .44975 L closepath p F P
0 g
s
.787 .466 .445 r
.22596 .4187 m .22784 .41487 L p .24455 .42913 L F P
0 g
s
.794 .473 .447 r
.22596 .4187 m .22466 .41398 L .22784 .41487 L closepath p F P
0 g
s
.483 .278 .525 r
.64085 .37218 m .64067 .36066 L .6645 .34962 L p F P
0 g
s
.825 .542 .51 r
.19202 .39305 m .1802 .38873 L .18298 .37861 L p F P
0 g
s
.828 .545 .51 r
.177 .37636 m .18298 .37861 L .1802 .38873 L p F P
0 g
s
.603 .338 .489 r
.47972 .38928 m .48085 .37858 L .50956 .37381 L p F P
0 g
s
.711 .349 .361 r
.3354 .46281 m .31341 .46011 L .3059 .45057 L p F P
0 g
s
.718 .349 .349 r
.30507 .45045 m .3059 .45057 L .31341 .46011 L p F P
0 g
s
.718 .349 .349 r
.31341 .46011 m .29993 .45819 L .30507 .45045 L p F P
0 g
s
.733 .367 .358 r
.28596 .44722 m .30507 .45045 L .29993 .45819 L p F P
0 g
s
.538 .197 .339 r
.50054 .45923 m .50358 .45034 L .53197 .44532 L p F P
0 g
s
.561 .249 .396 r
.53303 .44086 m .53197 .44532 L .50358 .45034 L p F P
0 g
s
.735 .45 .497 r
.34906 .39175 m .32686 .38904 L .3245 .37811 L p F P
0 g
s
.744 .456 .494 r
.31323 .37649 m .3245 .37811 L .32686 .38904 L p F P
0 g
s
.801 .479 .444 r
.22466 .41398 m .22596 .4187 L .22344 .42348 L p F P
0 g
s
.801 .479 .444 r
.20885 .40918 m .22466 .41398 L p .22344 .42348 L F P
0 g
s
.769 .504 .535 r
.30396 .37485 m .28495 .37105 L .28473 .35953 L p F P
0 g
s
.777 .511 .534 r
.27266 .35681 m .28473 .35953 L .28495 .37105 L p F P
0 g
s
.835 .571 .539 r
.177 .37636 m .16316 .37077 L .16365 .35913 L p F P
0 g
s
.845 .579 .537 r
.15039 .3533 m .16365 .35913 L .16316 .37077 L p F P
0 g
s
.531 .222 .389 r
.55942 .43913 m .55126 .44097 L .53303 .44086 L p F P
0 g
s
.53 .221 .387 r
.55126 .44097 m .53197 .44532 L .53303 .44086 L closepath p F P
0 g
s
.744 .456 .494 r
.32686 .38904 m .31111 .38678 L .31323 .37649 L p F P
0 g
s
.757 .469 .496 r
.30396 .37485 m .31323 .37649 L .31111 .38678 L p F P
0 g
s
.828 .545 .51 r
.1802 .38873 m .17753 .38773 L .177 .37636 L p F P
0 g
s
.836 .552 .508 r
.16316 .37077 m .177 .37636 L .17753 .38773 L p F P
0 g
s
.67 .366 .45 r
.40256 .39421 m .41805 .39417 L .41576 .40398 L p F P
0 g
s
.67 .366 .45 r
.41576 .40398 m .40901 .40399 L .40256 .39421 L p F P
0 g
s
.675 .367 .445 r
.38477 .39403 m .40256 .39421 L .40901 .40399 L p F P
0 g
s
.646 .343 .443 r
.41805 .39417 m .43601 .39331 L .44409 .40261 L p F P
0 g
s
.646 .343 .443 r
.44409 .40261 m .41576 .40398 L .41805 .39417 L p F P
0 g
s
.607 .218 .281 r
.40797 .46632 m .4165 .46612 L .43196 .47346 L p F P
0 g
s
.607 .218 .281 r
.43196 .47346 m .40331 .47413 L .40797 .46632 L p F P
0 g
s
.635 .25 .297 r
.38631 .466 m .40797 .46632 L .40331 .47413 L p F P
0 g
s
.489 .215 .424 r
.58799 .42221 m .58943 .41213 L .61501 .40357 L p F P
0 g
s
.51 .257 .467 r
.61584 .393 m .61501 .40357 L .58943 .41213 L p F P
0 g
s
.521 .242 .431 r
.58943 .41213 m .58799 .42221 L .56152 .42959 L p F P
0 g
s
.675 .367 .445 r
.40901 .40399 m .38224 .40372 L .38477 .39403 L p F P
0 g
s
.696 .389 .451 r
.37426 .39348 m .38477 .39403 L .38224 .40372 L p F P
0 g
s
.606 .225 .294 r
.4165 .46612 m .44013 .46535 L .43582 .47333 L p F P
0 g
s
.606 .225 .294 r
.43582 .47333 m .43196 .47346 L .4165 .46612 L p F P
0 g
s
.635 .25 .297 r
.40331 .47413 m .39923 .47406 L .38631 .466 L p F P
0 g
s
.635 .24 .278 r
.37416 .46567 m .38631 .466 L .39923 .47406 L p F P
0 g
s
.696 .389 .451 r
.38224 .40372 m .37959 .40359 L .37426 .39348 L p F P
0 g
s
.703 .392 .448 r
.34938 .39179 m .37426 .39348 L .37959 .40359 L p F P
0 g
s
.498 .195 .382 r
.55942 .43913 m .56152 .42959 L .58799 .42221 L p F P
0 g
s
.635 .24 .278 r
.36963 .4725 m .37416 .46567 L p .39923 .47406 L F P
0 g
s
.662 .274 .3 r
.36963 .4725 m .35967 .46478 L .37416 .46567 L closepath p F P
0 g
s
.642 .343 .448 r
.43601 .39331 m .4496 .39252 L .44752 .40242 L p F P
0 g
s
.642 .343 .448 r
.44752 .40242 m .44409 .40261 L .43601 .39331 L p F P
0 g
s
.574 .191 .277 r
.43582 .47333 m .44013 .46535 L .45267 .46442 L p F P
0 g
s
.814 .513 .479 r
.20885 .40918 m .19366 .40414 L .19202 .39305 L p F P
0 g
s
.824 .521 .476 r
.1802 .38873 m .19202 .39305 L .19366 .40414 L p F P
0 g
s
.733 .367 .358 r
.29993 .45819 m .29271 .45697 L .28596 .44722 L p F P
0 g
s
.741 .372 .354 r
.26693 .44355 m .28596 .44722 L .29271 .45697 L p F P
0 g
s
.753 .41 .404 r
.28596 .44722 m .26693 .44355 L .26538 .44044 L p F P
0 g
s
.77 .428 .406 r
.2639 .44291 m .2491 .43946 L .24455 .42913 L p F P
0 g
s
.78 .434 .401 r
.22771 .4247 m .24455 .42913 L .2491 .43946 L p F P
0 g
s
.787 .466 .445 r
.24455 .42913 m .22771 .4247 L .22596 .4187 L p F P
0 g
s
.478 .23 .46 r
.61501 .40357 m .61584 .393 L .64057 .38324 L p F P
0 g
s
.497 .269 .497 r
.64085 .37218 m .64057 .38324 L .61584 .393 L p F P
0 g
s
.777 .511 .534 r
.28495 .37105 m .27138 .36802 L .27266 .35681 L p F P
0 g
s
.787 .521 .534 r
.26684 .35534 m .27266 .35681 L .27138 .36802 L p F P
0 g
s
.757 .469 .496 r
.31111 .38678 m .30596 .38588 L .30396 .37485 L p F P
0 g
s
.765 .475 .494 r
.28495 .37105 m .30396 .37485 L .30596 .38588 L p F P
0 g
s
.795 .471 .44 r
.22771 .4247 m .22344 .42348 L .22596 .4187 L closepath p F P
0 g
s
.615 .317 .441 r
.44752 .40242 m .4496 .39252 L .47916 .38935 L p F P
0 g
s
.666 .273 .291 r
.35967 .46478 m .36963 .4725 L .36909 .47324 L p F P
0 g
s
.666 .273 .291 r
.33835 .46313 m .35967 .46478 L p .36909 .47324 L F P
0 g
s
.562 .332 .525 r
.53716 .36766 m .53739 .35623 L .55913 .35004 L p F P
0 g
s
.59 .355 .528 r
.53739 .35623 m .53716 .36766 L .50956 .37381 L p F P
0 g
s
.574 .191 .277 r
.45267 .46442 m .46777 .46939 L p .43582 .47333 L F P
0 g
s
.576 .2 .292 r
.46777 .46939 m .45267 .46442 L .47093 .46294 L closepath p F P
0 g
s
.574 .314 .485 r
.50853 .38453 m .50956 .37381 L .53716 .36766 L p F P
0 g
s
.603 .338 .489 r
.50956 .37381 m .50853 .38453 L .47972 .38928 L p F P
0 g
s
.703 .392 .448 r
.34926 .39221 m .34938 .39179 L p .37959 .40359 L F P
0 g
s
.722 .411 .453 r
.34926 .39221 m .34906 .39175 L .34938 .39179 L closepath p F P
0 g
s
.728 .414 .448 r
.34906 .39175 m .34926 .39221 L .34647 .40125 L p F P
0 g
s
.728 .414 .448 r
.32686 .38904 m .34906 .39175 L p .34647 .40125 L F P
0 g
s
.76 .413 .397 r
.26693 .44355 m .2639 .44291 L .26538 .44044 L closepath p F P
0 g
s
.787 .521 .534 r
.27138 .36802 m .26693 .3669 L .26684 .35534 L p F P
0 g
s
.796 .528 .533 r
.25018 .3507 m .26684 .35534 L .26693 .3669 L p F P
0 g
s
.703 .392 .448 r
.37959 .40359 m .35419 .40189 L .34926 .39221 L p F P
0 g
s
.709 .394 .442 r
.35419 .40189 m .34647 .40125 L .34926 .39221 L closepath p F P
0 g
s
.801 .479 .444 r
.22344 .42348 m .21171 .41995 L .20885 .40918 L p F P
0 g
s
.811 .486 .44 r
.19366 .40414 m .20885 .40918 L .21171 .41995 L p F P
0 g
s
.504 .167 .329 r
.52909 .45425 m .53197 .44532 L .55126 .44097 L p F P
0 g
s
.538 .197 .339 r
.53197 .44532 m .52909 .45425 L .50054 .45923 L p F P
0 g
s
.666 .273 .291 r
.33728 .46461 m .33835 .46313 L p .36909 .47324 L F P
0 g
s
.69 .302 .309 r
.33728 .46461 m .3354 .46281 L .33835 .46313 L closepath p F P
0 g
s
.539 .157 .266 r
.47093 .46294 m .50023 .45927 L p .49671 .4674 L F P
0 g
s
.539 .157 .266 r
.46777 .46939 m .47093 .46294 L p .49671 .4674 L F P
0 g
s
.693 .297 .293 r
.3354 .46281 m .33728 .46461 L .33271 .47032 L p F P
0 g
s
.693 .297 .293 r
.31341 .46011 m .3354 .46281 L p .33271 .47032 L F P
0 g
s
.464 .242 .491 r
.64057 .38324 m .64085 .37218 L .66475 .36116 L p F P
0 g
s
.483 .278 .525 r
.6645 .34962 m .66475 .36116 L .64085 .37218 L p F P
0 g
s
.845 .579 .537 r
.16316 .37077 m .14985 .36496 L .15039 .3533 L p F P
0 g
s
.854 .588 .536 r
.13763 .34725 m .15039 .3533 L .14985 .36496 L p F P
0 g
s
.614 .32 .447 r
.47964 .38973 m .47916 .38935 L .47972 .38928 L closepath p F P
0 g
s
.615 .317 .441 r
.47916 .38935 m .47964 .38973 L p .44752 .40242 L F P
0 g
s
.585 .293 .439 r
.47972 .38928 m .50853 .38453 L .50676 .39452 L p F P
0 g
s
.585 .293 .439 r
.47964 .38973 m .47972 .38928 L p .50676 .39452 L F P
0 g
s
.741 .372 .354 r
.29271 .45697 m .27345 .45336 L .26693 .44355 L p F P
0 g
s
.749 .373 .342 r
.2639 .44291 m .26693 .44355 L .27345 .45336 L p F P
0 g
s
.765 .475 .494 r
.30596 .38588 m .28685 .3821 L .28495 .37105 L p F P
0 g
s
.775 .482 .491 r
.27138 .36802 m .28495 .37105 L .28685 .3821 L p F P
0 g
s
.728 .414 .448 r
.34647 .40125 m .33124 .3994 L .32686 .38904 L p F P
0 g
s
.736 .417 .442 r
.31111 .38678 m .32686 .38904 L .33124 .3994 L p F P
0 g
s
.586 .291 .434 r
.49385 .39665 m .47778 .39921 L .47964 .38973 L closepath p F P
0 g
s
.615 .317 .441 r
.47964 .38973 m .47778 .39921 L .44752 .40242 L p F P
0 g
s
.585 .293 .439 r
.50676 .39452 m .49385 .39665 L .47964 .38973 L p F P
0 g
s
.836 .552 .508 r
.17753 .38773 m .16363 .38217 L .16316 .37077 L p F P
0 g
s
.846 .561 .506 r
.14985 .36496 m .16316 .37077 L .16363 .38217 L p F P
0 g
s
.824 .521 .476 r
.17825 .39306 m .1802 .38873 L p .19366 .40414 L F P
0 g
s
.827 .524 .476 r
.17825 .39306 m .17753 .38773 L .1802 .38873 L closepath p F P
0 g
s
.749 .373 .342 r
.27345 .45336 m .25794 .45009 L .2639 .44291 L p F P
0 g
s
.76 .388 .35 r
.2491 .43946 m .2639 .44291 L .25794 .45009 L p F P
0 g
s
.666 .273 .291 r
.36909 .47324 m .34597 .47152 L .33728 .46461 L p F P
0 g
s
.67 .268 .275 r
.34597 .47152 m .33271 .47032 L .33728 .46461 L closepath p F P
0 g
s
.78 .434 .401 r
.2491 .43946 m .23209 .43507 L .22771 .4247 L p F P
0 g
s
.789 .438 .392 r
.22344 .42348 m .22771 .4247 L .23209 .43507 L p F P
0 g
s
.836 .531 .473 r
.17753 .38773 m .17825 .39306 L .17601 .39765 L p F P
0 g
s
.836 .531 .473 r
.16363 .38217 m .17753 .38773 L p .17601 .39765 L F P
0 g
s
.693 .297 .293 r
.33271 .47032 m .3229 .46913 L .31341 .46011 L p F P
0 g
s
.698 .294 .278 r
.29993 .45819 m .31341 .46011 L .3229 .46913 L p F P
0 g
s
.789 .438 .392 r
.23209 .43507 m .21774 .431 L .22344 .42348 L p F P
0 g
s
.796 .448 .397 r
.21171 .41995 m .22344 .42348 L .21774 .431 L p F P
0 g
s
.796 .528 .533 r
.26693 .3669 m .25022 .36227 L .25018 .3507 L p F P
0 g
s
.806 .537 .531 r
.23423 .34578 m .25018 .3507 L .25022 .36227 L p F P
0 g
s
.548 .18 .296 r
.5005 .45932 m .50023 .45927 L .50054 .45923 L closepath p F P
0 g
s
.539 .157 .266 r
.50023 .45927 m .5005 .45932 L .49671 .4674 L p F P
0 g
s
.736 .417 .442 r
.30873 .39362 m .31111 .38678 L p .33124 .3994 L F P
0 g
s
.752 .435 .449 r
.30873 .39362 m .30596 .38588 L .31111 .38678 L closepath p F P
0 g
s
.513 .146 .28 r
.5005 .45932 m .50054 .45923 L .52909 .45425 L p F P
0 g
s
.513 .146 .28 r
.52909 .45425 m .52638 .46052 L .5005 .45932 L p F P
0 g
s
.507 .13 .261 r
.49671 .4674 m .5005 .45932 L .52638 .46052 L p F P
0 g
s
.509 .177 .34 r
.55899 .4406 m .55126 .44097 L .55942 .43913 L closepath p F P
0 g
s
.504 .167 .329 r
.55126 .44097 m .55899 .4406 L p .52909 .45425 L F P
0 g
s
.561 .332 .525 r
.56383 .35222 m .55913 .35004 L .56387 .34868 L closepath p F P
0 g
s
.562 .332 .525 r
.55913 .35004 m .56383 .35222 L p .53716 .36766 L F P
0 g
s
.775 .482 .491 r
.28685 .3821 m .26886 .3781 L .27138 .36802 L p F P
0 g
s
.786 .493 .493 r
.26693 .3669 m .27138 .36802 L .26886 .3781 L p F P
0 g
s
.811 .486 .44 r
.21171 .41995 m .19641 .41494 L .19366 .40414 L p F P
0 g
s
.821 .494 .436 r
.17907 .39884 m .19366 .40414 L .19641 .41494 L p F P
0 g
s
.824 .521 .476 r
.19366 .40414 m .17907 .39884 L .17825 .39306 L p F P
0 g
s
.463 .163 .371 r
.586 .43176 m .58799 .42221 L .61366 .41365 L p F P
0 g
s
.489 .215 .424 r
.61501 .40357 m .61366 .41365 L .58799 .42221 L p F P
0 g
s
.498 .195 .382 r
.58799 .42221 m .586 .43176 L .55942 .43913 L p F P
0 g
s
.759 .44 .444 r
.30596 .38588 m .30873 .39362 L .30781 .39603 L p F P
0 g
s
.759 .44 .444 r
.28685 .3821 m .30596 .38588 L p .30781 .39603 L F P
0 g
s
.655 .319 .392 r
.41404 .40882 m .40901 .40399 L .41576 .40398 L closepath p F P
0 g
s
.658 .316 .382 r
.40901 .40399 m .41404 .40882 L .41248 .41287 L p F P
0 g
s
.658 .316 .382 r
.38224 .40372 m .40901 .40399 L p .41248 .41287 L F P
0 g
s
.45 .252 .52 r
.6813 .34062 m .6645 .34962 L .66475 .36116 L p F P
0 g
s
.626 .287 .377 r
.41576 .40398 m .44409 .40261 L p .44449 .41142 L F P
0 g
s
.626 .287 .377 r
.41404 .40882 m .41576 .40398 L p .44449 .41142 L F P
0 g
s
.542 .287 .479 r
.53623 .37839 m .53716 .36766 L .56372 .36013 L p F P
0 g
s
.562 .332 .525 r
.56383 .35222 m .56372 .36013 L .53716 .36766 L p F P
0 g
s
.574 .314 .485 r
.53716 .36766 m .53623 .37839 L .50853 .38453 L p F P
0 g
s
.698 .294 .278 r
.29687 .46162 m .29993 .45819 L p .3229 .46913 L F P
0 g
s
.718 .322 .298 r
.29687 .46162 m .29271 .45697 L .29993 .45819 L closepath p F P
0 g
s
.658 .316 .382 r
.38142 .40582 m .38224 .40372 L p .41248 .41287 L F P
0 g
s
.683 .345 .395 r
.38142 .40582 m .37959 .40359 L .38224 .40372 L closepath p F P
0 g
s
.688 .343 .385 r
.37959 .40359 m .38142 .40582 L .3786 .41241 L p F P
0 g
s
.688 .343 .385 r
.35419 .40189 m .37959 .40359 L p .3786 .41241 L F P
0 g
s
.453 .184 .414 r
.61366 .41365 m .61501 .40357 L .63981 .39382 L p F P
0 g
s
.478 .23 .46 r
.64057 .38324 m .63981 .39382 L .61501 .40357 L p F P
0 g
s
.76 .388 .35 r
.25794 .45009 m .25508 .44943 L .2491 .43946 L p F P
0 g
s
.769 .394 .346 r
.23209 .43507 m .2491 .43946 L .25508 .44943 L p F P
0 g
s
.786 .493 .493 r
.26886 .3781 m .26856 .37802 L .26693 .3669 L p F P
0 g
s
.794 .5 .491 r
.25022 .36227 m .26693 .3669 L .26856 .37802 L p F P
0 g
s
.531 .308 .521 r
.56383 .35222 m .56841 .34709 L .56387 .34868 L closepath p F P
0 g
s
.473 .144 .327 r
.55899 .4406 m .55942 .43913 L .586 .43176 L p F P
0 g
s
.552 .263 .43 r
.50676 .39452 m .50853 .38453 L .53623 .37839 L p F P
0 g
s
.625 .295 .391 r
.44684 .40459 m .44409 .40261 L .44752 .40242 L closepath p F P
0 g
s
.626 .287 .377 r
.44409 .40261 m .44684 .40459 L .44449 .41142 L p F P
0 g
s
.723 .32 .285 r
.29271 .45697 m .29687 .46162 L .29355 .46489 L p F P
0 g
s
.723 .32 .285 r
.27345 .45336 m .29271 .45697 L p .29355 .46489 L F P
0 g
s
.833 .527 .472 r
.17907 .39884 m .17601 .39765 L .17825 .39306 L closepath p F P
0 g
s
.594 .261 .376 r
.44752 .40242 m .47778 .39921 L .47497 .40832 L p F P
0 g
s
.594 .261 .376 r
.44684 .40459 m .44752 .40242 L p .47497 .40832 L F P
0 g
s
.688 .343 .385 r
.3786 .41241 m .36189 .4113 L .35419 .40189 L p F P
0 g
s
.694 .343 .376 r
.34647 .40125 m .35419 .40189 L .36189 .4113 L p F P
0 g
s
.804 .454 .393 r
.19641 .41494 m .21171 .41995 L .21579 .43041 L p F P
0 g
s
.796 .448 .397 r
.21774 .431 m .21579 .43041 L .21171 .41995 L p F P
0 g
s
.635 .24 .278 r
.39923 .47406 m .37094 .47331 L .36963 .4725 L p F P
0 g
s
.637 .234 .263 r
.37094 .47331 m .36909 .47324 L .36963 .4725 L closepath p F P
0 g
s
.854 .588 .536 r
.14985 .36496 m .13704 .35892 L .13763 .34725 L p F P
0 g
s
.863 .597 .534 r
.12533 .34098 m .13763 .34725 L .13704 .35892 L p F P
0 g
s
.572 .145 .192 r
.40331 .47413 m .43196 .47346 L p .43045 .48039 L F P
0 g
s
.572 .145 .192 r
.40224 .47552 m .40331 .47413 L p .43045 .48039 L F P
0 g
s
.61 .194 .228 r
.40224 .47552 m .39923 .47406 L .40331 .47413 L closepath p F P
0 g
s
.53 .307 .521 r
.56841 .34709 m .58937 .33973 L p .56372 .36013 L F P
0 g
s
.53 .307 .521 r
.56372 .36013 m .56383 .35222 L .56841 .34709 L p F P
0 g
s
.658 .316 .382 r
.41248 .41287 m .38852 .41264 L .38142 .40582 L p F P
0 g
s
.663 .314 .373 r
.38852 .41264 m .3786 .41241 L .38142 .40582 L closepath p F P
0 g
s
.606 .177 .201 r
.39923 .47406 m .40224 .47552 L .39753 .48095 L p F P
0 g
s
.606 .177 .201 r
.37094 .47331 m .39923 .47406 L p .39753 .48095 L F P
0 g
s
.441 .2 .451 r
.63981 .39382 m .64057 .38324 L .66454 .37223 L p F P
0 g
s
.464 .242 .491 r
.66475 .36116 m .66454 .37223 L .64057 .38324 L p F P
0 g
s
.473 .144 .327 r
.586 .43176 m .58512 .43487 L .55899 .4406 L p F P
0 g
s
.468 .134 .316 r
.55667 .44808 m .55899 .4406 L .58512 .43487 L p F P
0 g
s
.504 .167 .329 r
.55899 .4406 m .55667 .44808 L .52909 .45425 L p F P
0 g
s
.846 .561 .506 r
.16363 .38217 m .15025 .37637 L .14985 .36496 L p F P
0 g
s
.855 .57 .504 r
.13704 .35892 m .14985 .36496 L .15025 .37637 L p F P
0 g
s
.694 .343 .376 r
.36189 .4113 m .34243 .4097 L .34647 .40125 L p F P
0 g
s
.716 .367 .386 r
.33124 .3994 m .34647 .40125 L .34243 .4097 L p F P
0 g
s
.579 .167 .225 r
.43498 .47454 m .43196 .47346 L .43582 .47333 L closepath p F P
0 g
s
.572 .145 .192 r
.43196 .47346 m .43498 .47454 L .43045 .48039 L p F P
0 g
s
.537 .115 .187 r
.43582 .47333 m .46689 .47105 L .46187 .47829 L p F P
0 g
s
.537 .115 .187 r
.43498 .47454 m .43582 .47333 L p .46187 .47829 L F P
0 g
s
.574 .191 .277 r
.46777 .46939 m .46689 .47105 L .43582 .47333 L p F P
0 g
s
.606 .177 .201 r
.39753 .48095 m .38641 .48067 L .37094 .47331 L p F P
0 g
s
.606 .167 .18 r
.36909 .47324 m .37094 .47331 L .38641 .48067 L p F P
0 g
s
.606 .167 .18 r
.38641 .48067 m .36279 .47975 L .36909 .47324 L p F P
0 g
s
.637 .204 .203 r
.34597 .47152 m .36909 .47324 L .36279 .47975 L p F P
0 g
s
.537 .149 .254 r
.47303 .47032 m .46689 .47105 L .46777 .46939 L closepath p F P
0 g
s
.539 .157 .266 r
.49671 .4674 m .47303 .47032 L .46777 .46939 L p F P
0 g
s
.836 .531 .473 r
.17601 .39765 m .16507 .39331 L .16363 .38217 L p F P
0 g
s
.845 .539 .47 r
.15025 .37637 m .16363 .38217 L .16507 .39331 L p F P
0 g
s
.594 .261 .376 r
.47497 .40832 m .45843 .41006 L .44684 .40459 L p F P
0 g
s
.595 .257 .367 r
.45843 .41006 m .44449 .41142 L .44684 .40459 L closepath p F P
0 g
s
.759 .44 .444 r
.30781 .39603 m .29053 .39265 L .28685 .3821 L p F P
0 g
s
.769 .445 .439 r
.26886 .3781 m .28685 .3821 L .29053 .39265 L p F P
0 g
s
.806 .537 .531 r
.25022 .36227 m .23421 .35737 L .23423 .34578 L p F P
0 g
s
.815 .545 .53 r
.22472 .34258 m .23423 .34578 L .23421 .35737 L p F P
0 g
s
.464 .089 .241 r
.52909 .45425 m .55667 .44808 L .55321 .45637 L p F P
0 g
s
.464 .089 .241 r
.52638 .46052 m .52909 .45425 L p .55321 .45637 L F P
0 g
s
.716 .367 .386 r
.34243 .4097 m .33781 .40914 L .33124 .3994 L p F P
0 g
s
.723 .37 .379 r
.30987 .39636 m .33124 .3994 L .33781 .40914 L p F P
0 g
s
.736 .417 .442 r
.33124 .3994 m .30987 .39636 L .30873 .39362 L p F P
0 g
s
.572 .145 .192 r
.43045 .48039 m .41723 .4807 L .40224 .47552 L p F P
0 g
s
.57 .133 .172 r
.41723 .4807 m .39753 .48095 L .40224 .47552 L closepath p F P
0 g
s
.559 .229 .365 r
.47497 .40832 m .47778 .39921 L .49385 .39665 L p F P
0 g
s
.626 .287 .377 r
.44449 .41142 m .41944 .41261 L .41404 .40882 L p F P
0 g
s
.629 .284 .368 r
.41944 .41261 m .41248 .41287 L .41404 .40882 L closepath p F P
0 g
s
.537 .115 .187 r
.46187 .47829 m .45427 .47884 L .43498 .47454 L p F P
0 g
s
.534 .103 .168 r
.45427 .47884 m .43045 .48039 L .43498 .47454 L closepath p F P
0 g
s
.723 .32 .285 r
.29355 .46489 m .28175 .46271 L .27345 .45336 L p F P
0 g
s
.73 .321 .272 r
.25794 .45009 m .27345 .45336 L .28175 .46271 L p F P
0 g
s
.637 .204 .203 r
.36279 .47975 m .35931 .4795 L .34597 .47152 L p F P
0 g
s
.635 .19 .177 r
.33271 .47032 m .34597 .47152 L .35931 .4795 L p F P
0 g
s
.821 .494 .436 r
.19641 .41494 m .1817 .40968 L .17907 .39884 L p F P
0 g
s
.831 .5 .429 r
.17601 .39765 m .17907 .39884 L .1817 .40968 L p F P
0 g
s
.769 .394 .346 r
.25508 .44943 m .23789 .44508 L .23209 .43507 L p F P
0 g
s
.778 .398 .336 r
.21774 .431 m .23209 .43507 L .23789 .44508 L p F P
0 g
s
.794 .5 .491 r
.26856 .37802 m .25177 .37341 L .25022 .36227 L p F P
0 g
s
.804 .508 .488 r
.23421 .35737 m .25022 .36227 L .25177 .37341 L p F P
0 g
s
.743 .42 .437 r
.30987 .39636 m .30781 .39603 L .30873 .39362 L closepath p F P
0 g
s
.498 .074 .166 r
.46187 .47829 m .46689 .47105 L .47303 .47032 L p F P
0 g
s
.698 .294 .278 r
.3229 .46913 m .3016 .46616 L .29687 .46162 L p F P
0 g
s
.702 .29 .262 r
.3016 .46616 m .29355 .46489 L .29687 .46162 L closepath p F P
0 g
s
.831 .5 .429 r
.1817 .40968 m .17023 .40523 L .17601 .39765 L p F P
0 g
s
.834 .505 .432 r
.16507 .39331 m .17601 .39765 L .17023 .40523 L p F P
0 g
s
.635 .19 .177 r
.32908 .4737 m .33271 .47032 L p .35931 .4795 L F P
0 g
s
.668 .237 .215 r
.32908 .4737 m .3229 .46913 L .33271 .47032 L closepath p F P
0 g
s
.506 .093 .191 r
.49351 .47256 m .47303 .47032 L .49671 .4674 L closepath p F P
0 g
s
.498 .074 .166 r
.47303 .47032 m .49351 .47256 L p .46187 .47829 L F P
0 g
s
.428 .213 .483 r
.68 .35304 m .66475 .36116 L .66454 .37223 L p F P
0 g
s
.45 .252 .52 r
.66475 .36116 m .68 .35304 L .6813 .34062 L p F P
0 g
s
.815 .545 .53 r
.23421 .35737 m .22312 .35365 L .22472 .34258 L p F P
0 g
s
.822 .552 .53 r
.21908 .34055 m .22472 .34258 L .22312 .35365 L p F P
0 g
s
.804 .454 .393 r
.21579 .43041 m .20035 .42543 L .19641 .41494 L p F P
0 g
s
.815 .461 .387 r
.1817 .40968 m .19641 .41494 L .20035 .42543 L p F P
0 g
s
.559 .229 .365 r
.49385 .39665 m .50538 .39951 L p .47497 .40832 L F P
0 g
s
.561 .236 .376 r
.50538 .39951 m .49385 .39665 L .50676 .39452 L closepath p F P
0 g
s
.517 .232 .422 r
.53457 .3884 m .53623 .37839 L .56289 .37087 L p F P
0 g
s
.542 .287 .479 r
.56372 .36013 m .56289 .37087 L .53623 .37839 L p F P
0 g
s
.552 .263 .43 r
.53623 .37839 m .53457 .3884 L .50676 .39452 L p F P
0 g
s
.507 .258 .472 r
.56289 .37087 m .56372 .36013 L .5893 .35119 L p F P
0 g
s
.53 .307 .521 r
.58937 .33973 m .5893 .35119 L .56372 .36013 L p F P
0 g
s
.669 .228 .193 r
.3229 .46913 m .32908 .4737 L .32571 .47637 L p F P
0 g
s
.669 .228 .193 r
.3016 .46616 m .3229 .46913 L p .32571 .47637 L F P
0 g
s
.723 .37 .379 r
.33781 .40914 m .31631 .40613 L .30987 .39636 L p F P
0 g
s
.73 .371 .369 r
.30781 .39603 m .30987 .39636 L .31631 .40613 L p F P
0 g
s
.769 .445 .439 r
.2687 .37849 m .26886 .3781 L p .29053 .39265 L F P
0 g
s
.781 .461 .445 r
.2687 .37849 m .26856 .37802 L .26886 .3781 L closepath p F P
0 g
s
.79 .465 .439 r
.26856 .37802 m .2687 .37849 L .26484 .38683 L p F P
0 g
s
.79 .465 .439 r
.25177 .37341 m .26856 .37802 L p .26484 .38683 L F P
0 g
s
.73 .371 .369 r
.31631 .40613 m .30312 .40403 L .30781 .39603 L p F P
0 g
s
.749 .394 .38 r
.29053 .39265 m .30781 .39603 L .30312 .40403 L p F P
0 g
s
.769 .445 .439 r
.29053 .39265 m .27211 .3886 L .2687 .37849 L p F P
0 g
s
.777 .45 .433 r
.27211 .3886 m .26484 .38683 L .2687 .37849 L closepath p F P
0 g
s
.863 .597 .534 r
.13704 .35892 m .1247 .35267 L .12533 .34098 L p F P
0 g
s
.872 .605 .532 r
.11929 .33768 m .12533 .34098 L .1247 .35267 L p F P
0 g
s
.73 .321 .272 r
.25654 .45134 m .25794 .45009 L p .28175 .46271 L F P
0 g
s
.747 .346 .291 r
.25654 .45134 m .25508 .44943 L .25794 .45009 L closepath p F P
0 g
s
.421 .125 .355 r
.63853 .40389 m .61366 .41365 L .61175 .4232 L p F P
0 g
s
.463 .163 .371 r
.61366 .41365 m .61175 .4232 L .586 .43176 L p F P
0 g
s
.453 .184 .414 r
.63981 .39382 m .63853 .40389 L .61366 .41365 L p F P
0 g
s
.432 .106 .312 r
.58512 .43487 m .586 .43176 L .61175 .4232 L p F P
0 g
s
.855 .57 .504 r
.15025 .37637 m .13738 .37036 L .13704 .35892 L p F P
0 g
s
.865 .578 .501 r
.1247 .35267 m .13704 .35892 L .13738 .37036 L p F P
0 g
s
.447 .25 .519 r
.68756 .33723 m .6813 .34062 L .68 .35304 L p F P
0 g
s
.822 .552 .53 r
.22312 .35365 m .21896 .35216 L .21908 .34055 L p F P
0 g
s
.831 .56 .528 r
.2048 .33497 m .21908 .34055 L .21896 .35216 L p F P
0 g
s
.752 .341 .272 r
.25508 .44943 m .25654 .45134 L .25044 .45598 L p F P
0 g
s
.752 .341 .272 r
.23789 .44508 m .25508 .44943 L p .25044 .45598 L F P
0 g
s
.598 .21 .279 r
.41248 .41287 m .41944 .41261 L .43514 .41969 L p F P
0 g
s
.598 .21 .279 r
.43514 .41969 m .40803 .42069 L .41248 .41287 L p F P
0 g
s
.632 .247 .297 r
.38852 .41264 m .41248 .41287 L .40803 .42069 L p F P
0 g
s
.778 .398 .336 r
.21664 .43205 m .21774 .431 L p .23789 .44508 L F P
0 g
s
.788 .413 .346 r
.21664 .43205 m .21579 .43041 L .21774 .431 L closepath p F P
0 g
s
.452 .029 .144 r
.49671 .4674 m .52546 .4625 L .52093 .46993 L p F P
0 g
s
.452 .029 .144 r
.49351 .47256 m .49671 .4674 L p .52093 .46993 L F P
0 g
s
.507 .13 .261 r
.52638 .46052 m .52546 .4625 L .49671 .4674 L p F P
0 g
s
.845 .539 .47 r
.16507 .39331 m .15162 .38754 L .15025 .37637 L p F P
0 g
s
.855 .547 .466 r
.13738 .37036 m .15025 .37637 L .15162 .38754 L p F P
0 g
s
.522 .196 .357 r
.50676 .39452 m .53457 .3884 L .5321 .39763 L p F P
0 g
s
.522 .196 .357 r
.50538 .39951 m .50676 .39452 L p .5321 .39763 L F P
0 g
s
.632 .247 .297 r
.40803 .42069 m .40118 .42062 L .38852 .41264 L p F P
0 g
s
.634 .242 .283 r
.3786 .41241 m .38852 .41264 L .40118 .42062 L p F P
0 g
s
.597 .218 .294 r
.41944 .41261 m .44449 .41142 L .44039 .41944 L p F P
0 g
s
.597 .218 .294 r
.44039 .41944 m .43514 .41969 L .41944 .41261 L p F P
0 g
s
.495 .28 .516 r
.5893 .35119 m .58937 .33973 L .6139 .32934 L p F P
0 g
s
.634 .242 .283 r
.40118 .42062 m .37375 .41999 L .3786 .41241 L p F P
0 g
s
.665 .277 .301 r
.36189 .4113 m .3786 .41241 L .37375 .41999 L p F P
0 g
s
.795 .413 .333 r
.21579 .43041 m .21664 .43205 L .21039 .43713 L p F P
0 g
s
.795 .413 .333 r
.20035 .42543 m .21579 .43041 L p .21039 .43713 L F P
0 g
s
.412 .149 .402 r
.66384 .3828 m .63981 .39382 L .63853 .40389 L p F P
0 g
s
.441 .2 .451 r
.66454 .37223 m .66384 .3828 L .63981 .39382 L p F P
0 g
s
.804 .508 .488 r
.25177 .37341 m .23568 .36853 L .23421 .35737 L p F P
0 g
s
.814 .515 .484 r
.22312 .35365 m .23421 .35737 L .23568 .36853 L p F P
0 g
s
.426 .058 .235 r
.55321 .45637 m .55667 .44808 L .58337 .44072 L p F P
0 g
s
.468 .134 .316 r
.58512 .43487 m .58337 .44072 L .55667 .44808 L p F P
0 g
s
.834 .505 .432 r
.17023 .40523 m .16757 .40418 L .16507 .39331 L p F P
0 g
s
.843 .512 .427 r
.15162 .38754 m .16507 .39331 L .16757 .40418 L p F P
0 g
s
.667 .211 .158 r
.29355 .46489 m .3016 .46616 L .31308 .47465 L p F P
0 g
s
.669 .228 .193 r
.32571 .47637 m .31308 .47465 L .3016 .46616 L p F P
0 g
s
.559 .178 .275 r
.44039 .41944 m .44449 .41142 L .45843 .41006 L p F P
0 g
s
.665 .277 .301 r
.37375 .41999 m .37245 .41991 L .36189 .4113 L p F P
0 g
s
.667 .269 .282 r
.34243 .4097 m .36189 .4113 L .37245 .41991 L p F P
0 g
s
.73 .321 .272 r
.28175 .46271 m .26306 .45886 L .25654 .45134 L p F P
0 g
s
.736 .318 .255 r
.26306 .45886 m .25044 .45598 L .25654 .45134 L closepath p F P
0 g
s
.778 .398 .336 r
.23789 .44508 m .22139 .44048 L .21664 .43205 L p F P
0 g
s
.786 .4 .324 r
.22139 .44048 m .21039 .43713 L .21664 .43205 L closepath p F P
0 g
s
.749 .394 .38 r
.30312 .40403 m .29614 .40266 L .29053 .39265 L p F P
0 g
s
.757 .397 .372 r
.27211 .3886 m .29053 .39265 L .29614 .40266 L p F P
0 g
s
.872 .605 .532 r
.1247 .35267 m .11709 .34854 L .11929 .33768 L p F P
0 g
s
.872 .606 .532 r
.11346 .3345 m .11929 .33768 L .11709 .34854 L p F P
0 g
s
.432 .106 .312 r
.61175 .4232 m .61135 .42467 L .58512 .43487 L p F P
0 g
s
.425 .094 .299 r
.58337 .44072 m .58512 .43487 L .61135 .42467 L p F P
0 g
s
.464 .089 .241 r
.55321 .45637 m .5411 .45906 L .52638 .46052 L p F P
0 g
s
.461 .081 .232 r
.5411 .45906 m .52546 .4625 L .52638 .46052 L closepath p F P
0 g
s
.667 .211 .158 r
.28844 .46857 m .29355 .46489 L p .31308 .47465 L F P
0 g
s
.698 .257 .2 r
.28844 .46857 m .28175 .46271 L .29355 .46489 L closepath p F P
0 g
s
.41 .222 .513 r
.68788 .3488 m .68756 .33723 L .70982 .32338 L p F P
0 g
s
.447 .25 .519 r
.68 .35304 m .68788 .3488 L .68756 .33723 L p F P
0 g
s
.562 .191 .294 r
.4724 .41399 m .45843 .41006 L .47497 .40832 L closepath p F P
0 g
s
.559 .178 .275 r
.45843 .41006 m .4724 .41399 L p .44039 .41944 L F P
0 g
s
.79 .465 .439 r
.26484 .38683 m .25491 .38412 L .25177 .37341 L p F P
0 g
s
.8 .472 .434 r
.23568 .36853 m .25177 .37341 L .25491 .38412 L p F P
0 g
s
.667 .269 .282 r
.34072 .41215 m .34243 .4097 L p .37245 .41991 L F P
0 g
s
.697 .311 .312 r
.34072 .41215 m .33781 .40914 L .34243 .4097 L closepath p F P
0 g
s
.815 .461 .387 r
.20035 .42543 m .18552 .42021 L .1817 .40968 L p F P
0 g
s
.825 .467 .379 r
.17023 .40523 m .1817 .40968 L .18552 .42021 L p F P
0 g
s
.635 .19 .177 r
.35931 .4795 m .33526 .47737 L .32908 .4737 L p F P
0 g
s
.636 .18 .153 r
.33526 .47737 m .32571 .47637 L .32908 .4737 L closepath p F P
0 g
s
.701 .303 .291 r
.33781 .40914 m .34072 .41215 L .33693 .41683 L p F P
0 g
s
.701 .303 .291 r
.31631 .40613 m .33781 .40914 L p .33693 .41683 L F P
0 g
s
.401 .167 .44 r
.67505 .36665 m .66454 .37223 L .66384 .3828 L p F P
0 g
s
.428 .213 .483 r
.66454 .37223 m .67505 .36665 L .68 .35304 L p F P
0 g
s
.752 .341 .272 r
.25044 .45598 m .24528 .45468 L .23789 .44508 L p F P
0 g
s
.76 .345 .263 r
.22139 .44048 m .23789 .44508 L .24528 .45468 L p F P
0 g
s
.814 .515 .484 r
.22013 .3626 m .22312 .35365 L p .23568 .36853 L F P
0 g
s
.822 .524 .486 r
.22013 .3626 m .21896 .35216 L .22312 .35365 L closepath p F P
0 g
s
.516 .137 .261 r
.47497 .40832 m .50413 .4037 L .50049 .4119 L p F P
0 g
s
.516 .137 .261 r
.4724 .41399 m .47497 .40832 L p .50049 .4119 L F P
0 g
s
.559 .229 .365 r
.50538 .39951 m .50413 .4037 L .47497 .40832 L p F P
0 g
s
.701 .25 .179 r
.28175 .46271 m .28844 .46857 L .28557 .47025 L p F P
0 g
s
.701 .25 .179 r
.26306 .45886 m .28175 .46271 L p .28557 .47025 L F P
0 g
s
.504 .015 .028 r
.39753 .48095 m .41723 .4807 L p .42378 .48629 L F P
0 g
s
.504 .015 .028 r
.39452 .48357 m .39753 .48095 L p .42378 .48629 L F P
0 g
s
.564 .095 .099 r
.39452 .48357 m .38641 .48067 L .39753 .48095 L closepath p F P
0 g
s
.831 .56 .528 r
.21896 .35216 m .20463 .3466 L .2048 .33497 L p F P
0 g
s
.842 .569 .526 r
.19112 .32914 m .2048 .33497 L .20463 .3466 L p F P
0 g
s
.522 .196 .357 r
.5321 .39763 m .52227 .39979 L .50538 .39951 L p F P
0 g
s
.519 .189 .348 r
.52227 .39979 m .50413 .4037 L .50538 .39951 L closepath p F P
0 g
s
.424 .21 .482 r
.68788 .3488 m .68 .35304 L .67505 .36665 L p F P
0 g
s
.412 0 .137 r
.52093 .46993 m .52546 .4625 L .5411 .45906 L p F P
0 g
s
.504 .015 .028 r
.41723 .4807 m .42749 .48329 L .42378 .48629 L p F P
0 g
s
.528 .063 .093 r
.42749 .48329 m .41723 .4807 L .43045 .48039 L closepath p F P
0 g
s
.549 .06 .048 r
.38641 .48067 m .39452 .48357 L .39033 .48655 L p F P
0 g
s
.549 .06 .048 r
.36279 .47975 m .38641 .48067 L p .39033 .48655 L F P
0 g
s
.872 .606 .532 r
.11709 .34854 m .11279 .3462 L .11346 .3345 L p F P
0 g
s
.881 .614 .53 r
.10202 .32781 m .11346 .3345 L .11279 .3462 L p F P
0 g
s
.865 .578 .501 r
.13738 .37036 m .12497 .36412 L .1247 .35267 L p F P
0 g
s
.874 .587 .497 r
.11709 .34854 m .1247 .35267 L .12497 .36412 L p F P
0 g
s
.464 0 .02 r
.43045 .48039 m .45427 .47884 L p .4556 .4844 L F P
0 g
s
.464 0 .02 r
.42749 .48329 m .43045 .48039 L p .4556 .4844 L F P
0 g
s
.477 .198 .411 r
.56132 .38089 m .56289 .37087 L .58854 .36195 L p F P
0 g
s
.507 .258 .472 r
.5893 .35119 m .58854 .36195 L .56289 .37087 L p F P
0 g
s
.517 .232 .422 r
.56289 .37087 m .56132 .38089 L .53457 .3884 L p F P
0 g
s
.795 .413 .333 r
.21039 .43713 m .20561 .4356 L .20035 .42543 L p F P
0 g
s
.804 .419 .326 r
.18552 .42021 m .20035 .42543 L .20561 .4356 L p F P
0 g
s
.831 .532 .483 r
.21896 .35216 m .22013 .3626 L .21989 .36326 L p F P
0 g
s
.831 .532 .483 r
.20463 .3466 m .21896 .35216 L p .21989 .36326 L F P
0 g
s
.855 .547 .466 r
.15162 .38754 m .13867 .38154 L .13738 .37036 L p F P
0 g
s
.865 .556 .462 r
.12497 .36412 m .13738 .37036 L .13867 .38154 L p F P
0 g
s
.757 .397 .372 r
.29614 .40266 m .27761 .39863 L .27211 .3886 L p F P
0 g
s
.765 .395 .355 r
.26484 .38683 m .27211 .3886 L .27761 .39863 L p F P
0 g
s
.549 .06 .048 r
.36168 .48062 m .36279 .47975 L p .39033 .48655 L F P
0 g
s
.602 .133 .114 r
.36168 .48062 m .35931 .4795 L .36279 .47975 L closepath p F P
0 g
s
.481 .161 .347 r
.5321 .39763 m .53457 .3884 L .56132 .38089 L p F P
0 g
s
.661 .398 .512 r
.41645 .33357 m .42732 .33296 L .43019 .34383 L p F P
0 g
s
.661 .398 .512 r
.43019 .34383 m .41546 .34465 L .41645 .33357 L p F P
0 g
s
.687 .421 .515 r
.39466 .33353 m .41645 .33357 L .41546 .34465 L p F P
0 g
s
.687 .421 .515 r
.41546 .34465 m .39674 .34461 L .39466 .33353 L p F P
0 g
s
.693 .425 .513 r
.3827 .33333 m .39466 .33353 L .39674 .34461 L p F P
0 g
s
.587 .098 .06 r
.35931 .4795 m .36168 .48062 L .35492 .48491 L p F P
0 g
s
.587 .098 .06 r
.33526 .47737 m .35931 .4795 L p .35492 .48491 L F P
0 g
s
.693 .425 .513 r
.39674 .34461 m .38155 .34436 L .3827 .33333 L p F P
0 g
s
.718 .447 .516 r
.3677 .33222 m .3827 .33333 L .38155 .34436 L p F P
0 g
s
.701 .303 .291 r
.33693 .41683 m .32522 .4152 L .31631 .40613 L p F P
0 g
s
.704 .294 .267 r
.30312 .40403 m .31631 .40613 L .32522 .4152 L p F P
0 g
s
.667 .269 .282 r
.37245 .41991 m .3478 .41789 L .34072 .41215 L p F P
0 g
s
.671 .264 .266 r
.3478 .41789 m .33693 .41683 L .34072 .41215 L closepath p F P
0 g
s
.655 .394 .514 r
.42732 .33296 m .44803 .3315 L .4472 .34264 L p F P
0 g
s
.655 .394 .514 r
.4472 .34264 m .43019 .34383 L .42732 .33296 L p F P
0 g
s
.468 .226 .464 r
.58854 .36195 m .5893 .35119 L .6139 .34082 L p F P
0 g
s
.495 .28 .516 r
.6139 .32934 m .6139 .34082 L .5893 .35119 L p F P
0 g
s
.843 .512 .427 r
.16757 .40418 m .15402 .39844 L .15162 .38754 L p F P
0 g
s
.853 .52 .422 r
.13867 .38154 m .15162 .38754 L .15402 .39844 L p F P
0 g
s
.495 .038 .095 r
.46051 .4798 m .45427 .47884 L .46187 .47829 L closepath p F P
0 g
s
.464 0 .02 r
.45427 .47884 m .46051 .4798 L .4556 .4844 L p F P
0 g
s
.718 .447 .516 r
.38155 .34436 m .36924 .34346 L .3677 .33222 L p F P
0 g
s
.723 .451 .515 r
.34624 .33032 m .3677 .33222 L .36924 .34346 L p F P
0 g
s
.825 .467 .379 r
.16844 .40679 m .17023 .40523 L p .18552 .42021 L F P
0 g
s
.829 .475 .385 r
.16844 .40679 m .16757 .40418 L .17023 .40523 L closepath p F P
0 g
s
.448 0 .063 r
.46051 .4798 m .46187 .47829 L .49197 .47476 L p F P
0 g
s
.498 .074 .166 r
.49351 .47256 m .49197 .47476 L .46187 .47829 L p F P
0 g
s
.765 .395 .355 r
.25954 .39386 m .26484 .38683 L p .27761 .39863 L F P
0 g
s
.781 .42 .373 r
.25954 .39386 m .25491 .38412 L .26484 .38683 L closepath p F P
0 g
s
.445 .014 .125 r
.50684 .47231 m .49197 .47476 L .49351 .47256 L closepath p F P
0 g
s
.452 .029 .144 r
.52093 .46993 m .50684 .47231 L .49351 .47256 L p F P
0 g
s
.8 .472 .434 r
.25491 .38412 m .23873 .37925 L .23568 .36853 L p F P
0 g
s
.81 .478 .428 r
.22023 .36338 m .23568 .36853 L .23873 .37925 L p F P
0 g
s
.814 .515 .484 r
.23568 .36853 m .22023 .36338 L .22013 .3626 L p F P
0 g
s
.388 .068 .297 r
.61135 .42467 m .61913 .42031 L .61175 .4232 L closepath p F P
0 g
s
.421 .125 .355 r
.63758 .40895 m .63853 .40389 L p .61175 .4232 L F P
0 g
s
.421 .125 .355 r
.61175 .4232 m .61913 .42031 L .63758 .40895 L p F P
0 g
s
.549 .06 .048 r
.39033 .48655 m .37764 .48606 L .36168 .48062 L p F P
0 g
s
.543 .042 .016 r
.37764 .48606 m .35492 .48491 L .36168 .48062 L closepath p F P
0 g
s
.626 .37 .51 r
.44803 .3315 m .47271 .32827 L .47693 .33876 L p F P
0 g
s
.626 .37 .51 r
.47693 .33876 m .4472 .34264 L .44803 .3315 L p F P
0 g
s
.587 .098 .06 r
.35492 .48491 m .35132 .48459 L .33526 .47737 L p F P
0 g
s
.572 .063 .005 r
.32571 .47637 m .33526 .47737 L .35132 .48459 L p F P
0 g
s
.43 .029 .174 r
.55252 .45764 m .5411 .45906 L .55321 .45637 L closepath p F P
0 g
s
.412 0 .137 r
.5411 .45906 m .55252 .45764 L p .52093 .46993 L F P
0 g
s
.838 .479 .375 r
.16757 .40418 m .16844 .40679 L .16244 .41112 L p F P
0 g
s
.838 .479 .375 r
.15402 .39844 m .16757 .40418 L p .16244 .41112 L F P
0 g
s
.379 .015 .215 r
.58003 .44901 m .58337 .44072 L .60922 .43215 L p F P
0 g
s
.426 .058 .235 r
.58337 .44072 m .58003 .44901 L .55321 .45637 L p F P
0 g
s
.425 .094 .299 r
.61135 .42467 m .60922 .43215 L .58337 .44072 L p F P
0 g
s
.704 .294 .267 r
.30002 .40749 m .30312 .40403 L p .32522 .4152 L F P
0 g
s
.731 .335 .3 r
.30002 .40749 m .29614 .40266 L .30312 .40403 L closepath p F P
0 g
s
.701 .25 .179 r
.28557 .47025 m .27315 .46773 L .26306 .45886 L p F P
0 g
s
.703 .242 .154 r
.25044 .45598 m .26306 .45886 L .27315 .46773 L p F P
0 g
s
.76 .345 .263 r
.24528 .45468 m .2286 .45012 L .22139 .44048 L p F P
0 g
s
.767 .344 .245 r
.21039 .43713 m .22139 .44048 L .2286 .45012 L p F P
0 g
s
.38 .092 .346 r
.63758 .40895 m .64983 .39873 L .63853 .40389 L closepath p F P
0 g
s
.412 .149 .402 r
.66357 .38503 m .66384 .3828 L p .63853 .40389 L F P
0 g
s
.412 .149 .402 r
.63853 .40389 m .64983 .39873 L .66357 .38503 L p F P
0 g
s
.474 .101 .25 r
.50049 .4119 m .50413 .4037 L .52227 .39979 L p F P
0 g
s
.383 .177 .473 r
.7102 .33497 m .68788 .3488 L .68773 .35987 L p F P
0 g
s
.41 .222 .513 r
.70982 .32338 m .7102 .33497 L .68788 .3488 L p F P
0 g
s
.424 .21 .482 r
.67505 .36665 m .68773 .35987 L .68788 .3488 L p F P
0 g
s
.723 .451 .515 r
.36924 .34346 m .34493 .34131 L .34624 .33032 L p F P
0 g
s
.746 .472 .517 r
.34363 .32994 m .34624 .33032 L .34493 .34131 L p F P
0 g
s
.378 .054 .283 r
.60922 .43215 m .61135 .42467 L .61913 .42031 L p F P
0 g
s
.874 .587 .497 r
.11301 .35694 m .11709 .34854 L p .12497 .36412 L F P
0 g
s
.875 .587 .497 r
.11301 .35694 m .11279 .3462 L .11709 .34854 L closepath p F P
0 g
s
.401 .167 .44 r
.66384 .3828 m .66634 .38148 L .67505 .36665 L p F P
0 g
s
.397 .162 .437 r
.68773 .35987 m .67505 .36665 L .66634 .38148 L p F P
0 g
s
.572 .063 .005 r
.32092 .47914 m .32571 .47637 L p .35132 .48459 L F P
0 g
s
.628 .143 .083 r
.32092 .47914 m .31308 .47465 L .32571 .47637 L closepath p F P
0 g
s
.746 .472 .517 r
.34493 .34131 m .34478 .34129 L .34363 .32994 L p F P
0 g
s
.755 .478 .514 r
.32302 .3265 m .34363 .32994 L .34478 .34129 L p F P
0 g
s
.736 .33 .279 r
.29614 .40266 m .30002 .40749 L .29676 .41054 L p F P
0 g
s
.736 .33 .279 r
.27761 .39863 m .29614 .40266 L p .29676 .41054 L F P
0 g
s
.457 .249 .509 r
.6139 .34082 m .6139 .32934 L .63749 .31744 L p F P
0 g
s
.79 .424 .363 r
.25491 .38412 m .25954 .39386 L .25926 .39418 L p F P
0 g
s
.79 .424 .363 r
.23873 .37925 m .25491 .38412 L p .25926 .39418 L F P
0 g
s
.538 .089 .133 r
.40803 .42069 m .43514 .41969 L p .43486 .42611 L F P
0 g
s
.538 .089 .133 r
.40627 .42285 m .40803 .42069 L p .43486 .42611 L F P
0 g
s
.594 .164 .195 r
.40627 .42285 m .40118 .42062 L .40803 .42069 L closepath p F P
0 g
s
.448 0 .063 r
.49197 .47476 m .4864 .48075 L .46051 .4798 L p F P
0 g
s
.417 0 0 r
.4556 .4844 m .46051 .4798 L .4864 .48075 L p F P
0 g
s
.583 .132 .146 r
.40118 .42062 m .40627 .42285 L .40205 .4271 L p F P
0 g
s
.583 .132 .146 r
.37375 .41999 m .40118 .42062 L p .40205 .4271 L F P
0 g
s
.842 .569 .526 r
.20463 .3466 m .1909 .34078 L .19112 .32914 L p F P
0 g
s
.852 .579 .524 r
.178 .32306 m .19112 .32914 L .1909 .34078 L p F P
0 g
s
.504 .015 .028 r
.42378 .48629 m .40729 .48651 L .39452 .48357 L p F P
0 g
s
.496 0 0 r
.40729 .48651 m .39033 .48655 L .39452 .48357 L closepath p F P
0 g
s
.825 .467 .379 r
.18552 .42021 m .17124 .41475 L .16844 .40679 L p F P
0 g
s
.834 .472 .369 r
.17124 .41475 m .16244 .41112 L .16844 .40679 L closepath p F P
0 g
s
.378 .054 .283 r
.61913 .42031 m .6367 .41342 L p .60922 .43215 L F P
0 g
s
.418 .122 .352 r
.61913 .42031 m .6367 .41342 L .63758 .40895 L closepath p F P
0 g
s
.804 .419 .326 r
.20561 .4356 m .19063 .43041 L .18552 .42021 L p F P
0 g
s
.813 .424 .317 r
.17124 .41475 m .18552 .42021 L .19063 .43041 L p F P
0 g
s
.583 .132 .146 r
.37335 .42044 m .37375 .41999 L p .40205 .4271 L F P
0 g
s
.633 .202 .206 r
.37335 .42044 m .37245 .41991 L .37375 .41999 L closepath p F P
0 g
s
.623 .17 .156 r
.37245 .41991 m .37335 .42044 L .36718 .42601 L p F P
0 g
s
.623 .17 .156 r
.3478 .41789 m .37245 .41991 L p .36718 .42601 L F P
0 g
s
.667 .211 .158 r
.31308 .47465 m .29239 .47143 L .28844 .46857 L p F P
0 g
s
.669 .202 .135 r
.29239 .47143 m .28557 .47025 L .28844 .46857 L closepath p F P
0 g
s
.352 0 0 r
.49197 .47476 m .50684 .47231 L p .51525 .47629 L F P
0 g
s
.352 0 0 r
.4864 .48075 m .49197 .47476 L p .51525 .47629 L F P
0 g
s
.464 0 .02 r
.4556 .4844 m .44256 .48525 L .42749 .48329 L p F P
0 g
s
.453 0 0 r
.44256 .48525 m .42378 .48629 L .42749 .48329 L closepath p F P
0 g
s
.831 .532 .483 r
.21989 .36326 m .20583 .35784 L .20463 .3466 L p F P
0 g
s
.842 .541 .479 r
.1909 .34078 m .20463 .3466 L .20583 .35784 L p F P
0 g
s
.622 .368 .512 r
.47271 .32827 m .47793 .32752 L .47724 .33872 L p F P
0 g
s
.622 .368 .512 r
.47724 .33872 m .47693 .33876 L .47271 .32827 L p F P
0 g
s
.381 0 .149 r
.55252 .45764 m .55321 .45637 L .58003 .44901 L p F P
0 g
s
.62 .12 .041 r
.31308 .47465 m .32092 .47914 L .31691 .48088 L p F P
0 g
s
.62 .12 .041 r
.29239 .47143 m .31308 .47465 L p .31691 .48088 L F P
0 g
s
.557 .133 .193 r
.43932 .42094 m .43514 .41969 L .44039 .41944 L closepath p F P
0 g
s
.538 .089 .133 r
.43514 .41969 m .43932 .42094 L .43486 .42611 L p F P
0 g
s
.516 .137 .261 r
.50049 .4119 m .4816 .41488 L .4724 .41399 L p F P
0 g
s
.512 .124 .242 r
.4816 .41488 m .47114 .41646 L .4724 .41399 L closepath p F P
0 g
s
.559 .178 .275 r
.4724 .41399 m .47114 .41646 L .44039 .41944 L p F P
0 g
s
.497 .057 .133 r
.44039 .41944 m .47114 .41646 L .46598 .42335 L p F P
0 g
s
.497 .057 .133 r
.43932 .42094 m .44039 .41944 L p .46598 .42335 L F P
0 g
s
.884 .595 .494 r
.11279 .3462 m .11301 .35694 L .1127 .35748 L p F P
0 g
s
.884 .595 .494 r
.1013 .33953 m .11279 .3462 L p .1127 .35748 L F P
0 g
s
.881 .614 .53 r
.11279 .3462 m .1013 .33953 L .10202 .32781 L p F P
0 g
s
.371 .115 .391 r
.66357 .38503 m .66634 .38148 L .66384 .3828 L closepath p F P
0 g
s
.703 .242 .154 r
.24786 .45736 m .25044 .45598 L p .27315 .46773 L F P
0 g
s
.73 .284 .194 r
.24786 .45736 m .24528 .45468 L .25044 .45598 L closepath p F P
0 g
s
.89 .623 .527 r
.091 .32091 m .10202 .32781 L .1013 .33953 L p F P
0 g
s
.583 .132 .146 r
.40205 .4271 m .38884 .42679 L .37335 .42044 L p F P
0 g
s
.58 .118 .12 r
.38884 .42679 m .36718 .42601 L .37335 .42044 L closepath p F P
0 g
s
.589 .34 .508 r
.47724 .33872 m .47793 .32752 L .50619 .32159 L p F P
0 g
s
.865 .556 .462 r
.13867 .38154 m .1262 .37533 L .12497 .36412 L p F P
0 g
s
.875 .564 .458 r
.11302 .35767 m .12497 .36412 L .1262 .37533 L p F P
0 g
s
.874 .587 .497 r
.12497 .36412 m .11302 .35767 L .11301 .35694 L p F P
0 g
s
.767 .344 .245 r
.20764 .43866 m .21039 .43713 L p .2286 .45012 L F P
0 g
s
.781 .368 .267 r
.20764 .43866 m .20561 .4356 L .21039 .43713 L closepath p F P
0 g
s
.824 .522 .48 r
.22023 .36338 m .21989 .36326 L .22013 .3626 L closepath p F P
0 g
s
.81 .478 .428 r
.23873 .37925 m .2232 .37412 L .22023 .36338 L p F P
0 g
s
.82 .484 .42 r
.21989 .36326 m .22023 .36338 L .2232 .37412 L p F P
0 g
s
.82 .484 .42 r
.2232 .37412 m .21462 .37104 L .21989 .36326 L p F P
0 g
s
.829 .497 .426 r
.20583 .35784 m .21989 .36326 L .21462 .37104 L p F P
0 g
s
.853 .52 .422 r
.15402 .39844 m .14098 .39247 L .13867 .38154 L p F P
0 g
s
.863 .528 .416 r
.1262 .37533 m .13867 .38154 L .14098 .39247 L p F P
0 g
s
.366 .11 .387 r
.66634 .38148 m .68708 .37043 L p .66262 .39285 L F P
0 g
s
.366 .11 .387 r
.66262 .39285 m .66357 .38503 L .66634 .38148 L p F P
0 g
s
.397 .162 .437 r
.66634 .38148 m .68708 .37043 L .68773 .35987 L p F P
0 g
s
.474 .101 .25 r
.52227 .39979 m .53147 .39927 L p .50049 .4119 L F P
0 g
s
.485 .124 .278 r
.53147 .39927 m .52227 .39979 L .5321 .39763 L closepath p F P
0 g
s
.755 .478 .514 r
.34478 .34129 m .32415 .33784 L .32302 .3265 L p F P
0 g
s
.76 .482 .513 r
.30577 .32336 m .32302 .3265 L .32415 .33784 L p F P
0 g
s
.73 .271 .162 r
.24528 .45468 m .24786 .45736 L .24094 .46019 L p F P
0 g
s
.73 .271 .162 r
.2286 .45012 m .24528 .45468 L p .24094 .46019 L F P
0 g
s
.381 0 .149 r
.58003 .44901 m .57886 .45124 L .55252 .45764 L p F P
0 g
s
.359 0 .108 r
.54884 .46382 m .55252 .45764 L .57886 .45124 L p F P
0 g
s
.412 0 .137 r
.55252 .45764 m .54884 .46382 L .52093 .46993 L p F P
0 g
s
.636 .321 .421 r
.41546 .34465 m .43019 .34383 L .43932 .35276 L p F P
0 g
s
.636 .321 .421 r
.43932 .35276 m .41295 .35423 L .41546 .34465 L p F P
0 g
s
.667 .352 .43 r
.39674 .34461 m .41546 .34465 L .41295 .35423 L p F P
0 g
s
.623 .17 .156 r
.36718 .42601 m .36161 .42555 L .3478 .41789 L p F P
0 g
s
.611 .135 .1 r
.33693 .41683 m .3478 .41789 L .36161 .42555 L p F P
0 g
s
.667 .352 .43 r
.41295 .35423 m .40367 .35421 L .39674 .34461 L p F P
0 g
s
.673 .353 .424 r
.38155 .34436 m .39674 .34461 L .40367 .35421 L p F P
0 g
s
.673 .353 .424 r
.40367 .35421 m .37878 .3538 L .38155 .34436 L p F P
0 g
s
.703 .383 .433 r
.36924 .34346 m .38155 .34436 L .37878 .3538 L p F P
0 g
s
.409 .145 .399 r
.64983 .39873 m .66262 .39285 L .66357 .38503 L closepath p F P
0 g
s
.372 .083 .337 r
.6367 .41342 m .63758 .40895 L .64983 .39873 L p F P
0 g
s
.435 .12 .331 r
.55897 .39013 m .56132 .38089 L .58707 .37198 L p F P
0 g
s
.477 .198 .411 r
.58854 .36195 m .58707 .37198 L .56132 .38089 L p F P
0 g
s
.481 .161 .347 r
.56132 .38089 m .55897 .39013 L .5321 .39763 L p F P
0 g
s
.408 0 .059 r
.51955 .47167 m .50684 .47231 L .52093 .46993 L closepath p F P
0 g
s
.352 0 0 r
.50684 .47231 m .51955 .47167 L .51525 .47629 L p F P
0 g
s
.786 .364 .246 r
.20561 .4356 m .20764 .43866 L .20095 .44152 L p F P
0 g
s
.786 .364 .246 r
.19063 .43041 m .20561 .4356 L p .20095 .44152 L F P
0 g
s
.631 .322 .429 r
.43019 .34383 m .4472 .34264 L .44496 .35236 L p F P
0 g
s
.631 .322 .429 r
.44496 .35236 m .43932 .35276 L .43019 .34383 L p F P
0 g
s
.497 .057 .133 r
.46598 .42335 m .46058 .42387 L .43932 .42094 L p F P
0 g
s
.489 .036 .102 r
.46058 .42387 m .43486 .42611 L .43932 .42094 L closepath p F P
0 g
s
.372 .083 .337 r
.64983 .39873 m .66262 .39285 L p .6367 .41342 L F P
0 g
s
.538 .089 .133 r
.43486 .42611 m .42051 .42664 L .40627 .42285 L p F P
0 g
s
.532 .071 .104 r
.42051 .42664 m .40205 .4271 L .40627 .42285 L closepath p F P
0 g
s
.736 .33 .279 r
.29676 .41054 m .28529 .40805 L .27761 .39863 L p F P
0 g
s
.743 .329 .263 r
.2598 .39433 m .27761 .39863 L .28529 .40805 L p F P
0 g
s
.765 .395 .355 r
.27761 .39863 m .2598 .39433 L .25954 .39386 L p F P
0 g
s
.432 .16 .399 r
.58707 .37198 m .58854 .36195 L .61323 .35159 L p F P
0 g
s
.468 .226 .464 r
.6139 .34082 m .61323 .35159 L .58854 .36195 L p F P
0 g
s
.611 .135 .1 r
.33249 .42044 m .33693 .41683 L p .36161 .42555 L F P
0 g
s
.664 .215 .176 r
.33249 .42044 m .32522 .4152 L .33693 .41683 L closepath p F P
0 g
s
.703 .383 .433 r
.37878 .3538 m .3747 .3535 L .36924 .34346 L p F P
0 g
s
.709 .38 .419 r
.34493 .34131 m .36924 .34346 L .3747 .3535 L p F P
0 g
s
.838 .479 .375 r
.16244 .41112 m .15753 .40905 L .15402 .39844 L p F P
0 g
s
.847 .485 .368 r
.14098 .39247 m .15402 .39844 L .15753 .40905 L p F P
0 g
s
.447 .006 .107 r
.46598 .42335 m .47114 .41646 L .4816 .41488 L p F P
0 g
s
.704 .294 .267 r
.32522 .4152 m .30444 .4119 L .30002 .40749 L p F P
0 g
s
.709 .29 .25 r
.30444 .4119 m .29676 .41054 L .30002 .40749 L closepath p F P
0 g
s
.62 .12 .041 r
.31691 .48088 m .3063 .47925 L .29239 .47143 L p F P
0 g
s
.604 .084 0 r
.28557 .47025 m .29239 .47143 L .3063 .47925 L p F P
0 g
s
.596 .289 .419 r
.44496 .35236 m .4472 .34264 L .47693 .33876 L p F P
0 g
s
.437 .079 .258 r
.53147 .39927 m .5321 .39763 L .55897 .39013 L p F P
0 g
s
.79 .424 .363 r
.25926 .39418 m .24351 .38949 L .23873 .37925 L p F P
0 g
s
.8 .428 .353 r
.2232 .37412 m .23873 .37925 L .24351 .38949 L p F P
0 g
s
.703 .242 .154 r
.27315 .46773 m .255 .46365 L .24786 .45736 L p F P
0 g
s
.706 .235 .129 r
.255 .46365 m .24094 .46019 L .24786 .45736 L closepath p F P
0 g
s
.604 .084 0 r
.28005 .47248 m .28557 .47025 L p .3063 .47925 L F P
0 g
s
.658 .165 .066 r
.28005 .47248 m .27315 .46773 L .28557 .47025 L closepath p F P
0 g
s
.661 .194 .135 r
.32522 .4152 m .33249 .42044 L .32955 .42227 L p F P
0 g
s
.661 .194 .135 r
.30444 .4119 m .32522 .4152 L p .32955 .42227 L F P
0 g
s
.371 .192 .505 r
.71344 .32081 m .70982 .32338 L .7102 .33497 L p F P
0 g
s
.76 .482 .513 r
.32415 .33784 m .30418 .33422 L .30577 .32336 L p F P
0 g
s
.781 .503 .514 r
.30322 .32275 m .30577 .32336 L .30418 .33422 L p F P
0 g
s
.352 .127 .426 r
.70987 .34618 m .68773 .35987 L .68708 .37043 L p F P
0 g
s
.383 .177 .473 r
.71011 .34533 m .7102 .33497 L p .68773 .35987 L F P
0 g
s
.383 .177 .473 r
.68773 .35987 m .70987 .34618 L .71011 .34533 L p F P
0 g
s
.352 0 .026 r
.51955 .47167 m .52093 .46993 L .54884 .46382 L p F P
0 g
s
.465 .044 .154 r
.49838 .41522 m .4816 .41488 L .50049 .4119 L closepath p F P
0 g
s
.447 .006 .107 r
.4816 .41488 m .49838 .41522 L p .46598 .42335 L F P
0 g
s
.852 .579 .524 r
.1909 .34078 m .17773 .33472 L .178 .32306 L p F P
0 g
s
.862 .588 .522 r
.16541 .31673 m .178 .32306 L .17773 .33472 L p F P
0 g
s
.813 .424 .317 r
.19063 .43041 m .17622 .42498 L .17124 .41475 L p F P
0 g
s
.822 .427 .303 r
.16244 .41112 m .17124 .41475 L .17622 .42498 L p F P
0 g
s
.709 .38 .419 r
.34487 .34151 m .34493 .34131 L p .3747 .3535 L F P
0 g
s
.735 .416 .44 r
.34487 .34151 m .34478 .34129 L .34493 .34131 L closepath p F P
0 g
s
.744 .414 .425 r
.34478 .34129 m .34487 .34151 L .34158 .35033 L p F P
0 g
s
.744 .414 .425 r
.32415 .33784 m .34478 .34129 L p .34158 .35033 L F P
0 g
s
.767 .344 .245 r
.2286 .45012 m .21256 .44531 L .20764 .43866 L p F P
0 g
s
.773 .342 .226 r
.21256 .44531 m .20095 .44152 L .20764 .43866 L closepath p F P
0 g
s
.709 .38 .419 r
.3747 .3535 m .35038 .35126 L .34487 .34151 L p F P
0 g
s
.714 .382 .414 r
.35038 .35126 m .34158 .35033 L .34487 .34151 L closepath p F P
0 g
s
.781 .503 .514 r
.30418 .33422 m .30403 .33418 L .30322 .32275 L p F P
0 g
s
.792 .51 .511 r
.28592 .31813 m .30322 .32275 L .30403 .33418 L p F P
0 g
s
.424 .191 .454 r
.61323 .35159 m .6139 .34082 L .63756 .32894 L p F P
0 g
s
.457 .249 .509 r
.63749 .31744 m .63756 .32894 L .6139 .34082 L p F P
0 g
s
.842 .541 .479 r
.20583 .35784 m .19204 .35204 L .1909 .34078 L p F P
0 g
s
.853 .55 .475 r
.17773 .33472 m .1909 .34078 L .19204 .35204 L p F P
0 g
s
.437 .079 .258 r
.55897 .39013 m .55778 .39329 L .53147 .39927 L p F P
0 g
s
.421 .049 .224 r
.52862 .40586 m .53147 .39927 L .55778 .39329 L p F P
0 g
s
.474 .101 .25 r
.53147 .39927 m .52862 .40586 L .50049 .4119 L p F P
0 g
s
.316 0 .175 r
.63424 .42234 m .60922 .43215 L .60598 .44043 L p F P
0 g
s
.379 .015 .215 r
.60922 .43215 m .60598 .44043 L .58003 .44901 L p F P
0 g
s
.378 .054 .283 r
.6367 .41342 m .63424 .42234 L .60922 .43215 L p F P
0 g
s
.572 .063 .005 r
.35132 .48459 m .32799 .48219 L .32092 .47914 L p F P
0 g
s
.566 .046 0 r
.32799 .48219 m .31691 .48088 L .32092 .47914 L closepath p F P
0 g
s
.329 .011 .264 r
.63424 .42234 m .6367 .41342 L .66085 .40234 L p F P
0 g
s
.372 .083 .337 r
.66262 .39285 m .66085 .40234 L .6367 .41342 L p F P
0 g
s
.73 .271 .162 r
.24094 .46019 m .23763 .45929 L .2286 .45012 L p F P
0 g
s
.735 .27 .146 r
.21256 .44531 m .2286 .45012 L .23763 .45929 L p F P
0 g
s
.552 .31 .502 r
.50558 .33279 m .50619 .32159 L .53313 .31395 L p F P
0 g
s
.589 .34 .508 r
.50619 .32159 m .50558 .33279 L .47724 .33872 L p F P
0 g
s
.883 .595 .494 r
.11302 .35767 m .1127 .35748 L .11301 .35694 L closepath p F P
0 g
s
.374 0 0 r
.39033 .48655 m .40729 .48651 L p .41527 .49055 L F P
0 g
s
.374 0 0 r
.38678 .48838 m .39033 .48655 L p .41527 .49055 L F P
0 g
s
.481 0 0 r
.38678 .48838 m .37764 .48606 L .39033 .48655 L closepath p F P
0 g
s
.773 .397 .344 r
.2598 .39433 m .25926 .39418 L .25954 .39386 L closepath p F P
0 g
s
.437 0 0 r
.41995 .48857 m .40729 .48651 L .42378 .48629 L closepath p F P
0 g
s
.374 0 0 r
.40729 .48651 m .41995 .48857 L .41527 .49055 L p F P
0 g
s
.884 .595 .494 r
.1127 .35748 m .10149 .35102 L .1013 .33953 L p F P
0 g
s
.893 .604 .49 r
.09025 .33265 m .1013 .33953 L .10149 .35102 L p F P
0 g
s
.89 .623 .527 r
.1013 .33953 m .09025 .33265 L .091 .32091 L p F P
0 g
s
.839 .504 .42 r
.19204 .35204 m .20583 .35784 L .20848 .36868 L p F P
0 g
s
.829 .497 .426 r
.21462 .37104 m .20848 .36868 L .20583 .35784 L p F P
0 g
s
.326 0 0 r
.42378 .48629 m .44256 .48525 L p .44762 .48897 L F P
0 g
s
.326 0 0 r
.41995 .48857 m .42378 .48629 L p .44762 .48897 L F P
0 g
s
.875 .564 .458 r
.1262 .37533 m .11418 .3689 L .11302 .35767 L p F P
0 g
s
.884 .572 .452 r
.1127 .35748 m .11302 .35767 L .11418 .3689 L p F P
0 g
s
.9 .632 .524 r
.08039 .31379 m .091 .32091 L .09025 .33265 L p F P
0 g
s
.743 .329 .263 r
.28529 .40805 m .2674 .40376 L .2598 .39433 L p F P
0 g
s
.749 .327 .246 r
.25926 .39418 m .2598 .39433 L .2674 .40376 L p F P
0 g
s
.651 .142 .021 r
.27315 .46773 m .28005 .47248 L .27541 .47374 L p F P
0 g
s
.651 .142 .021 r
.255 .46365 m .27315 .46773 L p .27541 .47374 L F P
0 g
s
.371 .192 .505 r
.7102 .33497 m .71287 .33308 L .71344 .32081 L p F P
0 g
s
.362 .186 .503 r
.7312 .3079 m .71344 .32081 L .71287 .33308 L p F P
0 g
s
.434 0 0 r
.37764 .48606 m .38678 .48838 L .38114 .49037 L p F P
0 g
s
.434 0 0 r
.35492 .48491 m .37764 .48606 L p .38114 .49037 L F P
0 g
s
.884 .572 .452 r
.11418 .3689 m .10528 .36381 L .1127 .35748 L p F P
0 g
s
.885 .572 .452 r
.10149 .35102 m .1127 .35748 L .10528 .36381 L p F P
0 g
s
.749 .327 .246 r
.2674 .40376 m .25145 .39956 L .25926 .39418 L p F P
0 g
s
.771 .358 .268 r
.24351 .38949 m .25926 .39418 L .25145 .39956 L p F P
0 g
s
.325 0 .12 r
.57886 .45124 m .58003 .44901 L .60598 .44043 L p F P
0 g
s
.595 .295 .431 r
.4772 .33892 m .47693 .33876 L .47724 .33872 L closepath p F P
0 g
s
.596 .289 .419 r
.47693 .33876 m .4772 .33892 L p .44496 .35236 L F P
0 g
s
.553 .255 .416 r
.47724 .33872 m .50558 .33279 L .50369 .34265 L p F P
0 g
s
.553 .255 .416 r
.4772 .33892 m .47724 .33872 L p .50369 .34265 L F P
0 g
s
.863 .528 .416 r
.14098 .39247 m .12843 .38628 L .1262 .37533 L p F P
0 g
s
.873 .536 .41 r
.11418 .3689 m .1262 .37533 L .12843 .38628 L p F P
0 g
s
.786 .364 .246 r
.20095 .44152 m .1972 .44023 L .19063 .43041 L p F P
0 g
s
.794 .367 .235 r
.17622 .42498 m .19063 .43041 L .1972 .44023 L p F P
0 g
s
.553 .255 .416 r
.50369 .34265 m .49881 .34367 L .4772 .33892 L p F P
0 g
s
.553 .246 .402 r
.49881 .34367 m .47506 .34838 L .4772 .33892 L closepath p F P
0 g
s
.596 .289 .419 r
.4772 .33892 m .47506 .34838 L .44496 .35236 L p F P
0 g
s
.661 .194 .135 r
.32955 .42227 m .31621 .42015 L .30444 .4119 L p F P
0 g
s
.649 .16 .077 r
.29676 .41054 m .30444 .4119 L .31621 .42015 L p F P
0 g
s
.41 0 .123 r
.49838 .41522 m .50049 .4119 L .52862 .40586 L p F P
0 g
s
.314 0 0 r
.51525 .47629 m .51955 .47167 L .54585 .4676 L p F P
0 g
s
.352 0 .026 r
.54884 .46382 m .54585 .4676 L .51955 .47167 L p F P
0 g
s
.326 0 0 r
.44256 .48525 m .45318 .4861 L .44762 .48897 L p F P
0 g
s
.4 0 0 r
.45318 .4861 m .44256 .48525 L .4556 .4844 L closepath p F P
0 g
s
.434 0 0 r
.35374 .48545 m .35492 .48491 L p .38114 .49037 L F P
0 g
s
.53 .002 0 r
.35374 .48545 m .35132 .48459 L .35492 .48491 L closepath p F P
0 g
s
.744 .414 .425 r
.34158 .35033 m .32861 .34816 L .32415 .33784 L p F P
0 g
s
.75 .412 .412 r
.30418 .33422 m .32415 .33784 L .32861 .34816 L p F P
0 g
s
.319 .036 .316 r
.68592 .38045 m .66262 .39285 L .66085 .40234 L p F P
0 g
s
.366 .11 .387 r
.68708 .37043 m .68592 .38045 L .66262 .39285 L p F P
0 g
s
.822 .427 .303 r
.15912 .4126 m .16244 .41112 L p .17622 .42498 L F P
0 g
s
.829 .44 .315 r
.15912 .4126 m .15753 .40905 L .16244 .41112 L closepath p F P
0 g
s
.489 0 0 r
.35132 .48459 m .35374 .48545 L .34578 .48793 L p F P
0 g
s
.489 0 0 r
.34578 .48793 m .32799 .48219 L .35132 .48459 L p F P
0 g
s
.339 0 0 r
.45318 .4861 m .4556 .4844 L .48605 .48106 L p F P
0 g
s
.417 0 0 r
.4864 .48075 m .48605 .48106 L .4556 .4844 L p F P
0 g
s
.8 .428 .353 r
.24351 .38949 m .2279 .38438 L .2232 .37412 L p F P
0 g
s
.809 .429 .337 r
.21462 .37104 m .2232 .37412 L .2279 .38438 L p F P
0 g
s
.847 .485 .368 r
.15753 .40905 m .1444 .40311 L .14098 .39247 L p F P
0 g
s
.857 .492 .36 r
.12843 .38628 m .14098 .39247 L .1444 .40311 L p F P
0 g
s
.649 .16 .077 r
.29157 .41357 m .29676 .41054 L p .31621 .42015 L F P
0 g
s
.7 .242 .16 r
.29157 .41357 m .28529 .40805 L .29676 .41054 L closepath p F P
0 g
s
.792 .51 .511 r
.30403 .33418 m .28671 .32956 L .28592 .31813 L p F P
0 g
s
.8 .516 .508 r
.26919 .31327 m .28592 .31813 L .28671 .32956 L p F P
0 g
s
.434 0 0 r
.38114 .49037 m .37379 .48999 L .35374 .48545 L p F P
0 g
s
.42 0 0 r
.37379 .48999 m .35374 .48545 L .34578 .48793 L p F P
0 g
s
.573 .174 .248 r
.41295 .35423 m .43932 .35276 L p .44083 .36018 L F P
0 g
s
.573 .174 .248 r
.41059 .35878 m .41295 .35423 L p .44083 .36018 L F P
0 g
s
.631 .253 .308 r
.41059 .35878 m .40367 .35421 L .41295 .35423 L closepath p F P
0 g
s
.414 .217 .501 r
.64535 .31277 m .63749 .31744 L .63756 .32894 L p F P
0 g
s
.622 .217 .254 r
.40367 .35421 m .41059 .35878 L .40852 .36189 L p F P
0 g
s
.622 .217 .254 r
.37878 .3538 m .40367 .35421 L p .40852 .36189 L F P
0 g
s
.325 0 .12 r
.60598 .44043 m .60534 .4417 L .57886 .45124 L p F P
0 g
s
.297 0 .073 r
.57581 .45647 m .57886 .45124 L .60534 .4417 L p F P
0 g
s
.359 0 .108 r
.57886 .45124 m .57581 .45647 L .54884 .46382 L p F P
0 g
s
.836 .441 .299 r
.15753 .40905 m .15912 .4126 L .15202 .41479 L p F P
0 g
s
.836 .441 .299 r
.1444 .40311 m .15753 .40905 L p .15202 .41479 L F P
0 g
s
.622 .217 .254 r
.37747 .35607 m .37878 .3538 L p .40852 .36189 L F P
0 g
s
.673 .293 .318 r
.37747 .35607 m .3747 .3535 L .37878 .3538 L closepath p F P
0 g
s
.611 .135 .1 r
.36161 .42555 m .33781 .42321 L .33249 .42044 L p F P
0 g
s
.609 .122 .073 r
.33781 .42321 m .32955 .42227 L .33249 .42044 L closepath p F P
0 g
s
.381 .07 .309 r
.61184 .36161 m .58707 .37198 L .58481 .38121 L p F P
0 g
s
.432 .16 .399 r
.61323 .35159 m .61184 .36161 L .58707 .37198 L p F P
0 g
s
.435 .12 .331 r
.58707 .37198 m .58481 .38121 L .55897 .39013 L p F P
0 g
s
.862 .588 .522 r
.17773 .33472 m .1651 .32841 L .16541 .31673 L p F P
0 g
s
.873 .598 .519 r
.16239 .31509 m .16541 .31673 L .1651 .32841 L p F P
0 g
s
.391 0 0 r
.40205 .4271 m .42051 .42664 L p .42734 .43091 L F P
0 g
s
.391 0 0 r
.39854 .42944 m .40205 .4271 L p .42734 .43091 L F P
0 g
s
.507 0 0 r
.39854 .42944 m .38884 .42679 L .40205 .4271 L closepath p F P
0 g
s
.671 .267 .271 r
.3747 .3535 m .37747 .35607 L .37378 .36106 L p F P
0 g
s
.671 .267 .271 r
.35038 .35126 m .3747 .3535 L p .37378 .36106 L F P
0 g
s
.284 0 0 r
.54585 .4676 m .54884 .46382 L .57581 .45647 L p F P
0 g
s
.444 0 0 r
.32799 .48219 m .34578 .48793 L .3448 .48809 L p F P
0 g
s
.444 0 0 r
.31691 .48088 m .32799 .48219 L p .3448 .48809 L F P
0 g
s
.34 .144 .462 r
.71011 .34533 m .71287 .33308 L .7102 .33497 L closepath p F P
0 g
s
.382 .027 .233 r
.55778 .39329 m .55897 .39013 L .58481 .38121 L p F P
0 g
s
.735 .27 .146 r
.23763 .45929 m .22143 .45451 L .21256 .44531 L p F P
0 g
s
.739 .264 .119 r
.20095 .44152 m .21256 .44531 L .22143 .45451 L p F P
0 g
s
.651 .142 .021 r
.27541 .47374 m .26727 .47193 L .255 .46365 L p F P
0 g
s
.646 .125 0 r
.24094 .46019 m .255 .46365 L .26727 .47193 L p F P
0 g
s
.454 0 0 r
.38884 .42679 m .39854 .42944 L .39392 .4315 L p F P
0 g
s
.454 0 0 r
.36718 .42601 m .38884 .42679 L p .39392 .4315 L F P
0 g
s
.853 .55 .475 r
.19204 .35204 m .17882 .34599 L .17773 .33472 L p F P
0 g
s
.864 .559 .47 r
.1651 .32841 m .17773 .33472 L .17882 .34599 L p F P
0 g
s
.461 0 0 r
.4318 .42848 m .42051 .42664 L .43486 .42611 L closepath p F P
0 g
s
.391 0 0 r
.42051 .42664 m .4318 .42848 L .42734 .43091 L p F P
0 g
s
.352 0 0 r
.51525 .47629 m .48926 .48055 L .4864 .48075 L p F P
0 g
s
.334 0 0 r
.48926 .48055 m .48605 .48106 L .4864 .48075 L closepath p F P
0 g
s
.698 .223 .118 r
.28529 .40805 m .29157 .41357 L .28811 .415 L p F P
0 g
s
.698 .223 .118 r
.2674 .40376 m .28529 .40805 L p .28811 .415 L F P
0 g
s
.59 .221 .31 r
.44388 .35478 m .43932 .35276 L .44496 .35236 L closepath p F P
0 g
s
.573 .174 .248 r
.43932 .35276 m .44388 .35478 L .44083 .36018 L p F P
0 g
s
.771 .358 .268 r
.25145 .39956 m .25022 .39919 L .24351 .38949 L p F P
0 g
s
.778 .358 .25 r
.2279 .38438 m .24351 .38949 L .25022 .39919 L p F P
0 g
s
.809 .429 .337 r
.21072 .3743 m .21462 .37104 L p .2279 .38438 L F P
0 g
s
.821 .452 .356 r
.21072 .3743 m .20848 .36868 L .21462 .37104 L closepath p F P
0 g
s
.75 .412 .412 r
.3041 .33441 m .30418 .33422 L p .32861 .34816 L F P
0 g
s
.774 .448 .434 r
.3041 .33441 m .30403 .33418 L .30418 .33422 L closepath p F P
0 g
s
.784 .449 .419 r
.30403 .33418 m .3041 .33441 L .30014 .34273 L p F P
0 g
s
.784 .449 .419 r
.28671 .32956 m .30403 .33418 L p .30014 .34273 L F P
0 g
s
.345 0 0 r
.43486 .42611 m .46058 .42387 L p .45893 .42841 L F P
0 g
s
.345 0 0 r
.4318 .42848 m .43486 .42611 L p .45893 .42841 L F P
0 g
s
.75 .412 .412 r
.32861 .34816 m .3086 .34445 L .3041 .33441 L p F P
0 g
s
.756 .415 .406 r
.3086 .34445 m .30014 .34273 L .3041 .33441 L closepath p F P
0 g
s
.454 0 0 r
.36539 .42705 m .36718 .42601 L p .39392 .4315 L F P
0 g
s
.56 .053 .008 r
.36539 .42705 m .36161 .42555 L .36718 .42601 L closepath p F P
0 g
s
.531 .149 .261 r
.44496 .35236 m .47506 .34838 L .47128 .35643 L p F P
0 g
s
.531 .149 .261 r
.44388 .35478 m .44496 .35236 L p .47128 .35643 L F P
0 g
s
.177 0 0 r
.48605 .48106 m .48926 .48055 L p .508 .48119 L F P
0 g
s
.177 0 0 r
.47921 .4855 m .48605 .48106 L p .508 .48119 L F P
0 g
s
.339 0 0 r
.48605 .48106 m .47921 .4855 L .45318 .4861 L p F P
0 g
s
.839 .504 .42 r
.20848 .36868 m .19463 .3629 L .19204 .35204 L p F P
0 g
s
.85 .512 .412 r
.17882 .34599 m .19204 .35204 L .19463 .3629 L p F P
0 g
s
.314 .066 .369 r
.70332 .36044 m .68708 .37043 L .68592 .38045 L p F P
0 g
s
.352 .127 .426 r
.68708 .37043 m .70332 .36044 L .70987 .34618 L p F P
0 g
s
.444 0 0 r
.31276 .48207 m .31691 .48088 L p .3448 .48809 L F P
0 g
s
.551 .007 0 r
.31276 .48207 m .3063 .47925 L .31691 .48088 L closepath p F P
0 g
s
.873 .598 .519 r
.1651 .32841 m .15992 .32561 L .16239 .31509 L p F P
0 g
s
.876 .602 .519 r
.15349 .31013 m .16239 .31509 L .15992 .32561 L p F P
0 g
s
.518 0 0 r
.36161 .42555 m .36539 .42705 L .35824 .42984 L p F P
0 g
s
.518 0 0 r
.33781 .42321 m .36161 .42555 L p .35824 .42984 L F P
0 g
s
.374 0 0 r
.41527 .49055 m .40322 .49057 L .38678 .48838 L p F P
0 g
s
.354 0 0 r
.40322 .49057 m .38114 .49037 L .38678 .48838 L closepath p F P
0 g
s
.291 0 0 r
.5126 .47842 m .48926 .48055 L .51525 .47629 L closepath p F P
0 g
s
.177 0 0 r
.48926 .48055 m .5126 .47842 L .508 .48119 L p F P
0 g
s
.382 .118 .384 r
.63696 .33971 m .61323 .35159 L .61184 .36161 L p F P
0 g
s
.424 .191 .454 r
.63756 .32894 m .63696 .33971 L .61323 .35159 L p F P
0 g
s
.41 0 .123 r
.52862 .40586 m .52465 .41205 L .49838 .41522 L p F P
0 g
s
.374 0 .049 r
.49558 .41888 m .49838 .41522 L .52465 .41205 L p F P
0 g
s
.447 .006 .107 r
.49838 .41522 m .49558 .41888 L .46598 .42335 L p F P
0 g
s
.338 .142 .461 r
.71287 .33308 m .73164 .31951 L p .7101 .34604 L F P
0 g
s
.338 .142 .461 r
.7101 .34604 m .71011 .34533 L .71287 .33308 L p F P
0 g
s
.362 .186 .503 r
.71287 .33308 m .73164 .31951 L .7312 .3079 L p F P
0 g
s
.604 .084 0 r
.3063 .47925 m .2862 .47579 L .28005 .47248 L p F P
0 g
s
.599 .068 0 r
.2862 .47579 m .27541 .47374 L .28005 .47248 L closepath p F P
0 g
s
.794 .367 .235 r
.1972 .44023 m .18266 .43484 L .17622 .42498 L p F P
0 g
s
.802 .37 .22 r
.16236 .41933 m .17622 .42498 L .18266 .43484 L p F P
0 g
s
.822 .427 .303 r
.17622 .42498 m .16236 .41933 L .15912 .4126 L p F P
0 g
s
.656 .223 .208 r
.34158 .35033 m .35038 .35126 L .36058 .35982 L p F P
0 g
s
.671 .267 .271 r
.37378 .36106 m .36058 .35982 L .35038 .35126 L p F P
0 g
s
.508 .215 .403 r
.50369 .34265 m .50558 .33279 L .5326 .32516 L p F P
0 g
s
.552 .31 .502 r
.53313 .31395 m .5326 .32516 L .50558 .33279 L p F P
0 g
s
.264 0 0 r
.44762 .48897 m .45318 .4861 L .47921 .4855 L p F P
0 g
s
.893 .604 .49 r
.10149 .35102 m .09038 .34415 L .09025 .33265 L p F P
0 g
s
.903 .613 .486 r
.0796 .32555 m .09025 .33265 L .09038 .34415 L p F P
0 g
s
.9 .632 .524 r
.09025 .33265 m .0796 .32555 L .08039 .31379 L p F P
0 g
s
.885 .572 .452 r
.10528 .36381 m .1026 .36227 L .10149 .35102 L p F P
0 g
s
.894 .58 .447 r
.09038 .34415 m .10149 .35102 L .1026 .36227 L p F P
0 g
s
.83 .43 .288 r
.16236 .41933 m .15202 .41479 L .15912 .4126 L closepath p F P
0 g
s
.51 .276 .494 r
.5326 .32516 m .53313 .31395 L .55876 .30456 L p F P
0 g
s
.326 0 0 r
.44762 .48897 m .43808 .4895 L .41995 .48857 L p F P
0 g
s
.301 0 0 r
.43808 .4895 m .41527 .49055 L .41995 .48857 L closepath p F P
0 g
s
.622 .217 .254 r
.40852 .36189 m .38678 .36148 L .37747 .35607 L p F P
0 g
s
.624 .21 .237 r
.38678 .36148 m .37378 .36106 L .37747 .35607 L closepath p F P
0 g
s
.909 .642 .521 r
.07019 .30647 m .08039 .31379 L .0796 .32555 L p F P
0 g
s
.338 0 .074 r
.52465 .41205 m .52862 .40586 L .55562 .39838 L p F P
0 g
s
.421 .049 .224 r
.55778 .39329 m .55562 .39838 L .52862 .40586 L p F P
0 g
s
.873 .536 .41 r
.12843 .38628 m .11634 .37988 L .11418 .3689 L p F P
0 g
s
.882 .543 .402 r
.10528 .36381 m .11418 .3689 L .11634 .37988 L p F P
0 g
s
.656 .223 .208 r
.33633 .35689 m .34158 .35033 L p .36058 .35982 L F P
0 g
s
.714 .316 .292 r
.33633 .35689 m .32861 .34816 L .34158 .35033 L closepath p F P
0 g
s
.513 0 0 r
.3063 .47925 m .31276 .48207 L .30551 .48313 L p F P
0 g
s
.513 0 0 r
.2862 .47579 m .3063 .47925 L p .30551 .48313 L F P
0 g
s
.83 .455 .342 r
.20848 .36868 m .21072 .3743 L .207 .37673 L p F P
0 g
s
.83 .455 .342 r
.19463 .3629 m .20848 .36868 L p .207 .37673 L F P
0 g
s
.425 0 0 r
.46511 .42416 m .46058 .42387 L .46598 .42335 L closepath p F P
0 g
s
.345 0 0 r
.46058 .42387 m .46511 .42416 L .45893 .42841 L p F P
0 g
s
.807 .522 .506 r
.25857 .30993 m .26919 .31327 L .26997 .3247 L p F P
0 g
s
.8 .516 .508 r
.28671 .32956 m .26997 .3247 L .26919 .31327 L p F P
0 g
s
.414 .217 .501 r
.63756 .32894 m .64357 .32539 L .64535 .31277 L p F P
0 g
s
.408 .211 .499 r
.66005 .30385 m .64535 .31277 L .64357 .32539 L p F P
0 g
s
.359 0 0 r
.46511 .42416 m .46598 .42335 L .49558 .41888 L p F P
0 g
s
.646 .125 0 r
.23925 .46062 m .24094 .46019 L p .26727 .47193 L F P
0 g
s
.694 .198 .062 r
.23925 .46062 m .23763 .45929 L .24094 .46019 L closepath p F P
0 g
s
.382 .027 .233 r
.58481 .38121 m .58422 .38284 L .55778 .39329 L p F P
0 g
s
.358 0 .193 r
.55562 .39838 m .55778 .39329 L .58422 .38284 L p F P
0 g
s
.518 0 0 r
.35824 .42984 m .3559 .42961 L .33781 .42321 L p F P
0 g
s
.459 0 0 r
.32955 .42227 m .33781 .42321 L .3559 .42961 L p F P
0 g
s
.857 .492 .36 r
.1444 .40311 m .13176 .39695 L .12843 .38628 L p F P
0 g
s
.866 .499 .351 r
.11634 .37988 m .12843 .38628 L .13176 .39695 L p F P
0 g
s
.531 .149 .261 r
.47128 .35643 m .46082 .35782 L .44388 .35478 L p F P
0 g
s
.526 .126 .226 r
.46082 .35782 m .44083 .36018 L .44388 .35478 L closepath p F P
0 g
s
.739 .264 .119 r
.19875 .44209 m .20095 .44152 L p .22143 .45451 L F P
0 g
s
.763 .305 .163 r
.19875 .44209 m .1972 .44023 L .20095 .44152 L closepath p F P
0 g
s
.454 0 0 r
.39392 .4315 m .38263 .43107 L .36539 .42705 L p F P
0 g
s
.44 0 0 r
.38263 .43107 m .35824 .42984 L .36539 .42705 L closepath p F P
0 g
s
.683 .169 .008 r
.23763 .45929 m .23925 .46062 L .23065 .46185 L p F P
0 g
s
.683 .169 .008 r
.23065 .46185 m .22143 .45451 L .23763 .45929 L p F P
0 g
s
.269 0 .168 r
.63189 .42858 m .63424 .42234 L .65845 .41122 L p F P
0 g
s
.316 0 .175 r
.63189 .42858 m .63424 .42234 L p .60598 .44043 L F P
0 g
s
.329 .011 .264 r
.66085 .40234 m .65845 .41122 L .63424 .42234 L p F P
0 g
s
.459 0 0 r
.32433 .42419 m .32955 .42227 L p .3559 .42961 L F P
0 g
s
.585 .058 0 r
.32433 .42419 m .31621 .42015 L .32955 .42227 L closepath p F P
0 g
s
.698 .223 .118 r
.28811 .415 m .27757 .41246 L .2674 .40376 L p F P
0 g
s
.697 .207 .081 r
.25145 .39956 m .2674 .40376 L .27757 .41246 L p F P
0 g
s
.481 .1 .24 r
.47128 .35643 m .47506 .34838 L .49881 .34367 L p F P
0 g
s
.573 .174 .248 r
.44083 .36018 m .41805 .3615 L .41059 .35878 L p F P
0 g
s
.572 .159 .22 r
.41805 .3615 m .40852 .36189 L .41059 .35878 L closepath p F P
0 g
s
.316 0 .175 r
.60598 .44043 m .6169 .43615 L .63189 .42858 L p F P
0 g
s
.268 0 .094 r
.60534 .4417 m .6169 .43615 L .60598 .44043 L closepath p F P
0 g
s
.717 .297 .248 r
.32861 .34816 m .33633 .35689 L .336 .3572 L p F P
0 g
s
.717 .297 .248 r
.3086 .34445 m .32861 .34816 L p .336 .3572 L F P
0 g
s
.784 .449 .419 r
.30014 .34273 m .29034 .34012 L .28671 .32956 L p F P
0 g
s
.794 .45 .406 r
.26997 .3247 m .28671 .32956 L .29034 .34012 L p F P
0 g
s
.762 .291 .126 r
.1972 .44023 m .19875 .44209 L .18991 .44335 L p F P
0 g
s
.762 .291 .126 r
.18991 .44335 m .18266 .43484 L .1972 .44023 L p F P
0 g
s
.359 0 0 r
.49558 .41888 m .49125 .42266 L .46511 .42416 L p F P
0 g
s
.287 0 0 r
.45893 .42841 m .46511 .42416 L .49125 .42266 L p F P
0 g
s
.836 .441 .299 r
.15202 .41479 m .14903 .41345 L .1444 .40311 L p F P
0 g
s
.845 .446 .289 r
.13176 .39695 m .1444 .40311 L .14903 .41345 L p F P
0 g
s
.778 .358 .25 r
.25022 .39919 m .23454 .39409 L .2279 .38438 L p F P
0 g
s
.786 .357 .231 r
.2129 .37902 m .2279 .38438 L .23454 .39409 L p F P
0 g
s
.809 .429 .337 r
.2279 .38438 m .2129 .37902 L .21072 .3743 L p F P
0 g
s
.376 .152 .442 r
.64357 .32539 m .63756 .32894 L .63696 .33971 L p F P
0 g
s
.22 0 0 r
.5126 .47842 m .51525 .47629 L .54338 .47024 L p F P
0 g
s
.314 0 0 r
.54585 .4676 m .54338 .47024 L .51525 .47629 L p F P
0 g
s
.646 .125 0 r
.26727 .47193 m .24964 .46762 L .23925 .46062 L p F P
0 g
s
.642 .112 0 r
.24964 .46762 m .23925 .46062 L .23065 .46185 L p F P
0 g
s
.876 .602 .519 r
.15992 .32561 m .1531 .32183 L .15349 .31013 L p F P
0 g
s
.887 .612 .516 r
.14211 .30326 m .15349 .31013 L .1531 .32183 L p F P
0 g
s
.27 0 .238 r
.67966 .39233 m .66085 .40234 L .65845 .41122 L p F P
0 g
s
.319 .036 .316 r
.68472 .38704 m .68592 .38045 L p .66085 .40234 L F P
0 g
s
.319 .036 .316 r
.66085 .40234 m .67966 .39233 L .68472 .38704 L p F P
0 g
s
.391 0 0 r
.42734 .43091 m .41341 .43126 L .39854 .42944 L p F P
0 g
s
.369 0 0 r
.41341 .43126 m .39392 .4315 L .39854 .42944 L closepath p F P
0 g
s
.864 .559 .47 r
.17882 .34599 m .16614 .3397 L .1651 .32841 L p F P
0 g
s
.875 .567 .464 r
.15992 .32561 m .1651 .32841 L .16614 .3397 L p F P
0 g
s
.807 .522 .506 r
.26997 .3247 m .25646 .32048 L .25857 .30993 L p F P
0 g
s
.826 .542 .508 r
.25346 .30803 m .25857 .30993 L .25646 .32048 L p F P
0 g
s
.513 0 0 r
.30551 .48313 m .30324 .48274 L .2862 .47579 L p F P
0 g
s
.476 0 0 r
.27541 .47374 m .2862 .47579 L .30324 .48274 L p F P
0 g
s
.649 .16 .077 r
.31621 .42015 m .29611 .41657 L .29157 .41357 L p F P
0 g
s
.647 .148 .049 r
.29611 .41657 m .28811 .415 L .29157 .41357 L closepath p F P
0 g
s
.376 .171 .47 r
.70987 .34618 m .7101 .34604 L .71011 .34533 L closepath p F P
0 g
s
.345 0 0 r
.45893 .42841 m .45197 .42903 L .4318 .42848 L p F P
0 g
s
.316 0 0 r
.45197 .42903 m .42734 .43091 L .4318 .42848 L closepath p F P
0 g
s
.232 0 .044 r
.60187 .44785 m .60534 .4417 L .6169 .43615 L p F P
0 g
s
.297 0 .073 r
.60534 .4417 m .60187 .44785 L .57581 .45647 L p F P
0 g
s
.55 0 0 r
.31621 .42015 m .32433 .42419 L .31933 .42512 L p F P
0 g
s
.55 0 0 r
.29611 .41657 m .31621 .42015 L p .31933 .42512 L F P
0 g
s
.233 0 0 r
.54338 .47024 m .54585 .4676 L .57236 .4609 L p F P
0 g
s
.284 0 0 r
.57581 .45647 m .57236 .4609 L .54585 .4676 L p F P
0 g
s
.343 .118 .421 r
.7101 .34604 m .70987 .34618 L .70332 .36044 L p F P
0 g
s
.739 .264 .119 r
.22143 .45451 m .20584 .44949 L .19875 .44209 L p F P
0 g
s
.741 .257 .092 r
.20584 .44949 m .19875 .44209 L .18991 .44335 L p F P
0 g
s
.292 .078 .407 r
.73159 .33057 m .7101 .34604 L .7095 .35657 L p F P
0 g
s
.338 .142 .461 r
.73164 .31951 m .73159 .33057 L .7101 .34604 L p F P
0 g
s
.343 .118 .421 r
.70332 .36044 m .7095 .35657 L .7101 .34604 L p F P
0 g
s
.85 .512 .412 r
.19463 .3629 m .18134 .35687 L .17882 .34599 L p F P
0 g
s
.861 .519 .404 r
.16614 .3397 m .17882 .34599 L .18134 .35687 L p F P
0 g
s
.818 .432 .324 r
.2129 .37902 m .207 .37673 L .21072 .3743 L closepath p F P
0 g
s
.215 0 0 r
.57236 .4609 m .57581 .45647 L .60187 .44785 L p F P
0 g
s
.444 0 0 r
.3448 .48809 m .32499 .48573 L .31276 .48207 L p F P
0 g
s
.429 0 0 r
.32499 .48573 m .30551 .48313 L .31276 .48207 L closepath p F P
0 g
s
.809 .37 .2 r
.15202 .41479 m .16236 .41933 L .16867 .42922 L p F P
0 g
s
.802 .37 .22 r
.18266 .43484 m .16867 .42922 L .16236 .41933 L p F P
0 g
s
.882 .543 .402 r
.10306 .36471 m .10528 .36381 L p .11634 .37988 L F P
0 g
s
.883 .545 .405 r
.10306 .36471 m .1026 .36227 L .10528 .36381 L closepath p F P
0 g
s
.258 0 0 r
.49125 .42266 m .49558 .41888 L .52395 .41294 L p F P
0 g
s
.374 0 .049 r
.52465 .41205 m .52395 .41294 L .49558 .41888 L p F P
0 g
s
.826 .542 .508 r
.25646 .32048 m .25395 .31954 L .25346 .30803 L p F P
0 g
s
.838 .551 .503 r
.23928 .30221 m .25346 .30803 L .25395 .31954 L p F P
0 g
s
.319 .154 .494 r
.73614 .30381 m .7312 .3079 L .73164 .31951 L p F P
0 g
s
.717 .297 .248 r
.336 .3572 m .31711 .3535 L .3086 .34445 L p F P
0 g
s
.705 .26 .193 r
.30014 .34273 m .3086 .34445 L .31711 .3535 L p F P
0 g
s
.83 .455 .342 r
.207 .37673 m .19877 .37332 L .19463 .3629 L p F P
0 g
s
.84 .46 .33 r
.18134 .35687 m .19463 .3629 L .19877 .37332 L p F P
0 g
s
.476 0 0 r
.27168 .4743 m .27541 .47374 L p .30324 .48274 L F P
0 g
s
.583 .033 0 r
.27168 .4743 m .26727 .47193 L .27541 .47374 L closepath p F P
0 g
s
.323 0 .21 r
.58422 .38284 m .59352 .37757 L .58481 .38121 L closepath p F P
0 g
s
.381 .07 .309 r
.61068 .36659 m .61184 .36161 L p .58481 .38121 L F P
0 g
s
.381 .07 .309 r
.58481 .38121 m .59352 .37757 L .61068 .36659 L p F P
0 g
s
.894 .58 .447 r
.1026 .36227 m .09145 .35542 L .09038 .34415 L p F P
0 g
s
.903 .589 .441 r
.0797 .33708 m .09038 .34415 L .09145 .35542 L p F P
0 g
s
.903 .613 .486 r
.09038 .34415 m .0797 .33708 L .0796 .32555 L p F P
0 g
s
.697 .207 .081 r
.2508 .39982 m .25145 .39956 L p .27757 .41246 L F P
0 g
s
.74 .281 .161 r
.2508 .39982 m .25022 .39919 L .25145 .39956 L closepath p F P
0 g
s
.875 .567 .464 r
.16614 .3397 m .15449 .33345 L .15992 .32561 L p F P
0 g
s
.879 .573 .467 r
.1531 .32183 m .15992 .32561 L .15449 .33345 L p F P
0 g
s
.912 .622 .481 r
.06937 .31825 m .0796 .32555 L .0797 .33708 L p F P
0 g
s
.909 .642 .521 r
.0796 .32555 m .06937 .31825 L .07019 .30647 L p F P
0 g
s
.376 .152 .442 r
.63696 .33971 m .63738 .33946 L .64357 .32539 L p F P
0 g
s
.367 .143 .437 r
.66019 .31537 m .64357 .32539 L .63738 .33946 L p F P
0 g
s
.408 .211 .499 r
.64357 .32539 m .66019 .31537 L .66005 .30385 L p F P
0 g
s
.892 .551 .395 r
.1026 .36227 m .10306 .36471 L .09386 .36666 L p F P
0 g
s
.892 .551 .395 r
.09145 .35542 m .1026 .36227 L p .09386 .36666 L F P
0 g
s
.736 .257 .11 r
.25022 .39919 m .2508 .39982 L .24218 .40196 L p F P
0 g
s
.736 .257 .11 r
.24218 .40196 m .23454 .39409 L .25022 .39919 L p F P
0 g
s
.307 0 .163 r
.6169 .43615 m .63108 .43056 L .63189 .42858 L closepath p F P
0 g
s
.232 0 .044 r
.6169 .43615 m .63108 .43056 L p .60187 .44785 L F P
0 g
s
.481 .1 .24 r
.49881 .34367 m .50331 .34367 L p .47128 .35643 L F P
0 g
s
.497 .139 .288 r
.50331 .34367 m .49881 .34367 L .50369 .34265 L closepath p F P
0 g
s
.456 .169 .387 r
.5308 .33501 m .5326 .32516 L .55832 .31578 L p F P
0 g
s
.51 .276 .494 r
.55876 .30456 m .55832 .31578 L .5326 .32516 L p F P
0 g
s
.508 .215 .403 r
.5326 .32516 m .5308 .33501 L .50369 .34265 L p F P
0 g
s
.678 .154 0 r
.22143 .45451 m .23065 .46185 L .22852 .46191 L p F P
0 g
s
.678 .154 0 r
.20584 .44949 m .22143 .45451 L p .22852 .46191 L F P
0 g
s
.268 0 .301 r
.68472 .38704 m .69368 .37569 L .68592 .38045 L closepath p F P
0 g
s
.314 .066 .369 r
.68592 .38045 m .69368 .37569 L .70332 .36044 L p F P
0 g
s
.918 .651 .518 r
.06039 .29894 m .07019 .30647 L .06937 .31825 L p F P
0 g
s
.32 0 0 r
.40852 .36189 m .41805 .3615 L p .43402 .36531 L F P
0 g
s
.32 0 0 r
.40282 .36604 m .40852 .36189 L p .43402 .36531 L F P
0 g
s
.514 .012 .002 r
.40282 .36604 m .38678 .36148 L .40852 .36189 L closepath p F P
0 g
s
.794 .45 .406 r
.29034 .34012 m .27368 .33522 L .26997 .3247 L p F P
0 g
s
.8 .448 .391 r
.25646 .32048 m .26997 .3247 L .27368 .33522 L p F P
0 g
s
.328 .029 .296 r
.61068 .36659 m .62242 .35633 L .61184 .36161 L closepath p F P
0 g
s
.382 .118 .384 r
.6369 .34016 m .63696 .33971 L p .61184 .36161 L F P
0 g
s
.382 .118 .384 r
.61184 .36161 m .62242 .35633 L .6369 .34016 L p F P
0 g
s
.697 .207 .081 r
.27757 .41246 m .26032 .4079 L .2508 .39982 L p F P
0 g
s
.697 .199 .057 r
.26032 .4079 m .2508 .39982 L .24218 .40196 L p F P
0 g
s
.462 0 .005 r
.43632 .36421 m .41805 .3615 L .44083 .36018 L closepath p F P
0 g
s
.32 0 0 r
.41805 .3615 m .43632 .36421 L .43402 .36531 L p F P
0 g
s
.4 0 0 r
.38678 .36148 m .40282 .36604 L .40113 .36664 L p F P
0 g
s
.4 0 0 r
.37378 .36106 m .38678 .36148 L p .40113 .36664 L F P
0 g
s
.263 0 .031 r
.55114 .40546 m .55562 .39838 L .58155 .38942 L p F P
0 g
s
.358 0 .193 r
.58422 .38284 m .58155 .38942 L .55562 .39838 L p F P
0 g
s
.338 0 .074 r
.55562 .39838 m .55114 .40546 L .52465 .41205 L p F P
0 g
s
.866 .499 .351 r
.13176 .39695 m .11959 .39057 L .11634 .37988 L p F P
0 g
s
.876 .506 .341 r
.1047 .37326 m .11634 .37988 L .11959 .39057 L p F P
0 g
s
.882 .543 .402 r
.11634 .37988 m .1047 .37326 L .10306 .36471 L p F P
0 g
s
.705 .26 .193 r
.29528 .3472 m .30014 .34273 L p .31711 .3535 L F P
0 g
s
.76 .355 .285 r
.29528 .3472 m .29034 .34012 L .30014 .34273 L closepath p F P
0 g
s
.44 .085 .264 r
.50331 .34367 m .50369 .34265 L .5308 .33501 L p F P
0 g
s
.275 0 0 r
.41236 .49136 m .40322 .49057 L .41527 .49055 L closepath p F P
0 g
s
.255 0 0 r
.40322 .49057 m .41236 .49136 L p .37901 .49084 L F P
0 g
s
.255 0 0 r
.37901 .49084 m .38114 .49037 L .40322 .49057 L p F P
0 g
s
.198 0 0 r
.41236 .49136 m .41527 .49055 L .43808 .4895 L p F P
0 g
s
.55 0 0 r
.31933 .42512 m .31161 .42371 L .29611 .41657 L p F P
0 g
s
.497 0 0 r
.28811 .415 m .29611 .41657 L .31161 .42371 L p F P
0 g
s
.4 0 0 r
.36945 .36388 m .37378 .36106 L p .40113 .36664 L F P
0 g
s
.583 .087 .043 r
.36945 .36388 m .36058 .35982 L .37378 .36106 L closepath p F P
0 g
s
.547 0 0 r
.26727 .47193 m .27168 .4743 L .2633 .47452 L p F P
0 g
s
.547 0 0 r
.2633 .47452 m .24964 .46762 L .26727 .47193 L p F P
0 g
s
.331 0 0 r
.37901 .49084 m .37379 .48999 L .38114 .49037 L closepath p F P
0 g
s
.766 .288 .104 r
.18266 .43484 m .18991 .44335 L .18853 .44339 L p F P
0 g
s
.766 .288 .104 r
.16867 .42922 m .18266 .43484 L p .18853 .44339 L F P
0 g
s
.291 0 .167 r
.58155 .38942 m .58422 .38284 L .59352 .37757 L p F P
0 g
s
.892 .55 .393 r
.1047 .37326 m .09386 .36666 L .10306 .36471 L closepath p F P
0 g
s
.789 .348 .199 r
.207 .37673 m .2129 .37902 L .21949 .38874 L p F P
0 g
s
.786 .357 .231 r
.23454 .39409 m .21949 .38874 L .2129 .37902 L p F P
0 g
s
.236 0 0 r
.37379 .48999 m .37901 .49084 L .3712 .49141 L p F P
0 g
s
.236 0 0 r
.3712 .49141 m .34788 .48833 L .37379 .48999 L p F P
0 g
s
.42 0 0 r
.34578 .48793 m .34788 .48833 L .37379 .48999 L p F P
0 g
s
.303 .054 .361 r
.7095 .35657 m .70332 .36044 L .69368 .37569 L p F P
0 g
s
.297 0 0 r
.44083 .36018 m .46082 .35782 L p .46484 .36175 L F P
0 g
s
.297 0 0 r
.43632 .36421 m .44083 .36018 L p .46484 .36175 L F P
0 g
s
.22 0 0 r
.54338 .47024 m .53904 .47365 L .5126 .47842 L p F P
0 g
s
.133 0 0 r
.508 .48119 m .5126 .47842 L .53904 .47365 L p F P
0 g
s
.464 .238 .486 r
.55832 .31578 m .55876 .30456 L .58316 .29338 L p F P
0 g
s
.236 0 0 r
.44578 .48963 m .43808 .4895 L .44762 .48897 L closepath p F P
0 g
s
.198 0 0 r
.43808 .4895 m .44578 .48963 L p .41236 .49136 L F P
0 g
s
.339 0 0 r
.34788 .48833 m .3448 .48809 L .34578 .48793 L closepath p F P
0 g
s
.845 .446 .289 r
.14903 .41345 m .13629 .40731 L .13176 .39695 L p F P
0 g
s
.853 .451 .276 r
.11959 .39057 m .13176 .39695 L .13629 .40731 L p F P
0 g
s
.44 .085 .264 r
.5308 .33501 m .52971 .33796 L .50331 .34367 L p F P
0 g
s
.407 .023 .194 r
.49999 .35064 m .50331 .34367 L .52971 .33796 L p F P
0 g
s
.481 .1 .24 r
.50331 .34367 m .49999 .35064 L .47128 .35643 L p F P
0 g
s
.52 0 0 r
.36058 .35982 m .36945 .36388 L .36551 .36513 L p F P
0 g
s
.52 0 0 r
.33691 .35731 m .36058 .35982 L p .36551 .36513 L F P
0 g
s
.656 .223 .208 r
.36058 .35982 m .33691 .35731 L .33633 .35689 L p F P
0 g
s
.497 0 0 r
.2832 .41598 m .28811 .415 L p .31161 .42371 L F P
0 g
s
.624 .091 0 r
.2832 .41598 m .27757 .41246 L .28811 .415 L closepath p F P
0 g
s
.157 0 0 r
.44578 .48963 m .44762 .48897 L .47849 .48583 L p F P
0 g
s
.264 0 0 r
.47921 .4855 m .47849 .48583 L .44762 .48897 L p F P
0 g
s
.358 .174 .489 r
.67486 .29332 m .66005 .30385 L .66019 .31537 L p F P
0 g
s
.305 .143 .49 r
.7516 .29054 m .73614 .30381 L .73582 .31607 L p F P
0 g
s
.319 .154 .494 r
.73164 .31951 m .73582 .31607 L .73614 .30381 L p F P
0 g
s
.809 .37 .2 r
.14996 .41507 m .15202 .41479 L p .16867 .42922 L F P
0 g
s
.82 .393 .226 r
.14996 .41507 m .14903 .41345 L .15202 .41479 L closepath p F P
0 g
s
.13 0 0 r
.53904 .47365 m .54338 .47024 L .57051 .46289 L p F P
0 g
s
.233 0 0 r
.57236 .4609 m .57051 .46289 L .54338 .47024 L p F P
0 g
s
.269 0 .168 r
.65845 .41122 m .65842 .41131 L .63189 .42858 L p F P
0 g
s
.242 0 .134 r
.63108 .43056 m .63189 .42858 L .65842 .41131 L p F P
0 g
s
.291 0 .167 r
.59352 .37757 m .60962 .37078 L p .58155 .38942 L F P
0 g
s
.37 .055 .295 r
.59352 .37757 m .60962 .37078 L .61068 .36659 L closepath p F P
0 g
s
.287 0 0 r
.52395 .41294 m .52465 .41205 L .55114 .40546 L p F P
0 g
s
.879 .573 .467 r
.15449 .33345 m .15399 .33317 L .1531 .32183 L p F P
0 g
s
.889 .582 .461 r
.14169 .31498 m .1531 .32183 L .15399 .33317 L p F P
0 g
s
.887 .612 .516 r
.1531 .32183 m .14169 .31498 L .14211 .30326 L p F P
0 g
s
.897 .622 .512 r
.13123 .29616 m .14211 .30326 L .14169 .31498 L p F P
0 g
s
.089 0 0 r
.34788 .48833 m .3712 .49141 L .36864 .49121 L p F P
0 g
s
.089 0 0 r
.3448 .48809 m .34788 .48833 L p .36864 .49121 L F P
0 g
s
.765 .34 .242 r
.29034 .34012 m .29528 .3472 L .29322 .34851 L p F P
0 g
s
.765 .34 .242 r
.27368 .33522 m .29034 .34012 L p .29322 .34851 L F P
0 g
s
.089 0 0 r
.3378 .48854 m .3448 .48809 L p .36864 .49121 L F P
0 g
s
.32 0 0 r
.3378 .48854 m .32499 .48573 L .3448 .48809 L closepath p F P
0 g
s
.459 0 0 r
.3559 .42961 m .33303 .4269 L .32433 .42419 L p F P
0 g
s
.447 0 0 r
.33303 .4269 m .31933 .42512 L .32433 .42419 L closepath p F P
0 g
s
.329 .076 .371 r
.6369 .34016 m .63738 .33946 L .63696 .33971 L closepath p F P
0 g
s
.861 .519 .404 r
.18134 .35687 m .1686 .35059 L .16614 .3397 L p F P
0 g
s
.872 .527 .394 r
.15449 .33345 m .16614 .3397 L .1686 .35059 L p F P
0 g
s
.789 .348 .199 r
.20172 .37841 m .207 .37673 L p .21949 .38874 L F P
0 g
s
.812 .391 .245 r
.20172 .37841 m .19877 .37332 L .207 .37673 L closepath p F P
0 g
s
.313 .059 .358 r
.63738 .33946 m .65962 .32611 L p .63559 .34967 L F P
0 g
s
.313 .059 .358 r
.63559 .34967 m .6369 .34016 L .63738 .33946 L p F P
0 g
s
.367 .143 .437 r
.63738 .33946 m .65962 .32611 L .66019 .31537 L p F P
0 g
s
.825 .388 .2 r
.14903 .41345 m .14996 .41507 L .1409 .41524 L p F P
0 g
s
.825 .388 .2 r
.1409 .41524 m .13629 .40731 L .14903 .41345 L p F P
0 g
s
.373 .107 .376 r
.62242 .35633 m .63559 .34967 L .6369 .34016 L closepath p F P
0 g
s
.658 .215 .187 r
.33691 .35731 m .336 .3572 L .33633 .35689 L closepath p F P
0 g
s
.43 0 .05 r
.46986 .35809 m .46082 .35782 L .47128 .35643 L closepath p F P
0 g
s
.297 0 0 r
.46082 .35782 m .46986 .35809 L .46484 .36175 L p F P
0 g
s
.838 .551 .503 r
.25395 .31954 m .23974 .31373 L .23928 .30221 L p F P
0 g
s
.849 .56 .499 r
.22568 .29613 m .23928 .30221 L .23974 .31373 L p F P
0 g
s
.255 0 0 r
.41236 .49136 m .40473 .49218 L .37901 .49084 L p F P
0 g
s
.007 .582 .729 r
.37901 .49084 m .40473 .49218 L .40383 .49213 L p F P
0 g
s
.007 .582 .729 r
.3712 .49141 m .37901 .49084 L p .40383 .49213 L F P
0 g
s
.8 .448 .391 r
.25489 .32304 m .25646 .32048 L p .27368 .33522 L F P
0 g
s
.822 .486 .418 r
.25489 .32304 m .25395 .31954 L .25646 .32048 L closepath p F P
0 g
s
.476 0 0 r
.30324 .48274 m .28378 .47901 L .27168 .4743 L p F P
0 g
s
.463 0 0 r
.28378 .47901 m .27168 .4743 L .2633 .47452 L p F P
0 g
s
.177 0 0 r
.508 .48119 m .48481 .48487 L .47921 .4855 L p F P
0 g
s
.136 0 0 r
.48481 .48487 m .47849 .48583 L .47921 .4855 L closepath p F P
0 g
s
.224 0 0 r
.3908 .43224 m .39392 .4315 L .41341 .43126 L p F P
0 g
s
.314 0 0 r
.3908 .43224 m .38263 .43107 L .39392 .4315 L closepath p F P
0 g
s
.092 0 0 r
.52395 .41294 m .55112 .40548 L .54486 .41079 L p F P
0 g
s
.092 0 0 r
.51767 .41821 m .52395 .41294 L p .54486 .41079 L F P
0 g
s
.258 0 0 r
.52395 .41294 m .51767 .41821 L .49125 .42266 L p F P
0 g
s
.287 0 0 r
.55114 .40546 m .55112 .40548 L .52395 .41294 L p F P
0 g
s
.52 0 0 r
.36551 .36513 m .35391 .36374 L .33691 .35731 L p F P
0 g
s
.374 0 0 r
.336 .3572 m .33691 .35731 L .35391 .36374 L p F P
0 g
s
.374 0 0 r
.32815 .35998 m .336 .3572 L p .35391 .36374 L F P
0 g
s
.616 .095 0 r
.32815 .35998 m .31711 .3535 L .336 .3572 L closepath p F P
0 g
s
.254 0 .288 r
.69368 .37569 m .70836 .36654 L p .68418 .38989 L F P
0 g
s
.254 0 .288 r
.68418 .38989 m .68472 .38704 L .69368 .37569 L p F P
0 g
s
.303 .054 .361 r
.69368 .37569 m .70836 .36654 L .7095 .35657 L p F P
0 g
s
.255 0 0 r
.42426 .43187 m .41341 .43126 L .42734 .43091 L closepath p F P
0 g
s
.224 0 0 r
.41341 .43126 m .42426 .43187 L p .3908 .43224 L F P
0 g
s
.735 .243 .07 r
.23454 .39409 m .24218 .40196 L .2405 .40212 L p F P
0 g
s
.735 .243 .07 r
.21949 .38874 m .23454 .39409 L p .2405 .40212 L F P
0 g
s
.308 0 0 r
.38263 .43107 m .3908 .43224 L p .35746 .42999 L F P
0 g
s
.308 0 0 r
.35746 .42999 m .35824 .42984 L .38263 .43107 L p F P
0 g
s
.588 .029 0 r
.27757 .41246 m .2832 .41598 L .27593 .41627 L p F P
0 g
s
.588 .029 0 r
.26032 .4079 m .27757 .41246 L p .27593 .41627 L F P
0 g
s
.84 .46 .33 r
.19877 .37332 m .18542 .3673 L .18134 .35687 L p F P
0 g
s
.85 .465 .316 r
.1686 .35059 m .18134 .35687 L .18542 .3673 L p F P
0 g
s
.678 .154 0 r
.22852 .46191 m .21672 .45815 L .20584 .44949 L p F P
0 g
s
.675 .142 0 r
.1908 .44424 m .20584 .44949 L .21672 .45815 L p F P
0 g
s
.741 .257 .092 r
.18991 .44335 m .1908 .44424 L .20584 .44949 L p F P
0 g
s
.166 0 0 r
.42426 .43187 m .42734 .43091 L .45197 .42903 L p F P
0 g
s
.835 .49 .403 r
.25395 .31954 m .25489 .32304 L .25111 .32792 L p F P
0 g
s
.835 .49 .403 r
.23974 .31373 m .25395 .31954 L p .25111 .32792 L F P
0 g
s
.305 0 .271 r
.60962 .37078 m .61068 .36659 L .62242 .35633 L p F P
0 g
s
.248 .011 .345 r
.7286 .34285 m .7095 .35657 L .70836 .36654 L p F P
0 g
s
.292 .078 .407 r
.73132 .33563 m .73159 .33057 L p .7095 .35657 L F P
0 g
s
.292 .078 .407 r
.7095 .35657 m .7286 .34285 L .73132 .33563 L p F P
0 g
s
.282 .099 .446 r
.73582 .31607 m .73164 .31951 L .73159 .33057 L p F P
0 g
s
.809 .37 .2 r
.16867 .42922 m .1552 .42337 L .14996 .41507 L p F P
0 g
s
.814 .368 .179 r
.1552 .42337 m .14996 .41507 L .1409 .41524 L p F P
0 g
s
.523 0 0 r
.24964 .46762 m .2633 .47452 L .26197 .47441 L p F P
0 g
s
.523 0 0 r
.23261 .46309 m .24964 .46762 L p .26197 .47441 L F P
0 g
s
.642 .112 0 r
.23065 .46185 m .23261 .46309 L .24964 .46762 L p F P
0 g
s
.242 0 .134 r
.65842 .41131 m .65532 .41935 L .63108 .43056 L p F P
0 g
s
.15 0 0 r
.65532 .41935 m .63108 .43056 L .62704 .43793 L p F P
0 g
s
.232 0 .044 r
.63108 .43056 m .62704 .43793 L .60187 .44785 L p F P
0 g
s
.354 0 .002 r
.46986 .35809 m .47128 .35643 L .49999 .35064 L p F P
0 g
s
.305 0 .271 r
.62242 .35633 m .63559 .34967 L p .60962 .37078 L F P
0 g
s
.198 0 0 r
.44578 .48963 m .43832 .49098 L .41236 .49136 L p F P
0 g
s
.065 .629 .746 r
.41236 .49136 m .43832 .49098 L .4369 .49099 L p F P
0 g
s
.065 .629 .746 r
.40473 .49218 m .41236 .49136 L p .4369 .49099 L F P
0 g
s
.157 0 0 r
.47849 .48583 m .47194 .48777 L .44578 .48963 L p F P
0 g
s
.09 .648 .728 r
.44578 .48963 m .47194 .48777 L .46828 .4881 L p F P
0 g
s
.09 .648 .728 r
.43832 .49098 m .44578 .48963 L p .46828 .4881 L F P
0 g
s
.02 0 0 r
.47194 .48777 m .47849 .48583 L .48481 .48487 L p F P
0 g
s
.215 0 0 r
.32499 .48573 m .3378 .48854 L .33092 .48793 L p F P
0 g
s
.215 0 0 r
.30551 .48313 m .32499 .48573 L p .33092 .48793 L F P
0 g
s
.152 0 0 r
.57051 .46289 m .57236 .4609 L .59903 .45161 L p F P
0 g
s
.215 0 0 r
.60187 .44785 m .59903 .45161 L .57236 .4609 L p F P
0 g
s
.396 0 0 r
.35746 .42999 m .3559 .42961 L .35824 .42984 L closepath p F P
0 g
s
.903 .589 .441 r
.09145 .35542 m .08071 .34836 L .0797 .33708 L p F P
0 g
s
.913 .597 .434 r
.06942 .32979 m .0797 .33708 L .08071 .34836 L p F P
0 g
s
.912 .622 .481 r
.0797 .33708 m .06942 .32979 L .06937 .31825 L p F P
0 g
s
.214 0 .153 r
.65842 .41131 m .6587 .41109 L .65845 .41122 L closepath p F P
0 g
s
.27 0 .238 r
.65845 .41122 m .6587 .41109 L .67966 .39233 L p F P
0 g
s
.31 .024 .307 r
.67966 .39233 m .68418 .38989 L .68472 .38704 L closepath p F P
0 g
s
.183 0 .118 r
.65532 .41935 m .65842 .41131 L .6587 .41109 L p F P
0 g
s
.183 0 .118 r
.6587 .41109 m .6818 .39867 L p .65532 .41935 L F P
0 g
s
.257 0 .225 r
.68418 .38989 m .67966 .39233 L .6587 .41109 L p F P
0 g
s
.257 0 .225 r
.6587 .41109 m .6818 .39867 L .68418 .38989 L p F P
0 g
s
.283 0 0 r
.3559 .42961 m .35746 .42999 L .34952 .43022 L p F P
0 g
s
.283 0 0 r
.34952 .43022 m .33303 .4269 L .3559 .42961 L p F P
0 g
s
.892 .551 .395 r
.09386 .36666 m .09348 .36643 L .09145 .35542 L p F P
0 g
s
.901 .558 .386 r
.08071 .34836 m .09145 .35542 L .09348 .36643 L p F P
0 g
s
.921 .631 .476 r
.05953 .31073 m .06937 .31825 L .06942 .32979 L p F P
0 g
s
.918 .651 .518 r
.06937 .31825 m .05953 .31073 L .06039 .29894 L p F P
0 g
s
.145 0 0 r
.59903 .45161 m .60187 .44785 L .62704 .43793 L p F P
0 g
s
.1 0 0 r
.50554 .48223 m .48481 .48487 L .508 .48119 L closepath p F P
0 g
s
.02 0 0 r
.48481 .48487 m .50554 .48223 L p .47194 .48777 L F P
0 g
s
.77 .285 .081 r
.1552 .42337 m .16867 .42922 L .17664 .43867 L p F P
0 g
s
.766 .288 .104 r
.18853 .44339 m .17664 .43867 L .16867 .42922 L p F P
0 g
s
.223 0 0 r
.45776 .42891 m .45197 .42903 L .45893 .42841 L closepath p F P
0 g
s
.166 0 0 r
.45197 .42903 m .45776 .42891 L p .42426 .43187 L F P
0 g
s
.817 .386 .217 r
.19877 .37332 m .20172 .37841 L .19591 .37934 L p F P
0 g
s
.817 .386 .217 r
.18542 .3673 m .19877 .37332 L p .19591 .37934 L F P
0 g
s
.876 .506 .341 r
.11959 .39057 m .10787 .38398 L .1047 .37326 L p F P
0 g
s
.885 .512 .33 r
.09386 .36666 m .1047 .37326 L .10787 .38398 L p F P
0 g
s
.927 .661 .514 r
.05098 .29119 m .06039 .29894 L .05953 .31073 L p F P
0 g
s
.308 0 0 r
.3908 .43224 m .38315 .43247 L p .35746 .42999 L F P
0 g
s
.308 0 0 r
.38269 .43244 m .35746 .42999 L p .38315 .43247 L F P
0 g
s
.308 0 0 r
.38315 .43247 m .38304 .43247 L .38269 .43244 L p F P
0 g
s
.045 .608 .794 r
.35746 .42999 m .38304 .43247 L .382 .4323 L p F P
0 g
s
.045 .608 .794 r
.34952 .43022 m .35746 .42999 L p .382 .4323 L F P
0 g
s
.045 .608 .794 r
.382 .4323 m .35984 .43065 L .34966 .43022 L p F P
0 g
s
.045 .608 .794 r
.34966 .43022 m .34952 .43022 L p .35066 .43029 L F P
0 g
s
.045 .608 .794 r
.382 .4323 m .34966 .43022 L .35066 .43029 L F
.147 0 0 r
.48887 .42411 m .49125 .42266 L .51767 .41821 L p F P
0 g
s
.287 0 0 r
.49125 .42266 m .48887 .42411 L .45893 .42841 L p F P
0 g
s
.132 0 0 r
.45776 .42891 m .45893 .42841 L .48887 .42411 L p F P
0 g
s
.8 .448 .391 r
.27368 .33522 m .2575 .33011 L .25489 .32304 L p F P
0 g
s
.809 .453 .383 r
.2575 .33011 m .25111 .32792 L .25489 .32304 L closepath p F P
0 g
s
.765 .323 .202 r
.2575 .33011 m .27368 .33522 L .28069 .34474 L p F P
0 g
s
.765 .34 .242 r
.29322 .34851 m .28069 .34474 L .27368 .33522 L p F P
0 g
s
.372 .019 .231 r
.52971 .33796 m .5308 .33501 L .55663 .32566 L p F P
0 g
s
.456 .169 .387 r
.55832 .31578 m .55663 .32566 L .5308 .33501 L p F P
0 g
s
.558 0 0 r
.31711 .3535 m .32815 .35998 L .32632 .36011 L p F P
0 g
s
.558 0 0 r
.29775 .34952 m .31711 .3535 L p .32632 .36011 L F P
0 g
s
.705 .26 .193 r
.31711 .3535 m .29775 .34952 L .29528 .3472 L p F P
0 g
s
.853 .451 .276 r
.13629 .40731 m .12403 .40096 L .11959 .39057 L p F P
0 g
s
.862 .456 .262 r
.10787 .38398 m .11959 .39057 L .12403 .40096 L p F P
0 g
s
.614 .061 0 r
.23261 .46309 m .22852 .46191 L .23065 .46185 L closepath p F P
0 g
s
.215 0 0 r
.30459 .48317 m .30551 .48313 L p .33092 .48793 L F P
0 g
s
.414 0 0 r
.30459 .48317 m .30324 .48274 L .30551 .48313 L closepath p F P
0 g
s
.354 0 .002 r
.49999 .35064 m .49618 .35474 L .46986 .35809 L p F P
0 g
s
.233 0 0 r
.46484 .36175 m .46986 .35809 L .49618 .35474 L p F P
0 g
s
.267 .087 .441 r
.7521 .30218 m .73582 .31607 L .73346 .32904 L p F P
0 g
s
.305 .143 .49 r
.73582 .31607 m .7521 .30218 L .7516 .29054 L p F P
0 g
s
.282 .099 .446 r
.73159 .33057 m .73346 .32904 L .73582 .31607 L p F P
0 g
s
.4 0 0 r
.40113 .36664 m .37914 .36578 L .36945 .36388 L p F P
0 g
s
.388 0 0 r
.37914 .36578 m .36551 .36513 L .36945 .36388 L closepath p F P
0 g
s
.399 .121 .371 r
.58281 .30463 m .55832 .31578 L .55663 .32566 L p F P
0 g
s
.464 .238 .486 r
.58316 .29338 m .58281 .30463 L .55832 .31578 L p F P
0 g
s
.335 0 0 r
.30324 .48274 m .30459 .48317 L .2964 .48266 L p F P
0 g
s
.335 0 0 r
.2964 .48266 m .28378 .47901 L .30324 .48274 L p F P
0 g
s
.189 0 .196 r
.70665 .3759 m .68418 .38989 L .6818 .39867 L p F P
0 g
s
.254 0 .288 r
.70836 .36654 m .70665 .3759 L .68418 .38989 L p F P
0 g
s
.118 0 0 r
.33303 .4269 m .34952 .43022 L .34479 .42945 L p F P
0 g
s
.118 0 0 r
.31933 .42512 m .33303 .4269 L p .34479 .42945 L F P
0 g
s
.311 .1 .423 r
.67365 .30584 m .66019 .31537 L .65962 .32611 L p F P
0 g
s
.358 .174 .489 r
.66019 .31537 m .67365 .30584 L .67486 .29332 L p F P
0 g
s
.733 .232 .041 r
.1908 .44424 m .18853 .44339 L .18991 .44335 L closepath p F P
0 g
s
.224 0 0 r
.42426 .43187 m .41667 .43248 L .3908 .43224 L p F P
0 g
s
.147 .685 .84 r
.3908 .43224 m .41667 .43248 L .41643 .43245 L p F P
0 g
s
.147 .685 .84 r
.38304 .43247 m .3908 .43224 L p .41643 .43245 L F P
0 g
s
.188 0 0 r
.5778 .39558 m .58155 .38942 L .60644 .37895 L p F P
0 g
s
.291 0 .167 r
.60962 .37078 m .60644 .37895 L .58155 .38942 L p F P
0 g
s
.263 0 .031 r
.58155 .38942 m .5778 .39558 L .55114 .40546 L p F P
0 g
s
.215 0 .126 r
.63341 .35877 m .60962 .37078 L .60644 .37895 L p F P
0 g
s
.305 0 .271 r
.63559 .34967 m .63341 .35877 L .60962 .37078 L p F P
0 g
s
.588 .029 0 r
.27593 .41627 m .27369 .41567 L .26032 .4079 L p F P
0 g
s
.562 0 0 r
.24364 .4031 m .26032 .4079 L .27369 .41567 L p F P
0 g
s
.697 .199 .057 r
.24218 .40196 m .24364 .4031 L .26032 .4079 L p F P
0 g
s
.889 .582 .461 r
.15399 .33317 m .14253 .32634 L .14169 .31498 L p F P
0 g
s
.9 .592 .454 r
.13077 .3079 m .14169 .31498 L .14253 .32634 L p F P
0 g
s
.897 .622 .512 r
.14169 .31498 m .13077 .3079 L .13123 .29616 L p F P
0 g
s
.708 .255 .174 r
.29775 .34952 m .29322 .34851 L .29528 .3472 L closepath p F P
0 g
s
.132 0 0 r
.48887 .42411 m .48404 .42581 L .45776 .42891 L p F P
0 g
s
.177 .713 .781 r
.45776 .42891 m .48404 .42581 L .47904 .42623 L p F P
0 g
s
.177 .713 .781 r
.45035 .43035 m .45776 .42891 L p .47904 .42623 L F P
0 g
s
.166 0 0 r
.45776 .42891 m .45035 .43035 L .42426 .43187 L p F P
0 g
s
.497 0 0 r
.31161 .42371 m .29233 .41981 L .2832 .41598 L p F P
0 g
s
.486 0 0 r
.29233 .41981 m .27593 .41627 L .2832 .41598 L closepath p F P
0 g
s
.872 .527 .394 r
.15409 .33369 m .15449 .33345 L p .1686 .35059 L F P
0 g
s
.877 .537 .404 r
.15409 .33369 m .15399 .33317 L .15449 .33345 L closepath p F P
0 g
s
.215 0 0 r
.33092 .48793 m .32784 .4875 L .30459 .48317 L p F P
0 g
s
.213 0 0 r
.32784 .4875 m .30459 .48317 L .2964 .48266 L p F P
0 g
s
.908 .633 .508 r
.12084 .28882 m .13123 .29616 L .13077 .3079 L p F P
0 g
s
.849 .56 .499 r
.23974 .31373 m .22613 .30766 L .22568 .29613 L p F P
0 g
s
.86 .569 .494 r
.21267 .2898 m .22568 .29613 L .22613 .30766 L p F P
0 g
s
.887 .543 .391 r
.15399 .33317 m .15409 .33369 L .14469 .33726 L p F P
0 g
s
.887 .543 .391 r
.14469 .33726 m .14253 .32634 L .15399 .33317 L p F P
0 g
s
.523 0 0 r
.26197 .47441 m .24764 .47058 L .23261 .46309 L p F P
0 g
s
.474 0 0 r
.22852 .46191 m .23261 .46309 L .24764 .47058 L p F P
0 g
s
.83 .387 .179 r
.13629 .40731 m .1409 .41524 L .13742 .4149 L p F P
0 g
s
.83 .387 .179 r
.12403 .40096 m .13629 .40731 L p .13742 .4149 L F P
0 g
s
.735 .243 .07 r
.2405 .40212 m .22836 .39781 L .21949 .38874 L p F P
0 g
s
.734 .231 .033 r
.205 .38314 m .21949 .38874 L .22836 .39781 L p F P
0 g
s
.789 .348 .199 r
.21949 .38874 m .205 .38314 L .20172 .37841 L p F P
0 g
s
.187 .717 .835 r
.42426 .43187 m .45035 .43035 L .44858 .43025 L p F P
0 g
s
.187 .717 .835 r
.41667 .43248 m .42426 .43187 L p .44858 .43025 L F P
0 g
s
.043 0 0 r
.5657 .46669 m .57051 .46289 L .59667 .45422 L p F P
0 g
s
.152 0 0 r
.59903 .45161 m .59667 .45422 L .57051 .46289 L p F P
0 g
s
.13 0 0 r
.57051 .46289 m .5657 .46669 L .53904 .47365 L p F P
0 g
s
.883 .534 .383 r
.15639 .34408 m .15409 .33369 L .14469 .33726 L p F P
0 g
s
.872 .527 .394 r
.1686 .35059 m .15639 .34408 L .15409 .33369 L p F P
0 g
s
.675 .142 0 r
.21672 .45815 m .20159 .45291 L .1908 .44424 L p F P
0 g
s
.656 .107 0 r
.18853 .44339 m .1908 .44424 L .20159 .45291 L p F P
0 g
s
.016 0 0 r
.50554 .48223 m .508 .48119 L .53638 .47519 L p F P
0 g
s
.133 0 0 r
.53904 .47365 m .53638 .47519 L .508 .48119 L p F P
0 g
s
.32 0 0 r
.43402 .36531 m .40863 .36644 L .40282 .36604 L p F P
0 g
s
.281 0 0 r
.40863 .36644 m .40113 .36664 L .40282 .36604 L closepath p F P
0 g
s
.297 0 0 r
.46484 .36175 m .44832 .36382 L .43632 .36421 L p F P
0 g
s
.231 0 0 r
.44832 .36382 m .43402 .36531 L .43632 .36421 L closepath p F P
0 g
s
.835 .49 .403 r
.25111 .32792 m .24271 .32449 L .23974 .31373 L p F P
0 g
s
.846 .495 .388 r
.22613 .30766 m .23974 .31373 L .24271 .32449 L p F P
0 g
s
.118 0 0 r
.3162 .42521 m .31933 .42512 L p .34479 .42945 L F P
0 g
s
.407 0 0 r
.3162 .42521 m .31161 .42371 L .31933 .42512 L closepath p F P
0 g
s
.232 0 0 r
.49618 .35474 m .49999 .35064 L .52728 .34306 L p F P
0 g
s
.407 .023 .194 r
.52971 .33796 m .52728 .34306 L .49999 .35064 L p F P
0 g
s
.85 .465 .316 r
.18542 .3673 m .17263 .36104 L .1686 .35059 L p F P
0 g
s
.86 .469 .301 r
.15639 .34408 m .1686 .35059 L .17263 .36104 L p F P
0 g
s
.656 .107 0 r
.18111 .44288 m .18853 .44339 L p .20159 .45291 L F P
0 g
s
.714 .194 0 r
.18111 .44288 m .17664 .43867 L .18853 .44339 L closepath p F P
0 g
s
.474 0 0 r
.22207 .46152 m .22852 .46191 L p .24764 .47058 L F P
0 g
s
.597 .032 0 r
.22207 .46152 m .21672 .45815 L .22852 .46191 L closepath p F P
0 g
s
.795 .345 .176 r
.205 .38314 m .19591 .37934 L .20172 .37841 L closepath p F P
0 g
s
.025 0 0 r
.53638 .47519 m .53904 .47365 L .5657 .46669 L p F P
0 g
s
.372 .019 .231 r
.55663 .32566 m .55627 .32668 L .52971 .33796 L p F P
0 g
s
.316 0 .143 r
.52728 .34306 m .52971 .33796 L .55627 .32668 L p F P
0 g
s
.147 0 0 r
.51767 .41821 m .51754 .41828 L .48887 .42411 L p F P
0 g
s
0 0 0 r
.48404 .42581 m .48887 .42411 L .51754 .41828 L p F P
0 g
s
.197 0 0 r
.55112 .40548 m .55114 .40546 L .5778 .39558 L p F P
0 g
s
0 0 0 r
.57714 .39646 m .55112 .40548 L .54486 .41079 L p F P
0 g
s
.197 0 0 r
.5778 .39558 m .57714 .39646 L .55112 .40548 L p F P
0 g
s
.242 0 .25 r
.65831 .33605 m .63559 .34967 L .63341 .35877 L p F P
0 g
s
.313 .059 .358 r
.65962 .32611 m .65831 .33605 L .63559 .34967 L p F P
0 g
s
.558 0 0 r
.32632 .36011 m .31194 .3568 L .29775 .34952 L p F P
0 g
s
.44 0 0 r
.29322 .34851 m .29775 .34952 L .31194 .3568 L p F P
0 g
s
.3 0 0 r
.31161 .42371 m .3162 .42521 L .30806 .4242 L p F P
0 g
s
.3 0 0 r
.30806 .4242 m .29233 .41981 L .31161 .42371 L p F P
0 g
s
.24 .036 .39 r
.73132 .33563 m .73346 .32904 L .73159 .33057 L closepath p F P
0 g
s
.411 .197 .476 r
.58722 .2911 m .58316 .29338 L .58281 .30463 L p F P
0 g
s
.347 .165 .485 r
.68154 .28842 m .67486 .29332 L .67365 .30584 L p F P
0 g
s
.814 .368 .179 r
.1409 .41524 m .14222 .41731 L .1552 .42337 L p F P
0 g
s
.77 .285 .081 r
.17664 .43867 m .16306 .43284 L .1552 .42337 L p F P
0 g
s
.772 .281 .055 r
.14222 .41731 m .1552 .42337 L .16306 .43284 L p F P
0 g
s
.243 0 0 r
.28378 .47901 m .2964 .48266 L .28952 .48133 L p F P
0 g
s
.243 0 0 r
.26488 .47507 m .28378 .47901 L p .28952 .48133 L F P
0 g
s
.463 0 0 r
.2633 .47452 m .26488 .47507 L .28378 .47901 L p F P
0 g
s
.765 .323 .202 r
.28069 .34474 m .26478 .33952 L .2575 .33011 L p F P
0 g
s
.756 .291 .143 r
.25111 .32792 m .2575 .33011 L .26478 .33952 L p F P
0 g
s
.824 .386 .195 r
.17263 .36104 m .18542 .3673 L .19125 .37725 L p F P
0 g
s
.817 .386 .217 r
.19591 .37934 m .19125 .37725 L .18542 .3673 L p F P
0 g
s
.675 .15 0 r
.24364 .4031 m .2405 .40212 L .24218 .40196 L closepath p F P
0 g
s
.44 0 0 r
.28686 .34961 m .29322 .34851 L p .31194 .3568 L F P
0 g
s
.677 .158 0 r
.28686 .34961 m .28069 .34474 L .29322 .34851 L closepath p F P
0 g
s
.913 .597 .434 r
.08071 .34836 m .07039 .34109 L .06942 .32979 L p F P
0 g
s
.922 .606 .426 r
.05955 .32229 m .06942 .32979 L .07039 .34109 L p F P
0 g
s
.921 .631 .476 r
.06942 .32979 m .05955 .32229 L .05953 .31073 L p F P
0 g
s
.901 .558 .386 r
.09348 .36643 m .0827 .35939 L .08071 .34836 L p F P
0 g
s
.91 .566 .377 r
.07039 .34109 m .08071 .34836 L .0827 .35939 L p F P
0 g
s
.089 0 0 r
.36864 .49121 m .35186 .48984 L .3378 .48854 L p F P
0 g
s
.068 0 0 r
.35186 .48984 m .33092 .48793 L .3378 .48854 L closepath p F P
0 g
s
.885 .512 .33 r
.09355 .36666 m .09386 .36666 L p .10787 .38398 L F P
0 g
s
.887 .517 .336 r
.09355 .36666 m .09348 .36643 L .09386 .36666 L closepath p F P
0 g
s
.098 0 0 r
.3951 .36676 m .37914 .36578 L .40113 .36664 L closepath p F P
0 g
s
.027 .599 .715 r
.3951 .36676 m .40113 .36664 L .40863 .36644 L p F P
0 g
s
.072 0 0 r
.59667 .45422 m .59903 .45161 L .62581 .43965 L p F P
0 g
s
.145 0 0 r
.62704 .43793 m .62581 .43965 L .59903 .45161 L p F P
0 g
s
.191 0 .265 r
.72086 .3576 m .70836 .36654 L .70665 .3759 L p F P
0 g
s
.248 .011 .345 r
.70836 .36654 m .72086 .3576 L .7286 .34285 L p F P
0 g
s
.93 .64 .47 r
.05009 .303 m .05953 .31073 L .05955 .32229 L p F P
0 g
s
.927 .661 .514 r
.05953 .31073 m .05009 .303 L .05098 .29119 L p F P
0 g
s
.033 0 0 r
.42878 .36587 m .40863 .36644 L .43402 .36531 L closepath p F P
0 g
s
.027 .599 .715 r
.40863 .36644 m .42878 .36587 L p .3951 .36676 L F P
0 g
s
.895 .521 .322 r
.09348 .36643 m .09355 .36666 L .08428 .36511 L p F P
0 g
s
.895 .521 .322 r
.08428 .36511 m .0827 .35939 L .09348 .36643 L p F P
0 g
s
.885 .512 .33 r
.10787 .38398 m .09659 .37717 L .09355 .36666 L p F P
0 g
s
.893 .517 .316 r
.09659 .37717 m .09355 .36666 L .08428 .36511 L p F P
0 g
s
.231 .029 .386 r
.73346 .32904 m .75193 .31335 L p .73101 .34107 L F P
0 g
s
.231 .029 .386 r
.73101 .34107 m .73132 .33563 L .73346 .32904 L p F P
0 g
s
.267 .087 .441 r
.75208 .31249 m .7521 .30218 L p .73346 .32904 L F P
0 g
s
.267 .087 .441 r
.73346 .32904 m .75193 .31335 L .75208 .31249 L p F P
0 g
s
.562 0 0 r
.27369 .41567 m .2572 .41078 L .24364 .4031 L p F P
0 g
s
.502 0 0 r
.2405 .40212 m .24364 .4031 L .2572 .41078 L p F P
0 g
s
.1 0 0 r
.37914 .36578 m .3951 .36676 L p .36152 .36516 L F P
0 g
s
.1 0 0 r
.36152 .36516 m .36551 .36513 L .37914 .36578 L p F P
0 g
s
.936 .671 .509 r
.04196 .28323 m .05098 .29119 L .05009 .303 L p F P
0 g
s
.411 .197 .476 r
.58281 .30463 m .58305 .3045 L .58722 .2911 L p F P
0 g
s
.398 .185 .47 r
.60612 .28007 m .58722 .2911 L .58305 .3045 L p F P
0 g
s
.862 .456 .262 r
.12403 .40096 m .11224 .39439 L .10787 .38398 L p F P
0 g
s
.87 .46 .247 r
.09659 .37717 m .10787 .38398 L .11224 .39439 L p F P
0 g
s
0 0 0 r
.42878 .36587 m .43402 .36531 L .44832 .36382 L p F P
0 g
s
.016 0 0 r
.53638 .47519 m .53211 .47688 L .50554 .48223 L p F P
0 g
s
.213 .737 .765 r
.50554 .48223 m .53211 .47688 L .52697 .47779 L p F P
0 g
s
.213 .737 .765 r
.49839 .48377 m .50554 .48223 L p .52697 .47779 L F P
0 g
s
.02 0 0 r
.50554 .48223 m .49839 .48377 L .47194 .48777 L p F P
0 g
s
.756 .291 .143 r
.24592 .33019 m .25111 .32792 L p .26478 .33952 L F P
0 g
s
.811 .394 .256 r
.24592 .33019 m .24271 .32449 L .25111 .32792 L closepath p F P
0 g
s
.247 0 0 r
.36152 .36516 m .35391 .36374 L .36551 .36513 L closepath p F P
0 g
s
.56 0 0 r
.21672 .45815 m .22207 .46152 L .21347 .46007 L p F P
0 g
s
.56 0 0 r
.21347 .46007 m .20159 .45291 L .21672 .45815 L p F P
0 g
s
.259 .11 .479 r
.75403 .28819 m .7516 .29054 L .7521 .30218 L p F P
0 g
s
.502 0 0 r
.23361 .40174 m .2405 .40212 L p .2572 .41078 L F P
0 g
s
.649 .101 0 r
.23361 .40174 m .22836 .39781 L .2405 .40212 L closepath p F P
0 g
s
.118 0 0 r
.34479 .42945 m .33597 .42819 L .3162 .42521 L p F P
0 g
s
.123 0 0 r
.33597 .42819 m .3162 .42521 L .30806 .4242 L p F P
0 g
s
.734 .231 .033 r
.22836 .39781 m .21388 .39219 L .205 .38314 L p F P
0 g
s
.726 .209 0 r
.19591 .37934 m .205 .38314 L .21388 .39219 L p F P
0 g
s
.385 0 0 r
.26488 .47507 m .26197 .47441 L .2633 .47452 L closepath p F P
0 g
s
.035 .604 .762 r
.37794 .49153 m .36864 .49121 L .3712 .49141 L closepath p F P
0 g
s
.007 .582 .729 r
.40383 .49213 m .37794 .49153 L .3712 .49141 L p F P
0 g
s
.871 .578 .489 r
.20023 .2832 m .21267 .2898 L .2131 .30133 L p F P
0 g
s
.86 .569 .494 r
.22613 .30766 m .2131 .30133 L .21267 .2898 L p F P
0 g
s
.7 .166 0 r
.17664 .43867 m .18111 .44288 L .1723 .44133 L p F P
0 g
s
.7 .166 0 r
.1723 .44133 m .16306 .43284 L .17664 .43867 L p F P
0 g
s
0 .429 .688 r
.29233 .41981 m .30806 .4242 L .30376 .42301 L p F P
0 g
s
0 .429 .688 r
.27593 .41627 m .29233 .41981 L p .30376 .42301 L F P
0 g
s
.278 .064 .399 r
.7286 .34285 m .73101 .34107 L .73132 .33563 L closepath p F P
0 g
s
.05 0 0 r
.46249 .36241 m .44832 .36382 L .46484 .36175 L closepath p F P
0 g
s
0 0 0 r
.44832 .36382 m .46249 .36241 L p .42878 .36587 L F P
0 g
s
.9 .592 .454 r
.14253 .32634 m .13157 .31927 L .13077 .3079 L p F P
0 g
s
.911 .602 .447 r
.12034 .30057 m .13077 .3079 L .13157 .31927 L p F P
0 g
s
.908 .633 .508 r
.13077 .3079 m .12034 .30057 L .12084 .28882 L p F P
0 g
s
0 .56 .772 r
.35391 .36374 m .36152 .36516 L .35363 .36305 L p F P
0 g
s
.374 0 0 r
.35391 .36374 m .33132 .36081 L .32815 .35998 L p F P
0 g
s
0 .56 .772 r
.35363 .36305 m .33132 .36081 L .35391 .36374 L p F P
0 g
s
.83 .387 .179 r
.13742 .4149 m .12982 .41099 L .12403 .40096 L p F P
0 g
s
.836 .388 .16 r
.11224 .39439 m .12403 .40096 L .12982 .41099 L p F P
0 g
s
.898 .551 .381 r
.14253 .32634 m .14469 .33726 L .14462 .33727 L p F P
0 g
s
.898 .551 .381 r
.13157 .31927 m .14253 .32634 L p .14462 .33727 L F P
0 g
s
.846 .495 .388 r
.24271 .32449 m .22913 .3184 L .22613 .30766 L p F P
0 g
s
.857 .498 .373 r
.2131 .30133 m .22613 .30766 L .22913 .3184 L p F P
0 g
s
.183 0 .118 r
.67938 .40506 m .67389 .40934 L .65532 .41935 L p F P
0 g
s
.183 0 .118 r
.6818 .39867 m .67938 .40506 L p .65532 .41935 L F P
0 g
s
.097 0 0 r
.65263 .42445 m .67389 .40934 L .65532 .41935 L closepath p F P
0 g
s
.15 0 0 r
.65263 .42445 m .65532 .41935 L p .62704 .43793 L F P
0 g
s
.076 0 0 r
.62581 .43965 m .63885 .43247 L .62704 .43793 L closepath p F P
0 g
s
.15 0 0 r
.62704 .43793 m .63885 .43247 L .65263 .42445 L p F P
0 g
s
0 0 0 r
.53211 .47688 m .53638 .47519 L .56369 .46784 L p F P
0 g
s
.025 0 0 r
.5657 .46669 m .56369 .46784 L .53638 .47519 L p F P
0 g
s
.25 .007 .337 r
.66898 .31952 m .65962 .32611 L .65831 .33605 L p F P
0 g
s
.311 .1 .423 r
.65962 .32611 m .66898 .31952 L .67365 .30584 L p F P
0 g
s
.631 .076 0 r
.28069 .34474 m .28686 .34961 L .28109 .3493 L p F P
0 g
s
.631 .076 0 r
.26478 .33952 m .28069 .34474 L p .28109 .3493 L F P
0 g
s
.919 .644 .503 r
.11093 .28123 m .12084 .28882 L .12034 .30057 L p F P
0 g
s
.149 .692 .75 r
.46828 .4881 m .47194 .48777 L .49839 .48377 L p F P
0 g
s
.243 0 0 r
.28952 .48133 m .28649 .48068 L .26488 .47507 L p F P
0 g
s
0 .453 .716 r
.26197 .47441 m .26488 .47507 L .28649 .48068 L p F P
0 g
s
.816 .359 .144 r
.14222 .41731 m .13742 .4149 L .1409 .41524 L closepath p F P
0 g
s
.291 .123 .473 r
.69528 .27662 m .68154 .28842 L .68172 .29994 L p F P
0 g
s
.347 .165 .485 r
.67365 .30584 m .68172 .29994 L .68154 .28842 L p F P
0 g
s
.065 .629 .746 r
.4369 .49099 m .40786 .49203 L .40473 .49218 L p F P
0 g
s
.104 .658 .79 r
.40786 .49203 m .40383 .49213 L .40473 .49218 L closepath p F P
0 g
s
.3 0 .207 r
.55627 .32668 m .56082 .32376 L .55663 .32566 L closepath p F P
0 g
s
.399 .121 .371 r
.58278 .30484 m .58281 .30463 L p .55663 .32566 L F P
0 g
s
.399 .121 .371 r
.55663 .32566 m .56082 .32376 L .58278 .30484 L p F P
0 g
s
.361 0 0 r
.33132 .36081 m .32632 .36011 L .32815 .35998 L closepath p F P
0 g
s
.259 .11 .479 r
.7521 .30218 m .75389 .30045 L .75403 .28819 L p F P
0 g
s
.241 .096 .475 r
.76847 .27352 m .75403 .28819 L .75389 .30045 L p F P
0 g
s
.86 .469 .301 r
.17263 .36104 m .16037 .35454 L .15639 .34408 L p F P
0 g
s
.87 .474 .284 r
.14471 .33732 m .15639 .34408 L .16037 .35454 L p F P
0 g
s
.883 .534 .383 r
.14469 .33726 m .14471 .33732 L .15639 .34408 L p F P
0 g
s
.092 0 0 r
.54486 .41079 m .52238 .41697 L .51767 .41821 L p F P
0 g
s
.009 0 0 r
.52238 .41697 m .51754 .41828 L .51767 .41821 L closepath p F P
0 g
s
.09 .648 .728 r
.46828 .4881 m .4452 .4903 L .43832 .49098 L p F P
0 g
s
.141 .686 .785 r
.4452 .4903 m .4369 .49099 L .43832 .49098 L closepath p F P
0 g
s
0 .453 .716 r
.25491 .47334 m .26197 .47441 L p .28649 .48068 L F P
0 g
s
.382 0 0 r
.25491 .47334 m .24764 .47058 L .26197 .47441 L closepath p F P
0 g
s
0 0 0 r
.51058 .4204 m .51754 .41828 L .52238 .41697 L p F P
0 g
s
0 0 0 r
.51754 .41828 m .51058 .4204 L .48404 .42581 L p F P
0 g
s
.816 .383 .212 r
.24271 .32449 m .24592 .33019 L .24126 .33113 L p F P
0 g
s
.816 .383 .212 r
.22913 .3184 m .24271 .32449 L p .24126 .33113 L F P
0 g
s
.295 .085 .414 r
.68172 .29994 m .67365 .30584 L .66898 .31952 L p F P
0 g
s
0 0 0 r
.46249 .36241 m .46484 .36175 L .49389 .35612 L p F P
0 g
s
.233 0 0 r
.49618 .35474 m .49389 .35612 L .46484 .36175 L p F P
0 g
s
.223 0 .109 r
.55316 .33362 m .55627 .32668 L .56082 .32376 L p F P
0 g
s
.316 0 .143 r
.55627 .32668 m .55316 .33362 L .52728 .34306 L p F P
0 g
s
.111 0 0 r
.52276 .34784 m .52728 .34306 L .55316 .33362 L p F P
0 g
s
.232 0 0 r
.52728 .34306 m .52276 .34784 L .49618 .35474 L p F P
0 g
s
.192 .715 .862 r
.39705 .49127 m .40383 .49213 L .40786 .49203 L p F P
0 g
s
.113 .66 .823 r
.39705 .49127 m .37794 .49153 L .40383 .49213 L closepath p F P
0 g
s
.155 .694 .827 r
.43081 .4905 m .40786 .49203 L .4369 .49099 L closepath p F P
0 g
s
.192 .715 .862 r
.40786 .49203 m .43081 .4905 L p .39705 .49127 L F P
0 g
s
.229 0 .332 r
.73101 .34107 m .7286 .34285 L .72086 .3576 L p F P
0 g
s
.114 0 .086 r
.67938 .40506 m .69515 .39036 L .6818 .39867 L closepath p F P
0 g
s
.189 0 .196 r
.70586 .37891 m .70665 .3759 L p .6818 .39867 L F P
0 g
s
.189 0 .196 r
.6818 .39867 m .69515 .39036 L .70586 .37891 L p F P
0 g
s
.772 .281 .055 r
.16306 .43284 m .14999 .4268 L .14222 .41731 L p F P
0 g
s
.769 .268 .016 r
.13742 .4149 m .14222 .41731 L .14999 .4268 L p F P
0 g
s
.058 .616 .807 r
.35984 .43065 m .34479 .42945 L .34952 .43022 L closepath p F P
0 g
s
.223 0 .109 r
.56082 .32376 m .58103 .31431 L p .55316 .33362 L F P
0 g
s
.378 .092 .348 r
.56082 .32376 m .58103 .31431 L .58278 .30484 L closepath p F P
0 g
s
.824 .386 .195 r
.19125 .37725 m .17841 .371 L .17263 .36104 L p F P
0 g
s
.831 .385 .17 r
.16037 .35454 m .17263 .36104 L .17841 .371 L p F P
0 g
s
0 0 0 r
.54431 .41108 m .52238 .41697 L .54486 .41079 L closepath p F P
0 g
s
0 0 0 r
.52238 .41697 m .54431 .41108 L p .51058 .4204 L F P
0 g
s
.126 .667 .839 r
.37794 .49153 m .39705 .49127 L p .36336 .49042 L F P
0 g
s
.126 .667 .839 r
.36336 .49042 m .36864 .49121 L .37794 .49153 L p F P
0 g
s
0 0 0 r
.59253 .4576 m .59667 .45422 L .62191 .4442 L p F P
0 g
s
.072 0 0 r
.62581 .43965 m .62191 .4442 L .59667 .45422 L p F P
0 g
s
.043 0 0 r
.59667 .45422 m .59253 .4576 L .5657 .46669 L p F P
0 g
s
.335 .736 .982 r
.33132 .36081 m .35363 .36305 L .34805 .36009 L p F P
0 g
s
.335 .736 .982 r
.32632 .36011 m .33132 .36081 L p .34805 .36009 L F P
0 g
s
.188 0 0 r
.60644 .37895 m .60455 .38224 L .5778 .39558 L p F P
0 g
s
.108 0 0 r
.57714 .39646 m .5778 .39558 L .60455 .38224 L p F P
0 g
s
.726 .209 0 r
.19285 .37925 m .19591 .37934 L p .21388 .39219 L F P
0 g
s
.778 .296 .086 r
.19285 .37925 m .19125 .37725 L .19591 .37934 L closepath p F P
0 g
s
.038 0 0 r
.49389 .35612 m .49618 .35474 L .52276 .34784 L p F P
0 g
s
.036 .601 .79 r
.36336 .49042 m .35186 .48984 L .36864 .49121 L closepath p F P
0 g
s
.336 .072 .357 r
.58278 .30484 m .58305 .3045 L .58281 .30463 L closepath p F P
0 g
s
.613 .047 0 r
.22836 .39781 m .23361 .40174 L .22504 .40011 L p F P
0 g
s
.613 .047 0 r
.22504 .40011 m .21388 .39219 L .22836 .39781 L p F P
0 g
s
.474 0 0 r
.24764 .47058 m .23116 .46579 L .22207 .46152 L p F P
0 g
s
.458 0 0 r
.23116 .46579 m .22207 .46152 L .21347 .46007 L p F P
0 g
s
.293 .022 .32 r
.58305 .3045 m .6058 .29129 L p .58103 .31431 L F P
0 g
s
.293 .022 .32 r
.58103 .31431 m .58278 .30484 L .58305 .3045 L p F P
0 g
s
.398 .185 .47 r
.58305 .3045 m .6058 .29129 L .60612 .28007 L p F P
0 g
s
.228 .743 .86 r
.43081 .4905 m .4369 .49099 L .4452 .4903 L p F P
0 g
s
.114 0 0 r
.60455 .38224 m .6218 .37122 L .60644 .37895 L closepath p F P
0 g
s
.215 0 .126 r
.63131 .36442 m .63341 .35877 L p .60644 .37895 L F P
0 g
s
.215 0 .126 r
.60644 .37895 m .6218 .37122 L .63131 .36442 L p F P
0 g
s
0 .429 .688 r
.27485 .41617 m .27593 .41627 L p .30376 .42301 L F P
0 g
s
.457 0 0 r
.27485 .41617 m .27369 .41567 L .27593 .41627 L closepath p F P
0 g
s
0 0 0 r
.62191 .4442 m .62581 .43965 L .63885 .43247 L p F P
0 g
s
.254 0 0 r
.32005 .35904 m .31194 .3568 L .32632 .36011 L closepath p F P
0 g
s
.335 .736 .982 r
.32005 .35904 m .32632 .36011 L p .34805 .36009 L F P
0 g
s
.91 .566 .377 r
.0827 .35939 m .07233 .35214 L .07039 .34109 L p F P
0 g
s
.919 .573 .366 r
.06048 .33361 m .07039 .34109 L .07233 .35214 L p F P
0 g
s
.922 .606 .426 r
.07039 .34109 m .06048 .33361 L .05955 .32229 L p F P
0 g
s
.169 0 .313 r
.74765 .32704 m .73101 .34107 L .72989 .35096 L p F P
0 g
s
.231 .029 .386 r
.75193 .31335 m .74765 .32704 L .73101 .34107 L p F P
0 g
s
.229 0 .332 r
.72086 .3576 m .72989 .35096 L .73101 .34107 L p F P
0 g
s
0 0 0 r
.56369 .46784 m .5657 .46669 L .59253 .4576 L p F P
0 g
s
.366 0 0 r
.27369 .41567 m .27485 .41617 L .26651 .41443 L p F P
0 g
s
.366 0 0 r
.26651 .41443 m .2572 .41078 L .27369 .41567 L p F P
0 g
s
.167 .705 .802 r
.4646 .48808 m .4452 .4903 L .46828 .4881 L closepath p F P
0 g
s
.228 .743 .86 r
.4452 .4903 m .4646 .48808 L p .43081 .4905 L F P
0 g
s
.931 .614 .418 r
.05007 .31458 m .05955 .32229 L .06048 .33361 L p F P
0 g
s
.93 .64 .47 r
.05955 .32229 m .05007 .31458 L .05009 .303 L p F P
0 g
s
.228 .748 .791 r
.47904 .42623 m .48404 .42581 L .51058 .4204 L p F P
0 g
s
.533 0 0 r
.20159 .45291 m .21347 .46007 L .21131 .4595 L p F P
0 g
s
.533 0 0 r
.187 .44746 m .20159 .45291 L p .21131 .4595 L F P
0 g
s
.656 .107 0 r
.20159 .45291 m .187 .44746 L .18111 .44288 L p F P
0 g
s
.646 .091 0 r
.187 .44746 m .18111 .44288 L .1723 .44133 L p F P
0 g
s
.902 .525 .305 r
.0827 .35939 m .08428 .36511 L .07508 .36207 L p F P
0 g
s
.902 .525 .305 r
.07508 .36207 m .07233 .35214 L .0827 .35939 L p F P
0 g
s
.213 0 0 r
.2964 .48266 m .30685 .4842 L .32784 .4875 L p F P
0 g
s
0 .513 .741 r
.30685 .4842 m .28952 .48133 L .2964 .48266 L closepath p F P
0 g
s
.028 .593 .787 r
.35186 .48984 m .36336 .49042 L p .32979 .48775 L F P
0 g
s
.028 .593 .787 r
.32979 .48775 m .33092 .48793 L .35186 .48984 L p F P
0 g
s
0 0 0 r
.57114 .40167 m .57714 .39646 L .60204 .38586 L p F P
0 g
s
0 0 0 r
.57114 .40167 m .57714 .39646 L p .54486 .41079 L F P
0 g
s
.108 0 0 r
.60455 .38224 m .60204 .38586 L .57714 .39646 L p F P
0 g
s
.1 0 0 r
.3951 .36676 m .38738 .36432 L .36152 .36516 L p F P
0 g
s
.498 .792 .998 r
.36152 .36516 m .38738 .36432 L .38574 .36331 L p F P
0 g
s
.498 .792 .998 r
.35363 .36305 m .36152 .36516 L p .38574 .36331 L F P
0 g
s
.147 .685 .84 r
.41643 .43245 m .38606 .43236 L .38304 .43247 L p F P
0 g
s
.176 .701 .867 r
.38606 .43236 m .382 .4323 L .38304 .43247 L closepath p F P
0 g
s
.939 .649 .463 r
.04104 .29505 m .05009 .303 L .05007 .31458 L p F P
0 g
s
.936 .671 .509 r
.05009 .303 m .04104 .29505 L .04196 .28323 L p F P
0 g
s
.769 .268 .016 r
.13188 .41382 m .13742 .4149 L p .14999 .4268 L F P
0 g
s
.796 .316 .075 r
.13188 .41382 m .12982 .41099 L .13742 .4149 L closepath p F P
0 g
s
0 .429 .688 r
.30376 .42301 m .29515 .42097 L .27485 .41617 L p F P
0 g
s
.182 0 0 r
.29515 .42097 m .27485 .41617 L .26651 .41443 L p F P
0 g
s
.15 0 .114 r
.63131 .36442 m .64578 .35139 L .63341 .35877 L closepath p F P
0 g
s
.242 0 .25 r
.65782 .33822 m .65831 .33605 L p .63341 .35877 L F P
0 g
s
.242 0 .25 r
.63341 .35877 m .64578 .35139 L .65782 .33822 L p F P
0 g
s
.772 .276 .035 r
.19125 .37725 m .19285 .37925 L .18404 .37788 L p F P
0 g
s
.772 .276 .035 r
.18404 .37788 m .17841 .371 L .19125 .37725 L p F P
0 g
s
.304 0 0 r
.24764 .47058 m .25491 .47334 L .2465 .47114 L p F P
0 g
s
.304 0 0 r
.2465 .47114 m .23116 .46579 L .24764 .47058 L p F P
0 g
s
.87 .46 .247 r
.11224 .39439 m .10089 .3876 L .09659 .37717 L p F P
0 g
s
.877 .463 .23 r
.08574 .37015 m .09659 .37717 L .10089 .3876 L p F P
0 g
s
.893 .517 .316 r
.08428 .36511 m .08574 .37015 L .09659 .37717 L p F P
0 g
s
.177 .713 .781 r
.47904 .42623 m .46105 .42873 L .45035 .43035 L p F P
0 g
s
.253 .762 .859 r
.46105 .42873 m .44858 .43025 L .45035 .43035 L closepath p F P
0 g
s
.215 .047 .426 r
.75208 .31249 m .75389 .30045 L .7521 .30218 L closepath p F P
0 g
s
.631 .076 0 r
.28109 .3493 m .27626 .34764 L .26478 .33952 L p F P
0 g
s
.573 0 0 r
.24927 .33412 m .26478 .33952 L .27626 .34764 L p F P
0 g
s
.756 .291 .143 r
.26478 .33952 m .24927 .33412 L .24592 .33019 L p F P
0 g
s
.693 .153 0 r
.16306 .43284 m .1723 .44133 L .17117 .44102 L p F P
0 g
s
.693 .153 0 r
.14999 .4268 m .16306 .43284 L p .17117 .44102 L F P
0 g
s
.187 .717 .835 r
.44858 .43025 m .41763 .43238 L .41667 .43248 L p F P
0 g
s
.238 .746 .883 r
.41763 .43238 m .41643 .43245 L .41667 .43248 L closepath p F P
0 g
s
.871 .578 .489 r
.2131 .30133 m .20064 .29474 L .20023 .2832 L p F P
0 g
s
.884 .589 .483 r
.19313 .27907 m .20023 .2832 L .20064 .29474 L p F P
0 g
s
0 0 0 r
.63885 .43247 m .65132 .42662 L p .62191 .4442 L F P
0 g
s
.125 0 0 r
.63885 .43247 m .65132 .42662 L .65263 .42445 L closepath p F P
0 g
s
.341 .795 .947 r
.40905 .43068 m .41643 .43245 L .41763 .43238 L p F P
0 g
s
.272 .754 .926 r
.40905 .43068 m .38606 .43236 L .41643 .43245 L closepath p F P
0 g
s
.295 .778 .915 r
.44289 .42927 m .41763 .43238 L .44858 .43025 L closepath p F P
0 g
s
.341 .795 .947 r
.41763 .43238 m .44289 .42927 L p .40905 .43068 L F P
0 g
s
.287 .759 .937 r
.38606 .43236 m .40905 .43068 L p .37526 .43053 L F P
0 g
s
.287 .759 .937 r
.37526 .43053 m .382 .4323 L .38606 .43236 L p F P
0 g
s
.167 0 .246 r
.72989 .35096 m .72086 .3576 L .71039 .37324 L p F P
0 g
s
.191 0 .265 r
.70665 .3759 m .71039 .37324 L .72086 .3576 L p F P
0 g
s
0 0 0 r
.49389 .35612 m .48896 .35699 L .46249 .36241 L p F P
0 g
s
.48 .866 .974 r
.48896 .35699 m .46249 .36241 L .45509 .36165 L p F P
0 g
s
0 0 0 r
.46249 .36241 m .45509 .36165 L .42878 .36587 L p F P
0 g
s
.2 .705 .905 r
.37526 .43053 m .35984 .43065 L .382 .4323 L closepath p F P
0 g
s
.44 0 0 r
.31194 .3568 m .2937 .35237 L .28686 .34961 L p F P
0 g
s
.439 0 0 r
.2937 .35237 m .28109 .3493 L .28686 .34961 L closepath p F P
0 g
s
.867 .502 .355 r
.20064 .29474 m .2131 .30133 L .21614 .31205 L p F P
0 g
s
.857 .498 .373 r
.22913 .3184 m .21614 .31205 L .2131 .30133 L p F P
0 g
s
.239 .755 .835 r
.4646 .48808 m .46828 .4881 L .49834 .48377 L p F P
0 g
s
.149 .692 .75 r
.49839 .48377 m .49834 .48377 L .46828 .4881 L p F P
0 g
s
.027 .599 .715 r
.42878 .36587 m .42121 .36382 L .3951 .36676 L p F P
0 g
s
.552 .813 .994 r
.3951 .36676 m .42121 .36382 L .42002 .36309 L p F P
0 g
s
.552 .813 .994 r
.38738 .36432 m .3951 .36676 L p .42002 .36309 L F P
0 g
s
.126 0 .175 r
.70586 .37891 m .71039 .37324 L .70665 .3759 L closepath p F P
0 g
s
0 .513 .724 r
.32979 .48775 m .32784 .4875 L .33092 .48793 L closepath p F P
0 g
s
.836 .388 .16 r
.12982 .41099 m .11795 .40444 L .11224 .39439 L p F P
0 g
s
.84 .388 .138 r
.10089 .3876 m .11224 .39439 L .11795 .40444 L p F P
0 g
s
.25 .007 .337 r
.65831 .33605 m .66067 .3344 L .66898 .31952 L p F P
0 g
s
.228 0 .321 r
.68118 .31065 m .66898 .31952 L .66067 .3344 L p F P
0 g
s
.295 .085 .414 r
.66898 .31952 m .68118 .31065 L .68172 .29994 L p F P
0 g
s
.759 .286 .12 r
.24927 .33412 m .24126 .33113 L .24592 .33019 L closepath p F P
0 g
s
0 .514 .785 r
.31194 .3568 m .32005 .35904 L .31197 .35586 L p F P
0 g
s
0 .514 .785 r
.31197 .35586 m .2937 .35237 L .31194 .3568 L p F P
0 g
s
.549 .841 .998 r
.42878 .36587 m .45509 .36165 L .45143 .35981 L p F P
0 g
s
.549 .841 .998 r
.42121 .36382 m .42878 .36587 L p .45143 .35981 L F P
0 g
s
.054 .602 .835 r
.32784 .4875 m .32979 .48775 L .32175 .48561 L p F P
0 g
s
.054 .602 .835 r
.32175 .48561 m .30685 .4842 L .32784 .4875 L p F P
0 g
s
.898 .551 .381 r
.14462 .33727 m .1337 .33027 L .13157 .31927 L p F P
0 g
s
.908 .559 .369 r
.12111 .31196 m .13157 .31927 L .1337 .33027 L p F P
0 g
s
.911 .602 .447 r
.13157 .31927 m .12111 .31196 L .12034 .30057 L p F P
0 g
s
.922 .612 .438 r
.1104 .293 m .12034 .30057 L .12111 .31196 L p F P
0 g
s
.919 .644 .503 r
.12034 .30057 m .1104 .293 L .11093 .28123 L p F P
0 g
s
.723 .199 0 r
.19995 .38635 m .19285 .37925 L .18404 .37788 L p F P
0 g
s
.726 .209 0 r
.21388 .39219 m .19995 .38635 L .19285 .37925 L p F P
0 g
s
.208 .042 .423 r
.75389 .30045 m .7684 .28581 L p .75208 .31322 L F P
0 g
s
.208 .042 .423 r
.75208 .31322 m .75208 .31249 L .75389 .30045 L p F P
0 g
s
.241 .096 .475 r
.75389 .30045 m .7684 .28581 L .76847 .27352 L p F P
0 g
s
.038 0 0 r
.52276 .34784 m .5214 .3486 L .49389 .35612 L p F P
0 g
s
.258 .766 .761 r
.48896 .35699 m .49389 .35612 L .5214 .3486 L p F P
0 g
s
.893 .539 .367 r
.14471 .33732 m .14462 .33727 L .14469 .33726 L closepath p F P
0 g
s
.232 .036 .397 r
.69444 .28908 m .68172 .29994 L .68118 .31065 L p F P
0 g
s
.291 .123 .473 r
.68172 .29994 m .69444 .28908 L .69528 .27662 L p F P
0 g
s
.87 .474 .284 r
.16037 .35454 m .14864 .3478 L .14471 .33732 L p F P
0 g
s
.877 .474 .258 r
.14462 .33727 m .14471 .33732 L .14864 .3478 L p F P
0 g
s
.93 .655 .497 r
.1015 .2734 m .11093 .28123 L .1104 .293 L p F P
0 g
s
.877 .474 .258 r
.13561 .33601 m .14462 .33727 L p .14864 .3478 L F P
0 g
s
.886 .497 .288 r
.13561 .33601 m .1337 .33027 L .14462 .33727 L closepath p F P
0 g
s
.187 .696 .899 r
.35984 .43065 m .37526 .43053 L p .34157 .42863 L F P
0 g
s
.187 .696 .899 r
.34157 .42863 m .34479 .42945 L .35984 .43065 L p F P
0 g
s
.816 .383 .212 r
.24126 .33113 m .23496 .32827 L .22913 .3184 L p F P
0 g
s
.82 .373 .171 r
.21614 .31205 m .22913 .3184 L .23496 .32827 L p F P
0 g
s
0 0 0 r
.5589 .4697 m .56369 .46784 L .58997 .4591 L p F P
0 g
s
0 0 0 r
.56369 .46784 m .5589 .4697 L .53211 .47688 L p F P
0 g
s
0 0 0 r
.59253 .4576 m .58997 .4591 L .56369 .46784 L p F P
0 g
s
.028 .593 .787 r
.36336 .49042 m .35548 .48811 L .32979 .48775 L p F P
0 g
s
.336 .755 .977 r
.32979 .48775 m .35548 .48811 L .34865 .48514 L p F P
0 g
s
.336 .755 .977 r
.32175 .48561 m .32979 .48775 L p .34865 .48514 L F P
0 g
s
.486 0 0 r
.24122 .40569 m .23361 .40174 L .22504 .40011 L p F P
0 g
s
.502 0 0 r
.2572 .41078 m .24122 .40569 L .23361 .40174 L p F P
0 g
s
.359 .815 .935 r
.44289 .42927 m .44858 .43025 L .46105 .42873 L p F P
0 g
s
.034 0 0 r
.65132 .42662 m .65263 .42445 L .67389 .40934 L p F P
0 g
s
.247 .758 .756 r
.52697 .47779 m .53211 .47688 L .5589 .4697 L p F P
0 g
s
.901 .52 .298 r
.08574 .37015 m .08428 .36511 L .07508 .36207 L p F P
0 g
s
.022 0 0 r
.60204 .38586 m .60455 .38224 L .6218 .37122 L p F P
0 g
s
.336 .137 .455 r
.62038 .27 m .60612 .28007 L .6058 .29129 L p F P
0 g
s
.793 .303 .036 r
.12982 .41099 m .13188 .41382 L .12287 .41114 L p F P
0 g
s
.793 .303 .036 r
.12287 .41114 m .11795 .40444 L .12982 .41099 L p F P
0 g
s
.582 .006 0 r
.21388 .39219 m .22504 .40011 L .22418 .39985 L p F P
0 g
s
.582 .006 0 r
.19995 .38635 m .21388 .39219 L p .22418 .39985 L F P
0 g
s
.174 0 .231 r
.65782 .33822 m .66067 .3344 L .65831 .33605 L closepath p F P
0 g
s
0 0 0 r
.54486 .41079 m .56637 .40337 L .57114 .40167 L p F P
0 g
s
0 0 0 r
.54431 .41108 m .56637 .40337 L .54486 .41079 L closepath p F P
0 g
s
.265 0 0 r
.2572 .41078 m .26651 .41443 L .25815 .41156 L p F P
0 g
s
.265 0 0 r
.25815 .41156 m .24122 .40569 L .2572 .41078 L p F P
0 g
s
.072 .617 .844 r
.34157 .42863 m .33597 .42819 L .34479 .42945 L closepath p F P
0 g
s
.831 .385 .17 r
.17841 .371 m .16612 .3645 L .16037 .35454 L p F P
0 g
s
.835 .383 .143 r
.14864 .3478 m .16037 .35454 L .16612 .3645 L p F P
0 g
s
.094 0 .147 r
.71039 .37324 m .72816 .36021 L p .70427 .38457 L F P
0 g
s
.094 0 .147 r
.70427 .38457 m .70586 .37891 L .71039 .37324 L p F P
0 g
s
.167 0 .246 r
.71039 .37324 m .72816 .36021 L .72989 .35096 L p F P
0 g
s
.884 .589 .483 r
.20064 .29474 m .18913 .28808 L .19313 .27907 L p F P
0 g
s
.895 .604 .487 r
.18865 .27624 m .19313 .27907 L .18913 .28808 L p F P
0 g
s
.508 0 0 r
.17291 .44178 m .187 .44746 L .20037 .4554 L p F P
0 g
s
.646 .091 0 r
.1723 .44133 m .17291 .44178 L .187 .44746 L p F P
0 g
s
.533 0 0 r
.21131 .4595 m .20037 .4554 L .187 .44746 L p F P
0 g
s
.359 .815 .935 r
.46105 .42873 m .47675 .42609 L p .44289 .42927 L F P
0 g
s
.278 .778 .87 r
.47675 .42609 m .46105 .42873 L .47904 .42623 L closepath p F P
0 g
s
.167 0 .175 r
.69515 .39036 m .70427 .38457 L .70586 .37891 L closepath p F P
0 g
s
.123 0 0 r
.30806 .4242 m .31483 .42483 L .33597 .42819 L p F P
0 g
s
.07 .611 .849 r
.31483 .42483 m .30376 .42301 L .30806 .4242 L closepath p F P
0 g
s
0 0 0 r
.54431 .41108 m .53736 .41301 L .51058 .4204 L p F P
0 g
s
.256 .755 .699 r
.56637 .40337 m .54431 .41108 L .53736 .41301 L p F P
0 g
s
.225 0 0 r
.23116 .46579 m .2465 .47114 L .24235 .46966 L p F P
0 g
s
.225 0 0 r
.21518 .46081 m .23116 .46579 L p .24235 .46966 L F P
0 g
s
.458 0 0 r
.21347 .46007 m .21518 .46081 L .23116 .46579 L p F P
0 g
s
0 .453 .716 r
.28649 .48068 m .26848 .47638 L .25491 .47334 L p F P
0 g
s
0 .457 .722 r
.26848 .47638 m .25491 .47334 L .2465 .47114 L p F P
0 g
s
.22 .698 .936 r
.33597 .42819 m .34157 .42863 L .3336 .42539 L p F P
0 g
s
.22 .698 .936 r
.3336 .42539 m .31483 .42483 L .33597 .42819 L p F P
0 g
s
.126 .667 .839 r
.39705 .49127 m .38933 .48899 L .36336 .49042 L p F P
0 g
s
.415 .793 .992 r
.36336 .49042 m .38933 .48899 L .38553 .48729 L p F P
0 g
s
.415 .793 .992 r
.35548 .48811 m .36336 .49042 L p .38553 .48729 L F P
0 g
s
.151 0 .074 r
.67389 .40934 m .6787 .4067 L .67938 .40506 L closepath p F P
0 g
s
.034 0 0 r
.67389 .40934 m .6787 .4067 L p .65132 .42662 L F P
0 g
s
.021 .579 .814 r
.30685 .4842 m .32175 .48561 L p .28819 .481 L F P
0 g
s
.021 .579 .814 r
.28819 .481 m .28952 .48133 L .30685 .4842 L p F P
0 g
s
.133 0 .196 r
.66067 .3344 m .67986 .3205 L p .65612 .34504 L F P
0 g
s
.133 0 .196 r
.65612 .34504 m .65782 .33822 L .66067 .3344 L p F P
0 g
s
.228 0 .321 r
.66067 .3344 m .67986 .3205 L .68118 .31065 L p F P
0 g
s
.068 0 .039 r
.69515 .39036 m .70427 .38457 L p .6787 .4067 L F P
0 g
s
.068 0 .039 r
.6787 .4067 m .67938 .40506 L .69515 .39036 L p F P
0 g
s
.482 0 0 r
.24126 .33113 m .24927 .33412 L .26143 .34199 L p F P
0 g
s
.573 0 0 r
.27626 .34764 m .26143 .34199 L .24927 .33412 L p F P
0 g
s
.213 .737 .765 r
.52697 .47779 m .49893 .48365 L .49839 .48377 L p F P
0 g
s
.284 .785 .839 r
.49893 .48365 m .49834 .48377 L .49839 .48377 L closepath p F P
0 g
s
.356 .825 .899 r
.49116 .4833 m .49834 .48377 L .49893 .48365 L p F P
0 g
s
.239 .755 .835 r
.49834 .48377 m .49116 .4833 L .4646 .48808 L p F P
0 g
s
.261 .77 .812 r
.52508 .47791 m .49893 .48365 L .52697 .47779 L closepath p F P
0 g
s
.356 .825 .899 r
.49893 .48365 m .52508 .47791 L p .49116 .4833 L F P
0 g
s
.022 0 0 r
.6218 .37122 m .63027 .36686 L p .60204 .38586 L F P
0 g
s
.185 0 .091 r
.6218 .37122 m .63027 .36686 L .63131 .36442 L closepath p F P
0 g
s
.218 0 .228 r
.64578 .35139 m .65612 .34504 L .65782 .33822 L closepath p F P
0 g
s
.237 .666 .959 r
.2937 .35237 m .31197 .35586 L .30528 .3519 L p F P
0 g
s
.237 .666 .959 r
.28109 .3493 m .2937 .35237 L p .30528 .3519 L F P
0 g
s
.011 0 0 r
.54953 .33769 m .55316 .33362 L .57771 .32231 L p F P
0 g
s
.223 0 .109 r
.58103 .31431 m .57771 .32231 L .55316 .33362 L p F P
0 g
s
.111 0 0 r
.55316 .33362 m .54953 .33769 L .52276 .34784 L p F P
0 g
s
.919 .573 .366 r
.07233 .35214 m .06238 .34467 L .06048 .33361 L p F P
0 g
s
.927 .58 .354 r
.05097 .32591 m .06048 .33361 L .06238 .34467 L p F P
0 g
s
.931 .614 .418 r
.06048 .33361 m .05097 .32591 L .05007 .31458 L p F P
0 g
s
.765 .257 0 r
.17841 .371 m .18404 .37788 L .17859 .37635 L p F P
0 g
s
.765 .257 0 r
.16612 .3645 m .17841 .371 L p .17859 .37635 L F P
0 g
s
.769 .268 .016 r
.14999 .4268 m .13742 .42053 L .13188 .41382 L p F P
0 g
s
.767 .26 0 r
.13742 .42053 m .13188 .41382 L .12287 .41114 L p F P
0 g
s
.909 .53 .29 r
.07233 .35214 m .07508 .36207 L .07249 .36081 L p F P
0 g
s
.909 .53 .29 r
.06238 .34467 m .07233 .35214 L p .07249 .36081 L F P
0 g
s
.94 .622 .408 r
.04099 .30665 m .05007 .31458 L .05097 .32591 L p F P
0 g
s
.939 .649 .463 r
.05007 .31458 m .04099 .30665 L .04104 .29505 L p F P
0 g
s
.693 .153 0 r
.17117 .44102 m .15972 .43576 L .14999 .4268 L p F P
0 g
s
.685 .139 0 r
.13742 .42053 m .14999 .4268 L .15972 .43576 L p F P
0 g
s
.192 .715 .862 r
.43081 .4905 m .42325 .4885 L .39705 .49127 L p F P
0 g
s
.456 .816 .996 r
.39705 .49127 m .42325 .4885 L .41994 .48707 L p F P
0 g
s
.456 .816 .996 r
.38933 .48899 m .39705 .49127 L p .41994 .48707 L F P
0 g
s
0 0 0 r
.62191 .4442 m .61949 .44628 L .59253 .4576 L p F P
0 g
s
0 0 0 r
.58997 .4591 m .59253 .4576 L .61949 .44628 L p F P
0 g
s
.149 0 .087 r
.60416 .30104 m .58103 .31431 L .57771 .32231 L p F P
0 g
s
.293 .022 .32 r
.6058 .29129 m .60416 .30104 L .58103 .31431 L p F P
0 g
s
0 0 0 r
.64654 .43247 m .65132 .42662 L .67469 .41381 L p F P
0 g
s
0 0 0 r
.65132 .42662 m .64654 .43247 L p .62191 .4442 L F P
0 g
s
.034 0 0 r
.6787 .4067 m .67469 .41381 L .65132 .42662 L p F P
0 g
s
.273 .108 .467 r
.70176 .2708 m .69528 .27662 L .69444 .28908 L p F P
0 g
s
.454 .848 .977 r
.49116 .4833 m .4646 .48808 L .4572 .48668 L p F P
0 g
s
.228 .743 .86 r
.4646 .48808 m .4572 .48668 L .43081 .4905 L p F P
0 g
s
.086 0 .047 r
.63027 .36686 m .63131 .36442 L .64578 .35139 L p F P
0 g
s
.877 .463 .23 r
.10089 .3876 m .08998 .3806 L .08574 .37015 L p F P
0 g
s
.883 .466 .211 r
.07532 .36292 m .08574 .37015 L .08998 .3806 L p F P
0 g
s
.901 .52 .298 r
.07508 .36207 m .07532 .36292 L .08574 .37015 L p F P
0 g
s
.335 .736 .982 r
.34805 .36009 m .34228 .35893 L .32005 .35904 L p F P
0 g
s
.279 .729 .959 r
.34228 .35893 m .32005 .35904 L .31197 .35586 L p F P
0 g
s
.086 0 .047 r
.64578 .35139 m .65612 .34504 L p .63027 .36686 L F P
0 g
s
0 0 0 r
.5214 .3486 m .52276 .34784 L .54953 .33769 L p F P
0 g
s
.352 .823 .896 r
.47675 .42609 m .47904 .42623 L .50798 .42044 L p F P
0 g
s
.228 .748 .791 r
.51058 .4204 m .50798 .42044 L .47904 .42623 L p F P
0 g
s
.47 .834 .993 r
.43081 .4905 m .4572 .48668 L .45232 .48483 L p F P
0 g
s
.47 .834 .993 r
.42325 .4885 m .43081 .4905 L p .45232 .48483 L F P
0 g
s
.249 .071 .434 r
.75193 .31335 m .75208 .31322 L .75208 .31249 L closepath p F P
0 g
s
.895 .604 .487 r
.18913 .28808 m .1888 .28787 L .18865 .27624 L p F P
0 g
s
.908 .616 .48 r
.17802 .26888 m .18865 .27624 L .1888 .28787 L p F P
0 g
s
.1 0 .223 r
.74119 .34147 m .72989 .35096 L .72816 .36021 L p F P
0 g
s
.169 0 .313 r
.72989 .35096 m .74119 .34147 L .74765 .32704 L p F P
0 g
s
.867 .502 .355 r
.21614 .31205 m .20372 .30544 L .20064 .29474 L p F P
0 g
s
.878 .506 .335 r
.18913 .28808 m .20064 .29474 L .20372 .30544 L p F P
0 g
s
.199 .001 .371 r
.75208 .31322 m .75193 .31335 L .74765 .32704 L p F P
0 g
s
.142 0 .354 r
.76658 .29872 m .75208 .31322 L .75151 .32365 L p F P
0 g
s
.208 .042 .423 r
.7684 .28581 m .76658 .29872 L .75208 .31322 L p F P
0 g
s
.199 .001 .371 r
.74765 .32704 m .75151 .32365 L .75208 .31322 L p F P
0 g
s
0 0 0 r
.61949 .44628 m .64356 .43405 L .62191 .4442 L closepath p F P
0 g
s
0 0 0 r
.64654 .43247 m .64356 .43405 L .62191 .4442 L p F P
0 g
s
.068 0 .039 r
.70427 .38457 m .70114 .39245 L .6787 .4067 L p F P
0 g
s
0 0 0 r
.70114 .39245 m .6787 .4067 L .67469 .41381 L p F P
0 g
s
.187 .696 .899 r
.37526 .43053 m .36745 .42701 L .34157 .42863 L p F P
0 g
s
.503 .786 .996 r
.36745 .42701 m .34157 .42863 L .3336 .42539 L p F P
0 g
s
0 .489 .742 r
.28819 .481 m .28649 .48068 L .28952 .48133 L closepath p F P
0 g
s
.84 .388 .138 r
.11795 .40444 m .10653 .39767 L .10089 .3876 L p F P
0 g
s
.844 .388 .115 r
.08998 .3806 m .10089 .3876 L .10653 .39767 L p F P
0 g
s
.482 0 0 r
.23726 .33063 m .24126 .33113 L p .26143 .34199 L F P
0 g
s
.729 .209 0 r
.23726 .33063 m .23496 .32827 L .24126 .33113 L closepath p F P
0 g
s
.188 .68 .921 r
.31483 .42483 m .3336 .42539 L p .29991 .42166 L F P
0 g
s
.188 .68 .921 r
.29991 .42166 m .30376 .42301 L .31483 .42483 L p F P
0 g
s
.365 .835 .869 r
.50798 .42044 m .51058 .4204 L .53736 .41301 L p F P
0 g
s
.82 .373 .171 r
.23496 .32827 m .22209 .32187 L .21614 .31205 L p F P
0 g
s
.821 .361 .128 r
.20372 .30544 m .21614 .31205 L .22209 .32187 L p F P
0 g
s
.381 0 0 r
.21518 .46081 m .21131 .4595 L .21347 .46007 L closepath p F P
0 g
s
.908 .559 .369 r
.1337 .33027 m .1232 .32297 L .12111 .31196 L p F P
0 g
s
.918 .567 .355 r
.11113 .30441 m .12111 .31196 L .1232 .32297 L p F P
0 g
s
.922 .612 .438 r
.12111 .31196 m .11113 .30441 L .1104 .293 L p F P
0 g
s
.486 0 0 r
.22504 .40011 m .22568 .4004 L .24122 .40569 L p F P
0 g
s
0 .417 .743 r
.24122 .40569 m .25815 .41156 L .25637 .41076 L p F P
0 g
s
0 .417 .743 r
.22568 .4004 m .24122 .40569 L p .25637 .41076 L F P
0 g
s
.021 .566 .837 r
.28649 .48068 m .28819 .481 L .27995 .47818 L p F P
0 g
s
.021 .566 .837 r
.27995 .47818 m .26848 .47638 L .28649 .48068 L p F P
0 g
s
.38 0 0 r
.27852 .34863 m .27626 .34764 L .28109 .3493 L closepath p F P
0 g
s
.237 .666 .959 r
.27852 .34863 m .28109 .3493 L p .30528 .3519 L F P
0 g
s
.932 .621 .429 r
.10094 .28519 m .1104 .293 L .11113 .30441 L p F P
0 g
s
.93 .655 .497 r
.1104 .293 m .10094 .28519 L .1015 .2734 L p F P
0 g
s
.894 .499 .265 r
.1337 .33027 m .13561 .33601 L .12658 .33312 L p F P
0 g
s
.894 .499 .265 r
.12658 .33312 m .1232 .32297 L .1337 .33027 L p F P
0 g
s
.582 .006 0 r
.22418 .39985 m .21174 .39454 L .19995 .38635 L p F P
0 g
s
.55 0 0 r
.18655 .38027 m .19995 .38635 L .21174 .39454 L p F P
0 g
s
.723 .199 0 r
.18404 .37788 m .18655 .38027 L .19995 .38635 L p F P
0 g
s
0 0 0 r
.54953 .33769 m .54733 .33904 L .5214 .3486 L p F P
0 g
s
.391 .85 .828 r
.51567 .34939 m .5214 .3486 L .54733 .33904 L p F P
0 g
s
.258 .766 .761 r
.5214 .3486 m .51567 .34939 L .48896 .35699 L p F P
0 g
s
.218 .079 .468 r
.77084 .27098 m .76847 .27352 L .7684 .28581 L p F P
0 g
s
.613 .044 0 r
.17291 .44178 m .17117 .44102 L .1723 .44133 L closepath p F P
0 g
s
.94 .666 .491 r
.09255 .26533 m .1015 .2734 L .10094 .28519 L p F P
0 g
s
.021 .579 .814 r
.32175 .48561 m .31368 .48242 L .28819 .481 L p F P
0 g
s
.321 .73 .979 r
.28819 .481 m .31368 .48242 L .30801 .47954 L p F P
0 g
s
.321 .73 .979 r
.27995 .47818 m .28819 .481 L p .30801 .47954 L F P
0 g
s
0 0 0 r
.5981 .38956 m .60204 .38586 L .62588 .37364 L p F P
0 g
s
0 0 0 r
.60204 .38586 m .5981 .38956 L .57114 .40167 L p F P
0 g
s
.022 0 0 r
.63027 .36686 m .62588 .37364 L .60204 .38586 L p F P
0 g
s
.287 .759 .937 r
.40905 .43068 m .40139 .42718 L .37526 .43053 L p F P
0 g
s
.556 .801 .99 r
.40139 .42718 m .37526 .43053 L .36745 .42701 L p F P
0 g
s
.498 .792 .998 r
.38574 .36331 m .36686 .3613 L .35363 .36305 L p F P
0 g
s
.479 .8 1 r
.36686 .3613 m .34805 .36009 L .35363 .36305 L closepath p F P
0 g
s
.225 0 0 r
.24235 .46966 m .23435 .46708 L .21518 .46081 L p F P
0 g
s
0 .432 .75 r
.21131 .4595 m .21518 .46081 L .23435 .46708 L p F P
0 g
s
.155 0 .297 r
.69074 .30252 m .68118 .31065 L .67986 .3205 L p F P
0 g
s
.232 .036 .397 r
.68118 .31065 m .69074 .30252 L .69444 .28908 L p F P
0 g
s
.788 .29 0 r
.11795 .40444 m .12287 .41114 L .11447 .40779 L p F P
0 g
s
.788 .29 0 r
.10653 .39767 m .11795 .40444 L p .11447 .40779 L F P
0 g
s
0 0 0 r
.65296 .35299 m .63027 .36686 L .62588 .37364 L p F P
0 g
s
.086 0 .047 r
.65612 .34504 m .65296 .35299 L .63027 .36686 L p F P
0 g
s
.508 0 0 r
.20037 .4554 m .1863 .4497 L .17291 .44178 L p F P
0 g
s
.455 0 0 r
.17117 .44102 m .17291 .44178 L .1863 .4497 L p F P
0 g
s
.047 .583 .854 r
.29991 .42166 m .29515 .42097 L .30376 .42301 L closepath p F P
0 g
s
.182 0 0 r
.26651 .41443 m .27754 .41642 L .29515 .42097 L p F P
0 g
s
0 .543 .822 r
.27754 .41642 m .26651 .41443 L .25815 .41156 L p F P
0 g
s
.835 .383 .143 r
.16612 .3645 m .15435 .35776 L .14864 .3478 L p F P
0 g
s
.839 .38 .113 r
.13743 .34081 m .14864 .3478 L .15435 .35776 L p F P
0 g
s
.877 .474 .258 r
.14864 .3478 m .13743 .34081 L .13561 .33601 L p F P
0 g
s
.352 .823 .896 r
.50798 .42044 m .50341 .41989 L .47675 .42609 L p F P
0 g
s
.535 .868 .993 r
.50341 .41989 m .47675 .42609 L .4694 .42395 L p F P
0 g
s
.359 .815 .935 r
.47675 .42609 m .4694 .42395 L .44289 .42927 L p F P
0 g
s
0 .362 .691 r
.27023 .34517 m .26143 .34199 L .27626 .34764 L p F P
0 g
s
0 .362 .691 r
.27626 .34764 m .27852 .34863 L .27023 .34517 L p F P
0 g
s
.23 0 .306 r
.61749 .28308 m .6058 .29129 L .60416 .30104 L p F P
0 g
s
.336 .137 .455 r
.6058 .29129 m .61749 .28308 L .62038 .27 L p F P
0 g
s
.564 .884 .99 r
.48896 .35699 m .51567 .34939 L .50918 .34733 L p F P
0 g
s
.564 .884 .99 r
.48167 .3551 m .48896 .35699 L p .50918 .34733 L F P
0 g
s
.48 .866 .974 r
.45509 .36165 m .48167 .3551 L .48896 .35699 L p F P
0 g
s
.341 .795 .947 r
.44289 .42927 m .43539 .42621 L .40905 .43068 L p F P
0 g
s
.574 .816 .99 r
.43539 .42621 m .40905 .43068 L .40139 .42718 L p F P
0 g
s
.455 0 0 r
.1635 .43856 m .17117 .44102 L p .1863 .4497 L F P
0 g
s
.597 .024 0 r
.1635 .43856 m .15972 .43576 L .17117 .44102 L closepath p F P
0 g
s
0 0 0 r
.56637 .40337 m .57101 .40175 L .57114 .40167 L closepath p F P
0 g
s
.256 .755 .699 r
.57101 .40175 m .56637 .40337 L p .53736 .41301 L F P
0 g
s
.695 .154 0 r
.23496 .32827 m .23726 .33063 L .2287 .32816 L p F P
0 g
s
.695 .154 0 r
.2287 .32816 m .22209 .32187 L .23496 .32827 L p F P
0 g
s
.003 0 .018 r
.7201 .37298 m .70427 .38457 L .70114 .39245 L p F P
0 g
s
.094 0 .147 r
.72704 .36432 m .7201 .37298 L .70427 .38457 L p F P
0 g
s
.094 0 .147 r
.72816 .36021 m .72704 .36432 L p .70427 .38457 L F P
0 g
s
.567 .839 .996 r
.4694 .42395 m .44289 .42927 L .43539 .42621 L p F P
0 g
s
0 .432 .75 r
.20486 .45751 m .21131 .4595 L p .23435 .46708 L F P
0 g
s
.392 0 0 r
.20486 .45751 m .20037 .4554 L .21131 .4595 L closepath p F P
0 g
s
.552 .813 .994 r
.42002 .36309 m .39255 .3633 L .38738 .36432 L p F P
0 g
s
.554 .811 .993 r
.39255 .3633 m .38574 .36331 L .38738 .36432 L closepath p F P
0 g
s
0 0 0 r
.58997 .4591 m .58587 .46075 L .5589 .4697 L p F P
0 g
s
0 0 0 r
.61949 .44628 m .61527 .44896 L .58997 .4591 L p F P
0 g
s
.263 .751 .657 r
.58587 .46075 m .58997 .4591 L .61527 .44896 L p F P
0 g
s
.339 .819 .799 r
.55449 .47041 m .5589 .4697 L .58587 .46075 L p F P
0 g
s
.247 .758 .756 r
.5589 .4697 m .55449 .47041 L .52697 .47779 L p F P
0 g
s
.332 .816 .84 r
.52508 .47791 m .52697 .47779 L .55449 .47041 L p F P
0 g
s
.169 .043 .455 r
.78035 .25954 m .77084 .27098 L .77139 .28263 L p F P
0 g
s
.218 .079 .468 r
.7684 .28581 m .77139 .28263 L .77084 .27098 L p F P
0 g
s
.564 .849 .997 r
.45143 .35981 m .45509 .36165 L .48167 .3551 L p F P
0 g
s
.211 .063 .451 r
.71081 .26135 m .70176 .2708 L .70199 .28234 L p F P
0 g
s
.273 .108 .467 r
.69444 .28908 m .70199 .28234 L .70176 .2708 L p F P
0 g
s
.237 .666 .959 r
.30528 .3519 m .30256 .35099 L .27852 .34863 L p F P
0 g
s
.155 .646 .918 r
.30256 .35099 m .27852 .34863 L .27023 .34517 L p F P
0 g
s
.177 .654 .93 r
.29515 .42097 m .29991 .42166 L .29175 .4178 L p F P
0 g
s
.177 .654 .93 r
.29175 .4178 m .27754 .41642 L .29515 .42097 L p F P
0 g
s
.139 0 .293 r
.75151 .32365 m .74765 .32704 L .74119 .34147 L p F P
0 g
s
.549 .841 .998 r
.45143 .35981 m .42638 .36266 L .42121 .36382 L p F P
0 g
s
.574 .821 .992 r
.42638 .36266 m .42002 .36309 L .42121 .36382 L closepath p F P
0 g
s
.765 .257 0 r
.17859 .37635 m .17391 .37388 L .16612 .3645 L p F P
0 g
s
.759 .244 0 r
.15435 .35776 m .16612 .3645 L .17391 .37388 L p F P
0 g
s
0 0 0 r
.57101 .40175 m .57114 .40167 L .5981 .38956 L p F P
0 g
s
.207 .014 .384 r
.70199 .28234 m .69444 .28908 L .69074 .30252 L p F P
0 g
s
0 0 0 r
.5981 .38956 m .59591 .39095 L .57101 .40175 L p F P
0 g
s
.356 .82 .739 r
.56432 .40378 m .57101 .40175 L .59591 .39095 L p F P
0 g
s
.256 .755 .699 r
.53736 .41301 m .56432 .40378 L .57101 .40175 L p F P
0 g
s
.685 .139 0 r
.15972 .43576 m .14708 .42951 L .13742 .42053 L p F P
0 g
s
.674 .124 0 r
.12532 .41405 m .13742 .42053 L .14708 .42951 L p F P
0 g
s
.767 .26 0 r
.12287 .41114 m .12532 .41405 L .13742 .42053 L p F P
0 g
s
.696 .155 0 r
.18655 .38027 m .17859 .37635 L .18404 .37788 L closepath p F P
0 g
s
.454 .873 .939 r
.50341 .41989 m .50798 .42044 L .53557 .413 L p F P
0 g
s
.365 .835 .869 r
.53736 .41301 m .53557 .413 L .50798 .42044 L p F P
0 g
s
.317 .12 .447 r
.62769 .26459 m .62038 .27 L .61749 .28308 L p F P
0 g
s
.02 0 .032 r
.67303 .33283 m .65612 .34504 L .65296 .35299 L p F P
0 g
s
.133 0 .196 r
.67872 .32532 m .67303 .33283 L .65612 .34504 L p F P
0 g
s
.133 0 .196 r
.67986 .3205 m .67872 .32532 L p .65612 .34504 L F P
0 g
s
.336 .755 .977 r
.34865 .48514 m .34554 .48476 L .32175 .48561 L p F P
0 g
s
.327 .754 .973 r
.34554 .48476 m .32175 .48561 L .31368 .48242 L p F P
0 g
s
0 0 0 r
.61527 .44896 m .61949 .44628 L .64356 .43405 L p F P
0 g
s
.116 .622 .898 r
.26848 .47638 m .27995 .47818 L .27169 .47448 L p F P
0 g
s
.116 .622 .898 r
.27169 .47448 m .25083 .47194 L .26848 .47638 L p F P
0 g
s
0 .457 .722 r
.2465 .47114 m .25083 .47194 L .26848 .47638 L p F P
0 g
s
.907 .523 .28 r
.07532 .36292 m .07249 .36081 L .07508 .36207 L closepath p F P
0 g
s
.927 .58 .354 r
.06238 .34467 m .05283 .33699 L .05097 .32591 L p F P
0 g
s
.935 .586 .34 r
.04186 .318 m .05097 .32591 L .05283 .33699 L p F P
0 g
s
.94 .622 .408 r
.05097 .32591 m .04186 .318 L .04099 .30665 L p F P
0 g
s
.909 .53 .29 r
.07249 .36081 m .06532 .35547 L .06238 .34467 L p F P
0 g
s
.916 .534 .274 r
.05283 .33699 m .06238 .34467 L .06532 .35547 L p F P
0 g
s
.885 .477 .236 r
.13743 .34081 m .13561 .33601 L .12658 .33312 L p F P
0 g
s
.584 .803 .983 r
.37966 .35909 m .38574 .36331 L .39255 .3633 L p F P
0 g
s
.549 .79 .988 r
.37966 .35909 m .36686 .3613 L .38574 .36331 L closepath p F P
0 g
s
.39 0 0 r
.22568 .4004 m .22418 .39985 L .22504 .40011 L closepath p F P
0 g
s
.583 .804 .984 r
.41364 .35862 m .39255 .3633 L .42002 .36309 L closepath p F P
0 g
s
.584 .803 .983 r
.39255 .3633 m .41364 .35862 L p .37966 .35909 L F P
0 g
s
.482 0 0 r
.26143 .34199 m .24701 .33615 L .23726 .33063 L p F P
0 g
s
.484 0 0 r
.24701 .33615 m .23726 .33063 L .2287 .32816 L p F P
0 g
s
.878 .506 .335 r
.18887 .28816 m .18913 .28808 L p .20372 .30544 L F P
0 g
s
.893 .543 .376 r
.18887 .28816 m .1888 .28787 L .18913 .28808 L closepath p F P
0 g
s
.599 .809 .981 r
.41364 .35862 m .42002 .36309 L .42638 .36266 L p F P
0 g
s
.905 .55 .357 r
.1888 .28787 m .18887 .28816 L .17982 .28844 L p F P
0 g
s
.905 .55 .357 r
.17982 .28844 m .17815 .28052 L .1888 .28787 L p F P
0 g
s
.908 .616 .48 r
.1888 .28787 m .17815 .28052 L .17802 .26888 L p F P
0 g
s
.883 .466 .211 r
.08998 .3806 m .07951 .37338 L .07532 .36292 L p F P
0 g
s
.887 .466 .188 r
.07249 .36081 m .07532 .36292 L .07951 .37338 L p F P
0 g
s
.92 .628 .473 r
.16797 .26125 m .17802 .26888 L .17815 .28052 L p F P
0 g
s
.878 .506 .335 r
.20372 .30544 m .1919 .29856 L .18887 .28816 L p F P
0 g
s
.889 .513 .318 r
.1919 .29856 m .18887 .28816 L .17982 .28844 L p F P
0 g
s
0 .417 .743 r
.25637 .41076 m .24462 .40642 L .22568 .4004 L p F P
0 g
s
0 .495 .832 r
.22418 .39985 m .22568 .4004 L .24462 .40642 L p F P
0 g
s
.599 .809 .981 r
.42638 .36266 m .44764 .35749 L p .41364 .35862 L F P
0 g
s
.583 .829 .991 r
.44764 .35749 m .42638 .36266 L .45143 .35981 L closepath p F P
0 g
s
.011 0 0 r
.57771 .32231 m .57642 .32395 L .54953 .33769 L p F P
0 g
s
0 0 0 r
.54733 .33904 m .54953 .33769 L .57642 .32395 L p F P
0 g
s
.396 0 0 r
.21648 .39696 m .21174 .39454 L .22418 .39985 L closepath p F P
0 g
s
0 .495 .832 r
.21648 .39696 m .22418 .39985 L p .24462 .40642 L F P
0 g
s
.332 .816 .84 r
.55449 .47041 m .55198 .47053 L .52508 .47791 L p F P
0 g
s
.464 .875 .947 r
.55198 .47053 m .52508 .47791 L .51795 .47702 L p F P
0 g
s
.356 .825 .899 r
.52508 .47791 m .51795 .47702 L .49116 .4833 L p F P
0 g
s
.821 .361 .128 r
.22209 .32187 m .2098 .31521 L .20372 .30544 L p F P
0 g
s
.819 .346 .08 r
.1919 .29856 m .20372 .30544 L .2098 .31521 L p F P
0 g
s
.188 .68 .921 r
.3336 .42539 m .32561 .42092 L .29991 .42166 L p F P
0 g
s
.493 .762 .99 r
.32561 .42092 m .29991 .42166 L .29175 .4178 L p F P
0 g
s
.844 .388 .115 r
.10653 .39767 m .09556 .39068 L .08998 .3806 L p F P
0 g
s
.846 .386 .089 r
.07951 .37338 m .08998 .3806 L .09556 .39068 L p F P
0 g
s
0 .545 .829 r
.25083 .47194 m .24235 .46966 L .2465 .47114 L closepath p F P
0 g
s
.415 .793 .992 r
.38553 .48729 m .3718 .48651 L .35548 .48811 L p F P
0 g
s
.417 .793 .993 r
.3718 .48651 m .34865 .48514 L .35548 .48811 L closepath p F P
0 g
s
.55 0 0 r
.21174 .39454 m .19847 .3884 L .18655 .38027 L p F P
0 g
s
.504 0 0 r
.17859 .37635 m .18655 .38027 L .19847 .3884 L p F P
0 g
s
.324 0 0 r
.20037 .4554 m .20486 .45751 L .19622 .4541 L p F P
0 g
s
.324 0 0 r
.19622 .4541 m .1863 .4497 L .20037 .4554 L p F P
0 g
s
.534 .8 .995 r
.36686 .3613 m .37966 .35909 L p .34574 .35866 L F P
0 g
s
.534 .8 .995 r
.34574 .35866 m .34805 .36009 L .36686 .3613 L p F P
0 g
s
.075 0 .272 r
.76295 .31227 m .75151 .32365 L .75037 .33344 L p F P
0 g
s
.142 0 .354 r
.75151 .32365 m .76295 .31227 L .76658 .29872 L p F P
0 g
s
.139 0 .293 r
.74119 .34147 m .75037 .33344 L .75151 .32365 L p F P
0 g
s
.166 .008 .408 r
.77139 .28263 m .7684 .28581 L .76658 .29872 L p F P
0 g
s
.918 .567 .355 r
.1232 .32297 m .11319 .31543 L .11113 .30441 L p F P
0 g
s
.927 .574 .34 r
.10164 .29661 m .11113 .30441 L .11319 .31543 L p F P
0 g
s
.932 .621 .429 r
.11113 .30441 m .10164 .29661 L .10094 .28519 L p F P
0 g
s
.887 .466 .188 r
.06597 .3572 m .07249 .36081 L p .07951 .37338 L F P
0 g
s
.892 .479 .207 r
.06597 .3572 m .06532 .35547 L .07249 .36081 L closepath p F P
0 g
s
0 .475 .816 r
.26143 .34199 m .27023 .34517 L .26193 .34048 L p F P
0 g
s
0 .475 .816 r
.26193 .34048 m .24701 .33615 L .26143 .34199 L p F P
0 g
s
.901 .502 .244 r
.1232 .32297 m .12658 .33312 L .12527 .33248 L p F P
0 g
s
.901 .502 .244 r
.11319 .31543 m .1232 .32297 L p .12527 .33248 L F P
0 g
s
.56 0 0 r
.15972 .43576 m .1635 .43856 L .15467 .43497 L p F P
0 g
s
.56 0 0 r
.15467 .43497 m .14708 .42951 L .15972 .43576 L p F P
0 g
s
.755 .238 0 r
.12532 .41405 m .11447 .40779 L .12287 .41114 L closepath p F P
0 g
s
.943 .631 .418 r
.09196 .27713 m .10094 .28519 L .10164 .29661 L p F P
0 g
s
.94 .666 .491 r
.10094 .28519 m .09196 .27713 L .09255 .26533 L p F P
0 g
s
.1 0 .223 r
.72816 .36021 m .73239 .35667 L .74119 .34147 L p F P
0 g
s
.063 0 .195 r
.75037 .33344 m .74119 .34147 L .73239 .35667 L p F P
0 g
s
.023 0 .119 r
.72704 .36432 m .73239 .35667 L .72816 .36021 L closepath p F P
0 g
s
.527 .867 .992 r
.49116 .4833 m .51795 .47702 L .51222 .47506 L p F P
0 g
s
.527 .867 .992 r
.48386 .48122 m .49116 .4833 L p .51222 .47506 L F P
0 g
s
.454 .848 .977 r
.4572 .48668 m .48386 .48122 L .49116 .4833 L p F P
0 g
s
.456 .816 .996 r
.41994 .48707 m .40122 .48729 L .38933 .48899 L p F P
0 g
s
.466 .815 .998 r
.40122 .48729 m .38553 .48729 L .38933 .48899 L closepath p F P
0 g
s
.454 .767 .996 r
.34574 .35866 m .34228 .35893 L .34805 .36009 L closepath p F P
0 g
s
.788 .29 0 r
.11447 .40779 m .1137 .40734 L .10653 .39767 L p F P
0 g
s
.785 .284 0 r
.09556 .39068 m .10653 .39767 L .1137 .40734 L p F P
0 g
s
0 0 0 r
.57642 .32395 m .58573 .31775 L .57771 .32231 L closepath p F P
0 g
s
.149 0 .087 r
.60328 .30344 m .60416 .30104 L p .57771 .32231 L F P
0 g
s
.149 0 .087 r
.57771 .32231 m .58573 .31775 L .60328 .30344 L p F P
0 g
s
.276 .699 .968 r
.27754 .41642 m .29175 .4178 L .28356 .41294 L p F P
0 g
s
.276 .699 .968 r
.28356 .41294 m .26001 .41179 L .27754 .41642 L p F P
0 g
s
0 .543 .822 r
.25815 .41156 m .26001 .41179 L .27754 .41642 L p F P
0 g
s
.479 .783 .998 r
.32375 .35454 m .30528 .3519 L .31197 .35586 L closepath p F P
0 g
s
.279 .729 .959 r
.31197 .35586 m .32375 .35454 L .34228 .35893 L p F P
0 g
s
.597 .833 .989 r
.44764 .35749 m .45143 .35981 L .48155 .35502 L p F P
0 g
s
.564 .849 .997 r
.48167 .3551 m .48155 .35502 L .45143 .35981 L p F P
0 g
s
.839 .38 .113 r
.15435 .35776 m .14311 .35078 L .13743 .34081 L p F P
0 g
s
.84 .376 .08 r
.12675 .33357 m .13743 .34081 L .14311 .35078 L p F P
0 g
s
.885 .477 .236 r
.12658 .33312 m .12675 .33357 L .13743 .34081 L p F P
0 g
s
.645 .088 0 r
.22209 .32187 m .2287 .32816 L .22172 .32511 L p F P
0 g
s
.645 .088 0 r
.2098 .31521 m .22209 .32187 L p .22172 .32511 L F P
0 g
s
.458 .884 .902 r
.53557 .413 m .53736 .41301 L .56432 .40378 L p F P
0 g
s
.47 .834 .993 r
.45232 .48483 m .4374 .486 L .42325 .4885 L p F P
0 g
s
.49 .831 .998 r
.4374 .486 m .41994 .48707 L .42325 .4885 L closepath p F P
0 g
s
.497 .847 .994 r
.45232 .48483 m .4572 .48668 L .48386 .48122 L p F P
0 g
s
.155 0 .297 r
.67986 .3205 m .68402 .31698 L .69074 .30252 L p F P
0 g
s
.122 0 .275 r
.70146 .29299 m .69074 .30252 L .68402 .31698 L p F P
0 g
s
.207 .014 .384 r
.69074 .30252 m .70146 .29299 L .70199 .28234 L p F P
0 g
s
.072 .593 .877 r
.25083 .47194 m .27169 .47448 L p .23806 .46798 L F P
0 g
s
.072 .593 .877 r
.23806 .46798 m .24235 .46966 L .25083 .47194 L p F P
0 g
s
.553 .769 .978 r
.34228 .35893 m .34574 .35866 L .33786 .35228 L p F P
0 g
s
.553 .769 .978 r
.33786 .35228 m .32375 .35454 L .34228 .35893 L p F P
0 g
s
.503 .786 .996 r
.3336 .42539 m .35962 .42208 L .36745 .42701 L p F P
0 g
s
.576 .775 .973 r
.3336 .42539 m .35962 .42208 L .35495 .4184 L p F P
0 g
s
.576 .775 .973 r
.32561 .42092 m .3336 .42539 L p .35495 .4184 L F P
0 g
s
.239 .061 .426 r
.64064 .25294 m .62769 .26459 L .6274 .27578 L p F P
0 g
s
.317 .12 .447 r
.61749 .28308 m .6274 .27578 L .62769 .26459 L p F P
0 g
s
0 0 0 r
.64356 .43405 m .64623 .43277 L p .61527 .44896 L F P
0 g
s
0 0 0 r
.64356 .43405 m .64623 .43277 L .64654 .43247 L closepath p F P
0 g
s
.23 0 .306 r
.60416 .30104 m .60803 .29833 L .61749 .28308 L p F P
0 g
s
.195 0 .279 r
.6274 .27578 m .61749 .28308 L .60803 .29833 L p F P
0 g
s
.06 0 .171 r
.67872 .32532 m .68402 .31698 L .67986 .3205 L closepath p F P
0 g
s
0 0 0 r
.67469 .41381 m .67358 .41528 L .64654 .43247 L p F P
0 g
s
0 0 0 r
.64623 .43277 m .64654 .43247 L .67358 .41528 L p F P
0 g
s
.112 0 .392 r
.78041 .27184 m .77139 .28263 L .77138 .29364 L p F P
0 g
s
.169 .043 .455 r
.77139 .28263 m .78041 .27184 L .78035 .25954 L p F P
0 g
s
.166 .008 .408 r
.76658 .29872 m .77138 .29364 L .77139 .28263 L p F P
0 g
s
0 0 0 r
.62588 .37364 m .62513 .37443 L .5981 .38956 L p F P
0 g
s
0 0 0 r
.59591 .39095 m .5981 .38956 L .62513 .37443 L p F P
0 g
s
0 0 0 r
.57642 .32395 m .57183 .3275 L .54733 .33904 L p F P
0 g
s
.462 .888 .831 r
.54258 .33985 m .54733 .33904 L .57183 .3275 L p F P
0 g
s
.391 .85 .828 r
.54733 .33904 m .54258 .33985 L .51567 .34939 L p F P
0 g
s
0 .434 .754 r
.21915 .46176 m .20486 .45751 L .19622 .4541 L p F P
0 g
s
0 .432 .75 r
.23435 .46708 m .21915 .46176 L .20486 .45751 L p F P
0 g
s
.759 .244 0 r
.17391 .37388 m .16213 .36713 L .15435 .35776 L p F P
0 g
s
.749 .23 0 r
.14311 .35078 m .15435 .35776 L .16213 .36713 L p F P
0 g
s
.136 0 .362 r
.71023 .27378 m .70199 .28234 L .70146 .29299 L p F P
0 g
s
.211 .063 .451 r
.70199 .28234 m .71023 .27378 L .71081 .26135 L p F P
0 g
s
.072 0 .085 r
.60328 .30344 m .60803 .29833 L .60416 .30104 L closepath p F P
0 g
s
.674 .124 0 r
.14708 .42951 m .13493 .42303 L .12532 .41405 L p F P
0 g
s
.659 .107 0 r
.11447 .40779 m .12532 .41405 L .13493 .42303 L p F P
0 g
s
.504 0 0 r
.17526 .37511 m .17859 .37635 L p .19847 .3884 L F P
0 g
s
.668 .116 0 r
.17526 .37511 m .17391 .37388 L .17859 .37635 L closepath p F P
0 g
s
0 0 0 r
.64023 .43702 m .64623 .43277 L .66954 .41973 L p F P
0 g
s
0 0 0 r
.67358 .41528 m .66954 .41973 L .64623 .43277 L p F P
0 g
s
0 0 0 r
.64623 .43277 m .64023 .43702 L p .61527 .44896 L F P
0 g
s
.406 .859 .868 r
.55198 .47053 m .55449 .47041 L .58092 .4616 L p F P
0 g
s
.339 .819 .799 r
.58587 .46075 m .58092 .4616 L .55449 .47041 L p F P
0 g
s
.534 .8 .995 r
.37966 .35909 m .37194 .35186 L .34574 .35866 L p F P
0 g
s
.667 .728 .895 r
.37194 .35186 m .34574 .35866 L .33786 .35228 L p F P
0 g
s
0 0 0 r
.67358 .41528 m .68014 .41036 L .67469 .41381 L closepath p F P
0 g
s
0 0 0 r
.70051 .39364 m .70114 .39245 L p .67469 .41381 L F P
0 g
s
0 0 0 r
.67469 .41381 m .68014 .41036 L .70051 .39364 L p F P
0 g
s
.597 .905 .983 r
.50918 .34733 m .51567 .34939 L .54258 .33985 L p F P
0 g
s
.263 .751 .657 r
.61527 .44896 m .613 .44995 L .58587 .46075 L p F P
0 g
s
.411 .861 .816 r
.58092 .4616 m .58587 .46075 L .613 .44995 L p F P
0 g
s
.556 .801 .99 r
.36745 .42701 m .3937 .42209 L .40139 .42718 L p F P
0 g
s
.614 .777 .959 r
.36745 .42701 m .3937 .42209 L .39211 .42074 L p F P
0 g
s
.614 .777 .959 r
.35962 .42208 m .36745 .42701 L p .39211 .42074 L F P
0 g
s
.455 0 0 r
.1863 .4497 m .17273 .44379 L .1635 .43856 L p F P
0 g
s
.436 0 0 r
.17273 .44379 m .1635 .43856 L .15467 .43497 L p F P
0 g
s
.321 .73 .979 r
.30801 .47954 m .30229 .47832 L .27995 .47818 L p F P
0 g
s
.303 .728 .972 r
.30229 .47832 m .27995 .47818 L .27169 .47448 L p F P
0 g
s
.315 0 0 r
.21174 .39454 m .21648 .39696 L .20791 .39289 L p F P
0 g
s
.315 0 0 r
.20791 .39289 m .19847 .3884 L .21174 .39454 L p F P
0 g
s
.454 .873 .939 r
.53557 .413 m .53029 .41221 L .50341 .41989 L p F P
0 g
s
.576 .877 .993 r
.53029 .41221 m .50341 .41989 L .49616 .41714 L p F P
0 g
s
.535 .868 .993 r
.4694 .42395 m .49616 .41714 L .50341 .41989 L p F P
0 g
s
0 0 0 r
.57183 .3275 m .57642 .32395 L .58573 .31775 L p F P
0 g
s
0 0 .083 r
.73239 .35667 m .7486 .34254 L p .72575 .36872 L F P
0 g
s
0 0 .083 r
.72575 .36872 m .72704 .36432 L .73239 .35667 L p F P
0 g
s
.063 0 .195 r
.73239 .35667 m .7486 .34254 L .75037 .33344 L p F P
0 g
s
0 .493 .801 r
.23806 .46798 m .23435 .46708 L .24235 .46966 L closepath p F P
0 g
s
.521 .902 .953 r
.53029 .41221 m .53557 .413 L .5618 .40379 L p F P
0 g
s
.458 .884 .902 r
.56432 .40378 m .5618 .40379 L .53557 .413 L p F P
0 g
s
.147 .633 .919 r
.26001 .41179 m .25637 .41076 L .25815 .41156 L closepath p F P
0 g
s
.584 .803 .983 r
.41364 .35862 m .40604 .3511 L .37966 .35909 L p F P
0 g
s
.678 .717 .879 r
.40604 .3511 m .37966 .35909 L .37194 .35186 L p F P
0 g
s
.574 .816 .99 r
.40139 .42718 m .42784 .42138 L .43539 .42621 L p F P
0 g
s
.627 .783 .956 r
.40139 .42718 m .42784 .42138 L .42598 .41981 L p F P
0 g
s
.627 .783 .956 r
.3937 .42209 m .40139 .42718 L p .42598 .41981 L F P
0 g
s
.916 .556 .337 r
.17815 .28052 m .17982 .28844 L .17472 .28712 L p F P
0 g
s
.916 .556 .337 r
.16807 .2729 m .17815 .28052 L p .17472 .28712 L F P
0 g
s
.92 .628 .473 r
.17815 .28052 m .16807 .2729 L .16797 .26125 L p F P
0 g
s
.916 .534 .274 r
.06532 .35547 m .05575 .3478 L .05283 .33699 L p F P
0 g
s
.922 .538 .255 r
.0437 .32909 m .05283 .33699 L .05575 .3478 L p F P
0 g
s
.935 .586 .34 r
.05283 .33699 m .0437 .32909 L .04186 .318 L p F P
0 g
s
.61 .834 .985 r
.49616 .41714 m .4694 .42395 L .46199 .4199 L p F P
0 g
s
.567 .839 .996 r
.43539 .42621 m .46199 .4199 L .4694 .42395 L p F P
0 g
s
.182 .041 .441 r
.7205 .25058 m .71081 .26135 L .71023 .27378 L p F P
0 g
s
.933 .64 .464 r
.15851 .25333 m .16797 .26125 L .16807 .2729 L p F P
0 g
s
.625 .8 .966 r
.43539 .42621 m .46199 .4199 L .45744 .41634 L p F P
0 g
s
.625 .8 .966 r
.42784 .42138 m .43539 .42621 L p .45744 .41634 L F P
0 g
s
0 0 0 r
.58573 .31775 m .60073 .30879 L p .57183 .3275 L F P
0 g
s
.079 0 .01 r
.58573 .31775 m .60073 .30879 L .60328 .30344 L closepath p F P
0 g
s
.896 .479 .183 r
.06532 .35547 m .06597 .3572 L .05693 .35097 L p F P
0 g
s
.896 .479 .183 r
.05693 .35097 m .05575 .3478 L .06532 .35547 L p F P
0 g
s
0 .323 .674 r
.1863 .4497 m .19622 .4541 L .18756 .44998 L p F P
0 g
s
0 .323 .674 r
.18756 .44998 m .17273 .44379 L .1863 .4497 L p F P
0 g
s
.599 .809 .981 r
.44764 .35749 m .44017 .35053 L .41364 .35862 L p F P
0 g
s
.673 .721 .885 r
.44017 .35053 m .41364 .35862 L .40604 .3511 L p F P
0 g
s
.104 0 .334 r
.77138 .29364 m .76658 .29872 L .76295 .31227 L p F P
0 g
s
.058 0 .114 r
.7201 .37298 m .72575 .36872 L .72704 .36432 L closepath p F P
0 g
s
.487 .816 1 r
.38157 .48539 m .38553 .48729 L .40122 .48729 L p F P
0 g
s
.447 .799 .997 r
.38157 .48539 m .3718 .48651 L .38553 .48729 L closepath p F P
0 g
s
.479 .819 .999 r
.41564 .48507 m .40122 .48729 L .41994 .48707 L closepath p F P
0 g
s
.487 .816 1 r
.40122 .48729 m .41564 .48507 L p .38157 .48539 L F P
0 g
s
.238 .679 .957 r
.26001 .41179 m .28356 .41294 L p .24979 .40748 L F P
0 g
s
.238 .679 .957 r
.24979 .40748 m .25637 .41076 L .26001 .41179 L p F P
0 g
s
.564 .884 .99 r
.50918 .34733 m .48397 .35441 L .48167 .3551 L p F P
0 g
s
.626 .833 .98 r
.48397 .35441 m .48155 .35502 L .48167 .3551 L closepath p F P
0 g
s
.819 .346 .08 r
.2098 .31521 m .19811 .30828 L .1919 .29856 L p F P
0 g
s
.813 .329 .026 r
.18072 .2914 m .1919 .29856 L .19811 .30828 L p F P
0 g
s
.889 .513 .318 r
.17982 .28844 m .18072 .2914 L .1919 .29856 L p F P
0 g
s
.636 .817 .97 r
.47432 .34962 m .48155 .35502 L .48397 .35441 L p F P
0 g
s
.597 .833 .989 r
.48155 .35502 m .47432 .34962 L .44764 .35749 L p F P
0 g
s
.078 .562 .899 r
.24701 .33615 m .26193 .34048 L .25361 .33475 L p F P
0 g
s
.484 0 0 r
.2287 .32816 m .23291 .33015 L .24701 .33615 L p F P
0 g
s
.078 .562 .899 r
.25361 .33475 m .23291 .33015 L .24701 .33615 L p F P
0 g
s
.509 .831 1 r
.41564 .48507 m .41994 .48707 L .4374 .486 L p F P
0 g
s
.635 .077 0 r
.17391 .37388 m .17526 .37511 L .1665 .37101 L p F P
0 g
s
.635 .077 0 r
.1665 .37101 m .16213 .36713 L .17391 .37388 L p F P
0 g
s
0 0 0 r
.60803 .29833 m .6257 .28537 L p .60073 .30879 L F P
0 g
s
0 0 0 r
.60073 .30879 m .60328 .30344 L .60803 .29833 L p F P
0 g
s
.195 0 .279 r
.60803 .29833 m .6257 .28537 L .6274 .27578 L p F P
0 g
s
.662 .749 .914 r
.47432 .34962 m .44764 .35749 L .44017 .35053 L p F P
0 g
s
0 0 0 r
.62513 .37443 m .62984 .37122 L .62588 .37364 L closepath p F P
0 g
s
0 0 0 r
.6521 .35445 m .65296 .35299 L p .62588 .37364 L F P
0 g
s
0 0 0 r
.62588 .37364 m .62984 .37122 L .6521 .35445 L p F P
0 g
s
.001 0 .125 r
.68402 .31698 m .70012 .30273 L p .67766 .32936 L F P
0 g
s
.001 0 .125 r
.67766 .32936 m .67872 .32532 L .68402 .31698 L p F P
0 g
s
.122 0 .275 r
.68402 .31698 m .70012 .30273 L .70146 .29299 L p F P
0 g
s
.003 0 .018 r
.70114 .39245 m .70371 .39057 L .7201 .37298 L p F P
0 g
s
0 0 0 r
.70051 .39364 m .70371 .39057 L .70114 .39245 L closepath p F P
0 g
s
0 0 0 r
.64023 .43702 m .6344 .43985 L .61527 .44896 L p F P
0 g
s
.325 .788 .666 r
.613 .44995 m .6344 .43985 L .61527 .44896 L closepath p F P
0 g
s
.529 .785 .991 r
.32375 .35454 m .33786 .35228 L p .30389 .35098 L F P
0 g
s
.529 .785 .991 r
.30389 .35098 m .30528 .3519 L .32375 .35454 L p F P
0 g
s
.846 .386 .089 r
.09556 .39068 m .08504 .38348 L .07951 .37338 L p F P
0 g
s
.846 .383 .061 r
.06946 .36594 m .07951 .37338 L .08504 .38348 L p F P
0 g
s
.887 .466 .188 r
.07951 .37338 m .06946 .36594 L .06597 .3572 L p F P
0 g
s
.155 .646 .918 r
.27023 .34517 m .2881 .34518 L .30256 .35099 L p F P
0 g
s
.358 .73 .988 r
.2881 .34518 m .27023 .34517 L .26193 .34048 L p F P
0 g
s
.595 .872 .993 r
.50848 .347 m .48397 .35441 L .50918 .34733 L closepath p F P
0 g
s
.636 .817 .97 r
.48397 .35441 m .50848 .347 L p .47432 .34962 L F P
0 g
s
.442 .798 .997 r
.3718 .48651 m .38157 .48539 L p .34757 .48463 L F P
0 g
s
.442 .798 .997 r
.34757 .48463 m .34865 .48514 L .3718 .48651 L p F P
0 g
s
0 0 0 r
.66954 .41973 m .67358 .41528 L .68014 .41036 L p F P
0 g
s
.064 .566 .887 r
.24979 .40748 m .24462 .40642 L .25637 .41076 L closepath p F P
0 g
s
0 0 0 r
.72575 .36872 m .7201 .37298 L .70371 .39057 L p F P
0 g
s
.89 .467 .164 r
.06946 .36594 m .06597 .3572 L .05693 .35097 L p F P
0 g
s
.519 0 0 r
.14708 .42951 m .15467 .43497 L .14583 .43067 L p F P
0 g
s
.519 0 0 r
.14583 .43067 m .13493 .42303 L .14708 .42951 L p F P
0 g
s
.132 .016 .443 r
.78866 .24871 m .78035 .25954 L .78041 .27184 L p F P
0 g
s
.509 .831 1 r
.4374 .486 m .44974 .48374 L p .41564 .48507 L F P
0 g
s
.49 .836 .997 r
.44974 .48374 m .4374 .486 L .45232 .48483 L closepath p F P
0 g
s
.028 .548 .864 r
.23435 .46708 m .23806 .46798 L .2296 .46399 L p F P
0 g
s
.028 .548 .864 r
.2296 .46399 m .21915 .46176 L .23435 .46708 L p F P
0 g
s
.327 .754 .973 r
.31368 .48242 m .32369 .48162 L .34554 .48476 L p F P
0 g
s
.427 .778 .997 r
.32369 .48162 m .30801 .47954 L .31368 .48242 L closepath p F P
0 g
s
0 0 0 r
.68014 .41036 m .69706 .39933 L p .66954 .41973 L F P
0 g
s
0 0 0 r
.68014 .41036 m .69706 .39933 L .70051 .39364 L closepath p F P
0 g
s
.504 0 0 r
.19847 .3884 m .18573 .38202 L .17526 .37511 L p F P
0 g
s
.487 0 0 r
.18573 .38202 m .17526 .37511 L .1665 .37101 L p F P
0 g
s
.927 .574 .34 r
.11319 .31543 m .10366 .30765 L .10164 .29661 L p F P
0 g
s
.936 .581 .323 r
.09263 .28857 m .10164 .29661 L .10366 .30765 L p F P
0 g
s
.943 .631 .418 r
.10164 .29661 m .09263 .28857 L .09196 .27713 L p F P
0 g
s
.901 .502 .244 r
.12527 .33248 m .11669 .32605 L .11319 .31543 L p F P
0 g
s
.907 .505 .221 r
.10366 .30765 m .11319 .31543 L .11669 .32605 L p F P
0 g
s
0 0 0 r
.62513 .37443 m .61971 .3785 L .59591 .39095 L p F P
0 g
s
.41 .848 .732 r
.59144 .39255 m .59591 .39095 L .61971 .3785 L p F P
0 g
s
.356 .82 .739 r
.59591 .39095 m .59144 .39255 L .56432 .40378 L p F P
0 g
s
.406 .859 .868 r
.58092 .4616 m .57909 .4617 L .55198 .47053 L p F P
0 g
s
.5 .894 .947 r
.57909 .4617 m .55198 .47053 L .54497 .46947 L p F P
0 g
s
.464 .875 .947 r
.51795 .47702 m .54497 .46947 L .55198 .47053 L p F P
0 g
s
0 .492 .826 r
.2302 .40068 m .21648 .39696 L .20791 .39289 L p F P
0 g
s
0 .495 .832 r
.24462 .40642 m .2302 .40068 L .21648 .39696 L p F P
0 g
s
0 0 0 r
.6521 .35445 m .65649 .35045 L .65296 .35299 L closepath p F P
0 g
s
.02 0 .032 r
.65296 .35299 m .65649 .35045 L .67303 .33283 L p F P
0 g
s
.645 .088 0 r
.22172 .32511 m .21948 .32386 L .2098 .31521 L p F P
0 g
s
.596 .035 0 r
.19811 .30828 m .2098 .31521 L .21948 .32386 L p F P
0 g
s
.386 .771 .99 r
.34757 .48463 m .34554 .48476 L .34865 .48514 L closepath p F P
0 g
s
.785 .284 0 r
.1137 .40734 m .10268 .40036 L .09556 .39068 L p F P
0 g
s
.78 .275 0 r
.08504 .38348 m .09556 .39068 L .10268 .40036 L p F P
0 g
s
0 0 0 r
.61971 .3785 m .62513 .37443 L .62984 .37122 L p F P
0 g
s
.1 0 .164 r
.67303 .33283 m .67766 .32936 L .67872 .32532 L closepath p F P
0 g
s
.89 .475 .206 r
.12675 .33357 m .12527 .33248 L .12658 .33312 L closepath p F P
0 g
s
0 0 0 r
.70371 .39057 m .72254 .37637 L .72575 .36872 L p F P
0 g
s
0 0 0 r
.70371 .39057 m .72254 .37637 L p .69706 .39933 L F P
0 g
s
0 0 0 r
.69706 .39933 m .70051 .39364 L .70371 .39057 L p F P
0 g
s
.519 .848 .997 r
.44974 .48374 m .45232 .48483 L .48309 .48086 L p F P
0 g
s
.497 .847 .994 r
.48386 .48122 m .48309 .48086 L .45232 .48483 L p F P
0 g
s
.464 .782 .998 r
.34554 .48476 m .34757 .48463 L .33962 .48005 L p F P
0 g
s
.464 .782 .998 r
.33962 .48005 m .32369 .48162 L .34554 .48476 L p F P
0 g
s
.84 .376 .08 r
.14311 .35078 m .13241 .34354 L .12675 .33357 L p F P
0 g
s
.836 .366 .038 r
.12527 .33248 m .12675 .33357 L .13241 .34354 L p F P
0 g
s
.319 0 0 r
.23291 .33015 m .22172 .32511 L .2287 .32816 L closepath p F P
0 g
s
0 0 0 r
.62984 .37122 m .64847 .35948 L p .61971 .3785 L F P
0 g
s
0 0 0 r
.62984 .37122 m .64847 .35948 L .6521 .35445 L closepath p F P
0 g
s
0 0 .17 r
.75739 .32648 m .75037 .33344 L .7486 .34254 L p F P
0 g
s
.075 0 .272 r
.75037 .33344 m .75739 .32648 L .76295 .31227 L p F P
0 g
s
.493 .762 .99 r
.29175 .4178 m .31759 .41533 L .32561 .42092 L p F P
0 g
s
.558 .76 .972 r
.29175 .4178 m .31759 .41533 L .31363 .4121 L p F P
0 g
s
.558 .76 .972 r
.28356 .41294 m .29175 .4178 L p .31363 .4121 L F P
0 g
s
.398 .728 .99 r
.30389 .35098 m .30256 .35099 L .30528 .3519 L closepath p F P
0 g
s
0 0 0 r
.67766 .32936 m .67303 .33283 L .65649 .35045 L p F P
0 g
s
.442 .798 .997 r
.38157 .48539 m .37377 .48062 L .34757 .48463 L p F P
0 g
s
.58 .785 .976 r
.37377 .48062 m .34757 .48463 L .33962 .48005 L p F P
0 g
s
.072 .593 .877 r
.27169 .47448 m .26339 .46999 L .23806 .46798 L p F P
0 g
s
.334 .708 .983 r
.23806 .46798 m .26339 .46999 L .26193 .46909 L p F P
0 g
s
.334 .708 .983 r
.2296 .46399 m .23806 .46798 L p .26193 .46909 L F P
0 g
s
.522 .916 .906 r
.5618 .40379 m .56432 .40378 L .59144 .39255 L p F P
0 g
s
.836 .366 .038 r
.11766 .32806 m .12527 .33248 L p .13241 .34354 L F P
0 g
s
.865 .419 .112 r
.11766 .32806 m .11669 .32605 L .12527 .33248 L closepath p F P
0 g
s
.095 0 .243 r
.63851 .26583 m .6274 .27578 L .6257 .28537 L p F P
0 g
s
.239 .061 .426 r
.6274 .27578 m .63851 .26583 L .64064 .25294 L p F P
0 g
s
.659 .107 0 r
.11387 .40752 m .11447 .40779 L p .13493 .42303 L F P
0 g
s
.727 .197 0 r
.11387 .40752 m .1137 .40734 L .11447 .40779 L closepath p F P
0 g
s
.495 .741 .982 r
.30256 .35099 m .30389 .35098 L .29581 .34456 L p F P
0 g
s
.495 .741 .982 r
.29581 .34456 m .2881 .34518 L .30256 .35099 L p F P
0 g
s
.749 .23 0 r
.16213 .36713 m .15089 .36014 L .14311 .35078 L p F P
0 g
s
.736 .213 0 r
.13241 .34354 m .14311 .35078 L .15089 .36014 L p F P
0 g
s
.547 .88 .99 r
.51222 .47506 m .51795 .47702 L .54497 .46947 L p F P
0 g
s
.71 .176 0 r
.1137 .40734 m .11387 .40752 L .10488 .40278 L p F P
0 g
s
.71 .176 0 r
.10488 .40278 m .10268 .40036 L .1137 .40734 L p F P
0 g
s
0 .328 .706 r
.19847 .3884 m .20791 .39289 L .19931 .38804 L p F P
0 g
s
0 .328 .706 r
.19931 .38804 m .18573 .38202 L .19847 .3884 L p F P
0 g
s
0 0 0 r
.64847 .35948 m .6521 .35445 L .65649 .35045 L p F P
0 g
s
0 0 0 r
.65649 .35045 m .6744 .33706 L p .64847 .35948 L F P
0 g
s
0 0 0 r
.65649 .35045 m .6744 .33706 L .67766 .32936 L p F P
0 g
s
.659 .107 0 r
.13493 .42303 m .12326 .41632 L .11387 .40752 L p F P
0 g
s
.645 .092 0 r
.12326 .41632 m .11387 .40752 L .10488 .40278 L p F P
0 g
s
.9 .514 .283 r
.18072 .2914 m .17472 .28712 L .17982 .28844 L closepath p F P
0 g
s
.045 0 .315 r
.77888 .28471 m .77138 .29364 L .77081 .30398 L p F P
0 g
s
.112 0 .392 r
.77138 .29364 m .77888 .28471 L .78041 .27184 L p F P
0 g
s
.104 0 .334 r
.76295 .31227 m .77081 .30398 L .77138 .29364 L p F P
0 g
s
.529 .785 .991 r
.33786 .35228 m .32997 .3445 L .30389 .35098 L p F P
0 g
s
.661 .728 .899 r
.32997 .3445 m .30389 .35098 L .29581 .34456 L p F P
0 g
s
.487 .816 1 r
.41564 .48507 m .40798 .48034 L .38157 .48539 L p F P
0 g
s
.603 .79 .97 r
.40798 .48034 m .38157 .48539 L .37377 .48062 L p F P
0 g
s
.03 0 .243 r
.77081 .30398 m .76295 .31227 L .75739 .32648 L p F P
0 g
s
.386 .839 .75 r
.6344 .43985 m .613 .44995 L .60636 .45132 L p F P
0 g
s
.411 .861 .816 r
.613 .44995 m .60636 .45132 L p .58092 .4616 L F P
0 g
s
0 0 0 r
.73889 .35734 m .72575 .36872 L .72254 .37637 L p F P
0 g
s
0 0 .083 r
.74822 .3439 m .73889 .35734 L .72575 .36872 L p F P
0 g
s
0 0 .083 r
.7486 .34254 m .74822 .3439 L p .72575 .36872 L F P
0 g
s
.041 0 .247 r
.70718 .28707 m .70146 .29299 L .70012 .30273 L p F P
0 g
s
.136 0 .362 r
.70146 .29299 m .70718 .28707 L .71023 .27378 L p F P
0 g
s
.159 .614 .933 r
.24462 .40642 m .24979 .40748 L .2414 .40253 L p F P
0 g
s
.159 .614 .933 r
.2414 .40253 m .2302 .40068 L .24462 .40642 L p F P
0 g
s
.527 .867 .992 r
.51222 .47506 m .49191 .47921 L .48386 .48122 L p F P
0 g
s
.56 .856 .997 r
.49191 .47921 m .48309 .48086 L .48386 .48122 L closepath p F P
0 g
s
.099 0 .344 r
.72077 .26212 m .71023 .27378 L .70718 .28707 L p F P
0 g
s
.182 .041 .441 r
.71023 .27378 m .72077 .26212 L .7205 .25058 L p F P
0 g
s
.509 .831 1 r
.44974 .48374 m .44223 .47936 L .41564 .48507 L p F P
0 g
s
.61 .8 .972 r
.44223 .47936 m .41564 .48507 L .40798 .48034 L p F P
0 g
s
.576 .775 .973 r
.35495 .4184 m .34678 .41686 L .32561 .42092 L p F P
0 g
s
.567 .79 .983 r
.34678 .41686 m .32561 .42092 L .31759 .41533 L p F P
0 g
s
.448 .782 .998 r
.32369 .48162 m .33962 .48005 L p .30557 .47824 L F P
0 g
s
.448 .782 .998 r
.30557 .47824 m .30801 .47954 L .32369 .48162 L p F P
0 g
s
0 .369 .738 r
.17273 .44379 m .18756 .44998 L .18336 .4477 L p F P
0 g
s
.436 0 0 r
.15467 .43497 m .15965 .43765 L .17273 .44379 L p F P
0 g
s
0 .369 .738 r
.15965 .43765 m .17273 .44379 L p .18336 .4477 L F P
0 g
s
.462 .888 .831 r
.57183 .3275 m .56966 .32811 L .54258 .33985 L p F P
0 g
s
.561 .922 .948 r
.56966 .32811 m .54258 .33985 L .53551 .33786 L p F P
0 g
s
.597 .905 .983 r
.54258 .33985 m .53551 .33786 L p .50918 .34733 L F P
0 g
s
.519 .848 .997 r
.48309 .48086 m .47649 .47755 L .44974 .48374 L p F P
0 g
s
.606 .818 .981 r
.47649 .47755 m .44974 .48374 L .44223 .47936 L p F P
0 g
s
.252 .623 .959 r
.23291 .33015 m .25361 .33475 L .25095 .33267 L p F P
0 g
s
.252 .623 .959 r
.22172 .32511 m .23291 .33015 L p .25095 .33267 L F P
0 g
s
.693 .702 .854 r
.36421 .3429 m .33786 .35228 L .32997 .3445 L p F P
0 g
s
.667 .728 .895 r
.33786 .35228 m .36421 .3429 L .37194 .35186 L p F P
0 g
s
.916 .556 .337 r
.17472 .28712 m .17039 .28386 L .16807 .2729 L p F P
0 g
s
.926 .564 .316 r
.15858 .265 m .16807 .2729 L .17039 .28386 L p F P
0 g
s
.933 .64 .464 r
.16807 .2729 m .15858 .265 L .15851 .25333 L p F P
0 g
s
.572 .851 .996 r
.47649 .47755 m .48309 .48086 L .49191 .47921 L p F P
0 g
s
0 0 0 r
.69202 .31671 m .67766 .32936 L .6744 .33706 L p F P
0 g
s
.001 0 .125 r
.69961 .30481 m .69202 .31671 L .67766 .32936 L p F P
0 g
s
.001 0 .125 r
.70012 .30273 m .69961 .30481 L p .67766 .32936 L F P
0 g
s
.105 .59 .908 r
.21915 .46176 m .2296 .46399 L .2211 .45932 L p F P
0 g
s
.105 .59 .908 r
.2211 .45932 m .2044 .45625 L .21915 .46176 L p F P
0 g
s
0 .434 .754 r
.19622 .4541 m .2044 .45625 L .21915 .46176 L p F P
0 g
s
.597 .037 0 r
.16213 .36713 m .1665 .37101 L .15772 .36606 L p F P
0 g
s
.597 .037 0 r
.15772 .36606 m .15089 .36014 L .16213 .36713 L p F P
0 g
s
.813 .329 .026 r
.19811 .30828 m .18703 .30107 L .18072 .2914 L p F P
0 g
s
.8 .307 0 r
.17472 .28712 m .18072 .2914 L .18703 .30107 L p F P
0 g
s
.461 .888 .877 r
.57909 .4617 m .60581 .45154 L .58092 .4616 L closepath p F P
0 g
s
.411 .861 .816 r
.60636 .45132 m .60581 .45154 L .58092 .4616 L p F P
0 g
s
.922 .538 .255 r
.05575 .3478 m .04658 .3399 L .0437 .32909 L p F P
0 g
s
.945 .653 .453 r
.14963 .24513 m .15851 .25333 L .15858 .265 L p F P
0 g
s
.521 .902 .953 r
.5618 .40379 m .55738 .40318 L .53029 .41221 L p F P
0 g
s
.596 .89 .99 r
.55738 .40318 m .53029 .41221 L .52314 .40922 L p F P
0 g
s
.576 .877 .993 r
.49616 .41714 m .52314 .40922 L .53029 .41221 L p F P
0 g
s
0 .502 .835 r
.2044 .45625 m .19622 .4541 L .18756 .44998 L p F P
0 g
s
.678 .717 .879 r
.37194 .35186 m .39845 .34151 L .40604 .3511 L p F P
0 g
s
.696 .683 .833 r
.39845 .34151 m .37194 .35186 L .36421 .3429 L p F P
0 g
s
.897 .479 .158 r
.05575 .3478 m .05693 .35097 L .04794 .34356 L p F P
0 g
s
.897 .479 .158 r
.04794 .34356 m .04658 .3399 L .05575 .3478 L p F P
0 g
s
.614 .777 .959 r
.39211 .42074 m .37242 .41892 L .35962 .42208 L p F P
0 g
s
.611 .785 .965 r
.37242 .41892 m .35495 .4184 L .35962 .42208 L closepath p F P
0 g
s
.214 .039 .416 r
.64754 .24639 m .64064 .25294 L .63851 .26583 L p F P
0 g
s
.067 0 .372 r
.78925 .26037 m .78041 .27184 L .77888 .28471 L p F P
0 g
s
.132 .016 .443 r
.78041 .27184 m .78925 .26037 L .78866 .24871 L p F P
0 g
s
.621 .88 .989 r
.50848 .347 m .53317 .33866 L .50918 .34733 L closepath p F P
0 g
s
.597 .905 .983 r
.53551 .33786 m .53317 .33866 L .50918 .34733 L p F P
0 g
s
.484 0 0 r
.13493 .42303 m .14583 .43067 L .14242 .42877 L p F P
0 g
s
.484 0 0 r
.12326 .41632 m .13493 .42303 L p .14242 .42877 L F P
0 g
s
.673 .721 .885 r
.40604 .3511 m .43268 .34118 L .44017 .35053 L p F P
0 g
s
.687 .679 .837 r
.43268 .34118 m .40604 .3511 L .39845 .34151 L p F P
0 g
s
.303 .728 .972 r
.27169 .47448 m .28397 .47403 L .30229 .47832 L p F P
0 g
s
.397 .753 .993 r
.28397 .47403 m .27169 .47448 L .26339 .46999 L p F P
0 g
s
.846 .383 .061 r
.08504 .38348 m .07495 .37605 L .06946 .36594 L p F P
0 g
s
.843 .378 .03 r
.05985 .35828 m .06946 .36594 L .07495 .37605 L p F P
0 g
s
.89 .467 .164 r
.05693 .35097 m .05985 .35828 L .06946 .36594 L p F P
0 g
s
.377 .748 .99 r
.30557 .47824 m .30229 .47832 L .30801 .47954 L closepath p F P
0 g
s
.564 .922 .951 r
.55738 .40318 m .5618 .40379 L .58679 .39285 L p F P
0 g
s
.522 .916 .906 r
.59144 .39255 m .58679 .39285 L .5618 .40379 L p F P
0 g
s
.365 0 0 r
.15965 .43765 m .15467 .43497 L .14583 .43067 L p F P
0 g
s
.627 .783 .956 r
.42598 .41981 m .39909 .42064 L .3937 .42209 L p F P
0 g
s
.627 .78 .954 r
.39909 .42064 m .39211 .42074 L .3937 .42209 L closepath p F P
0 g
s
0 0 0 r
.59681 .31269 m .61599 .2977 L .60073 .30879 L closepath p F P
0 g
s
0 0 0 r
.62387 .28988 m .61599 .2977 L .60073 .30879 L p F P
0 g
s
0 0 0 r
.6257 .28537 m .62387 .28988 L p .60073 .30879 L F P
0 g
s
0 0 0 r
.60073 .30879 m .59681 .31269 L p .57183 .3275 L F P
0 g
s
.537 .866 .994 r
.51075 .47448 m .49191 .47921 L .51222 .47506 L closepath p F P
0 g
s
.572 .851 .996 r
.49191 .47921 m .51075 .47448 L p .47649 .47755 L F P
0 g
s
.662 .749 .914 r
.44017 .35053 m .46693 .34152 L .47432 .34962 L p F P
0 g
s
.673 .696 .864 r
.46693 .34152 m .44017 .35053 L .43268 .34118 L p F P
0 g
s
0 0 0 r
.59681 .31269 m .58431 .32023 L .57183 .3275 L p F P
0 g
s
.495 .901 .791 r
.56966 .32811 m .58431 .32023 L .57183 .3275 L closepath p F P
0 g
s
.238 .679 .957 r
.28356 .41294 m .27534 .40722 L .24979 .40748 L p F P
0 g
s
.488 .735 .981 r
.27534 .40722 m .24979 .40748 L .2414 .40253 L p F P
0 g
s
.648 .82 .966 r
.53317 .33866 m .50848 .347 L .50122 .34111 L p F P
0 g
s
.636 .817 .97 r
.50848 .347 m .50122 .34111 L .47432 .34962 L p F P
0 g
s
.631 .829 .977 r
.49616 .41714 m .52314 .40922 L .51593 .40427 L p F P
0 g
s
.631 .829 .977 r
.48884 .41244 m .49616 .41714 L p .51593 .40427 L F P
0 g
s
.61 .834 .985 r
.46199 .4199 m .48884 .41244 L .49616 .41714 L p F P
0 g
s
.596 .035 0 r
.21948 .32386 m .20805 .31683 L .19811 .30828 L p F P
0 g
s
.542 0 0 r
.18703 .30107 m .19811 .30828 L .20805 .31683 L p F P
0 g
s
.625 .8 .966 r
.45744 .41634 m .43588 .41917 L .42784 .42138 L p F P
0 g
s
.63 .784 .955 r
.43588 .41917 m .42598 .41981 L .42784 .42138 L closepath p F P
0 g
s
.66 .738 .908 r
.50122 .34111 m .47432 .34962 L .46693 .34152 L p F P
0 g
s
.627 .802 .966 r
.45744 .41634 m .46199 .4199 L .48884 .41244 L p F P
0 g
s
.444 .761 .996 r
.30229 .47832 m .30557 .47824 L .29744 .47317 L p F P
0 g
s
.444 .761 .996 r
.29744 .47317 m .28397 .47403 L .30229 .47832 L p F P
0 g
s
.78 .275 0 r
.10268 .40036 m .09211 .39317 L .08504 .38348 L p F P
0 g
s
.771 .265 0 r
.07495 .37605 m .08504 .38348 L .09211 .39317 L p F P
0 g
s
.907 .505 .221 r
.11669 .32605 m .10714 .31827 L .10366 .30765 L p F P
0 g
s
.911 .507 .195 r
.09463 .29962 m .10366 .30765 L .10714 .31827 L p F P
0 g
s
.936 .581 .323 r
.10366 .30765 m .09463 .29962 L .09263 .28857 L p F P
0 g
s
0 0 .17 r
.7486 .34254 m .74977 .34138 L .75739 .32648 L p F P
0 g
s
0 0 .149 r
.76962 .31363 m .75739 .32648 L .74977 .34138 L p F P
0 g
s
.03 0 .243 r
.75739 .32648 m .76962 .31363 L .77081 .30398 L p F P
0 g
s
.115 0 .421 r
.72334 .24691 m .7205 .25058 L .72077 .26212 L p F P
0 g
s
.89 .465 .136 r
.05985 .35828 m .05693 .35097 L .04794 .34356 L p F P
0 g
s
.555 .751 .968 r
.2881 .34518 m .29581 .34456 L .28772 .33718 L p F P
0 g
s
.555 .751 .968 r
.28772 .33718 m .27346 .33937 L .2881 .34518 L p F P
0 g
s
.358 .73 .988 r
.26193 .34048 m .27346 .33937 L .2881 .34518 L p F P
0 g
s
.316 .778 .644 r
.6344 .43985 m .63959 .43732 L .64023 .43702 L closepath p F P
0 g
s
.386 .839 .75 r
.63959 .43732 m .6344 .43985 L p .60636 .45132 L F P
0 g
s
.863 .414 .077 r
.11669 .32605 m .11766 .32806 L .10878 .32168 L p F P
0 g
s
.863 .414 .077 r
.10878 .32168 m .10714 .31827 L .11669 .32605 L p F P
0 g
s
.63 .778 .952 r
.38599 .41548 m .39211 .42074 L .39909 .42064 L p F P
0 g
s
.619 .775 .955 r
.38599 .41548 m .37242 .41892 L .39211 .42074 L closepath p F P
0 g
s
.63 .78 .953 r
.42025 .41485 m .39909 .42064 L .42598 .41981 L closepath p F P
0 g
s
.63 .778 .952 r
.39909 .42064 m .42025 .41485 L p .38599 .41548 L F P
0 g
s
.52 .909 .934 r
.60581 .45154 m .57909 .4617 L .57219 .46071 L p F P
0 g
s
.5 .894 .947 r
.54497 .46947 m .57219 .46071 L .57909 .4617 L p F P
0 g
s
.489 .76 .99 r
.27346 .33937 m .26193 .34048 L .25361 .33475 L p F P
0 g
s
.41 .848 .732 r
.61971 .3785 m .61868 .37896 L .59144 .39255 L p F P
0 g
s
.571 .94 .888 r
.58679 .39285 m .59144 .39255 L .61868 .37896 L p F P
0 g
s
.487 0 0 r
.1665 .37101 m .17353 .3754 L .18573 .38202 L p F P
0 g
s
0 .385 .78 r
.18573 .38202 m .19931 .38804 L .19307 .38405 L p F P
0 g
s
0 .385 .78 r
.17353 .3754 m .18573 .38202 L p .19307 .38405 L F P
0 g
s
.448 .782 .998 r
.33962 .48005 m .33165 .47452 L .30557 .47824 L p F P
0 g
s
.581 .769 .969 r
.33165 .47452 m .30557 .47824 L .29744 .47317 L p F P
0 g
s
.366 0 0 r
.22014 .32424 m .21948 .32386 L .22172 .32511 L closepath p F P
0 g
s
.252 .623 .959 r
.22014 .32424 m .22172 .32511 L p .25095 .33267 L F P
0 g
s
.8 .307 0 r
.17097 .28514 m .17472 .28712 L p .18703 .30107 L F P
0 g
s
.875 .439 .143 r
.17097 .28514 m .17039 .28386 L .17472 .28712 L closepath p F P
0 g
s
.633 .781 .952 r
.42025 .41485 m .42598 .41981 L .43588 .41917 L p F P
0 g
s
.041 0 .247 r
.70012 .30273 m .70156 .30124 L .70718 .28707 L p F P
0 g
s
0 0 .222 r
.72023 .27271 m .70718 .28707 L .70156 .30124 L p F P
0 g
s
.099 0 .344 r
.70718 .28707 m .72023 .27271 L .72077 .26212 L p F P
0 g
s
0 0 0 r
.66751 .42133 m .67872 .41374 L .66954 .41973 L closepath p F P
0 g
s
0 0 0 r
.69475 .40211 m .67872 .41374 L .66954 .41973 L p F P
0 g
s
0 0 0 r
.69706 .39933 m .69475 .40211 L p .66954 .41973 L F P
0 g
s
0 0 0 r
.66954 .41973 m .66751 .42133 L .64023 .43702 L p F P
0 g
s
.414 .838 .679 r
.63959 .43732 m .64023 .43702 L .66751 .42133 L p F P
0 g
s
.236 .648 .96 r
.2302 .40068 m .2414 .40253 L .23298 .39688 L p F P
0 g
s
.236 .648 .96 r
.23298 .39688 m .2162 .39475 L .2302 .40068 L p F P
0 g
s
0 .492 .826 r
.20791 .39289 m .2162 .39475 L .2302 .40068 L p F P
0 g
s
.408 0 0 r
.17353 .3754 m .1665 .37101 L .15772 .36606 L p F P
0 g
s
.736 .213 0 r
.15089 .36014 m .14017 .3529 L .13241 .34354 L p F P
0 g
s
.718 .195 0 r
.12223 .33605 m .13241 .34354 L .14017 .3529 L p F P
0 g
s
.836 .366 .038 r
.13241 .34354 m .12223 .33605 L .11766 .32806 L p F P
0 g
s
.084 0 .428 r
.79054 .24598 m .78866 .24871 L .78925 .26037 L p F P
0 g
s
.69 .154 0 r
.10268 .40036 m .10488 .40278 L .09589 .39728 L p F P
0 g
s
.69 .154 0 r
.09589 .39728 m .09211 .39317 L .10268 .40036 L p F P
0 g
s
.628 .797 .963 r
.45454 .414 m .43588 .41917 L .45744 .41634 L closepath p F P
0 g
s
.633 .781 .952 r
.43588 .41917 m .45454 .414 L p .42025 .41485 L F P
0 g
s
.831 .358 0 r
.12223 .33605 m .11766 .32806 L .10878 .32168 L p F P
0 g
s
.078 .561 .899 r
.2162 .39475 m .20791 .39289 L .19931 .38804 L p F P
0 g
s
.616 .783 .961 r
.37242 .41892 m .38599 .41548 L p .35176 .41583 L F P
0 g
s
.616 .783 .961 r
.35176 .41583 m .35495 .4184 L .37242 .41892 L p F P
0 g
s
0 .28 .695 r
.21948 .32386 m .22014 .32424 L .21162 .31872 L p F P
0 g
s
0 .28 .695 r
.21162 .31872 m .20805 .31683 L .21948 .32386 L p F P
0 g
s
0 .369 .738 r
.18336 .4477 m .17668 .4445 L .15965 .43765 L p F P
0 g
s
.365 0 0 r
.14583 .43067 m .14706 .4313 L .15965 .43765 L p F P
0 g
s
0 .397 .778 r
.14706 .4313 m .15965 .43765 L .17668 .4445 L p F P
0 g
s
0 0 .059 r
.74822 .3439 m .74977 .34138 L .7486 .34254 L closepath p F P
0 g
s
.544 .779 .985 r
.30562 .40943 m .28356 .41294 L .27534 .40722 L p F P
0 g
s
.558 .76 .972 r
.31363 .4121 m .30562 .40943 L .28356 .41294 L p F P
0 g
s
.588 .774 .968 r
.35176 .41583 m .34678 .41686 L .35495 .4184 L closepath p F P
0 g
s
.476 .889 .776 r
.63376 .43904 m .63959 .43732 L .66282 .42399 L p F P
0 g
s
.386 .839 .75 r
.60636 .45132 m .63376 .43904 L .63959 .43732 L p F P
0 g
s
.414 .838 .679 r
.66751 .42133 m .66282 .42399 L .63959 .43732 L p F P
0 g
s
0 0 0 r
.69475 .40211 m .7057 .39283 L .69706 .39933 L closepath p F P
0 g
s
0 0 0 r
.72177 .37773 m .7057 .39283 L .69706 .39933 L p F P
0 g
s
0 0 0 r
.72254 .37637 m .72177 .37773 L p .69706 .39933 L F P
0 g
s
.173 .622 .938 r
.2044 .45625 m .2211 .45932 L .21256 .45405 L p F P
0 g
s
.173 .622 .938 r
.21256 .45405 m .19006 .45056 L .2044 .45625 L p F P
0 g
s
0 .502 .835 r
.18756 .44998 m .19006 .45056 L .2044 .45625 L p F P
0 g
s
0 0 0 r
.62387 .28988 m .63119 .28047 L .6257 .28537 L closepath p F P
0 g
s
.095 0 .243 r
.6257 .28537 m .63119 .28047 L .63851 .26583 L p F P
0 g
s
.252 .623 .959 r
.25095 .33267 m .24297 .32798 L .22014 .32424 L p F P
0 g
s
.202 .621 .949 r
.24297 .32798 m .22014 .32424 L .21162 .31872 L p F P
0 g
s
.566 .877 .993 r
.51075 .47448 m .51222 .47506 L .54002 .46764 L p F P
0 g
s
.547 .88 .99 r
.54497 .46947 m .54002 .46764 L .51222 .47506 L p F P
0 g
s
.54 .927 .877 r
.58431 .32023 m .56966 .32811 L .56272 .32715 L p F P
0 g
s
.561 .922 .948 r
.53551 .33786 m .56272 .32715 L .56966 .32811 L p F P
0 g
s
.58 .785 .976 r
.33962 .48005 m .36594 .47476 L .37377 .48062 L p F P
0 g
s
.619 .768 .951 r
.36594 .47476 m .33962 .48005 L .33165 .47452 L p F P
0 g
s
0 0 .22 r
.77571 .29816 m .77081 .30398 L .76962 .31363 L p F P
0 g
s
.045 0 .315 r
.77081 .30398 m .77571 .29816 L .77888 .28471 L p F P
0 g
s
.115 0 .421 r
.72077 .26212 m .72295 .25933 L .72334 .24691 L p F P
0 g
s
.079 0 .409 r
.73318 .23321 m .72334 .24691 L .72295 .25933 L p F P
0 g
s
.052 0 .214 r
.64727 .25756 m .63851 .26583 L .63119 .28047 L p F P
0 g
s
.214 .039 .416 r
.63851 .26583 m .64727 .25756 L .64754 .24639 L p F P
0 g
s
.587 .892 .989 r
.54002 .46764 m .54497 .46947 L .57219 .46071 L p F P
0 g
s
.003 0 .296 r
.78925 .27133 m .77888 .28471 L .77571 .29816 L p F P
0 g
s
.067 0 .372 r
.77888 .28471 m .78925 .27133 L .78925 .26037 L p F P
0 g
s
.315 .708 .979 r
.24914 .46474 m .2296 .46399 L .2211 .45932 L p F P
0 g
s
.334 .708 .983 r
.26193 .46909 m .24914 .46474 L .2296 .46399 L p F P
0 g
s
.661 .728 .899 r
.29581 .34456 m .32207 .33555 L .32997 .3445 L p F P
0 g
s
.689 .714 .868 r
.32207 .33555 m .29581 .34456 L .28772 .33718 L p F P
0 g
s
0 0 .016 r
.74977 .34138 m .76357 .32707 L p .74609 .35081 L F P
0 g
s
0 0 .016 r
.74609 .35081 m .74822 .3439 L .74977 .34138 L p F P
0 g
s
0 0 .149 r
.76918 .31583 m .76962 .31363 L p .74977 .34138 L F P
0 g
s
0 0 .149 r
.74977 .34138 m .76357 .32707 L .76918 .31583 L p F P
0 g
s
.116 0 .386 r
.65501 .23765 m .64754 .24639 L .64727 .25756 L p F P
0 g
s
.555 0 0 r
.15089 .36014 m .15772 .36606 L .14893 .36034 L p F P
0 g
s
.555 0 0 r
.14893 .36034 m .14017 .3529 L .15089 .36014 L p F P
0 g
s
.49 .771 .994 r
.28397 .47403 m .29744 .47317 L .28927 .46735 L p F P
0 g
s
.49 .771 .994 r
.28927 .46735 m .26518 .46984 L .28397 .47403 L p F P
0 g
s
.397 .753 .993 r
.26339 .46999 m .26518 .46984 L .28397 .47403 L p F P
0 g
s
.926 .564 .316 r
.17039 .28386 m .16089 .27597 L .15858 .265 L p F P
0 g
s
.934 .57 .293 r
.14968 .25681 m .15858 .265 L .16089 .27597 L p F P
0 g
s
.945 .653 .453 r
.15858 .265 m .14968 .25681 L .14963 .24513 L p F P
0 g
s
.084 0 .428 r
.78925 .26037 m .79069 .25829 L .79054 .24598 L p F P
0 g
s
.05 0 .417 r
.7989 .23288 m .79054 .24598 L .79069 .25829 L p F P
0 g
s
.626 .764 .945 r
.34678 .41686 m .35176 .41583 L .34388 .40844 L p F P
0 g
s
.626 .764 .945 r
.34388 .40844 m .32712 .41287 L .34678 .41686 L p F P
0 g
s
.567 .79 .983 r
.31759 .41533 m .32712 .41287 L .34678 .41686 L p F P
0 g
s
.645 .092 0 r
.10488 .40278 m .11207 .40939 L .12326 .41632 L p F P
0 g
s
.61 .058 0 r
.11207 .40939 m .10488 .40278 L .09589 .39728 L p F P
0 g
s
.603 .79 .97 r
.37377 .48062 m .40029 .47439 L .40798 .48034 L p F P
0 g
s
.636 .766 .942 r
.40029 .47439 m .37377 .48062 L .36594 .47476 L p F P
0 g
s
.874 .433 .102 r
.17039 .28386 m .17097 .28514 L .16226 .27901 L p F P
0 g
s
.874 .433 .102 r
.16226 .27901 m .16089 .27597 L .17039 .28386 L p F P
0 g
s
0 0 .048 r
.73889 .35734 m .74609 .35081 L .74822 .3439 L closepath p F P
0 g
s
0 0 .106 r
.69961 .30481 m .70156 .30124 L .70012 .30273 L closepath p F P
0 g
s
.693 .702 .854 r
.35911 .33597 m .36421 .3429 L p .32997 .3445 L F P
0 g
s
.693 .702 .854 r
.32997 .3445 m .34971 .33545 L .35911 .33597 L p F P
0 g
s
.718 .698 .83 r
.34971 .33545 m .32997 .3445 L .32207 .33555 L p F P
0 g
s
0 0 0 r
.64593 .36174 m .62473 .37536 L .61971 .3785 L p F P
0 g
s
0 0 0 r
.64847 .35948 m .64593 .36174 L p .61971 .3785 L F P
0 g
s
.454 .864 .705 r
.61868 .37896 m .62473 .37536 L .61971 .3785 L closepath p F P
0 g
s
0 0 0 r
.64593 .36174 m .65789 .35246 L .64847 .35948 L closepath p F P
0 g
s
0 0 0 r
.67305 .33915 m .65789 .35246 L .64847 .35948 L p F P
0 g
s
0 0 0 r
.6744 .33706 m .67305 .33915 L p .64847 .35948 L F P
0 g
s
.696 .683 .833 r
.39651 .33854 m .39845 .34151 L p .36421 .3429 L F P
0 g
s
.696 .683 .833 r
.36421 .3429 m .37418 .338 L .39651 .33854 L p F P
0 g
s
.703 .707 .851 r
.36421 .3429 m .37418 .338 L .35911 .33597 L closepath p F P
0 g
s
.633 .798 .962 r
.45454 .414 m .45744 .41634 L .4874 .41116 L p F P
0 g
s
.627 .802 .966 r
.48884 .41244 m .4874 .41116 L .45744 .41634 L p F P
0 g
s
.484 0 0 r
.14242 .42877 m .13523 .42463 L .12326 .41632 L p F P
0 g
s
.452 0 0 r
.11207 .40939 m .12326 .41632 L .13523 .42463 L p F P
0 g
s
.619 .778 .957 r
.32712 .41287 m .31363 .4121 L .31759 .41533 L closepath p F P
0 g
s
.566 .877 .993 r
.54002 .46764 m .53787 .46674 L .51075 .47448 L p F P
0 g
s
.612 .848 .988 r
.53787 .46674 m .51075 .47448 L .50348 .47036 L p F P
0 g
s
.572 .851 .996 r
.51075 .47448 m .50348 .47036 L .47649 .47755 L p F P
0 g
s
.687 .679 .837 r
.43016 .33722 m .43268 .34118 L p .39845 .34151 L F P
0 g
s
.687 .679 .837 r
.39845 .34151 m .40573 .33822 L .43016 .33722 L p F P
0 g
s
.687 .681 .838 r
.39845 .34151 m .40573 .33822 L .39651 .33854 L closepath p F P
0 g
s
.61 .8 .972 r
.40798 .48034 m .43467 .47365 L .44223 .47936 L p F P
0 g
s
.641 .771 .942 r
.43467 .47365 m .40798 .48034 L .40029 .47439 L p F P
0 g
s
.8 .307 0 r
.18703 .30107 m .1766 .29357 L .17097 .28514 L p F P
0 g
s
.788 .294 0 r
.1766 .29357 m .17097 .28514 L .16226 .27901 L p F P
0 g
s
.564 .922 .951 r
.58679 .39285 m .58464 .39265 L .55738 .40318 L p F P
0 g
s
.605 .909 .982 r
.58464 .39265 m .55738 .40318 L .55033 .40033 L p F P
0 g
s
.596 .89 .99 r
.52314 .40922 m .55033 .40033 L .55738 .40318 L p F P
0 g
s
.606 .818 .981 r
.44223 .47936 m .46907 .47245 L .47649 .47755 L p F P
0 g
s
.637 .785 .953 r
.46907 .47245 m .44223 .47936 L .43467 .47365 L p F P
0 g
s
.628 .811 .97 r
.50348 .47036 m .47649 .47755 L .46907 .47245 L p F P
0 g
s
.599 .759 .955 r
.27346 .33937 m .28772 .33718 L .27959 .32906 L p F P
0 g
s
.599 .759 .955 r
.27959 .32906 m .25695 .33412 L .27346 .33937 L p F P
0 g
s
.489 .76 .99 r
.25361 .33475 m .25695 .33412 L .27346 .33937 L p F P
0 g
s
.843 .378 .03 r
.07495 .37605 m .06531 .3684 L .05985 .35828 L p F P
0 g
s
.838 .372 0 r
.05065 .3504 m .05985 .35828 L .06531 .3684 L p F P
0 g
s
.89 .465 .136 r
.04794 .34356 m .05065 .3504 L .05985 .35828 L p F P
0 g
s
0 0 .05 r
.70156 .30124 m .71487 .28671 L p .69781 .31135 L F P
0 g
s
0 0 .05 r
.69781 .31135 m .69961 .30481 L .70156 .30124 L p F P
0 g
s
0 0 .222 r
.72017 .27313 m .72023 .27271 L p .70156 .30124 L F P
0 g
s
0 0 .222 r
.70156 .30124 m .71487 .28671 L .72017 .27313 L p F P
0 g
s
.673 .696 .864 r
.46045 .33223 m .46693 .34152 L p .43268 .34118 L F P
0 g
s
.673 .696 .864 r
.43268 .34118 m .45405 .33298 L .46045 .33223 L p F P
0 g
s
.668 .671 .844 r
.43268 .34118 m .45405 .33298 L .43016 .33722 L closepath p F P
0 g
s
.54 .927 .877 r
.59478 .31371 m .58431 .32023 L p .56272 .32715 L F P
0 g
s
.425 .841 .67 r
.58431 .32023 m .59478 .31371 L .59681 .31269 L closepath p F P
0 g
s
.542 0 0 r
.20805 .31683 m .1972 .30952 L .18703 .30107 L p F P
0 g
s
.484 0 0 r
.1766 .29357 m .18703 .30107 L .1972 .30952 L p F P
0 g
s
.461 .854 .654 r
.66282 .42399 m .66751 .42133 L .67872 .41374 L p F P
0 g
s
.616 .783 .961 r
.38599 .41548 m .37825 .40754 L .35176 .41583 L p F P
0 g
s
.675 .725 .887 r
.37825 .40754 m .35176 .41583 L .34388 .40844 L p F P
0 g
s
.648 .82 .966 r
.53539 .33778 m .53317 .33866 L p .50122 .34111 L F P
0 g
s
.65 .841 .973 r
.53317 .33866 m .53539 .33778 L .53551 .33786 L closepath p F P
0 g
s
.689 .675 .832 r
.40573 .33822 m .39651 .33854 L .39086 .32961 L p F P
0 g
s
.698 .679 .828 r
.39651 .33854 m .39086 .32961 L .37418 .338 L closepath p F P
0 g
s
0 0 0 r
.72254 .37637 m .72501 .37424 L .73889 .35734 L p F P
0 g
s
0 0 0 r
.72177 .37773 m .72501 .37424 L .72254 .37637 L closepath p F P
0 g
s
.489 .894 .769 r
.62473 .37536 m .61868 .37896 L .61204 .38013 L p F P
0 g
s
.571 .94 .888 r
.61868 .37896 m .61204 .38013 L p .58679 .39285 L F P
0 g
s
0 0 0 r
.74609 .35081 m .73889 .35734 L .72501 .37424 L p F P
0 g
s
0 0 .093 r
.69202 .31671 m .69781 .31135 L .69961 .30481 L closepath p F P
0 g
s
.688 .673 .83 r
.43016 .33722 m .42518 .32919 L .40573 .33822 L closepath p F P
0 g
s
.689 .675 .832 r
.41769 .31453 m .42518 .32919 L .40573 .33822 L p F P
0 g
s
.689 .675 .832 r
.39086 .32961 m .41769 .31453 L p .40573 .33822 L F P
0 g
s
.023 0 .318 r
.72295 .25933 m .72077 .26212 L .72023 .27271 L p F P
0 g
s
.63 .778 .952 r
.42025 .41485 m .41264 .40678 L .38599 .41548 L p F P
0 g
s
.677 .718 .879 r
.41264 .40678 m .38599 .41548 L .37825 .40754 L p F P
0 g
s
.771 .265 0 r
.09211 .39317 m .08199 .38575 L .07495 .37605 L p F P
0 g
s
.759 .253 0 r
.06531 .3684 m .07495 .37605 L .08199 .38575 L p F P
0 g
s
.66 .738 .908 r
.46693 .34152 m .4939 .33257 L .50122 .34111 L p F P
0 g
s
.661 .69 .867 r
.48903 .32519 m .4939 .33257 L .46693 .34152 L p F P
0 g
s
.661 .69 .867 r
.46693 .34152 m .46045 .33223 L .48903 .32519 L p F P
0 g
s
.063 .554 .891 r
.19006 .45056 m .18336 .4477 L .18756 .44998 L closepath p F P
0 g
s
.706 .703 .845 r
.38329 .31559 m .39086 .32961 L .37418 .338 L p F P
0 g
s
.706 .703 .845 r
.35648 .3323 m .38329 .31559 L p .37418 .338 L F P
0 g
s
.706 .703 .845 r
.37418 .338 m .35911 .33597 L .35648 .3323 L p F P
0 g
s
.678 .848 .964 r
.53539 .33778 m .53551 .33786 L .56272 .32715 L p F P
0 g
s
.668 .826 .96 r
.52833 .33226 m .53539 .33778 L .55925 .32521 L p F P
0 g
s
.678 .848 .964 r
.56272 .32715 m .55925 .32521 L .53539 .33778 L p F P
0 g
s
.648 .82 .966 r
.50122 .34111 m .52833 .33226 L .53539 .33778 L p F P
0 g
s
.299 .671 .974 r
.2162 .39475 m .23298 .39688 L .22452 .39064 L p F P
0 g
s
.299 .671 .974 r
.22452 .39064 m .20258 .38864 L .2162 .39475 L p F P
0 g
s
.078 .561 .899 r
.19931 .38804 m .20258 .38864 L .2162 .39475 L p F P
0 g
s
0 0 0 r
.67872 .41374 m .69181 .40495 L .69475 .40211 L closepath p F P
0 g
s
.461 .854 .654 r
.67872 .41374 m .69181 .40495 L p .66282 .42399 L F P
0 g
s
.911 .507 .195 r
.10714 .31827 m .09808 .31025 L .09463 .29962 L p F P
0 g
s
0 0 0 r
.63119 .28047 m .64552 .26701 L p .62221 .29293 L F P
0 g
s
0 0 0 r
.62221 .29293 m .62387 .28988 L .63119 .28047 L p F P
0 g
s
.052 0 .214 r
.63119 .28047 m .64552 .26701 L .64727 .25756 L p F P
0 g
s
.466 .765 .995 r
.26518 .46984 m .26193 .46909 L .26339 .46999 L closepath p F P
0 g
s
.633 .781 .952 r
.45454 .414 m .44704 .40635 L .42025 .41485 L p F P
0 g
s
.671 .722 .888 r
.44704 .40635 m .42025 .41485 L .41264 .40678 L p F P
0 g
s
.52 .909 .934 r
.60632 .45132 m .60581 .45154 L p .57219 .46071 L F P
0 g
s
.49 .901 .899 r
.60581 .45154 m .60632 .45132 L .60636 .45132 L closepath p F P
0 g
s
.644 .838 .975 r
.51593 .40427 m .52314 .40922 L .55033 .40033 L p F P
0 g
s
.408 0 0 r
.15772 .36606 m .16188 .36853 L .17353 .3754 L p F P
0 g
s
0 .385 .78 r
.19307 .38405 m .18977 .3822 L .17353 .3754 L p F P
0 g
s
0 .416 .819 r
.16188 .36853 m .17353 .3754 L .18977 .3822 L p F P
0 g
s
.41 .821 .625 r
.62473 .37536 m .64216 .36399 L .64593 .36174 L closepath p F P
0 g
s
.489 .894 .769 r
.64216 .36399 m .62473 .37536 L p .61204 .38013 L F P
0 g
s
.859 .407 .04 r
.10714 .31827 m .10878 .32168 L .09995 .31412 L p F P
0 g
s
.859 .407 .04 r
.09995 .31412 m .09808 .31025 L .10714 .31827 L p F P
0 g
s
.553 .93 .907 r
.60632 .45132 m .60636 .45132 L .63376 .43904 L p F P
0 g
s
.668 .666 .838 r
.45405 .33298 m .43016 .33722 L .42518 .32919 L p F P
0 g
s
.653 .746 .918 r
.52833 .33226 m .50122 .34111 L .4939 .33257 L p F P
0 g
s
.577 .932 .938 r
.5996 .45067 m .60632 .45132 L .63047 .43925 L p F P
0 g
s
.553 .93 .907 r
.63376 .43904 m .63047 .43925 L .60632 .45132 L p F P
0 g
s
.52 .909 .934 r
.57219 .46071 m .5996 .45067 L .60632 .45132 L p F P
0 g
s
0 .268 .66 r
.14706 .4313 m .14242 .42877 L .14583 .43067 L closepath p F P
0 g
s
.59 .925 .713 r
.59478 .31371 m .59681 .31269 L .61599 .2977 L p F P
0 g
s
0 0 0 r
.67305 .33915 m .67848 .33347 L .6744 .33706 L closepath p F P
0 g
s
0 0 0 r
.6744 .33706 m .67848 .33347 L .69202 .31671 L p F P
0 g
s
.488 .735 .981 r
.2414 .40253 m .2671 .40077 L .27534 .40722 L p F P
0 g
s
.536 .739 .969 r
.2414 .40253 m .2671 .40077 L .26462 .39865 L p F P
0 g
s
.536 .739 .969 r
.23298 .39688 m .2414 .40253 L p .26462 .39865 L F P
0 g
s
.633 .798 .962 r
.4874 .41116 m .48147 .40582 L .45454 .414 L p F P
0 g
s
.661 .741 .91 r
.48147 .40582 m .45454 .414 L .44704 .40635 L p F P
0 g
s
.622 .776 .955 r
.32712 .41287 m .34388 .40844 L p .30955 .40873 L F P
0 g
s
.622 .776 .955 r
.30955 .40873 m .31363 .4121 L .32712 .41287 L p F P
0 g
s
.631 .829 .977 r
.51593 .40427 m .51535 .40443 L .48884 .41244 L p F P
0 g
s
.645 .787 .95 r
.51535 .40443 m .4874 .41116 L .48884 .41244 L closepath p F P
0 g
s
.479 .768 .994 r
.26518 .46984 m .28927 .46735 L p .25505 .46475 L F P
0 g
s
.479 .768 .994 r
.25505 .46475 m .26193 .46909 L .26518 .46984 L p F P
0 g
s
.015 0 .355 r
.79069 .25829 m .78925 .26037 L .78925 .27133 L p F P
0 g
s
.666 .448 .58 r
.39895 .24129 m .42444 .23921 L .41953 .25289 L p F P
0 g
s
.666 .448 .58 r
.41953 .25289 m .39967 .25449 L .39895 .24129 L p F P
0 g
s
.712 .484 .577 r
.38746 .24082 m .39895 .24129 L .39967 .25449 L p F P
0 g
s
.262 .652 .966 r
.19006 .45056 m .21256 .45405 L .20426 .44844 L p F P
0 g
s
.262 .652 .966 r
.18336 .4477 m .19006 .45056 L p .20426 .44844 L F P
0 g
s
0 0 .22 r
.76962 .31363 m .77081 .31222 L .77571 .29816 L p F P
0 g
s
0 0 .202 r
.78637 .28459 m .77571 .29816 L .77081 .31222 L p F P
0 g
s
.003 0 .296 r
.78921 .27198 m .78925 .27133 L p .77571 .29816 L F P
0 g
s
.003 0 .296 r
.77571 .29816 m .78637 .28459 L .78921 .27198 L p F P
0 g
s
0 0 0 r
.74312 .35747 m .74609 .35081 L p .72501 .37424 L F P
0 g
s
0 0 0 r
.72501 .37424 m .7417 .35919 L .74312 .35747 L p F P
0 g
s
0 0 0 r
.72501 .37424 m .7417 .35919 L p .71835 .38296 L F P
0 g
s
0 0 0 r
.71835 .38296 m .72177 .37773 L .72501 .37424 L p F P
0 g
s
0 .397 .778 r
.17668 .4445 m .16426 .43806 L .14706 .4313 L p F P
0 g
s
0 .43 .818 r
.14242 .42877 m .14706 .4313 L .16426 .43806 L p F P
0 g
s
0 0 0 r
.69181 .40495 m .69475 .40211 L .7057 .39283 L p F P
0 g
s
0 0 0 r
.61599 .2977 m .62221 .29293 L .62387 .28988 L closepath p F P
0 g
s
.667 .132 0 r
.09211 .39317 m .09589 .39728 L .08689 .39105 L p F P
0 g
s
.667 .132 0 r
.08689 .39105 m .08199 .38575 L .09211 .39317 L p F P
0 g
s
.718 .195 0 r
.14017 .3529 m .12999 .34541 L .12223 .33605 L p F P
0 g
s
.696 .175 0 r
.11259 .32831 m .12223 .33605 L .12999 .34541 L p F P
0 g
s
.831 .358 0 r
.10878 .32168 m .11259 .32831 L .12223 .33605 L p F P
0 g
s
.712 .484 .577 r
.39967 .25449 m .38429 .25387 L .38746 .24082 L p F P
0 g
s
.745 .517 .585 r
.3633 .23805 m .38746 .24082 L .38429 .25387 L p F P
0 g
s
.573 .76 .967 r
.30955 .40873 m .30562 .40943 L .31363 .4121 L closepath p F P
0 g
s
.694 .699 .851 r
.35911 .33597 m .35648 .3323 L .34971 .33545 L closepath p F P
0 g
s
0 0 0 r
.7057 .39283 m .71835 .38296 L .72177 .37773 L closepath p F P
0 g
s
.389 .727 .99 r
.25505 .46475 m .24914 .46474 L .26193 .46909 L closepath p F P
0 g
s
0 .339 .765 r
.20805 .31683 m .21162 .31872 L .20308 .31243 L p F P
0 g
s
0 .339 .765 r
.20308 .31243 m .1972 .30952 L .20805 .31683 L p F P
0 g
s
.59 .925 .713 r
.61599 .2977 m .62221 .29293 L p .59478 .31371 L F P
0 g
s
.594 .939 .937 r
.58464 .39265 m .60089 .38534 L .58679 .39285 L closepath p F P
0 g
s
.571 .94 .888 r
.61204 .38013 m .60089 .38534 L .58679 .39285 L p F P
0 g
s
0 0 0 r
.69781 .31135 m .69202 .31671 L .67848 .33347 L p F P
0 g
s
0 0 0 r
.7057 .39283 m .71835 .38296 L p .69181 .40495 L F P
0 g
s
.572 .768 .971 r
.25695 .33412 m .25095 .33267 L .25361 .33475 L closepath p F P
0 g
s
.023 0 .318 r
.72023 .27271 m .72038 .27252 L .72295 .25933 L p F P
0 g
s
0 0 .298 r
.73283 .24566 m .72295 .25933 L .72038 .27252 L p F P
0 g
s
.079 0 .409 r
.72295 .25933 m .73283 .24566 L .73318 .23321 L p F P
0 g
s
.718 .698 .83 r
.32207 .33555 m .32876 .33171 L .34971 .33545 L p F P
0 g
s
.687 .67 .829 r
.34877 .31999 m .32876 .33171 L .34971 .33545 L p F P
0 g
s
.687 .67 .829 r
.34971 .33545 m .35648 .3323 L .34877 .31999 L p F P
0 g
s
.646 .784 .948 r
.48147 .40582 m .4874 .41116 L .51535 .40443 L p F P
0 g
s
.581 .769 .969 r
.29744 .47317 m .32363 .46812 L .33165 .47452 L p F P
0 g
s
.616 .759 .947 r
.32363 .46812 m .29744 .47317 L .28927 .46735 L p F P
0 g
s
.015 0 .355 r
.78925 .27133 m .78939 .27113 L .79069 .25829 L p F P
0 g
s
0 0 .341 r
.79911 .24521 m .79069 .25829 L .78939 .27113 L p F P
0 g
s
.05 0 .417 r
.79069 .25829 m .79911 .24521 L .7989 .23288 L p F P
0 g
s
.663 .446 .579 r
.42444 .23921 m .43146 .2386 L .43224 .25179 L p F P
0 g
s
.663 .446 .579 r
.43224 .25179 m .41953 .25289 L .42444 .23921 L p F P
0 g
s
.818 .344 0 r
.11259 .32831 m .10878 .32168 L .09995 .31412 L p F P
0 g
s
.596 .885 .991 r
.53787 .46674 m .54002 .46764 L .56663 .45867 L p F P
0 g
s
.587 .892 .989 r
.57219 .46071 m .56663 .45867 L .54002 .46764 L p F P
0 g
s
.534 .888 .661 r
.64216 .36399 m .64593 .36174 L .65789 .35246 L p F P
0 g
s
.703 .615 .756 r
.41769 .31453 m .39086 .32961 L .38329 .31559 L p F P
0 g
s
.59 .766 .963 r
.25695 .33412 m .27959 .32906 L p .24529 .32806 L F P
0 g
s
.59 .766 .963 r
.24529 .32806 m .25095 .33267 L .25695 .33412 L p F P
0 g
s
0 .223 .644 r
.16188 .36853 m .15772 .36606 L .14893 .36034 L p F P
0 g
s
.601 .398 .579 r
.43224 .25179 m .43146 .2386 L .46028 .23166 L p F P
0 g
s
.51 0 0 r
.14017 .3529 m .14893 .36034 L .14012 .35388 L p F P
0 g
s
.51 0 0 r
.14012 .35388 m .12999 .34541 L .14017 .3529 L p F P
0 g
s
0 0 .166 r
.65339 .25043 m .64727 .25756 L .64552 .26701 L p F P
0 g
s
.116 0 .386 r
.64727 .25756 m .65339 .25043 L .65501 .23765 L p F P
0 g
s
.722 .635 .761 r
.38329 .31559 m .35648 .3323 L .34877 .31999 L p F P
0 g
s
0 .43 .818 r
.13696 .42561 m .14242 .42877 L p .16426 .43806 L F P
0 g
s
0 .225 .626 r
.13696 .42561 m .13523 .42463 L .14242 .42877 L closepath p F P
0 g
s
.179 .607 .941 r
.20258 .38864 m .19307 .38405 L .19931 .38804 L closepath p F P
0 g
s
0 0 0 r
.67848 .33347 m .69442 .31877 L p .66976 .34323 L F P
0 g
s
0 0 0 r
.66976 .34323 m .67305 .33915 L .67848 .33347 L p F P
0 g
s
0 0 0 r
.67848 .33347 m .69442 .31877 L .69781 .31135 L p F P
0 g
s
.544 .779 .985 r
.27534 .40722 m .291 .40374 L .30562 .40943 L p F P
0 g
s
.595 .775 .966 r
.291 .40374 m .27534 .40722 L .2671 .40077 L p F P
0 g
s
0 0 0 r
.65789 .35246 m .66976 .34323 L .67305 .33915 L closepath p F P
0 g
s
.534 .888 .661 r
.65789 .35246 m .66976 .34323 L p .64216 .36399 L F P
0 g
s
.262 .652 .966 r
.17887 .44518 m .18336 .4477 L p .20426 .44844 L F P
0 g
s
0 .479 .841 r
.17887 .44518 m .17668 .4445 L .18336 .4477 L closepath p F P
0 g
s
.668 .666 .838 r
.42518 .32919 m .45208 .31702 L p .45405 .33298 L F P
0 g
s
.679 .613 .774 r
.45208 .31702 m .42518 .32919 L .41769 .31453 L p F P
0 g
s
.618 .905 .985 r
.56663 .45867 m .57219 .46071 L .5996 .45067 L p F P
0 g
s
.767 .531 .577 r
.36121 .24898 m .3633 .23805 L .36051 .23751 L closepath p F P
0 g
s
.745 .517 .585 r
.36121 .24898 m .3633 .23805 L p .38429 .25387 L F P
0 g
s
.609 .757 .949 r
.30562 .40943 m .30955 .40873 L .30148 .40129 L p F P
0 g
s
.609 .757 .949 r
.30148 .40129 m .291 .40374 L .30562 .40943 L p F P
0 g
s
.452 0 0 r
.13523 .42463 m .12404 .41769 L .11207 .40939 L p F P
0 g
s
.418 0 0 r
.10136 .40223 m .11207 .40939 L .12404 .41769 L p F P
0 g
s
.61 .058 0 r
.09589 .39728 m .10136 .40223 L .11207 .40939 L p F P
0 g
s
.689 .714 .868 r
.31488 .32657 m .32207 .33555 L p .28772 .33718 L F P
0 g
s
.689 .714 .868 r
.28772 .33718 m .31247 .32639 L .31488 .32657 L p F P
0 g
s
.713 .71 .846 r
.31247 .32639 m .28772 .33718 L .27959 .32906 L p F P
0 g
s
.87 .427 .06 r
.16089 .27597 m .16226 .27901 L .1536 .27141 L p F P
0 g
s
.87 .427 .06 r
.1536 .27141 m .15197 .26779 L .16089 .27597 L p F P
0 g
s
.934 .57 .293 r
.16089 .27597 m .15197 .26779 L .14968 .25681 L p F P
0 g
s
.619 .768 .951 r
.33165 .47452 m .35808 .46789 L .36594 .47476 L p F P
0 g
s
.647 .752 .925 r
.35808 .46789 m .33165 .47452 L .32363 .46812 L p F P
0 g
s
.727 .728 .851 r
.32207 .33555 m .32876 .33171 L .31488 .32657 L closepath p F P
0 g
s
.674 .691 .858 r
.46045 .33223 m .45951 .33085 L .45405 .33298 L closepath p F P
0 g
s
.668 .666 .838 r
.45208 .31702 m .45951 .33085 L .45405 .33298 L p F P
0 g
s
.084 0 .372 r
.66531 .22486 m .65501 .23765 L .65339 .25043 L p F P
0 g
s
.202 .621 .949 r
.21162 .31872 m .23186 .3208 L .24297 .32798 L p F P
0 g
s
.312 .66 .973 r
.23186 .3208 m .21162 .31872 L .20308 .31243 L p F P
0 g
s
.739 .509 .581 r
.36051 .23751 m .34274 .23401 L p .36077 .25087 L F P
0 g
s
.739 .509 .581 r
.36077 .25087 m .36121 .24898 L .36051 .23751 L p F P
0 g
s
.65 .969 .884 r
.59006 .31407 m .61128 .30118 L .59478 .31371 L closepath p F P
0 g
s
.54 .927 .877 r
.56272 .32715 m .59006 .31407 L .59478 .31371 L p F P
0 g
s
.59 .925 .713 r
.62221 .29293 m .61745 .29685 L p .59478 .31371 L F P
0 g
s
.59 .925 .713 r
.61745 .29685 m .61128 .30118 L .59478 .31371 L p F P
0 g
s
0 0 .114 r
.76918 .31583 m .77081 .31222 L .76962 .31363 L closepath p F P
0 g
s
.403 .689 .977 r
.24529 .32806 m .24297 .32798 L .25095 .33267 L closepath p F P
0 g
s
.663 .686 .862 r
.48653 .3213 m .48903 .32519 L .46045 .33223 L p F P
0 g
s
.663 .686 .862 r
.46045 .33223 m .45951 .33085 L .48653 .3213 L p F P
0 g
s
.315 .708 .979 r
.2211 .45932 m .23397 .45932 L .24914 .46474 L p F P
0 g
s
.386 .727 .99 r
.23397 .45932 m .2211 .45932 L .21256 .45405 L p F P
0 g
s
.613 .931 .965 r
.60089 .38534 m .58464 .39265 L .57772 .39031 L p F P
0 g
s
.605 .909 .982 r
.55033 .40033 m .57772 .39031 L .58464 .39265 L p F P
0 g
s
.636 .766 .942 r
.36594 .47476 m .39256 .46728 L .40029 .47439 L p F P
0 g
s
.66 .745 .913 r
.39256 .46728 m .36594 .47476 L .35808 .46789 L p F P
0 g
s
0 0 0 r
.74312 .35747 m .75395 .3427 L .74609 .35081 L closepath p F P
0 g
s
0 0 .016 r
.76357 .32707 m .75395 .3427 L .74609 .35081 L p F P
0 g
s
.733 .725 .844 r
.34106 .30653 m .34877 .31999 L .32876 .33171 L p F P
0 g
s
.733 .725 .844 r
.31415 .32564 m .34106 .30653 L p .32876 .33171 L F P
0 g
s
.733 .725 .844 r
.32876 .33171 m .31488 .32657 L .31415 .32564 L p F P
0 g
s
.484 0 0 r
.1972 .30952 m .18696 .30194 L .1766 .29357 L p F P
0 g
s
0 .101 .568 r
.16686 .28575 m .1766 .29357 L .18696 .30194 L p F P
0 g
s
.788 .294 0 r
.16226 .27901 m .16686 .28575 L .1766 .29357 L p F P
0 g
s
.572 .025 0 r
.10136 .40223 m .09589 .39728 L .08689 .39105 L p F P
0 g
s
.68 .725 .884 r
.33597 .40004 m .30955 .40873 L .30148 .40129 L p F P
0 g
s
.622 .776 .955 r
.34388 .40844 m .33597 .40004 L .30955 .40873 L p F P
0 g
s
.25 .643 .962 r
.20258 .38864 m .22452 .39064 L p .19069 .38247 L F P
0 g
s
.25 .643 .962 r
.19069 .38247 m .19307 .38405 L .20258 .38864 L p F P
0 g
s
.656 .626 .808 r
.48653 .3213 m .45951 .33085 L .45208 .31702 L p F P
0 g
s
.838 .372 0 r
.06531 .3684 m .05609 .36053 L .05065 .3504 L p F P
0 g
s
0 0 .081 r
.77081 .31222 m .78164 .29865 L p .76774 .32248 L F P
0 g
s
0 0 .081 r
.76774 .32248 m .76918 .31583 L .77081 .31222 L p F P
0 g
s
0 0 .202 r
.77081 .31222 m .78164 .29865 L .78637 .28459 L p F P
0 g
s
.435 .737 .991 r
.24914 .46474 m .25505 .46475 L .24668 .45889 L p F P
0 g
s
.435 .737 .991 r
.24668 .45889 m .23397 .45932 L .24914 .46474 L p F P
0 g
s
.641 .771 .942 r
.40029 .47439 m .42707 .46665 L .43467 .47365 L p F P
0 g
s
.661 .744 .911 r
.42707 .46665 m .40029 .47439 L .39256 .46728 L p F P
0 g
s
.596 .885 .991 r
.56663 .45867 m .5652 .45808 L .53787 .46674 L p F P
0 g
s
.624 .856 .987 r
.5652 .45808 m .53787 .46674 L .53069 .46243 L p F P
0 g
s
.612 .848 .988 r
.50348 .47036 m .53069 .46243 L .53787 .46674 L p F P
0 g
s
0 0 0 r
.64456 .26924 m .63456 .28124 L .62221 .29293 L p F P
0 g
s
0 0 0 r
.64552 .26701 m .64456 .26924 L p .62221 .29293 L F P
0 g
s
.524 .853 .569 r
.61745 .29685 m .63456 .28124 L .62221 .29293 L closepath p F P
0 g
s
.677 .501 .64 r
.39967 .25449 m .41953 .25289 L .40624 .26944 L p F P
0 g
s
.677 .501 .64 r
.40624 .26944 m .40226 .26976 L .39967 .25449 L p F P
0 g
s
.717 .528 .633 r
.38429 .25387 m .39967 .25449 L .40226 .26976 L p F P
0 g
s
.675 .725 .887 r
.37449 .40307 m .37825 .40754 L p .34388 .40844 L F P
0 g
s
.675 .725 .887 r
.34388 .40844 m .35874 .40278 L .37449 .40307 L p F P
0 g
s
.698 .726 .871 r
.35874 .40278 m .34388 .40844 L .33597 .40004 L p F P
0 g
s
.476 .889 .776 r
.66282 .42399 m .66124 .42457 L .63376 .43904 L p F P
0 g
s
.592 .948 .887 r
.63047 .43925 m .63376 .43904 L .66124 .42457 L p F P
0 g
s
.755 .26 0 r
.16686 .28575 m .16226 .27901 L .1536 .27141 L p F P
0 g
s
.637 .785 .953 r
.43467 .47365 m .46159 .46595 L .46907 .47245 L p F P
0 g
s
.656 .753 .921 r
.46159 .46595 m .43467 .47365 L .42707 .46665 L p F P
0 g
s
0 0 0 r
.70654 .30186 m .69781 .31135 L .69442 .31877 L p F P
0 g
s
0 0 .05 r
.71487 .28671 m .70654 .30186 L .69781 .31135 L p F P
0 g
s
0 .223 .644 r
.14893 .36034 m .1508 .3614 L .16188 .36853 L p F P
0 g
s
0 .416 .819 r
.18977 .3822 m .1784 .37521 L .16188 .36853 L p F P
0 g
s
0 .44 .848 r
.1508 .3614 m .16188 .36853 L .1784 .37521 L p F P
0 g
s
.71 .89 .963 r
.55925 .32521 m .56272 .32715 L .59006 .31407 L p F P
0 g
s
.637 .809 .965 r
.53069 .46243 m .50348 .47036 L .49614 .46477 L p F P
0 g
s
.628 .811 .97 r
.46907 .47245 m .49614 .46477 L .50348 .47036 L p F P
0 g
s
.759 .253 0 r
.08199 .38575 m .07231 .3781 L .06531 .3684 L p F P
0 g
s
.743 .24 0 r
.05609 .36053 m .06531 .3684 L .07231 .3781 L p F P
0 g
s
0 0 .107 r
.76357 .32707 m .76774 .32248 L .76918 .31583 L closepath p F P
0 g
s
.717 .528 .633 r
.40226 .26976 m .37602 .26871 L .38429 .25387 L p F P
0 g
s
.745 .563 .649 r
.36135 .25095 m .38429 .25387 L .37602 .26871 L p F P
0 g
s
.745 .517 .585 r
.38429 .25387 m .36135 .25095 L .36121 .24898 L p F P
0 g
s
.677 .718 .879 r
.4102 .40371 m .41264 .40678 L p .37825 .40754 L F P
0 g
s
.677 .718 .879 r
.37825 .40754 m .38781 .40384 L .4102 .40371 L p F P
0 g
s
.678 .727 .886 r
.37825 .40754 m .38781 .40384 L .37449 .40307 L closepath p F P
0 g
s
.647 .774 .941 r
.49614 .46477 m .46907 .47245 L .46159 .46595 L p F P
0 g
s
.026 .511 .877 r
.17668 .4445 m .17887 .44518 L .17014 .43977 L p F P
0 g
s
.026 .511 .877 r
.17014 .43977 m .16426 .43806 L .17668 .4445 L p F P
0 g
s
0 0 .19 r
.72017 .27313 m .72038 .27252 L .72023 .27271 L closepath p F P
0 g
s
0 0 .151 r
.72038 .27252 m .73033 .25888 L p .71876 .28219 L F P
0 g
s
0 0 .151 r
.71876 .28219 m .72017 .27313 L .72038 .27252 L p F P
0 g
s
0 0 .298 r
.72038 .27252 m .73033 .25888 L .73283 .24566 L p F P
0 g
s
.671 .722 .888 r
.4431 .40147 m .44704 .40635 L p .41264 .40678 L F P
0 g
s
.671 .722 .888 r
.41264 .40678 m .42454 .40245 L .4431 .40147 L p F P
0 g
s
.67 .715 .883 r
.41264 .40678 m .42454 .40245 L .4102 .40371 L closepath p F P
0 g
s
0 0 .188 r
.71487 .28671 m .71876 .28219 L .72017 .27313 L closepath p F P
0 g
s
.739 .509 .581 r
.34274 .23401 m .34027 .24679 L .36077 .25087 L p F P
0 g
s
.819 .576 .572 r
.32637 .22847 m .34274 .23401 L .34027 .24679 L p F P
0 g
s
.653 .746 .918 r
.4939 .33257 m .52108 .32404 L .52833 .33226 L p F P
0 g
s
.645 .674 .864 r
.51469 .31463 m .52108 .32404 L .4939 .33257 L p F P
0 g
s
.645 .674 .864 r
.4939 .33257 m .48903 .32519 L .51469 .31463 L p F P
0 g
s
.703 .615 .756 r
.41519 .30873 m .41769 .31453 L p .38329 .31559 L F P
0 g
s
.703 .615 .756 r
.38329 .31559 m .39302 .30895 L .41519 .30873 L p F P
0 g
s
.711 .633 .768 r
.38329 .31559 m .39302 .30895 L .37996 .30854 L closepath p F P
0 g
s
.722 .635 .761 r
.37996 .30854 m .38329 .31559 L p .34877 .31999 L F P
0 g
s
.674 .497 .638 r
.41953 .25289 m .43224 .25179 L .4348 .26699 L p F P
0 g
s
.674 .497 .638 r
.4348 .26699 m .40624 .26944 L .41953 .25289 L p F P
0 g
s
0 .26 .676 r
.13523 .42463 m .13696 .42561 L .12808 .41992 L p F P
0 g
s
0 .26 .676 r
.12808 .41992 m .12404 .41769 L .13523 .42463 L p F P
0 g
s
.642 .863 .983 r
.57772 .39031 m .55033 .40033 L .5432 .39551 L p F P
0 g
s
.644 .838 .975 r
.55033 .40033 m .5432 .39551 L p .51593 .40427 L F P
0 g
s
.679 .613 .774 r
.44663 .30478 m .45208 .31702 L p .41769 .31453 L F P
0 g
s
.679 .613 .774 r
.41769 .31453 m .43335 .30632 L .44663 .30478 L p F P
0 g
s
.675 .602 .766 r
.41769 .31453 m .43335 .30632 L .41519 .30873 L closepath p F P
0 g
s
.661 .741 .91 r
.44704 .40635 m .47404 .39742 L .48147 .40582 L p F P
0 g
s
.661 .719 .891 r
.47296 .39593 m .47404 .39742 L .44704 .40635 L p F P
0 g
s
.661 .719 .891 r
.44704 .40635 m .4431 .40147 L .47296 .39593 L p F P
0 g
s
.035 0 .392 r
.73728 .22699 m .73318 .23321 L .73283 .24566 L p F P
0 g
s
0 .381 .813 r
.1972 .30952 m .20308 .31243 L .19451 .30548 L p F P
0 g
s
0 .381 .813 r
.19451 .30548 m .18696 .30194 L .1972 .30952 L p F P
0 g
s
0 0 .269 r
.78921 .27198 m .78939 .27113 L .78925 .27133 L closepath p F P
0 g
s
0 0 0 r
.71609 .38543 m .70231 .39677 L .69181 .40495 L p F P
0 g
s
0 0 0 r
.71835 .38296 m .71609 .38543 L p .69181 .40495 L F P
0 g
s
.461 .854 .654 r
.69181 .40495 m .68873 .40705 L p .66282 .42399 L F P
0 g
s
.469 .843 .607 r
.68873 .40705 m .70231 .39677 L .69181 .40495 L closepath p F P
0 g
s
.668 .826 .96 r
.55925 .32521 m .55565 .32277 L .52833 .33226 L p F P
0 g
s
.649 .775 .94 r
.55565 .32277 m .52833 .33226 L .52108 .32404 L p F P
0 g
s
.511 .901 .75 r
.66124 .42457 m .6694 .41957 L .66282 .42399 L closepath p F P
0 g
s
.461 .854 .654 r
.68873 .40705 m .6694 .41957 L .66282 .42399 L p F P
0 g
s
.262 .652 .966 r
.20426 .44844 m .20384 .44824 L .17887 .44518 L p F P
0 g
s
.248 .651 .963 r
.20384 .44824 m .17887 .44518 L .17014 .43977 L p F P
0 g
s
.641 .11 0 r
.08199 .38575 m .08689 .39105 L .07788 .38411 L p F P
0 g
s
.641 .11 0 r
.07788 .38411 m .07231 .3781 L .08199 .38575 L p F P
0 g
s
0 0 .253 r
.78939 .27113 m .79788 .25808 L p .78861 .28153 L F P
0 g
s
0 0 .253 r
.78861 .28153 m .78921 .27198 L .78939 .27113 L p F P
0 g
s
0 0 .341 r
.78939 .27113 m .79788 .25808 L .79911 .24521 L p F P
0 g
s
0 0 .397 r
.80459 .22293 m .7989 .23288 L .79911 .24521 L p F P
0 g
s
.696 .175 0 r
.12999 .34541 m .12034 .33765 L .11259 .32831 L p F P
0 g
s
.668 .154 0 r
.10349 .32029 m .11259 .32831 L .12034 .33765 L p F P
0 g
s
.818 .344 0 r
.09995 .31412 m .10349 .32029 L .11259 .32831 L p F P
0 g
s
.479 .768 .994 r
.28927 .46735 m .28106 .46085 L .25505 .46475 L p F P
0 g
s
.587 .754 .958 r
.28106 .46085 m .25505 .46475 L .24668 .45889 L p F P
0 g
s
.621 .461 .644 r
.4348 .26699 m .43224 .25179 L .46105 .24476 L p F P
0 g
s
.601 .398 .579 r
.46028 .23166 m .46105 .24476 L .43224 .25179 L p F P
0 g
s
.753 .523 .584 r
.36135 .25095 m .36121 .24898 L .36077 .25087 L closepath p F P
0 g
s
0 0 .27 r
.78637 .28459 m .78861 .28153 L .78921 .27198 L closepath p F P
0 g
s
.704 .604 .743 r
.41519 .30873 m .41025 .29634 L .39302 .30895 L closepath p F P
0 g
s
.713 .622 .754 r
.40735 .28777 m .41025 .29634 L .39302 .30895 L p F P
0 g
s
.713 .622 .754 r
.38841 .28754 m .40735 .28777 L p .39302 .30895 L F P
0 g
s
.713 .622 .754 r
.37576 .29896 m .38841 .28754 L p .39302 .30895 L F P
0 g
s
.713 .622 .754 r
.39302 .30895 m .37996 .30854 L .37576 .29896 L p F P
0 g
s
.646 .784 .948 r
.51591 .40426 m .50862 .39735 L .48147 .40582 L p F P
0 g
s
.646 .784 .948 r
.51535 .40443 m .51591 .40426 L p .48147 .40582 L F P
0 g
s
.657 .734 .906 r
.50862 .39735 m .48147 .40582 L .47404 .39742 L p F P
0 g
s
.613 .931 .965 r
.61044 .37997 m .60089 .38534 L p .57772 .39031 L F P
0 g
s
.606 .944 .936 r
.60089 .38534 m .61044 .37997 L .61204 .38013 L closepath p F P
0 g
s
.633 .825 .974 r
.51591 .40426 m .51535 .40443 L .51593 .40427 L closepath p F P
0 g
s
.452 .7 .973 r
.24297 .32798 m .24529 .32806 L .23693 .32075 L p F P
0 g
s
.452 .7 .973 r
.23693 .32075 m .23186 .3208 L .24297 .32798 L p F P
0 g
s
.722 .635 .761 r
.34877 .31999 m .36535 .30739 L .37996 .30854 L p F P
0 g
s
.746 .645 .749 r
.36535 .30739 m .34877 .31999 L .34106 .30653 L p F P
0 g
s
.643 .828 .972 r
.51591 .40426 m .51648 .40408 L .51593 .40427 L closepath p F P
0 g
s
.644 .838 .975 r
.5432 .39551 m .51648 .40408 L .51593 .40427 L p F P
0 g
s
.65 .786 .946 r
.51648 .40408 m .51591 .40426 L .50862 .39735 L p F P
0 g
s
.674 .59 .753 r
.43335 .30632 m .41519 .30873 L .41025 .29634 L p F P
0 g
s
.536 .739 .969 r
.26462 .39865 m .25588 .39411 L .23298 .39688 L p F P
0 g
s
.521 .757 .982 r
.25588 .39411 m .23298 .39688 L .22452 .39064 L p F P
0 g
s
0 .43 .818 r
.16426 .43806 m .15234 .4314 L .13696 .42561 L p F P
0 g
s
0 .435 .827 r
.15234 .4314 m .13696 .42561 L .12808 .41992 L p F P
0 g
s
.65 .786 .946 r
.54179 .39421 m .51648 .40408 L p .50862 .39735 L F P
0 g
s
.654 .79 .947 r
.51648 .40408 m .54179 .39421 L .5432 .39551 L closepath p F P
0 g
s
.724 .627 .749 r
.37996 .30854 m .37576 .29896 L .36535 .30739 L closepath p F P
0 g
s
.677 .718 .88 r
.4102 .40371 m .405 .39719 L .38781 .40384 L closepath p F P
0 g
s
.678 .727 .886 r
.39735 .3861 m .405 .39719 L .38781 .40384 L p F P
0 g
s
.678 .727 .886 r
.37049 .39833 m .39735 .3861 L p .38781 .40384 L F P
0 g
s
.678 .727 .886 r
.38781 .40384 m .37449 .40307 L .37049 .39833 L p F P
0 g
s
.745 .563 .649 r
.37602 .26871 m .36487 .26731 L .36135 .25095 L p F P
0 g
s
.752 .568 .646 r
.36077 .25087 m .36135 .25095 L .36487 .26731 L p F P
0 g
s
.638 .758 .935 r
.291 .40374 m .30148 .40129 L .29338 .39316 L p F P
0 g
s
.638 .758 .935 r
.29338 .39316 m .2734 .39897 L .291 .40374 L p F P
0 g
s
.595 .775 .966 r
.2671 .40077 m .2734 .39897 L .291 .40374 L p F P
0 g
s
.783 .588 .637 r
.34027 .24679 m .36077 .25087 L .35299 .26553 L p F P
0 g
s
.752 .568 .646 r
.36487 .26731 m .35299 .26553 L .36077 .25087 L p F P
0 g
s
.67 .716 .883 r
.42454 .40245 m .4102 .40371 L .405 .39719 L p F P
0 g
s
.511 .327 .568 r
.46105 .24476 m .46028 .23166 L .48542 .22026 L p F P
0 g
s
.682 .534 .678 r
.40293 .27251 m .40624 .26944 L .40226 .26976 L closepath p F P
0 g
s
.727 .593 .706 r
.40226 .26976 m .40293 .27251 L .38841 .28754 L p F P
0 g
s
.727 .593 .706 r
.37602 .26871 m .40226 .26976 L p .38841 .28754 L F P
0 g
s
0 0 0 r
.76774 .32248 m .76357 .32707 L .75395 .3427 L p F P
0 g
s
0 0 .166 r
.64552 .26701 m .64754 .26465 L .65339 .25043 L p F P
0 g
s
0 0 .101 r
.66506 .23602 m .65339 .25043 L .64754 .26465 L p F P
0 g
s
.084 0 .372 r
.65339 .25043 m .66506 .23602 L .66531 .22486 L p F P
0 g
s
.676 .548 .702 r
.40624 .26944 m .4348 .26699 L p .42629 .28571 L F P
0 g
s
.676 .548 .702 r
.40293 .27251 m .40624 .26944 L p .42629 .28571 L F P
0 g
s
.676 .548 .702 r
.42629 .28571 m .40735 .28777 L .40293 .27251 L p F P
0 g
s
.711 .568 .692 r
.40735 .28777 m .40293 .27251 L .38841 .28754 L closepath p F P
0 g
s
.041 .511 .886 r
.19069 .38247 m .18977 .3822 L .19307 .38405 L closepath p F P
0 g
s
.59 .766 .963 r
.27959 .32906 m .27144 .32041 L .24529 .32806 L p F P
0 g
s
.663 .733 .902 r
.27144 .32041 m .24529 .32806 L .23693 .32075 L p F P
0 g
s
.675 .726 .888 r
.37449 .40307 m .37049 .39833 L .35874 .40278 L closepath p F P
0 g
s
.69 .713 .866 r
.31488 .32657 m .31415 .32564 L .31247 .32639 L closepath p F P
0 g
s
.746 .645 .749 r
.34106 .30653 m .34421 .30363 L .36535 .30739 L p F P
0 g
s
.712 .605 .735 r
.3626 .28532 m .34421 .30363 L .36535 .30739 L p F P
0 g
s
.712 .605 .735 r
.37081 .28624 m .3626 .28532 L p .36535 .30739 L F P
0 g
s
.712 .605 .735 r
.36535 .30739 m .37576 .29896 L .37081 .28624 L p F P
0 g
s
.656 .626 .808 r
.45208 .31702 m .47913 .30683 L .48653 .3213 L p F P
0 g
s
.651 .597 .781 r
.47523 .29758 m .47913 .30683 L .45208 .31702 L p F P
0 g
s
.651 .597 .781 r
.45208 .31702 m .44663 .30478 L .47523 .29758 L p F P
0 g
s
.713 .71 .846 r
.27959 .32906 m .29215 .32235 L .31247 .32639 L p F P
0 g
s
.686 .696 .854 r
.30623 .31473 m .29215 .32235 L .31247 .32639 L p F P
0 g
s
.686 .696 .854 r
.31247 .32639 m .31415 .32564 L .30623 .31473 L p F P
0 g
s
.698 .726 .871 r
.33597 .40004 m .33846 .39891 L .35874 .40278 L p F P
0 g
s
.672 .7 .868 r
.36272 .38791 m .33846 .39891 L .35874 .40278 L p F P
0 g
s
.672 .7 .868 r
.35874 .40278 m .37049 .39833 L .36272 .38791 L p F P
0 g
s
.467 0 0 r
.12999 .34541 m .14012 .35388 L .13826 .35237 L p F P
0 g
s
.467 0 0 r
.12034 .33765 m .12999 .34541 L p .13826 .35237 L F P
0 g
s
.674 .59 .753 r
.41025 .29634 m .42629 .28571 L p .43335 .30632 L F P
0 g
s
.678 .568 .724 r
.41025 .29634 m .42629 .28571 L .40735 .28777 L closepath p F P
0 g
s
.727 .593 .706 r
.36832 .2788 m .37602 .26871 L p .38841 .28754 L F P
0 g
s
.743 .59 .686 r
.36832 .2788 m .37602 .26871 L .36487 .26731 L closepath p F P
0 g
s
.671 .722 .888 r
.4431 .40147 m .43951 .39702 L .42454 .40245 L closepath p F P
0 g
s
.67 .716 .883 r
.43196 .38596 m .43951 .39702 L .42454 .40245 L p F P
0 g
s
.67 .716 .883 r
.405 .39719 m .43196 .38596 L p .42454 .40245 L F P
0 g
s
.745 .66 .767 r
.34106 .30653 m .31415 .32564 L .30623 .31473 L p F P
0 g
s
.725 .611 .73 r
.37576 .29896 m .38841 .28754 L .37081 .28624 L closepath p F P
0 g
s
.616 .759 .947 r
.28927 .46735 m .31559 .46093 L .32363 .46812 L p F P
0 g
s
.643 .749 .927 r
.31559 .46093 m .28927 .46735 L .28106 .46085 L p F P
0 g
s
.727 .593 .706 r
.38841 .28754 m .37081 .28624 L .36832 .2788 L p F P
0 g
s
.418 0 0 r
.12404 .41769 m .11332 .41052 L .10136 .40223 L p F P
0 g
s
.572 .025 0 r
.08689 .39105 m .09112 .39484 L .10136 .40223 L p F P
0 g
s
0 .159 .604 r
.09112 .39484 m .10136 .40223 L .11332 .41052 L p F P
0 g
s
.534 .888 .661 r
.66976 .34323 m .66695 .3454 L p .64216 .36399 L F P
0 g
s
.534 .888 .661 r
.66695 .3454 m .65103 .35709 L .64216 .36399 L p F P
0 g
s
.592 .942 .789 r
.63951 .36481 m .65103 .35709 L .64216 .36399 L closepath p F P
0 g
s
.489 .894 .769 r
.61204 .38013 m .63951 .36481 L .64216 .36399 L p F P
0 g
s
0 0 0 r
.71609 .38543 m .72487 .3771 L .71835 .38296 L closepath p F P
0 g
s
0 0 0 r
.7417 .35919 m .72487 .3771 L .71835 .38296 L p F P
0 g
s
.577 .932 .938 r
.63047 .43925 m .62715 .4391 L .5996 .45067 L p F P
0 g
s
.601 .924 .969 r
.62715 .4391 m .5996 .45067 L .59272 .44839 L p F P
0 g
s
.618 .905 .985 r
.5996 .45067 m .59272 .44839 L p .56663 .45867 L F P
0 g
s
.473 .745 .988 r
.23397 .45932 m .24668 .45889 L .23827 .45251 L p F P
0 g
s
.473 .745 .988 r
.23827 .45251 m .2189 .45381 L .23397 .45932 L p F P
0 g
s
.386 .727 .99 r
.21256 .45405 m .2189 .45381 L .23397 .45932 L p F P
0 g
s
.679 .599 .759 r
.44663 .30478 m .44465 .30002 L .43335 .30632 L closepath p F P
0 g
s
.674 .59 .753 r
.43933 .28437 m .44465 .30002 L .43335 .30632 L p F P
0 g
s
.674 .59 .753 r
.42629 .28571 m .43933 .28437 L p .43335 .30632 L F P
0 g
s
.675 .965 .931 r
.61044 .37997 m .61204 .38013 L .63951 .36481 L p F P
0 g
s
.677 .857 .968 r
.55565 .32277 m .57774 .31396 L .55925 .32521 L closepath p F P
0 g
s
.71 .89 .963 r
.58315 .31171 m .57774 .31396 L .55925 .32521 L p F P
0 g
s
.71 .89 .963 r
.59006 .31407 m .58315 .31171 L p .55925 .32521 L F P
0 g
s
.643 .668 .859 r
.51376 .31323 m .51469 .31463 L .48903 .32519 L p F P
0 g
s
.643 .668 .859 r
.48903 .32519 m .48653 .3213 L .51376 .31323 L p F P
0 g
s
.531 .917 .792 r
.6694 .41957 m .66124 .42457 L .65481 .42558 L p F P
0 g
s
.592 .948 .887 r
.66124 .42457 m .65481 .42558 L p .63047 .43925 L F P
0 g
s
.74 .733 .845 r
.29215 .32235 m .27959 .32906 L .27144 .32041 L p F P
0 g
s
0 0 .005 r
.71876 .28219 m .71487 .28671 L .70654 .30186 L p F P
0 g
s
.671 .722 .888 r
.46658 .38718 m .47296 .39593 L .4431 .40147 L p F P
0 g
s
.671 .722 .888 r
.4431 .40147 m .43951 .39702 L .46658 .38718 L p F P
0 g
s
.102 .538 .912 r
.18977 .3822 m .19069 .38247 L .18204 .37622 L p F P
0 g
s
.102 .538 .912 r
.18204 .37622 m .1784 .37521 L .18977 .3822 L p F P
0 g
s
.618 .895 .988 r
.5652 .45808 m .58443 .45132 L .56663 .45867 L closepath p F P
0 g
s
.618 .905 .985 r
.59272 .44839 m .58443 .45132 L .56663 .45867 L p F P
0 g
s
0 .273 .712 r
.1508 .3614 m .14893 .36034 L .14012 .35388 L p F P
0 g
s
.726 .581 .692 r
.36487 .26731 m .35299 .26553 L p .3626 .28532 L F P
0 g
s
.726 .581 .692 r
.3626 .28532 m .36832 .2788 L .36487 .26731 L p F P
0 g
s
.634 .771 .946 r
.2734 .39897 m .26462 .39865 L .2671 .40077 L closepath p F P
0 g
s
.738 .599 .702 r
.37081 .28624 m .36832 .2788 L .3626 .28532 L closepath p F P
0 g
s
.602 .947 .922 r
.62715 .4391 m .64753 .42921 L .63047 .43925 L closepath p F P
0 g
s
.592 .948 .887 r
.65481 .42558 m .64753 .42921 L .63047 .43925 L p F P
0 g
s
.647 .752 .925 r
.32363 .46812 m .35019 .46007 L .35808 .46789 L p F P
0 g
s
.669 .737 .901 r
.35019 .46007 m .32363 .46812 L .31559 .46093 L p F P
0 g
s
0 0 0 r
.64456 .26924 m .64754 .26465 L .64552 .26701 L closepath p F P
0 g
s
.628 .496 .683 r
.43729 .27743 m .4348 .26699 L .46341 .25971 L p F P
0 g
s
.621 .461 .644 r
.46105 .24476 m .46341 .25971 L .4348 .26699 L p F P
0 g
s
.676 .548 .702 r
.4348 .26699 m .43729 .27743 L .42629 .28571 L p F P
0 g
s
.25 .643 .962 r
.22452 .39064 m .21603 .3839 L .19069 .38247 L p F P
0 g
s
.422 .69 .975 r
.21603 .3839 m .19069 .38247 L .18204 .37622 L p F P
0 g
s
.819 .576 .572 r
.34027 .24679 m .32426 .24113 L .32637 .22847 L p F P
0 g
s
.861 .615 .565 r
.31302 .22182 m .32637 .22847 L .32426 .24113 L p F P
0 g
s
0 0 0 r
.69412 .31919 m .67737 .33621 L .66976 .34323 L p F P
0 g
s
0 0 0 r
.69442 .31877 m .69412 .31919 L p .66976 .34323 L F P
0 g
s
.526 .861 .589 r
.66695 .3454 m .67737 .33621 L .66976 .34323 L closepath p F P
0 g
s
0 .101 .568 r
.18696 .30194 m .17734 .29407 L .16686 .28575 L p F P
0 g
s
.755 .26 0 r
.1536 .27141 m .15785 .2776 L .16686 .28575 L p F P
0 g
s
0 .133 .619 r
.15785 .2776 m .16686 .28575 L .17734 .29407 L p F P
0 g
s
.678 .55 .703 r
.43933 .28437 m .43729 .27743 L .42629 .28571 L closepath p F P
0 g
s
.652 .585 .767 r
.47173 .28865 m .47523 .29758 L .44663 .30478 L p F P
0 g
s
.652 .585 .767 r
.44663 .30478 m .44465 .30002 L .47173 .28865 L p F P
0 g
s
.494 .883 .707 r
.6694 .41957 m .6849 .40879 L .68873 .40705 L closepath p F P
0 g
s
.531 .917 .792 r
.6849 .40879 m .6694 .41957 L p .65481 .42558 L F P
0 g
s
.625 .956 .915 r
.61128 .30118 m .59006 .31407 L .58315 .31171 L p F P
0 g
s
.312 .66 .973 r
.20308 .31243 m .22125 .31339 L .23186 .3208 L p F P
0 g
s
.386 .679 .975 r
.22125 .31339 m .20308 .31243 L .19451 .30548 L p F P
0 g
s
.765 .661 .748 r
.34163 .28145 m .3626 .28532 L .34421 .30363 L p F P
0 g
s
.726 .581 .692 r
.35299 .26553 m .34163 .28145 L .3626 .28532 L p F P
0 g
s
0 0 0 r
.75395 .3427 m .7651 .33047 L p .74276 .35818 L F P
0 g
s
0 0 0 r
.74276 .35818 m .74312 .35747 L .75395 .3427 L p F P
0 g
s
0 0 0 r
.75395 .3427 m .7651 .33047 L .76774 .32248 L p F P
0 g
s
.66 .745 .913 r
.35808 .46789 m .3848 .45906 L .39256 .46728 L p F P
0 g
s
.677 .725 .886 r
.3848 .45906 m .35808 .46789 L .35019 .46007 L p F P
0 g
s
.783 .588 .637 r
.35299 .26553 m .33422 .26086 L .34027 .24679 L p F P
0 g
s
.825 .625 .633 r
.32426 .24113 m .34027 .24679 L .33422 .26086 L p F P
0 g
s
.68 .725 .884 r
.33409 .39783 m .33597 .40004 L p .30148 .40129 L F P
0 g
s
.68 .725 .884 r
.30148 .40129 m .31344 .39652 L .33409 .39783 L p F P
0 g
s
.705 .74 .879 r
.31344 .39652 m .30148 .40129 L .29338 .39316 L p F P
0 g
s
.079 .536 .903 r
.16426 .43806 m .17014 .43977 L .16138 .43386 L p F P
0 g
s
.079 .536 .903 r
.16138 .43386 m .15234 .4314 L .16426 .43806 L p F P
0 g
s
.643 .549 .734 r
.46805 .27723 m .47173 .28865 L .44465 .30002 L p F P
0 g
s
.643 .549 .734 r
.44465 .30002 m .43933 .28437 L .46805 .27723 L p F P
0 g
s
0 .273 .712 r
.14012 .35388 m .14033 .354 L .1508 .3614 L p F P
0 g
s
0 .44 .848 r
.1784 .37521 m .16758 .36797 L .1508 .3614 L p F P
0 g
s
.008 .458 .869 r
.14033 .354 m .1508 .3614 L .16758 .36797 L p F P
0 g
s
.631 .623 .824 r
.51376 .31323 m .48653 .3213 L .47913 .30683 L p F P
0 g
s
.641 .529 .71 r
.43933 .28437 m .43729 .27743 L .46436 .26395 L p F P
0 g
s
.628 .496 .683 r
.46341 .25971 m .46436 .26395 L .43729 .27743 L p F P
0 g
s
.792 .65 .706 r
.33422 .26086 m .35299 .26553 L .34163 .28145 L p F P
0 g
s
.699 .732 .876 r
.33597 .40004 m .33846 .39891 L .33409 .39783 L closepath p F P
0 g
s
0 0 .159 r
.78861 .28153 m .78637 .28459 L .78164 .29865 L p F P
0 g
s
.702 .674 .82 r
.39735 .3861 m .37049 .39833 L .36272 .38791 L p F P
0 g
s
.661 .744 .911 r
.39256 .46728 m .41943 .45837 L .42707 .46665 L p F P
0 g
s
.675 .72 .882 r
.41943 .45837 m .39256 .46728 L .3848 .45906 L p F P
0 g
s
.759 .67 .763 r
.34106 .30653 m .34421 .30363 L .33873 .30218 L closepath p F P
0 g
s
.765 .661 .748 r
.33338 .2914 m .34163 .28145 L p .34421 .30363 L F P
0 g
s
.765 .661 .748 r
.34421 .30363 m .33873 .30218 L .33338 .2914 L p F P
0 g
s
.745 .66 .767 r
.33873 .30218 m .34106 .30653 L p .30623 .31473 L F P
0 g
s
.441 .737 .99 r
.2189 .45381 m .20426 .44844 L .21256 .45405 L closepath p F P
0 g
s
0 0 .365 r
.74123 .21998 m .73728 .22699 L .73757 .23851 L p F P
0 g
s
.035 0 .392 r
.73283 .24566 m .73757 .23851 L .73728 .22699 L p F P
0 g
s
.641 .529 .71 r
.46436 .26395 m .46805 .27723 L .43933 .28437 L p F P
0 g
s
.532 0 0 r
.09112 .39484 m .08689 .39105 L .07788 .38411 L p F P
0 g
s
.632 .871 .987 r
.58443 .45132 m .5652 .45808 L .55812 .45385 L p F P
0 g
s
.624 .856 .987 r
.53069 .46243 m .55812 .45385 L .5652 .45808 L p F P
0 g
s
.668 .947 .958 r
.60526 .37876 m .6319 .36558 L .61044 .37997 L closepath p F P
0 g
s
.613 .931 .965 r
.57772 .39031 m .60526 .37876 L .61044 .37997 L p F P
0 g
s
.675 .965 .931 r
.63292 .36505 m .6319 .36558 L .61044 .37997 L p F P
0 g
s
.675 .965 .931 r
.63951 .36481 m .63292 .36505 L p .61044 .37997 L F P
0 g
s
0 0 0 r
.77508 .31335 m .76774 .32248 L .7651 .33047 L p F P
0 g
s
0 0 .081 r
.78164 .29865 m .77508 .31335 L .76774 .32248 L p F P
0 g
s
.689 .665 .822 r
.43196 .38596 m .405 .39719 L .39735 .3861 L p F P
0 g
s
.64 .731 .914 r
.29338 .39316 m .2734 .39897 L .28606 .38534 L closepath p F P
0 g
s
.74 .733 .845 r
.27144 .32041 m .2783 .31611 L .29215 .32235 L p F P
0 g
s
.711 .698 .836 r
.29828 .30337 m .2783 .31611 L .29215 .32235 L p F P
0 g
s
.711 .698 .836 r
.29215 .32235 m .30623 .31473 L .29828 .30337 L p F P
0 g
s
.699 .732 .876 r
.35493 .37643 m .36272 .38791 L .33846 .39891 L p F P
0 g
s
.699 .732 .876 r
.32805 .39072 m .35493 .37643 L p .33846 .39891 L F P
0 g
s
.699 .732 .876 r
.33846 .39891 m .33409 .39783 L .32805 .39072 L p F P
0 g
s
0 0 .266 r
.73757 .23851 m .73283 .24566 L .73033 .25888 L p F P
0 g
s
.743 .24 0 r
.07231 .3781 m .06308 .37023 L .05609 .36053 L p F P
0 g
s
.656 .753 .921 r
.42707 .46665 m .45407 .45807 L .46159 .46595 L p F P
0 g
s
.668 .723 .891 r
.45407 .45807 m .42707 .46665 L .41943 .45837 L p F P
0 g
s
0 0 0 r
.64754 .26465 m .659 .25029 L p .64176 .2741 L F P
0 g
s
0 0 0 r
.64176 .2741 m .64456 .26924 L .64754 .26465 L p F P
0 g
s
0 0 .101 r
.66502 .23622 m .66506 .23602 L p .64754 .26465 L F P
0 g
s
0 0 .101 r
.64754 .26465 m .659 .25029 L .66502 .23622 L p F P
0 g
s
.662 .777 .934 r
.25882 .39367 m .28182 .38567 L .26462 .39865 L closepath p F P
0 g
s
.556 .744 .964 r
.25882 .39367 m .25588 .39411 L .26462 .39865 L closepath p F P
0 g
s
0 .29 .719 r
.12404 .41769 m .12808 .41992 L .11916 .41367 L p F P
0 g
s
0 .29 .719 r
.11916 .41367 m .11332 .41052 L .12404 .41769 L p F P
0 g
s
0 0 .309 r
.80521 .2346 m .79911 .24521 L .79788 .25808 L p F P
0 g
s
0 0 .397 r
.79911 .24521 m .80521 .2346 L .80459 .22293 L p F P
0 g
s
.647 .774 .941 r
.46159 .46595 m .48874 .45774 L .49614 .46477 L p F P
0 g
s
.658 .739 .91 r
.48874 .45774 m .46159 .46595 L .45407 .45807 L p F P
0 g
s
.672 .67 .839 r
.46658 .38718 m .43951 .39702 L .43196 .38596 L p F P
0 g
s
.548 .404 .637 r
.46341 .25971 m .46105 .24476 L .48636 .2335 L p F P
0 g
s
.511 .327 .568 r
.48542 .22026 m .48636 .2335 L .46105 .24476 L p F P
0 g
s
.745 .66 .767 r
.30623 .31473 m .32443 .29937 L .33873 .30218 L p F P
0 g
s
.748 .655 .758 r
.33873 .30218 m .33338 .2914 L .32443 .29937 L closepath p F P
0 g
s
.642 .815 .966 r
.55812 .45385 m .53069 .46243 L .52344 .45663 L p F P
0 g
s
.637 .809 .965 r
.49614 .46477 m .52344 .45663 L .53069 .46243 L p F P
0 g
s
.588 .928 .727 r
.6849 .40879 m .68873 .40705 L .70231 .39677 L p F P
0 g
s
.68 .726 .885 r
.33409 .39783 m .32805 .39072 L .31344 .39652 L closepath p F P
0 g
s
0 0 0 r
.63456 .28124 m .64176 .2741 L .64456 .26924 L closepath p F P
0 g
s
0 .409 .843 r
.18696 .30194 m .19451 .30548 L .18592 .29794 L p F P
0 g
s
0 .409 .843 r
.18592 .29794 m .17734 .29407 L .18696 .30194 L p F P
0 g
s
.649 .77 .937 r
.52344 .45663 m .49614 .46477 L .48874 .45774 L p F P
0 g
s
0 0 0 r
.7417 .35919 m .74276 .35818 L .74312 .35747 L closepath p F P
0 g
s
0 0 0 r
.7163 .29054 m .70654 .30186 L .6951 .31803 L p F P
0 g
s
0 0 .005 r
.70654 .30186 m .7163 .29054 L .71876 .28219 L p F P
0 g
s
0 0 0 r
.69442 .31877 m .6951 .31803 L .70654 .30186 L p F P
0 g
s
.647 .895 .984 r
.60526 .37876 m .57772 .39031 L .57069 .38604 L p F P
0 g
s
.642 .863 .983 r
.5432 .39551 m .57069 .38604 L .57772 .39031 L p F P
0 g
s
0 0 0 r
.74276 .35818 m .7417 .35919 L .72487 .3771 L p F P
0 g
s
.486 .707 .968 r
.23186 .3208 m .23693 .32075 L .22853 .31304 L p F P
0 g
s
.486 .707 .968 r
.22853 .31304 m .22125 .31339 L .23186 .3208 L p F P
0 g
s
0 0 .33 r
.66635 .22322 m .66531 .22486 L .66506 .23602 L p F P
0 g
s
.613 .09 0 r
.07231 .3781 m .07788 .38411 L .06887 .37646 L p F P
0 g
s
.613 .09 0 r
.06887 .37646 m .06308 .37023 L .07231 .3781 L p F P
0 g
s
0 0 0 r
.72557 .27289 m .71876 .28219 L .7163 .29054 L p F P
0 g
s
0 0 .151 r
.73033 .25888 m .72557 .27289 L .71876 .28219 L p F P
0 g
s
.649 .775 .94 r
.52108 .32404 m .54848 .31556 L .55565 .32277 L p F P
0 g
s
.633 .679 .876 r
.54123 .30594 m .54848 .31556 L .52108 .32404 L p F P
0 g
s
.633 .679 .876 r
.51932 .31178 m .54123 .30594 L p .52108 .32404 L F P
0 g
s
.633 .679 .876 r
.52108 .32404 m .51469 .31463 L .51932 .31178 L p F P
0 g
s
.625 .956 .915 r
.61601 .29737 m .61128 .30118 L p .58315 .31171 L F P
0 g
s
.594 .94 .771 r
.61128 .30118 m .61601 .29737 L .61745 .29685 L closepath p F P
0 g
s
.668 .154 0 r
.12034 .33765 m .11123 .32964 L .10349 .32029 L p F P
0 g
s
.656 .697 .877 r
.50092 .38816 m .50126 .38864 L .47404 .39742 L p F P
0 g
s
.656 .697 .877 r
.47404 .39742 m .47296 .39593 L .50092 .38816 L p F P
0 g
s
.657 .734 .906 r
.47404 .39742 m .50126 .38864 L .50862 .39735 L p F P
0 g
s
.593 .946 .821 r
.65103 .35709 m .63951 .36481 L .63292 .36505 L p F P
0 g
s
.654 .826 .966 r
.57774 .31396 m .55565 .32277 L .54848 .31556 L p F P
0 g
s
0 0 0 r
.70231 .39677 m .7129 .38818 L .71609 .38543 L closepath p F P
0 g
s
.588 .928 .727 r
.70231 .39677 m .7129 .38818 L p .6849 .40879 L F P
0 g
s
0 0 .135 r
.79518 .27148 m .78861 .28153 L .78731 .29094 L p F P
0 g
s
0 0 .253 r
.79788 .25808 m .79518 .27148 L .78861 .28153 L p F P
0 g
s
0 0 .159 r
.78164 .29865 m .78731 .29094 L .78861 .28153 L p F P
0 g
s
0 0 0 r
.76443 .3319 m .75485 .34508 L .74276 .35818 L p F P
0 g
s
0 0 0 r
.7651 .33047 m .76443 .3319 L p .74276 .35818 L F P
0 g
s
0 0 0 r
.75485 .34508 m .74276 .35818 L .73837 .36437 L p F P
0 g
s
0 0 0 r
.72487 .3771 m .73837 .36437 L .74276 .35818 L p F P
0 g
s
.705 .74 .879 r
.29338 .39316 m .29784 .39105 L .31344 .39652 L p F P
0 g
s
.677 .71 .873 r
.3201 .38064 m .29784 .39105 L .31344 .39652 L p F P
0 g
s
.677 .71 .873 r
.31344 .39652 m .32805 .39072 L .3201 .38064 L p F P
0 g
s
.784 .664 .731 r
.33338 .2914 m .34163 .28145 L .32609 .27626 L closepath p F P
0 g
s
.792 .65 .706 r
.32571 .27534 m .33422 .26086 L p .34163 .28145 L F P
0 g
s
.792 .65 .706 r
.34163 .28145 m .32609 .27626 L .32571 .27534 L p F P
0 g
s
.737 .986 .779 r
.61601 .29737 m .61745 .29685 L .63456 .28124 L p F P
0 g
s
.454 .74 .99 r
.2189 .45381 m .23827 .45251 L p .20399 .44825 L F P
0 g
s
.454 .74 .99 r
.20399 .44825 m .20426 .44844 L .2189 .45381 L p F P
0 g
s
.737 .986 .779 r
.63456 .28124 m .64176 .2741 L p .61601 .29737 L F P
0 g
s
.529 .85 .555 r
.72487 .3771 m .73837 .36437 L p .7129 .38818 L F P
0 g
s
.529 .85 .555 r
.7129 .38818 m .71609 .38543 L .72487 .3771 L p F P
0 g
s
.771 .679 .762 r
.32443 .29937 m .30623 .31473 L .29828 .30337 L p F P
0 g
s
.659 .699 .876 r
.49385 .37803 m .50092 .38816 L .47296 .39593 L p F P
0 g
s
.659 .699 .876 r
.47296 .39593 m .46658 .38718 L .49385 .37803 L p F P
0 g
s
.65 .786 .946 r
.50862 .39735 m .53598 .38877 L .54179 .39421 L p F P
0 g
s
.651 .738 .913 r
.53598 .38877 m .50862 .39735 L .50126 .38864 L p F P
0 g
s
.665 .794 .943 r
.54179 .39421 m .5432 .39551 L .57069 .38604 L p F P
0 g
s
.587 .754 .958 r
.24668 .45889 m .27282 .45376 L .28106 .46085 L p F P
0 g
s
.614 .751 .943 r
.27282 .45376 m .24668 .45889 L .23827 .45251 L p F P
0 g
s
.304 .668 .974 r
.19138 .44178 m .17014 .43977 L .16138 .43386 L p F P
0 g
s
.248 .651 .963 r
.17014 .43977 m .19138 .44178 L .20384 .44824 L p F P
0 g
s
0 0 .33 r
.66506 .23602 m .66512 .23593 L .66635 .22322 L p F P
0 g
s
0 0 .295 r
.67396 .2099 m .66635 .22322 L .66512 .23593 L p F P
0 g
s
0 0 .381 r
.80608 .22005 m .80459 .22293 L .80521 .2346 L p F P
0 g
s
0 0 0 r
.69412 .31919 m .6951 .31803 L .69442 .31877 L closepath p F P
0 g
s
.555 .91 .709 r
.65103 .35709 m .66318 .34722 L .66695 .3454 L closepath p F P
0 g
s
.593 .946 .821 r
.66318 .34722 m .65103 .35709 L p .63292 .36505 L F P
0 g
s
.521 .757 .982 r
.22452 .39064 m .24418 .38731 L .25588 .39411 L p F P
0 g
s
.562 .759 .97 r
.24418 .38731 m .22452 .39064 L .21603 .3839 L p F P
0 g
s
.771 .679 .762 r
.29828 .30337 m .30782 .294 L .32443 .29937 L p F P
0 g
s
.744 .649 .754 r
.32514 .27602 m .30782 .294 L .32443 .29937 L p F P
0 g
s
.744 .649 .754 r
.32609 .27626 m .32514 .27602 L p .32443 .29937 L F P
0 g
s
.744 .649 .754 r
.32443 .29937 m .33338 .2914 L .32609 .27626 L p F P
0 g
s
.467 0 0 r
.13826 .35237 m .13065 .34624 L .12034 .33765 L p F P
0 g
s
0 .09 .57 r
.11123 .32964 m .12034 .33765 L .13065 .34624 L p F P
0 g
s
0 .435 .827 r
.12808 .41992 m .14092 .42451 L .15234 .4314 L p F P
0 g
s
0 .466 .862 r
.14092 .42451 m .12808 .41992 L .11916 .41367 L p F P
0 g
s
.61 .942 .945 r
.64753 .42921 m .62715 .4391 L .62041 .4374 L p F P
0 g
s
.601 .924 .969 r
.59272 .44839 m .62041 .4374 L .62715 .4391 L p F P
0 g
s
.816 .645 .671 r
.33422 .26086 m .32571 .27534 L .3181 .25715 L p F P
0 g
s
.816 .645 .671 r
.3181 .25715 m .31928 .25484 L .33422 .26086 L p F P
0 g
s
.825 .625 .633 r
.33422 .26086 m .31928 .25484 L .32426 .24113 L p F P
0 g
s
.631 .623 .824 r
.47913 .30683 m .50639 .29925 L .51376 .31323 L p F P
0 g
s
.617 .571 .78 r
.50096 .28689 m .50639 .29925 L .47913 .30683 L p F P
0 g
s
.617 .571 .78 r
.47913 .30683 m .47523 .29758 L .50096 .28689 L p F P
0 g
s
.663 .733 .902 r
.23693 .32075 m .26324 .31144 L .27144 .32041 L p F P
0 g
s
.68 .736 .893 r
.26324 .31144 m .23693 .32075 L .22853 .31304 L p F P
0 g
s
0 .159 .604 r
.11332 .41052 m .10309 .40312 L .09112 .39484 L p F P
0 g
s
.532 0 0 r
.07788 .38411 m .08137 .38722 L .09112 .39484 L p F P
0 g
s
0 .18 .639 r
.08137 .38722 m .09112 .39484 L .10309 .40312 L p F P
0 g
s
0 0 0 r
.71516 .29291 m .7163 .29054 L p .6951 .31803 L F P
0 g
s
0 0 0 r
.6951 .31803 m .70738 .30382 L .71516 .29291 L p F P
0 g
s
0 0 0 r
.67737 .33621 m .68951 .32444 L .69412 .31919 L closepath p F P
0 g
s
.567 .833 .478 r
.6951 .31803 m .70738 .30382 L p .68951 .32444 L F P
0 g
s
.567 .833 .478 r
.68951 .32444 m .69412 .31919 L .6951 .31803 L p F P
0 g
s
.848 .653 .639 r
.31113 .23441 m .32426 .24113 L .31928 .25484 L p F P
0 g
s
.861 .615 .565 r
.32426 .24113 m .31113 .23441 L .31302 .22182 L p F P
0 g
s
0 0 .027 r
.78731 .29094 m .78164 .29865 L .77508 .31335 L p F P
0 g
s
.888 .643 .563 r
.30711 .21806 m .31302 .22182 L .31113 .23441 L p F P
0 g
s
.15 .556 .928 r
.1784 .37521 m .18204 .37622 L .17336 .36947 L p F P
0 g
s
.15 .556 .928 r
.17336 .36947 m .16758 .36797 L .1784 .37521 L p F P
0 g
s
.658 .788 .944 r
.53598 .38877 m .54179 .39421 L .56634 .38233 L p F P
0 g
s
.665 .794 .943 r
.57069 .38604 m .56634 .38233 L .54179 .39421 L p F P
0 g
s
.584 .745 .953 r
.25588 .39411 m .25882 .39367 L .25051 .3861 L p F P
0 g
s
.584 .745 .953 r
.25051 .3861 m .24418 .38731 L .25588 .39411 L p F P
0 g
s
.574 .454 .679 r
.46436 .26395 m .46341 .25971 L .48904 .24879 L p F P
0 g
s
.548 .404 .637 r
.48636 .2335 m .48904 .24879 L .46341 .25971 L p F P
0 g
s
.761 .744 .837 r
.2783 .31611 m .27144 .32041 L .26324 .31144 L p F P
0 g
s
.663 .954 .725 r
.66318 .34722 m .66695 .3454 L .67737 .33621 L p F P
0 g
s
.664 .741 .908 r
.30752 .45304 m .28106 .46085 L .27282 .45376 L p F P
0 g
s
.643 .749 .927 r
.28106 .46085 m .30752 .45304 L .31559 .46093 L p F P
0 g
s
.663 .954 .725 r
.67737 .33621 m .68951 .32444 L p .66318 .34722 L F P
0 g
s
.636 .881 .986 r
.58443 .45132 m .592 .44801 L .59272 .44839 L closepath p F P
0 g
s
.632 .871 .987 r
.592 .44801 m .58443 .45132 L p .55812 .45385 L F P
0 g
s
.61 .554 .767 r
.49899 .28208 m .50096 .28689 L .47523 .29758 L p F P
0 g
s
.61 .554 .767 r
.47523 .29758 m .47173 .28865 L .49899 .28208 L p F P
0 g
s
.583 .486 .71 r
.46805 .27723 m .46436 .26395 L .49158 .25931 L p F P
0 g
s
.574 .454 .679 r
.48904 .24879 m .49158 .25931 L .46436 .26395 L p F P
0 g
s
.736 .985 .901 r
.61074 .29718 m .62782 .28532 L .61601 .29737 L closepath p F P
0 g
s
.737 .986 .779 r
.63827 .27669 m .62782 .28532 L .61601 .29737 L p F P
0 g
s
.737 .986 .779 r
.64176 .2741 m .63827 .27669 L p .61601 .29737 L F P
0 g
s
.625 .956 .915 r
.58315 .31171 m .61074 .29718 L .61601 .29737 L p F P
0 g
s
0 0 .103 r
.73695 .24894 m .73033 .25888 L .72557 .27289 L p F P
0 g
s
0 0 .266 r
.73033 .25888 m .73695 .24894 L .73757 .23851 L p F P
0 g
s
.405 .252 .559 r
.49011 .21687 m .48542 .22026 L .48636 .2335 L p F P
0 g
s
.124 .554 .921 r
.15234 .4314 m .16138 .43386 L .15258 .42749 L p F P
0 g
s
.124 .554 .921 r
.15258 .42749 m .14092 .42451 L .15234 .4314 L p F P
0 g
s
.761 .744 .837 r
.26324 .31144 m .26654 .30909 L .2783 .31611 L p F P
0 g
s
.732 .703 .824 r
.29029 .29191 m .26654 .30909 L .2783 .31611 L p F P
0 g
s
.732 .703 .824 r
.2783 .31611 m .29828 .30337 L .29029 .29191 L p F P
0 g
s
0 0 .381 r
.80521 .2346 m .80635 .2324 L .80608 .22005 L p F P
0 g
s
0 0 .363 r
.8119 .20754 m .80608 .22005 L .80635 .2324 L p F P
0 g
s
.683 .738 .892 r
.28182 .38567 m .25882 .39367 L .25051 .3861 L p F P
0 g
s
.702 .674 .82 r
.36272 .38791 m .38969 .37359 L .39735 .3861 L p F P
0 g
s
.712 .657 .794 r
.38969 .37359 m .36272 .38791 L .35493 .37643 L p F P
0 g
s
.669 .737 .901 r
.31559 .46093 m .34227 .45138 L .35019 .46007 L p F P
0 g
s
.686 .725 .879 r
.34227 .45138 m .31559 .46093 L .30752 .45304 L p F P
0 g
s
0 .133 .619 r
.17734 .29407 m .16837 .28589 L .15785 .2776 L p F P
0 g
s
0 0 .365 r
.73757 .23851 m .74101 .23243 L .74123 .21998 L p F P
0 g
s
0 0 .342 r
.74765 .20716 m .74123 .21998 L .74101 .23243 L p F P
0 g
s
.689 .665 .822 r
.39735 .3861 m .42439 .37318 L .43196 .38596 L p F P
0 g
s
.695 .643 .793 r
.42439 .37318 m .39735 .3861 L .38969 .37359 L p F P
0 g
s
0 .313 .761 r
.14033 .354 m .13826 .35237 L .14012 .35388 L closepath p F P
0 g
s
0 0 .215 r
.80517 .24546 m .79788 .25808 L .79518 .27148 L p F P
0 g
s
0 0 .309 r
.79788 .25808 m .80517 .24546 L .80521 .2346 L p F P
0 g
s
.596 .514 .733 r
.49364 .26629 m .49899 .28208 L .47173 .28865 L p F P
0 g
s
.596 .514 .733 r
.47173 .28865 m .46805 .27723 L .49364 .26629 L p F P
0 g
s
.583 .486 .71 r
.49158 .25931 m .49364 .26629 L .46805 .27723 L p F P
0 g
s
.008 .458 .869 r
.16758 .36797 m .1573 .36048 L .14033 .354 L p F P
0 g
s
.05 .473 .885 r
.13826 .35237 m .14033 .354 L .1573 .36048 L p F P
0 g
s
.721 .683 .813 r
.35493 .37643 m .32805 .39072 L .3201 .38064 L p F P
0 g
s
.677 .725 .886 r
.35019 .46007 m .37702 .44976 L .3848 .45906 L p F P
0 g
s
.692 .709 .861 r
.37702 .44976 m .35019 .46007 L .34227 .45138 L p F P
0 g
s
0 0 .234 r
.74101 .23243 m .73757 .23851 L .73695 .24894 L p F P
0 g
s
.707 .749 .885 r
.29338 .39316 m .29784 .39105 L .28606 .38534 L closepath p F P
0 g
s
.693 .456 .559 r
.38599 .21908 m .41381 .21901 L .41413 .23179 L p F P
0 g
s
.693 .456 .559 r
.41413 .23179 m .38376 .23186 L .38599 .21908 L p F P
0 g
s
.723 .485 .565 r
.37808 .2185 m .38599 .21908 L .38376 .23186 L p F P
0 g
s
.422 .69 .975 r
.18204 .37622 m .20749 .37676 L .21603 .3839 L p F P
0 g
s
.452 .695 .971 r
.20749 .37676 m .18204 .37622 L .17336 .36947 L p F P
0 g
s
.602 .384 .558 r
.41381 .21901 m .42764 .21595 L .42107 .23026 L p F P
0 g
s
.602 .384 .558 r
.42107 .23026 m .41413 .23179 L .41381 .21901 L p F P
0 g
s
.672 .67 .839 r
.43196 .38596 m .45909 .37508 L .46658 .38718 L p F P
0 g
s
.675 .642 .809 r
.45909 .37508 m .43196 .38596 L .42439 .37318 L p F P
0 g
s
.675 .72 .882 r
.3848 .45906 m .41176 .44885 L .41943 .45837 L p F P
0 g
s
.687 .698 .855 r
.41176 .44885 m .3848 .45906 L .37702 .44976 L p F P
0 g
s
.386 .679 .975 r
.19451 .30548 m .21115 .30572 L .22125 .31339 L p F P
0 g
s
.434 .686 .97 r
.21115 .30572 m .19451 .30548 L .18592 .29794 L p F P
0 g
s
.768 .64 .72 r
.32609 .27626 m .32571 .27534 L .32514 .27602 L closepath p F P
0 g
s
.631 .674 .872 r
.51469 .31463 m .51376 .31323 L .51932 .31178 L closepath p F P
0 g
s
.723 .485 .565 r
.38376 .23186 m .37848 .23148 L .37808 .2185 L p F P
0 g
s
.758 .512 .561 r
.36259 .21591 m .37808 .2185 L .37848 .23148 L p F P
0 g
s
.768 .64 .719 r
.32514 .27602 m .32571 .27534 L .3181 .25715 L p F P
0 g
s
.663 .888 .98 r
.592 .44801 m .59272 .44839 L .62041 .4374 L p F P
0 g
s
.804 .697 .747 r
.3082 .27069 m .32514 .27602 L .30782 .294 L p F P
0 g
s
.768 .64 .719 r
.3181 .25715 m .3082 .27069 L .32514 .27602 L p F P
0 g
s
0 .315 .753 r
.11332 .41052 m .11916 .41367 L .11021 .4069 L p F P
0 g
s
0 .315 .753 r
.11021 .4069 m .10309 .40312 L .11332 .41052 L p F P
0 g
s
.668 .723 .891 r
.41943 .45837 m .44651 .44881 L .45407 .45807 L p F P
0 g
s
.677 .697 .862 r
.44651 .44881 m .41943 .45837 L .41176 .44885 L p F P
0 g
s
.707 .749 .885 r
.31213 .36995 m .3201 .38064 L .29784 .39105 L p F P
0 g
s
.707 .749 .885 r
.28525 .38448 m .31213 .36995 L p .29784 .39105 L F P
0 g
s
.707 .749 .885 r
.29784 .39105 m .28606 .38534 L .28525 .38448 L p F P
0 g
s
.888 .643 .563 r
.31113 .23441 m .30964 .23347 L .30711 .21806 L p F P
0 g
s
.855 .622 .584 r
.30059 .21479 m .30711 .21806 L .30964 .23347 L p F P
0 g
s
.492 0 0 r
.08137 .38722 m .07788 .38411 L .06887 .37646 L p F P
0 g
s
.654 .826 .966 r
.58204 .31092 m .57774 .31396 L p .54848 .31556 L F P
0 g
s
.687 .855 .963 r
.57774 .31396 m .58204 .31092 L .58315 .31171 L closepath p F P
0 g
s
.05 .473 .885 r
.1313 .34666 m .13826 .35237 L p .1573 .36048 L F P
0 g
s
0 .236 .697 r
.1313 .34666 m .13065 .34624 L .13826 .35237 L closepath p F P
0 g
s
.335 .684 .979 r
.20399 .44825 m .20384 .44824 L .20426 .44844 L closepath p F P
0 g
s
.61 .942 .945 r
.65357 .42552 m .64753 .42921 L p .62041 .4374 L F P
0 g
s
.61 .95 .919 r
.64753 .42921 m .65357 .42552 L .65481 .42558 L closepath p F P
0 g
s
.627 .621 .825 r
.51932 .31178 m .51376 .31323 L .50639 .29925 L p F P
0 g
s
.656 .931 .971 r
.6319 .36558 m .60526 .37876 L .59836 .37538 L p F P
0 g
s
.647 .895 .984 r
.57069 .38604 m .59836 .37538 L .60526 .37876 L p F P
0 g
s
.374 .692 .981 r
.20384 .44824 m .20399 .44825 L .19537 .44197 L p F P
0 g
s
.374 .692 .981 r
.19537 .44197 m .19138 .44178 L .20384 .44824 L p F P
0 g
s
.454 .74 .99 r
.23827 .45251 m .22982 .44568 L .20399 .44825 L p F P
0 g
s
.545 .739 .966 r
.22982 .44568 m .20399 .44825 L .19537 .44197 L p F P
0 g
s
.658 .739 .91 r
.45407 .45807 m .48129 .44926 L .48874 .45774 L p F P
0 g
s
.665 .708 .88 r
.48129 .44926 m .45407 .45807 L .44651 .44881 L p F P
0 g
s
.657 .878 .981 r
.58574 .44451 m .592 .44801 L .61593 .43535 L p F P
0 g
s
.632 .871 .987 r
.55812 .45385 m .58574 .44451 L .592 .44801 L p F P
0 g
s
.663 .888 .98 r
.62041 .4374 m .61593 .43535 L .592 .44801 L p F P
0 g
s
.509 .71 .962 r
.22125 .31339 m .22853 .31304 L .22008 .30503 L p F P
0 g
s
.509 .71 .962 r
.22008 .30503 m .21115 .30572 L .22125 .31339 L p F P
0 g
s
0 0 0 r
.7651 .33047 m .76651 .32871 L .77508 .31335 L p F P
0 g
s
0 0 0 r
.78491 .30002 m .77508 .31335 L .76651 .32871 L p F P
0 g
s
0 0 .027 r
.78545 .2988 m .78731 .29094 L p .77508 .31335 L F P
0 g
s
0 0 .027 r
.77508 .31335 m .78491 .30002 L .78545 .2988 L p F P
0 g
s
.657 .657 .839 r
.49385 .37803 m .46658 .38718 L .45909 .37508 L p F P
0 g
s
.007 .424 .86 r
.17734 .29407 m .18592 .29794 L .1773 .28986 L p F P
0 g
s
.007 .424 .86 r
.1773 .28986 m .16837 .28589 L .17734 .29407 L p F P
0 g
s
.798 .702 .759 r
.30782 .294 m .29828 .30337 L .29029 .29191 L p F P
0 g
s
.798 .702 .759 r
.29029 .29191 m .29419 .28757 L .30782 .294 L p F P
0 g
s
.804 .697 .747 r
.30782 .294 m .29419 .28757 L .3082 .27069 L p F P
0 g
s
.401 .25 .559 r
.5071 .20438 m .49011 .21687 L .49487 .22739 L p F P
0 g
s
.405 .252 .559 r
.48636 .2335 m .49487 .22739 L .49011 .21687 L p F P
0 g
s
0 0 .085 r
.66502 .23622 m .66512 .23593 L .66506 .23602 L closepath p F P
0 g
s
0 0 0 r
.66512 .23593 m .67268 .22266 L p .66299 .24499 L F P
0 g
s
0 0 0 r
.66299 .24499 m .66502 .23622 L .66512 .23593 L p F P
0 g
s
0 0 .295 r
.66512 .23593 m .67268 .22266 L .67396 .2099 L p F P
0 g
s
0 0 .064 r
.659 .25029 m .66299 .24499 L .66502 .23622 L closepath p F P
0 g
s
.645 .83 .972 r
.58574 .44451 m .55812 .45385 L .55095 .44814 L p F P
0 g
s
.642 .815 .966 r
.52344 .45663 m .55095 .44814 L .55812 .45385 L p F P
0 g
s
.614 .952 .803 r
.68251 .40944 m .69234 .40275 L .6849 .40879 L closepath p F P
0 g
s
.531 .917 .792 r
.65481 .42558 m .68251 .40944 L .6849 .40879 L p F P
0 g
s
.588 .928 .727 r
.71015 .38981 m .69234 .40275 L .6849 .40879 L p F P
0 g
s
.588 .928 .727 r
.7129 .38818 m .71015 .38981 L p .6849 .40879 L F P
0 g
s
.649 .77 .937 r
.48874 .45774 m .51611 .44937 L .52344 .45663 L p F P
0 g
s
.655 .733 .907 r
.51611 .44937 m .48874 .45774 L .48129 .44926 L p F P
0 g
s
0 0 0 r
.659 .25029 m .64788 .26634 L .64176 .2741 L p F P
0 g
s
.672 .928 .631 r
.63827 .27669 m .64788 .26634 L .64176 .2741 L closepath p F P
0 g
s
.836 .673 .68 r
.3181 .25715 m .31928 .25484 L .31643 .25338 L closepath p F P
0 g
s
.848 .653 .639 r
.31061 .236 m .31113 .23441 L p .31928 .25484 L F P
0 g
s
.848 .653 .639 r
.31928 .25484 m .31643 .25338 L .31061 .236 L p F P
0 g
s
.736 .865 .941 r
.58204 .31092 m .58315 .31171 L .61074 .29718 L p F P
0 g
s
.673 .97 .915 r
.65357 .42552 m .65481 .42558 L .68251 .40944 L p F P
0 g
s
.648 .774 .94 r
.55095 .44814 m .52344 .45663 L .51611 .44937 L p F P
0 g
s
.607 .389 .56 r
.42764 .21595 m .44341 .21262 L .44387 .22547 L p F P
0 g
s
.607 .389 .56 r
.44387 .22547 m .42107 .23026 L .42764 .21595 L p F P
0 g
s
.758 .512 .561 r
.37848 .23148 m .36078 .22852 L .36259 .21591 L p F P
0 g
s
.807 .555 .558 r
.34517 .21062 m .36259 .21591 L .36078 .22852 L p F P
0 g
s
.791 .656 .713 r
.3082 .27069 m .3181 .25715 L .31643 .25338 L p F P
0 g
s
.632 .656 .856 r
.54123 .30594 m .51932 .31178 L .53878 .30188 L closepath p F P
0 g
s
.627 .621 .825 r
.53391 .29365 m .53878 .30188 L .51932 .31178 L p F P
0 g
s
.627 .621 .825 r
.50639 .29925 m .53391 .29365 L p .51932 .31178 L F P
0 g
s
0 0 .291 r
.80635 .2324 m .80521 .2346 L .80517 .24546 L p F P
0 g
s
.651 .738 .913 r
.50126 .38864 m .52869 .38024 L .53598 .38877 L p F P
0 g
s
.649 .688 .873 r
.52763 .37873 m .52869 .38024 L .50126 .38864 L p F P
0 g
s
.649 .688 .873 r
.50126 .38864 m .50092 .38816 L .52763 .37873 L p F P
0 g
s
.654 .826 .966 r
.54848 .31556 m .5761 .30615 L .58204 .31092 L p F P
0 g
s
.635 .754 .934 r
.5761 .30615 m .54848 .31556 L .54123 .30594 L p F P
0 g
s
.874 .674 .629 r
.31061 .236 m .31113 .23441 L .30964 .23347 L closepath p F P
0 g
s
0 0 0 r
.7163 .29054 m .71836 .28773 L .72557 .27289 L p F P
0 g
s
0 0 0 r
.73453 .25949 m .72557 .27289 L .71836 .28773 L p F P
0 g
s
0 0 .103 r
.7358 .25576 m .73695 .24894 L p .72557 .27289 L F P
0 g
s
0 0 .103 r
.72557 .27289 m .73453 .25949 L .7358 .25576 L p F P
0 g
s
0 0 0 r
.76443 .3319 m .76651 .32871 L .7651 .33047 L closepath p F P
0 g
s
.584 .911 .669 r
.71015 .38981 m .7201 .38141 L .7129 .38818 L closepath p F P
0 g
s
.529 .85 .555 r
.73837 .36437 m .73757 .36517 L p .7129 .38818 L F P
0 g
s
.529 .85 .555 r
.73757 .36517 m .7201 .38141 L .7129 .38818 L p F P
0 g
s
.646 .688 .875 r
.52134 .36986 m .52763 .37873 L .50092 .38816 L p F P
0 g
s
.646 .688 .875 r
.50092 .38816 m .49385 .37803 L .52134 .36986 L p F P
0 g
s
.791 .656 .713 r
.31643 .25338 m .30447 .24871 L p .3082 .27069 L F P
0 g
s
.815 .638 .663 r
.31643 .25338 m .31061 .236 L .30447 .24871 L closepath p F P
0 g
s
.855 .622 .584 r
.30964 .23347 m .29796 .22764 L .30059 .21479 L p F P
0 g
s
.894 .661 .579 r
.28936 .20727 m .30059 .21479 L .29796 .22764 L p F P
0 g
s
.693 .837 .952 r
.5761 .30615 m .59837 .29676 L .58204 .31092 L closepath p F P
0 g
s
.736 .865 .941 r
.60387 .29432 m .59837 .29676 L .58204 .31092 L p F P
0 g
s
.736 .865 .941 r
.61074 .29718 m .60387 .29432 L p .58204 .31092 L F P
0 g
s
.681 .818 .949 r
.56634 .38233 m .57069 .38604 L .59836 .37538 L p F P
0 g
s
.83 .657 .669 r
.30447 .24871 m .31061 .236 L .30964 .23347 L p F P
0 g
s
.466 .355 .643 r
.49487 .22739 m .48636 .2335 L .48904 .24879 L p F P
0 g
s
.83 .657 .669 r
.30964 .23347 m .29796 .22764 L p .30447 .24871 L F P
0 g
s
0 .09 .57 r
.13065 .34624 m .12155 .33822 L .11123 .32964 L p F P
0 g
s
.658 .788 .944 r
.56634 .38233 m .56357 .37989 L .53598 .38877 L p F P
0 g
s
.646 .755 .929 r
.56357 .37989 m .53598 .38877 L .52869 .38024 L p F P
0 g
s
.605 .747 .945 r
.24418 .38731 m .25051 .3861 L .24214 .37817 L p F P
0 g
s
.605 .747 .945 r
.24214 .37817 m .23296 .38028 L .24418 .38731 L p F P
0 g
s
.562 .759 .97 r
.21603 .3839 m .23296 .38028 L .24418 .38731 L p F P
0 g
s
.614 .751 .943 r
.23827 .45251 m .26454 .44618 L .27282 .45376 L p F P
0 g
s
.635 .748 .93 r
.26454 .44618 m .23827 .45251 L .22982 .44568 L p F P
0 g
s
.699 .653 .8 r
.38969 .37359 m .40534 .36493 L .38499 .36502 L closepath p F P
0 g
s
.712 .657 .794 r
.38499 .36502 m .38969 .37359 L p .35493 .37643 L F P
0 g
s
.695 .643 .793 r
.41989 .36452 m .42439 .37318 L p .38969 .37359 L F P
0 g
s
.695 .643 .793 r
.38969 .37359 m .40534 .36493 L .41989 .36452 L p F P
0 g
s
.188 .567 .937 r
.16758 .36797 m .17336 .36947 L .16464 .36227 L p F P
0 g
s
.188 .567 .937 r
.16464 .36227 m .1573 .36048 L .16758 .36797 L p F P
0 g
s
0 0 0 r
.78545 .2988 m .79091 .28545 L .78731 .29094 L closepath p F P
0 g
s
0 0 .135 r
.78731 .29094 m .79091 .28545 L .79518 .27148 L p F P
0 g
s
0 .18 .639 r
.10309 .40312 m .09334 .39548 L .08137 .38722 L p F P
0 g
s
.492 0 0 r
.06887 .37646 m .07211 .37934 L .08137 .38722 L p F P
0 g
s
0 .2 .671 r
.07211 .37934 m .08137 .38722 L .09334 .39548 L p F P
0 g
s
0 0 .1 r
.80269 .25867 m .79518 .27148 L .79091 .28545 L p F P
0 g
s
0 0 .215 r
.80513 .24609 m .80517 .24546 L p .79518 .27148 L F P
0 g
s
0 0 .215 r
.79518 .27148 m .80269 .25867 L .80513 .24609 L p F P
0 g
s
.667 .96 .939 r
.64823 .42473 m .67274 .41169 L .65357 .42552 L closepath p F P
0 g
s
.673 .97 .915 r
.67612 .40982 m .67274 .41169 L .65357 .42552 L p F P
0 g
s
.673 .97 .915 r
.68251 .40944 m .67612 .40982 L p .65357 .42552 L F P
0 g
s
.61 .942 .945 r
.62041 .4374 m .64823 .42473 L .65357 .42552 L p F P
0 g
s
.304 .668 .974 r
.16138 .43386 m .17937 .43512 L .19138 .44178 L p F P
0 g
s
.349 .679 .978 r
.17937 .43512 m .16138 .43386 L .15258 .42749 L p F P
0 g
s
.593 .759 .958 r
.23296 .38028 m .21603 .3839 L .20749 .37676 L p F P
0 g
s
0 0 0 r
.71516 .29291 m .71836 .28773 L .7163 .29054 L closepath p F P
0 g
s
.712 .657 .794 r
.35493 .37643 m .37429 .36441 L .38499 .36502 L p F P
0 g
s
.729 .657 .779 r
.37429 .36441 m .35493 .37643 L .34714 .364 L p F P
0 g
s
.721 .683 .813 r
.3201 .38064 m .34714 .364 L .35493 .37643 L p F P
0 g
s
.693 .74 .887 r
.25499 .30234 m .22853 .31304 L .22008 .30503 L p F P
0 g
s
.68 .736 .893 r
.22853 .31304 m .25499 .30234 L .26324 .31144 L p F P
0 g
s
.778 .752 .83 r
.26654 .30909 m .26324 .31144 L .25499 .30234 L p F P
0 g
s
0 0 .234 r
.73695 .24894 m .73886 .24558 L .74101 .23243 L p F P
0 g
s
0 0 .199 r
.74746 .21963 m .74101 .23243 L .73886 .24558 L p F P
0 g
s
0 0 .342 r
.74101 .23243 m .74746 .21963 L .74765 .20716 L p F P
0 g
s
0 0 0 r
.76651 .32871 m .77655 .31538 L p .76151 .33738 L F P
0 g
s
0 0 0 r
.76151 .33738 m .76443 .3319 L .76651 .32871 L p F P
0 g
s
0 0 0 r
.76651 .32871 m .77655 .31538 L .78491 .30002 L p F P
0 g
s
0 0 .291 r
.80517 .24546 m .80528 .24526 L .80635 .2324 L p F P
0 g
s
0 0 .27 r
.81221 .21991 m .80635 .2324 L .80528 .24526 L p F P
0 g
s
0 0 .363 r
.80635 .2324 m .81221 .21991 L .8119 .20754 L p F P
0 g
s
0 .466 .862 r
.11916 .41367 m .13001 .41739 L .14092 .42451 L p F P
0 g
s
.045 .489 .886 r
.13001 .41739 m .11916 .41367 L .11021 .4069 L p F P
0 g
s
.675 .642 .809 r
.42439 .37318 m .45157 .36106 L .45909 .37508 L p F P
0 g
s
.673 .633 .802 r
.45113 .3601 m .45157 .36106 L .42439 .37318 L p F P
0 g
s
.673 .633 .802 r
.42439 .37318 m .41989 .36452 L .45113 .3601 L p F P
0 g
s
.828 .716 .741 r
.29442 .26422 m .3082 .27069 L .29419 .28757 L p F P
0 g
s
.791 .656 .713 r
.30447 .24871 m .29442 .26422 L .3082 .27069 L p F P
0 g
s
.778 .752 .83 r
.25499 .30234 m .2559 .30162 L .26654 .30909 L p F P
0 g
s
.751 .714 .817 r
.28223 .28066 m .2559 .30162 L .26654 .30909 L p F P
0 g
s
.751 .714 .817 r
.26654 .30909 m .29029 .29191 L .28223 .28066 L p F P
0 g
s
.479 .292 .548 r
.45642 .20606 m .44341 .21262 L .44387 .22547 L p F P
0 g
s
.704 .507 .619 r
.38376 .23186 m .41413 .23179 L p .4097 .24625 L F P
0 g
s
.704 .507 .619 r
.37976 .24178 m .38376 .23186 L p .4097 .24625 L F P
0 g
s
.727 .519 .609 r
.37976 .24178 m .38376 .23186 L .37848 .23148 L closepath p F P
0 g
s
.162 .567 .932 r
.14092 .42451 m .15258 .42749 L .14374 .42071 L p F P
0 g
s
.162 .567 .932 r
.14374 .42071 m .13001 .41739 L .14092 .42451 L p F P
0 g
s
.617 .427 .603 r
.41462 .23678 m .42107 .23026 L .41413 .23179 L closepath p F P
0 g
s
.704 .507 .619 r
.41413 .23179 m .41462 .23678 L .4097 .24625 L p F P
0 g
s
0 0 0 r
.75485 .34508 m .76151 .33738 L .76443 .3319 L closepath p F P
0 g
s
.584 .562 .795 r
.52653 .27869 m .53391 .29365 L .50639 .29925 L p F P
0 g
s
.584 .562 .795 r
.51048 .28088 m .52653 .27869 L p .50639 .29925 L F P
0 g
s
.584 .562 .795 r
.50639 .29925 m .50096 .28689 L .51048 .28088 L p F P
0 g
s
.663 .954 .725 r
.68813 .32538 m .66941 .34114 L .66318 .34722 L p F P
0 g
s
.663 .954 .725 r
.68951 .32444 m .68813 .32538 L p .66318 .34722 L F P
0 g
s
.688 .979 .825 r
.66059 .34779 m .66941 .34114 L .66318 .34722 L closepath p F P
0 g
s
.593 .946 .821 r
.63292 .36505 m .66059 .34779 L .66318 .34722 L p F P
0 g
s
.662 .737 .906 r
.28606 .38534 m .28525 .38448 L .28182 .38567 L closepath p F P
0 g
s
.683 .738 .892 r
.25051 .3861 m .26137 .38169 L .28182 .38567 L p F P
0 g
s
.662 .728 .899 r
.27709 .37536 m .26137 .38169 L .28182 .38567 L p F P
0 g
s
.662 .728 .899 r
.28182 .38567 m .28525 .38448 L .27709 .37536 L p F P
0 g
s
.664 .741 .908 r
.27282 .45376 m .29941 .44454 L .30752 .45304 L p F P
0 g
s
.681 .736 .892 r
.29941 .44454 m .27282 .45376 L .26454 .44618 L p F P
0 g
s
.733 .523 .608 r
.37848 .23148 m .36078 .22852 L p .37819 .24584 L F P
0 g
s
.733 .523 .608 r
.37819 .24584 m .37976 .24178 L .37848 .23148 L p F P
0 g
s
.733 .674 .792 r
.34714 .364 m .3201 .38064 L .31213 .36995 L p F P
0 g
s
.569 .812 .431 r
.66299 .24499 m .659 .25029 L .64788 .26634 L p F P
0 g
s
.701 .716 .86 r
.33432 .4419 m .30752 .45304 L .29941 .44454 L p F P
0 g
s
.686 .725 .879 r
.30752 .45304 m .33432 .4419 L .34227 .45138 L p F P
0 g
s
.692 .709 .861 r
.34227 .45138 m .36922 .43943 L .37702 .44976 L p F P
0 g
s
.704 .694 .838 r
.36922 .43943 m .34227 .45138 L .33432 .4419 L p F P
0 g
s
.656 .931 .971 r
.63271 .36501 m .6319 .36558 L p .59836 .37538 L F P
0 g
s
.674 .954 .95 r
.6319 .36558 m .63271 .36501 L .63292 .36505 L closepath p F P
0 g
s
0 .256 .727 r
.13065 .34624 m .1313 .34666 L .12247 .33881 L p F P
0 g
s
0 .256 .727 r
.12247 .33881 m .12155 .33822 L .13065 .34624 L p F P
0 g
s
.702 .753 .892 r
.26137 .38169 m .25051 .3861 L .24214 .37817 L p F P
0 g
s
.687 .698 .855 r
.37702 .44976 m .40408 .43805 L .41176 .44885 L p F P
0 g
s
.697 .679 .829 r
.40408 .43805 m .37702 .44976 L .36922 .43943 L p F P
0 g
s
.736 .967 .935 r
.63271 .36501 m .63292 .36505 L .66059 .34779 L p F P
0 g
s
.616 .956 .827 r
.69234 .40275 m .68251 .40944 L .67612 .40982 L p F P
0 g
s
.729 .709 .831 r
.31213 .36995 m .28525 .38448 L .27709 .37536 L p F P
0 g
s
.629 .445 .615 r
.42107 .23026 m .44387 .22547 L p .41573 .24603 L F P
0 g
s
.629 .445 .615 r
.41573 .24603 m .41462 .23678 L .42107 .23026 L p F P
0 g
s
.657 .657 .839 r
.45909 .37508 m .4864 .36551 L .49385 .37803 L p F P
0 g
s
.655 .629 .812 r
.4864 .36551 m .45909 .37508 L .45157 .36106 L p F P
0 g
s
.699 .652 .8 r
.40534 .36493 m .38499 .36502 L .38203 .35961 L p F P
0 g
s
.712 .657 .794 r
.38499 .36502 m .38203 .35961 L .37429 .36441 L closepath p F P
0 g
s
.714 .945 .956 r
.62618 .36285 m .6508 .34943 L .63271 .36501 L closepath p F P
0 g
s
.736 .967 .935 r
.65406 .34754 m .6508 .34943 L .63271 .36501 L p F P
0 g
s
.736 .967 .935 r
.66059 .34779 m .65406 .34754 L p .63271 .36501 L F P
0 g
s
.656 .931 .971 r
.59836 .37538 m .62618 .36285 L .63271 .36501 L p F P
0 g
s
.05 .473 .885 r
.1573 .36048 m .14759 .35271 L .1313 .34666 L p F P
0 g
s
.076 .478 .892 r
.14759 .35271 m .1313 .34666 L .12247 .33881 L p F P
0 g
s
.699 .652 .8 r
.40925 .34194 m .41682 .35856 L .40534 .36493 L p F P
0 g
s
.699 .652 .8 r
.38203 .35961 m .40925 .34194 L p .40534 .36493 L F P
0 g
s
.696 .643 .792 r
.41989 .36452 m .41682 .35856 L .40534 .36493 L closepath p F P
0 g
s
.677 .697 .862 r
.41176 .44885 m .43892 .43813 L .44651 .44881 L p F P
0 g
s
.684 .674 .834 r
.43892 .43813 m .41176 .44885 L .40408 .43805 L p F P
0 g
s
.807 .555 .558 r
.36078 .22852 m .34359 .22315 L .34517 .21062 L p F P
0 g
s
.861 .605 .551 r
.33163 .20392 m .34517 .21062 L .34359 .22315 L p F P
0 g
s
.688 .487 .61 r
.41573 .24603 m .41462 .23678 L .4097 .24625 L closepath p F P
0 g
s
0 0 0 r
.71836 .28773 m .72737 .27437 L p .71258 .2974 L F P
0 g
s
0 0 0 r
.71258 .2974 m .71516 .29291 L .71836 .28773 L p F P
0 g
s
0 0 0 r
.71836 .28773 m .72737 .27437 L .73453 .25949 L p F P
0 g
s
.686 .912 .973 r
.61593 .43535 m .62041 .4374 L .64823 .42473 L p F P
0 g
s
.82 .721 .756 r
.29419 .28757 m .29029 .29191 L .28223 .28066 L p F P
0 g
s
.82 .721 .756 r
.28223 .28066 m .28241 .28045 L .29419 .28757 L p F P
0 g
s
.828 .716 .741 r
.29419 .28757 m .28241 .28045 L .29442 .26422 L p F P
0 g
s
0 0 .07 r
.7358 .25576 m .73886 .24558 L .73695 .24894 L closepath p F P
0 g
s
.404 .698 .981 r
.19138 .44178 m .19537 .44197 L .18672 .43529 L p F P
0 g
s
.404 .698 .981 r
.18672 .43529 m .17937 .43512 L .19138 .44178 L p F P
0 g
s
0 .334 .779 r
.10309 .40312 m .11021 .4069 L .10124 .39962 L p F P
0 g
s
0 .334 .779 r
.10124 .39962 m .09334 .39548 L .10309 .40312 L p F P
0 g
s
.687 .974 .914 r
.62782 .28532 m .61074 .29718 L .60387 .29432 L p F P
0 g
s
.686 .638 .796 r
.44406 .34472 m .45113 .3601 L .41989 .36452 L p F P
0 g
s
.686 .638 .796 r
.41989 .36452 m .41682 .35856 L .44406 .34472 L p F P
0 g
s
.535 .437 .69 r
.48904 .24879 m .50827 .23509 L p .50271 .26024 L F P
0 g
s
.535 .437 .69 r
.50271 .26024 m .49158 .25931 L .48904 .24879 L p F P
0 g
s
.466 .355 .643 r
.48904 .24879 m .50827 .23509 L .49487 .22739 L p F P
0 g
s
.845 .705 .708 r
.29171 .2418 m .30447 .24871 L .29442 .26422 L p F P
0 g
s
.83 .657 .669 r
.29796 .22764 m .29171 .2418 L .30447 .24871 L p F P
0 g
s
.729 .657 .779 r
.34714 .364 m .35057 .36149 L .37429 .36441 L p F P
0 g
s
.704 .637 .779 r
.37438 .34415 m .35057 .36149 L .37429 .36441 L p F P
0 g
s
.704 .637 .779 r
.37429 .36441 m .38203 .35961 L .37438 .34415 L p F P
0 g
s
0 0 0 r
.73837 .36437 m .74018 .36241 L .75485 .34508 L p F P
0 g
s
.539 .836 .509 r
.73757 .36517 m .74018 .36241 L .73837 .36437 L closepath p F P
0 g
s
0 0 0 r
.76151 .33738 m .75485 .34508 L .74018 .36241 L p F P
0 g
s
0 0 .276 r
.67998 .19852 m .67396 .2099 L .67268 .22266 L p F P
0 g
s
.616 .956 .827 r
.7057 .39145 m .69234 .40275 L p .67612 .40982 L F P
0 g
s
.601 .94 .759 r
.69234 .40275 m .7057 .39145 L .71015 .38981 L closepath p F P
0 g
s
.434 .686 .97 r
.18592 .29794 m .20161 .29778 L .21115 .30572 L p F P
0 g
s
.463 .685 .962 r
.20161 .29778 m .18592 .29794 L .1773 .28986 L p F P
0 g
s
.452 .695 .971 r
.17336 .36947 m .1989 .36928 L .20749 .37676 L p F P
0 g
s
.472 .698 .967 r
.1989 .36928 m .17336 .36947 L .16464 .36227 L p F P
0 g
s
.576 .544 .782 r
.50096 .28689 m .49899 .28208 L .51048 .28088 L closepath p F P
0 g
s
.665 .708 .88 r
.44651 .44881 m .4738 .4393 L .48129 .44926 L p F P
0 g
s
.669 .68 .851 r
.4738 .4393 m .44651 .44881 L .43892 .43813 L p F P
0 g
s
0 0 0 r
.70738 .30382 m .71258 .2974 L .71516 .29291 L closepath p F P
0 g
s
.523 .711 .957 r
.21115 .30572 m .22008 .30503 L .21157 .29684 L p F P
0 g
s
.523 .711 .957 r
.21157 .29684 m .20161 .29778 L .21115 .30572 L p F P
0 g
s
.733 .523 .608 r
.36078 .22852 m .35648 .24207 L .37819 .24584 L p F P
0 g
s
.813 .591 .601 r
.34359 .22315 m .36078 .22852 L .35648 .24207 L p F P
0 g
s
.575 .51 .745 r
.51048 .28088 m .49899 .28208 L .49364 .26629 L p F P
0 g
s
.704 .507 .619 r
.4097 .24625 m .38034 .24609 L .37976 .24178 L p F P
0 g
s
.742 .533 .612 r
.38034 .24609 m .37976 .24178 L .37819 .24584 L closepath p F P
0 g
s
.71 .608 .742 r
.40925 .34194 m .38203 .35961 L .37438 .34415 L p F P
0 g
s
.531 .462 .723 r
.49364 .26629 m .49158 .25931 L .50271 .26024 L closepath p F P
0 g
s
.647 .925 .644 r
.68813 .32538 m .69226 .32126 L .68951 .32444 L closepath p F P
0 g
s
.567 .833 .478 r
.70738 .30382 m .69226 .32126 L .68951 .32444 L p F P
0 g
s
.663 .807 .952 r
.56357 .37989 m .58294 .37316 L .56634 .38233 L closepath p F P
0 g
s
.681 .818 .949 r
.59135 .37021 m .58294 .37316 L .56634 .38233 L p F P
0 g
s
.681 .818 .949 r
.59836 .37538 m .59135 .37021 L p .56634 .38233 L F P
0 g
s
.569 .812 .431 r
.65919 .25132 m .66299 .24499 L p .64788 .26634 L F P
0 g
s
.818 .997 .774 r
.64788 .26634 m .65855 .25217 L p .63503 .27772 L F P
0 g
s
.818 .997 .774 r
.63503 .27772 m .63827 .27669 L .64788 .26634 L p F P
0 g
s
.569 .812 .431 r
.64788 .26634 m .65855 .25217 L .65919 .25132 L p F P
0 g
s
.575 .51 .745 r
.49364 .26629 m .50271 .26024 L p .51048 .28088 L F P
0 g
s
.878 .704 .662 r
.28684 .22008 m .29796 .22764 L .29171 .2418 L p F P
0 g
s
.894 .661 .579 r
.29796 .22764 m .28684 .22008 L .28936 .20727 L p F P
0 g
s
.655 .733 .907 r
.48129 .44926 m .50873 .44064 L .51611 .44937 L p F P
0 g
s
.656 .7 .879 r
.50873 .44064 m .48129 .44926 L .4738 .4393 L p F P
0 g
s
.68 .595 .753 r
.44406 .34472 m .41682 .35856 L .40925 .34194 L p F P
0 g
s
0 0 0 r
.79091 .28545 m .79856 .27264 L p .78527 .29949 L F P
0 g
s
0 0 0 r
.78527 .29949 m .78545 .2988 L .79091 .28545 L p F P
0 g
s
0 0 .1 r
.79091 .28545 m .79856 .27264 L .80269 .25867 L p F P
0 g
s
.639 .656 .851 r
.52134 .36986 m .49385 .37803 L .4864 .36551 L p F P
0 g
s
.687 .974 .914 r
.63503 .27772 m .62782 .28532 L p .60387 .29432 L F P
0 g
s
.696 .977 .789 r
.62782 .28532 m .63503 .27772 L .63827 .27669 L closepath p F P
0 g
s
.464 .355 .646 r
.50812 .21771 m .49487 .22739 L .50827 .23509 L p F P
0 g
s
.401 .25 .559 r
.49487 .22739 m .50812 .21771 L .5071 .20438 L p F P
0 g
s
.545 .739 .966 r
.19537 .44197 m .22132 .43848 L .22982 .44568 L p F P
0 g
s
.567 .74 .958 r
.22132 .43848 m .19537 .44197 L .18672 .43529 L p F P
0 g
s
.682 .969 .765 r
.7057 .39145 m .71015 .38981 L .7201 .38141 L p F P
0 g
s
0 0 0 r
.75908 .34053 m .76151 .33738 L p .74018 .36241 L F P
0 g
s
0 0 0 r
.74018 .36241 m .7522 .3486 L .75908 .34053 L p F P
0 g
s
.639 .909 .607 r
.74018 .36241 m .7522 .3486 L p .73262 .36903 L F P
0 g
s
.639 .909 .607 r
.73262 .36903 m .73757 .36517 L .74018 .36241 L p F P
0 g
s
.702 .753 .892 r
.24214 .37817 m .24904 .37499 L .26137 .38169 L p F P
0 g
s
.68 .729 .887 r
.26887 .36598 m .24904 .37499 L .26137 .38169 L p F P
0 g
s
.68 .729 .887 r
.26137 .38169 m .27709 .37536 L .26887 .36598 L p F P
0 g
s
.554 .872 .59 r
.7201 .38141 m .73262 .36903 L .73757 .36517 L closepath p F P
0 g
s
.657 .878 .981 r
.61593 .43535 m .61356 .43416 L .58574 .44451 L p F P
0 g
s
.65 .854 .978 r
.61356 .43416 m .58574 .44451 L .57867 .43919 L p F P
0 g
s
.645 .83 .972 r
.55095 .44814 m .57867 .43919 L .58574 .44451 L p F P
0 g
s
.682 .969 .765 r
.7201 .38141 m .73262 .36903 L p .7057 .39145 L F P
0 g
s
.692 .512 .639 r
.4097 .24625 m .41573 .24603 L .41845 .26157 L p F P
0 g
s
.692 .512 .639 r
.41845 .26157 m .39826 .26231 L .4097 .24625 L p F P
0 g
s
.707 .532 .65 r
.38034 .24609 m .4097 .24625 L .39826 .26231 L p F P
0 g
s
0 0 .334 r
.81677 .19523 m .8119 .20754 L .81221 .21991 L p F P
0 g
s
.707 .532 .65 r
.39826 .26231 m .38357 .26223 L .38034 .24609 L p F P
0 g
s
.742 .555 .641 r
.37819 .24584 m .38034 .24609 L .38357 .26223 L p F P
0 g
s
.635 .754 .934 r
.54123 .30594 m .56895 .29825 L .5761 .30615 L p F P
0 g
s
.609 .646 .862 r
.56171 .28825 m .56895 .29825 L .54123 .30594 L p F P
0 g
s
.609 .646 .862 r
.55409 .2898 m .56171 .28825 L p .54123 .30594 L F P
0 g
s
.609 .646 .862 r
.54123 .30594 m .53878 .30188 L .55409 .2898 L p F P
0 g
s
.631 .471 .647 r
.41845 .26157 m .41573 .24603 L .44545 .23964 L p F P
0 g
s
.629 .445 .615 r
.44387 .22547 m .44545 .23964 L .41573 .24603 L p F P
0 g
s
.738 .677 .792 r
.34714 .364 m .35057 .36149 L .34504 .36043 L closepath p F P
0 g
s
.733 .674 .792 r
.34504 .36043 m .34714 .364 L p .31213 .36995 L F P
0 g
s
.629 .892 .57 r
.71258 .2974 m .70738 .30382 L .69226 .32126 L p F P
0 g
s
.93 .702 .572 r
.28015 .19895 m .28936 .20727 L .28684 .22008 L p F P
0 g
s
.742 .555 .641 r
.38357 .26223 m .37024 .2607 L .37819 .24584 L p F P
0 g
s
.774 .579 .635 r
.35648 .24207 m .37819 .24584 L .37024 .2607 L p F P
0 g
s
0 0 .313 r
.75133 .19877 m .74765 .20716 L .74746 .21963 L p F P
0 g
s
.648 .774 .94 r
.51611 .44937 m .5437 .44099 L .55095 .44814 L p F P
0 g
s
.648 .736 .913 r
.5437 .44099 m .51611 .44937 L .50873 .44064 L p F P
0 g
s
.738 .677 .791 r
.37182 .33852 m .37438 .34415 L .35057 .36149 L p F P
0 g
s
.738 .677 .791 r
.35573 .33665 m .37182 .33852 L p .35057 .36149 L F P
0 g
s
.738 .677 .791 r
.33933 .35064 m .35573 .33665 L p .35057 .36149 L F P
0 g
s
.738 .677 .791 r
.35057 .36149 m .34504 .36043 L .33933 .35064 L p F P
0 g
s
0 0 .014 r
.73886 .24558 m .74535 .23281 L p .73534 .25817 L F P
0 g
s
0 0 .014 r
.73534 .25817 m .7358 .25576 L .73886 .24558 L p F P
0 g
s
0 0 .199 r
.73886 .24558 m .74535 .23281 L .74746 .21963 L p F P
0 g
s
0 0 .187 r
.80513 .24609 m .80528 .24526 L .80517 .24546 L closepath p F P
0 g
s
.647 .788 .949 r
.57867 .43919 m .55095 .44814 L .5437 .44099 L p F P
0 g
s
.675 .977 .841 r
.66941 .34114 m .66059 .34779 L .65406 .34754 L p F P
0 g
s
0 0 .161 r
.80528 .24526 m .81121 .23279 L p .80441 .25543 L F P
0 g
s
0 0 .161 r
.80441 .25543 m .80513 .24609 L .80528 .24526 L p F P
0 g
s
0 0 .27 r
.80528 .24526 m .81121 .23279 L .81221 .21991 L p F P
0 g
s
.622 .749 .937 r
.23296 .38028 m .24214 .37817 L .23373 .36999 L p F P
0 g
s
.622 .749 .937 r
.23373 .36999 m .22209 .37306 L .23296 .38028 L p F P
0 g
s
.593 .759 .958 r
.20749 .37676 m .22209 .37306 L .23296 .38028 L p F P
0 g
s
.668 .886 .978 r
.62618 .36285 m .59836 .37538 L .59135 .37021 L p F P
0 g
s
0 0 0 r
.67268 .22266 m .66772 .2367 L .66299 .24499 L p F P
0 g
s
.628 .802 .371 r
.65919 .25132 m .66772 .2367 L .66299 .24499 L closepath p F P
0 g
s
.84 .731 .743 r
.28271 .25697 m .29442 .26422 L .28241 .28045 L p F P
0 g
s
.845 .705 .708 r
.29442 .26422 m .28271 .25697 L .29171 .2418 L p F P
0 g
s
0 0 .178 r
.80269 .25867 m .80441 .25543 L .80513 .24609 L closepath p F P
0 g
s
.657 .825 .964 r
.59837 .29676 m .5761 .30615 L .56895 .29825 L p F P
0 g
s
.511 .354 .605 r
.44545 .23964 m .44387 .22547 L .4627 .21603 L p F P
0 g
s
.479 .292 .548 r
.44387 .22547 m .4627 .21603 L .45642 .20606 L p F P
0 g
s
.484 .293 .546 r
.4681 .20035 m .45642 .20606 L .4627 .21603 L p F P
0 g
s
.217 .573 .941 r
.1573 .36048 m .16464 .36227 L .15588 .35466 L p F P
0 g
s
.217 .573 .941 r
.15588 .35466 m .14759 .35271 L .1573 .36048 L p F P
0 g
s
.662 .959 .747 r
.66941 .34114 m .6825 .32772 L .68813 .32538 L closepath p F P
0 g
s
.675 .977 .841 r
.6825 .32772 m .66941 .34114 L p .65406 .34754 L F P
0 g
s
.733 .674 .792 r
.31213 .36995 m .32924 .35777 L .34504 .36043 L p F P
0 g
s
.733 .675 .794 r
.34504 .36043 m .33933 .35064 L .32924 .35777 L closepath p F P
0 g
s
.641 .692 .882 r
.55255 .36697 m .55636 .37199 L .52869 .38024 L p F P
0 g
s
.641 .692 .882 r
.52869 .38024 m .52763 .37873 L .55255 .36697 L p F P
0 g
s
.646 .755 .929 r
.52869 .38024 m .55636 .37199 L .56357 .37989 L p F P
0 g
s
.655 .629 .812 r
.47992 .35288 m .4864 .36551 L p .45157 .36106 L F P
0 g
s
.655 .629 .812 r
.45157 .36106 m .46157 .35737 L .47992 .35288 L p F P
0 g
s
.648 .602 .788 r
.45157 .36106 m .46157 .35737 L .45113 .3601 L closepath p F P
0 g
s
.619 .395 .555 r
.40201 .2184 m .40176 .20563 L .43236 .20013 L p F P
0 g
s
.71 .468 .556 r
.39324 .20527 m .40176 .20563 L .40201 .2184 L p F P
0 g
s
.648 .601 .788 r
.46157 .35737 m .45113 .3601 L .44406 .34472 L p F P
0 g
s
0 .2 .671 r
.09334 .39548 m .08408 .38759 L .07211 .37934 L p F P
0 g
s
.752 .983 .747 r
.69226 .32126 m .7035 .30732 L p .6825 .32772 L F P
0 g
s
.752 .983 .747 r
.6825 .32772 m .68813 .32538 L .69226 .32126 L p F P
0 g
s
.629 .892 .57 r
.70939 .30074 m .71258 .2974 L p .69226 .32126 L F P
0 g
s
.629 .892 .57 r
.69226 .32126 m .7035 .30732 L .70939 .30074 L p F P
0 g
s
.71 .468 .556 r
.40201 .2184 m .3914 .21796 L .39324 .20527 L p F P
0 g
s
.747 .498 .554 r
.36943 .20216 m .39324 .20527 L .3914 .21796 L p F P
0 g
s
.605 .638 .857 r
.53878 .30188 m .53391 .29365 L .55409 .2898 L closepath p F P
0 g
s
.755 .688 .787 r
.32924 .35777 m .31213 .36995 L .30413 .35884 L p F P
0 g
s
.729 .709 .831 r
.27709 .37536 m .30413 .35884 L .31213 .36995 L p F P
0 g
s
.781 .76 .834 r
.25499 .30234 m .2559 .30162 L .25035 .29729 L closepath p F P
0 g
s
.693 .74 .887 r
.25035 .29729 m .25499 .30234 L p .22008 .30503 L F P
0 g
s
.791 .759 .824 r
.2817 .27995 m .28223 .28066 L .2559 .30162 L p F P
0 g
s
.791 .759 .824 r
.26945 .27365 m .2817 .27995 L p .2559 .30162 L F P
0 g
s
.791 .759 .824 r
.24667 .29323 m .26945 .27365 L p .2559 .30162 L F P
0 g
s
.791 .759 .824 r
.2559 .30162 m .25035 .29729 L .24667 .29323 L p F P
0 g
s
.648 .786 .947 r
.58294 .37316 m .56357 .37989 L .55636 .37199 L p F P
0 g
s
.635 .748 .93 r
.22982 .44568 m .25622 .4382 L .26454 .44618 L p F P
0 g
s
.652 .746 .919 r
.25622 .4382 m .22982 .44568 L .22132 .43848 L p F P
0 g
s
.636 .69 .884 r
.54908 .36239 m .55255 .36697 L .52763 .37873 L p F P
0 g
s
.636 .69 .884 r
.52763 .37873 m .52134 .36986 L .54908 .36239 L p F P
0 g
s
.193 .575 .939 r
.13001 .41739 m .14374 .42071 L .13485 .41355 L p F P
0 g
s
.193 .575 .939 r
.13485 .41355 m .11962 .41001 L .13001 .41739 L p F P
0 g
s
.045 .489 .886 r
.11021 .4069 m .11962 .41001 L .13001 .41739 L p F P
0 g
s
.693 .74 .887 r
.22008 .30503 m .24316 .2948 L .25035 .29729 L p F P
0 g
s
.703 .751 .889 r
.24316 .2948 m .22008 .30503 L .21157 .29684 L p F P
0 g
s
.615 .758 .947 r
.22209 .37306 m .20749 .37676 L .1989 .36928 L p F P
0 g
s
.68 .595 .753 r
.44064 .33617 m .44406 .34472 L p .40925 .34194 L F P
0 g
s
.68 .595 .753 r
.40925 .34194 m .41453 .33886 L .44064 .33617 L p F P
0 g
s
.68 .594 .752 r
.40925 .34194 m .41453 .33886 L .40828 .33952 L closepath p F P
0 g
s
.71 .608 .742 r
.40828 .33952 m .40925 .34194 L p .37438 .34415 L F P
0 g
s
.262 .149 .531 r
.51287 .19795 m .5071 .20438 L .50812 .21771 L p F P
0 g
s
.71 .608 .742 r
.37438 .34415 m .38091 .33915 L .40828 .33952 L p F P
0 g
s
.721 .631 .757 r
.37438 .34415 m .38091 .33915 L .37182 .33852 L closepath p F P
0 g
s
.708 .548 .669 r
.38686 .27599 m .39826 .26231 L .38357 .26223 L closepath p F P
0 g
s
.694 .549 .685 r
.39826 .26231 m .41845 .26157 L p .42063 .27806 L F P
0 g
s
.694 .549 .685 r
.38686 .27599 m .39826 .26231 L p .42063 .27806 L F P
0 g
s
.349 .679 .978 r
.15258 .42749 m .16782 .42823 L .17937 .43512 L p F P
0 g
s
.383 .685 .978 r
.16782 .42823 m .15258 .42749 L .14374 .42071 L p F P
0 g
s
.718 .554 .666 r
.38357 .26223 m .37024 .2607 L p .38441 .2792 L F P
0 g
s
.718 .554 .666 r
.38441 .2792 m .38686 .27599 L .38357 .26223 L p F P
0 g
s
.68 .592 .75 r
.41453 .33886 m .40828 .33952 L .40172 .32301 L p F P
0 g
s
.71 .607 .74 r
.40828 .33952 m .40172 .32301 L .38091 .33915 L closepath p F P
0 g
s
.697 .679 .829 r
.40142 .43388 m .40408 .43805 L p .36922 .43943 L F P
0 g
s
.697 .679 .829 r
.36922 .43943 m .3811 .43352 L .40142 .43388 L p F P
0 g
s
.701 .694 .84 r
.36922 .43943 m .3811 .43352 L .36433 .43235 L closepath p F P
0 g
s
.704 .694 .838 r
.36433 .43235 m .36922 .43943 L p .33432 .4419 L F P
0 g
s
.861 .605 .551 r
.34359 .22315 m .33019 .21641 L .33163 .20392 L p F P
0 g
s
.902 .647 .544 r
.3248 .19917 m .33163 .20392 L .33019 .21641 L p F P
0 g
s
.088 .504 .902 r
.11962 .41001 m .11021 .4069 L .10124 .39962 L p F P
0 g
s
.855 .637 .608 r
.33019 .21641 m .34359 .22315 L .34001 .23645 L p F P
0 g
s
.813 .591 .601 r
.35648 .24207 m .34001 .23645 L .34359 .22315 L p F P
0 g
s
.722 .629 .754 r
.39991 .31788 m .40172 .32301 L .38091 .33915 L p F P
0 g
s
.722 .629 .754 r
.37781 .31697 m .39991 .31788 L p .38091 .33915 L F P
0 g
s
.722 .629 .754 r
.36675 .32721 m .37781 .31697 L p .38091 .33915 L F P
0 g
s
.722 .629 .754 r
.38091 .33915 m .37182 .33852 L .36675 .32721 L p F P
0 g
s
.704 .694 .838 r
.33432 .4419 m .3546 .43154 L .36433 .43235 L p F P
0 g
s
.72 .693 .824 r
.3546 .43154 m .33432 .4419 L .32635 .4317 L p F P
0 g
s
.701 .716 .86 r
.29941 .44454 m .32635 .4317 L .33432 .4419 L p F P
0 g
s
.684 .674 .834 r
.43508 .43198 m .43892 .43813 L p .40408 .43805 L F P
0 g
s
.684 .674 .834 r
.40408 .43805 m .41516 .43313 L .43508 .43198 L p F P
0 g
s
.684 .675 .835 r
.40408 .43805 m .41516 .43313 L .40142 .43388 L closepath p F P
0 g
s
0 0 0 r
.78491 .30002 m .78527 .29949 L .78545 .2988 L closepath p F P
0 g
s
.657 .95 .952 r
.67274 .41169 m .64823 .42473 L .64152 .42233 L p F P
0 g
s
.686 .912 .973 r
.64823 .42473 m .64152 .42233 L p .61593 .43535 L F P
0 g
s
.632 .487 .667 r
.42171 .27701 m .41845 .26157 L .44791 .25485 L p F P
0 g
s
.631 .471 .647 r
.44545 .23964 m .44791 .25485 L .41845 .26157 L p F P
0 g
s
.694 .549 .685 r
.41845 .26157 m .42171 .27701 L .42063 .27806 L p F P
0 g
s
.681 .736 .892 r
.26454 .44618 m .29127 .43552 L .29941 .44454 L p F P
0 g
s
.696 .732 .878 r
.29127 .43552 m .26454 .44618 L .25622 .4382 L p F P
0 g
s
.585 .555 .787 r
.52653 .27869 m .51048 .28088 L .52404 .27277 L closepath p F P
0 g
s
.575 .51 .745 r
.5191 .26016 m .52404 .27277 L .51048 .28088 L p F P
0 g
s
.575 .51 .745 r
.50271 .26024 m .5191 .26016 L p .51048 .28088 L F P
0 g
s
.68 .592 .75 r
.44064 .33617 m .43655 .32584 L .41453 .33886 L closepath p F P
0 g
s
.68 .592 .75 r
.43289 .31514 m .43655 .32584 L .41453 .33886 L p F P
0 g
s
.68 .592 .75 r
.4103 .31708 m .43289 .31514 L p .41453 .33886 L F P
0 g
s
.68 .592 .75 r
.40172 .32301 m .4103 .31708 L p .41453 .33886 L F P
0 g
s
.774 .579 .635 r
.37024 .2607 m .35021 .25634 L .35648 .24207 L p F P
0 g
s
.814 .628 .65 r
.34001 .23645 m .35648 .24207 L .35021 .25634 L p F P
0 g
s
.714 .707 .842 r
.32635 .4317 m .29941 .44454 L .29127 .43552 L p F P
0 g
s
0 0 0 r
.67966 .20956 m .67268 .22266 L .66772 .2367 L p F P
0 g
s
0 0 .276 r
.67268 .22266 m .67966 .20956 L .67998 .19852 L p F P
0 g
s
0 0 0 r
.78527 .29949 m .78491 .30002 L .77655 .31538 L p F P
0 g
s
.671 .899 .978 r
.61356 .43416 m .62652 .42872 L .61593 .43535 L closepath p F P
0 g
s
.686 .912 .973 r
.64152 .42233 m .62652 .42872 L .61593 .43535 L p F P
0 g
s
.867 .729 .708 r
.28097 .23413 m .29171 .2418 L .28271 .25697 L p F P
0 g
s
.878 .704 .662 r
.29171 .2418 m .28097 .23413 L .28684 .22008 L p F P
0 g
s
.733 .635 .749 r
.37182 .33852 m .36675 .32721 L .35573 .33665 L closepath p F P
0 g
s
.742 .71 .821 r
.30413 .35884 m .27709 .37536 L .26887 .36598 L p F P
0 g
s
.829 .737 .762 r
.28223 .28066 m .28241 .28045 L .2817 .27995 L closepath p F P
0 g
s
.84 .731 .743 r
.27412 .26946 m .28271 .25697 L p .28241 .28045 L F P
0 g
s
.84 .731 .743 r
.28241 .28045 m .2817 .27995 L .27412 .26946 L p F P
0 g
s
.755 .688 .787 r
.30413 .35884 m .31152 .35282 L .32924 .35777 L p F P
0 g
s
.729 .666 .788 r
.33151 .33667 m .31152 .35282 L .32924 .35777 L p F P
0 g
s
.729 .666 .788 r
.32924 .35777 m .33933 .35064 L .33151 .33667 L p F P
0 g
s
.428 .702 .979 r
.17937 .43512 m .18672 .43529 L .17801 .42828 L p F P
0 g
s
.428 .702 .979 r
.17801 .42828 m .16782 .42823 L .17937 .43512 L p F P
0 g
s
0 0 .055 r
.73453 .25949 m .73534 .25817 L .7358 .25576 L closepath p F P
0 g
s
0 0 0 r
.79276 .28719 m .78527 .29949 L .78234 .30699 L p F P
0 g
s
0 0 0 r
.79856 .27264 m .79276 .28719 L .78527 .29949 L p F P
0 g
s
0 0 0 r
.77655 .31538 m .78234 .30699 L .78527 .29949 L p F P
0 g
s
.718 .554 .666 r
.37024 .2607 m .36051 .2762 L .38441 .2792 L p F P
0 g
s
.782 .621 .682 r
.35021 .25634 m .37024 .2607 L .36051 .2762 L p F P
0 g
s
.669 .68 .851 r
.43892 .43813 m .46627 .4278 L .4738 .4393 L p F P
0 g
s
.667 .667 .84 r
.46577 .42692 m .46627 .4278 L .43892 .43813 L p F P
0 g
s
.667 .667 .84 r
.43892 .43813 m .43508 .43198 L .46577 .42692 L p F P
0 g
s
.717 .758 .885 r
.24904 .37499 m .24214 .37817 L .23373 .36999 L p F P
0 g
s
.654 .626 .809 r
.47992 .35288 m .47893 .35094 L .46157 .35737 L closepath p F P
0 g
s
.648 .601 .788 r
.47143 .33394 m .47893 .35094 L .46157 .35737 L p F P
0 g
s
.648 .601 .788 r
.44406 .34472 m .47143 .33394 L p .46157 .35737 L F P
0 g
s
.783 .723 .796 r
.2817 .27995 m .27412 .26946 L .26945 .27365 L closepath p F P
0 g
s
.694 .549 .685 r
.42063 .27806 m .38778 .27945 L .38686 .27599 L p F P
0 g
s
.729 .57 .675 r
.38778 .27945 m .38686 .27599 L .38441 .2792 L closepath p F P
0 g
s
.55 .494 .746 r
.5191 .26016 m .50271 .26024 L .51617 .25145 L closepath p F P
0 g
s
.535 .437 .69 r
.51164 .23595 m .51617 .25145 L .50271 .26024 L p F P
0 g
s
.535 .437 .69 r
.50827 .23509 m .51164 .23595 L p .50271 .26024 L F P
0 g
s
.747 .498 .554 r
.3914 .21796 m .36792 .21471 L .36943 .20216 L p F P
0 g
s
.806 .554 .556 r
.36058 .1994 m .36943 .20216 L .36792 .21471 L p F P
0 g
s
.639 .656 .851 r
.4864 .36551 m .51394 .35762 L .52134 .36986 L p F P
0 g
s
.628 .614 .817 r
.50649 .34344 m .51394 .35762 L .4864 .36551 L p F P
0 g
s
.628 .614 .817 r
.49636 .34621 m .50649 .34344 L p .4864 .36551 L F P
0 g
s
.628 .614 .817 r
.4864 .36551 m .47992 .35288 L .49636 .34621 L p F P
0 g
s
.695 .56 .698 r
.38778 .27945 m .42063 .27806 L .39856 .29774 L p F P
0 g
s
.695 .56 .698 r
.39856 .29774 m .39318 .29796 L .38778 .27945 L p F P
0 g
s
.729 .579 .687 r
.38441 .2792 m .38778 .27945 L .39318 .29796 L p F P
0 g
s
.686 .579 .729 r
.40172 .32301 m .4103 .31708 L .39991 .31788 L closepath p F P
0 g
s
0 .349 .799 r
.09334 .39548 m .10124 .39962 L .09224 .39186 L p F P
0 g
s
0 .349 .799 r
.09224 .39186 m .08408 .38759 L .09334 .39548 L p F P
0 g
s
0 0 0 r
.77655 .31538 m .76597 .33148 L .76151 .33738 L p F P
0 g
s
.568 .813 .433 r
.75908 .34053 m .76597 .33148 L .76151 .33738 L closepath p F P
0 g
s
.076 .478 .892 r
.12247 .33881 m .13847 .34467 L .14759 .35271 L p F P
0 g
s
.646 .576 .762 r
.46953 .32894 m .47143 .33394 L .44406 .34472 L p F P
0 g
s
.646 .576 .762 r
.44406 .34472 m .44064 .33617 L .46953 .32894 L p F P
0 g
s
.756 .62 .708 r
.36051 .2762 m .38441 .2792 L .37018 .29626 L p F P
0 g
s
.729 .579 .687 r
.39318 .29796 m .37018 .29626 L .38441 .2792 L p F P
0 g
s
.686 .575 .724 r
.4103 .31708 m .39991 .31788 L .39424 .3014 L p F P
0 g
s
.718 .592 .714 r
.39991 .31788 m .39424 .3014 L .37781 .31697 L closepath p F P
0 g
s
.757 .651 .744 r
.35573 .33665 m .33933 .35064 L .33151 .33667 L p F P
0 g
s
.684 .676 .837 r
.41516 .43313 m .40142 .43388 L .39637 .42601 L p F P
0 g
s
.696 .681 .831 r
.40142 .43388 m .39637 .42601 L .3811 .43352 L closepath p F P
0 g
s
0 0 0 r
.73534 .25817 m .73453 .25949 L .72737 .27437 L p F P
0 g
s
.701 .695 .842 r
.38865 .41271 m .39637 .42601 L .3811 .43352 L p F P
0 g
s
.701 .695 .842 r
.36139 .42812 m .38865 .41271 L p .3811 .43352 L F P
0 g
s
.701 .695 .842 r
.3811 .43352 m .36433 .43235 L .36139 .42812 L p F P
0 g
s
.695 .566 .706 r
.39424 .3014 m .39856 .29774 L .39318 .29796 L closepath p F P
0 g
s
.737 .623 .732 r
.39318 .29796 m .39424 .3014 L .37781 .31697 L p F P
0 g
s
.737 .623 .732 r
.37018 .29626 m .39318 .29796 L p .37781 .31697 L F P
0 g
s
.727 .622 .741 r
.35423 .31391 m .33582 .33239 L .35573 .33665 L p F P
0 g
s
.727 .622 .741 r
.36164 .31504 m .35423 .31391 L p .35573 .33665 L F P
0 g
s
.727 .622 .741 r
.35573 .33665 m .36675 .32721 L .36164 .31504 L p F P
0 g
s
.757 .651 .744 r
.33151 .33667 m .33582 .33239 L .35573 .33665 L p F P
0 g
s
.686 .575 .724 r
.39424 .3014 m .39856 .29774 L p .4103 .31708 L F P
0 g
s
.604 .598 .818 r
.55409 .2898 m .53391 .29365 L .52653 .27869 L p F P
0 g
s
.463 .685 .962 r
.1773 .28986 m .19268 .28956 L .20161 .29778 L p F P
0 g
s
.529 .708 .953 r
.20161 .29778 m .21157 .29684 L .20301 .2885 L p F P
0 g
s
.529 .708 .953 r
.20301 .2885 m .19268 .28956 L .20161 .29778 L p F P
0 g
s
.686 .575 .724 r
.39856 .29774 m .42684 .29593 L p .4103 .31708 L F P
0 g
s
.688 .548 .69 r
.42684 .29593 m .39856 .29774 L .42063 .27806 L p F P
0 g
s
.534 .396 .64 r
.44791 .25485 m .44545 .23964 L .47031 .22749 L p F P
0 g
s
.511 .354 .605 r
.46912 .21819 m .47031 .22749 L .44545 .23964 L p F P
0 g
s
.511 .354 .605 r
.4627 .21603 m .46912 .21819 L p .44545 .23964 L F P
0 g
s
.686 .575 .724 r
.42684 .29593 m .42909 .30373 L .4103 .31708 L p F P
0 g
s
.683 .569 .72 r
.43289 .31514 m .42909 .30373 L .4103 .31708 L closepath p F P
0 g
s
.656 .7 .879 r
.4738 .4393 m .50129 .43039 L .50873 .44064 L p F P
0 g
s
.656 .671 .853 r
.50129 .43039 m .4738 .4393 L .46627 .4278 L p F P
0 g
s
.736 .626 .737 r
.36675 .32721 m .37781 .31697 L .36164 .31504 L closepath p F P
0 g
s
.737 .623 .732 r
.35914 .30888 m .37018 .29626 L p .37781 .31697 L F P
0 g
s
.737 .623 .732 r
.37781 .31697 m .36164 .31504 L .35914 .30888 L p F P
0 g
s
.684 .675 .836 r
.43508 .43198 m .43131 .426 L .41516 .43313 L closepath p F P
0 g
s
.684 .676 .837 r
.42368 .41235 m .43131 .426 L .41516 .43313 L p F P
0 g
s
.684 .676 .837 r
.39637 .42601 m .42368 .41235 L p .41516 .43313 L F P
0 g
s
.904 .737 .664 r
.27764 .21177 m .28684 .22008 L .28097 .23413 L p F P
0 g
s
.93 .702 .572 r
.28684 .22008 m .27764 .21177 L .28015 .19895 L p F P
0 g
s
.717 .758 .885 r
.23373 .36999 m .23808 .36778 L .24904 .37499 L p F P
0 g
s
.697 .733 .879 r
.26061 .3565 m .23808 .36778 L .24904 .37499 L p F P
0 g
s
.697 .733 .879 r
.24904 .37499 m .26887 .36598 L .26061 .3565 L p F P
0 g
s
.472 .698 .967 r
.16464 .36227 m .19027 .36153 L .1989 .36928 L p F P
0 g
s
.485 .699 .963 r
.19027 .36153 m .16464 .36227 L .15588 .35466 L p F P
0 g
s
.641 .508 .686 r
.42194 .27797 m .42171 .27701 L .44908 .26082 L p F P
0 g
s
.632 .487 .667 r
.44791 .25485 m .44908 .26082 L .42171 .27701 L p F P
0 g
s
.687 .537 .677 r
.42194 .27797 m .42171 .27701 L .42063 .27806 L closepath p F P
0 g
s
.65 .576 .759 r
.46394 .31411 m .46953 .32894 L .44064 .33617 L p F P
0 g
s
.65 .576 .759 r
.44064 .33617 m .43655 .32584 L .46394 .31411 L p F P
0 g
s
.688 .548 .69 r
.42063 .27806 m .42194 .27797 L .42684 .29593 L p F P
0 g
s
0 0 0 r
.72737 .27437 m .71745 .29019 L .71258 .2974 L p F P
0 g
s
.666 .887 .527 r
.70939 .30074 m .71745 .29019 L .71258 .2974 L closepath p F P
0 g
s
0 0 .045 r
.80441 .25543 m .80269 .25867 L .79856 .27264 L p F P
0 g
s
0 0 .231 r
.81712 .20763 m .81221 .21991 L .81121 .23279 L p F P
0 g
s
0 0 .334 r
.81221 .21991 m .81712 .20763 L .81677 .19523 L p F P
0 g
s
.641 .52 .699 r
.42684 .29593 m .42194 .27797 L .45154 .27139 L p F P
0 g
s
.641 .508 .686 r
.44908 .26082 m .45154 .27139 L .42194 .27797 L p F P
0 g
s
.694 .74 .887 r
.25035 .29729 m .24667 .29323 L .24316 .2948 L closepath p F P
0 g
s
.28 .14 .506 r
.48342 .18545 m .4681 .20035 L .46858 .21317 L p F P
0 g
s
.484 .293 .546 r
.4627 .21603 m .46858 .21317 L .4681 .20035 L p F P
0 g
s
0 0 .152 r
.7516 .21025 m .74746 .21963 L .74535 .23281 L p F P
0 g
s
0 0 .313 r
.74746 .21963 m .7516 .21025 L .75133 .19877 L p F P
0 g
s
.796 .99 .884 r
.63166 .2775 m .63994 .27075 L .63503 .27772 L closepath p F P
0 g
s
.687 .974 .914 r
.60387 .29432 m .63166 .2775 L .63503 .27772 L p F P
0 g
s
.818 .997 .774 r
.65855 .25217 m .63994 .27075 L .63503 .27772 L p F P
0 g
s
.447 .259 .531 r
.43261 .21282 m .43236 .20013 L .45627 .18675 L p F P
0 g
s
.619 .395 .555 r
.43236 .20013 m .43261 .21282 L .40201 .2184 L p F P
0 g
s
0 0 0 r
.74122 .2467 m .73534 .25817 L .73254 .26597 L p F P
0 g
s
0 0 .014 r
.74535 .23281 m .74122 .2467 L .73534 .25817 L p F P
0 g
s
0 0 0 r
.72737 .27437 m .73254 .26597 L .73534 .25817 L p F P
0 g
s
.657 .825 .964 r
.60238 .2932 m .59837 .29676 L p .56895 .29825 L F P
0 g
s
.701 .856 .956 r
.59837 .29676 m .60238 .2932 L .60387 .29432 L closepath p F P
0 g
s
.703 .696 .841 r
.36433 .43235 m .36139 .42812 L .3546 .43154 L closepath p F P
0 g
s
.676 .672 .839 r
.45871 .4147 m .46577 .42692 L .43508 .43198 L p F P
0 g
s
.676 .672 .839 r
.43508 .43198 m .43131 .426 L .45871 .4147 L p F P
0 g
s
.806 .554 .556 r
.36792 .21471 m .36109 .21259 L .36058 .1994 L p F P
0 g
s
.814 .559 .555 r
.35238 .19665 m .36058 .1994 L .36109 .21259 L p F P
0 g
s
.662 .883 .98 r
.62652 .42872 m .61356 .43416 L .6066 .42945 L p F P
0 g
s
.65 .854 .978 r
.57867 .43919 m .6066 .42945 L .61356 .43416 L p F P
0 g
s
.755 .626 .717 r
.35914 .30888 m .37018 .29626 L .35299 .2931 L closepath p F P
0 g
s
.756 .62 .708 r
.35155 .28921 m .36051 .2762 L p .37018 .29626 L F P
0 g
s
.756 .62 .708 r
.37018 .29626 m .35299 .2931 L .35155 .28921 L p F P
0 g
s
.642 .55 .735 r
.46197 .30805 m .46394 .31411 L .43655 .32584 L p F P
0 g
s
.642 .55 .735 r
.43655 .32584 m .43289 .31514 L .46197 .30805 L p F P
0 g
s
.902 .647 .544 r
.33019 .21641 m .32683 .21408 L .3248 .19917 L p F P
0 g
s
.881 .633 .559 r
.3202 .19641 m .3248 .19917 L .32683 .21408 L p F P
0 g
s
.689 .934 .966 r
.6508 .34943 m .62618 .36285 L .61931 .35891 L p F P
0 g
s
.668 .886 .978 r
.59135 .37021 m .61931 .35891 L .62618 .36285 L p F P
0 g
s
0 0 0 r
.78234 .30699 m .77655 .31538 L .76597 .33148 L p F P
0 g
s
.637 .524 .708 r
.42909 .30373 m .42684 .29593 L .456 .28888 L p F P
0 g
s
.641 .52 .699 r
.45154 .27139 m .456 .28888 L .42684 .29593 L p F P
0 g
s
.629 .432 .596 r
.40324 .23231 m .40201 .2184 L .43261 .21282 L p F P
0 g
s
.714 .495 .59 r
.3914 .21796 m .40201 .2184 L .40324 .23231 L p F P
0 g
s
.648 .736 .913 r
.50873 .44064 m .53639 .43238 L .5437 .44099 L p F P
0 g
s
.645 .701 .887 r
.53639 .43238 m .50873 .44064 L .50129 .43039 L p F P
0 g
s
.72 .693 .824 r
.32635 .4317 m .33228 .42821 L .3546 .43154 L p F P
0 g
s
.698 .679 .828 r
.35355 .41591 m .33228 .42821 L .3546 .43154 L p F P
0 g
s
.698 .679 .828 r
.3546 .43154 m .36139 .42812 L .35355 .41591 L p F P
0 g
s
.647 .549 .73 r
.45647 .29063 m .46197 .30805 L .43289 .31514 L p F P
0 g
s
.647 .549 .73 r
.43289 .31514 m .42909 .30373 L .45647 .29063 L p F P
0 g
s
.855 .737 .732 r
.28271 .25697 m .27412 .26946 L .2659 .25916 L p F P
0 g
s
.855 .737 .732 r
.2659 .25916 m .27251 .24913 L .28271 .25697 L p F P
0 g
s
.867 .729 .708 r
.28271 .25697 m .27251 .24913 L .28097 .23413 L p F P
0 g
s
.567 .74 .958 r
.18672 .43529 m .21278 .43099 L .22132 .43848 L p F P
0 g
s
.583 .741 .951 r
.21278 .43099 m .18672 .43529 L .17801 .42828 L p F P
0 g
s
0 0 .281 r
.75285 .19462 m .75133 .19877 L .7516 .21025 L p F P
0 g
s
.746 .627 .728 r
.36164 .31504 m .35914 .30888 L .35423 .31391 L closepath p F P
0 g
s
.648 .786 .947 r
.58962 .36855 m .58294 .37316 L p .55636 .37199 L F P
0 g
s
.667 .795 .943 r
.58294 .37316 m .58962 .36855 L .59135 .37021 L closepath p F P
0 g
s
.779 .63 .695 r
.35155 .28921 m .36051 .2762 L .34531 .27216 L closepath p F P
0 g
s
.782 .621 .682 r
.34401 .26824 m .35021 .25634 L p .36051 .2762 L F P
0 g
s
.782 .621 .682 r
.36051 .2762 m .34531 .27216 L .34401 .26824 L p F P
0 g
s
.635 .751 .932 r
.22209 .37306 m .23373 .36999 L .22526 .36167 L p F P
0 g
s
.635 .751 .932 r
.22526 .36167 m .2114 .36571 L .22209 .37306 L p F P
0 g
s
.615 .758 .947 r
.1989 .36928 m .2114 .36571 L .22209 .37306 L p F P
0 g
s
.637 .524 .708 r
.456 .28888 m .45647 .29063 L .42909 .30373 L p F P
0 g
s
.714 .495 .59 r
.40324 .23231 m .38688 .23163 L .3914 .21796 L p F P
0 g
s
.757 .53 .588 r
.36792 .21471 m .3914 .21796 L .38688 .23163 L p F P
0 g
s
0 0 .213 r
.68067 .19676 m .67998 .19852 L .67966 .20956 L p F P
0 g
s
.623 .667 .872 r
.54908 .36239 m .52134 .36986 L .51394 .35762 L p F P
0 g
s
.657 .95 .952 r
.67536 .40972 m .67274 .41169 L p .64152 .42233 L F P
0 g
s
.672 .964 .932 r
.67274 .41169 m .67536 .40972 L .67612 .40982 L closepath p F P
0 g
s
.764 .867 .924 r
.60238 .2932 m .60387 .29432 L .63166 .2775 L p F P
0 g
s
.357 .282 .634 r
.51587 .20913 m .50812 .21771 L .51093 .23316 L p F P
0 g
s
.262 .149 .531 r
.50812 .21771 m .51587 .20913 L .51287 .19795 L p F P
0 g
s
.464 .355 .646 r
.50827 .23509 m .51093 .23316 L .50812 .21771 L p F P
0 g
s
.809 .639 .671 r
.34401 .26824 m .35021 .25634 L .33831 .25191 L closepath p F P
0 g
s
.814 .628 .65 r
.33651 .24583 m .34001 .23645 L p .35021 .25634 L F P
0 g
s
.814 .628 .65 r
.35021 .25634 m .33831 .25191 L .33651 .24583 L p F P
0 g
s
.778 .707 .785 r
.31152 .35282 m .30413 .35884 L .29608 .34753 L p F P
0 g
s
.742 .71 .821 r
.26887 .36598 m .29608 .34753 L .30413 .35884 L p F P
0 g
s
.144 .079 .518 r
.52258 .18334 m .51287 .19795 L .51587 .20913 L p F P
0 g
s
0 0 0 r
.67961 .20975 m .67966 .20956 L p .66772 .2367 L F P
0 g
s
0 0 0 r
.66772 .2367 m .67452 .2236 L .67961 .20975 L p F P
0 g
s
.794 .915 .526 r
.66772 .2367 m .67452 .2236 L p .65894 .25161 L F P
0 g
s
.794 .915 .526 r
.65894 .25161 m .65919 .25132 L .66772 .2367 L p F P
0 g
s
.741 .619 .723 r
.35423 .31391 m .35914 .30888 L .35299 .2931 L p F P
0 g
s
.703 .751 .889 r
.21157 .29684 m .23106 .28769 L .24316 .2948 L p F P
0 g
s
.695 .746 .891 r
.23829 .28427 m .23106 .28769 L .24316 .2948 L p F P
0 g
s
.695 .746 .891 r
.24316 .2948 m .24667 .29323 L .23829 .28427 L p F P
0 g
s
.616 .956 .827 r
.67612 .40982 m .704 .39178 L .7057 .39145 L p F P
0 g
s
.73 .977 .92 r
.67536 .40972 m .67612 .40982 L .704 .39178 L p F P
0 g
s
.628 .614 .817 r
.47992 .35288 m .47893 .35094 L .49636 .34621 L closepath p F P
0 g
s
.647 .788 .949 r
.5437 .44099 m .57152 .43245 L .57867 .43919 L p F P
0 g
s
.643 .749 .925 r
.57152 .43245 m .5437 .44099 L .53639 .43238 L p F P
0 g
s
.778 .707 .785 r
.29608 .34753 m .29687 .3468 L .31152 .35282 L p F P
0 g
s
.745 .669 .776 r
.31809 .32736 m .29687 .3468 L .31152 .35282 L p F P
0 g
s
.745 .669 .776 r
.32779 .32987 m .31809 .32736 L p .31152 .35282 L F P
0 g
s
.745 .669 .776 r
.31152 .35282 m .33151 .33667 L .32779 .32987 L p F P
0 g
s
.847 .654 .641 r
.33651 .24583 m .34001 .23645 L .33193 .23231 L closepath p F P
0 g
s
.855 .637 .608 r
.32911 .22091 m .33019 .21641 L p .34001 .23645 L F P
0 g
s
.855 .637 .608 r
.34001 .23645 m .33193 .23231 L .32911 .22091 L p F P
0 g
s
.65 .812 .961 r
.6066 .42945 m .57867 .43919 L .57152 .43245 L p F P
0 g
s
.238 .574 .941 r
.14759 .35271 m .15588 .35466 L .14708 .34666 L p F P
0 g
s
.238 .574 .941 r
.14708 .34666 m .13847 .34467 L .14759 .35271 L p F P
0 g
s
.773 .676 .757 r
.33465 .30947 m .35423 .31391 L .33582 .33239 L p F P
0 g
s
.741 .619 .723 r
.34906 .29232 m .33465 .30947 L .35423 .31391 L p F P
0 g
s
.741 .619 .723 r
.35299 .2931 m .34906 .29232 L p .35423 .31391 L F P
0 g
s
.692 .981 .827 r
.704 .39178 m .70969 .38748 L .7057 .39145 L closepath p F P
0 g
s
.682 .969 .765 r
.73173 .36949 m .70969 .38748 L .7057 .39145 L p F P
0 g
s
.682 .969 .765 r
.73262 .36903 m .73173 .36949 L p .7057 .39145 L F P
0 g
s
.696 .636 .785 r
.42368 .41235 m .39637 .42601 L .38865 .41271 L p F P
0 g
s
.715 .652 .786 r
.38865 .41271 m .36139 .42812 L .35355 .41591 L p F P
0 g
s
.657 .825 .964 r
.56895 .29825 m .59686 .28861 L .60238 .2932 L p F P
0 g
s
.627 .758 .941 r
.59686 .28861 m .56895 .29825 L .56171 .28825 L p F P
0 g
s
0 0 .022 r
.80883 .24617 m .80441 .25543 L .80291 .2645 L p F P
0 g
s
0 0 .161 r
.81121 .23279 m .80883 .24617 L .80441 .25543 L p F P
0 g
s
0 0 .045 r
.79856 .27264 m .80291 .2645 L .80441 .25543 L p F P
0 g
s
.623 .582 .787 r
.49636 .34621 m .47893 .35094 L .47143 .33394 L p F P
0 g
s
.892 .672 .597 r
.32911 .22091 m .33019 .21641 L .32683 .21408 L closepath p F P
0 g
s
.794 .747 .809 r
.26945 .27365 m .24667 .29323 L .23829 .28427 L p F P
0 g
s
.623 .817 .404 r
.73254 .26597 m .72737 .27437 L .71745 .29019 L p F P
0 g
s
0 0 .213 r
.67966 .20956 m .6797 .20945 L .68067 .19676 L p F P
0 g
s
0 0 .156 r
.68456 .18443 m .68067 .19676 L .6797 .20945 L p F P
0 g
s
.814 .559 .555 r
.36109 .21259 m .35089 .20919 L .35238 .19665 L p F P
0 g
s
.867 .61 .548 r
.33919 .18972 m .35238 .19665 L .35089 .20919 L p F P
0 g
s
.552 .426 .662 r
.44908 .26082 m .44791 .25485 L .47315 .24312 L p F P
0 g
s
.534 .396 .64 r
.47031 .22749 m .47315 .24312 L .44791 .25485 L p F P
0 g
s
.514 .352 .599 r
.46912 .21819 m .4627 .21603 L .46858 .21317 L closepath p F P
0 g
s
.218 .579 .943 r
.11962 .41001 m .13485 .41355 L .12593 .40602 L p F P
0 g
s
.218 .579 .943 r
.12593 .40602 m .10978 .40238 L .11962 .41001 L p F P
0 g
s
.088 .504 .902 r
.10124 .39962 m .10978 .40238 L .11962 .41001 L p F P
0 g
s
.773 .676 .757 r
.32367 .32226 m .33465 .30947 L p .33582 .33239 L F P
0 g
s
.773 .676 .757 r
.33582 .33239 m .32779 .32987 L .32367 .32226 L p F P
0 g
s
.772 .678 .76 r
.33151 .33667 m .33582 .33239 L .32779 .32987 L closepath p F P
0 g
s
.726 .712 .837 r
.32635 .4317 m .33228 .42821 L .32194 .42573 L closepath p F P
0 g
s
.714 .707 .842 r
.32194 .42573 m .32635 .4317 L p .29127 .43552 L F P
0 g
s
.881 .633 .559 r
.32683 .21408 m .31837 .20904 L .3202 .19641 L p F P
0 g
s
.93 .685 .547 r
.31069 .18815 m .3202 .19641 L .31837 .20904 L p F P
0 g
s
.674 .632 .8 r
.45871 .4147 m .43131 .426 L .42368 .41235 L p F P
0 g
s
.713 .964 .941 r
.66958 .40844 m .69031 .39633 L .67536 .40972 L closepath p F P
0 g
s
.73 .977 .92 r
.69767 .39181 m .69031 .39633 L .67536 .40972 L p F P
0 g
s
.73 .977 .92 r
.704 .39178 m .69767 .39181 L p .67536 .40972 L F P
0 g
s
.657 .95 .952 r
.64152 .42233 m .66958 .40844 L .67536 .40972 L p F P
0 g
s
.499 .418 .695 r
.51164 .23595 m .50827 .23509 L .51093 .23316 L closepath p F P
0 g
s
.604 .598 .818 r
.52653 .27869 m .55439 .27591 L p .55409 .2898 L F P
0 g
s
.54 .53 .793 r
.547 .26142 m .55439 .27591 L .52653 .27869 L p F P
0 g
s
.54 .53 .793 r
.53688 .26128 m .547 .26142 L p .52653 .27869 L F P
0 g
s
.54 .53 .793 r
.52653 .27869 m .52404 .27277 L .53688 .26128 L p F P
0 g
s
.714 .84 .942 r
.59686 .28861 m .61057 .28214 L .60238 .2932 L closepath p F P
0 g
s
.764 .867 .924 r
.62486 .27485 m .61057 .28214 L .60238 .2932 L p F P
0 g
s
.764 .867 .924 r
.63166 .2775 m .62486 .27485 L p .60238 .2932 L F P
0 g
s
.648 .786 .947 r
.55636 .37199 m .58425 .36331 L .58962 .36855 L p F P
0 g
s
.636 .709 .9 r
.57705 .35485 m .58425 .36331 L .55636 .37199 L p F P
0 g
s
.636 .709 .9 r
.5646 .35821 m .57705 .35485 L p .55636 .37199 L F P
0 g
s
.636 .709 .9 r
.55636 .37199 m .55255 .36697 L .5646 .35821 L p F P
0 g
s
.761 .622 .706 r
.35299 .2931 m .35155 .28921 L .34906 .29232 L closepath p F P
0 g
s
.69 .802 .934 r
.58962 .36855 m .59135 .37021 L .61931 .35891 L p F P
0 g
s
.794 .747 .809 r
.23829 .28427 m .25852 .26609 L .26945 .27365 L p F P
0 g
s
.791 .741 .806 r
.2659 .25916 m .25852 .26609 L .26945 .27365 L p F P
0 g
s
.791 .741 .806 r
.26945 .27365 m .27412 .26946 L .2659 .25916 L p F P
0 g
s
.652 .746 .919 r
.22132 .43848 m .24785 .42991 L .25622 .4382 L p F P
0 g
s
.666 .747 .911 r
.24785 .42991 m .22132 .43848 L .21278 .43099 L p F P
0 g
s
.707 .76 .893 r
.23106 .28769 m .21157 .29684 L .20301 .2885 L p F P
0 g
s
.678 .896 .975 r
.62652 .42872 m .63856 .42072 L .64152 .42233 L closepath p F P
0 g
s
.662 .883 .98 r
.63856 .42072 m .62652 .42872 L p .6066 .42945 L F P
0 g
s
.759 .62 .705 r
.34906 .29232 m .35155 .28921 L .34531 .27216 L p F P
0 g
s
0 0 0 r
.78046 .31023 m .78234 .30699 L p .76597 .33148 L F P
0 g
s
0 0 0 r
.76597 .33148 m .77512 .31836 L .78046 .31023 L p F P
0 g
s
.66 .881 .519 r
.76597 .33148 m .77512 .31836 L p .75677 .34298 L F P
0 g
s
.66 .881 .519 r
.75677 .34298 m .75908 .34053 L .76597 .33148 L p F P
0 g
s
.632 .757 .938 r
.2114 .36571 m .1989 .36928 L .19027 .36153 L p F P
0 g
s
.73 .712 .833 r
.31236 .42409 m .29127 .43552 L .28309 .42611 L p F P
0 g
s
.696 .732 .878 r
.25622 .4382 m .28309 .42611 L .29127 .43552 L p F P
0 g
s
.714 .707 .842 r
.29127 .43552 m .31236 .42409 L .32194 .42573 L p F P
0 g
s
.561 .45 .684 r
.45154 .27139 m .44908 .26082 L .4765 .25867 L p F P
0 g
s
.552 .426 .662 r
.47315 .24312 m .4765 .25867 L .44908 .26082 L p F P
0 g
s
.885 .753 .711 r
.27186 .2258 m .28097 .23413 L .27251 .24913 L p F P
0 g
s
.904 .737 .664 r
.28097 .23413 m .27186 .2258 L .27764 .21177 L p F P
0 g
s
.804 .579 .597 r
.36109 .21259 m .36792 .21471 L .36446 .22801 L p F P
0 g
s
.757 .53 .588 r
.38688 .23163 m .36446 .22801 L .36792 .21471 L p F P
0 g
s
.446 .704 .976 r
.16782 .42823 m .17801 .42828 L .16925 .42097 L p F P
0 g
s
.446 .704 .976 r
.16925 .42097 m .15678 .42111 L .16782 .42823 L p F P
0 g
s
.383 .685 .978 r
.14374 .42071 m .15678 .42111 L .16782 .42823 L p F P
0 g
s
.725 .713 .839 r
.3457 .40287 m .35355 .41591 L .33228 .42821 L p F P
0 g
s
.725 .713 .839 r
.31835 .4209 m .3457 .40287 L p .33228 .42821 L F P
0 g
s
.725 .713 .839 r
.33228 .42821 m .32194 .42573 L .31835 .4209 L p F P
0 g
s
.797 .665 .717 r
.33081 .28738 m .34906 .29232 L .33465 .30947 L p F P
0 g
s
.759 .62 .705 r
.34204 .27132 m .33081 .28738 L .34906 .29232 L p F P
0 g
s
.759 .62 .705 r
.34531 .27216 m .34204 .27132 L p .34906 .29232 L F P
0 g
s
0 0 .306 r
.81779 .19224 m .81677 .19523 L .81712 .20763 L p F P
0 g
s
.754 .711 .812 r
.29608 .34753 m .26887 .36598 L .26061 .3565 L p F P
0 g
s
.527 .509 .779 r
.52404 .27277 m .5191 .26016 L .53688 .26128 L closepath p F P
0 g
s
0 0 0 r
.80291 .2645 m .79856 .27264 L .79276 .28719 L p F P
0 g
s
.41 .687 .976 r
.15678 .42111 m .14374 .42071 L .13485 .41355 L p F P
0 g
s
.709 .731 .868 r
.28309 .42611 m .25622 .4382 L .24785 .42991 L p F P
0 g
s
.835 .626 .621 r
.33193 .23231 m .32911 .22091 L .32625 .22983 L closepath p F P
0 g
s
.864 .66 .626 r
.32625 .22983 m .32911 .22091 L .32683 .21408 L p F P
0 g
s
.123 .513 .911 r
.10978 .40238 m .10124 .39962 L .09224 .39186 L p F P
0 g
s
.864 .66 .626 r
.32683 .21408 m .31837 .20904 L p .32625 .22983 L F P
0 g
s
0 0 .281 r
.7516 .21025 m .75276 .2071 L .75285 .19462 L p F P
0 g
s
0 0 .246 r
.7566 .18245 m .75285 .19462 L .75276 .2071 L p F P
0 g
s
.779 .62 .683 r
.34531 .27216 m .34401 .26824 L .34204 .27132 L closepath p F P
0 g
s
.784 .627 .686 r
.34204 .27132 m .34401 .26824 L .33831 .25191 L p F P
0 g
s
.476 .403 .695 r
.51093 .23316 m .52418 .21859 L p .52648 .24131 L F P
0 g
s
.476 .403 .695 r
.52648 .24131 m .51164 .23595 L .51093 .23316 L p F P
0 g
s
.357 .282 .634 r
.51093 .23316 m .52418 .21859 L .51587 .20913 L p F P
0 g
s
.676 .953 .705 r
.73173 .36949 m .7344 .36698 L .73262 .36903 L closepath p F P
0 g
s
.639 .909 .607 r
.7522 .3486 m .7344 .36698 L .73262 .36903 L p F P
0 g
s
.656 .671 .853 r
.4945 .41962 m .50129 .43039 L p .46627 .4278 L F P
0 g
s
.656 .671 .853 r
.46627 .4278 m .48006 .42317 L .4945 .41962 L p F P
0 g
s
.651 .644 .83 r
.46627 .4278 m .48006 .42317 L .46577 .42692 L closepath p F P
0 g
s
.583 .849 .503 r
.7522 .3486 m .75677 .34298 L .75908 .34053 L closepath p F P
0 g
s
.689 .934 .966 r
.65317 .3473 m .6508 .34943 L p .61931 .35891 L F P
0 g
s
.719 .959 .946 r
.6508 .34943 m .65317 .3473 L .65406 .34754 L closepath p F P
0 g
s
.636 .863 .494 r
.65855 .25217 m .65894 .25161 L .65919 .25132 L closepath p F P
0 g
s
.729 .762 .879 r
.23808 .36778 m .23373 .36999 L .22526 .36167 L p F P
0 g
s
0 0 0 r
.75083 .22044 m .74535 .23281 L .74122 .2467 L p F P
0 g
s
0 0 .152 r
.74535 .23281 m .75083 .22044 L .7516 .21025 L p F P
0 g
s
.461 .416 .722 r
.51617 .25145 m .51164 .23595 L .52648 .24131 L closepath p F P
0 g
s
0 0 .112 r
.81617 .22052 m .81121 .23279 L .80883 .24617 L p F P
0 g
s
0 0 .231 r
.81121 .23279 m .81617 .22052 L .81712 .20763 L p F P
0 g
s
.759 .672 .765 r
.32779 .32987 m .32367 .32226 L .31809 .32736 L closepath p F P
0 g
s
.802 .998 .852 r
.65894 .25161 m .65855 .25217 L .63994 .27075 L p F P
0 g
s
.817 .64 .663 r
.33423 .25056 m .33651 .24583 L .33193 .23231 L p F P
0 g
s
.803 .622 .657 r
.33831 .25191 m .33651 .24583 L .33423 .25056 L closepath p F P
0 g
s
.652 .647 .832 r
.48006 .42317 m .46577 .42692 L .45871 .4147 L p F P
0 g
s
.417 .282 .589 r
.46858 .21317 m .48532 .19698 L p .47391 .22443 L F P
0 g
s
.417 .282 .589 r
.47391 .22443 m .46912 .21819 L .46858 .21317 L p F P
0 g
s
.28 .14 .506 r
.46858 .21317 m .48532 .19698 L .48342 .18545 L p F P
0 g
s
.668 .792 .941 r
.58425 .36331 m .6066 .3554 L .58962 .36855 L closepath p F P
0 g
s
.69 .802 .934 r
.61233 .35335 m .6066 .3554 L .58962 .36855 L p F P
0 g
s
.69 .802 .934 r
.61931 .35891 m .61233 .35335 L p .58962 .36855 L F P
0 g
s
.727 .989 .876 r
.70969 .38748 m .704 .39178 L .69767 .39181 L p F P
0 g
s
.568 .465 .697 r
.456 .28888 m .45154 .27139 L .47674 .25964 L p F P
0 g
s
.561 .45 .684 r
.4765 .25867 m .47674 .25964 L .45154 .27139 L p F P
0 g
s
.784 .627 .686 r
.33831 .25191 m .33423 .25056 L p .34204 .27132 L F P
0 g
s
.814 .665 .698 r
.32563 .26569 m .34204 .27132 L .33081 .28738 L p F P
0 g
s
.784 .627 .686 r
.33423 .25056 m .32563 .26569 L .34204 .27132 L p F P
0 g
s
.793 .963 .917 r
.63994 .27075 m .63166 .2775 L .62486 .27485 L p F P
0 g
s
.609 .549 .762 r
.49559 .31832 m .49901 .32694 L .47143 .33394 L p F P
0 g
s
.609 .549 .762 r
.47143 .33394 m .46953 .32894 L .49559 .31832 L p F P
0 g
s
.623 .582 .787 r
.47143 .33394 m .49901 .32694 L p .49636 .34621 L F P
0 g
s
.817 .64 .663 r
.33193 .23231 m .32625 .22983 L p .33423 .25056 L F P
0 g
s
.632 .453 .622 r
.40324 .23231 m .43367 .22648 L p .41697 .24482 L F P
0 g
s
.632 .453 .622 r
.41697 .24482 m .4052 .24709 L .40324 .23231 L p F P
0 g
s
.629 .432 .596 r
.43261 .21282 m .43367 .22648 L .40324 .23231 L p F P
0 g
s
.716 .513 .613 r
.38688 .23163 m .40324 .23231 L .4052 .24709 L p F P
0 g
s
.675 .977 .841 r
.65406 .34754 m .68188 .32782 L .6825 .32772 L p F P
0 g
s
.781 .966 .921 r
.65317 .3473 m .65406 .34754 L .68188 .32782 L p F P
0 g
s
.533 .484 .748 r
.53688 .26128 m .5191 .26016 L .51617 .25145 L p F P
0 g
s
.478 .312 .578 r
.43367 .22648 m .43261 .21282 L .45668 .19957 L p F P
0 g
s
.447 .259 .531 r
.45627 .18675 m .45668 .19957 L .43261 .21282 L p F P
0 g
s
.841 .994 .746 r
.65274 .25386 m .66499 .23925 L .65894 .25161 L closepath p F P
0 g
s
.794 .915 .526 r
.67452 .2236 m .66499 .23925 L .65894 .25161 L p F P
0 g
s
.802 .998 .852 r
.65274 .25386 m .65894 .25161 L p .63994 .27075 L F P
0 g
s
.727 .989 .876 r
.69767 .39181 m .72335 .37321 L .70969 .38748 L p F P
0 g
s
.682 .971 .78 r
.72568 .37139 m .72335 .37321 L .70969 .38748 L p F P
0 g
s
.682 .971 .78 r
.70969 .38748 m .73173 .36949 L .72568 .37139 L p F P
0 g
s
.678 .943 .668 r
.75677 .34298 m .7522 .3486 L .7344 .36698 L p F P
0 g
s
.804 .579 .597 r
.36446 .22801 m .36325 .22764 L .36109 .21259 L p F P
0 g
s
.811 .584 .594 r
.35089 .20919 m .36109 .21259 L .36325 .22764 L p F P
0 g
s
.533 .484 .748 r
.51617 .25145 m .52648 .24131 L p .53688 .26128 L F P
0 g
s
.768 .951 .626 r
.71745 .29019 m .72554 .27706 L p .70723 .30238 L F P
0 g
s
.768 .951 .626 r
.70723 .30238 m .70939 .30074 L .71745 .29019 L p F P
0 g
s
.623 .817 .404 r
.73052 .26925 m .73254 .26597 L p .71745 .29019 L F P
0 g
s
.623 .817 .404 r
.71745 .29019 m .72554 .27706 L .73052 .26925 L p F P
0 g
s
.793 .963 .917 r
.62486 .27485 m .64925 .25696 L .63994 .27075 L p F P
0 g
s
.802 .998 .852 r
.63994 .27075 m .64925 .25696 L .65274 .25386 L p F P
0 g
s
.604 .544 .76 r
.4915 .30789 m .49559 .31832 L .46953 .32894 L p F P
0 g
s
.604 .544 .76 r
.46953 .32894 m .46394 .31411 L .4915 .30789 L p F P
0 g
s
.729 .762 .879 r
.22526 .36167 m .22782 .36026 L .23808 .36778 L p F P
0 g
s
.711 .739 .874 r
.25228 .34706 m .22782 .36026 L .23808 .36778 L p F P
0 g
s
.711 .739 .874 r
.23808 .36778 m .26061 .3565 L .25228 .34706 L p F P
0 g
s
.797 .665 .717 r
.33465 .30947 m .31891 .3037 L .33081 .28738 L p F P
0 g
s
.796 .667 .722 r
.33465 .30947 m .32367 .32226 L .3158 .30782 L p F P
0 g
s
.796 .667 .722 r
.3158 .30782 m .31891 .3037 L .33465 .30947 L p F P
0 g
s
.716 .513 .613 r
.4052 .24709 m .38034 .24606 L .38688 .23163 L p F P
0 g
s
.758 .562 .632 r
.36446 .22801 m .38688 .23163 L .38034 .24606 L p F P
0 g
s
.61 .648 .864 r
.56171 .28825 m .55409 .2898 L .55984 .28517 L closepath p F P
0 g
s
.604 .598 .818 r
.55439 .27591 m .55984 .28517 L .55409 .2898 L p F P
0 g
s
.713 .71 .846 r
.32194 .42573 m .31835 .4209 L .31236 .42409 L closepath p F P
0 g
s
.837 .673 .68 r
.31994 .24413 m .33423 .25056 L .32563 .26569 L p F P
0 g
s
.817 .64 .663 r
.32625 .22983 m .31994 .24413 L .33423 .25056 L p F P
0 g
s
0 0 .289 r
.82061 .18315 m .81779 .19224 L .8184 .20389 L p F P
0 g
s
0 0 .306 r
.81712 .20763 m .8184 .20389 L .81779 .19224 L p F P
0 g
s
.623 .667 .872 r
.51394 .35762 m .54172 .35105 L .54908 .36239 L p F P
0 g
s
.607 .63 .848 r
.54172 .35105 m .51394 .35762 L .50649 .34344 L p F P
0 g
s
.729 .983 .773 r
.7344 .36698 m .73173 .36949 L .72568 .37139 L p F P
0 g
s
.729 .983 .773 r
.72568 .37139 m .74548 .3534 L .7344 .36698 L p F P
0 g
s
.678 .943 .668 r
.7534 .34539 m .75677 .34298 L p .7344 .36698 L F P
0 g
s
.678 .943 .668 r
.7344 .36698 m .74548 .3534 L .7534 .34539 L p F P
0 g
s
.636 .709 .9 r
.55255 .36697 m .54908 .36239 L .5646 .35821 L closepath p F P
0 g
s
.714 .904 .963 r
.63856 .42072 m .64152 .42233 L .66958 .40844 L p F P
0 g
s
.392 .276 .6 r
.47031 .22749 m .46912 .21819 L .47391 .22443 L closepath p F P
0 g
s
.75 .945 .945 r
.64737 .34509 m .66412 .33488 L .65317 .3473 L closepath p F P
0 g
s
.689 .934 .966 r
.61931 .35891 m .64737 .34509 L .65317 .3473 L p F P
0 g
s
.781 .966 .921 r
.67542 .32746 m .66412 .33488 L .65317 .3473 L p F P
0 g
s
.781 .966 .921 r
.68188 .32782 m .67542 .32746 L p .65317 .3473 L F P
0 g
s
.7 .647 .793 r
.38865 .41271 m .40683 .40231 L .38322 .40243 L closepath p F P
0 g
s
.715 .652 .786 r
.38322 .40243 m .38865 .41271 L p .35355 .41591 L F P
0 g
s
.696 .636 .785 r
.41851 .40198 m .42368 .41235 L p .38865 .41271 L F P
0 g
s
.696 .636 .785 r
.38865 .41271 m .40683 .40231 L .41851 .40198 L p F P
0 g
s
.58 .481 .706 r
.45647 .29063 m .456 .28888 L .48172 .27774 L p F P
0 g
s
.568 .465 .697 r
.47674 .25964 m .48172 .27774 L .456 .28888 L p F P
0 g
s
.645 .701 .887 r
.50129 .43039 m .52901 .42229 L .53639 .43238 L p F P
0 g
s
.639 .663 .857 r
.52158 .41064 m .52901 .42229 L .50129 .43039 L p F P
0 g
s
.639 .663 .857 r
.50762 .41462 m .52158 .41064 L p .50129 .43039 L F P
0 g
s
.639 .663 .857 r
.50129 .43039 m .4945 .41962 L .50762 .41462 L p F P
0 g
s
.485 .699 .963 r
.15588 .35466 m .18158 .35357 L .19027 .36153 L p F P
0 g
s
.49 .697 .961 r
.15588 .35466 m .18158 .35357 L .17445 .34692 L p F P
0 g
s
.49 .697 .961 r
.14708 .34666 m .15588 .35466 L p .17445 .34692 L F P
0 g
s
.752 .983 .747 r
.7035 .30732 m .68359 .32636 L .6825 .32772 L p F P
0 g
s
.759 .995 .831 r
.68188 .32782 m .68359 .32636 L .6825 .32772 L closepath p F P
0 g
s
.58 .481 .706 r
.48172 .27774 m .48399 .2856 L .45647 .29063 L p F P
0 g
s
.588 .507 .73 r
.46197 .30805 m .45647 .29063 L .48399 .2856 L p F P
0 g
s
.595 .515 .734 r
.48782 .2971 m .4915 .30789 L .46394 .31411 L p F P
0 g
s
.595 .515 .734 r
.46394 .31411 m .46197 .30805 L .48782 .2971 L p F P
0 g
s
.588 .507 .73 r
.48399 .2856 m .48782 .2971 L .46197 .30805 L p F P
0 g
s
.68 .927 .62 r
.7035 .30732 m .70723 .30238 L .70939 .30074 L closepath p F P
0 g
s
.785 .721 .793 r
.29608 .34753 m .29687 .3468 L .29486 .34583 L closepath p F P
0 g
s
.786 .721 .791 r
.30218 .32167 m .31809 .32736 L .29687 .3468 L p F P
0 g
s
.786 .721 .791 r
.28799 .33614 m .30218 .32167 L p .29687 .3468 L F P
0 g
s
.786 .721 .791 r
.29687 .3468 m .29486 .34583 L .28799 .33614 L p F P
0 g
s
.754 .711 .812 r
.29486 .34583 m .29608 .34753 L p .26061 .3565 L F P
0 g
s
.76 .674 .766 r
.3158 .30782 m .30218 .32167 L .31809 .32736 L p F P
0 g
s
.76 .674 .766 r
.31809 .32736 m .32367 .32226 L .3158 .30782 L p F P
0 g
s
.715 .652 .786 r
.35355 .41591 m .37504 .40193 L .38322 .40243 L p F P
0 g
s
.729 .651 .772 r
.37504 .40193 m .35355 .41591 L .3457 .40287 L p F P
0 g
s
.868 .69 .658 r
.31427 .22253 m .32625 .22983 L .31994 .24413 L p F P
0 g
s
.864 .66 .626 r
.31837 .20904 m .31427 .22253 L .32625 .22983 L p F P
0 g
s
.674 .632 .8 r
.42368 .41235 m .45113 .39983 L .45871 .4147 L p F P
0 g
s
.674 .626 .794 r
.45021 .39776 m .45113 .39983 L .42368 .41235 L p F P
0 g
s
.674 .626 .794 r
.42368 .41235 m .41851 .40198 L .45021 .39776 L p F P
0 g
s
0 0 .117 r
.75276 .2071 m .7516 .21025 L .75083 .22044 L p F P
0 g
s
.87 .759 .737 r
.27251 .24913 m .2659 .25916 L .25756 .24999 L p F P
0 g
s
.87 .759 .737 r
.25756 .24999 m .26355 .24078 L .27251 .24913 L p F P
0 g
s
.885 .753 .711 r
.27251 .24913 m .26355 .24078 L .27186 .2258 L p F P
0 g
s
.71 .701 .84 r
.31032 .40965 m .29402 .41942 L .31236 .42409 L p F P
0 g
s
.71 .701 .84 r
.31236 .42409 m .31835 .4209 L .31032 .40965 L p F P
0 g
s
.73 .712 .833 r
.28309 .42611 m .29402 .41942 L .31236 .42409 L p F P
0 g
s
.644 .753 .928 r
.2114 .36571 m .22526 .36167 L .21673 .35327 L p F P
0 g
s
.644 .753 .928 r
.21673 .35327 m .20031 .35842 L .2114 .36571 L p F P
0 g
s
.632 .757 .938 r
.19027 .36153 m .20031 .35842 L .2114 .36571 L p F P
0 g
s
.771 .996 .81 r
.70723 .30238 m .7035 .30732 L .68359 .32636 L p F P
0 g
s
.624 .59 .795 r
.50649 .34344 m .49636 .34621 L .50605 .34247 L closepath p F P
0 g
s
.623 .582 .787 r
.49901 .32694 m .50605 .34247 L .49636 .34621 L p F P
0 g
s
.707 .76 .893 r
.20301 .2885 m .22155 .27961 L .23106 .28769 L p F P
0 g
s
.705 .758 .893 r
.22981 .27562 m .22155 .27961 L .23106 .28769 L p F P
0 g
s
.705 .758 .893 r
.23106 .28769 m .23829 .28427 L .22981 .27562 L p F P
0 g
s
0 0 0 r
.78046 .31023 m .78515 .30237 L .78234 .30699 L closepath p F P
0 g
s
0 0 0 r
.78234 .30699 m .78515 .30237 L .79276 .28719 L p F P
0 g
s
.786 .993 .878 r
.68359 .32636 m .68188 .32782 L .67542 .32746 L p F P
0 g
s
.754 .711 .812 r
.26061 .3565 m .28135 .34102 L .29486 .34583 L p F P
0 g
s
.753 .713 .814 r
.29486 .34583 m .28799 .33614 L .28135 .34102 L closepath p F P
0 g
s
.771 .996 .81 r
.70328 .30391 m .70723 .30238 L p .68359 .32636 L F P
0 g
s
.771 .996 .81 r
.68359 .32636 m .69361 .31275 L .70328 .30391 L p F P
0 g
s
.786 .993 .878 r
.67542 .32746 m .69361 .31275 L .68359 .32636 L p F P
0 g
s
.817 .694 .729 r
.31605 .28121 m .33081 .28738 L .31891 .3037 L p F P
0 g
s
.814 .665 .698 r
.33081 .28738 m .31605 .28121 L .32563 .26569 L p F P
0 g
s
0 0 0 r
.67961 .20975 m .6797 .20945 L .67966 .20956 L closepath p F P
0 g
s
0 0 0 r
.67452 .2236 m .6772 .21795 L .67961 .20975 L closepath p F P
0 g
s
.69 .722 .205 r
.6772 .21795 m .67961 .20975 L .6797 .20945 L p F P
0 g
s
.69 .722 .205 r
.6797 .20945 m .68356 .19717 L p .6772 .21795 L F P
0 g
s
0 0 .156 r
.6797 .20945 m .68356 .19717 L .68456 .18443 L p F P
0 g
s
0 0 0 r
.79956 .27458 m .79276 .28719 L .78515 .30237 L p F P
0 g
s
0 0 0 r
.80132 .27013 m .80291 .2645 L p .79276 .28719 L F P
0 g
s
0 0 0 r
.79276 .28719 m .79956 .27458 L .80132 .27013 L p F P
0 g
s
.811 .584 .594 r
.36325 .22764 m .34759 .22243 L .35089 .20919 L p F P
0 g
s
.866 .639 .592 r
.33777 .20224 m .35089 .20919 L .34759 .22243 L p F P
0 g
s
.867 .61 .548 r
.35089 .20919 m .33777 .20224 L .33919 .18972 L p F P
0 g
s
.929 .674 .531 r
.32946 .18151 m .33919 .18972 L .33777 .20224 L p F P
0 g
s
.656 .672 .853 r
.4945 .41962 m .49381 .41855 L .48006 .42317 L closepath p F P
0 g
s
.652 .647 .832 r
.48629 .40504 m .49381 .41855 L .48006 .42317 L p F P
0 g
s
.652 .647 .832 r
.45871 .4147 m .48629 .40504 L p .48006 .42317 L F P
0 g
s
.296 .269 .658 r
.52468 .19515 m .51587 .20913 L .52418 .21859 L p F P
0 g
s
.144 .079 .518 r
.52447 .19314 m .52258 .18334 L p .51587 .20913 L F P
0 g
s
.144 .079 .518 r
.51587 .20913 m .52468 .19515 L .52447 .19314 L p F P
0 g
s
.583 .741 .951 r
.17801 .42828 m .20418 .42326 L .21278 .43099 L p F P
0 g
s
.595 .742 .946 r
.20418 .42326 m .17801 .42828 L .16925 .42097 L p F P
0 g
s
.915 .716 .62 r
.30886 .20078 m .31837 .20904 L .31427 .22253 L p F P
0 g
s
.93 .685 .547 r
.31837 .20904 m .30886 .20078 L .31069 .18815 L p F P
0 g
s
.627 .758 .941 r
.56171 .28825 m .58974 .28085 L .59686 .28861 L p F P
0 g
s
.597 .643 .866 r
.58252 .27135 m .58974 .28085 L .56171 .28825 L p F P
0 g
s
.597 .643 .866 r
.57195 .27314 m .58252 .27135 L p .56171 .28825 L F P
0 g
s
.597 .643 .866 r
.56171 .28825 m .55984 .28517 L .57195 .27314 L p F P
0 g
s
.643 .749 .925 r
.53639 .43238 m .56428 .42431 L .57152 .43245 L p F P
0 g
s
.636 .712 .902 r
.56428 .42431 m .53639 .43238 L .52901 .42229 L p F P
0 g
s
.738 .672 .786 r
.3457 .40287 m .31835 .4209 L .31032 .40965 L p F P
0 g
s
.758 .562 .632 r
.36375 .23 m .36446 .22801 L p .38034 .24606 L F P
0 g
s
.801 .595 .624 r
.36375 .23 m .36446 .22801 L .36325 .22764 L closepath p F P
0 g
s
.662 .883 .98 r
.6066 .42945 m .6347 .41847 L .63856 .42072 L p F P
0 g
s
.66 .845 .971 r
.6347 .41847 m .6066 .42945 L .59955 .42339 L p F P
0 g
s
.65 .812 .961 r
.57152 .43245 m .59955 .42339 L .6066 .42945 L p F P
0 g
s
.791 .589 .628 r
.36325 .22764 m .34759 .22243 L p .35907 .24204 L F P
0 g
s
.791 .589 .628 r
.35907 .24204 m .36375 .23 L .36325 .22764 L p F P
0 g
s
.636 .469 .639 r
.40628 .2538 m .41697 .24482 L .4052 .24709 L closepath p F P
0 g
s
.69 .505 .632 r
.4052 .24709 m .38034 .24606 L p .40021 .26278 L F P
0 g
s
.69 .505 .632 r
.40021 .26278 m .40628 .2538 L .4052 .24709 L p F P
0 g
s
.427 .332 .645 r
.47391 .22443 m .47031 .22749 L .47315 .24312 L p F P
0 g
s
.652 .617 .802 r
.48629 .40504 m .45871 .4147 L .45113 .39983 L p F P
0 g
s
.805 .767 .818 r
.25852 .26609 m .23829 .28427 L .22981 .27562 L p F P
0 g
s
.808 .764 .812 r
.25852 .26609 m .2659 .25916 L .25756 .24999 L p F P
0 g
s
.643 .772 .941 r
.59955 .42339 m .57152 .43245 L .56428 .42431 L p F P
0 g
s
0 0 0 r
.73254 .26597 m .7349 .26137 L .74122 .2467 L p F P
0 g
s
0 0 0 r
.74684 .23415 m .74122 .2467 L .7349 .26137 L p F P
0 g
s
0 0 0 r
.75075 .22083 m .75083 .22044 L p .74122 .2467 L F P
0 g
s
0 0 0 r
.74122 .2467 m .74684 .23415 L .75075 .22083 L p F P
0 g
s
.635 .672 .869 r
.5646 .35821 m .54908 .36239 L .54172 .35105 L p F P
0 g
s
.7 .648 .795 r
.40683 .40231 m .38322 .40243 L .38093 .39815 L p F P
0 g
s
.714 .654 .788 r
.38322 .40243 m .38093 .39815 L .37504 .40193 L closepath p F P
0 g
s
.758 .562 .632 r
.38034 .24606 m .36636 .24375 L .36375 .23 L p F P
0 g
s
.78 .577 .625 r
.36636 .24375 m .36375 .23 L .35907 .24204 L closepath p F P
0 g
s
.237 .58 .944 r
.10978 .40238 m .12593 .40602 L .11696 .39814 L p F P
0 g
s
.237 .58 .944 r
.11696 .39814 m .10049 .39449 L .10978 .40238 L p F P
0 g
s
.123 .513 .911 r
.09224 .39186 m .10049 .39449 L .10978 .40238 L p F P
0 g
s
.805 .767 .818 r
.22981 .27562 m .24929 .25786 L .25852 .26609 L p F P
0 g
s
.808 .764 .812 r
.25756 .24999 m .24929 .25786 L .25852 .26609 L p F P
0 g
s
0 0 .19 r
.8184 .20389 m .81712 .20763 L .81617 .22052 L p F P
0 g
s
.675 .845 .965 r
.61057 .28214 m .59686 .28861 L .58974 .28085 L p F P
0 g
s
.7 .648 .795 r
.40842 .3801 m .41605 .39708 L .40683 .40231 L p F P
0 g
s
.7 .648 .795 r
.38093 .39815 m .40842 .3801 L p .40683 .40231 L F P
0 g
s
.696 .638 .787 r
.41851 .40198 m .41605 .39708 L .40683 .40231 L closepath p F P
0 g
s
.672 .825 .392 r
.73052 .26925 m .7349 .26137 L .73254 .26597 L closepath p F P
0 g
s
.686 .89 .972 r
.64737 .34509 m .61931 .35891 L .61233 .35335 L p F P
0 g
s
.844 .695 .698 r
.3123 .25895 m .32563 .26569 L .31605 .28121 L p F P
0 g
s
.837 .673 .68 r
.32563 .26569 m .3123 .25895 L .31994 .24413 L p F P
0 g
s
.592 .634 .862 r
.55984 .28517 m .55439 .27591 L .57195 .27314 L closepath p F P
0 g
s
.684 .633 .792 r
.44355 .38304 m .45021 .39776 L .41851 .40198 L p F P
0 g
s
.684 .633 .792 r
.41851 .40198 m .41605 .39708 L .44355 .38304 L p F P
0 g
s
0 0 .022 r
.80291 .2645 m .80502 .26009 L .80883 .24617 L p F P
0 g
s
0 0 0 r
.81389 .23391 m .80883 .24617 L .80502 .26009 L p F P
0 g
s
0 0 .112 r
.80883 .24617 m .81389 .23391 L .81617 .22052 L p F P
0 g
s
.729 .651 .772 r
.3457 .40287 m .35056 .39921 L .37504 .40193 L p F P
0 g
s
.707 .636 .776 r
.37321 .38237 m .35056 .39921 L .37504 .40193 L p F P
0 g
s
.707 .636 .776 r
.37504 .40193 m .38093 .39815 L .37321 .38237 L p F P
0 g
s
.69 .505 .632 r
.38034 .24606 m .37236 .26103 L .40021 .26278 L p F P
0 g
s
.757 .574 .649 r
.36636 .24375 m .38034 .24606 L .37236 .26103 L p F P
0 g
s
0 0 .117 r
.75083 .22044 m .75091 .22023 L .75276 .2071 L p F P
0 g
s
0 0 .071 r
.75653 .19495 m .75276 .2071 L .75091 .22023 L p F P
0 g
s
0 0 .246 r
.75276 .2071 m .75653 .19495 L .7566 .18245 L p F P
0 g
s
.515 .36 .609 r
.43367 .22648 m .45805 .21355 L p .45063 .23339 L F P
0 g
s
.515 .36 .609 r
.45063 .23339 m .43393 .22865 L .43367 .22648 L p F P
0 g
s
.478 .312 .578 r
.45668 .19957 m .45805 .21355 L .43367 .22648 L p F P
0 g
s
.632 .453 .622 r
.43367 .22648 m .43393 .22865 L .41697 .24482 L p F P
0 g
s
.749 .726 .831 r
.29402 .41942 m .28309 .42611 L .27486 .41643 L p F P
0 g
s
.709 .731 .868 r
.24785 .42991 m .27486 .41643 L .28309 .42611 L p F P
0 g
s
.46 .703 .973 r
.15678 .42111 m .16925 .42097 L .16044 .41341 L p F P
0 g
s
.46 .703 .973 r
.16044 .41341 m .14627 .41374 L .15678 .42111 L p F P
0 g
s
.41 .687 .976 r
.13485 .41355 m .14627 .41374 L .15678 .42111 L p F P
0 g
s
.771 .728 .813 r
.28135 .34102 m .26061 .3565 L .25228 .34706 L p F P
0 g
s
.708 .94 .633 r
.7534 .34539 m .76219 .33528 L .75677 .34298 L closepath p F P
0 g
s
.66 .881 .519 r
.77512 .31836 m .76219 .33528 L .75677 .34298 L p F P
0 g
s
.694 .891 .969 r
.6347 .41847 m .65012 .41154 L .63856 .42072 L closepath p F P
0 g
s
.714 .904 .963 r
.66292 .40564 m .65012 .41154 L .63856 .42072 L p F P
0 g
s
.714 .904 .963 r
.66958 .40844 m .66292 .40564 L p .63856 .42072 L F P
0 g
s
.666 .747 .911 r
.21278 .43099 m .23943 .42141 L .24785 .42991 L p F P
0 g
s
.677 .748 .905 r
.23943 .42141 m .21278 .43099 L .20418 .42326 L p F P
0 g
s
.647 .486 .651 r
.40795 .26277 m .40628 .2538 L .41697 .24482 L p F P
0 g
s
.704 .524 .642 r
.40795 .26277 m .40628 .2538 L .40021 .26278 L closepath p F P
0 g
s
.607 .63 .848 r
.50649 .34344 m .53431 .33798 L .54172 .35105 L p F P
0 g
s
.594 .574 .801 r
.52989 .32912 m .53431 .33798 L .50649 .34344 L p F P
0 g
s
.594 .574 .801 r
.50649 .34344 m .50605 .34247 L .52989 .32912 L p F P
0 g
s
.814 .697 .735 r
.3158 .30782 m .31891 .3037 L .31133 .3 L closepath p F P
0 g
s
.817 .694 .729 r
.30787 .29377 m .31605 .28121 L p .31891 .3037 L F P
0 g
s
.817 .694 .729 r
.31891 .3037 m .31133 .3 L .30787 .29377 L p F P
0 g
s
.71 .609 .742 r
.40842 .3801 m .38093 .39815 L .37321 .38237 L p F P
0 g
s
.511 .369 .624 r
.4357 .24127 m .43393 .22865 L .45063 .23339 L closepath p F P
0 g
s
.634 .455 .624 r
.4357 .24127 m .43393 .22865 L .41697 .24482 L closepath p F P
0 g
s
.206 .082 .481 r
.4604 .18198 m .45627 .18675 L .45668 .19957 L p F P
0 g
s
.645 .782 .947 r
.6066 .3554 m .58425 .36331 L .57705 .35485 L p F P
0 g
s
.587 .57 .802 r
.52685 .32303 m .52989 .32912 L .50605 .34247 L p F P
0 g
s
.587 .57 .802 r
.50605 .34247 m .49901 .32694 L .52685 .32303 L p F P
0 g
s
0 0 0 r
.80132 .27013 m .80502 .26009 L .80291 .2645 L closepath p F P
0 g
s
.643 .756 .931 r
.20031 .35842 m .19027 .36153 L .18158 .35357 L p F P
0 g
s
.721 .731 .859 r
.27486 .41643 m .24785 .42991 L .23943 .42141 L p F P
0 g
s
.647 .486 .651 r
.41697 .24482 m .4357 .24127 L p .40795 .26277 L F P
0 g
s
.68 .593 .752 r
.44355 .38304 m .41605 .39708 L .40842 .3801 L p F P
0 g
s
.779 .687 .762 r
.30218 .32167 m .3158 .30782 L .31133 .3 L p F P
0 g
s
.429 .687 .972 r
.14627 .41374 m .13485 .41355 L .12593 .40602 L p F P
0 g
s
.64 .665 .859 r
.4945 .41962 m .49381 .41855 L .50762 .41462 L closepath p F P
0 g
s
.868 .709 .682 r
.30839 .2367 m .31994 .24413 L .3123 .25895 L p F P
0 g
s
.868 .69 .658 r
.31994 .24413 m .30839 .2367 L .31427 .22253 L p F P
0 g
s
.724 .701 .828 r
.30225 .39809 m .27891 .41367 L .29402 .41942 L p F P
0 g
s
.724 .701 .828 r
.29402 .41942 m .31032 .40965 L .30225 .39809 L p F P
0 g
s
.749 .726 .831 r
.27486 .41643 m .27891 .41367 L .29402 .41942 L p F P
0 g
s
.18 .075 .49 r
.48699 .18085 m .48342 .18545 L .48532 .19698 L p F P
0 g
s
.427 .332 .645 r
.47315 .24312 m .48525 .2329 L .47391 .22443 L p F P
0 g
s
.408 .334 .662 r
.48982 .20871 m .47391 .22443 L .48525 .2329 L p F P
0 g
s
.417 .282 .589 r
.48916 .20435 m .48982 .20871 L .47391 .22443 L p F P
0 g
s
.417 .282 .589 r
.48532 .19698 m .48916 .20435 L p .47391 .22443 L F P
0 g
s
.794 .99 .744 r
.70328 .30391 m .71235 .29401 L .70723 .30238 L closepath p F P
0 g
s
.768 .951 .626 r
.72554 .27706 m .71235 .29401 L .70723 .30238 L p F P
0 g
s
0 0 0 r
.78515 .30237 m .79211 .28976 L .79956 .27458 L p F P
0 g
s
.673 .84 .422 r
.78515 .30237 m .79211 .28976 L p .77838 .31328 L F P
0 g
s
.673 .84 .422 r
.77838 .31328 m .78046 .31023 L .78515 .30237 L p F P
0 g
s
.738 .766 .876 r
.22782 .36026 m .22526 .36167 L .21673 .35327 L p F P
0 g
s
.696 .956 .95 r
.69031 .39633 m .66958 .40844 L .66292 .40564 L p F P
0 g
s
.757 .574 .649 r
.37236 .26103 m .3702 .26068 L .36636 .24375 L p F P
0 g
s
.779 .587 .64 r
.35907 .24204 m .36636 .24375 L .3702 .26068 L p F P
0 g
s
.779 .687 .762 r
.3047 .29736 m .28879 .31508 L .30218 .32167 L p F P
0 g
s
.779 .687 .762 r
.31133 .3 m .3047 .29736 L p .30218 .32167 L F P
0 g
s
.802 .709 .763 r
.30218 .32167 m .28799 .33614 L .27983 .32503 L p F P
0 g
s
.802 .709 .763 r
.27983 .32503 m .28879 .31508 L .30218 .32167 L p F P
0 g
s
.739 .673 .786 r
.3457 .40287 m .35056 .39921 L .3428 .39779 L closepath p F P
0 g
s
.738 .672 .786 r
.3428 .39779 m .3457 .40287 L p .31032 .40965 L F P
0 g
s
.636 .634 .832 r
.50762 .41462 m .49381 .41855 L .48629 .40504 L p F P
0 g
s
.771 .728 .813 r
.25228 .34706 m .26789 .33449 L .28135 .34102 L p F P
0 g
s
.756 .719 .818 r
.27983 .32503 m .26789 .33449 L .28135 .34102 L p F P
0 g
s
.756 .719 .818 r
.28135 .34102 m .28799 .33614 L .27983 .32503 L p F P
0 g
s
.704 .532 .652 r
.40021 .26278 m .40795 .26277 L .4113 .27915 L p F P
0 g
s
.704 .532 .652 r
.4113 .27915 m .38812 .2792 L .40021 .26278 L p F P
0 g
s
.728 .565 .669 r
.37236 .26103 m .40021 .26278 L .38812 .2792 L p F P
0 g
s
.738 .766 .876 r
.21673 .35327 m .21808 .35249 L .22782 .36026 L p F P
0 g
s
.723 .747 .871 r
.24387 .3378 m .21808 .35249 L .22782 .36026 L p F P
0 g
s
.723 .747 .871 r
.22782 .36026 m .25228 .34706 L .24387 .3378 L p F P
0 g
s
.634 .486 .663 r
.40795 .26277 m .4383 .25676 L p .43925 .27316 L F P
0 g
s
.634 .486 .663 r
.43925 .27316 m .4113 .27915 L .40795 .26277 L p F P
0 g
s
.647 .486 .651 r
.4357 .24127 m .4383 .25676 L .40795 .26277 L p F P
0 g
s
.739 .674 .788 r
.3705 .37639 m .37321 .38237 L .35056 .39921 L p F P
0 g
s
.739 .674 .788 r
.35483 .37453 m .3705 .37639 L p .35056 .39921 L F P
0 g
s
.739 .674 .788 r
.33783 .38915 m .35483 .37453 L p .35056 .39921 L F P
0 g
s
.739 .674 .788 r
.35056 .39921 m .3428 .39779 L .33783 .38915 L p F P
0 g
s
.675 .845 .965 r
.61996 .27147 m .61057 .28214 L p .58974 .28085 L F P
0 g
s
.727 .879 .952 r
.61057 .28214 m .61996 .27147 L .62486 .27485 L closepath p F P
0 g
s
.495 .397 .672 r
.47315 .24312 m .48525 .2329 L p .47758 .259 L F P
0 g
s
.495 .397 .672 r
.47758 .259 m .4765 .25867 L .47315 .24312 L p F P
0 g
s
.799 .941 .585 r
.6772 .21795 m .67452 .2236 L .66499 .23925 L p F P
0 g
s
0 0 .107 r
.68777 .17222 m .68456 .18443 L .68356 .19717 L p F P
0 g
s
0 0 .172 r
.82099 .19556 m .8184 .20389 L .81824 .21454 L p F P
0 g
s
0 0 .289 r
.8184 .20389 m .82099 .19556 L .82061 .18315 L p F P
0 g
s
0 0 .19 r
.81617 .22052 m .81824 .21454 L .8184 .20389 L p F P
0 g
s
.84 .699 .707 r
.31605 .28121 m .30787 .29377 L .29985 .28062 L p F P
0 g
s
.84 .699 .707 r
.29985 .28062 m .30374 .27413 L .31605 .28121 L p F P
0 g
s
.844 .695 .698 r
.31605 .28121 m .30374 .27413 L .3123 .25895 L p F P
0 g
s
.652 .617 .802 r
.47914 .39046 m .48629 .40504 L p .45113 .39983 L F P
0 g
s
.652 .617 .802 r
.45113 .39983 m .47156 .3923 L .47914 .39046 L p F P
0 g
s
.646 .595 .783 r
.45113 .39983 m .47156 .3923 L .45021 .39776 L closepath p F P
0 g
s
.902 .733 .662 r
.30482 .21426 m .31427 .22253 L .30839 .2367 L p F P
0 g
s
.915 .716 .62 r
.31427 .22253 m .30482 .21426 L .30886 .20078 L p F P
0 g
s
.779 .587 .64 r
.3702 .26068 m .3525 .25652 L .35907 .24204 L p F P
0 g
s
.825 .631 .641 r
.34292 .23621 m .35907 .24204 L .3525 .25652 L p F P
0 g
s
.791 .589 .628 r
.34759 .22243 m .34292 .23621 L .35907 .24204 L p F P
0 g
s
.611 .815 .406 r
.77512 .31836 m .77838 .31328 L .78046 .31023 L closepath p F P
0 g
s
.867 .661 .622 r
.33475 .21539 m .34759 .22243 L .34292 .23621 L p F P
0 g
s
.866 .639 .592 r
.34759 .22243 m .33475 .21539 L .33777 .20224 L p F P
0 g
s
0 0 .46 r
.52447 .19314 m .52258 .18334 L .5234 .18152 L closepath p F P
0 g
s
0 0 0 r
.7349 .26137 m .74055 .24885 L .74684 .23415 L p F P
0 g
s
.767 .889 .479 r
.7349 .26137 m .74055 .24885 L p .72832 .27209 L F P
0 g
s
.767 .889 .479 r
.72832 .27209 m .73052 .26925 L .7349 .26137 L p F P
0 g
s
.536 .545 .811 r
.547 .26142 m .53688 .26128 L .54372 .25416 L closepath p F P
0 g
s
.533 .484 .748 r
.53955 .24429 m .54372 .25416 L .53688 .26128 L p F P
0 g
s
.533 .484 .748 r
.52648 .24131 m .53955 .24429 L p .53688 .26128 L F P
0 g
s
.738 .672 .786 r
.31032 .40965 m .32932 .39542 L .3428 .39779 L p F P
0 g
s
.737 .674 .789 r
.3428 .39779 m .33783 .38915 L .32932 .39542 L closepath p F P
0 g
s
0 0 .252 r
.82354 .17125 m .82061 .18315 L .82099 .19556 L p F P
0 g
s
.646 .597 .785 r
.47156 .3923 m .45021 .39776 L .44355 .38304 L p F P
0 g
s
.593 .601 .829 r
.57195 .27314 m .55439 .27591 L .547 .26142 L p F P
0 g
s
.728 .565 .669 r
.3709 .2635 m .37236 .26103 L p .38812 .2792 L F P
0 g
s
.756 .581 .659 r
.3709 .2635 m .37236 .26103 L .3702 .26068 L closepath p F P
0 g
s
.791 .687 .749 r
.31133 .3 m .30787 .29377 L .3047 .29736 L closepath p F P
0 g
s
.565 .532 .777 r
.51935 .30609 m .52685 .32303 L .49901 .32694 L p F P
0 g
s
.565 .532 .777 r
.51393 .30647 m .51935 .30609 L p .49901 .32694 L F P
0 g
s
.565 .532 .777 r
.49901 .32694 m .49559 .31832 L .51393 .30647 L p F P
0 g
s
.65 .754 .926 r
.20031 .35842 m .21673 .35327 L .20813 .34488 L p F P
0 g
s
.65 .754 .926 r
.20813 .34488 m .18679 .35187 L .20031 .35842 L p F P
0 g
s
.643 .756 .931 r
.18158 .35357 m .18679 .35187 L .20031 .35842 L p F P
0 g
s
.474 .472 .775 r
.53955 .24429 m .52648 .24131 L .53459 .23122 L closepath p F P
0 g
s
.476 .403 .695 r
.53205 .22361 m .53459 .23122 L .52648 .24131 L p F P
0 g
s
.476 .403 .695 r
.52418 .21859 m .53205 .22361 L p .52648 .24131 L F P
0 g
s
.49 .697 .961 r
.17445 .34692 m .17279 .34541 L .14708 .34666 L p F P
0 g
s
.521 .391 .643 r
.4383 .25676 m .4357 .24127 L .45063 .23339 L p F P
0 g
s
.92 .699 .587 r
.32805 .19403 m .33777 .20224 L .33475 .21539 L p F P
0 g
s
.929 .674 .531 r
.33777 .20224 m .32805 .19403 L .32946 .18151 L p F P
0 g
s
.757 .581 .659 r
.3702 .26068 m .3525 .25652 L p .36338 .27638 L F P
0 g
s
.757 .581 .659 r
.36338 .27638 m .3709 .2635 L .3702 .26068 L p F P
0 g
s
.68 .593 .752 r
.43998 .37407 m .44355 .38304 L p .40842 .3801 L F P
0 g
s
.68 .593 .752 r
.40842 .3801 m .4142 .37672 L .43998 .37407 L p F P
0 g
s
.68 .594 .752 r
.40842 .3801 m .4142 .37672 L .40734 .37742 L closepath p F P
0 g
s
.71 .609 .742 r
.40734 .37742 m .40842 .3801 L p .37321 .38237 L F P
0 g
s
.636 .703 .894 r
.57705 .35485 m .5646 .35821 L .57473 .35166 L closepath p F P
0 g
s
.635 .672 .869 r
.56978 .34485 m .57473 .35166 L .5646 .35821 L p F P
0 g
s
.635 .672 .869 r
.54172 .35105 m .56978 .34485 L p .5646 .35821 L F P
0 g
s
0 0 .2 r
.75948 .17045 m .7566 .18245 L .75653 .19495 L p F P
0 g
s
.757 .684 .781 r
.32932 .39542 m .31032 .40965 L .30225 .39809 L p F P
0 g
s
.71 .609 .742 r
.37321 .38237 m .38017 .37703 L .40734 .37742 L p F P
0 g
s
.721 .631 .757 r
.37321 .38237 m .38017 .37703 L .3705 .37639 L closepath p F P
0 g
s
.728 .565 .669 r
.38812 .2792 m .37463 .27826 L .3709 .2635 L p F P
0 g
s
.758 .583 .659 r
.37463 .27826 m .3709 .2635 L .36338 .27638 L closepath p F P
0 g
s
.68 .595 .753 r
.4142 .37672 m .40734 .37742 L .40081 .36126 L p F P
0 g
s
.71 .609 .743 r
.40734 .37742 m .40081 .36126 L .38017 .37703 L closepath p F P
0 g
s
0 0 0 r
.80502 .26009 m .81018 .24783 L p .80056 .27253 L F P
0 g
s
0 0 0 r
.80056 .27253 m .80132 .27013 L .80502 .26009 L p F P
0 g
s
0 0 0 r
.80502 .26009 m .81018 .24783 L .81389 .23391 L p F P
0 g
s
.206 .082 .481 r
.45668 .19957 m .46183 .19365 L .4604 .18198 L p F P
0 g
s
.021 0 .421 r
.4691 .16742 m .4604 .18198 L .46183 .19365 L p F P
0 g
s
.636 .712 .902 r
.52901 .42229 m .55697 .41479 L .56428 .42431 L p F P
0 g
s
.626 .677 .879 r
.55697 .41479 m .52901 .42229 L .52158 .41064 L p F P
0 g
s
.721 .631 .758 r
.39868 .35539 m .40081 .36126 L .38017 .37703 L p F P
0 g
s
.721 .631 .758 r
.37761 .35451 m .39868 .35539 L p .38017 .37703 L F P
0 g
s
.721 .631 .758 r
.3655 .36542 m .37761 .35451 L p .38017 .37703 L F P
0 g
s
.721 .631 .758 r
.38017 .37703 m .3705 .37639 L .3655 .36542 L p F P
0 g
s
.703 .915 .57 r
.77838 .31328 m .77512 .31836 L .76219 .33528 L p F P
0 g
s
.486 .41 .695 r
.47674 .25964 m .4765 .25867 L .47758 .259 L closepath p F P
0 g
s
.564 .529 .775 r
.49559 .31832 m .4915 .30789 L .51393 .30647 L closepath p F P
0 g
s
.708 .564 .69 r
.38812 .2792 m .4113 .27915 L p .40651 .29652 L F P
0 g
s
.708 .564 .69 r
.37826 .29184 m .38812 .2792 L p .40651 .29652 L F P
0 g
s
.728 .57 .676 r
.37826 .29184 m .38812 .2792 L .37463 .27826 L closepath p F P
0 g
s
.696 .956 .95 r
.69557 .39142 m .69031 .39633 L p .66292 .40564 L F P
0 g
s
.718 .972 .93 r
.69031 .39633 m .69557 .39142 L .69767 .39181 L closepath p F P
0 g
s
.499 .431 .711 r
.47758 .259 m .47674 .25964 L .48172 .27774 L p F P
0 g
s
.636 .493 .671 r
.41351 .28927 m .43925 .27316 L .4113 .27915 L closepath p F P
0 g
s
.708 .564 .69 r
.4113 .27915 m .41351 .28927 L .40651 .29652 L p F P
0 g
s
.162 .085 .514 r
.5234 .18152 m .52854 .16987 L p .52488 .19479 L F P
0 g
s
.162 .085 .514 r
.52488 .19479 m .52447 .19314 L .5234 .18152 L p F P
0 g
s
0 0 .055 r
.81824 .21454 m .81617 .22052 L .81389 .23391 L p F P
0 g
s
.68 .594 .752 r
.43998 .37407 m .43597 .36407 L .4142 .37672 L closepath p F P
0 g
s
.68 .595 .753 r
.43197 .35268 m .43597 .36407 L .4142 .37672 L p F P
0 g
s
.68 .595 .753 r
.41082 .35448 m .43197 .35268 L p .4142 .37672 L F P
0 g
s
.68 .595 .753 r
.40081 .36126 m .41082 .35448 L p .4142 .37672 L F P
0 g
s
0 0 0 r
.75075 .22083 m .75091 .22023 L .75083 .22044 L closepath p F P
0 g
s
.724 .942 .955 r
.66412 .33488 m .64737 .34509 L .64055 .341 L p F P
0 g
s
.686 .89 .972 r
.61233 .35335 m .64055 .341 L .64737 .34509 L p F P
0 g
s
.804 .889 .905 r
.61996 .27147 m .62486 .27485 L .64925 .25696 L p F P
0 g
s
.595 .654 .878 r
.56978 .34485 m .54172 .35105 L .53431 .33798 L p F P
0 g
s
0 0 0 r
.75091 .22023 m .75471 .2081 L p .74881 .22907 L F P
0 g
s
0 0 0 r
.74881 .22907 m .75075 .22083 L .75091 .22023 L p F P
0 g
s
0 0 .071 r
.75091 .22023 m .75471 .2081 L .75653 .19495 L p F P
0 g
s
.689 .865 .465 r
.72554 .27706 m .72832 .27209 L .73052 .26925 L closepath p F P
0 g
s
.734 .638 .751 r
.3705 .37639 m .3655 .36542 L .35483 .37453 L closepath p F P
0 g
s
0 0 0 r
.74684 .23415 m .74881 .22907 L .75075 .22083 L closepath p F P
0 g
s
.499 .431 .711 r
.48172 .27774 m .49986 .26402 L .47758 .259 L p F P
0 g
s
.494 .438 .723 r
.49764 .24253 m .47758 .259 L .49986 .26402 L p F P
0 g
s
.495 .397 .672 r
.4967 .23902 m .49764 .24253 L .47758 .259 L p F P
0 g
s
.495 .397 .672 r
.48525 .2329 m .4967 .23902 L p .47758 .259 L F P
0 g
s
0 0 .426 r
.49196 .17103 m .48699 .18085 L .4877 .19394 L p F P
0 g
s
.18 .075 .49 r
.48532 .19698 m .4877 .19394 L .48699 .18085 L p F P
0 g
s
.869 .724 .699 r
.30125 .25135 m .3123 .25895 L .30374 .27413 L p F P
0 g
s
.868 .709 .682 r
.3123 .25895 m .30125 .25135 L .30839 .2367 L p F P
0 g
s
.678 .882 .974 r
.65012 .41154 m .6347 .41847 L .62777 .41329 L p F P
0 g
s
.66 .845 .971 r
.59955 .42339 m .62777 .41329 L .6347 .41847 L p F P
0 g
s
.894 .983 .804 r
.66499 .23925 m .67095 .22636 L p .65125 .25386 L F P
0 g
s
.894 .983 .804 r
.65125 .25386 m .65274 .25386 L .66499 .23925 L p F P
0 g
s
.799 .941 .585 r
.67374 .22212 m .6772 .21795 L p .66499 .23925 L F P
0 g
s
.799 .941 .585 r
.66499 .23925 m .67095 .22636 L .67374 .22212 L p F P
0 g
s
.735 .574 .674 r
.37463 .27826 m .36338 .27638 L p .37528 .29589 L F P
0 g
s
.735 .574 .674 r
.37528 .29589 m .37826 .29184 L .37463 .27826 L p F P
0 g
s
.801 .703 .757 r
.3047 .29736 m .30787 .29377 L .29985 .28062 L p F P
0 g
s
.757 .684 .781 r
.30225 .39809 m .31112 .39061 L .32932 .39542 L p F P
0 g
s
.734 .667 .784 r
.32994 .37494 m .31112 .39061 L .32932 .39542 L p F P
0 g
s
.734 .667 .784 r
.32932 .39542 m .33783 .38915 L .32994 .37494 L p F P
0 g
s
.595 .742 .946 r
.16925 .42097 m .19552 .41536 L .20418 .42326 L p F P
0 g
s
.603 .743 .943 r
.19552 .41536 m .16925 .42097 L .16044 .41341 L p F P
0 g
s
.774 .98 .911 r
.69557 .39142 m .69767 .39181 L .72335 .37321 L p F P
0 g
s
.564 .505 .747 r
.51393 .30647 m .4915 .30789 L .48782 .2971 L p F P
0 g
s
.636 .638 .834 r
.52158 .41064 m .50762 .41462 L .52108 .40976 L closepath p F P
0 g
s
.636 .634 .832 r
.5141 .39739 m .52108 .40976 L .50762 .41462 L p F P
0 g
s
.636 .634 .832 r
.48629 .40504 m .5141 .39739 L p .50762 .41462 L F P
0 g
s
.822 .73 .763 r
.29164 .29056 m .3047 .29736 L .28879 .31508 L p F P
0 g
s
.801 .703 .757 r
.29985 .28062 m .29164 .29056 L .3047 .29736 L p F P
0 g
s
.538 .463 .719 r
.48172 .27774 m .49986 .26402 L p .50304 .28653 L F P
0 g
s
.538 .463 .719 r
.50304 .28653 m .48399 .2856 L .48172 .27774 L p F P
0 g
s
.272 .172 .553 r
.46183 .19365 m .45668 .19957 L .45805 .21355 L p F P
0 g
s
.686 .582 .733 r
.40081 .36126 m .41082 .35448 L .39868 .35539 L closepath p F P
0 g
s
.535 .483 .745 r
.48782 .2971 m .48399 .2856 L .50304 .28653 L closepath p F P
0 g
s
.564 .505 .747 r
.48782 .2971 m .50304 .28653 L p .51393 .30647 L F P
0 g
s
.646 .597 .785 r
.44355 .38304 m .47118 .37224 L p .47156 .3923 L F P
0 g
s
.645 .575 .761 r
.46915 .36691 m .47118 .37224 L .44355 .38304 L p F P
0 g
s
.645 .575 .761 r
.44355 .38304 m .43998 .37407 L .46915 .36691 L p F P
0 g
s
.646 .513 .687 r
.41525 .2962 m .41351 .28927 L .43925 .27316 L p F P
0 g
s
.695 .543 .677 r
.41525 .2962 m .41351 .28927 L .40651 .29652 L closepath p F P
0 g
s
.754 .74 .84 r
.27486 .41643 m .27891 .41367 L .26822 .40854 L closepath p F P
0 g
s
.721 .731 .859 r
.26822 .40854 m .27486 .41643 L p .23943 .42141 L F P
0 g
s
.756 .651 .745 r
.35483 .37453 m .33783 .38915 L .32994 .37494 L p F P
0 g
s
.643 .772 .941 r
.56428 .42431 m .59241 .41602 L .59955 .42339 L p F P
0 g
s
.633 .734 .921 r
.59241 .41602 m .56428 .42431 L .55697 .41479 L p F P
0 g
s
.645 .782 .947 r
.61087 .3519 m .6066 .3554 L p .57705 .35485 L F P
0 g
s
.67 .793 .941 r
.6066 .3554 m .61087 .3519 L .61233 .35335 L closepath p F P
0 g
s
.686 .582 .733 r
.41082 .35448 m .39868 .35539 L .39323 .3404 L p F P
0 g
s
.718 .599 .722 r
.39868 .35539 m .39323 .3404 L .37761 .35451 L closepath p F P
0 g
s
.37 .364 .722 r
.53205 .22361 m .52418 .21859 L .52849 .21183 L closepath p F P
0 g
s
.296 .269 .658 r
.52418 .21859 m .52849 .21183 L .52468 .19515 L p F P
0 g
s
.624 .603 .809 r
.50657 .38236 m .5141 .39739 L .48629 .40504 L p F P
0 g
s
.624 .603 .809 r
.48595 .38777 m .50657 .38236 L p .48629 .40504 L F P
0 g
s
.624 .603 .809 r
.48629 .40504 m .47914 .39046 L .48595 .38777 L p F P
0 g
s
.708 .564 .69 r
.40651 .29652 m .37955 .29638 L .37826 .29184 L p F P
0 g
s
.742 .584 .679 r
.37955 .29638 m .37826 .29184 L .37528 .29589 L closepath p F P
0 g
s
.793 .972 .677 r
.72832 .27209 m .72554 .27706 L .71235 .29401 L p F P
0 g
s
.695 .547 .681 r
.40651 .29652 m .41525 .2962 L .41987 .314 L p F P
0 g
s
.695 .547 .681 r
.41987 .314 m .38795 .31515 L .40651 .29652 L p F P
0 g
s
.708 .568 .694 r
.37955 .29638 m .40651 .29652 L .38795 .31515 L p F P
0 g
s
.47 .701 .969 r
.14627 .41374 m .16044 .41341 L .15158 .40562 L p F P
0 g
s
.47 .701 .969 r
.15158 .40562 m .13635 .4061 L .14627 .41374 L p F P
0 g
s
.429 .687 .972 r
.12593 .40602 m .13635 .4061 L .14627 .41374 L p F P
0 g
s
.753 .741 .841 r
.29414 .38641 m .30225 .39809 L .27891 .41367 L p F P
0 g
s
.753 .741 .841 r
.26659 .40661 m .29414 .38641 L p .27891 .41367 L F P
0 g
s
.753 .741 .841 r
.27891 .41367 m .26822 .40854 L .26659 .40661 L p F P
0 g
s
.786 .744 .815 r
.26789 .33449 m .25228 .34706 L .24387 .3378 L p F P
0 g
s
.708 .568 .694 r
.38795 .31515 m .38505 .31514 L .37955 .29638 L p F P
0 g
s
.742 .587 .683 r
.37528 .29589 m .37955 .29638 L .38505 .31514 L p F P
0 g
s
.756 .651 .745 r
.32994 .37494 m .33459 .37035 L .35483 .37453 L p F P
0 g
s
.728 .626 .744 r
.35368 .35151 m .33459 .37035 L .35483 .37453 L p F P
0 g
s
.728 .626 .744 r
.35996 .35249 m .35368 .35151 L p .35483 .37453 L F P
0 g
s
.728 .626 .744 r
.35483 .37453 m .3655 .36542 L .35996 .35249 L p F P
0 g
s
.651 .804 .957 r
.62777 .41329 m .59955 .42339 L .59241 .41602 L p F P
0 g
s
.675 .845 .965 r
.58974 .28085 m .61791 .26986 L .61996 .27147 L p F P
0 g
s
.639 .788 .953 r
.61791 .26986 m .58974 .28085 L .58252 .27135 L p F P
0 g
s
.636 .511 .693 r
.41525 .2962 m .44526 .28979 L p .43517 .31051 L F P
0 g
s
.636 .511 .693 r
.43517 .31051 m .41987 .314 L .41525 .2962 L p F P
0 g
s
.646 .513 .687 r
.4413 .27273 m .44526 .28979 L .41525 .2962 L p F P
0 g
s
.646 .513 .687 r
.43925 .27316 m .4413 .27273 L p .41525 .2962 L F P
0 g
s
.781 .978 .704 r
.76219 .33528 m .77052 .32236 L p .75051 .34681 L F P
0 g
s
.781 .978 .704 r
.75051 .34681 m .7534 .34539 L .76219 .33528 L p F P
0 g
s
.703 .915 .57 r
.77502 .31656 m .77838 .31328 L p .76219 .33528 L F P
0 g
s
.703 .915 .57 r
.76219 .33528 m .77052 .32236 L .77502 .31656 L p F P
0 g
s
.69 .722 .205 r
.68356 .19717 m .67936 .21104 L .6772 .21795 L p F P
0 g
s
.838 .913 .512 r
.67374 .22212 m .67936 .21104 L .6772 .21795 L closepath p F P
0 g
s
.804 .889 .905 r
.64925 .25696 m .65125 .25386 L p .61996 .27147 L F P
0 g
s
.809 .996 .859 r
.64925 .25696 m .65125 .25386 L .65274 .25386 L closepath p F P
0 g
s
.735 .629 .741 r
.3655 .36542 m .37761 .35451 L .35996 .35249 L closepath p F P
0 g
s
.735 .574 .674 r
.36338 .27638 m .35378 .29199 L .37528 .29589 L p F P
0 g
s
.803 .632 .67 r
.34516 .27132 m .36338 .27638 L .35378 .29199 L p F P
0 g
s
.757 .581 .659 r
.3525 .25652 m .34516 .27132 L .36338 .27638 L p F P
0 g
s
.742 .587 .683 r
.38505 .31514 m .36268 .31254 L .37528 .29589 L p F P
0 g
s
.778 .62 .684 r
.35378 .29199 m .37528 .29589 L .36268 .31254 L p F P
0 g
s
.649 .578 .761 r
.46362 .35243 m .46915 .36691 L .43998 .37407 L p F P
0 g
s
.649 .578 .761 r
.43998 .37407 m .43597 .36407 L .46362 .35243 L p F P
0 g
s
.735 .629 .741 r
.39138 .33477 m .39323 .3404 L .37761 .35451 L p F P
0 g
s
.735 .629 .741 r
.37107 .33324 m .39138 .33477 L p .37761 .35451 L F P
0 g
s
.735 .629 .741 r
.3578 .34745 m .37107 .33324 L p .37761 .35451 L F P
0 g
s
.735 .629 .741 r
.37761 .35451 m .35996 .35249 L .3578 .34745 L p F P
0 g
s
.549 .419 .656 r
.4383 .25676 m .463 .24418 L p .44299 .27191 L F P
0 g
s
.549 .419 .656 r
.44299 .27191 m .44113 .27194 L .4383 .25676 L p F P
0 g
s
.521 .391 .643 r
.46128 .23516 m .463 .24418 L .4383 .25676 L p F P
0 g
s
.521 .391 .643 r
.45063 .23339 m .46128 .23516 L p .4383 .25676 L F P
0 g
s
.634 .486 .663 r
.4383 .25676 m .44113 .27194 L .43925 .27316 L p F P
0 g
s
.683 .576 .729 r
.43197 .35268 m .42842 .34256 L .41082 .35448 L closepath p F P
0 g
s
.686 .582 .733 r
.42543 .33282 m .42842 .34256 L .41082 .35448 L p F P
0 g
s
.686 .582 .733 r
.4007 .33438 m .42543 .33282 L p .41082 .35448 L F P
0 g
s
.686 .582 .733 r
.39323 .3404 m .4007 .33438 L p .41082 .35448 L F P
0 g
s
.724 .942 .955 r
.67149 .32633 m .66412 .33488 L p .64055 .341 L F P
0 g
s
.758 .965 .932 r
.66412 .33488 m .67149 .32633 L .67542 .32746 L closepath p F P
0 g
s
.695 .574 .715 r
.39323 .3404 m .4007 .33438 L .39138 .33477 L closepath p F P
0 g
s
.695 .573 .713 r
.4007 .33438 m .39138 .33477 L .38571 .31735 L p F P
0 g
s
.729 .591 .702 r
.39138 .33477 m .38571 .31735 L .37107 .33324 L closepath p F P
0 g
s
0 0 0 r
.79956 .27458 m .80056 .27253 L .80132 .27013 L closepath p F P
0 g
s
.834 .652 .656 r
.3373 .25038 m .3525 .25652 L .34516 .27132 L p F P
0 g
s
.825 .631 .641 r
.3525 .25652 m .3373 .25038 L .34292 .23621 L p F P
0 g
s
.695 .573 .713 r
.38795 .31515 m .41987 .314 L p .4007 .33438 L F P
0 g
s
.695 .573 .713 r
.38571 .31735 m .38795 .31515 L p .4007 .33438 L F P
0 g
s
.708 .57 .697 r
.38571 .31735 m .38795 .31515 L .38505 .31514 L closepath p F P
0 g
s
.753 .63 .725 r
.38505 .31514 m .38571 .31735 L .37107 .33324 L p F P
0 g
s
.753 .63 .725 r
.36268 .31254 m .38505 .31514 L p .37107 .33324 L F P
0 g
s
.822 .73 .763 r
.28879 .31508 m .27719 .30782 L .29164 .29056 L p F P
0 g
s
.821 .73 .764 r
.28879 .31508 m .27983 .32503 L .27158 .31445 L p F P
0 g
s
.821 .73 .764 r
.27158 .31445 m .27719 .30782 L .28879 .31508 L p F P
0 g
s
.786 .744 .815 r
.24387 .3378 m .25624 .32728 L .26789 .33449 L p F P
0 g
s
.771 .733 .818 r
.27158 .31445 m .25624 .32728 L .26789 .33449 L p F P
0 g
s
.771 .733 .818 r
.26789 .33449 m .27983 .32503 L .27158 .31445 L p F P
0 g
s
.677 .748 .905 r
.20418 .42326 m .23095 .4128 L .23943 .42141 L p F P
0 g
s
.686 .752 .901 r
.23095 .4128 m .20418 .42326 L .19552 .41536 L p F P
0 g
s
.895 .744 .687 r
.29905 .22841 m .30839 .2367 L .30125 .25135 L p F P
0 g
s
.902 .733 .662 r
.30839 .2367 m .29905 .22841 L .30482 .21426 L p F P
0 g
s
.645 .782 .947 r
.57705 .35485 m .60525 .34624 L .61087 .3519 L p F P
0 g
s
.628 .7 .897 r
.59808 .33778 m .60525 .34624 L .57705 .35485 L p F P
0 g
s
.628 .7 .897 r
.58791 .34031 m .59808 .33778 L p .57705 .35485 L F P
0 g
s
.628 .7 .897 r
.57705 .35485 m .57473 .35166 L .58791 .34031 L p F P
0 g
s
.721 .731 .859 r
.23943 .42141 m .26491 .4075 L .26822 .40854 L p F P
0 g
s
.733 .737 .854 r
.26491 .4075 m .23943 .42141 L .23095 .4128 L p F P
0 g
s
.688 .56 .705 r
.42543 .33282 m .42092 .31797 L .4007 .33438 L closepath p F P
0 g
s
.695 .573 .713 r
.41987 .314 m .42092 .31797 L .4007 .33438 L p F P
0 g
s
.72 .966 .709 r
.74548 .3534 m .75051 .34681 L .7534 .34539 L closepath p F P
0 g
s
.703 .803 .927 r
.61087 .3519 m .61233 .35335 L .64055 .341 L p F P
0 g
s
.593 .601 .829 r
.547 .26142 m .57523 .26018 L p .57195 .27314 L F P
0 g
s
.513 .532 .813 r
.56786 .24727 m .57523 .26018 L .547 .26142 L p F P
0 g
s
.513 .532 .813 r
.55041 .24577 m .56786 .24727 L p .547 .26142 L F P
0 g
s
.513 .532 .813 r
.547 .26142 m .54372 .25416 L .55041 .24577 L p F P
0 g
s
.729 .99 .845 r
.72335 .37321 m .72492 .37147 L .72568 .37139 L closepath p F P
0 g
s
.774 .98 .911 r
.72335 .37321 m .72492 .37147 L p .69557 .39142 L F P
0 g
s
.649 .755 .926 r
.18679 .35187 m .17445 .34692 L .18158 .35357 L closepath p F P
0 g
s
0 0 .107 r
.68356 .19717 m .68673 .185 L .68777 .17222 L p F P
0 g
s
.753 .777 .277 r
.68673 .185 m .68356 .19717 L .67936 .21104 L p F P
0 g
s
.87 .679 .641 r
.33051 .22903 m .34292 .23621 L .3373 .25038 L p F P
0 g
s
.867 .661 .622 r
.34292 .23621 m .33051 .22903 L .33475 .21539 L p F P
0 g
s
.789 .999 .83 r
.72492 .37147 m .72568 .37139 L .74548 .3534 L p F P
0 g
s
.273 .197 .586 r
.48916 .20435 m .48532 .19698 L .4877 .19394 L closepath p F P
0 g
s
.789 .999 .83 r
.74548 .3534 m .75051 .34681 L p .72492 .37147 L F P
0 g
s
.643 .554 .739 r
.46136 .34567 m .46362 .35243 L .43597 .36407 L p F P
0 g
s
.643 .554 .739 r
.43597 .36407 m .43197 .35268 L .46136 .34567 L p F P
0 g
s
.652 .618 .803 r
.47914 .39046 m .47875 .38966 L .47156 .3923 L closepath p F P
0 g
s
.646 .597 .785 r
.47118 .37224 m .47875 .38966 L .47156 .3923 L p F P
0 g
s
.637 .514 .696 r
.42092 .31797 m .43517 .31051 L .41987 .314 L closepath p F P
0 g
s
.818 .967 .9 r
.67149 .32633 m .67542 .32746 L .69361 .31275 L p F P
0 g
s
.64 .776 .316 r
.80056 .27253 m .79956 .27458 L .79211 .28976 L p F P
0 g
s
.678 .882 .974 r
.65961 .40368 m .65012 .41154 L p .62777 .41329 L F P
0 g
s
.699 .894 .968 r
.65012 .41154 m .65961 .40368 L .66292 .40564 L closepath p F P
0 g
s
.443 .685 .967 r
.13635 .4061 m .12593 .40602 L .11696 .39814 L p F P
0 g
s
.752 .631 .726 r
.3578 .34745 m .37107 .33324 L .35047 .32961 L closepath p F P
0 g
s
.753 .63 .725 r
.3501 .32872 m .36268 .31254 L p .37107 .33324 L F P
0 g
s
.753 .63 .725 r
.37107 .33324 m .35047 .32961 L .3501 .32872 L p F P
0 g
s
.647 .536 .715 r
.42543 .33282 m .42092 .31797 L .43517 .31051 L p F P
0 g
s
.744 .77 .874 r
.21808 .35249 m .21673 .35327 L .20813 .34488 L p F P
0 g
s
.849 .998 .8 r
.71235 .29401 m .71952 .28111 L p .69941 .30444 L F P
0 g
s
.849 .998 .8 r
.69941 .30444 m .70328 .30391 L .71235 .29401 L p F P
0 g
s
.793 .972 .677 r
.72466 .27472 m .72832 .27209 L p .71235 .29401 L F P
0 g
s
.793 .972 .677 r
.71235 .29401 m .71952 .28111 L .72466 .27472 L p F P
0 g
s
.648 .557 .738 r
.45606 .32976 m .46136 .34567 L .43197 .35268 L p F P
0 g
s
.648 .557 .738 r
.43197 .35268 m .42842 .34256 L .45606 .32976 L p F P
0 g
s
.101 .048 .505 r
.52468 .19515 m .52447 .19314 L .52488 .19479 L closepath p F P
0 g
s
.746 .634 .735 r
.35996 .35249 m .3578 .34745 L .35368 .35151 L closepath p F P
0 g
s
.744 .77 .874 r
.20813 .34488 m .20878 .34449 L .21808 .35249 L p F P
0 g
s
.733 .757 .872 r
.23538 .32884 m .20878 .34449 L .21808 .35249 L p F P
0 g
s
.733 .757 .872 r
.21808 .35249 m .24387 .3378 L .23538 .32884 L p F P
0 g
s
.673 .84 .422 r
.79211 .28976 m .78265 .30562 L .77838 .31328 L p F P
0 g
s
.735 .914 .549 r
.77502 .31656 m .78265 .30562 L .77838 .31328 L closepath p F P
0 g
s
.865 .727 .709 r
.30374 .27413 m .29985 .28062 L .2917 .26906 L p F P
0 g
s
.865 .727 .709 r
.2917 .26906 m .29324 .26637 L .30374 .27413 L p F P
0 g
s
.869 .724 .699 r
.30374 .27413 m .29324 .26637 L .30125 .25135 L p F P
0 g
s
.64 .533 .718 r
.42842 .34256 m .42543 .33282 L .45495 .3259 L p F P
0 g
s
.647 .536 .715 r
.44964 .30734 m .45495 .3259 L .42543 .33282 L p F P
0 g
s
.647 .536 .715 r
.43517 .31051 m .44964 .30734 L p .42543 .33282 L F P
0 g
s
.914 .716 .621 r
.32509 .20717 m .33475 .21539 L .33051 .22903 L p F P
0 g
s
.92 .699 .587 r
.33475 .21539 m .32509 .20717 L .32805 .19403 L p F P
0 g
s
.751 .966 .932 r
.6912 .39024 m .70386 .38205 L .69557 .39142 L closepath p F P
0 g
s
.774 .98 .911 r
.71944 .37136 m .70386 .38205 L .69557 .39142 L p F P
0 g
s
.774 .98 .911 r
.72492 .37147 m .71944 .37136 L p .69557 .39142 L F P
0 g
s
.696 .956 .95 r
.66292 .40564 m .6912 .39024 L .69557 .39142 L p F P
0 g
s
.64 .533 .718 r
.45495 .3259 m .45606 .32976 L .42842 .34256 L p F P
0 g
s
0 0 .172 r
.81824 .21454 m .82014 .20846 L .82099 .19556 L p F P
0 g
s
0 0 .13 r
.82395 .18368 m .82099 .19556 L .82014 .20846 L p F P
0 g
s
0 0 .252 r
.82099 .19556 m .82395 .18368 L .82354 .17125 L p F P
0 g
s
.496 .507 .798 r
.54372 .25416 m .53955 .24429 L .55041 .24577 L closepath p F P
0 g
s
.777 .995 .871 r
.71944 .37136 m .73374 .3598 L .72492 .37147 L closepath p F P
0 g
s
.789 .999 .83 r
.74747 .34766 m .73374 .3598 L .72492 .37147 L p F P
0 g
s
.789 .999 .83 r
.75051 .34681 m .74747 .34766 L p .72492 .37147 L F P
0 g
s
.677 .793 .936 r
.60525 .34624 m .61978 .34078 L .61087 .3519 L closepath p F P
0 g
s
.703 .803 .927 r
.63361 .33548 m .61978 .34078 L .61087 .3519 L p F P
0 g
s
.703 .803 .927 r
.64055 .341 m .63361 .33548 L p .61087 .3519 L F P
0 g
s
.787 .999 .825 r
.69361 .31275 m .69941 .30444 L .70328 .30391 L closepath p F P
0 g
s
.818 .967 .9 r
.69361 .31275 m .69941 .30444 L p .67149 .32633 L F P
0 g
s
.65 .754 .926 r
.18679 .35187 m .20813 .34488 L p .17283 .34541 L F P
0 g
s
.65 .754 .926 r
.17283 .34541 m .17445 .34692 L .18679 .35187 L p F P
0 g
s
.778 .702 .78 r
.31112 .39061 m .30225 .39809 L .29414 .38641 L p F P
0 g
s
.263 .247 .652 r
.52488 .19479 m .52468 .19515 L .52849 .21183 L p F P
0 g
s
.846 .963 .881 r
.64605 .25229 m .65505 .24419 L .65125 .25386 L closepath p F P
0 g
s
.804 .889 .905 r
.65125 .25386 m .64605 .25229 L p .61996 .27147 L F P
0 g
s
.894 .983 .804 r
.67095 .22636 m .65505 .24419 L .65125 .25386 L p F P
0 g
s
.777 .622 .687 r
.36268 .31254 m .3501 .32872 L .3424 .30967 L p F P
0 g
s
.777 .622 .687 r
.3424 .30967 m .34361 .30783 L .36268 .31254 L p F P
0 g
s
.778 .62 .684 r
.36268 .31254 m .34361 .30783 L .35378 .29199 L p F P
0 g
s
.742 .626 .731 r
.35368 .35151 m .3578 .34745 L .35047 .32961 L p F P
0 g
s
.628 .7 .897 r
.57473 .35166 m .56978 .34485 L .58791 .34031 L closepath p F P
0 g
s
.708 .804 .336 r
.74881 .22907 m .74684 .23415 L .74055 .24885 L p F P
0 g
s
0 0 .038 r
.82014 .20846 m .81824 .21454 L .81727 .22417 L p F P
0 g
s
0 0 .055 r
.81389 .23391 m .81727 .22417 L .81824 .21454 L p F P
0 g
s
0 0 .011 r
.75943 .18298 m .75653 .19495 L .75471 .2081 L p F P
0 g
s
0 0 .2 r
.75653 .19495 m .75943 .18298 L .75948 .17045 L p F P
0 g
s
.771 .678 .761 r
.33389 .34711 m .35368 .35151 L .33459 .37035 L p F P
0 g
s
.742 .626 .731 r
.3495 .32941 m .33389 .34711 L .35368 .35151 L p F P
0 g
s
.742 .626 .731 r
.35047 .32961 m .3495 .32941 L p .35368 .35151 L F P
0 g
s
.595 .654 .878 r
.53431 .33798 m .56243 .33334 L .56978 .34485 L p F P
0 g
s
.572 .584 .827 r
.55502 .32038 m .56243 .33334 L .53431 .33798 L p F P
0 g
s
.572 .584 .827 r
.53872 .32193 m .55502 .32038 L p .53431 .33798 L F P
0 g
s
.572 .584 .827 r
.53431 .33798 m .52989 .32912 L .53872 .32193 L p F P
0 g
s
.638 .494 .67 r
.4413 .27273 m .44113 .27194 L .43925 .27316 L closepath p F P
0 g
s
.594 .665 .888 r
.58252 .27135 m .57195 .27314 L .57771 .26405 L closepath p F P
0 g
s
.593 .601 .829 r
.57523 .26018 m .57771 .26405 L .57195 .27314 L p F P
0 g
s
.778 .702 .78 r
.29414 .38641 m .29587 .38479 L .31112 .39061 L p F P
0 g
s
.748 .67 .774 r
.31678 .36533 m .29587 .38479 L .31112 .39061 L p F P
0 g
s
.748 .67 .774 r
.32602 .36778 m .31678 .36533 L p .31112 .39061 L F P
0 g
s
.748 .67 .774 r
.31112 .39061 m .32994 .37494 L .32602 .36778 L p F P
0 g
s
.263 .247 .652 r
.52849 .21183 m .53271 .20444 L .52488 .19479 L p F P
0 g
s
.094 .133 .611 r
.53074 .18139 m .52488 .19479 L .53271 .20444 L p F P
0 g
s
.162 .085 .514 r
.52854 .16987 m .53074 .18139 L .52488 .19479 L p F P
0 g
s
0 0 0 r
.81727 .22417 m .81389 .23391 L .81018 .24783 L p F P
0 g
s
.626 .677 .879 r
.52158 .41064 m .5496 .40383 L .55697 .41479 L p F P
0 g
s
.618 .629 .839 r
.54585 .39753 m .5496 .40383 L .52158 .41064 L p F P
0 g
s
.618 .629 .839 r
.52158 .41064 m .52108 .40976 L .54585 .39753 L p F P
0 g
s
.625 .605 .811 r
.47914 .39046 m .47875 .38966 L .48595 .38777 L closepath p F P
0 g
s
.549 .436 .676 r
.4413 .27273 m .44113 .27194 L .44299 .27191 L closepath p F P
0 g
s
.62 .577 .785 r
.48595 .38777 m .47875 .38966 L .47118 .37224 L p F P
0 g
s
.554 .445 .684 r
.44526 .28979 m .4413 .27273 L .44299 .27191 L p F P
0 g
s
.614 .629 .843 r
.54216 .3914 m .54585 .39753 L .52108 .40976 L p F P
0 g
s
.614 .629 .843 r
.52108 .40976 m .5141 .39739 L .54216 .3914 L p F P
0 g
s
.522 .39 .642 r
.46128 .23516 m .45063 .23339 L .46014 .22841 L closepath p F P
0 g
s
.515 .36 .609 r
.45805 .21355 m .46014 .22841 L .45063 .23339 L p F P
0 g
s
0 0 0 r
.81018 .24783 m .80494 .2623 L .80056 .27253 L p F P
0 g
s
.682 .794 .329 r
.80494 .2623 m .80056 .27253 L .79719 .27933 L p F P
0 g
s
.64 .776 .316 r
.79211 .28976 m .79719 .27933 L .80056 .27253 L p F P
0 g
s
.771 .678 .76 r
.32994 .37494 m .33459 .37035 L .32602 .36778 L closepath p F P
0 g
s
.771 .678 .761 r
.32202 .3605 m .33389 .34711 L p .33459 .37035 L F P
0 g
s
.771 .678 .761 r
.33459 .37035 m .32602 .36778 L .32202 .3605 L p F P
0 g
s
.801 .653 .699 r
.33719 .28639 m .35378 .29199 L .34361 .30783 L p F P
0 g
s
.803 .632 .67 r
.35378 .29199 m .33719 .28639 L .34516 .27132 L p F P
0 g
s
.823 .729 .76 r
.29164 .29056 m .29985 .28062 L .2917 .26906 L p F P
0 g
s
.312 .227 .596 r
.466 .20448 m .45805 .21355 L .46014 .22841 L p F P
0 g
s
.272 .172 .553 r
.45805 .21355 m .466 .20448 L .46183 .19365 L p F P
0 g
s
.249 .18 .58 r
.4877 .19394 m .49339 .18277 L p .49066 .20743 L F P
0 g
s
.249 .18 .58 r
.49066 .20743 m .48916 .20435 L .4877 .19394 L p F P
0 g
s
0 0 .426 r
.4877 .19394 m .49339 .18277 L .49196 .17103 L p F P
0 g
s
.82 .96 .629 r
.72466 .27472 m .7318 .26439 L .72832 .27209 L closepath p F P
0 g
s
.767 .889 .479 r
.74055 .24885 m .7318 .26439 L .72832 .27209 L p F P
0 g
s
.433 .372 .69 r
.4967 .23902 m .48525 .2329 L .49325 .22506 L closepath p F P
0 g
s
.408 .334 .662 r
.48525 .2329 m .49325 .22506 L .48982 .20871 L p F P
0 g
s
.072 .034 .504 r
.47015 .17926 m .46183 .19365 L .466 .20448 L p F P
0 g
s
.021 0 .421 r
.46183 .19365 m .47015 .17926 L .4691 .16742 L p F P
0 g
s
.553 .439 .677 r
.46874 .27086 m .44299 .27191 L .46646 .26068 L closepath p F P
0 g
s
.549 .419 .656 r
.463 .24418 m .46646 .26068 L .44299 .27191 L p F P
0 g
s
.554 .445 .684 r
.44299 .27191 m .46874 .27086 L p .44526 .28979 L F P
0 g
s
.504 .49 .775 r
.55041 .24577 m .53955 .24429 L .53459 .23122 L p F P
0 g
s
.739 .902 .951 r
.65961 .40368 m .66292 .40564 L .6912 .39024 L p F P
0 g
s
.749 .862 .931 r
.61791 .26986 m .62167 .26774 L .61996 .27147 L closepath p F P
0 g
s
.804 .889 .905 r
.64605 .25229 m .62167 .26774 L .61996 .27147 L p F P
0 g
s
.718 .733 .862 r
.26822 .40854 m .26659 .40661 L .26491 .4075 L closepath p F P
0 g
s
.833 .674 .685 r
.33097 .26484 m .34516 .27132 L .33719 .28639 L p F P
0 g
s
.834 .652 .656 r
.34516 .27132 m .33097 .26484 L .3373 .25038 L p F P
0 g
s
.641 .523 .703 r
.44964 .30734 m .44855 .30345 L .43517 .31051 L closepath p F P
0 g
s
.636 .511 .693 r
.44526 .28979 m .44855 .30345 L .43517 .31051 L p F P
0 g
s
.823 .729 .76 r
.2917 .26906 m .28065 .28299 L .29164 .29056 L p F P
0 g
s
.838 .749 .765 r
.28065 .28299 m .29164 .29056 L .27719 .30782 L p F P
0 g
s
.89 .752 .703 r
.29205 .24304 m .30125 .25135 L .29324 .26637 L p F P
0 g
s
.895 .744 .687 r
.30125 .25135 m .29205 .24304 L .29905 .22841 L p F P
0 g
s
.76 .634 .721 r
.35047 .32961 m .3501 .32872 L .3495 .32941 L closepath p F P
0 g
s
.759 .632 .72 r
.3495 .32941 m .3501 .32872 L .3424 .30967 L p F P
0 g
s
.426 .4 .726 r
.52849 .21183 m .53271 .20444 L p .53795 .22633 L F P
0 g
s
.426 .4 .726 r
.53795 .22633 m .53205 .22361 L .52849 .21183 L p F P
0 g
s
.793 .668 .726 r
.33095 .32455 m .3495 .32941 L .33389 .34711 L p F P
0 g
s
.759 .632 .72 r
.3424 .30967 m .33095 .32455 L .3495 .32941 L p F P
0 g
s
.504 .49 .775 r
.53459 .23122 m .53795 .22633 L p .55041 .24577 L F P
0 g
s
.41 .407 .745 r
.53459 .23122 m .53205 .22361 L .53795 .22633 L closepath p F P
0 g
s
.572 .583 .826 r
.52989 .32912 m .52685 .32303 L .53872 .32193 L closepath p F P
0 g
s
.719 .734 .863 r
.25825 .3968 m .24996 .40158 L .26491 .4075 L p F P
0 g
s
.719 .734 .863 r
.26491 .4075 m .26659 .40661 L .25825 .3968 L p F P
0 g
s
.733 .737 .854 r
.23095 .4128 m .24996 .40158 L .26491 .4075 L p F P
0 g
s
0 0 .064 r
.68944 .16428 m .68777 .17222 L .68673 .185 L p F P
0 g
s
.571 .46 .689 r
.44526 .28979 m .47051 .27785 L p .46192 .3017 L F P
0 g
s
.571 .46 .689 r
.46192 .3017 m .44855 .30345 L .44526 .28979 L p F P
0 g
s
.554 .445 .684 r
.46874 .27086 m .47051 .27785 L .44526 .28979 L p F P
0 g
s
.72 .871 .461 r
.79719 .27933 m .79211 .28976 L .78265 .30562 L p F P
0 g
s
.621 .582 .79 r
.50657 .38236 m .48595 .38777 L .50565 .38027 L closepath p F P
0 g
s
.62 .577 .785 r
.49902 .36541 m .50565 .38027 L .48595 .38777 L p F P
0 g
s
.62 .577 .785 r
.47118 .37224 m .49902 .36541 L p .48595 .38777 L F P
0 g
s
.874 .695 .656 r
.3254 .24303 m .3373 .25038 L .33097 .26484 L p F P
0 g
s
.87 .679 .641 r
.3373 .25038 m .3254 .24303 L .33051 .22903 L p F P
0 g
s
.763 .712 .805 r
.29414 .38641 m .26659 .40661 L .25825 .3968 L p F P
0 g
s
.919 .947 .601 r
.67936 .21104 m .68236 .19896 L p .67223 .22329 L F P
0 g
s
.919 .947 .601 r
.67223 .22329 m .67374 .22212 L .67936 .21104 L p F P
0 g
s
.753 .777 .277 r
.67936 .21104 m .68236 .19896 L .68673 .185 L p F P
0 g
s
.762 .675 .766 r
.32602 .36778 m .32202 .3605 L .31678 .36533 L closepath p F P
0 g
s
.633 .734 .921 r
.55697 .41479 m .58518 .40735 L .59241 .41602 L p F P
0 g
s
.619 .698 .901 r
.58518 .40735 m .55697 .41479 L .5496 .40383 L p F P
0 g
s
.603 .743 .943 r
.16044 .41341 m .1868 .40735 L .19552 .41536 L p F P
0 g
s
.608 .745 .942 r
.1868 .40735 m .16044 .41341 L .15158 .40562 L p F P
0 g
s
.607 .547 .762 r
.49544 .35635 m .49902 .36541 L .47118 .37224 L p F P
0 g
s
.607 .547 .762 r
.47118 .37224 m .46915 .36691 L .49544 .35635 L p F P
0 g
s
0 0 .208 r
.82566 .1595 m .82354 .17125 L .82395 .18368 L p F P
0 g
s
0 0 .263 r
.49428 .15864 m .49196 .17103 L .49339 .18277 L p F P
0 g
s
.22 .167 .582 r
.48982 .20871 m .48916 .20435 L .49066 .20743 L closepath p F P
0 g
s
.797 .759 .819 r
.25624 .32728 m .24387 .3378 L .23538 .32884 L p F P
0 g
s
.604 .546 .763 r
.49144 .34626 m .49544 .35635 L .46915 .36691 L p F P
0 g
s
.604 .546 .763 r
.46915 .36691 m .46362 .35243 L .49144 .34626 L p F P
0 g
s
.476 .698 .966 r
.13635 .4061 m .15158 .40562 L .14266 .39761 L p F P
0 g
s
.476 .698 .966 r
.14266 .39761 m .12705 .39817 L .13635 .4061 L p F P
0 g
s
.443 .685 .967 r
.11696 .39814 m .12705 .39817 L .13635 .4061 L p F P
0 g
s
.639 .788 .953 r
.58252 .27135 m .61085 .26284 L .61791 .26986 L p F P
0 g
s
.61 .672 .884 r
.60368 .2544 m .61085 .26284 L .58252 .27135 L p F P
0 g
s
.61 .672 .884 r
.58245 .25875 m .60368 .2544 L p .58252 .27135 L F P
0 g
s
.61 .672 .884 r
.58252 .27135 m .57771 .26405 L .58245 .25875 L p F P
0 g
s
.793 .669 .727 r
.33389 .34711 m .32202 .3605 L .31406 .34619 L p F P
0 g
s
.793 .669 .727 r
.31406 .34619 m .31777 .34146 L .33389 .34711 L p F P
0 g
s
.793 .668 .726 r
.33389 .34711 m .31777 .34146 L .33095 .32455 L p F P
0 g
s
.801 .653 .699 r
.33466 .29098 m .33719 .28639 L p .34361 .30783 L F P
0 g
s
.801 .653 .699 r
.34361 .30783 m .34128 .30701 L .33466 .29098 L p F P
0 g
s
.8 .654 .701 r
.3424 .30967 m .34361 .30783 L .34128 .30701 L closepath p F P
0 g
s
.838 .749 .765 r
.27719 .30782 m .26698 .30001 L .28065 .28299 L p F P
0 g
s
.837 .75 .767 r
.27719 .30782 m .27158 .31445 L .26324 .3046 L p F P
0 g
s
.837 .75 .767 r
.26324 .3046 m .26698 .30001 L .27719 .30782 L p F P
0 g
s
0 0 .151 r
.76079 .16311 m .75948 .17045 L .75943 .18298 L p F P
0 g
s
.72 .821 .927 r
.62167 .26774 m .61791 .26986 L .61085 .26284 L p F P
0 g
s
.804 .914 .521 r
.74536 .23648 m .74055 .24885 L .7318 .26439 L p F P
0 g
s
.708 .804 .336 r
.74567 .23579 m .74881 .22907 L p .74055 .24885 L F P
0 g
s
.708 .804 .336 r
.74055 .24885 m .74536 .23648 L .74567 .23579 L p F P
0 g
s
.52 .71 .958 r
.17283 .34541 m .17279 .34541 L .17445 .34692 L closepath p F P
0 g
s
.797 .759 .819 r
.23538 .32884 m .24596 .31954 L .25624 .32728 L p F P
0 g
s
.786 .75 .82 r
.26324 .3046 m .24596 .31954 L .25624 .32728 L p F P
0 g
s
.786 .75 .82 r
.25624 .32728 m .27158 .31445 L .26324 .3046 L p F P
0 g
s
.678 .882 .974 r
.62777 .41329 m .65614 .40151 L .65961 .40368 L p F P
0 g
s
.669 .846 .967 r
.65614 .40151 m .62777 .41329 L .62074 .40686 L p F P
0 g
s
.651 .804 .957 r
.59241 .41602 m .62074 .40686 L .62777 .41329 L p F P
0 g
s
.573 .559 .8 r
.53872 .32193 m .52685 .32303 L .51935 .30609 L p F P
0 g
s
.574 .481 .712 r
.44964 .30734 m .44855 .30345 L .46192 .3017 L closepath p F P
0 g
s
.788 .994 .774 r
.74747 .34766 m .75475 .34026 L .75051 .34681 L closepath p F P
0 g
s
.781 .978 .704 r
.77052 .32236 m .75475 .34026 L .75051 .34681 L p F P
0 g
s
0 0 0 r
.75471 .2081 m .75105 .22193 L .74881 .22907 L p F P
0 g
s
.751 .811 .335 r
.74567 .23579 m .75105 .22193 L .74881 .22907 L closepath p F P
0 g
s
.91 .727 .643 r
.32097 .22078 m .33051 .22903 L .3254 .24303 L p F P
0 g
s
.914 .716 .621 r
.33051 .22903 m .32097 .22078 L .32509 .20717 L p F P
0 g
s
.628 .669 .87 r
.58791 .34031 m .56978 .34485 L .56243 .33334 L p F P
0 g
s
.724 .942 .955 r
.64055 .341 m .6688 .32525 L .67149 .32633 L p F P
0 g
s
.713 .905 .964 r
.6688 .32525 m .64055 .341 L .63361 .33548 L p F P
0 g
s
.78 .646 .714 r
.33095 .32455 m .3424 .30967 L .34128 .30701 L p F P
0 g
s
.575 .485 .715 r
.45495 .3259 m .44964 .30734 L .46192 .3017 L p F P
0 g
s
0 0 .282 r
.53002 .15783 m .52854 .16987 L .53074 .18139 L p F P
0 g
s
.638 .766 .94 r
.62074 .40686 m .59241 .41602 L .58518 .40735 L p F P
0 g
s
.795 .651 .702 r
.34128 .30701 m .33466 .29098 L .32702 .30225 L closepath p F P
0 g
s
.78 .646 .714 r
.34128 .30701 m .32702 .30225 L p .33095 .32455 L F P
0 g
s
.72 .821 .927 r
.61085 .26284 m .62624 .25534 L .62167 .26774 L p F P
0 g
s
.771 .917 .936 r
.6392 .24841 m .62624 .25534 L .62167 .26774 L p F P
0 g
s
.771 .917 .936 r
.62167 .26774 m .64605 .25229 L .6392 .24841 L p F P
0 g
s
.418 .318 .634 r
.46014 .22841 m .47224 .21468 L p .46723 .24014 L F P
0 g
s
.418 .318 .634 r
.46723 .24014 m .46128 .23516 L .46014 .22841 L p F P
0 g
s
.312 .227 .596 r
.46014 .22841 m .47224 .21468 L .466 .20448 L p F P
0 g
s
.745 .749 .855 r
.24996 .40158 m .23095 .4128 L .22241 .40416 L p F P
0 g
s
.686 .752 .901 r
.19552 .41536 m .22241 .40416 L .23095 .4128 L p F P
0 g
s
.285 .251 .643 r
.49066 .20743 m .48982 .20871 L .49325 .22506 L p F P
0 g
s
0 0 0 r
.81649 .22794 m .81727 .22417 L p .81081 .24573 L F P
0 g
s
0 0 0 r
.81018 .24783 m .81109 .24496 L .81081 .24573 L F
.81109 .24496 m .81649 .22794 L .81081 .24573 L F
.81018 .24783 m .81444 .23575 L .81649 .22794 L p F P
0 g
s
0 0 0 r
.81444 .23575 m .81018 .24783 L .80548 .26081 L p F P
0 g
s
0 0 0 r
.80548 .26081 m .80494 .2623 L p .80576 .26002 L F P
0 g
s
0 0 0 r
.80576 .26002 m .81444 .23575 L .80548 .26081 L F
.737 .829 .372 r
.79803 .27736 m .80254 .26529 L .8087 .25161 L p F P
0 g
s
0 0 0 r
.80494 .2623 m .80932 .25023 L .81438 .23594 L p F P
0 g
s
0 0 0 r
.80494 .2623 m .81438 .23594 L .81433 .23606 L F
.737 .829 .372 r
.8087 .25161 m .80932 .25023 L p .80845 .25232 L F P
0 g
s
.737 .829 .372 r
.79803 .27736 m .8087 .25161 L .80845 .25232 L F
0 0 0 r
.81438 .23594 m .81444 .23575 L p .81433 .23606 L F P
0 g
s
.785 .949 .927 r
.6688 .32525 m .67498 .32098 L .67149 .32633 L closepath p F P
0 g
s
.818 .967 .9 r
.69694 .30427 m .67498 .32098 L .67149 .32633 L p F P
0 g
s
.818 .967 .9 r
.69941 .30444 m .69694 .30427 L p .67149 .32633 L F P
0 g
s
.6 .614 .837 r
.54216 .3914 m .5141 .39739 L .50657 .38236 L p F P
0 g
s
0 0 .038 r
.81727 .22417 m .818 .22184 L .82014 .20846 L p F P
0 g
s
0 0 0 r
.82315 .1966 m .82014 .20846 L .818 .22184 L p F P
0 g
s
0 0 .13 r
.82014 .20846 m .82315 .1966 L .82395 .18368 L p F P
0 g
s
.595 .519 .739 r
.48742 .33477 m .49144 .34626 L .46362 .35243 L p F P
0 g
s
.595 .519 .739 r
.46362 .35243 m .46136 .34567 L .48742 .33477 L p F P
0 g
s
.693 .756 .9 r
.22241 .40416 m .19552 .41536 L .1868 .40735 L p F P
0 g
s
.564 .505 .747 r
.51181 .2868 m .51837 .30362 L .51393 .30647 L p F P
0 g
s
.564 .505 .747 r
.50304 .28653 m .51181 .2868 L p .51393 .30647 L F P
0 g
s
.566 .533 .777 r
.51935 .30609 m .51393 .30647 L .51837 .30362 L closepath p F P
0 g
s
.763 .677 .768 r
.31678 .36533 m .32202 .3605 L .31406 .34619 L p F P
0 g
s
.763 .677 .768 r
.31406 .34619 m .30081 .35965 L .31678 .36533 L p F P
0 g
s
.786 .72 .79 r
.30081 .35965 m .31678 .36533 L .29587 .38479 L p F P
0 g
s
.591 .516 .739 r
.48385 .32456 m .48742 .33477 L .46136 .34567 L p F P
0 g
s
.591 .516 .739 r
.46136 .34567 m .45606 .32976 L .48385 .32456 L p F P
0 g
s
.582 .491 .716 r
.45606 .32976 m .45495 .3259 L .48083 .31474 L p F P
0 g
s
.575 .485 .715 r
.47628 .29977 m .48083 .31474 L .45495 .3259 L p F P
0 g
s
.575 .485 .715 r
.46192 .3017 m .47628 .29977 L p .45495 .3259 L F P
0 g
s
.787 .719 .789 r
.29414 .38641 m .29587 .38479 L .29161 .38281 L closepath p F P
0 g
s
.786 .72 .79 r
.28598 .37485 m .30081 .35965 L p .29587 .38479 L F P
0 g
s
.786 .72 .79 r
.29587 .38479 m .29161 .38281 L .28598 .37485 L p F P
0 g
s
0 0 .011 r
.75471 .2081 m .75764 .19615 L .75943 .18298 L p F P
0 g
s
.701 .717 .193 r
.75764 .19615 m .75471 .2081 L .75105 .22193 L p F P
0 g
s
.763 .712 .805 r
.29161 .38281 m .29414 .38641 L p .25825 .3968 L F P
0 g
s
.539 .495 .755 r
.51181 .2868 m .50304 .28653 L .50998 .28159 L closepath p F P
0 g
s
.538 .463 .719 r
.50426 .26483 m .50998 .28159 L .50304 .28653 L p F P
0 g
s
.538 .463 .719 r
.49986 .26402 m .50426 .26483 L p .50304 .28653 L F P
0 g
s
.65 .754 .926 r
.20813 .34488 m .19946 .33654 L .17283 .34541 L p F P
0 g
s
.582 .491 .716 r
.48083 .31474 m .48385 .32456 L .45606 .32976 L p F P
0 g
s
.833 .674 .685 r
.32684 .27365 m .33097 .26484 L p .33719 .28639 L F P
0 g
s
.833 .674 .685 r
.33719 .28639 m .33123 .28347 L .32684 .27365 L p F P
0 g
s
.832 .676 .69 r
.33466 .29098 m .33719 .28639 L .33123 .28347 L closepath p F P
0 g
s
.834 .958 .621 r
.67095 .22636 m .67223 .22329 L .67374 .22212 L closepath p F P
0 g
s
.885 .755 .714 r
.29324 .26637 m .2917 .26906 L .2834 .25941 L p F P
0 g
s
.885 .755 .714 r
.2834 .25941 m .28418 .25803 L .29324 .26637 L p F P
0 g
s
.89 .752 .703 r
.29324 .26637 m .28418 .25803 L .29205 .24304 L p F P
0 g
s
.651 .793 .951 r
.61978 .34078 m .60525 .34624 L .59808 .33778 L p F P
0 g
s
.72 .871 .461 r
.79634 .28047 m .79719 .27933 L p .78265 .30562 L F P
0 g
s
.72 .871 .461 r
.78265 .30562 m .78881 .2932 L .79634 .28047 L p F P
0 g
s
.802 .953 .616 r
.78265 .30562 m .78881 .2932 L p .77309 .31801 L F P
0 g
s
.802 .953 .616 r
.77309 .31801 m .77502 .31656 L .78265 .30562 L p F P
0 g
s
.285 .251 .643 r
.49325 .22506 m .49849 .21712 L .49066 .20743 L p F P
0 g
s
.127 .148 .612 r
.4974 .19369 m .49066 .20743 L .49849 .21712 L p F P
0 g
s
.249 .18 .58 r
.49339 .18277 m .4974 .19369 L .49066 .20743 L p F P
0 g
s
.716 .891 .96 r
.65614 .40151 m .66675 .39632 L .65961 .40368 L closepath p F P
0 g
s
.739 .902 .951 r
.6846 .3873 m .66675 .39632 L .65961 .40368 L p F P
0 g
s
.739 .902 .951 r
.6912 .39024 m .6846 .3873 L p .65961 .40368 L F P
0 g
s
.746 .773 .875 r
.20878 .34449 m .20813 .34488 L .19946 .33654 L p F P
0 g
s
.746 .773 .875 r
.19946 .33654 m .19988 .33628 L .20878 .34449 L p F P
0 g
s
.74 .768 .876 r
.22681 .32024 m .19988 .33628 L .20878 .34449 L p F P
0 g
s
.74 .768 .876 r
.20878 .34449 m .23538 .32884 L .22681 .32024 L p F P
0 g
s
.735 .963 .939 r
.70386 .38205 m .6912 .39024 L .6846 .3873 L p F P
0 g
s
.4 .319 .648 r
.463 .24418 m .46128 .23516 L .46723 .24014 L closepath p F P
0 g
s
.867 .979 .849 r
.67223 .22329 m .67095 .22636 L .65505 .24419 L p F P
0 g
s
0 0 .252 r
.47012 .16111 m .4691 .16742 L .47015 .17926 L p F P
0 g
s
.811 .699 .741 r
.31581 .31849 m .33095 .32455 L .31777 .34146 L p F P
0 g
s
.78 .646 .714 r
.32702 .30225 m .31581 .31849 L .33095 .32455 L p F P
0 g
s
.504 .49 .775 r
.53795 .22633 m .55712 .23239 L .55041 .24577 L p F P
0 g
s
.395 .472 .822 r
.54437 .21291 m .53795 .22633 L .55712 .23239 L p F P
0 g
s
.426 .4 .726 r
.53271 .20444 m .54437 .21291 L .53795 .22633 L p F P
0 g
s
.846 .76 .768 r
.28065 .28299 m .2917 .26906 L .2834 .25941 L p F P
0 g
s
.806 .667 .71 r
.32702 .30225 m .33466 .29098 L .33123 .28347 L p F P
0 g
s
.447 .491 .812 r
.55041 .24577 m .56786 .24727 L .56043 .23319 L p F P
0 g
s
.447 .491 .812 r
.56043 .23319 m .55712 .23239 L .55041 .24577 L p F P
0 g
s
.849 .998 .8 r
.71952 .28111 m .70208 .29951 L .69941 .30444 L p F P
0 g
s
.831 .993 .857 r
.69694 .30427 m .70208 .29951 L .69941 .30444 L closepath p F P
0 g
s
.763 .712 .805 r
.25825 .3968 m .28085 .37884 L .29161 .38281 L p F P
0 g
s
.761 .714 .808 r
.29161 .38281 m .28598 .37485 L .28085 .37884 L closepath p F P
0 g
s
.871 .698 .665 r
.33097 .26484 m .32684 .27365 L .31888 .25903 L p F P
0 g
s
.871 .698 .665 r
.31888 .25903 m .31961 .25733 L .33097 .26484 L p F P
0 g
s
.874 .695 .656 r
.33097 .26484 m .31961 .25733 L .3254 .24303 L p F P
0 g
s
.573 .559 .8 r
.51935 .30609 m .54755 .30592 L p .53872 .32193 L F P
0 g
s
.512 .502 .782 r
.54004 .28998 m .54755 .30592 L .51935 .30609 L p F P
0 g
s
.512 .502 .782 r
.53326 .28926 m .54004 .28998 L p .51935 .30609 L F P
0 g
s
.512 .502 .782 r
.51935 .30609 m .51837 .30362 L .53326 .28926 L p F P
0 g
s
.878 .981 .691 r
.7318 .26439 m .73659 .25208 L p .72216 .27586 L F P
0 g
s
.878 .981 .691 r
.72216 .27586 m .72466 .27472 L .7318 .26439 L p F P
0 g
s
.804 .914 .521 r
.7318 .26439 m .73659 .25208 L .74536 .23648 L p F P
0 g
s
.404 .353 .687 r
.49325 .22506 m .49849 .21712 L p .49916 .24062 L F P
0 g
s
.404 .353 .687 r
.49916 .24062 m .4967 .23902 L .49325 .22506 L p F P
0 g
s
.51 .498 .779 r
.51837 .30362 m .51181 .2868 L .53326 .28926 L closepath p F P
0 g
s
.752 .945 .618 r
.77052 .32236 m .77309 .31801 L .77502 .31656 L closepath p F P
0 g
s
.735 .963 .939 r
.71396 .37016 m .70386 .38205 L p .6846 .3873 L F P
0 g
s
.758 .977 .919 r
.70386 .38205 m .71396 .37016 L .71944 .37136 L closepath p F P
0 g
s
.605 .664 .881 r
.57771 .26405 m .57523 .26018 L .58245 .25875 L closepath p F P
0 g
s
.502 .451 .733 r
.50426 .26483 m .49986 .26402 L .50317 .26133 L closepath p F P
0 g
s
.494 .438 .723 r
.49986 .26402 m .50317 .26133 L .49764 .24253 L p F P
0 g
s
.745 .749 .855 r
.22241 .40416 m .23719 .39488 L .24996 .40158 L p F P
0 g
s
.731 .741 .86 r
.24984 .38714 m .23719 .39488 L .24996 .40158 L p F P
0 g
s
.731 .741 .86 r
.24996 .40158 m .25825 .3968 L .24984 .38714 L p F P
0 g
s
.829 .938 .899 r
.65505 .24419 m .64605 .25229 L .6392 .24841 L p F P
0 g
s
.829 .938 .899 r
.6392 .24841 m .65958 .23171 L .65505 .24419 L p F P
0 g
s
.867 .979 .849 r
.66729 .22386 m .67223 .22329 L p .65505 .24419 L F P
0 g
s
.867 .979 .849 r
.65505 .24419 m .65958 .23171 L .66729 .22386 L p F P
0 g
s
.413 .338 .663 r
.46723 .24014 m .463 .24418 L .46646 .26068 L p F P
0 g
s
.819 .669 .697 r
.33123 .28347 m .32684 .27365 L .32307 .2799 L closepath p F P
0 g
s
.806 .667 .71 r
.33123 .28347 m .32307 .2799 L p .32702 .30225 L F P
0 g
s
0 0 .064 r
.68673 .185 m .68885 .17497 L .68944 .16428 L p F P
0 g
s
.816 .823 .346 r
.68885 .17497 m .68673 .185 L .68236 .19896 L p F P
0 g
s
0 0 0 r
.81649 .22794 m .818 .22184 L .81727 .22417 L closepath p F P
0 g
s
.192 .18 .615 r
.47321 .1905 m .466 .20448 L .47224 .21468 L p F P
0 g
s
.072 .034 .504 r
.466 .20448 m .47321 .1905 L .47015 .17926 L p F P
0 g
s
.218 .326 .761 r
.53674 .19169 m .53271 .20444 L .54437 .21291 L p F P
0 g
s
.094 .133 .611 r
.53271 .20444 m .53674 .19169 L .53074 .18139 L p F P
0 g
s
.798 .989 .739 r
.77309 .31801 m .77052 .32236 L .75475 .34026 L p F P
0 g
s
.846 .76 .768 r
.2834 .25941 m .27138 .27475 L .28065 .28299 L p F P
0 g
s
.85 .768 .77 r
.27138 .27475 m .28065 .28299 L .26698 .30001 L p F P
0 g
s
.572 .594 .837 r
.55502 .32038 m .53872 .32193 L .55044 .31152 L closepath p F P
0 g
s
.573 .559 .8 r
.54755 .30592 m .55044 .31152 L .53872 .32193 L p F P
0 g
s
.835 .701 .715 r
.31329 .29564 m .32702 .30225 L .31581 .31849 L p F P
0 g
s
.806 .667 .71 r
.32307 .2799 m .31329 .29564 L .32702 .30225 L p F P
0 g
s
.811 .699 .741 r
.31406 .34619 m .31777 .34146 L .30886 .33727 L closepath p F P
0 g
s
.811 .699 .741 r
.30603 .3324 m .31581 .31849 L p .31777 .34146 L F P
0 g
s
.811 .699 .741 r
.31777 .34146 m .30886 .33727 L .30603 .3324 L p F P
0 g
s
.619 .698 .901 r
.5496 .40383 m .57788 .39742 L .58518 .40735 L p F P
0 g
s
.603 .639 .859 r
.57051 .3862 m .57788 .39742 L .5496 .40383 L p F P
0 g
s
.603 .639 .859 r
.55892 .38831 m .57051 .3862 L p .5496 .40383 L F P
0 g
s
.603 .639 .859 r
.5496 .40383 m .54585 .39753 L .55892 .38831 L p F P
0 g
s
.775 .923 .934 r
.67498 .32098 m .6688 .32525 L .66205 .32135 L p F P
0 g
s
.713 .905 .964 r
.63361 .33548 m .66205 .32135 L .6688 .32525 L p F P
0 g
s
.905 .738 .664 r
.31599 .23475 m .3254 .24303 L .31961 .25733 L p F P
0 g
s
.91 .727 .643 r
.3254 .24303 m .31599 .23475 L .32097 .22078 L p F P
0 g
s
.6 .614 .837 r
.50657 .38236 m .53467 .37745 L .54216 .3914 L p F P
0 g
s
.587 .565 .796 r
.52957 .36686 m .53467 .37745 L .50657 .38236 L p F P
0 g
s
.587 .565 .796 r
.50657 .38236 m .50565 .38027 L .52957 .36686 L p F P
0 g
s
0 0 0 r
.6898 .16029 m .68944 .16428 L .68885 .17497 L p F P
0 g
s
.914 .98 .758 r
.66729 .22386 m .6743 .21421 L .67223 .22329 L closepath p F P
0 g
s
.919 .947 .601 r
.68236 .19896 m .6743 .21421 L .67223 .22329 L p F P
0 g
s
.388 .356 .701 r
.49764 .24253 m .4967 .23902 L .49916 .24062 L closepath p F P
0 g
s
0 0 .077 r
.8261 .17196 m .82395 .18368 L .82315 .1966 L p F P
0 g
s
0 0 .208 r
.82395 .18368 m .8261 .17196 L .82566 .1595 L p F P
0 g
s
.571 .46 .689 r
.47051 .27785 m .47521 .29577 L .46192 .3017 L p F P
0 g
s
.574 .475 .704 r
.47628 .29977 m .46192 .3017 L .47521 .29577 L closepath p F P
0 g
s
.824 .985 .709 r
.71952 .28111 m .72216 .27586 L .72466 .27472 L closepath p F P
0 g
s
.778 .728 .806 r
.28085 .37884 m .25825 .3968 L .24984 .38714 L p F P
0 g
s
.682 .794 .329 r
.79719 .27933 m .79803 .27736 L .80494 .2623 L p F P
0 g
s
.737 .829 .372 r
.80932 .25023 m .80494 .2623 L .79803 .27736 L p F P
0 g
s
.583 .565 .799 r
.52713 .36185 m .52957 .36686 L .50565 .38027 L p F P
0 g
s
.583 .565 .799 r
.50565 .38027 m .49902 .36541 L .52713 .36185 L p F P
0 g
s
.809 .98 .895 r
.71396 .37016 m .71944 .37136 L .73374 .3598 L p F P
0 g
s
.407 .382 .72 r
.49916 .24062 m .49764 .24253 L .50317 .26133 L p F P
0 g
s
.516 .481 .757 r
.53326 .28926 m .51181 .2868 L .50998 .28159 L p F P
0 g
s
.651 .793 .951 r
.62943 .33144 m .61978 .34078 L p .59808 .33778 L F P
0 g
s
.679 .806 .943 r
.61978 .34078 m .62943 .33144 L .63361 .33548 L closepath p F P
0 g
s
.781 .69 .764 r
.30081 .35965 m .31406 .34619 L .30886 .33727 L p F P
0 g
s
.775 .923 .934 r
.66205 .32135 m .68287 .30788 L .67498 .32098 L p F P
0 g
s
.796 .974 .908 r
.69043 .30254 m .68287 .30788 L .67498 .32098 L p F P
0 g
s
.796 .974 .908 r
.67498 .32098 m .69694 .30427 L .69043 .30254 L p F P
0 g
s
.466 .446 .752 r
.50998 .28159 m .50426 .26483 L .52107 .26956 L closepath p F P
0 g
s
.516 .481 .757 r
.50998 .28159 m .52107 .26956 L p .53326 .28926 L F P
0 g
s
.839 .699 .708 r
.32307 .2799 m .32684 .27365 L .31888 .25903 L p F P
0 g
s
0 0 0 r
.76096 .17446 m .75943 .18298 L .75764 .19615 L p F P
0 g
s
0 0 .151 r
.75943 .18298 m .76096 .17446 L .76079 .16311 L p F P
0 g
s
.606 .636 .854 r
.58245 .25875 m .57523 .26018 L .56786 .24727 L p F P
0 g
s
.627 .708 .904 r
.59808 .33778 m .58791 .34031 L .59456 .33304 L closepath p F P
0 g
s
.628 .669 .87 r
.59083 .32802 m .59456 .33304 L .58791 .34031 L p F P
0 g
s
.628 .669 .87 r
.56243 .33334 m .59083 .32802 L p .58791 .34031 L F P
0 g
s
.832 .999 .817 r
.75475 .34026 m .76225 .32755 L p .74205 .34807 L F P
0 g
s
.832 .999 .817 r
.74205 .34807 m .74747 .34766 L .75475 .34026 L p F P
0 g
s
.798 .989 .739 r
.76928 .31974 m .77309 .31801 L p .75475 .34026 L F P
0 g
s
.798 .989 .739 r
.75475 .34026 m .76225 .32755 L .76928 .31974 L p F P
0 g
s
0 0 .118 r
.76137 .15867 m .76079 .16311 L .76096 .17446 L p F P
0 g
s
.571 .657 .895 r
.59083 .32802 m .56243 .33334 L .55502 .32038 L p F P
0 g
s
0 0 .421 r
.49542 .1705 m .49339 .18277 L .4974 .19369 L p F P
0 g
s
0 0 .257 r
.49542 .1705 m .49865 .18172 L p .49688 .17423 L F P
0 g
s
0 0 .263 r
.49542 .1705 m .49428 .15864 L p .49397 .1668 L F P
0 g
s
.806 .589 .029 r
.49244 .14758 m .49428 .15864 L .49542 .1705 L p F P
0 g
s
.806 .589 .029 r
.4934 .15953 m .49244 .14758 L p .49367 .15699 L F P
0 g
s
.806 .589 .029 r
.49542 .1705 m .4934 .15953 L p .49367 .15699 L F P
0 g
s
.845 .517 0 r
.4934 .15953 m .492 .15643 L .49331 .16036 L p F P
0 g
s
0 0 .257 r
.4934 .15953 m .49542 .1705 L p .49688 .17423 L F P
0 g
s
0 0 .257 r
.49434 .16343 m .4934 .15953 L p .49463 .16472 L F P
0 g
s
0 0 .257 r
.49865 .18172 m .49434 .16343 L .49463 .16472 L F
.845 .517 0 r
.49331 .16036 m .49434 .16343 L .4934 .15953 L p F P
0 g
s
0 0 .291 r
.49434 .16343 m .492 .15643 L p .49412 .16247 L F P
0 g
s
0 0 .291 r
.49698 .17064 m .49434 .16343 L p .49412 .16247 L F P
0 g
s
0 0 .263 r
.49339 .18277 m .49542 .1705 L p .49397 .1668 L F P
0 g
s
.847 .996 .832 r
.72216 .27586 m .71952 .28111 L .70208 .29951 L p F P
0 g
s
.809 .98 .895 r
.73374 .3598 m .74205 .34807 L p .71396 .37016 L F P
0 g
s
.783 .998 .837 r
.73374 .3598 m .74205 .34807 L .74747 .34766 L closepath p F P
0 g
s
.476 .435 .733 r
.50317 .26133 m .51359 .2483 L p .52107 .26956 L F P
0 g
s
.476 .435 .733 r
.52107 .26956 m .50426 .26483 L .50317 .26133 L p F P
0 g
s
.407 .382 .72 r
.50317 .26133 m .51359 .2483 L .49916 .24062 L p F P
0 g
s
.827 .859 .407 r
.75105 .22193 m .75401 .21001 L p .74549 .23609 L F P
0 g
s
.827 .859 .407 r
.74549 .23609 m .74567 .23579 L .75105 .22193 L p F P
0 g
s
.701 .717 .193 r
.75105 .22193 m .75401 .21001 L .75764 .19615 L p F P
0 g
s
.802 .711 .764 r
.30081 .35965 m .28598 .37485 L .27774 .36364 L p F P
0 g
s
.802 .711 .764 r
.27774 .36364 m .28723 .35313 L .30081 .35965 L p F P
0 g
s
.781 .69 .764 r
.30355 .33513 m .28723 .35313 L .30081 .35965 L p F P
0 g
s
.781 .69 .764 r
.30886 .33727 m .30355 .33513 L p .30081 .35965 L F P
0 g
s
0 0 0 r
.818 .22184 m .82107 .20999 L p .81538 .23262 L F P
0 g
s
0 0 0 r
.81538 .23262 m .81649 .22794 L .818 .22184 L p F P
0 g
s
0 0 0 r
.818 .22184 m .82107 .20999 L .82315 .1966 L p F P
0 g
s
.698 .887 .967 r
.66675 .39632 m .65614 .40151 L .64925 .39616 L p F P
0 g
s
.669 .846 .967 r
.62074 .40686 m .64925 .39616 L .65614 .40151 L p F P
0 g
s
.608 .745 .942 r
.15158 .40562 m .17801 .39926 L .1868 .40735 L p F P
0 g
s
.61 .745 .941 r
.17801 .39926 m .15158 .40562 L .14266 .39761 L p F P
0 g
s
.778 .728 .806 r
.24984 .38714 m .26726 .37236 L .28085 .37884 L p F P
0 g
s
.764 .721 .813 r
.27774 .36364 m .26726 .37236 L .28085 .37884 L p F P
0 g
s
.764 .721 .813 r
.28085 .37884 m .28598 .37485 L .27774 .36364 L p F P
0 g
s
.804 .773 .824 r
.24596 .31954 m .23538 .32884 L .22681 .32024 L p F P
0 g
s
.477 .389 .677 r
.46646 .26068 m .4792 .24858 L p .47573 .2735 L F P
0 g
s
.477 .389 .677 r
.47573 .2735 m .46874 .27086 L .46646 .26068 L p F P
0 g
s
.413 .338 .663 r
.46646 .26068 m .4792 .24858 L .46723 .24014 L p F P
0 g
s
.85 .768 .77 r
.26698 .30001 m .25792 .29174 L .27138 .27475 L p F P
0 g
s
.849 .768 .773 r
.26698 .30001 m .26324 .3046 L .25478 .29563 L p F P
0 g
s
.849 .768 .773 r
.25478 .29563 m .25792 .29174 L .26698 .30001 L p F P
0 g
s
.804 .773 .824 r
.22681 .32024 m .23683 .31134 L .24596 .31954 L p F P
0 g
s
.799 .77 .826 r
.25478 .29563 m .23683 .31134 L .24596 .31954 L p F P
0 g
s
.799 .77 .826 r
.24596 .31954 m .26324 .3046 L .25478 .29563 L p F P
0 g
s
.358 .391 .76 r
.50822 .22629 m .49916 .24062 L .51359 .2483 L p F P
0 g
s
.404 .353 .687 r
.49849 .21712 m .50822 .22629 L .49916 .24062 L p F P
0 g
s
.855 .717 .71 r
.31111 .2726 m .32307 .2799 L .31329 .29564 L p F P
0 g
s
.839 .699 .708 r
.31888 .25903 m .31111 .2726 L .32307 .2799 L p F P
0 g
s
0 0 .51 r
.5318 .16951 m .53074 .18139 L .53674 .19169 L p F P
0 g
s
0 0 .439 r
.5318 .16951 m .53664 .18023 L p .53325 .16962 L F P
0 g
s
0 0 .282 r
.5318 .16951 m .53002 .15783 L p .53037 .1694 L F P
0 g
s
.763 .536 0 r
.52821 .14681 m .53002 .15783 L .5318 .16951 L p F P
0 g
s
.763 .536 0 r
.5318 .16951 m .52972 .15861 L .52821 .14681 L p F P
0 g
s
0 0 .439 r
.52972 .15861 m .5318 .16951 L p .53325 .16962 L F P
0 g
s
0 0 .282 r
.53074 .18139 m .5318 .16951 L p .53037 .1694 L F P
0 g
s
.847 .996 .832 r
.71851 .2764 m .72216 .27586 L p .70208 .29951 L F P
0 g
s
.847 .996 .832 r
.70208 .29951 m .70815 .28691 L .71851 .2764 L p F P
0 g
s
.834 .977 .881 r
.70208 .29951 m .69694 .30427 L .69043 .30254 L p F P
0 g
s
.834 .977 .881 r
.69043 .30254 m .70815 .28691 L .70208 .29951 L p F P
0 g
s
.379 .343 .693 r
.48001 .22447 m .46723 .24014 L .4792 .24858 L p F P
0 g
s
.418 .318 .634 r
.47224 .21468 m .48001 .22447 L .46723 .24014 L p F P
0 g
s
.638 .766 .94 r
.58518 .40735 m .61363 .39925 L .62074 .40686 L p F P
0 g
s
.622 .731 .925 r
.61363 .39925 m .58518 .40735 L .57788 .39742 L p F P
0 g
s
.604 .642 .861 r
.54585 .39753 m .54216 .3914 L .55892 .38831 L closepath p F P
0 g
s
.755 .877 .459 r
.79634 .28047 m .79803 .27736 L .79719 .27933 L closepath p F P
0 g
s
0 0 .213 r
.47081 .15516 m .47012 .16111 L .47094 .17442 L p F P
0 g
s
0 0 .252 r
.47015 .17926 m .47094 .17442 L .47012 .16111 L p F P
0 g
s
.834 .702 .718 r
.31581 .31849 m .30603 .3324 L .29791 .31963 L p F P
0 g
s
.834 .702 .718 r
.29791 .31963 m .30316 .31154 L .31581 .31849 L p F P
0 g
s
.835 .701 .715 r
.31581 .31849 m .30316 .31154 L .31329 .29564 L p F P
0 g
s
.754 .759 .856 r
.23719 .39488 m .22241 .40416 L .2138 .39557 L p F P
0 g
s
.693 .756 .9 r
.1868 .40735 m .2138 .39557 L .22241 .40416 L p F P
0 g
s
.684 .834 .955 r
.62624 .25534 m .61085 .26284 L .60368 .2544 L p F P
0 g
s
.563 .53 .776 r
.51956 .34453 m .52713 .36185 L .49902 .36541 L p F P
0 g
s
.563 .53 .776 r
.51362 .34489 m .51956 .34453 L p .49902 .36541 L F P
0 g
s
.563 .53 .776 r
.49902 .36541 m .49544 .35635 L .51362 .34489 L p F P
0 g
s
.467 .399 .697 r
.47051 .27785 m .46874 .27086 L .47573 .2735 L closepath p F P
0 g
s
.656 .808 .957 r
.64925 .39616 m .62074 .40686 L .61363 .39925 L p F P
0 g
s
.821 .983 .702 r
.76928 .31974 m .7772 .30984 L .77309 .31801 L closepath p F P
0 g
s
.802 .953 .616 r
.78881 .2932 m .7772 .30984 L .77309 .31801 L p F P
0 g
s
0 0 0 r
.68885 .17497 m .68902 .17301 L .6898 .16029 L p F P
0 g
s
.761 .647 .089 r
.68999 .14887 m .6898 .16029 L .68902 .17301 L p F P
0 g
s
.564 .635 .88 r
.58245 .25875 m .60368 .2544 L .59644 .24476 L p F P
0 g
s
.564 .635 .88 r
.59644 .24476 m .58923 .24546 L .58245 .25875 L p F P
0 g
s
.606 .636 .854 r
.56786 .24727 m .58923 .24546 L .58245 .25875 L p F P
0 g
s
.697 .761 .901 r
.2138 .39557 m .1868 .40735 L .17801 .39926 L p F P
0 g
s
0 0 0 r
.81444 .23575 m .81538 .23262 L .81649 .22794 L closepath p F P
0 g
s
.792 .693 .756 r
.30886 .33727 m .30603 .3324 L .30355 .33513 L closepath p F P
0 g
s
.698 .887 .967 r
.6788 .38376 m .66675 .39632 L p .64925 .39616 L F P
0 g
s
.72 .9 .96 r
.66675 .39632 m .6788 .38376 L .6846 .3873 L closepath p F P
0 g
s
.472 .407 .703 r
.47573 .2735 m .47051 .27785 L .47521 .29577 L p F P
0 g
s
0 0 .432 r
.47094 .17442 m .47015 .17926 L .47321 .1905 L p F P
0 g
s
.928 .959 .645 r
.68478 .18697 m .68236 .19896 L .6743 .21421 L p F P
0 g
s
.816 .823 .346 r
.68789 .17745 m .68885 .17497 L p .68236 .19896 L F P
0 g
s
.816 .823 .346 r
.68236 .19896 m .68478 .18697 L .68789 .17745 L p F P
0 g
s
.725 .819 .923 r
.62943 .33144 m .63361 .33548 L .66205 .32135 L p F P
0 g
s
0 0 .162 r
.82638 .15365 m .82566 .1595 L .8261 .17196 L p F P
0 g
s
.651 .793 .951 r
.59808 .33778 m .62658 .32862 L .62943 .33144 L p F P
0 g
s
.631 .71 .903 r
.61945 .32057 m .62658 .32862 L .59808 .33778 L p F P
0 g
s
.631 .71 .903 r
.60341 .32474 m .61945 .32057 L p .59808 .33778 L F P
0 g
s
.631 .71 .903 r
.59808 .33778 m .59456 .33304 L .60341 .32474 L p F P
0 g
s
.563 .531 .777 r
.49544 .35635 m .49144 .34626 L .51362 .34489 L closepath p F P
0 g
s
.817 .915 .519 r
.79803 .27736 m .80254 .26529 L p .79256 .2846 L F P
0 g
s
.817 .915 .519 r
.79256 .2846 m .79634 .28047 L .79803 .27736 L p F P
0 g
s
.901 .74 .672 r
.31888 .25903 m .31961 .25733 L .31331 .25167 L closepath p F P
0 g
s
.905 .738 .664 r
.31069 .24816 m .31599 .23475 L p .31961 .25733 L F P
0 g
s
.905 .738 .664 r
.31961 .25733 m .31331 .25167 L .31069 .24816 L p F P
0 g
s
0 0 .118 r
.76096 .17446 m .76138 .17121 L .76137 .15867 L p F P
0 g
s
0 0 .066 r
.76215 .14716 m .76137 .15867 L .76138 .17121 L p F P
0 g
s
.742 .75 .859 r
.24136 .37774 m .2259 .38764 L .23719 .39488 L p F P
0 g
s
.742 .75 .859 r
.23719 .39488 m .24984 .38714 L .24136 .37774 L p F P
0 g
s
.754 .759 .856 r
.2138 .39557 m .2259 .38764 L .23719 .39488 L p F P
0 g
s
.78 .909 .519 r
.78881 .2932 m .79256 .2846 L .79634 .28047 L closepath p F P
0 g
s
.875 .744 .714 r
.31111 .2726 m .31888 .25903 L .31331 .25167 L p F P
0 g
s
.604 .616 .836 r
.55892 .38831 m .54216 .3914 L .53467 .37745 L p F P
0 g
s
.206 .275 .714 r
.50349 .20401 m .49849 .21712 L .50822 .22629 L p F P
0 g
s
.127 .148 .612 r
.49849 .21712 m .50349 .20401 L .4974 .19369 L p F P
0 g
s
.8 .709 .764 r
.30355 .33513 m .30603 .3324 L .29791 .31963 L p F P
0 g
s
.564 .509 .752 r
.51362 .34489 m .49144 .34626 L .48742 .33477 L p F P
0 g
s
.774 .847 .395 r
.74536 .23648 m .74549 .23609 L .74567 .23579 L closepath p F P
0 g
s
.472 .407 .703 r
.47521 .29577 m .49442 .27994 L .47573 .2735 L p F P
0 g
s
.515 .438 .707 r
.47521 .29577 m .49442 .27994 L p .49671 .30297 L F P
0 g
s
.515 .438 .707 r
.49671 .30297 m .47628 .29977 L .47521 .29577 L p F P
0 g
s
.821 .731 .766 r
.29045 .32835 m .30355 .33513 L .28723 .35313 L p F P
0 g
s
.8 .709 .764 r
.29791 .31963 m .29045 .32835 L .30355 .33513 L p F P
0 g
s
.849 .938 .566 r
.74549 .23609 m .74536 .23648 L .73659 .25208 L p F P
0 g
s
.86 .73 .718 r
.30195 .28816 m .31329 .29564 L .30316 .31154 L p F P
0 g
s
.855 .717 .71 r
.31329 .29564 m .30195 .28816 L .31111 .2726 L p F P
0 g
s
.874 .994 .776 r
.71851 .2764 m .72493 .26866 L .72216 .27586 L closepath p F P
0 g
s
.878 .981 .691 r
.73659 .25208 m .72493 .26866 L .72216 .27586 L p F P
0 g
s
.51 .453 .729 r
.48083 .31474 m .47628 .29977 L .49671 .30297 L closepath p F P
0 g
s
.564 .509 .752 r
.48742 .33477 m .50171 .32506 L p .51362 .34489 L F P
0 g
s
.54 .494 .754 r
.48742 .33477 m .48385 .32456 L .50171 .32506 L closepath p F P
0 g
s
.883 .936 .562 r
.74838 .22458 m .74549 .23609 L .74032 .24082 L p F P
0 g
s
.849 .938 .566 r
.73659 .25208 m .74032 .24082 L .74549 .23609 L p F P
0 g
s
.827 .859 .407 r
.75401 .21001 m .74838 .22458 L .74549 .23609 L p F P
0 g
s
0 0 0 r
.82534 .18489 m .82315 .1966 L .82107 .20999 L p F P
0 g
s
0 0 .077 r
.82315 .1966 m .82534 .18489 L .8261 .17196 L p F P
0 g
s
.542 .475 .73 r
.48083 .31474 m .49671 .30297 L p .50171 .32506 L F P
0 g
s
.542 .475 .73 r
.50171 .32506 m .48385 .32456 L .48083 .31474 L p F P
0 g
s
.565 .597 .844 r
.58923 .24546 m .56786 .24727 L .56043 .23319 L p F P
0 g
s
.734 .784 .294 r
.81538 .23262 m .81444 .23575 L .80932 .25023 L p F P
0 g
s
.549 .582 .84 r
.5761 .30496 m .5835 .31704 L .55502 .32038 L p F P
0 g
s
.549 .582 .84 r
.55567 .30564 m .5761 .30496 L p .55502 .32038 L F P
0 g
s
.549 .582 .84 r
.55502 .32038 m .55044 .31152 L .55567 .30564 L p F P
0 g
s
.571 .657 .895 r
.55502 .32038 m .5835 .31704 L .59083 .32802 L p F P
0 g
s
0 0 0 r
.75989 .18343 m .76096 .17446 L p .75764 .19615 L F P
0 g
s
0 0 0 r
.75764 .19615 m .75977 .18436 L .75989 .18343 L p F P
0 g
s
.776 .765 .255 r
.75977 .18436 m .75764 .19615 L .75401 .21001 L p F P
0 g
s
.684 .834 .955 r
.63343 .24385 m .62624 .25534 L p .60368 .2544 L F P
0 g
s
.738 .864 .94 r
.62624 .25534 m .63343 .24385 L .6392 .24841 L closepath p F P
0 g
s
.792 .744 .809 r
.26726 .37236 m .24984 .38714 L .24136 .37774 L p F P
0 g
s
.735 .963 .939 r
.6846 .3873 m .71305 .36988 L .71396 .37016 L p F P
0 g
s
.765 .907 .938 r
.6788 .38376 m .6846 .3873 L .71305 .36988 L p F P
0 g
s
.821 .731 .766 r
.28723 .35313 m .27774 .36364 L .26941 .35301 L p F P
0 g
s
.821 .731 .766 r
.26941 .35301 m .27543 .34596 L .28723 .35313 L p F P
0 g
s
.821 .731 .766 r
.28723 .35313 m .27543 .34596 L .29045 .32835 L p F P
0 g
s
.236 .233 .652 r
.47667 .20596 m .47224 .21468 L .48001 .22447 L p F P
0 g
s
.192 .18 .615 r
.47387 .19204 m .47321 .1905 L p .47224 .21468 L F P
0 g
s
.192 .18 .615 r
.47224 .21468 m .47667 .20596 L .47387 .19204 L p F P
0 g
s
.631 .71 .903 r
.59456 .33304 m .59083 .32802 L .60341 .32474 L closepath p F P
0 g
s
.863 .816 .334 r
.68789 .17745 m .68902 .17301 L .68885 .17497 L closepath p F P
0 g
s
.728 .461 0 r
.4718 .16705 m .47467 .17838 L p .47294 .17119 L F P
0 g
s
0 0 .213 r
.4718 .16705 m .47081 .15516 L p .47087 .16366 L F P
0 g
s
.847 .617 .075 r
.46845 .14422 m .47081 .15516 L .4718 .16705 L p F P
0 g
s
.847 .617 .075 r
.4718 .16705 m .46931 .15617 L .46845 .14422 L p F P
0 g
s
.728 .461 0 r
.46931 .15617 m .4718 .16705 L p .47294 .17119 L F P
0 g
s
0 0 .213 r
.47094 .17442 m .4718 .16705 L p .47087 .16366 L F P
0 g
s
.792 .744 .809 r
.24136 .37774 m .25542 .36523 L .26726 .37236 L p F P
0 g
s
.779 .735 .813 r
.26941 .35301 m .25542 .36523 L .26726 .37236 L p F P
0 g
s
.779 .735 .813 r
.26726 .37236 m .27774 .36364 L .26941 .35301 L p F P
0 g
s
.461 .418 .724 r
.49037 .25938 m .47573 .2735 L .49442 .27994 L p F P
0 g
s
.477 .389 .677 r
.48905 .25476 m .49037 .25938 L .47573 .2735 L p F P
0 g
s
.477 .389 .677 r
.4792 .24858 m .48905 .25476 L p .47573 .2735 L F P
0 g
s
.826 .965 .642 r
.79256 .2846 m .78881 .2932 L .7772 .30984 L p F P
0 g
s
.928 .952 .782 r
.6743 .21421 m .67631 .2024 L p .6627 .22303 L F P
0 g
s
.928 .952 .782 r
.6627 .22303 m .66729 .22386 L .6743 .21421 L p F P
0 g
s
.928 .959 .645 r
.6743 .21421 m .67631 .2024 L .68478 .18697 L p F P
0 g
s
0 0 0 r
.75989 .18343 m .76138 .17121 L .76096 .17446 L closepath p F P
0 g
s
0 0 .396 r
.4718 .16705 m .47094 .17442 L .47335 .18965 L p F P
0 g
s
0 0 .432 r
.47321 .1905 m .47335 .18965 L .47094 .17442 L p F P
0 g
s
0 .053 .595 r
.49865 .18172 m .4974 .19369 L .50349 .20401 L p F P
0 g
s
0 0 .421 r
.4974 .19369 m .49865 .18172 L .49542 .1705 L p F P
0 g
s
.88 .753 .718 r
.30159 .2644 m .31111 .2726 L .30195 .28816 L p F P
0 g
s
.875 .744 .714 r
.31021 .24905 m .30159 .2644 L .31111 .2726 L p F P
0 g
s
.875 .744 .714 r
.31331 .25167 m .31021 .24905 L p .31111 .2726 L F P
0 g
s
.824 .874 .882 r
.63343 .24385 m .6392 .24841 L .65958 .23171 L p F P
0 g
s
0 0 .151 r
.827 .14791 m .82638 .15365 L .82694 .16522 L p F P
0 g
s
0 0 .162 r
.8261 .17196 m .82694 .16522 L .82638 .15365 L p F P
0 g
s
.395 .472 .822 r
.55294 .21741 m .54437 .21291 L p .55712 .23239 L F P
0 g
s
.301 .409 .805 r
.55294 .21741 m .54437 .21291 L .54579 .20163 L closepath p F P
0 g
s
.218 .326 .761 r
.54541 .20068 m .53674 .19169 L p .54437 .21291 L F P
0 g
s
.218 .326 .761 r
.54437 .21291 m .54579 .20163 L .54541 .20068 L p F P
0 g
s
.696 .807 .934 r
.62658 .32862 m .63198 .32633 L .62943 .33144 L closepath p F P
0 g
s
.725 .819 .923 r
.65518 .31617 m .63198 .32633 L .62943 .33144 L p F P
0 g
s
.725 .819 .923 r
.66205 .32135 m .65518 .31617 L p .62943 .33144 L F P
0 g
s
0 0 0 r
.82107 .20999 m .81767 .22389 L .81538 .23262 L p F P
0 g
s
.76 .793 .302 r
.81767 .22389 m .81538 .23262 L .81244 .23977 L p F P
0 g
s
.734 .784 .294 r
.80932 .25023 m .81244 .23977 L .81538 .23262 L p F P
0 g
s
.858 .731 .721 r
.30316 .31154 m .29791 .31963 L .28966 .30831 L p F P
0 g
s
.858 .731 .721 r
.28966 .30831 m .2924 .30388 L .30316 .31154 L p F P
0 g
s
.86 .73 .718 r
.30316 .31154 m .2924 .30388 L .30195 .28816 L p F P
0 g
s
.548 .581 .839 r
.55044 .31152 m .54755 .30592 L .55567 .30564 L closepath p F P
0 g
s
.428 .508 .838 r
.56043 .23319 m .55712 .23239 L .55817 .22864 L closepath p F P
0 g
s
.395 .472 .822 r
.55712 .23239 m .55817 .22864 L .55294 .21741 L p F P
0 g
s
.622 .731 .925 r
.57788 .39742 m .60643 .39051 L .61363 .39925 L p F P
0 g
s
.603 .697 .91 r
.60643 .39051 m .57788 .39742 L .57051 .3862 L p F P
0 g
s
.888 .985 .715 r
.74032 .24082 m .73659 .25208 L .72493 .26866 L p F P
0 g
s
.61 .745 .941 r
.14266 .39761 m .16916 .39111 L .17801 .39926 L p F P
0 g
s
.931 .85 .41 r
.68902 .17301 m .68919 .16163 L p .68547 .18212 L F P
0 g
s
.931 .85 .41 r
.68547 .18212 m .68789 .17745 L .68902 .17301 L p F P
0 g
s
.761 .647 .089 r
.68902 .17301 m .68919 .16163 L .68999 .14887 L p F P
0 g
s
.867 .978 .85 r
.65958 .23171 m .6627 .22303 L .66729 .22386 L closepath p F P
0 g
s
.881 .742 .703 r
.31331 .25167 m .31069 .24816 L .31021 .24905 L closepath p F P
0 g
s
.785 .969 .918 r
.71305 .36988 m .71523 .36831 L .71396 .37016 L closepath p F P
0 g
s
.809 .98 .895 r
.74135 .34803 m .71523 .36831 L .71396 .37016 L p F P
0 g
s
.809 .98 .895 r
.74205 .34807 m .74135 .34803 L p .71396 .37016 L F P
0 g
s
.752 .924 .947 r
.68287 .30788 m .66205 .32135 L .65518 .31617 L p F P
0 g
s
.824 .874 .882 r
.65958 .23171 m .6627 .22303 L p .63343 .24385 L F P
0 g
s
.604 .616 .836 r
.53467 .37745 m .56308 .37371 L p .55892 .38831 L F P
0 g
s
.563 .571 .82 r
.55558 .35995 m .56308 .37371 L .53467 .37745 L p F P
0 g
s
.563 .571 .82 r
.53665 .36119 m .55558 .35995 L p .53467 .37745 L F P
0 g
s
.563 .571 .82 r
.53467 .37745 m .52957 .36686 L .53665 .36119 L p F P
0 g
s
0 0 .021 r
.82694 .16522 m .8261 .17196 L .82534 .18489 L p F P
0 g
s
0 .135 .659 r
.53674 .19169 m .54541 .20068 L .53783 .18179 L p F P
0 g
s
0 .135 .659 r
.53783 .18179 m .53664 .18023 L .53674 .19169 L p F P
0 g
s
0 0 .51 r
.53674 .19169 m .53664 .18023 L .5318 .16951 L p F P
0 g
s
.761 .768 .859 r
.2259 .38764 m .2138 .39557 L .20511 .3871 L p F P
0 g
s
.697 .761 .901 r
.17801 .39926 m .20511 .3871 L .2138 .39557 L p F P
0 g
s
.698 .887 .967 r
.64925 .39616 m .67788 .38317 L .6788 .38376 L p F P
0 g
s
.684 .856 .965 r
.67788 .38317 m .64925 .39616 L .64227 .3897 L p F P
0 g
s
.656 .808 .957 r
.61363 .39925 m .64227 .3897 L .64925 .39616 L p F P
0 g
s
.864 .993 .747 r
.7772 .30984 m .7826 .29759 L p .76599 .32057 L F P
0 g
s
.864 .993 .747 r
.76599 .32057 m .76928 .31974 L .7772 .30984 L p F P
0 g
s
.826 .965 .642 r
.79089 .28574 m .79256 .2846 L p .7772 .30984 L F P
0 g
s
.826 .965 .642 r
.7772 .30984 m .7826 .29759 L .79089 .28574 L p F P
0 g
s
.822 .734 .767 r
.29045 .32835 m .29791 .31963 L .28966 .30831 L p F P
0 g
s
0 0 .066 r
.76138 .17121 m .76218 .15971 L .76215 .14716 L p F P
0 g
s
.762 .682 .135 r
.76138 .17121 m .76218 .15971 L p .7598 .18409 L F P
0 g
s
.762 .682 .135 r
.7598 .18409 m .75989 .18343 L .76138 .17121 L p F P
0 g
s
.684 .834 .955 r
.60368 .2544 m .63223 .2428 L .63343 .24385 L p F P
0 g
s
.647 .79 .951 r
.63223 .2428 m .60368 .2544 L .59644 .24476 L p F P
0 g
s
.801 .868 .427 r
.81244 .23977 m .80932 .25023 L .80254 .26529 L p F P
0 g
s
.551 .562 .819 r
.55567 .30564 m .54755 .30592 L .54004 .28998 L p F P
0 g
s
.867 .853 .396 r
.68478 .18697 m .68547 .18212 L .68789 .17745 L closepath p F P
0 g
s
.699 .767 .904 r
.20511 .3871 m .17801 .39926 L .16916 .39111 L p F P
0 g
s
.631 .684 .882 r
.60341 .32474 m .59083 .32802 L .5835 .31704 L p F P
0 g
s
.639 .773 .945 r
.64227 .3897 m .61363 .39925 L .60643 .39051 L p F P
0 g
s
.565 .597 .844 r
.56043 .23319 m .58912 .23413 L p .58923 .24546 L F P
0 g
s
.478 .536 .838 r
.58173 .22247 m .58912 .23413 L .56043 .23319 L p F P
0 g
s
.478 .536 .838 r
.56237 .21936 m .58173 .22247 L p .56043 .23319 L F P
0 g
s
.478 .536 .838 r
.56043 .23319 m .55817 .22864 L .56237 .21936 L p F P
0 g
s
.603 .64 .86 r
.57051 .3862 m .55892 .38831 L .56796 .38188 L closepath p F P
0 g
s
.604 .616 .836 r
.56308 .37371 m .56796 .38188 L .55892 .38831 L p F P
0 g
s
.784 .948 .928 r
.71523 .36831 m .71305 .36988 L .70652 .36701 L p F P
0 g
s
.765 .907 .938 r
.71305 .36988 m .70652 .36701 L p .6788 .38376 L F P
0 g
s
0 0 .535 r
.47387 .19204 m .47321 .1905 L .47335 .18965 L closepath p F P
0 g
s
.516 .481 .757 r
.52107 .26956 m .53248 .27252 L p .53326 .28926 L F P
0 g
s
.453 .474 .79 r
.53248 .27252 m .52107 .26956 L .52739 .26001 L closepath p F P
0 g
s
.476 .435 .733 r
.52489 .25367 m .52739 .26001 L .52107 .26956 L p F P
0 g
s
.476 .435 .733 r
.51359 .2483 m .52489 .25367 L p .52107 .26956 L F P
0 g
s
.516 .481 .757 r
.53248 .27252 m .5375 .28418 L .53326 .28926 L p F P
0 g
s
.504 .519 .806 r
.54004 .28998 m .53326 .28926 L .5375 .28418 L closepath p F P
0 g
s
.784 .948 .928 r
.70652 .36701 m .72324 .35547 L .71523 .36831 L p F P
0 g
s
.792 .984 .899 r
.73506 .34673 m .72324 .35547 L .71523 .36831 L p F P
0 g
s
.792 .984 .899 r
.71523 .36831 m .74135 .34803 L .73506 .34673 L p F P
0 g
s
.868 .88 .445 r
.75616 .19824 m .75401 .21001 L .74838 .22458 L p F P
0 g
s
.776 .765 .255 r
.75401 .21001 m .75616 .19824 L .75977 .18436 L p F P
0 g
s
0 0 0 r
.82107 .20999 m .82333 .1983 L .82534 .18489 L p F P
0 g
s
.736 .729 .205 r
.82333 .1983 m .82107 .20999 L .81767 .22389 L p F P
0 g
s
.836 .751 .769 r
.27936 .32083 m .29045 .32835 L .27543 .34596 L p F P
0 g
s
.822 .734 .767 r
.28966 .30831 m .27936 .32083 L .29045 .32835 L p F P
0 g
s
.818 .996 .857 r
.74135 .34803 m .74288 .34665 L .74205 .34807 L closepath p F P
0 g
s
.832 .999 .817 r
.76225 .32755 m .74288 .34665 L .74205 .34807 L p F P
0 g
s
.761 .768 .859 r
.20511 .3871 m .21571 .37995 L .2259 .38764 L p F P
0 g
s
.751 .762 .861 r
.23279 .36873 m .21571 .37995 L .2259 .38764 L p F P
0 g
s
.751 .762 .861 r
.2259 .38764 m .24136 .37774 L .23279 .36873 L p F P
0 g
s
.824 .996 .765 r
.76225 .32755 m .76599 .32057 L .76928 .31974 L closepath p F P
0 g
s
0 .058 .569 r
.47335 .18965 m .47467 .17838 L p .47827 .20114 L F P
0 g
s
0 .058 .569 r
.47827 .20114 m .47387 .19204 L .47335 .18965 L p F P
0 g
s
0 0 .249 r
.47467 .17838 m .47896 .1893 L p .4772 .18394 L F P
0 g
s
0 0 .396 r
.47467 .17838 m .4718 .16705 L p .4722 .17296 L F P
0 g
s
.728 .461 0 r
.47185 .16762 m .46931 .15617 L p .47075 .16213 L F P
0 g
s
.728 .461 0 r
.47467 .17838 m .47185 .16762 L p .47075 .16213 L F P
0 g
s
0 0 .249 r
.47185 .16762 m .47467 .17838 L p .4772 .18394 L F P
0 g
s
0 0 .249 r
.47565 .17873 m .47185 .16762 L p .47344 .17248 L F P
0 g
s
0 0 .249 r
.47896 .1893 m .47565 .17873 L p .47344 .17248 L F P
0 g
s
0 0 .319 r
.47565 .17873 m .47896 .1893 L .48425 .19997 L p F P
0 g
s
0 0 .319 r
.48037 .18961 m .47565 .17873 L p .47739 .18303 L F P
0 g
s
0 0 .319 r
.48425 .19997 m .48037 .18961 L p .47739 .18303 L F P
0 g
s
0 0 .359 r
.48037 .18961 m .48425 .19997 L .4903 .21049 L p F P
0 g
s
0 0 .359 r
.48581 .20034 m .48037 .18961 L p .4821 .19324 L F P
0 g
s
0 0 .359 r
.4903 .21049 m .48581 .20034 L p .4821 .19324 L F P
0 g
s
0 0 .53 r
.48458 .21145 m .48425 .19997 L .47896 .1893 L p F P
0 g
s
0 0 .412 r
.48651 .20159 m .48581 .20034 L .48658 .20208 L p F P
0 g
s
0 0 .412 r
.48658 .20208 m .4903 .21049 L p .48651 .20159 L F P
0 g
s
.711 .276 0 r
.48581 .20034 m .48118 .19391 L .48632 .20132 L p F P
0 g
s
.711 .276 0 r
.48632 .20132 m .48651 .20159 L .48581 .20034 L p F P
0 g
s
.748 .318 0 r
.48037 .18961 m .48581 .20034 L p .48337 .19624 L F P
0 g
s
0 0 .396 r
.47335 .18965 m .47467 .17838 L p .4722 .17296 L F P
0 g
s
0 0 .53 r
.47896 .1893 m .47827 .20114 L .48458 .21145 L p F P
0 g
s
0 .058 .569 r
.47467 .17838 m .47896 .1893 L .47827 .20114 L p F P
0 g
s
.748 .318 0 r
.47868 .19025 m .47375 .18009 L p .48581 .20034 L F P
0 g
s
.748 .318 0 r
.48581 .20034 m .48118 .19391 L .47868 .19025 L p F P
0 g
s
0 .017 .569 r
.48651 .20159 m .48118 .19391 L p .48633 .20039 L F P
0 g
s
0 .017 .569 r
.49413 .21019 m .48651 .20159 L p .48633 .20039 L F P
0 g
s
.748 .318 0 r
.47375 .18009 m .48037 .18961 L p .48337 .19624 L F P
0 g
s
.817 .406 0 r
.47565 .17873 m .48037 .18961 L p .47787 .18502 L F P
0 g
s
.817 .406 0 r
.46923 .16913 m .47565 .17873 L p .47787 .18502 L F P
0 g
s
.869 .482 .006 r
.47185 .16762 m .47565 .17873 L p .47295 .17316 L F P
0 g
s
.869 .482 .006 r
.4656 .15797 m .47185 .16762 L p .47295 .17316 L F P
0 g
s
.897 .981 .803 r
.72493 .26866 m .72883 .25657 L p .71299 .27599 L F P
0 g
s
.897 .981 .803 r
.71299 .27599 m .71851 .2764 L .72493 .26866 L p F P
0 g
s
.888 .985 .715 r
.73986 .24102 m .74032 .24082 L p .72493 .26866 L F P
0 g
s
.888 .985 .715 r
.72493 .26866 m .72883 .25657 L .73986 .24102 L p F P
0 g
s
.39 .359 .703 r
.48905 .25476 m .4792 .24858 L .4853 .24097 L closepath p F P
0 g
s
.379 .343 .693 r
.48144 .226 m .48001 .22447 L p .4792 .24858 L F P
0 g
s
.379 .343 .693 r
.4792 .24858 m .4853 .24097 L .48144 .226 L p F P
0 g
s
.88 .758 .724 r
.29259 .27992 m .30195 .28816 L .2924 .30388 L p F P
0 g
s
.88 .753 .718 r
.30195 .28816 m .29259 .27992 L .30159 .2644 L p F P
0 g
s
.054 .085 .575 r
.47667 .20596 m .47387 .19204 L .47827 .20114 L closepath p F P
0 g
s
.675 .779 .929 r
.63198 .32633 m .62658 .32862 L .61945 .32057 L p F P
0 g
s
.752 .924 .947 r
.68693 .30094 m .68287 .30788 L p .65518 .31617 L F P
0 g
s
.792 .944 .924 r
.68287 .30788 m .68693 .30094 L .69043 .30254 L closepath p F P
0 g
s
.452 .506 .823 r
.55817 .22864 m .55294 .21741 L .56237 .21936 L closepath p F P
0 g
s
.833 .997 .84 r
.76599 .32057 m .76225 .32755 L .74288 .34665 L p F P
0 g
s
.375 .413 .772 r
.52489 .25367 m .51359 .2483 L .51872 .23746 L closepath p F P
0 g
s
.358 .391 .76 r
.51727 .23346 m .50822 .22629 L p .51359 .2483 L F P
0 g
s
.358 .391 .76 r
.51359 .2483 m .51872 .23746 L .51727 .23346 L p F P
0 g
s
.564 .574 .822 r
.52957 .36686 m .52713 .36185 L .53665 .36119 L closepath p F P
0 g
s
.831 .691 .153 r
.68942 .1376 m .68999 .14887 L .68919 .16163 L p F P
0 g
s
.854 .992 .839 r
.70815 .28691 m .71299 .27599 L .71851 .2764 L closepath p F P
0 g
s
.826 .984 .878 r
.74288 .34665 m .74135 .34803 L .73506 .34673 L p F P
0 g
s
.826 .984 .878 r
.73506 .34673 m .74943 .33418 L .74288 .34665 L p F P
0 g
s
.833 .997 .84 r
.76331 .32076 m .76599 .32057 L p .74288 .34665 L F P
0 g
s
.833 .997 .84 r
.74288 .34665 m .74943 .33418 L .76331 .32076 L p F P
0 g
s
.845 .943 .886 r
.68693 .30094 m .69043 .30254 L .70815 .28691 L p F P
0 g
s
.845 .943 .886 r
.70815 .28691 m .71299 .27599 L p .68693 .30094 L F P
0 g
s
.675 .779 .929 r
.61945 .32057 m .63773 .31379 L .63198 .32633 L p F P
0 g
s
.701 .831 .945 r
.64821 .30984 m .63773 .31379 L .63198 .32633 L p F P
0 g
s
.701 .831 .945 r
.63198 .32633 m .65518 .31617 L .64821 .30984 L p F P
0 g
s
0 0 .151 r
.82694 .16522 m .82746 .16039 L .827 .14791 L p F P
0 g
s
0 0 .105 r
.82758 .13647 m .827 .14791 L .82746 .16039 L p F P
0 g
s
.836 .751 .77 r
.27543 .34596 m .26941 .35301 L .26098 .34316 L p F P
0 g
s
.836 .751 .77 r
.26098 .34316 m .26504 .33824 L .27543 .34596 L p F P
0 g
s
.836 .751 .769 r
.27543 .34596 m .26504 .33824 L .27936 .32083 L p F P
0 g
s
.948 .663 .212 r
.4896 .14126 m .49244 .14758 L .4934 .15953 L p F P
0 g
s
.566 .553 .799 r
.53665 .36119 m .52713 .36185 L .51956 .34453 L p F P
0 g
s
.803 .76 .814 r
.25542 .36523 m .24136 .37774 L .23279 .36873 L p F P
0 g
s
.94 .963 .69 r
.68547 .18212 m .68478 .18697 L .67631 .2024 L p F P
0 g
s
.803 .76 .814 r
.23279 .36873 m .24496 .35758 L .25542 .36523 L p F P
0 g
s
.793 .753 .816 r
.26098 .34316 m .24496 .35758 L .25542 .36523 L p F P
0 g
s
.793 .753 .816 r
.25542 .36523 m .26941 .35301 L .26098 .34316 L p F P
0 g
s
0 0 .006 r
.76215 .13579 m .76215 .14716 L .76218 .15971 L p F P
0 g
s
.508 .551 .835 r
.55567 .30564 m .5761 .30496 L .56865 .29192 L p F P
0 g
s
.508 .551 .835 r
.56865 .29192 m .56502 .29167 L .55567 .30564 L p F P
0 g
s
.551 .562 .819 r
.54004 .28998 m .56502 .29167 L .55567 .30564 L p F P
0 g
s
.248 .319 .741 r
.51727 .23346 m .50822 .22629 L .51097 .21596 L closepath p F P
0 g
s
.206 .275 .714 r
.50963 .21193 m .50349 .20401 L p .50822 .22629 L F P
0 g
s
.206 .275 .714 r
.50822 .22629 m .51097 .21596 L .50963 .21193 L p F P
0 g
s
.89 .607 .096 r
.52624 .14148 m .52821 .14681 L .52972 .15861 L p F P
0 g
s
.563 .531 .777 r
.51956 .34453 m .51362 .34489 L .51848 .3418 L closepath p F P
0 g
s
.564 .509 .752 r
.51195 .32534 m .51848 .3418 L .51362 .34489 L p F P
0 g
s
.564 .509 .752 r
.50171 .32506 m .51195 .32534 L p .51362 .34489 L F P
0 g
s
.539 .5 .76 r
.51195 .32534 m .50171 .32506 L .5098 .31937 L closepath p F P
0 g
s
.542 .475 .73 r
.50432 .30411 m .5098 .31937 L .50171 .32506 L p F P
0 g
s
.542 .475 .73 r
.49671 .30297 m .50432 .30411 L p .50171 .32506 L F P
0 g
s
.518 .527 .805 r
.56502 .29167 m .54004 .28998 L .5375 .28418 L p F P
0 g
s
.105 .143 .617 r
.47827 .20114 m .47667 .20596 L .4807 .22313 L p F P
0 g
s
.236 .233 .652 r
.48001 .22447 m .4807 .22313 L .47667 .20596 L p F P
0 g
s
.817 .915 .519 r
.80254 .26529 m .7939 .281 L .79256 .2846 L p F P
0 g
s
.849 .931 .551 r
.80619 .25339 m .80254 .26529 L .7939 .281 L p F P
0 g
s
.801 .868 .427 r
.81182 .24072 m .81244 .23977 L p .80254 .26529 L F P
0 g
s
.801 .868 .427 r
.80254 .26529 m .80619 .25339 L .81182 .24072 L p F P
0 g
s
.601 .69 .905 r
.60341 .32474 m .61945 .32057 L .61223 .3115 L p F P
0 g
s
.601 .69 .905 r
.61223 .3115 m .60954 .31201 L .60341 .32474 L p F P
0 g
s
.631 .684 .882 r
.5835 .31704 m .60954 .31201 L .60341 .32474 L p F P
0 g
s
.557 .663 .908 r
.59644 .24476 m .58923 .24546 L .58979 .23512 L closepath p F P
0 g
s
.565 .597 .844 r
.58912 .23413 m .58979 .23512 L .58923 .24546 L p F P
0 g
s
.456 .502 .817 r
.56237 .21936 m .55294 .21741 L .54579 .20163 L p F P
0 g
s
.603 .697 .91 r
.57051 .3862 m .59914 .38067 L .60643 .39051 L p F P
0 g
s
.584 .631 .864 r
.59179 .36977 m .59914 .38067 L .57051 .3862 L p F P
0 g
s
.584 .631 .864 r
.57917 .37146 m .59179 .36977 L p .57051 .3862 L F P
0 g
s
.584 .631 .864 r
.57051 .3862 m .56796 .38188 L .57917 .37146 L p F P
0 g
s
.739 .896 .95 r
.67788 .38317 m .68011 .38195 L .6788 .38376 L closepath p F P
0 g
s
.765 .907 .938 r
.70652 .36701 m .68011 .38195 L .6788 .38376 L p F P
0 g
s
.848 .959 .619 r
.79089 .28574 m .7939 .281 L .79256 .2846 L closepath p F P
0 g
s
.472 .498 .804 r
.5375 .28418 m .53248 .27252 L .54394 .27472 L closepath p F P
0 g
s
.518 .527 .805 r
.5375 .28418 m .54394 .27472 L p .56502 .29167 L F P
0 g
s
0 0 .011 r
.82746 .16039 m .82694 .16522 L .82651 .17548 L p F P
0 g
s
0 0 .021 r
.82534 .18489 m .82651 .17548 L .82694 .16522 L p F P
0 g
s
.883 .936 .562 r
.74032 .24082 m .74054 .23993 L .74838 .22458 L p F P
0 g
s
.915 .947 .599 r
.75055 .21284 m .74838 .22458 L .74054 .23993 L p F P
0 g
s
.868 .88 .445 r
.74838 .22458 m .75055 .21284 L .75616 .19824 L p F P
0 g
s
.878 .759 .727 r
.2924 .30388 m .28966 .30831 L .28127 .29879 L p F P
0 g
s
.878 .759 .727 r
.28127 .29879 m .2832 .29562 L .2924 .30388 L p F P
0 g
s
.88 .758 .724 r
.2924 .30388 m .2832 .29562 L .29259 .27992 L p F P
0 g
s
.723 .671 .122 r
.82651 .17548 m .82534 .18489 L .82333 .1983 L p F P
0 g
s
.72 .663 .111 r
.75977 .18436 m .7598 .18409 L .75989 .18343 L closepath p F P
0 g
s
.262 .264 .673 r
.48144 .226 m .48001 .22447 L .4807 .22313 L closepath p F P
0 g
s
.839 .804 .314 r
.7598 .18409 m .75977 .18436 L .75616 .19824 L p F P
0 g
s
.772 .854 .911 r
.63223 .2428 m .6337 .24186 L .63343 .24385 L closepath p F P
0 g
s
.824 .874 .882 r
.66061 .22211 m .6337 .24186 L .63343 .24385 L p F P
0 g
s
.824 .874 .882 r
.6627 .22303 m .66061 .22211 L p .63343 .24385 L F P
0 g
s
.76 .793 .302 r
.81244 .23977 m .81282 .23832 L .81767 .22389 L p F P
0 g
s
.81 .822 .343 r
.82 .21222 m .81767 .22389 L .81282 .23832 L p F P
0 g
s
.736 .729 .205 r
.81767 .22389 m .82 .21222 L .82333 .1983 L p F P
0 g
s
.015 .154 .666 r
.50963 .21193 m .50349 .20401 L .50385 .19518 L closepath p F P
0 g
s
0 .053 .595 r
.50198 .18895 m .49865 .18172 L p .50349 .20401 L F P
0 g
s
0 .053 .595 r
.50349 .20401 m .50385 .19518 L .50198 .18895 L p F P
0 g
s
.867 .809 .324 r
.76059 .17288 m .7598 .18409 L .75696 .19156 L p F P
0 g
s
.762 .682 .135 r
.76218 .15971 m .76059 .17288 L .7598 .18409 L p F P
0 g
s
.839 .804 .314 r
.75616 .19824 m .75696 .19156 L .7598 .18409 L p F P
0 g
s
.728 .869 .947 r
.68011 .38195 m .67788 .38317 L .67104 .3779 L p F P
0 g
s
.684 .856 .965 r
.64227 .3897 m .67104 .3779 L .67788 .38317 L p F P
0 g
s
.508 .465 .744 r
.50432 .30411 m .49671 .30297 L .50244 .29838 L closepath p F P
0 g
s
.515 .438 .707 r
.49668 .28068 m .50244 .29838 L .49671 .30297 L p F P
0 g
s
.515 .438 .707 r
.49442 .27994 m .49668 .28068 L p .49671 .30297 L F P
0 g
s
.975 .672 .305 r
.46238 .13448 m .46845 .14422 L .46931 .15617 L p F P
0 g
s
.843 .764 .775 r
.27936 .32083 m .28966 .30831 L .28127 .29879 L p F P
0 g
s
.745 .912 .95 r
.69987 .36304 m .68869 .36893 L .68011 .38195 L p F P
0 g
s
.745 .912 .95 r
.68011 .38195 m .70652 .36701 L .69987 .36304 L p F P
0 g
s
.728 .869 .947 r
.67104 .3779 m .68869 .36893 L .68011 .38195 L p F P
0 g
s
.586 .634 .866 r
.56796 .38188 m .56308 .37371 L .57917 .37146 L closepath p F P
0 g
s
.259 .262 .673 r
.4807 .22313 m .48458 .21145 L p .48884 .23401 L F P
0 g
s
.259 .262 .673 r
.48884 .23401 m .48144 .226 L .4807 .22313 L p F P
0 g
s
.105 .143 .617 r
.4807 .22313 m .48458 .21145 L .47827 .20114 L p F P
0 g
s
.566 .553 .799 r
.51956 .34453 m .54804 .3449 L p .53665 .36119 L F P
0 g
s
.508 .499 .782 r
.54045 .32863 m .54804 .3449 L .51956 .34453 L p F P
0 g
s
.508 .499 .782 r
.53322 .32778 m .54045 .32863 L p .51956 .34453 L F P
0 g
s
.508 .499 .782 r
.51956 .34453 m .51848 .3418 L .53322 .32778 L p F P
0 g
s
.88 .939 .851 r
.66061 .22211 m .66317 .21942 L .6627 .22303 L closepath p F P
0 g
s
.928 .952 .782 r
.67631 .2024 m .66317 .21942 L .6627 .22303 L p F P
0 g
s
.605 .652 .87 r
.60954 .31201 m .5835 .31704 L .5761 .30496 L p F P
0 g
s
.257 .262 .673 r
.4853 .24097 m .48144 .226 L .48884 .23401 L closepath p F P
0 g
s
.509 .501 .783 r
.51848 .3418 m .51195 .32534 L .53322 .32778 L closepath p F P
0 g
s
.765 .777 .863 r
.21571 .37995 m .20511 .3871 L .19634 .37877 L p F P
0 g
s
.699 .767 .904 r
.16916 .39111 m .19634 .37877 L .20511 .3871 L p F P
0 g
s
.478 .489 .79 r
.54394 .27472 m .53248 .27252 L .52739 .26001 L p F P
0 g
s
.647 .79 .951 r
.59644 .24476 m .62514 .2356 L .63223 .2428 L p F P
0 g
s
.62 .691 .895 r
.61796 .22741 m .62514 .2356 L .59644 .24476 L p F P
0 g
s
.62 .691 .895 r
.59094 .23371 m .61796 .22741 L p .59644 .24476 L F P
0 g
s
.62 .691 .895 r
.59644 .24476 m .58979 .23512 L .59094 .23371 L p F P
0 g
s
.562 .581 .831 r
.55558 .35995 m .53665 .36119 L .55027 .34933 L closepath p F P
0 g
s
.566 .553 .799 r
.54804 .3449 m .55027 .34933 L .53665 .36119 L p F P
0 g
s
.911 .942 .812 r
.67779 .19065 m .67631 .2024 L .66317 .21942 L p F P
0 g
s
.94 .963 .69 r
.68172 .18394 m .68547 .18212 L p .67631 .2024 L F P
0 g
s
.94 .963 .69 r
.67631 .2024 m .67779 .19065 L .68172 .18394 L p F P
0 g
s
.747 .822 .91 r
.6337 .24186 m .63223 .2428 L .62514 .2356 L p F P
0 g
s
.747 .822 .91 r
.62514 .2356 m .6337 .23073 L .6337 .24186 L p F P
0 g
s
.805 .913 .913 r
.65375 .21782 m .6337 .23073 L .6337 .24186 L p F P
0 g
s
.805 .913 .913 r
.6337 .24186 m .66061 .22211 L .65375 .21782 L p F P
0 g
s
.965 .932 .617 r
.68172 .18394 m .68554 .17542 L .68547 .18212 L closepath p F P
0 g
s
.931 .85 .41 r
.68919 .16163 m .68554 .17542 L .68547 .18212 L p F P
0 g
s
.639 .773 .945 r
.60643 .39051 m .63519 .3822 L .64227 .3897 L p F P
0 g
s
.619 .74 .933 r
.63519 .3822 m .60643 .39051 L .59914 .38067 L p F P
0 g
s
.848 .771 .775 r
.27 .31265 m .27936 .32083 L .26504 .33824 L p F P
0 g
s
.843 .764 .775 r
.28127 .29879 m .27 .31265 L .27936 .32083 L p F P
0 g
s
.811 .928 .911 r
.68378 .29922 m .68913 .29517 L .68693 .30094 L closepath p F P
0 g
s
.752 .924 .947 r
.65518 .31617 m .68378 .29922 L .68693 .30094 L p F P
0 g
s
.845 .943 .886 r
.71215 .27579 m .68913 .29517 L .68693 .30094 L p F P
0 g
s
.845 .943 .886 r
.71299 .27599 m .71215 .27579 L p .68693 .30094 L F P
0 g
s
.456 .502 .817 r
.54579 .20163 m .546 .20098 L p .56237 .21936 L F P
0 g
s
.342 .405 .782 r
.54579 .20163 m .54541 .20068 L .546 .20098 L closepath p F P
0 g
s
.849 .931 .551 r
.7939 .281 m .79766 .26911 L .80619 .25339 L p F P
0 g
s
.889 .973 .664 r
.7939 .281 m .79766 .26911 L p .7863 .28788 L F P
0 g
s
.889 .973 .664 r
.7863 .28788 m .79089 .28574 L .7939 .281 L p F P
0 g
s
0 0 .444 r
.50198 .18895 m .49865 .18172 L .49732 .17509 L closepath p F P
0 g
s
0 0 .257 r
.49865 .18172 m .49732 .17509 L .49434 .16343 L p F P
0 g
s
.342 .405 .782 r
.546 .20098 m .54541 .20068 L .53783 .18179 L p F P
0 g
s
.856 .997 .799 r
.76331 .32076 m .7684 .31513 L .76599 .32057 L closepath p F P
0 g
s
.864 .993 .747 r
.7826 .29759 m .7684 .31513 L .76599 .32057 L p F P
0 g
s
.96 .867 .461 r
.68858 .15039 m .68919 .16163 L .68554 .17542 L p F P
0 g
s
.831 .691 .153 r
.68919 .16163 m .68858 .15039 L .68942 .1376 L p F P
0 g
s
.733 .891 .951 r
.68378 .29922 m .65518 .31617 L .64821 .30984 L p F P
0 g
s
.668 .822 .958 r
.67104 .3779 m .64227 .3897 L .63519 .3822 L p F P
0 g
s
.365 .342 .701 r
.4853 .24097 m .48884 .23401 L p .49203 .25687 L F P
0 g
s
.365 .342 .701 r
.49203 .25687 m .48905 .25476 L .4853 .24097 L p F P
0 g
s
.759 .774 .865 r
.22412 .36016 m .20648 .37186 L .21571 .37995 L p F P
0 g
s
.759 .774 .865 r
.21571 .37995 m .23279 .36873 L .22412 .36016 L p F P
0 g
s
.765 .777 .863 r
.19634 .37877 m .20648 .37186 L .21571 .37995 L p F P
0 g
s
.907 .972 .671 r
.73986 .24102 m .74054 .23993 L .74032 .24082 L closepath p F P
0 g
s
.89 .607 .096 r
.52972 .15861 m .52923 .15727 L .52624 .14148 L p F P
0 g
s
0 0 .155 r
.52532 .13607 m .52624 .14148 L .52923 .15727 L p F P
0 g
s
.456 .502 .817 r
.546 .20098 m .56417 .20738 L .56237 .21936 L p F P
0 g
s
.238 .413 .834 r
.54804 .1888 m .546 .20098 L .56417 .20738 L p F P
0 g
s
.342 .405 .782 r
.53783 .18179 m .54804 .1888 L .546 .20098 L p F P
0 g
s
.878 .61 .088 r
.4883 .13723 m .4896 .14126 L .492 .15643 L p F P
0 g
s
.948 .663 .212 r
.4934 .15953 m .492 .15643 L .4896 .14126 L p F P
0 g
s
.514 .485 .762 r
.53322 .32778 m .51195 .32534 L .5098 .31937 L p F P
0 g
s
.86 .978 .678 r
.7826 .29759 m .7863 .28788 L .79089 .28574 L closepath p F P
0 g
s
.464 .423 .727 r
.49668 .28068 m .49442 .27994 L .49601 .27843 L closepath p F P
0 g
s
.461 .418 .724 r
.49442 .27994 m .49601 .27843 L .49037 .25938 L p F P
0 g
s
.478 .489 .79 r
.52739 .26001 m .52994 .25547 L p .54394 .27472 L F P
0 g
s
.417 .447 .784 r
.52739 .26001 m .52489 .25367 L .52994 .25547 L closepath p F P
0 g
s
.926 .973 .71 r
.74054 .23993 m .73986 .24102 L .73373 .2423 L p F P
0 g
s
.926 .973 .71 r
.73373 .2423 m .74269 .22824 L .74054 .23993 L p F P
0 g
s
.915 .947 .599 r
.74054 .23993 m .74269 .22824 L .75055 .21284 L p F P
0 g
s
.514 .485 .762 r
.5098 .31937 m .52031 .30809 L p .53322 .32778 L F P
0 g
s
.471 .459 .763 r
.5098 .31937 m .50432 .30411 L .52031 .30809 L closepath p F P
0 g
s
0 0 .011 r
.82651 .17548 m .82674 .17333 L .82746 .16039 L p F P
0 g
s
0 0 .105 r
.82746 .16039 m .82805 .14897 L .82758 .13647 L p F P
0 g
s
0 0 0 r
.82805 .14897 m .82746 .16039 L .82674 .17333 L p F P
0 g
s
0 .084 .639 r
.53783 .18179 m .53664 .18023 L .53618 .17786 L closepath p F P
0 g
s
0 0 .439 r
.53021 .15989 m .52972 .15861 L p .53664 .18023 L F P
0 g
s
0 0 .439 r
.53664 .18023 m .53618 .17786 L .53021 .15989 L p F P
0 g
s
.353 .343 .709 r
.49037 .25938 m .48905 .25476 L .49203 .25687 L closepath p F P
0 g
s
.825 .87 .428 r
.81182 .24072 m .81282 .23832 L .81244 .23977 L closepath p F P
0 g
s
.903 .984 .732 r
.72883 .25657 m .73986 .24102 L .73373 .2423 L p F P
0 g
s
.647 .783 .947 r
.63773 .31379 m .61945 .32057 L .61223 .3115 L p F P
0 g
s
.36 .353 .716 r
.49203 .25687 m .49037 .25938 L .49601 .27843 L p F P
0 g
s
.865 .913 .862 r
.66317 .21942 m .66061 .22211 L .65375 .21782 L p F P
0 g
s
.865 .913 .862 r
.65375 .21782 m .66377 .20802 L .66317 .21942 L p F P
0 g
s
.911 .942 .812 r
.66317 .21942 m .66377 .20802 L .67779 .19065 L p F P
0 g
s
.424 .442 .775 r
.52994 .25547 m .52489 .25367 L .51872 .23746 L p F P
0 g
s
.391 .493 .844 r
.56237 .21936 m .58173 .22247 L .57428 .21036 L p F P
0 g
s
.391 .493 .844 r
.57428 .21036 m .56417 .20738 L .56237 .21936 L p F P
0 g
s
0 0 .006 r
.76218 .15971 m .76219 .14837 L .76215 .13579 L p F P
0 g
s
.829 .722 .193 r
.76219 .14837 m .76218 .15971 L .76059 .17288 L p F P
0 g
s
.848 .771 .776 r
.26504 .33824 m .26098 .34316 L .25243 .33424 L p F P
0 g
s
.848 .771 .776 r
.25243 .33424 m .25586 .33003 L .26504 .33824 L p F P
0 g
s
.848 .771 .775 r
.26504 .33824 m .25586 .33003 L .27 .31265 L p F P
0 g
s
.48 .448 .744 r
.52031 .30809 m .50432 .30411 L .50244 .29838 L p F P
0 g
s
.588 .613 .845 r
.57917 .37146 m .56308 .37371 L .55558 .35995 L p F P
0 g
s
.48 .448 .744 r
.50244 .29838 m .51156 .28704 L p .52031 .30809 L F P
0 g
s
.423 .411 .741 r
.50244 .29838 m .49668 .28068 L .51156 .28704 L closepath p F P
0 g
s
.36 .353 .716 r
.49601 .27843 m .5047 .26534 L .49203 .25687 L p F P
0 g
s
.435 .404 .726 r
.49601 .27843 m .5047 .26534 L p .51156 .28704 L F P
0 g
s
.435 .404 .726 r
.51156 .28704 m .49668 .28068 L .49601 .27843 L p F P
0 g
s
.874 .897 .478 r
.81282 .23832 m .81524 .22665 L p .80819 .24525 L F P
0 g
s
.874 .897 .478 r
.80819 .24525 m .81182 .24072 L .81282 .23832 L p F P
0 g
s
.81 .822 .343 r
.81282 .23832 m .81524 .22665 L .82 .21222 L p F P
0 g
s
.811 .775 .82 r
.24496 .35758 m .23279 .36873 L .22412 .36016 L p F P
0 g
s
.811 .775 .82 r
.22412 .36016 m .2357 .34944 L .24496 .35758 L p F P
0 g
s
.806 .772 .822 r
.25243 .33424 m .2357 .34944 L .24496 .35758 L p F P
0 g
s
.806 .772 .822 r
.24496 .35758 m .26098 .34316 L .25243 .33424 L p F P
0 g
s
.235 .348 .776 r
.54804 .1888 m .53783 .18179 L .53618 .17786 L p F P
0 g
s
0 0 .256 r
.53021 .15989 m .52972 .15861 L .52923 .15727 L closepath p F P
0 g
s
.769 .949 .936 r
.72324 .35547 m .70652 .36701 L .69987 .36304 L p F P
0 g
s
.803 .769 .259 r
.8248 .18676 m .82333 .1983 L .82 .21222 L p F P
0 g
s
.723 .671 .122 r
.82583 .17976 m .82651 .17548 L p .82333 .1983 L F P
0 g
s
.723 .671 .122 r
.82333 .1983 m .8248 .18676 L .82583 .17976 L p F P
0 g
s
.913 .903 .498 r
.75696 .19156 m .75616 .19824 L .75055 .21284 L p F P
0 g
s
.871 .994 .763 r
.7863 .28788 m .7826 .29759 L .7684 .31513 L p F P
0 g
s
.235 .348 .776 r
.53618 .17786 m .53632 .16873 L p .54804 .1888 L F P
0 g
s
0 .106 .635 r
.53618 .17786 m .53021 .15989 L .53632 .16873 L closepath p F P
0 g
s
.854 .898 .479 r
.80619 .25339 m .80819 .24525 L .81182 .24072 L closepath p F P
0 g
s
.424 .442 .775 r
.51872 .23746 m .51981 .23494 L p .52994 .25547 L F P
0 g
s
.34 .381 .758 r
.51872 .23746 m .51727 .23346 L .51981 .23494 L closepath p F P
0 g
s
.343 .38 .756 r
.51981 .23494 m .51727 .23346 L .51097 .21596 L p F P
0 g
s
0 .067 .621 r
.53632 .16873 m .53021 .15989 L .52923 .15727 L p F P
0 g
s
.888 .725 .213 r
.68809 .12648 m .68942 .1376 L .68858 .15039 L p F P
0 g
s
.222 .285 .717 r
.49837 .24342 m .49203 .25687 L .5047 .26534 L p F P
0 g
s
.365 .342 .701 r
.48884 .23401 m .49837 .24342 L .49203 .25687 L p F P
0 g
s
0 .067 .621 r
.52923 .15727 m .52758 .14762 L p .53632 .16873 L F P
0 g
s
0 0 .374 r
.52758 .14762 m .53371 .15791 L p .52733 .14551 L F P
0 g
s
0 0 .155 r
.52758 .14762 m .52532 .13607 L p .5278 .14953 L F P
0 g
s
.882 .571 .061 r
.52104 .12571 m .52532 .13607 L .52758 .14762 L p F P
0 g
s
.882 .571 .061 r
.52312 .13733 m .52104 .12571 L p .52513 .13942 L F P
0 g
s
.882 .571 .061 r
.52758 .14762 m .52312 .13733 L p .52513 .13942 L F P
0 g
s
0 0 .374 r
.52312 .13733 m .52758 .14762 L p .52733 .14551 L F P
0 g
s
0 0 .374 r
.52881 .14778 m .52312 .13733 L p .52947 .14966 L F P
0 g
s
0 0 .374 r
.53371 .15791 m .52881 .14778 L p .52947 .14966 L F P
0 g
s
0 0 .52 r
.52881 .14778 m .53731 .15736 L p .52815 .14588 L F P
0 g
s
.733 .303 0 r
.52312 .13733 m .52881 .14778 L p .5211 .13521 L F P
0 g
s
.733 .303 0 r
.52881 .14778 m .52203 .1382 L .51649 .1277 L p F P
0 g
s
0 0 .52 r
.52203 .1382 m .52881 .14778 L p .52815 .14588 L F P
0 g
s
.733 .303 0 r
.51649 .1277 m .52312 .13733 L p .5211 .13521 L F P
0 g
s
0 0 .155 r
.52923 .15727 m .52758 .14762 L p .5278 .14953 L F P
0 g
s
.878 .61 .088 r
.492 .15643 m .48961 .14906 L p .49032 .1477 L F P
0 g
s
0 0 .291 r
.492 .15643 m .48961 .14906 L p .49698 .17064 L F P
0 g
s
.872 .485 .011 r
.48961 .14906 m .49332 .16014 L p .48875 .15071 L F P
0 g
s
.872 .485 .011 r
.48328 .13939 m .48961 .14906 L p .48875 .15071 L F P
0 g
s
.878 .61 .088 r
.48961 .14906 m .4883 .13723 L p .49032 .1477 L F P
0 g
s
.967 .649 .271 r
.48202 .12753 m .4883 .13723 L .48961 .14906 L p F P
0 g
s
.897 .981 .803 r
.72883 .25657 m .71347 .27443 L .71299 .27599 L p F P
0 g
s
.893 .974 .822 r
.73203 .24459 m .72883 .25657 L .71347 .27443 L p F P
0 g
s
.903 .984 .732 r
.73373 .2423 m .73203 .24459 L .72883 .25657 L p F P
0 g
s
0 0 .414 r
.49732 .17509 m .49434 .16343 L .49698 .17064 L closepath p F P
0 g
s
.871 .974 .85 r
.71215 .27579 m .71347 .27443 L .71299 .27599 L closepath p F P
0 g
s
.769 .949 .936 r
.72968 .3447 m .72324 .35547 L p .69987 .36304 L F P
0 g
s
.796 .962 .916 r
.72324 .35547 m .72968 .3447 L .73506 .34673 L closepath p F P
0 g
s
.605 .652 .87 r
.5761 .30496 m .60494 .30149 L p .60954 .31201 L F P
0 g
s
.53 .647 .908 r
.60494 .30149 m .5761 .30496 L .56865 .29192 L p F P
0 g
s
0 0 .051 r
.82743 .12516 m .82758 .13647 L .82805 .14897 L p F P
0 g
s
.799 .906 .915 r
.68913 .29517 m .68378 .29922 L .67699 .29454 L p F P
0 g
s
.733 .891 .951 r
.64821 .30984 m .67699 .29454 L .68378 .29922 L p F P
0 g
s
.343 .38 .756 r
.51097 .21596 m .51161 .21374 L p .51981 .23494 L F P
0 g
s
.223 .286 .718 r
.51097 .21596 m .50963 .21193 L .51161 .21374 L closepath p F P
0 g
s
.928 .576 .142 r
.46319 .14646 m .46931 .15617 L .47185 .16762 L p F P
0 g
s
.975 .672 .305 r
.46931 .15617 m .46319 .14646 L .46238 .13448 L p F P
0 g
s
.206 .283 .723 r
.51161 .21374 m .50963 .21193 L .50385 .19518 L p F P
0 g
s
.371 .477 .838 r
.53462 .24264 m .52994 .25547 L .54908 .26186 L p F P
0 g
s
.478 .489 .79 r
.52994 .25547 m .54908 .26186 L .54394 .27472 L p F P
0 g
s
.424 .442 .775 r
.51981 .23494 m .53462 .24264 L .52994 .25547 L p F P
0 g
s
.867 .991 .825 r
.7684 .31513 m .76331 .32076 L .75716 .3201 L p F P
0 g
s
.867 .991 .825 r
.75716 .3201 m .77301 .30308 L .7684 .31513 L p F P
0 g
s
.871 .994 .763 r
.78515 .28813 m .7863 .28788 L p .7684 .31513 L F P
0 g
s
.871 .994 .763 r
.7684 .31513 m .77301 .30308 L .78515 .28813 L p F P
0 g
s
.799 .906 .915 r
.67699 .29454 m .69304 .2831 L .68913 .29517 L p F P
0 g
s
.831 .958 .894 r
.70561 .27317 m .69304 .2831 L .68913 .29517 L p F P
0 g
s
.831 .958 .894 r
.68913 .29517 m .71215 .27579 L .70561 .27317 L p F P
0 g
s
.776 .618 .054 r
.7614 .12457 m .76215 .13579 L .76219 .14837 L p F P
0 g
s
.018 .126 .636 r
.50385 .19518 m .50198 .18895 L .50421 .19223 L closepath p F P
0 g
s
0 .092 .628 r
.50421 .19223 m .50198 .18895 L .49732 .17509 L p F P
0 g
s
.741 .68 .133 r
.82583 .17976 m .82674 .17333 L .82651 .17548 L closepath p F P
0 g
s
.978 .918 .649 r
.68554 .17542 m .68483 .16425 L p .67825 .18444 L F P
0 g
s
.978 .918 .649 r
.67825 .18444 m .68172 .18394 L .68554 .17542 L p F P
0 g
s
.96 .867 .461 r
.68554 .17542 m .68483 .16425 L .68858 .15039 L p F P
0 g
s
.615 .685 .892 r
.58979 .23512 m .58912 .23413 L .59094 .23371 L closepath p F P
0 g
s
.206 .283 .723 r
.50385 .19518 m .50421 .19223 L p .51161 .21374 L F P
0 g
s
.841 .993 .848 r
.74943 .33418 m .76331 .32076 L .75716 .3201 L p F P
0 g
s
.839 .961 .887 r
.72968 .3447 m .73506 .34673 L .74943 .33418 L p F P
0 g
s
.204 .34 .78 r
.52299 .22247 m .51981 .23494 L .53462 .24264 L p F P
0 g
s
.343 .38 .756 r
.51161 .21374 m .52299 .22247 L .51981 .23494 L p F P
0 g
s
.518 .527 .805 r
.54394 .27472 m .56114 .27794 L p .56502 .29167 L F P
0 g
s
.408 .469 .812 r
.54394 .27472 m .56114 .27794 L .55359 .26332 L p F P
0 g
s
.408 .469 .812 r
.55359 .26332 m .54908 .26186 L .54394 .27472 L p F P
0 g
s
0 .092 .628 r
.49732 .17509 m .49698 .17064 L p .50421 .19223 L F P
0 g
s
.841 .993 .848 r
.75716 .3201 m .75534 .32179 L .74943 .33418 L p F P
0 g
s
.839 .961 .887 r
.74943 .33418 m .75534 .32179 L p .72968 .3447 L F P
0 g
s
.893 .974 .822 r
.71347 .27443 m .71631 .26262 L .73203 .24459 L p F P
0 g
s
.868 .955 .863 r
.71347 .27443 m .71215 .27579 L .70561 .27317 L p F P
0 g
s
.868 .955 .863 r
.70561 .27317 m .71631 .26262 L .71347 .27443 L p F P
0 g
s
.616 .669 .878 r
.59094 .23371 m .58912 .23413 L .58173 .22247 L p F P
0 g
s
.647 .783 .947 r
.64473 .30624 m .63773 .31379 L p .61223 .3115 L F P
0 g
s
.677 .796 .938 r
.63773 .31379 m .64473 .30624 L .64821 .30984 L closepath p F P
0 g
s
.043 .165 .667 r
.49171 .22158 m .48884 .23401 L .49837 .24342 L p F P
0 g
s
.259 .262 .673 r
.48458 .21145 m .49171 .22158 L .48884 .23401 L p F P
0 g
s
.619 .74 .933 r
.59914 .38067 m .62802 .37373 L .63519 .3822 L p F P
0 g
s
.596 .709 .923 r
.62802 .37373 m .59914 .38067 L .59179 .36977 L p F P
0 g
s
.579 .657 .891 r
.59094 .23371 m .61796 .22741 L .61071 .21846 L p F P
0 g
s
.579 .657 .891 r
.61071 .21846 m .59698 .22041 L .59094 .23371 L p F P
0 g
s
.616 .669 .878 r
.58173 .22247 m .59698 .22041 L .59094 .23371 L p F P
0 g
s
.064 .235 .729 r
.51276 .20183 m .51161 .21374 L .52299 .22247 L p F P
0 g
s
.206 .283 .723 r
.50421 .19223 m .51276 .20183 L .51161 .21374 L p F P
0 g
s
.889 .948 .593 r
.80819 .24525 m .80619 .25339 L .79766 .26911 L p F P
0 g
s
.535 .567 .834 r
.57689 .34505 m .58437 .35787 L .55558 .35995 L p F P
0 g
s
.535 .567 .834 r
.55421 .3449 m .57689 .34505 L p .55558 .35995 L F P
0 g
s
.535 .567 .834 r
.55558 .35995 m .55027 .34933 L .55421 .3449 L p F P
0 g
s
.588 .613 .845 r
.55558 .35995 m .58437 .35787 L p .57917 .37146 L F P
0 g
s
0 0 0 r
.82674 .17333 m .82736 .16193 L .82805 .14897 L p F P
0 g
s
.795 .714 .179 r
.82674 .17333 m .82736 .16193 L p .82498 .18428 L F P
0 g
s
.795 .714 .179 r
.82498 .18428 m .82583 .17976 L .82674 .17333 L p F P
0 g
s
.709 .871 .958 r
.68869 .36893 m .67104 .3779 L .66411 .37164 L p F P
0 g
s
.668 .822 .958 r
.63519 .3822 m .66411 .37164 L .67104 .3779 L p F P
0 g
s
.939 .95 .63 r
.75194 .20125 m .75055 .21284 L .74269 .22824 L p F P
0 g
s
.913 .903 .498 r
.75457 .19449 m .75696 .19156 L p .75055 .21284 L F P
0 g
s
.913 .903 .498 r
.75055 .21284 m .75194 .20125 L .75457 .19449 L p F P
0 g
s
.912 .832 .372 r
.76061 .16157 m .76059 .17288 L .7573 .18669 L p F P
0 g
s
.829 .722 .193 r
.76059 .17288 m .76061 .16157 L .76219 .14837 L p F P
0 g
s
.867 .809 .324 r
.75696 .19156 m .7573 .18669 L .76059 .17288 L p F P
0 g
s
.723 .804 .915 r
.6337 .23073 m .62514 .2356 L .61796 .22741 L p F P
0 g
s
.949 .957 .705 r
.67779 .19065 m .67825 .18444 L .68172 .18394 L closepath p F P
0 g
s
.6 .696 .91 r
.61223 .3115 m .60954 .31201 L .6105 .30912 L closepath p F P
0 g
s
.605 .652 .87 r
.60494 .30149 m .6105 .30912 L .60954 .31201 L p F P
0 g
s
.864 .85 .391 r
.82154 .20068 m .82 .21222 L .81524 .22665 L p F P
0 g
s
.803 .769 .259 r
.82 .21222 m .82154 .20068 L .8248 .18676 L p F P
0 g
s
0 .076 .634 r
.50306 .18099 m .50421 .19223 L .51276 .20183 L p F P
0 g
s
0 .092 .628 r
.49698 .17064 m .50306 .18099 L .50421 .19223 L p F P
0 g
s
.582 .645 .878 r
.59179 .36977 m .57917 .37146 L .58716 .36232 L closepath p F P
0 g
s
.588 .613 .845 r
.58437 .35787 m .58716 .36232 L .57917 .37146 L p F P
0 g
s
.5 .568 .856 r
.56865 .29192 m .56502 .29167 L .56664 .28818 L closepath p F P
0 g
s
.518 .527 .805 r
.56114 .27794 m .56664 .28818 L .56502 .29167 L p F P
0 g
s
.65 .791 .95 r
.66411 .37164 m .63519 .3822 L .62802 .37373 L p F P
0 g
s
.926 .892 .481 r
.75457 .19449 m .7573 .18669 L .75696 .19156 L closepath p F P
0 g
s
0 0 .554 r
.48425 .19997 m .48458 .21145 L .49171 .22158 L p F P
0 g
s
.647 .783 .947 r
.61223 .3115 m .64114 .30247 L .64473 .30624 L p F P
0 g
s
.625 .707 .904 r
.63398 .29423 m .64114 .30247 L .61223 .3115 L p F P
0 g
s
.625 .707 .904 r
.62086 .29749 m .63398 .29423 L p .61223 .3115 L F P
0 g
s
.625 .707 .904 r
.61223 .3115 m .6105 .30912 L .62086 .29749 L p F P
0 g
s
.735 .812 .912 r
.64473 .30624 m .64821 .30984 L .67699 .29454 L p F P
0 g
s
.723 .804 .915 r
.61796 .22741 m .63382 .21944 L .6337 .23073 L p F P
0 g
s
.776 .875 .92 r
.64678 .21224 m .63382 .21944 L .6337 .23073 L p F P
0 g
s
.776 .875 .92 r
.6337 .23073 m .65375 .21782 L .64678 .21224 L p F P
0 g
s
.899 .926 .827 r
.67825 .18444 m .67779 .19065 L .66377 .20802 L p F P
0 g
s
0 0 .291 r
.49332 .16014 m .49698 .17064 L p .49257 .15773 L F P
0 g
s
0 0 .291 r
.48961 .14906 m .49332 .16014 L p .49257 .15773 L F P
0 g
s
0 0 .407 r
.49332 .16014 m .49698 .17064 L .50306 .18099 L p F P
0 g
s
0 0 .407 r
.49891 .17067 m .49332 .16014 L p .49671 .16741 L F P
0 g
s
0 0 .407 r
.50306 .18099 m .49891 .17067 L p .49671 .16741 L F P
0 g
s
0 0 .508 r
.50585 .18083 m .49891 .17067 L p .5025 .17692 L F P
0 g
s
0 0 .508 r
.51057 .19094 m .50585 .18083 L p .5025 .17692 L F P
0 g
s
0 0 .445 r
.50585 .18083 m .51375 .19076 L p .50922 .18477 L F P
0 g
s
.624 .183 0 r
.49891 .17067 m .50585 .18083 L p .50112 .17395 L F P
0 g
s
0 0 .508 r
.49891 .17067 m .50306 .18099 L .51057 .19094 L p F P
0 g
s
.624 .183 0 r
.50585 .18083 m .49904 .17133 L .49229 .1611 L p F P
0 g
s
0 0 .445 r
.49904 .17133 m .50585 .18083 L p .50922 .18477 L F P
0 g
s
.624 .183 0 r
.49229 .1611 m .49891 .17067 L p .50112 .17395 L F P
0 g
s
.737 .312 0 r
.49332 .16014 m .49891 .17067 L p .49407 .16257 L F P
0 g
s
.737 .312 0 r
.48687 .15052 m .49332 .16014 L p .49407 .16257 L F P
0 g
s
.981 .871 .502 r
.68722 .13931 m .68858 .15039 L .68483 .16425 L p F P
0 g
s
.888 .725 .213 r
.68858 .15039 m .68722 .13931 L .68809 .12648 L p F P
0 g
s
.786 .711 .175 r
.8248 .18676 m .82498 .18428 L .82583 .17976 L closepath p F P
0 g
s
.53 .647 .908 r
.56865 .29192 m .59758 .29068 L .60494 .30149 L p F P
0 g
s
.513 .575 .855 r
.59016 .27925 m .59758 .29068 L .56865 .29192 L p F P
0 g
s
.513 .575 .855 r
.57186 .27838 m .59016 .27925 L p .56865 .29192 L F P
0 g
s
.513 .575 .855 r
.56865 .29192 m .56664 .28818 L .57186 .27838 L p F P
0 g
s
.536 .569 .836 r
.55027 .34933 m .54804 .3449 L .55421 .3449 L closepath p F P
0 g
s
.625 .706 .904 r
.6105 .30912 m .60494 .30149 L .62086 .29749 L closepath p F P
0 g
s
.734 .883 .949 r
.68869 .36893 m .69515 .3596 L .69987 .36304 L closepath p F P
0 g
s
.709 .871 .958 r
.69515 .3596 m .68869 .36893 L p .66411 .37164 L F P
0 g
s
.889 .973 .664 r
.79766 .26911 m .78704 .28554 L .7863 .28788 L p F P
0 g
s
.889 .948 .593 r
.8065 .2465 m .80819 .24525 L p .79766 .26911 L F P
0 g
s
.889 .948 .593 r
.79766 .26911 m .80062 .25736 L .8065 .2465 L p F P
0 g
s
.903 .976 .684 r
.80062 .25736 m .79766 .26911 L .78704 .28554 L p F P
0 g
s
.967 .649 .271 r
.48961 .14906 m .48328 .13939 L .48202 .12753 L p F P
0 g
s
0 0 .051 r
.82805 .14897 m .82791 .13768 L .82743 .12516 L p F P
0 g
s
.774 .649 .091 r
.82791 .13768 m .82805 .14897 L .82736 .16193 L p F P
0 g
s
.238 .413 .834 r
.56417 .20738 m .56268 .19639 L .54804 .1888 L p F P
0 g
s
.083 .336 .811 r
.54661 .17769 m .54804 .1888 L .56268 .19639 L p F P
0 g
s
.235 .348 .776 r
.53632 .16873 m .54661 .17769 L .54804 .1888 L p F P
0 g
s
0 .156 .697 r
.53371 .15791 m .53632 .16873 L .54661 .17769 L p F P
0 g
s
0 .067 .621 r
.52758 .14762 m .53371 .15791 L .53632 .16873 L p F P
0 g
s
.511 .573 .854 r
.56664 .28818 m .56114 .27794 L .57186 .27838 L closepath p F P
0 g
s
.885 .753 .248 r
.76144 .13717 m .76219 .14837 L .76061 .16157 L p F P
0 g
s
.776 .618 .054 r
.76219 .14837 m .76144 .13717 L .7614 .12457 L p F P
0 g
s
.941 .961 .735 r
.74269 .22824 m .74405 .2167 L p .73251 .24229 L F P
0 g
s
.941 .961 .735 r
.73251 .24229 m .73373 .2423 L .74269 .22824 L p F P
0 g
s
.939 .95 .63 r
.74269 .22824 m .74405 .2167 L .75194 .20125 L p F P
0 g
s
.514 .485 .762 r
.52031 .30809 m .53282 .31116 L p .53322 .32778 L F P
0 g
s
.455 .479 .795 r
.53282 .31116 m .52031 .30809 L .5273 .29786 L closepath p F P
0 g
s
.48 .448 .744 r
.52515 .29266 m .5273 .29786 L .52031 .30809 L p F P
0 g
s
.48 .448 .744 r
.51156 .28704 m .52515 .29266 L p .52031 .30809 L F P
0 g
s
.54 .554 .817 r
.55421 .3449 m .54804 .3449 L .54045 .32863 L p F P
0 g
s
.848 .895 .87 r
.66377 .20802 m .65375 .21782 L .64678 .21224 L p F P
0 g
s
.848 .895 .87 r
.64678 .21224 m .66382 .19668 L .66377 .20802 L p F P
0 g
s
.899 .926 .827 r
.67513 .18352 m .67825 .18444 L p .66377 .20802 L F P
0 g
s
.899 .926 .827 r
.66377 .20802 m .66382 .19668 L .67513 .18352 L p F P
0 g
s
.889 .987 .73 r
.78515 .28813 m .78704 .28554 L .7863 .28788 L closepath p F P
0 g
s
.5 .517 .805 r
.54045 .32863 m .53322 .32778 L .53776 .32247 L closepath p F P
0 g
s
.514 .485 .762 r
.53282 .31116 m .53776 .32247 L .53322 .32778 L p F P
0 g
s
.928 .576 .142 r
.47185 .16762 m .4656 .15797 L .46319 .14646 L p F P
0 g
s
.286 .454 .853 r
.56417 .20738 m .57428 .21036 L .56679 .19814 L p F P
0 g
s
.286 .454 .853 r
.56679 .19814 m .56268 .19639 L .56417 .20738 L p F P
0 g
s
.578 .643 .879 r
.59698 .22041 m .58173 .22247 L .57428 .21036 L p F P
0 g
s
.391 .433 .784 r
.52515 .29266 m .51156 .28704 L .51783 .27431 L closepath p F P
0 g
s
.435 .404 .726 r
.51747 .2734 m .51783 .27431 L .51156 .28704 L p F P
0 g
s
.435 .404 .726 r
.5047 .26534 m .51747 .2734 L p .51156 .28704 L F P
0 g
s
.769 .949 .936 r
.69987 .36304 m .72863 .34423 L .72968 .3447 L p F P
0 g
s
.781 .89 .923 r
.69515 .3596 m .69987 .36304 L .72863 .34423 L p F P
0 g
s
.861 .804 .315 r
.82498 .18428 m .8248 .18676 L .82154 .20068 L p F P
0 g
s
.958 .901 .524 r
.7573 .18669 m .75734 .1754 L p .7522 .19658 L F P
0 g
s
.958 .901 .524 r
.7522 .19658 m .75457 .19449 L .7573 .18669 L p F P
0 g
s
.912 .832 .372 r
.7573 .18669 m .75734 .1754 L .76061 .16157 L p F P
0 g
s
.874 .897 .478 r
.81524 .22665 m .80893 .24166 L .80819 .24525 L p F P
0 g
s
.904 .91 .509 r
.81687 .21513 m .81524 .22665 L .80893 .24166 L p F P
0 g
s
.864 .85 .391 r
.81524 .22665 m .81687 .21513 L .82154 .20068 L p F P
0 g
s
.596 .709 .923 r
.59179 .36977 m .62077 .36437 L .62802 .37373 L p F P
0 g
s
.579 .643 .879 r
.61345 .35418 m .62077 .36437 L .59179 .36977 L p F P
0 g
s
.579 .643 .879 r
.59163 .35691 m .61345 .35418 L p .59179 .36977 L F P
0 g
s
.579 .643 .879 r
.59179 .36977 m .58716 .36232 L .59163 .35691 L p F P
0 g
s
.932 .748 .269 r
.686 .11552 m .68809 .12648 L .68722 .13931 L p F P
0 g
s
.707 .802 .924 r
.64114 .30247 m .64548 .30049 L .64473 .30624 L closepath p F P
0 g
s
.735 .812 .912 r
.6701 .28883 m .64548 .30049 L .64473 .30624 L p F P
0 g
s
.735 .812 .912 r
.67699 .29454 m .6701 .28883 L p .64473 .30624 L F P
0 g
s
.948 .604 .207 r
.51447 .11605 m .52104 .12571 L .52312 .13733 L p F P
0 g
s
.904 .985 .759 r
.78704 .28554 m .78515 .28813 L .77918 .28841 L p F P
0 g
s
.904 .985 .759 r
.77918 .28841 m .79007 .27381 L .78704 .28554 L p F P
0 g
s
.903 .976 .684 r
.78704 .28554 m .79007 .27381 L .80062 .25736 L p F P
0 g
s
.222 .285 .717 r
.5047 .26534 m .50854 .25274 L .49837 .24342 L p F P
0 g
s
.232 .296 .724 r
.5047 .26534 m .51747 .2734 L .50976 .25381 L p F P
0 g
s
.232 .296 .724 r
.50976 .25381 m .50854 .25274 L .5047 .26534 L p F P
0 g
s
.902 .941 .577 r
.8065 .2465 m .80893 .24166 L .80819 .24525 L closepath p F P
0 g
s
.745 .578 .003 r
.82659 .11397 m .82743 .12516 L .82791 .13768 L p F P
0 g
s
.884 .992 .778 r
.77301 .30308 m .78515 .28813 L .77918 .28841 L p F P
0 g
s
.914 .978 .769 r
.73203 .24459 m .73251 .24229 L .73373 .2423 L closepath p F P
0 g
s
.498 .537 .827 r
.55421 .3449 m .57689 .34505 L .56935 .33139 L p F P
0 g
s
.498 .537 .827 r
.56935 .33139 m .56421 .33086 L .55421 .3449 L p F P
0 g
s
.54 .554 .817 r
.54045 .32863 m .56421 .33086 L .55421 .3449 L p F P
0 g
s
.785 .89 .92 r
.69304 .2831 m .67699 .29454 L .6701 .28883 L p F P
0 g
s
.815 .951 .908 r
.72863 .34423 m .73057 .34273 L .72968 .3447 L closepath p F P
0 g
s
.839 .961 .887 r
.75534 .32179 m .73057 .34273 L .72968 .3447 L p F P
0 g
s
.889 .96 .837 r
.73251 .24229 m .73203 .24459 L .71631 .26262 L p F P
0 g
s
.838 .655 .111 r
.75992 .1135 m .7614 .12457 L .76144 .13717 L p F P
0 g
s
.946 .928 .753 r
.67513 .18352 m .67785 .17926 L .67825 .18444 L closepath p F P
0 g
s
.978 .918 .649 r
.68483 .16425 m .67785 .17926 L .67825 .18444 L p F P
0 g
s
.869 .805 .318 r
.82548 .17536 m .82498 .18428 L .82221 .19144 L p F P
0 g
s
.795 .714 .179 r
.82736 .16193 m .82548 .17536 L .82498 .18428 L p F P
0 g
s
.861 .804 .315 r
.82154 .20068 m .82221 .19144 L .82498 .18428 L p F P
0 g
s
.975 .912 .676 r
.68335 .15324 m .68483 .16425 L .67785 .17926 L p F P
0 g
s
.981 .871 .502 r
.68483 .16425 m .68335 .15324 L .68722 .13931 L p F P
0 g
s
.514 .566 .845 r
.57186 .27838 m .56114 .27794 L .55359 .26332 L p F P
0 g
s
.943 .913 .535 r
.75194 .20125 m .7522 .19658 L .75457 .19449 L closepath p F P
0 g
s
.509 .521 .805 r
.56421 .33086 m .54045 .32863 L .53776 .32247 L p F P
0 g
s
.137 .271 .74 r
.49953 .23159 m .49837 .24342 L .50854 .25274 L p F P
0 g
s
.043 .165 .667 r
.49837 .24342 m .49953 .23159 L .49171 .22158 L p F P
0 g
s
.699 .79 .921 r
.63382 .21944 m .61796 .22741 L .61071 .21846 L p F P
0 g
s
.626 .69 .89 r
.62086 .29749 m .60494 .30149 L .59758 .29068 L p F P
0 g
s
.709 .871 .958 r
.66411 .37164 m .69311 .35806 L .69515 .3596 L p F P
0 g
s
.692 .844 .956 r
.69311 .35806 m .66411 .37164 L .65708 .36449 L p F P
0 g
s
.65 .791 .95 r
.62802 .37373 m .65708 .36449 L .66411 .37164 L p F P
0 g
s
.629 .762 .942 r
.65708 .36449 m .62802 .37373 L .62077 .36437 L p F P
0 g
s
.785 .89 .92 r
.6701 .28883 m .69682 .27095 L .69304 .2831 L p F P
0 g
s
.821 .93 .904 r
.69895 .26939 m .69682 .27095 L .69304 .2831 L p F P
0 g
s
.821 .93 .904 r
.69304 .2831 m .70561 .27317 L .69895 .26939 L p F P
0 g
s
.88 .973 .839 r
.77301 .30308 m .77688 .29115 L p .75617 .31985 L F P
0 g
s
.88 .973 .839 r
.75617 .31985 m .75716 .3201 L .77301 .30308 L p F P
0 g
s
.884 .992 .778 r
.77918 .28841 m .77688 .29115 L .77301 .30308 L p F P
0 g
s
.809 .932 .913 r
.73057 .34273 m .72863 .34423 L .72207 .34054 L p F P
0 g
s
.781 .89 .923 r
.72863 .34423 m .72207 .34054 L p .69515 .3596 L F P
0 g
s
.809 .932 .913 r
.72207 .34054 m .7352 .33069 L .73057 .34273 L p F P
0 g
s
.825 .95 .901 r
.75617 .31985 m .75534 .32179 L .73057 .34273 L p F P
0 g
s
.825 .95 .901 r
.75085 .31798 m .75617 .31985 L p .73057 .34273 L F P
0 g
s
.825 .95 .901 r
.73057 .34273 m .7352 .33069 L .75085 .31798 L p F P
0 g
s
.371 .477 .838 r
.54599 .24826 m .53462 .24264 L p .54908 .26186 L F P
0 g
s
.223 .358 .79 r
.53462 .24264 m .54599 .24826 L .53836 .23317 L p F P
0 g
s
.223 .358 .79 r
.53836 .23317 m .53516 .23107 L .53462 .24264 L p F P
0 g
s
.204 .34 .78 r
.53462 .24264 m .53516 .23107 L .52299 .22247 L p F P
0 g
s
.889 .96 .837 r
.72738 .24114 m .73251 .24229 L p .71631 .26262 L F P
0 g
s
.889 .96 .837 r
.71631 .26262 m .7185 .25092 L .72738 .24114 L p F P
0 g
s
.86 .937 .872 r
.71631 .26262 m .70561 .27317 L .69895 .26939 L p F P
0 g
s
.86 .937 .872 r
.69895 .26939 m .7185 .25092 L .71631 .26262 L p F P
0 g
s
.12 .326 .795 r
.5224 .21116 m .52299 .22247 L .53516 .23107 L p F P
0 g
s
.064 .235 .729 r
.52299 .22247 m .5224 .21116 L .51276 .20183 L p F P
0 g
s
.509 .521 .805 r
.53776 .32247 m .54392 .31337 L p .56421 .33086 L F P
0 g
s
.467 .498 .807 r
.53776 .32247 m .53282 .31116 L .54392 .31337 L closepath p F P
0 g
s
.919 .961 .792 r
.72738 .24114 m .73354 .23305 L .73251 .24229 L closepath p F P
0 g
s
.941 .961 .735 r
.74405 .2167 m .73354 .23305 L .73251 .24229 L p F P
0 g
s
.58 .646 .88 r
.58716 .36232 m .58437 .35787 L .59163 .35691 L closepath p F P
0 g
s
.852 .746 .229 r
.82726 .15066 m .82736 .16193 L .82548 .17536 L p F P
0 g
s
.774 .649 .091 r
.82736 .16193 m .82726 .15066 L .82791 .13768 L p F P
0 g
s
0 .115 .667 r
.51057 .19094 m .51276 .20183 L .5224 .21116 L p F P
0 g
s
0 .076 .634 r
.51276 .20183 m .51057 .19094 L .50306 .18099 L p F P
0 g
s
.379 .485 .841 r
.55359 .26332 m .54908 .26186 L .54998 .25621 L closepath p F P
0 g
s
.371 .477 .838 r
.54908 .26186 m .54998 .25621 L .54599 .24826 L p F P
0 g
s
.845 .98 .869 r
.75534 .32179 m .75617 .31985 L .75716 .3201 L closepath p F P
0 g
s
.948 .846 .416 r
.75988 .15039 m .76061 .16157 L .75734 .1754 L p F P
0 g
s
.885 .753 .248 r
.76061 .16157 m .75988 .15039 L .76144 .13717 L p F P
0 g
s
.932 .948 .614 r
.80893 .24166 m .81065 .23015 L p .80227 .24864 L F P
0 g
s
.932 .948 .614 r
.80227 .24864 m .8065 .2465 L .80893 .24166 L p F P
0 g
s
.904 .91 .509 r
.80893 .24166 m .81065 .23015 L .81687 .21513 L p F P
0 g
s
0 .104 .653 r
.4903 .21049 m .49171 .22158 L .49953 .23159 L p F P
0 g
s
0 0 .554 r
.49171 .22158 m .4903 .21049 L .48425 .19997 L p F P
0 g
s
.687 .782 .923 r
.64548 .30049 m .64114 .30247 L .63398 .29423 L p F P
0 g
s
.955 .949 .661 r
.7522 .19658 m .75194 .20125 L .74405 .2167 L p F P
0 g
s
.908 .871 .436 r
.82221 .19144 m .82154 .20068 L .81687 .21513 L p F P
0 g
s
.531 .653 .913 r
.59698 .22041 m .61071 .21846 L .60338 .20895 L p F P
0 g
s
.531 .653 .913 r
.60338 .20895 m .5959 .20937 L .59698 .22041 L p F P
0 g
s
.578 .643 .879 r
.57428 .21036 m .5959 .20937 L .59698 .22041 L p F P
0 g
s
.687 .782 .923 r
.63398 .29423 m .6456 .28952 L .64548 .30049 L p F P
0 g
s
.715 .832 .937 r
.6631 .28223 m .6456 .28952 L .64548 .30049 L p F P
0 g
s
.715 .832 .937 r
.64548 .30049 m .6701 .28883 L .6631 .28223 L p F P
0 g
s
.537 .623 .884 r
.5959 .20937 m .57428 .21036 L .56679 .19814 L p F P
0 g
s
.872 .485 .011 r
.49332 .16014 m .48687 .15052 L .48328 .13939 L p F P
0 g
s
.917 .956 .626 r
.80062 .25736 m .80227 .24864 L .8065 .2465 L closepath p F P
0 g
s
.473 .49 .795 r
.54392 .31337 m .53282 .31116 L .5273 .29786 L p F P
0 g
s
.858 .967 .868 r
.75085 .31798 m .7593 .3099 L .75617 .31985 L closepath p F P
0 g
s
.88 .973 .839 r
.77688 .29115 m .7593 .3099 L .75617 .31985 L p F P
0 g
s
.582 .63 .864 r
.59163 .35691 m .58437 .35787 L .57689 .34505 L p F P
0 g
s
.993 .869 .535 r
.68509 .12838 m .68722 .13931 L .68335 .15324 L p F P
0 g
s
.932 .748 .269 r
.68722 .13931 m .68509 .12838 L .686 .11552 L p F P
0 g
s
.699 .79 .921 r
.61071 .21846 m .63595 .20738 L .63382 .21944 L p F P
0 g
s
.744 .84 .923 r
.6397 .20561 m .63595 .20738 L .63382 .21944 L p F P
0 g
s
.744 .84 .923 r
.63382 .21944 m .64678 .21224 L .6397 .20561 L p F P
0 g
s
.937 .91 .768 r
.67785 .17926 m .67513 .18352 L .66834 .1801 L p F P
0 g
s
.937 .91 .768 r
.66834 .1801 m .67615 .16835 L .67785 .17926 L p F P
0 g
s
.975 .912 .676 r
.67785 .17926 m .67615 .16835 L .68335 .15324 L p F P
0 g
s
.755 .881 .936 r
.69311 .35806 m .69679 .35593 L .69515 .3596 L closepath p F P
0 g
s
.781 .89 .923 r
.72207 .34054 m .69679 .35593 L .69515 .3596 L p F P
0 g
s
.869 .482 .006 r
.47565 .17873 m .46923 .16913 L .4656 .15797 L p F P
0 g
s
.472 .538 .844 r
.57479 .26625 m .55359 .26332 L .54998 .25621 L p F P
0 g
s
.514 .566 .845 r
.55359 .26332 m .57479 .26625 L .57186 .27838 L p F P
0 g
s
.899 .927 .827 r
.66382 .19668 m .67513 .18352 L .66834 .1801 L p F P
0 g
s
.457 .551 .864 r
.57186 .27838 m .59016 .27925 L .58269 .2674 L p F P
0 g
s
.457 .551 .864 r
.58269 .2674 m .57479 .26625 L .57186 .27838 L p F P
0 g
s
0 .156 .697 r
.54661 .17769 m .54283 .16727 L .53371 .15791 L p F P
0 g
s
0 .051 .609 r
.52881 .14778 m .53371 .15791 L .54283 .16727 L p F P
0 g
s
.833 .684 .144 r
.82708 .12651 m .82791 .13768 L .82726 .15066 L p F P
0 g
s
.745 .578 .003 r
.82791 .13768 m .82708 .12651 L .82659 .11397 L p F P
0 g
s
.083 .336 .811 r
.56268 .19639 m .55908 .18602 L .54661 .17769 L p F P
0 g
s
.003 .306 .798 r
.54283 .16727 m .54661 .17769 L .55908 .18602 L p F P
0 g
s
.473 .49 .795 r
.5273 .29786 m .52941 .29405 L p .54392 .31337 L F P
0 g
s
.421 .459 .794 r
.5273 .29786 m .52515 .29266 L .52941 .29405 L closepath p F P
0 g
s
.948 .604 .207 r
.52312 .13733 m .51649 .1277 L .51447 .11605 L p F P
0 g
s
.927 .774 .297 r
.75996 .12612 m .76144 .13717 L .75988 .15039 L p F P
0 g
s
.838 .655 .111 r
.76144 .13717 m .75996 .12612 L .75992 .1135 L p F P
0 g
s
.592 .7 .917 r
.62086 .29749 m .63398 .29423 L .62675 .28528 L p F P
0 g
s
.592 .7 .917 r
.62675 .28528 m .62185 .28617 L .62086 .29749 L p F P
0 g
s
.626 .69 .89 r
.59758 .29068 m .62185 .28617 L .62086 .29749 L p F P
0 g
s
.921 .975 .707 r
.80227 .24864 m .80062 .25736 L .79007 .27381 L p F P
0 g
s
.832 .878 .877 r
.66382 .19668 m .64678 .21224 L .6397 .20561 L p F P
0 g
s
.832 .878 .877 r
.6397 .20561 m .66343 .18538 L .66382 .19668 L p F P
0 g
s
.899 .927 .827 r
.66834 .1801 m .66343 .18538 L .66382 .19668 L p F P
0 g
s
.427 .454 .786 r
.52941 .29405 m .52515 .29266 L .51783 .27431 L p F P
0 g
s
.942 .955 .745 r
.74467 .20529 m .74405 .2167 L .73354 .23305 L p F P
0 g
s
.955 .949 .661 r
.74864 .19769 m .7522 .19658 L p .74405 .2167 L F P
0 g
s
.955 .949 .661 r
.74405 .2167 m .74467 .20529 L .74864 .19769 L p F P
0 g
s
.965 .934 .63 r
.74864 .19769 m .75222 .18992 L .7522 .19658 L closepath p F P
0 g
s
.958 .901 .524 r
.75734 .1754 m .75222 .18992 L .7522 .19658 L p F P
0 g
s
.165 .402 .845 r
.56268 .19639 m .56679 .19814 L .55926 .18612 L p F P
0 g
s
.165 .402 .845 r
.55926 .18612 m .55908 .18602 L .56268 .19639 L p F P
0 g
s
.582 .63 .864 r
.57689 .34505 m .59966 .34361 L .59163 .35691 L p F P
0 g
s
.547 .62 .876 r
.59163 .35691 m .61345 .35418 L .60606 .34326 L p F P
0 g
s
.547 .62 .876 r
.60606 .34326 m .59966 .34361 L .59163 .35691 L p F P
0 g
s
.472 .538 .844 r
.54998 .25621 m .55185 .24967 L p .57479 .26625 L F P
0 g
s
.423 .507 .84 r
.54998 .25621 m .54599 .24826 L .55185 .24967 L closepath p F P
0 g
s
.743 .86 .935 r
.69679 .35593 m .69311 .35806 L .68624 .35215 L p F P
0 g
s
.692 .844 .956 r
.65708 .36449 m .68624 .35215 L .69311 .35806 L p F P
0 g
s
.963 .76 .317 r
.68424 .10904 m .686 .11552 L .68509 .12838 L p F P
0 g
s
.974 .901 .551 r
.75661 .16426 m .75734 .1754 L .75222 .18992 L p F P
0 g
s
.948 .846 .416 r
.75734 .1754 m .75661 .16426 L .75988 .15039 L p F P
0 g
s
.599 .667 .887 r
.62185 .28617 m .59758 .29068 L .59016 .27925 L p F P
0 g
s
.869 .805 .318 r
.82221 .19144 m .82232 .18929 L .82548 .17536 L p F P
0 g
s
.907 .822 .356 r
.82541 .16411 m .82548 .17536 L .82232 .18929 L p F P
0 g
s
.852 .746 .229 r
.82548 .17536 m .82541 .16411 L .82726 .15066 L p F P
0 g
s
.743 .86 .935 r
.68624 .35215 m .70142 .34388 L .69679 .35593 L p F P
0 g
s
.764 .901 .937 r
.71539 .33592 m .70142 .34388 L .69679 .35593 L p F P
0 g
s
.764 .901 .937 r
.69679 .35593 m .72207 .34054 L .71539 .33592 L p F P
0 g
s
.935 .918 .541 r
.81774 .20374 m .81687 .21513 L .81065 .23015 L p F P
0 g
s
.908 .871 .436 r
.82124 .19283 m .82221 .19144 L p .81687 .21513 L F P
0 g
s
.908 .871 .436 r
.81687 .21513 m .81774 .20374 L .82124 .19283 L p F P
0 g
s
.629 .762 .942 r
.62077 .36437 m .64996 .35652 L .65708 .36449 L p F P
0 g
s
.606 .734 .936 r
.64996 .35652 m .62077 .36437 L .61345 .35418 L p F P
0 g
s
.805 .614 .056 r
.82508 .10291 m .82659 .11397 L .82708 .12651 L p F P
0 g
s
.673 .791 .938 r
.63595 .20738 m .61071 .21846 L .60338 .20895 L p F P
0 g
s
.767 .888 .931 r
.69682 .27095 m .6701 .28883 L .6631 .28223 L p F P
0 g
s
.427 .454 .786 r
.51783 .27431 m .51809 .2737 L p .52941 .29405 L F P
0 g
s
.361 .413 .78 r
.51783 .27431 m .51747 .2734 L .51809 .2737 L closepath p F P
0 g
s
.888 .683 .165 r
.75937 .11076 m .75992 .1135 L .75996 .12612 L p F P
0 g
s
.363 .412 .778 r
.51809 .2737 m .51747 .2734 L .50976 .25381 L p F P
0 g
s
.473 .49 .795 r
.52941 .29405 m .54926 .30057 L .54392 .31337 L p F P
0 g
s
.378 .485 .842 r
.53415 .28131 m .52941 .29405 L .54926 .30057 L p F P
0 g
s
.427 .454 .786 r
.51809 .2737 m .53415 .28131 L .52941 .29405 L p F P
0 g
s
.674 .816 .951 r
.68624 .35215 m .65708 .36449 L .64996 .35652 L p F P
0 g
s
.917 .973 .778 r
.79007 .27381 m .79232 .26222 L p .77767 .28822 L F P
0 g
s
.917 .973 .778 r
.77767 .28822 m .77918 .28841 L .79007 .27381 L p F P
0 g
s
.921 .975 .707 r
.80083 .24895 m .80227 .24864 L p .79007 .27381 L F P
0 g
s
.921 .975 .707 r
.79007 .27381 m .79232 .26222 L .80083 .24895 L p F P
0 g
s
.971 .897 .69 r
.68111 .14237 m .68335 .15324 L .67615 .16835 L p F P
0 g
s
.993 .869 .535 r
.68335 .15324 m .68111 .14237 L .68509 .12838 L p F P
0 g
s
.236 .369 .795 r
.52141 .26129 m .51809 .2737 L .53415 .28131 L p F P
0 g
s
.363 .412 .778 r
.50976 .25381 m .52141 .26129 L .51809 .2737 L p F P
0 g
s
.422 .508 .842 r
.55185 .24967 m .54599 .24826 L .53836 .23317 L p F P
0 g
s
.537 .623 .884 r
.56679 .19814 m .59241 .19903 L .5959 .20937 L p F P
0 g
s
.493 .606 .893 r
.59241 .19903 m .56679 .19814 L .55926 .18612 L p F P
0 g
s
.556 .603 .856 r
.59966 .34361 m .57689 .34505 L .56935 .33139 L p F P
0 g
s
.916 .946 .805 r
.73354 .23305 m .72738 .24114 L .72087 .2385 L p F P
0 g
s
.916 .946 .805 r
.72087 .2385 m .73406 .22173 L .73354 .23305 L p F P
0 g
s
.942 .955 .745 r
.73354 .23305 m .73406 .22173 L .74467 .20529 L p F P
0 g
s
.509 .521 .805 r
.54392 .31337 m .56176 .31703 L p .56421 .33086 L F P
0 g
s
.404 .467 .812 r
.54392 .31337 m .56176 .31703 L .55413 .30218 L p F P
0 g
s
.404 .467 .812 r
.55413 .30218 m .54926 .30057 L .54392 .31337 L p F P
0 g
s
.147 .281 .745 r
.50976 .25381 m .50854 .25274 L .50864 .25107 L closepath p F P
0 g
s
.137 .271 .74 r
.50203 .23457 m .49953 .23159 L p .50854 .25274 L F P
0 g
s
.137 .271 .74 r
.50854 .25274 m .50864 .25107 L .50203 .23457 L p F P
0 g
s
.666 .767 .925 r
.6456 .28952 m .63398 .29423 L .62675 .28528 L p F P
0 g
s
.89 .952 .839 r
.7185 .25092 m .72738 .24114 L .72087 .2385 L p F P
0 g
s
.916 .868 .434 r
.82124 .19283 m .82232 .18929 L .82221 .19144 L closepath p F P
0 g
s
0 .128 .671 r
.50203 .23457 m .49953 .23159 L .49864 .22683 L closepath p F P
0 g
s
0 .104 .653 r
.49429 .21671 m .4903 .21049 L p .49953 .23159 L F P
0 g
s
0 .104 .653 r
.49953 .23159 m .49864 .22683 L .49429 .21671 L p F P
0 g
s
.9 .687 .178 r
.75755 .10262 m .75937 .11076 L .75902 .12145 L p F P
0 g
s
.888 .683 .165 r
.75996 .12612 m .75902 .12145 L .75937 .11076 L p F P
0 g
s
.274 .364 .774 r
.52141 .26129 m .50976 .25381 L .50864 .25107 L p F P
0 g
s
.12 .326 .795 r
.5307 .21846 m .5224 .21116 L p .53516 .23107 L F P
0 g
s
0 .167 .704 r
.5224 .21116 m .5307 .21846 L .52301 .20467 L p F P
0 g
s
0 .167 .704 r
.52301 .20467 m .5191 .20066 L .5224 .21116 L p F P
0 g
s
0 .115 .667 r
.5224 .21116 m .5191 .20066 L .51057 .19094 L p F P
0 g
s
.8 .916 .917 r
.7352 .33069 m .72207 .34054 L .71539 .33592 L p F P
0 g
s
0 0 .559 r
.50585 .18083 m .51057 .19094 L .5191 .20066 L p F P
0 g
s
.898 .77 .276 r
.82645 .13951 m .82726 .15066 L .82541 .16411 L p F P
0 g
s
.833 .684 .144 r
.82726 .15066 m .82645 .13951 L .82708 .12651 L p F P
0 g
s
.893 .983 .804 r
.77688 .29115 m .77767 .28822 L .77918 .28841 L closepath p F P
0 g
s
.15 .352 .809 r
.53836 .23317 m .53516 .23107 L .53405 .22497 L closepath p F P
0 g
s
.12 .326 .795 r
.53516 .23107 m .53405 .22497 L .5307 .21846 L p F P
0 g
s
.737 .312 0 r
.49891 .17067 m .49229 .1611 L .48687 .15052 L p F P
0 g
s
.274 .364 .774 r
.50864 .25107 m .50971 .24092 L p .52141 .26129 L F P
0 g
s
.177 .298 .75 r
.50864 .25107 m .50203 .23457 L .50971 .24092 L closepath p F P
0 g
s
.973 .852 .453 r
.7584 .13937 m .75988 .15039 L .75661 .16426 L p F P
0 g
s
.927 .774 .297 r
.75988 .15039 m .7584 .13937 L .75996 .12612 L p F P
0 g
s
.856 .903 .866 r
.7185 .25092 m .72012 .23929 L p .6975 .26838 L F P
0 g
s
.856 .903 .866 r
.6975 .26838 m .69895 .26939 L .7185 .25092 L p F P
0 g
s
.89 .952 .839 r
.72087 .2385 m .72012 .23929 L .7185 .25092 L p F P
0 g
s
.875 .969 .849 r
.77767 .28822 m .77688 .29115 L .7593 .3099 L p F P
0 g
s
.767 .888 .931 r
.6975 .26838 m .69682 .27095 L p .6631 .28223 L F P
0 g
s
.806 .904 .91 r
.69682 .27095 m .6975 .26838 L .69895 .26939 L closepath p F P
0 g
s
0 0 .412 r
.4903 .21049 m .49429 .21671 L .48651 .20159 L p F P
0 g
s
.487 .555 .851 r
.56935 .33139 m .56421 .33086 L .56656 .32608 L closepath p F P
0 g
s
.509 .521 .805 r
.56176 .31703 m .56656 .32608 L .56421 .33086 L p F P
0 g
s
.975 .924 .653 r
.75222 .18992 m .7515 .1788 L p .7446 .19794 L F P
0 g
s
.975 .924 .653 r
.7446 .19794 m .74864 .19769 L .75222 .18992 L p F P
0 g
s
.974 .901 .551 r
.75222 .18992 m .7515 .1788 L .75661 .16426 L p F P
0 g
s
.932 .948 .614 r
.81065 .23015 m .8027 .24577 L .80227 .24864 L p F P
0 g
s
.945 .949 .633 r
.8116 .21877 m .81065 .23015 L .8027 .24577 L p F P
0 g
s
.935 .918 .541 r
.81065 .23015 m .8116 .21877 L .81774 .20374 L p F P
0 g
s
.8 .916 .917 r
.71539 .33592 m .73938 .31869 L .7352 .33069 L p F P
0 g
s
.825 .948 .901 r
.7444 .3148 m .73938 .31869 L .7352 .33069 L p F P
0 g
s
.825 .948 .901 r
.7352 .33069 m .75085 .31798 L .7444 .3148 L p F P
0 g
s
.817 .406 0 r
.48037 .18961 m .47375 .18009 L .46923 .16913 L p F P
0 g
s
.976 .752 .33 r
.6828 .10483 m .68424 .10904 L .68225 .11794 L p F P
0 g
s
.963 .76 .317 r
.68509 .12838 m .68225 .11794 L .68424 .10904 L p F P
0 g
s
.946 .88 .472 r
.82232 .18929 m .8223 .17805 L p .81786 .19654 L F P
0 g
s
.946 .88 .472 r
.81786 .19654 m .82124 .19283 L .82232 .18929 L p F P
0 g
s
.907 .822 .356 r
.82232 .18929 m .8223 .17805 L .82541 .16411 L p F P
0 g
s
.472 .538 .844 r
.55185 .24967 m .57432 .25511 L .57479 .26625 L p F P
0 g
s
.363 .533 .889 r
.55261 .23802 m .55185 .24967 L .57432 .25511 L p F P
0 g
s
.422 .508 .842 r
.53836 .23317 m .55261 .23802 L .55185 .24967 L p F P
0 g
s
.481 .636 .923 r
.5959 .20937 m .60338 .20895 L .596 .19911 L p F P
0 g
s
.481 .636 .923 r
.596 .19911 m .59241 .19903 L .5959 .20937 L p F P
0 g
s
.855 .951 .876 r
.7593 .3099 m .75085 .31798 L .7444 .3148 L p F P
0 g
s
.855 .951 .876 r
.7444 .3148 m .76231 .29818 L .7593 .3099 L p F P
0 g
s
.875 .969 .849 r
.77302 .28706 m .77767 .28822 L p .7593 .3099 L F P
0 g
s
.875 .969 .849 r
.7593 .3099 m .76231 .29818 L .77302 .28706 L p F P
0 g
s
.666 .767 .925 r
.62675 .28528 m .64897 .27739 L .6456 .28952 L p F P
0 g
s
.692 .805 .935 r
.65602 .27485 m .64897 .27739 L .6456 .28952 L p F P
0 g
s
.692 .805 .935 r
.6456 .28952 m .6631 .28223 L .65602 .27485 L p F P
0 g
s
.997 .86 .562 r
.68225 .11794 m .68509 .12838 L .68111 .14237 L p F P
0 g
s
.928 .881 .768 r
.67615 .16835 m .67368 .1576 L p .6627 .17623 L F P
0 g
s
.928 .881 .768 r
.6627 .17623 m .66834 .1801 L .67615 .16835 L p F P
0 g
s
.971 .897 .69 r
.67615 .16835 m .67368 .1576 L .68111 .14237 L p F P
0 g
s
.131 .29 .759 r
.50971 .24092 m .50203 .23457 L .49864 .22683 L p F P
0 g
s
.933 .966 .683 r
.80083 .24895 m .8027 .24577 L .80227 .24864 L closepath p F P
0 g
s
0 .051 .609 r
.54283 .16727 m .53731 .15736 L .52881 .14778 L p F P
0 g
s
.599 .667 .887 r
.59016 .27925 m .61944 .27576 L p .62185 .28617 L F P
0 g
s
.525 .669 .928 r
.61944 .27576 m .59016 .27925 L .58269 .2674 L p F P
0 g
s
.356 .481 .848 r
.55261 .23802 m .53836 .23317 L .53405 .22497 L p F P
0 g
s
.94 .884 .475 r
.81774 .20374 m .81786 .19654 L .82124 .19283 L closepath p F P
0 g
s
.826 .893 .89 r
.69215 .26434 m .6981 .25949 L .6975 .26838 L closepath p F P
0 g
s
.856 .903 .866 r
.72012 .23929 m .6981 .25949 L .6975 .26838 L p F P
0 g
s
.767 .888 .931 r
.6631 .28223 m .69215 .26434 L .6975 .26838 L p F P
0 g
s
.9 .971 .815 r
.77302 .28706 m .77936 .27954 L .77767 .28822 L closepath p F P
0 g
s
.917 .973 .778 r
.79232 .26222 m .77936 .27954 L .77767 .28822 L p F P
0 g
s
.003 .306 .798 r
.55168 .17415 m .54283 .16727 L p .55908 .18602 L F P
0 g
s
0 .208 .734 r
.54283 .16727 m .55168 .17415 L .54407 .16309 L p F P
0 g
s
0 .208 .734 r
.54407 .16309 m .53731 .15736 L .54283 .16727 L p F P
0 g
s
.963 .942 .679 r
.74467 .20529 m .7446 .19794 L .74864 .19769 L closepath p F P
0 g
s
.673 .791 .938 r
.63741 .20322 m .63595 .20738 L p .60338 .20895 L F P
0 g
s
.712 .811 .926 r
.63595 .20738 m .63741 .20322 L .6397 .20561 L closepath p F P
0 g
s
.556 .603 .856 r
.56935 .33139 m .59861 .33173 L p .59966 .34361 L F P
0 g
s
.491 .558 .851 r
.5911 .31972 m .59861 .33173 L .56935 .33139 L p F P
0 g
s
.491 .558 .851 r
.57079 .31779 m .5911 .31972 L p .56935 .33139 L F P
0 g
s
.491 .558 .851 r
.56935 .33139 m .56656 .32608 L .57079 .31779 L p F P
0 g
s
.881 .71 .193 r
.82558 .11547 m .82708 .12651 L .82645 .13951 L p F P
0 g
s
.805 .614 .056 r
.82708 .12651 m .82558 .11547 L .82508 .10291 L p F P
0 g
s
.606 .734 .936 r
.61345 .35418 m .64277 .34782 L .64996 .35652 L p F P
0 g
s
.581 .709 .93 r
.64277 .34782 m .61345 .35418 L .60606 .34326 L p F P
0 g
s
.959 .787 .342 r
.75902 .12145 m .75996 .12612 L .7584 .13937 L p F P
0 g
s
.016 .207 .717 r
.49864 .22683 m .49429 .21671 L .49803 .22054 L closepath p F P
0 g
s
.131 .29 .759 r
.49864 .22683 m .49803 .22054 L p .50971 .24092 L F P
0 g
s
.819 .831 .858 r
.63741 .20322 m .6397 .20561 L .66343 .18538 L p F P
0 g
s
.123 .399 .85 r
.55926 .18612 m .55908 .18602 L .55876 .18536 L closepath p F P
0 g
s
.003 .306 .798 r
.55908 .18602 m .55876 .18536 L .55168 .17415 L p F P
0 g
s
.446 .593 .905 r
.58756 .18904 m .55926 .18612 L .55876 .18536 L p F P
0 g
s
.493 .606 .893 r
.55926 .18612 m .58756 .18904 L .59241 .19903 L p F P
0 g
s
.88 .901 .841 r
.66343 .18538 m .6627 .17623 L .66834 .1801 L closepath p F P
0 g
s
.387 .529 .877 r
.57479 .26625 m .58269 .2674 L .57516 .25532 L p F P
0 g
s
.387 .529 .877 r
.57516 .25532 m .57432 .25511 L .57479 .26625 L p F P
0 g
s
.976 .752 .33 r
.68225 .11794 m .68214 .11763 L .6828 .10483 L p F P
0 g
s
.989 .752 .369 r
.67839 .09446 m .6828 .10483 L .68214 .11763 L p F P
0 g
s
.673 .791 .938 r
.60338 .20895 m .63253 .19797 L .63741 .20322 L p F P
0 g
s
.649 .769 .937 r
.63253 .19797 m .60338 .20895 L .596 .19911 L p F P
0 g
s
.729 .847 .937 r
.70142 .34388 m .68624 .35215 L .67928 .34546 L p F P
0 g
s
.674 .816 .951 r
.64996 .35652 m .67928 .34546 L .68624 .35215 L p F P
0 g
s
.819 .831 .858 r
.66343 .18538 m .6627 .17623 L p .63741 .20322 L F P
0 g
s
.446 .593 .905 r
.55876 .18536 m .55664 .17514 L p .58756 .18904 L F P
0 g
s
.39 .552 .895 r
.55876 .18536 m .55168 .17415 L .55664 .17514 L closepath p F P
0 g
s
.59 .709 .926 r
.62675 .28528 m .62185 .28617 L .62017 .2767 L closepath p F P
0 g
s
.599 .667 .887 r
.61944 .27576 m .62017 .2767 L .62185 .28617 L p F P
0 g
s
.943 .962 .708 r
.8027 .24577 m .80083 .24895 L .79492 .24912 L p F P
0 g
s
.943 .962 .708 r
.79492 .24912 m .80373 .23442 L .8027 .24577 L p F P
0 g
s
.945 .949 .633 r
.8027 .24577 m .80373 .23442 L .8116 .21877 L p F P
0 g
s
.943 .942 .757 r
.7446 .19794 m .74467 .20529 L .73406 .22173 L p F P
0 g
s
.494 .56 .853 r
.56656 .32608 m .56176 .31703 L .57079 .31779 L closepath p F P
0 g
s
.356 .481 .848 r
.53405 .22497 m .53398 .21996 L p .55261 .23802 L F P
0 g
s
.289 .434 .834 r
.53405 .22497 m .5307 .21846 L .53398 .21996 L closepath p F P
0 g
s
.933 .97 .724 r
.79232 .26222 m .80083 .24895 L .79492 .24912 L p F P
0 g
s
0 .167 .704 r
.49803 .22054 m .49429 .21671 L .48651 .20159 L p F P
0 g
s
.985 .896 .575 r
.75514 .15326 m .75661 .16426 L .7515 .1788 L p F P
0 g
s
.973 .852 .453 r
.75661 .16426 m .75514 .15326 L .7584 .13937 L p F P
0 g
s
.942 .836 .395 r
.82463 .15298 m .82541 .16411 L .8223 .17805 L p F P
0 g
s
.898 .77 .276 r
.82541 .16411 m .82463 .15298 L .82645 .13951 L p F P
0 g
s
.655 .791 .947 r
.67928 .34546 m .64996 .35652 L .64277 .34782 L p F P
0 g
s
.748 .863 .933 r
.69215 .26434 m .6631 .28223 L .65602 .27485 L p F P
0 g
s
.855 .643 .105 r
.824 .09734 m .82508 .10291 L .82558 .11547 L p F P
0 g
s
.957 .922 .572 r
.81786 .19654 m .81774 .20374 L .8116 .21877 L p F P
0 g
s
.9 .687 .178 r
.75902 .12145 m .75762 .11525 L .75755 .10262 L p F P
0 g
s
.935 .704 .225 r
.7544 .09191 m .75755 .10262 L .75762 .11525 L p F P
0 g
s
.666 .739 .905 r
.61944 .27576 m .62324 .2746 L p .64878 .27737 L F P
0 g
s
.666 .739 .905 r
.64897 .27739 m .64878 .27738 L .64878 .27737 L F
.64878 .27738 m .61944 .27576 L .64878 .27737 L F
.62324 .2746 m .65387 .27246 L p .64897 .27739 L F P
0 g
s
.666 .739 .905 r
.64878 .27738 m .62027 .27671 L .61953 .27577 L F
.64876 .27739 m .62017 .2767 L p .64878 .27738 L F P
0 g
s
.666 .778 .933 r
.64886 .26682 m .62324 .2746 L p .62659 .28481 L F P
0 g
s
.666 .778 .933 r
.62675 .28528 m .62688 .28517 L .62659 .28481 L F
.62688 .28517 m .64886 .26682 L .62659 .28481 L F
.666 .739 .905 r
.62017 .2767 m .61944 .27576 L p .61953 .27577 L F P
0 g
s
.666 .739 .905 r
.62027 .27671 m .62017 .2767 L .61953 .27577 L F
.64897 .27739 m .64876 .27739 L p .64878 .27738 L F P
0 g
s
.666 .778 .933 r
.62688 .28517 m .64891 .27481 L .64886 .26682 L F
.62675 .28528 m .62728 .28503 L .62688 .28517 L F
.62728 .28503 m .64891 .27481 L .62688 .28517 L F
.65387 .27246 m .64928 .2673 L p .64891 .27481 L F P
0 g
s
.666 .778 .933 r
.64928 .2673 m .64886 .26682 L p .64891 .27481 L F P
0 g
s
.666 .778 .933 r
.62324 .2746 m .62017 .2767 L .62675 .28528 L p F P
0 g
s
.666 .778 .933 r
.62675 .28528 m .64897 .27739 L .65387 .27246 L p F P
0 g
s
.778 .819 .885 r
.63253 .19797 m .63516 .19617 L .63741 .20322 L closepath p F P
0 g
s
.819 .831 .858 r
.6614 .17517 m .63516 .19617 L .63741 .20322 L p F P
0 g
s
.819 .831 .858 r
.6627 .17623 m .6614 .17517 L p .63741 .20322 L F P
0 g
s
.965 .881 .701 r
.67807 .13168 m .68111 .14237 L .67368 .1576 L p F P
0 g
s
.997 .86 .562 r
.68206 .118 m .68225 .11794 L p .68111 .14237 L F P
0 g
s
.997 .86 .562 r
.68111 .14237 m .67807 .13168 L .68206 .118 L p F P
0 g
s
.729 .847 .937 r
.67928 .34546 m .70656 .33155 L .70142 .34388 L p F P
0 g
s
.751 .876 .936 r
.70861 .33046 m .70656 .33155 L .70142 .34388 L p F P
0 g
s
.751 .876 .936 r
.70142 .34388 m .71539 .33592 L .70861 .33046 L p F P
0 g
s
.26 .438 .848 r
.53398 .21996 m .5307 .21846 L .52301 .20467 L p F P
0 g
s
.542 .638 .895 r
.60606 .34326 m .59966 .34361 L .60196 .33689 L closepath p F P
0 g
s
.556 .603 .856 r
.59861 .33173 m .60196 .33689 L .59966 .34361 L p F P
0 g
s
.964 .783 .343 r
.75762 .11525 m .75902 .12145 L .75628 .12893 L p F P
0 g
s
.959 .787 .342 r
.7584 .13937 m .75628 .12893 L .75902 .12145 L p F P
0 g
s
.92 .968 .781 r
.79384 .25076 m .79232 .26222 L .77936 .27954 L p F P
0 g
s
.933 .97 .724 r
.79492 .24912 m .79384 .25076 L .79232 .26222 L p F P
0 g
s
.913 .92 .807 r
.73406 .22173 m .73384 .21053 L p .72021 .23813 L F P
0 g
s
.913 .92 .807 r
.72021 .23813 m .72087 .2385 L .73406 .22173 L p F P
0 g
s
.943 .942 .757 r
.7424 .19748 m .7446 .19794 L p .73406 .22173 L F P
0 g
s
.943 .942 .757 r
.73406 .22173 m .73384 .21053 L .7424 .19748 L p F P
0 g
s
.497 .555 .845 r
.57079 .31779 m .56176 .31703 L .55413 .30218 L p F P
0 g
s
0 0 .559 r
.5191 .20066 m .51375 .19076 L .50585 .18083 L p F P
0 g
s
.525 .669 .928 r
.58269 .2674 m .61207 .26578 L .61944 .27576 L p F P
0 g
s
.489 .646 .927 r
.61207 .26578 m .58269 .2674 L .57516 .25532 L p F P
0 g
s
0 .058 .617 r
.5191 .20066 m .52301 .20467 L .51528 .19247 L p F P
0 g
s
0 .058 .617 r
.51528 .19247 m .51375 .19076 L .5191 .20066 L p F P
0 g
s
.236 .369 .795 r
.53415 .28131 m .53493 .26975 L .52141 .26129 L p F P
0 g
s
.171 .371 .819 r
.52106 .24998 m .52141 .26129 L .53493 .26975 L p F P
0 g
s
.274 .364 .774 r
.50971 .24092 m .52106 .24998 L .52141 .26129 L p F P
0 g
s
.131 .29 .759 r
.49803 .22054 m .50778 .23002 L .50971 .24092 L p F P
0 g
s
0 .212 .734 r
.50778 .23002 m .50971 .24092 L .52106 .24998 L p F P
0 g
s
.378 .485 .842 r
.54647 .28708 m .53415 .28131 L p .54926 .30057 L F P
0 g
s
.241 .373 .798 r
.53415 .28131 m .54647 .28708 L .53876 .2721 L p F P
0 g
s
.241 .373 .798 r
.53876 .2721 m .53493 .26975 L .53415 .28131 L p F P
0 g
s
0 .108 .661 r
.49413 .21019 m .49803 .22054 L .50778 .23002 L p F P
0 g
s
0 .167 .704 r
.48651 .20159 m .49413 .21019 L .49803 .22054 L p F P
0 g
s
.934 .786 .318 r
.82496 .12849 m .82645 .13951 L .82463 .15298 L p F P
0 g
s
.881 .71 .193 r
.82645 .13951 m .82496 .12849 L .82558 .11547 L p F P
0 g
s
.988 .851 .483 r
.75628 .12893 m .7584 .13937 L .75514 .15326 L p F P
0 g
s
.788 .916 .926 r
.73938 .31869 m .71539 .33592 L .70861 .33046 L p F P
0 g
s
.356 .481 .848 r
.53398 .21996 m .55057 .2272 L .55261 .23802 L p F P
0 g
s
.155 .41 .853 r
.53146 .2092 m .53398 .21996 L .55057 .2272 L p F P
0 g
s
.26 .438 .848 r
.52301 .20467 m .53146 .2092 L .53398 .21996 L p F P
0 g
s
.376 .483 .841 r
.55413 .30218 m .54926 .30057 L .55034 .29469 L closepath p F P
0 g
s
.378 .485 .842 r
.54926 .30057 m .55034 .29469 L .54647 .28708 L p F P
0 g
s
.814 .877 .892 r
.6981 .25949 m .69215 .26434 L .68525 .25839 L p F P
0 g
s
.748 .863 .933 r
.65602 .27485 m .68525 .25839 L .69215 .26434 L p F P
0 g
s
.581 .709 .93 r
.60606 .34326 m .63549 .33849 L .64277 .34782 L p F P
0 g
s
.566 .65 .892 r
.62815 .32864 m .63549 .33849 L .60606 .34326 L p F P
0 g
s
.566 .65 .892 r
.60511 .331 m .62815 .32864 L p .60606 .34326 L F P
0 g
s
.566 .65 .892 r
.60606 .34326 m .60196 .33689 L .60511 .331 L p F P
0 g
s
.431 .617 .929 r
.59241 .19903 m .596 .19911 L .58855 .18914 L p F P
0 g
s
.431 .617 .929 r
.58855 .18914 m .58756 .18904 L .59241 .19903 L p F P
0 g
s
.976 .916 .667 r
.75002 .16784 m .7515 .1788 L .74433 .19409 L p F P
0 g
s
.985 .896 .575 r
.7515 .1788 m .75002 .16784 L .75514 .15326 L p F P
0 g
s
.975 .924 .653 r
.7515 .1788 m .74433 .19409 L .7446 .19794 L p F P
0 g
s
.881 .932 .85 r
.72012 .23929 m .72021 .23813 L .72087 .2385 L closepath p F P
0 g
s
0 0 .52 r
.53731 .15736 m .53032 .14785 L .52203 .1382 L p F P
0 g
s
.841 .895 .878 r
.72021 .23813 m .72012 .23929 L .6981 .25949 L p F P
0 g
s
1 .833 .522 r
.68206 .118 m .68214 .11763 L .68225 .11794 L closepath p F P
0 g
s
.814 .877 .892 r
.68525 .25839 m .69819 .24831 L .6981 .25949 L p F P
0 g
s
.841 .895 .878 r
.7142 .23428 m .72021 .23813 L p .6981 .25949 L F P
0 g
s
.841 .895 .878 r
.6981 .25949 m .69819 .24831 L .7142 .23428 L p F P
0 g
s
.369 .564 .911 r
.55664 .17514 m .55168 .17415 L .54407 .16309 L p F P
0 g
s
.899 .958 .826 r
.77936 .27954 m .77302 .28706 L .76672 .28452 L p F P
0 g
s
.899 .958 .826 r
.76672 .28452 m .78087 .26813 L .77936 .27954 L p F P
0 g
s
.92 .968 .781 r
.77936 .27954 m .78087 .26813 L .79384 .25076 L p F P
0 g
s
.959 .944 .651 r
.81182 .20753 m .8116 .21877 L .80373 .23442 L p F P
0 g
s
.957 .922 .572 r
.81586 .19763 m .81786 .19654 L p .8116 .21877 L F P
0 g
s
.957 .922 .572 r
.8116 .21877 m .81182 .20753 L .81586 .19763 L p F P
0 g
s
.997 .821 .545 r
.68214 .11763 m .68206 .118 L .67538 .11725 L p F P
0 g
s
.997 .821 .545 r
.67538 .11725 m .67771 .10729 L .68214 .11763 L p F P
0 g
s
.989 .752 .369 r
.68214 .11763 m .67771 .10729 L .67839 .09446 L p F P
0 g
s
.856 .643 .106 r
.82294 .09196 m .824 .09734 L .82421 .10849 L p F P
0 g
s
.855 .643 .105 r
.82558 .11547 m .82421 .10849 L .824 .09734 L p F P
0 g
s
.995 .847 .579 r
.67807 .13168 m .68206 .118 L .67538 .11725 L p F P
0 g
s
.946 .88 .472 r
.8223 .17805 m .81785 .1925 L .81786 .19654 L p F P
0 g
s
.965 .883 .498 r
.82157 .16693 m .8223 .17805 L .81785 .1925 L p F P
0 g
s
.942 .836 .395 r
.8223 .17805 m .82157 .16693 L .82463 .15298 L p F P
0 g
s
.928 .881 .768 r
.67368 .1576 m .66218 .17426 L .6627 .17623 L p F P
0 g
s
.914 .869 .779 r
.67043 .14701 m .67368 .1576 L .66218 .17426 L p F P
0 g
s
.965 .881 .701 r
.67368 .1576 m .67043 .14701 L .67807 .13168 L p F P
0 g
s
.959 .934 .72 r
.7424 .19748 m .74433 .19409 L .7446 .19794 L closepath p F P
0 g
s
0 .155 .682 r
.53731 .15736 m .54407 .16309 L .53642 .15316 L p F P
0 g
s
0 .155 .682 r
.53642 .15316 m .53032 .14785 L .53731 .15736 L p F P
0 g
s
.877 .961 .851 r
.76231 .29818 m .77302 .28706 L .76672 .28452 L p F P
0 g
s
.913 .92 .807 r
.73384 .21053 m .7198 .22817 L .72021 .23813 L p F P
0 g
s
.885 .914 .84 r
.7142 .23428 m .7198 .22817 L .72021 .23813 L closepath p F P
0 g
s
.363 .533 .889 r
.56759 .24316 m .55261 .23802 L p .57432 .25511 L F P
0 g
s
.264 .451 .857 r
.55261 .23802 m .56759 .24316 L .55997 .23128 L p F P
0 g
s
.264 .451 .857 r
.55997 .23128 m .55057 .2272 L .55261 .23802 L p F P
0 g
s
.788 .916 .926 r
.74117 .31281 m .73938 .31869 L p .70861 .33046 L F P
0 g
s
.817 .927 .907 r
.73938 .31869 m .74117 .31281 L .7444 .3148 L closepath p F P
0 g
s
.649 .769 .937 r
.596 .19911 m .62527 .18969 L .63253 .19797 L p F P
0 g
s
.628 .752 .936 r
.62527 .18969 m .596 .19911 L .58855 .18914 L p F P
0 g
s
.855 .925 .874 r
.76231 .29818 m .76469 .28656 L p .74117 .31281 L F P
0 g
s
.855 .925 .874 r
.74117 .31281 m .7444 .3148 L .76231 .29818 L p F P
0 g
s
.877 .961 .851 r
.76672 .28452 m .76469 .28656 L .76231 .29818 L p F P
0 g
s
.962 .915 .561 r
.81586 .19763 m .81785 .1925 L .81786 .19654 L closepath p F P
0 g
s
.765 .807 .887 r
.63516 .19617 m .63253 .19797 L .62527 .18969 L p F P
0 g
s
.887 .875 .819 r
.6614 .17517 m .66218 .17426 L .6627 .17623 L closepath p F P
0 g
s
.92 .73 .238 r
.82421 .10849 m .82558 .11547 L .82496 .12849 L p F P
0 g
s
.666 .739 .905 r
.65387 .27246 m .65602 .27485 L .64897 .27739 L p F P
0 g
s
.44 .535 .858 r
.57079 .31779 m .5911 .31972 L .58354 .3074 L p F P
0 g
s
.44 .535 .858 r
.58354 .3074 m .57407 .30564 L .57079 .31779 L p F P
0 g
s
.497 .555 .845 r
.55413 .30218 m .57407 .30564 L .57079 .31779 L p F P
0 g
s
.982 .786 .378 r
.75448 .10456 m .75762 .11525 L .75618 .12848 L p F P
0 g
s
.935 .704 .225 r
.75762 .11525 m .75448 .10456 L .7544 .09191 L p F P
0 g
s
.964 .783 .343 r
.75628 .12893 m .75618 .12848 L .75762 .11525 L p F P
0 g
s
.765 .807 .887 r
.62527 .18969 m .63104 .18598 L .63516 .19617 L p F P
0 g
s
.816 .858 .88 r
.65434 .16859 m .63104 .18598 L .63516 .19617 L p F P
0 g
s
.816 .858 .88 r
.63516 .19617 m .6614 .17517 L .65434 .16859 L p F P
0 g
s
.144 .4 .848 r
.53146 .2092 m .52301 .20467 L .51528 .19247 L p F P
0 g
s
.456 .529 .844 r
.57407 .30564 m .55413 .30218 L .55034 .29469 L p F P
0 g
s
.993 .746 .4 r
.67319 .08427 m .67839 .09446 L .67771 .10729 L p F P
0 g
s
.712 .845 .945 r
.70656 .33155 m .67928 .34546 L .67222 .33806 L p F P
0 g
s
.655 .791 .947 r
.64277 .34782 m .67222 .33806 L .67928 .34546 L p F P
0 g
s
.446 .593 .905 r
.55664 .17514 m .58106 .17914 L p .58756 .18904 L F P
0 g
s
.36 .567 .916 r
.55664 .17514 m .58106 .17914 L .57351 .16929 L p F P
0 g
s
.36 .567 .916 r
.57351 .16929 m .55188 .16496 L .55664 .17514 L p F P
0 g
s
.369 .564 .911 r
.54407 .16309 m .55188 .16496 L .55664 .17514 L p F P
0 g
s
.635 .768 .943 r
.67222 .33806 m .64277 .34782 L .63549 .33849 L p F P
0 g
s
.568 .652 .892 r
.60196 .33689 m .59861 .33173 L .60511 .331 L closepath p F P
0 g
s
.646 .722 .904 r
.62324 .2746 m .61944 .27576 L .61207 .26578 L p F P
0 g
s
.875 .857 .82 r
.66218 .17426 m .6614 .17517 L .65434 .16859 L p F P
0 g
s
.875 .857 .82 r
.65434 .16859 m .65854 .16384 L .66218 .17426 L p F P
0 g
s
.914 .869 .779 r
.66218 .17426 m .65854 .16384 L .67043 .14701 L p F P
0 g
s
.37 .538 .891 r
.57516 .25532 m .57432 .25511 L .57402 .2535 L closepath p F P
0 g
s
.363 .533 .889 r
.57432 .25511 m .57402 .2535 L .56759 .24316 L p F P
0 g
s
.743 .804 .901 r
.65387 .27246 m .65602 .27485 L .68525 .25839 L p F P
0 g
s
.956 .919 .733 r
.74433 .19409 m .7424 .19748 L .73594 .19497 L p F P
0 g
s
.956 .919 .733 r
.73594 .19497 m .74283 .18317 L .74433 .19409 L p F P
0 g
s
.976 .916 .667 r
.74433 .19409 m .74283 .18317 L .75002 .16784 L p F P
0 g
s
0 .017 .569 r
.48118 .19391 m .47914 .19084 L p .49413 .21019 L F P
0 g
s
0 0 .496 r
.48118 .19391 m .47868 .19025 L .47914 .19084 L closepath p F P
0 g
s
.951 .95 .724 r
.80373 .23442 m .80401 .22319 L p .79397 .24899 L F P
0 g
s
.951 .95 .724 r
.79397 .24899 m .79492 .24912 L .80373 .23442 L p F P
0 g
s
.959 .944 .651 r
.80373 .23442 m .80401 .22319 L .81182 .20753 L p F P
0 g
s
.991 .887 .593 r
.75293 .1424 m .75514 .15326 L .75002 .16784 L p F P
0 g
s
.988 .851 .483 r
.75604 .12913 m .75628 .12893 L p .75514 .15326 L F P
0 g
s
.988 .851 .483 r
.75514 .15326 m .75293 .1424 L .75604 .12913 L p F P
0 g
s
.489 .646 .927 r
.57516 .25532 m .60464 .25553 L .61207 .26578 L p F P
0 g
s
.485 .601 .894 r
.59716 .24516 m .60464 .25553 L .57516 .25532 L p F P
0 g
s
.485 .601 .894 r
.57472 .24358 m .59716 .24516 L p .57516 .25532 L F P
0 g
s
.485 .601 .894 r
.57516 .25532 m .57402 .2535 L .57472 .24358 L p F P
0 g
s
.622 .717 .914 r
.62324 .2746 m .64886 .26682 L .64161 .25828 L p F P
0 g
s
.622 .717 .914 r
.64161 .25828 m .62949 .26133 L .62324 .2746 L p F P
0 g
s
.646 .722 .904 r
.61207 .26578 m .62949 .26133 L .62324 .2746 L p F P
0 g
s
.966 .842 .428 r
.82317 .14197 m .82463 .15298 L .82157 .16693 L p F P
0 g
s
.934 .786 .318 r
.82463 .15298 m .82317 .14197 L .82496 .12849 L p F P
0 g
s
.411 .504 .844 r
.55034 .29469 m .54647 .28708 L .55197 .2885 L closepath p F P
0 g
s
.456 .529 .844 r
.55034 .29469 m .55197 .2885 L p .57407 .30564 L F P
0 g
s
.856 .643 .106 r
.82421 .10849 m .82343 .10454 L .82294 .09196 L p F P
0 g
s
.895 .664 .151 r
.82016 .08111 m .82294 .09196 L .82343 .10454 L p F P
0 g
s
.96 .714 .268 r
.75055 .08133 m .7544 .09191 L .75448 .10456 L p F P
0 g
s
.942 .931 .761 r
.73384 .21053 m .7424 .19748 L .73594 .19497 L p F P
0 g
s
.481 .598 .893 r
.57402 .2535 m .56759 .24316 L .57472 .24358 L closepath p F P
0 g
s
.956 .863 .708 r
.67419 .12117 m .67807 .13168 L .67043 .14701 L p F P
0 g
s
.995 .847 .579 r
.67538 .11725 m .67419 .12117 L .67807 .13168 L p F P
0 g
s
.976 .912 .587 r
.81785 .1925 m .81716 .1814 L p .81145 .19893 L F P
0 g
s
.976 .912 .587 r
.81145 .19893 m .81586 .19763 L .81785 .1925 L p F P
0 g
s
.965 .883 .498 r
.81785 .1925 m .81716 .1814 L .82157 .16693 L p F P
0 g
s
.569 .644 .884 r
.60511 .331 m .59861 .33173 L .5911 .31972 L p F P
0 g
s
0 0 .445 r
.51375 .19076 m .50674 .18133 L .49904 .17133 L p F P
0 g
s
.718 .796 .912 r
.64886 .26682 m .65217 .26519 L .65387 .27246 L closepath p F P
0 g
s
.743 .804 .901 r
.67825 .25171 m .65217 .26519 L .65387 .27246 L p F P
0 g
s
.743 .804 .901 r
.68525 .25839 m .67825 .25171 L p .65387 .27246 L F P
0 g
s
.832 .918 .893 r
.73782 .31061 m .74216 .30701 L .74117 .31281 L closepath p F P
0 g
s
.855 .925 .874 r
.76469 .28656 m .74216 .30701 L .74117 .31281 L p F P
0 g
s
.788 .916 .926 r
.70861 .33046 m .73782 .31061 L .74117 .31281 L p F P
0 g
s
0 .017 .569 r
.47914 .19084 m .48754 .20067 L .49413 .21019 L p F P
0 g
s
0 0 .519 r
.51375 .19076 m .51528 .19247 L .50751 .18222 L p F P
0 g
s
0 0 .519 r
.50751 .18222 m .50674 .18133 L .51375 .19076 L p F P
0 g
s
.305 .558 .925 r
.55188 .16496 m .54407 .16309 L .53642 .15316 L p F P
0 g
s
.972 .92 .597 r
.81182 .20753 m .81145 .19893 L .81586 .19763 L closepath p F P
0 g
s
.409 .506 .846 r
.55197 .2885 m .54647 .28708 L .53876 .2721 L p F P
0 g
s
.908 .913 .812 r
.7329 .19946 m .73384 .21053 L .7198 .22817 L p F P
0 g
s
.942 .931 .761 r
.73594 .19497 m .7329 .19946 L .73384 .21053 L p F P
0 g
s
.938 .961 .746 r
.79384 .25076 m .79397 .24899 L .79492 .24912 L closepath p F P
0 g
s
0 .108 .661 r
.50778 .23002 m .5032 .21991 L .49413 .21019 L p F P
0 g
s
0 .011 .556 r
.48754 .20067 m .49413 .21019 L .5032 .21991 L p F P
0 g
s
.92 .956 .794 r
.79397 .24899 m .79384 .25076 L .78087 .26813 L p F P
0 g
s
.99 .842 .472 r
.75604 .12913 m .75618 .12848 L .75628 .12893 L closepath p F P
0 g
s
.921 .73 .239 r
.82285 .11674 m .82343 .10454 L .82421 .10849 L closepath p F P
0 g
s
.92 .73 .238 r
.82285 .11674 m .82421 .10849 L p .82496 .12849 L F P
0 g
s
.712 .845 .945 r
.70741 .32939 m .70656 .33155 L p .67222 .33806 L F P
0 g
s
.737 .854 .935 r
.70656 .33155 m .70741 .32939 L .70861 .33046 L closepath p F P
0 g
s
0 .212 .734 r
.52106 .24998 m .51795 .23948 L .50778 .23002 L p F P
0 g
s
0 .115 .664 r
.5032 .21991 m .50778 .23002 L .51795 .23948 L p F P
0 g
s
.96 .795 .354 r
.82281 .11758 m .82496 .12849 L .82317 .14197 L p F P
0 g
s
.92 .73 .238 r
.82496 .12849 m .82281 .11758 L .82285 .11674 L p F P
0 g
s
.998 .838 .5 r
.75618 .12848 m .75604 .12913 L .75 .1316 L p F P
0 g
s
.998 .838 .5 r
.75 .1316 m .75303 .11781 L .75618 .12848 L p F P
0 g
s
.982 .786 .378 r
.75618 .12848 m .75303 .11781 L .75448 .10456 L p F P
0 g
s
.997 .846 .509 r
.75293 .1424 m .75604 .12913 L .75 .1316 L p F P
0 g
s
.171 .371 .819 r
.53103 .25765 m .52106 .24998 L p .53493 .26975 L F P
0 g
s
0 .228 .744 r
.52106 .24998 m .53103 .25765 L .52326 .24423 L p F P
0 g
s
0 .228 .744 r
.52326 .24423 m .51795 .23948 L .52106 .24998 L p F P
0 g
s
.424 .623 .935 r
.58855 .18914 m .58756 .18904 L .58438 .18359 L closepath p F P
0 g
s
.446 .593 .905 r
.58106 .17914 m .58438 .18359 L .58756 .18904 L p F P
0 g
s
.786 .863 .906 r
.70741 .32939 m .70861 .33046 L .73782 .31061 L p F P
0 g
s
.144 .4 .848 r
.51528 .19247 m .52661 .19912 L .53146 .2092 L p F P
0 g
s
.002 .354 .828 r
.52661 .19912 m .51528 .19247 L .50751 .18222 L p F P
0 g
s
.155 .41 .853 r
.55057 .2272 m .54646 .21697 L .53146 .2092 L p F P
0 g
s
.053 .371 .839 r
.52661 .19912 m .53146 .2092 L .54646 .21697 L p F P
0 g
s
.532 .631 .895 r
.60511 .331 m .62815 .32864 L .62075 .31837 L p F P
0 g
s
.532 .631 .895 r
.62075 .31837 m .60879 .31883 L .60511 .331 L p F P
0 g
s
.569 .644 .884 r
.5911 .31972 m .60879 .31883 L .60511 .331 L p F P
0 g
s
.99 .805 .56 r
.67771 .10729 m .67248 .09712 L p .67145 .11528 L F P
0 g
s
.99 .805 .56 r
.67145 .11528 m .67538 .11725 L .67771 .10729 L p F P
0 g
s
.993 .746 .4 r
.67771 .10729 m .67248 .09712 L .67319 .08427 L p F P
0 g
s
.171 .371 .819 r
.53876 .2721 m .53493 .26975 L .53376 .26276 L closepath p F P
0 g
s
.171 .371 .819 r
.53493 .26975 m .53376 .26276 L .53103 .25765 L p F P
0 g
s
.628 .752 .936 r
.58855 .18914 m .61795 .18098 L .62527 .18969 L p F P
0 g
s
.62 .717 .915 r
.61056 .17197 m .61795 .18098 L .58855 .18914 L p F P
0 g
s
.62 .717 .915 r
.58493 .17821 m .61056 .17197 L p .58855 .18914 L F P
0 g
s
.62 .717 .915 r
.58855 .18914 m .58438 .18359 L .58493 .17821 L p F P
0 g
s
.804 .864 .893 r
.69819 .24831 m .68525 .25839 L .67825 .25171 L p F P
0 g
s
.976 .902 .677 r
.7478 .15701 m .75002 .16784 L .74283 .18317 L p F P
0 g
s
.991 .887 .593 r
.75002 .16784 m .7478 .15701 L .75293 .1424 L p F P
0 g
s
.936 .952 .765 r
.78879 .24749 m .79424 .23954 L .79397 .24899 L closepath p F P
0 g
s
.92 .956 .794 r
.78879 .24749 m .79397 .24899 L p .78087 .26813 L F P
0 g
s
.951 .95 .724 r
.80401 .22319 m .79424 .23954 L .79397 .24899 L p F P
0 g
s
.905 .853 .78 r
.66636 .1366 m .67043 .14701 L .65854 .16384 L p F P
0 g
s
.956 .863 .708 r
.67043 .14701 m .66636 .1366 L .67419 .12117 L p F P
0 g
s
.877 .898 .843 r
.7198 .22817 m .7142 .23428 L .70742 .22909 L p F P
0 g
s
.877 .898 .843 r
.70742 .22909 m .71861 .21724 L .7198 .22817 L p F P
0 g
s
.908 .913 .812 r
.7198 .22817 m .71861 .21724 L .7329 .19946 L p F P
0 g
s
.804 .864 .893 r
.67825 .25171 m .69771 .2372 L .69819 .24831 L p F P
0 g
s
.841 .898 .879 r
.70742 .22909 m .69771 .2372 L .69819 .24831 L p F P
0 g
s
.841 .898 .879 r
.69819 .24831 m .7142 .23428 L .70742 .22909 L p F P
0 g
s
.981 .882 .522 r
.82014 .15594 m .82157 .16693 L .81716 .1814 L p F P
0 g
s
.966 .842 .428 r
.82157 .16693 m .82014 .15594 L .82317 .14197 L p F P
0 g
s
.967 .936 .667 r
.81145 .19893 m .81182 .20753 L .80401 .22319 L p F P
0 g
s
.764 .856 .919 r
.70173 .32424 m .70852 .3201 L .70741 .32939 L closepath p F P
0 g
s
.786 .863 .906 r
.73114 .30555 m .70852 .3201 L .70741 .32939 L p F P
0 g
s
.786 .863 .906 r
.73782 .31061 m .73114 .30555 L p .70741 .32939 L F P
0 g
s
.712 .845 .945 r
.67222 .33806 m .70173 .32424 L .70741 .32939 L p F P
0 g
s
.754 .797 .888 r
.63104 .18598 m .62527 .18969 L .61795 .18098 L p F P
0 g
s
.456 .529 .844 r
.55197 .2885 m .5741 .29443 L .57407 .30564 L p F P
0 g
s
.356 .528 .888 r
.55263 .27697 m .55197 .2885 L .5741 .29443 L p F P
0 g
s
.409 .506 .846 r
.53876 .2721 m .55263 .27697 L .55197 .2885 L p F P
0 g
s
.899 .936 .829 r
.78087 .26813 m .78167 .25684 L p .76511 .28367 L F P
0 g
s
.899 .936 .829 r
.76511 .28367 m .76672 .28452 L .78087 .26813 L p F P
0 g
s
.92 .956 .794 r
.78087 .26813 m .78167 .25684 L .78879 .24749 L p F P
0 g
s
.635 .768 .943 r
.63549 .33849 m .66509 .33004 L .67222 .33806 L p F P
0 g
s
.614 .747 .941 r
.66509 .33004 m .63549 .33849 L .62815 .32864 L p F P
0 g
s
.477 .603 .899 r
.57472 .24358 m .56759 .24316 L .55997 .23128 L p F P
0 g
s
.164 .416 .856 r
.55057 .2272 m .55997 .23128 L .55232 .21993 L p F P
0 g
s
.164 .416 .856 r
.55232 .21993 m .54646 .21697 L .55057 .2272 L p F P
0 g
s
.624 .709 .907 r
.62949 .26133 m .61207 .26578 L .60464 .25553 L p F P
0 g
s
.754 .797 .888 r
.61795 .18098 m .62623 .17592 L .63104 .18598 L p F P
0 g
s
.798 .837 .881 r
.64717 .1612 m .62623 .17592 L .63104 .18598 L p F P
0 g
s
.798 .837 .881 r
.63104 .18598 m .65434 .16859 L .64717 .1612 L p F P
0 g
s
.991 .737 .426 r
.66718 .07425 m .67319 .08427 L .67248 .09712 L p F P
0 g
s
.993 .785 .409 r
.75062 .094 m .75448 .10456 L .75303 .11781 L p F P
0 g
s
.96 .714 .268 r
.75448 .10456 m .75062 .094 L .75055 .08133 L p F P
0 g
s
.947 .742 .277 r
.82343 .10454 m .82065 .09371 L p .82273 .11727 L F P
0 g
s
.947 .742 .277 r
.82273 .11727 m .82285 .11674 L .82343 .10454 L p F P
0 g
s
.895 .664 .151 r
.82343 .10454 m .82065 .09371 L .82016 .08111 L p F P
0 g
s
.696 .823 .944 r
.70173 .32424 m .67222 .33806 L .66509 .33004 L p F P
0 g
s
.322 .572 .93 r
.55188 .16496 m .57351 .16929 L .56591 .15974 L p F P
0 g
s
.322 .572 .93 r
.56591 .15974 m .54514 .15535 L .55188 .16496 L p F P
0 g
s
.305 .558 .925 r
.53642 .15316 m .54514 .15535 L .55188 .16496 L p F P
0 g
s
.824 .902 .895 r
.74216 .30701 m .73782 .31061 L .73114 .30555 L p F P
0 g
s
.345 .479 .851 r
.55263 .27697 m .53876 .2721 L .53376 .26276 L p F P
0 g
s
.824 .902 .895 r
.73114 .30555 m .74337 .29571 L .74216 .30701 L p F P
0 g
s
.844 .918 .882 r
.76511 .28367 m .76469 .28656 L .74216 .30701 L p F P
0 g
s
.844 .918 .882 r
.76027 .28082 m .76511 .28367 L p .74216 .30701 L F P
0 g
s
.844 .918 .882 r
.74216 .30701 m .74337 .29571 L .76027 .28082 L p F P
0 g
s
.872 .944 .86 r
.76469 .28656 m .76511 .28367 L .76672 .28452 L closepath p F P
0 g
s
.542 .625 .884 r
.60879 .31883 m .5911 .31972 L .58354 .3074 L p F P
0 g
s
.704 .784 .913 r
.65217 .26519 m .64886 .26682 L .64161 .25828 L p F P
0 g
s
.865 .843 .821 r
.65854 .16384 m .65434 .16859 L .64717 .1612 L p F P
0 g
s
.865 .843 .821 r
.64717 .1612 m .65412 .15358 L .65854 .16384 L p F P
0 g
s
.905 .853 .78 r
.65854 .16384 m .65412 .15358 L .66636 .1366 L p F P
0 g
s
.987 .829 .6 r
.67419 .12117 m .67145 .11528 L .67538 .11725 L closepath p F P
0 g
s
.704 .784 .913 r
.64161 .25828 m .64876 .25503 L .65217 .26519 L p F P
0 g
s
.73 .823 .923 r
.67116 .2444 m .64876 .25503 L .65217 .26519 L p F P
0 g
s
.73 .823 .923 r
.65217 .26519 m .67825 .25171 L .67116 .2444 L p F P
0 g
s
.614 .712 .915 r
.58438 .18359 m .58106 .17914 L .58493 .17821 L closepath p F P
0 g
s
.373 .514 .871 r
.57407 .30564 m .58354 .3074 L .57594 .29494 L p F P
0 g
s
.373 .514 .871 r
.57594 .29494 m .5741 .29443 L .57407 .30564 L p F P
0 g
s
.951 .899 .738 r
.74283 .18317 m .74058 .17238 L p .73186 .19269 L F P
0 g
s
.951 .899 .738 r
.73186 .19269 m .73594 .19497 L .74283 .18317 L p F P
0 g
s
.976 .902 .677 r
.74283 .18317 m .74058 .17238 L .7478 .15701 L p F P
0 g
s
.975 .717 .305 r
.746 .0709 m .75055 .08133 L .75062 .094 L p F P
0 g
s
.992 .875 .608 r
.74998 .13168 m .75293 .1424 L .7478 .15701 L p F P
0 g
s
.997 .846 .509 r
.75 .1316 m .74998 .13168 L .75293 .1424 L p F P
0 g
s
.927 .68 .194 r
.81674 .07039 m .82016 .08111 L .82065 .09371 L p F P
0 g
s
.983 .843 .456 r
.82104 .13108 m .82317 .14197 L .82014 .15594 L p F P
0 g
s
.96 .795 .354 r
.82317 .14197 m .82104 .13108 L .82281 .11758 L p F P
0 g
s
.431 .587 .906 r
.57472 .24358 m .59716 .24516 L .58962 .23483 L p F P
0 g
s
.431 .587 .906 r
.58962 .23483 m .57276 .23272 L .57472 .24358 L p F P
0 g
s
.477 .603 .899 r
.55997 .23128 m .57276 .23272 L .57472 .24358 L p F P
0 g
s
.967 .936 .667 r
.81012 .19893 m .81145 .19893 L p .80401 .22319 L F P
0 g
s
.967 .936 .667 r
.80401 .22319 m .80357 .21209 L .81012 .19893 L p F P
0 g
s
.954 .942 .727 r
.80357 .21209 m .80401 .22319 L .79424 .23954 L p F P
0 g
s
.945 .844 .713 r
.67145 .11528 m .67419 .12117 L .66636 .1366 L p F P
0 g
s
.878 .932 .853 r
.76027 .28082 m .76562 .27528 L .76511 .28367 L closepath p F P
0 g
s
.899 .936 .829 r
.78167 .25684 m .76562 .27528 L .76511 .28367 L p F P
0 g
s
.976 .912 .587 r
.81716 .1814 m .81129 .19642 L .81145 .19893 L p F P
0 g
s
.983 .907 .602 r
.81578 .17043 m .81716 .1814 L .81129 .19642 L p F P
0 g
s
.981 .882 .522 r
.81716 .1814 m .81578 .17043 L .82014 .15594 L p F P
0 g
s
.345 .479 .851 r
.53376 .26276 m .53361 .25877 L p .55263 .27697 L F P
0 g
s
.292 .447 .844 r
.53376 .26276 m .53103 .25765 L .53361 .25877 L closepath p F P
0 g
s
.002 .354 .828 r
.50751 .18222 m .51978 .18962 L .52661 .19912 L p F P
0 g
s
0 .011 .556 r
.5032 .21991 m .49639 .21045 L .48754 .20067 L p F P
0 g
s
.935 .913 .772 r
.7329 .19946 m .73186 .19269 L .73594 .19497 L closepath p F P
0 g
s
.598 .717 .928 r
.62949 .26133 m .64161 .25828 L .6343 .24937 L p F P
0 g
s
.598 .717 .928 r
.6343 .24937 m .6266 .25093 L .62949 .26133 L p F P
0 g
s
.624 .709 .907 r
.60464 .25553 m .6266 .25093 L .62949 .26133 L p F P
0 g
s
.614 .718 .92 r
.58493 .17821 m .58106 .17914 L .57351 .16929 L p F P
0 g
s
.947 .742 .277 r
.82281 .11758 m .82273 .11727 L .82285 .11674 L closepath p F P
0 g
s
.264 .451 .857 r
.53361 .25877 m .53103 .25765 L .52326 .24423 L p F P
0 g
s
0 .115 .664 r
.51795 .23948 m .51271 .22959 L .5032 .21991 L p F P
0 g
s
0 .037 .576 r
.49639 .21045 m .5032 .21991 L .51271 .22959 L p F P
0 g
s
.435 .595 .911 r
.57276 .23272 m .55997 .23128 L .55232 .21993 L p F P
0 g
s
.901 .898 .814 r
.73186 .19269 m .7329 .19946 L .71861 .21724 L p F P
0 g
s
1 .828 .521 r
.75303 .11781 m .74916 .10728 L p .74996 .1316 L F P
0 g
s
1 .828 .521 r
.74996 .1316 m .75 .1316 L .75303 .11781 L p F P
0 g
s
.993 .785 .409 r
.75303 .11781 m .74916 .10728 L .75062 .094 L p F P
0 g
s
.979 .799 .387 r
.82273 .11727 m .82281 .11758 L .82104 .13108 L p F P
0 g
s
.053 .371 .839 r
.54646 .21697 m .54074 .20718 L .52661 .19912 L p F P
0 g
s
0 .345 .822 r
.51978 .18962 m .52661 .19912 L .54074 .20718 L p F P
0 g
s
.99 .805 .56 r
.67248 .09712 m .66919 .11094 L .67145 .11528 L p F P
0 g
s
.982 .79 .572 r
.66645 .08713 m .67248 .09712 L .66919 .11094 L p F P
0 g
s
.991 .737 .426 r
.67248 .09712 m .66645 .08713 L .66718 .07425 L p F P
0 g
s
.972 .929 .65 r
.81012 .19893 m .81129 .19642 L .81145 .19893 L closepath p F P
0 g
s
.979 .799 .387 r
.82004 .10677 m .82273 .11727 L .81892 .1228 L p F P
0 g
s
.947 .742 .277 r
.82065 .09371 m .82004 .10677 L .82273 .11727 L p F P
0 g
s
.979 .799 .387 r
.82104 .13108 m .81892 .1228 L .82273 .11727 L p F P
0 g
s
.753 .844 .919 r
.70852 .3201 m .70173 .32424 L .69475 .31736 L p F P
0 g
s
.696 .823 .944 r
.66509 .33004 m .69475 .31736 L .70173 .32424 L p F P
0 g
s
.934 .939 .776 r
.79424 .23954 m .78879 .24749 L .78252 .2447 L p F P
0 g
s
.934 .939 .776 r
.78252 .2447 m .79384 .22848 L .79424 .23954 L p F P
0 g
s
.954 .942 .727 r
.79424 .23954 m .79384 .22848 L .80357 .21209 L p F P
0 g
s
0 .135 .679 r
.51795 .23948 m .52326 .24423 L .51546 .23229 L p F P
0 g
s
0 .135 .679 r
.51546 .23229 m .51271 .22959 L .51795 .23948 L p F P
0 g
s
.603 .717 .924 r
.58493 .17821 m .61056 .17197 L .6031 .16274 L p F P
0 g
s
.603 .717 .924 r
.6031 .16274 m .58146 .16754 L .58493 .17821 L p F P
0 g
s
.614 .718 .92 r
.57351 .16929 m .58146 .16754 L .58493 .17821 L p F P
0 g
s
.592 .729 .939 r
.65788 .32152 m .62815 .32864 L .62075 .31837 L p F P
0 g
s
.614 .747 .941 r
.62815 .32864 m .65788 .32152 L .66509 .33004 L p F P
0 g
s
.603 .699 .911 r
.6266 .25093 m .60464 .25553 L .59716 .24516 L p F P
0 g
s
.793 .852 .895 r
.69771 .2372 m .67825 .25171 L .67116 .2444 L p F P
0 g
s
.542 .625 .884 r
.58354 .3074 m .60886 .30769 L .60879 .31883 L p F P
0 g
s
.511 .608 .886 r
.60886 .30769 m .58354 .3074 L .57594 .29494 L p F P
0 g
s
.973 .887 .684 r
.74484 .14633 m .7478 .15701 L .74058 .17238 L p F P
0 g
s
.992 .875 .608 r
.7478 .15701 m .74484 .14633 L .74998 .13168 L p F P
0 g
s
.896 .837 .78 r
.66141 .12638 m .66636 .1366 L .65412 .15358 L p F P
0 g
s
.945 .844 .713 r
.66845 .11278 m .67145 .11528 L p .66636 .1366 L F P
0 g
s
.945 .844 .713 r
.66636 .1366 m .66141 .12638 L .66845 .11278 L p F P
0 g
s
.745 .79 .889 r
.62623 .17592 m .61795 .18098 L .61056 .17197 L p F P
0 g
s
.753 .844 .919 r
.69475 .31736 m .70939 .30889 L .70852 .3201 L p F P
0 g
s
.776 .876 .92 r
.72434 .29977 m .70939 .30889 L .70852 .3201 L p F P
0 g
s
.776 .876 .92 r
.70852 .3201 m .73114 .30555 L .72434 .29977 L p F P
0 g
s
.345 .479 .851 r
.53361 .25877 m .55062 .26621 L .55263 .27697 L p F P
0 g
s
.159 .415 .856 r
.53097 .24811 m .53361 .25877 L .55062 .26621 L p F P
0 g
s
.264 .451 .857 r
.52326 .24423 m .53097 .24811 L .53361 .25877 L p F P
0 g
s
.921 .944 .798 r
.78167 .25684 m .78879 .24749 L .78252 .2447 L p F P
0 g
s
.965 .83 .66 r
.66845 .11278 m .66919 .11094 L .67145 .11528 L closepath p F P
0 g
s
.901 .898 .814 r
.72933 .19099 m .73186 .19269 L p .71861 .21724 L F P
0 g
s
.901 .898 .814 r
.71861 .21724 m .71669 .20643 L .72933 .19099 L p F P
0 g
s
.868 .883 .845 r
.71861 .21724 m .70742 .22909 L .70053 .2231 L p F P
0 g
s
.868 .883 .845 r
.70053 .2231 m .71669 .20643 L .71861 .21724 L p F P
0 g
s
.991 .876 .542 r
.81805 .14507 m .82014 .15594 L .81578 .17043 L p F P
0 g
s
.983 .843 .456 r
.82014 .15594 m .81805 .14507 L .82104 .13108 L p F P
0 g
s
.985 .724 .447 r
.66036 .06443 m .66718 .07425 L .66645 .08713 L p F P
0 g
s
.679 .804 .942 r
.69475 .31736 m .66509 .33004 L .65788 .32152 L p F P
0 g
s
.068 .383 .845 r
.54646 .21697 m .55232 .21993 L .54462 .20932 L p F P
0 g
s
.068 .383 .845 r
.54462 .20932 m .54074 .20718 L .54646 .21697 L p F P
0 g
s
.975 .92 .667 r
.81129 .19642 m .81012 .19893 L .80411 .19781 L p F P
0 g
s
.975 .92 .667 r
.80411 .19781 m .80995 .18546 L .81129 .19642 L p F P
0 g
s
.983 .907 .602 r
.81129 .19642 m .80995 .18546 L .81578 .17043 L p F P
0 g
s
.793 .852 .895 r
.67116 .2444 m .69668 .22617 L .69771 .2372 L p F P
0 g
s
.828 .877 .88 r
.70053 .2231 m .69668 .22617 L .69771 .2372 L p F P
0 g
s
.828 .877 .88 r
.69771 .2372 m .70742 .22909 L .70053 .2231 L p F P
0 g
s
.745 .79 .889 r
.61056 .17197 m .62073 .16599 L .62623 .17592 L p F P
0 g
s
.782 .819 .881 r
.63992 .15312 m .62073 .16599 L .62623 .17592 L p F P
0 g
s
.782 .819 .881 r
.62623 .17592 m .64717 .1612 L .63992 .15312 L p F P
0 g
s
.493 .623 .907 r
.60879 .31883 m .62075 .31837 L .61328 .3078 L p F P
0 g
s
.493 .623 .907 r
.61328 .3078 m .60886 .30769 L .60879 .31883 L p F P
0 g
s
.997 .779 .434 r
.74605 .08359 m .75062 .094 L .74916 .10728 L p F P
0 g
s
.975 .717 .305 r
.75062 .094 m .74605 .08359 L .746 .0709 L p F P
0 g
s
.968 .748 .312 r
.81723 .08301 m .82065 .09371 L .82004 .10677 L p F P
0 g
s
.927 .68 .194 r
.82065 .09371 m .81723 .08301 L .81674 .07039 L p F P
0 g
s
.971 .926 .679 r
.80357 .21209 m .81012 .19893 L .80411 .19781 L p F P
0 g
s
.691 .775 .916 r
.64876 .25503 m .64161 .25828 L .6343 .24937 L p F P
0 g
s
.897 .931 .831 r
.78177 .24566 m .78167 .25684 L .76562 .27528 L p F P
0 g
s
.921 .944 .798 r
.78252 .2447 m .78177 .24566 L .78167 .25684 L p F P
0 g
s
.356 .528 .888 r
.56829 .2826 m .55263 .27697 L p .5741 .29443 L F P
0 g
s
.255 .448 .857 r
.55263 .27697 m .56829 .2826 L .5606 .27062 L p F P
0 g
s
.255 .448 .857 r
.5606 .27062 m .55062 .26621 L .55263 .27697 L p F P
0 g
s
.856 .829 .82 r
.65412 .15358 m .64717 .1612 L .63992 .15312 L p F P
0 g
s
.856 .829 .82 r
.63992 .15312 m .64888 .14351 L .65412 .15358 L p F P
0 g
s
.896 .837 .78 r
.65412 .15358 m .64888 .14351 L .66141 .12638 L p F P
0 g
s
.816 .889 .896 r
.74337 .29571 m .73114 .30555 L .72434 .29977 L p F P
0 g
s
.691 .775 .916 r
.6343 .24937 m .64469 .24499 L .64876 .25503 L p F P
0 g
s
.713 .806 .923 r
.664 .23658 m .64469 .24499 L .64876 .25503 L p F P
0 g
s
.713 .806 .923 r
.64876 .25503 m .67116 .2444 L .664 .23658 L p F P
0 g
s
.984 .716 .337 r
.74074 .0606 m .746 .0709 L .74605 .08359 L p F P
0 g
s
.872 .917 .856 r
.76562 .27528 m .76027 .28082 L .75369 .27623 L p F P
0 g
s
.872 .917 .856 r
.75369 .27623 m .76558 .2642 L .76562 .27528 L p F P
0 g
s
.897 .931 .831 r
.76562 .27528 m .76558 .2642 L .78177 .24566 L p F P
0 g
s
.816 .889 .896 r
.72434 .29977 m .74398 .28449 L .74337 .29571 L p F P
0 g
s
.844 .917 .882 r
.75369 .27623 m .74398 .28449 L .74337 .29571 L p F P
0 g
s
.844 .917 .882 r
.74337 .29571 m .76027 .28082 L .75369 .27623 L p F P
0 g
s
.95 .69 .232 r
.8127 .05977 m .81674 .07039 L .81723 .08301 L p F P
0 g
s
.999 .838 .534 r
.74998 .13168 m .74996 .1316 L .75 .1316 L closepath p F P
0 g
s
.988 .862 .623 r
.74996 .1316 m .74998 .13168 L .74484 .14633 L p F P
0 g
s
.156 .417 .858 r
.53097 .24811 m .52326 .24423 L .51546 .23229 L p F P
0 g
s
.991 .852 .603 r
.74356 .12904 m .74611 .12117 L .74996 .1316 L closepath p F P
0 g
s
1 .828 .521 r
.74916 .10728 m .74611 .12117 L .74996 .1316 L p F P
0 g
s
.988 .862 .623 r
.74356 .12904 m .74996 .1316 L p .74484 .14633 L F P
0 g
s
.951 .899 .738 r
.74058 .17238 m .73098 .18861 L .73186 .19269 L p F P
0 g
s
.946 .888 .742 r
.73759 .16175 m .74058 .17238 L .73098 .18861 L p F P
0 g
s
.973 .887 .684 r
.74058 .17238 m .73759 .16175 L .74484 .14633 L p F P
0 g
s
.954 .812 .664 r
.66919 .11094 m .66845 .11278 L .66133 .1054 L p F P
0 g
s
.954 .812 .664 r
.66133 .1054 m .66311 .10098 L .66919 .11094 L p F P
0 g
s
.982 .79 .572 r
.66919 .11094 m .66311 .10098 L .66645 .08713 L p F P
0 g
s
.928 .899 .778 r
.72933 .19099 m .73098 .18861 L .73186 .19269 L closepath p F P
0 g
s
.993 .84 .48 r
.81892 .1228 m .82104 .13108 L .81805 .14507 L p F P
0 g
s
.351 .524 .887 r
.57594 .29494 m .5741 .29443 L .57356 .2911 L closepath p F P
0 g
s
.356 .528 .888 r
.5741 .29443 m .57356 .2911 L .56829 .2826 L p F P
0 g
s
.936 .827 .712 r
.66141 .12638 m .66845 .11278 L .66133 .1054 L p F P
0 g
s
.387 .581 .918 r
.57276 .23272 m .58962 .23483 L .58203 .22468 L p F P
0 g
s
.387 .581 .918 r
.58203 .22468 m .56871 .22245 L .57276 .23272 L p F P
0 g
s
.435 .595 .911 r
.55232 .21993 m .56871 .22245 L .57276 .23272 L p F P
0 g
s
.39 .59 .924 r
.56871 .22245 m .55232 .21993 L .54462 .20932 L p F P
0 g
s
.971 .926 .679 r
.80411 .19781 m .80244 .20111 L .80357 .21209 L p F P
0 g
s
.955 .93 .732 r
.80244 .20111 m .80357 .21209 L .79384 .22848 L p F P
0 g
s
.601 .723 .93 r
.58146 .16754 m .57351 .16929 L .56591 .15974 L p F P
0 g
s
.987 .897 .616 r
.81371 .15958 m .81578 .17043 L .80995 .18546 L p F P
0 g
s
.991 .876 .542 r
.81578 .17043 m .81371 .15958 L .81805 .14507 L p F P
0 g
s
.511 .608 .886 r
.57594 .29494 m .60577 .29709 L p .60886 .30769 L F P
0 g
s
.448 .579 .892 r
.5982 .28639 m .60577 .29709 L .57594 .29494 L p F P
0 g
s
.448 .579 .892 r
.57378 .28323 m .5982 .28639 L p .57594 .29494 L F P
0 g
s
.448 .579 .892 r
.57594 .29494 m .57356 .2911 L .57378 .28323 L p F P
0 g
s
.592 .729 .939 r
.62075 .31837 m .6506 .31256 L .65788 .32152 L p F P
0 g
s
.57 .712 .938 r
.6506 .31256 m .62075 .31837 L .61328 .3078 L p F P
0 g
s
.603 .699 .911 r
.59716 .24516 m .62208 .24097 L .6266 .25093 L p F P
0 g
s
.583 .693 .917 r
.62208 .24097 m .59716 .24516 L .58962 .23483 L p F P
0 g
s
0 .037 .576 r
.51271 .22959 m .50569 .22021 L .49639 .21045 L p F P
0 g
s
0 .345 .822 r
.54074 .20718 m .53363 .19776 L .51978 .18962 L p F P
0 g
s
.971 .773 .58 r
.6596 .07732 m .66645 .08713 L .66311 .10098 L p F P
0 g
s
.985 .724 .447 r
.66645 .08713 m .6596 .07732 L .66036 .06443 L p F P
0 g
s
.574 .709 .934 r
.6266 .25093 m .6343 .24937 L .62693 .24019 L p F P
0 g
s
.574 .709 .934 r
.62693 .24019 m .62208 .24097 L .6266 .25093 L p F P
0 g
s
.998 .817 .535 r
.74458 .09689 m .74916 .10728 L .74611 .12117 L p F P
0 g
s
.997 .779 .434 r
.74916 .10728 m .74458 .09689 L .74605 .08359 L p F P
0 g
s
.979 .799 .387 r
.81892 .1228 m .81827 .1203 L .82004 .10677 L p F P
0 g
s
.99 .798 .413 r
.81662 .09609 m .82004 .10677 L .81827 .1203 L p F P
0 g
s
.968 .748 .312 r
.82004 .10677 m .81662 .09609 L .81723 .08301 L p F P
0 g
s
.451 .581 .893 r
.57356 .2911 m .56829 .2826 L .57378 .28323 L closepath p F P
0 g
s
.92 .883 .781 r
.73098 .18861 m .72933 .19099 L .72257 .18562 L p F P
0 g
s
.92 .883 .781 r
.72257 .18562 m .72792 .17803 L .73098 .18861 L p F P
0 g
s
.946 .888 .742 r
.73098 .18861 m .72792 .17803 L .73759 .16175 L p F P
0 g
s
0 .058 .596 r
.51271 .22959 m .51546 .23229 L .50761 .22216 L p F P
0 g
s
0 .058 .596 r
.50761 .22216 m .50569 .22021 L .51271 .22959 L p F P
0 g
s
.742 .834 .921 r
.70939 .30889 m .69475 .31736 L .68769 .30993 L p F P
0 g
s
.679 .804 .942 r
.65788 .32152 m .68769 .30993 L .69475 .31736 L p F P
0 g
s
.74 .784 .889 r
.62073 .16599 m .61056 .17197 L .6031 .16274 L p F P
0 g
s
.899 .891 .813 r
.71669 .20643 m .72933 .19099 L .72257 .18562 L p F P
0 g
s
.785 .85 .9 r
.69668 .22617 m .67116 .2444 L .664 .23658 L p F P
0 g
s
.598 .723 .932 r
.58146 .16754 m .6031 .16274 L .59558 .15336 L p F P
0 g
s
.598 .723 .932 r
.59558 .15336 m .57501 .15781 L .58146 .16754 L p F P
0 g
s
.601 .723 .93 r
.56591 .15974 m .57501 .15781 L .58146 .16754 L p F P
0 g
s
.888 .822 .777 r
.65554 .11638 m .66141 .12638 L .64888 .14351 L p F P
0 g
s
.936 .827 .712 r
.66133 .1054 m .65554 .11638 L .66141 .12638 L p F P
0 g
s
.932 .921 .779 r
.79384 .22848 m .79273 .21753 L p .78169 .24424 L F P
0 g
s
.932 .921 .779 r
.78169 .24424 m .78252 .2447 L .79384 .22848 L p F P
0 g
s
.955 .93 .732 r
.79384 .22848 m .79273 .21753 L .80244 .20111 L p F P
0 g
s
.967 .872 .689 r
.74114 .13579 m .74484 .14633 L .73759 .16175 L p F P
0 g
s
.988 .862 .623 r
.74484 .14633 m .74114 .13579 L .74356 .12904 L p F P
0 g
s
.663 .787 .94 r
.68769 .30993 m .65788 .32152 L .6506 .31256 L p F P
0 g
s
0 .359 .831 r
.54074 .20718 m .54462 .20932 L .53688 .1996 L p F P
0 g
s
0 .359 .831 r
.53688 .1996 m .53363 .19776 L .54074 .20718 L p F P
0 g
s
.159 .415 .856 r
.55062 .26621 m .54658 .25602 L .53097 .24811 L p F P
0 g
s
.064 .382 .845 r
.52605 .23811 m .53097 .24811 L .54658 .25602 L p F P
0 g
s
.156 .417 .858 r
.51546 .23229 m .52605 .23811 L .53097 .24811 L p F P
0 g
s
.74 .784 .889 r
.6031 .16274 m .61447 .15623 L .62073 .16599 L p F P
0 g
s
.77 .803 .879 r
.63259 .14443 m .61447 .15623 L .62073 .16599 L p F P
0 g
s
.77 .803 .879 r
.62073 .16599 m .63992 .15312 L .63259 .14443 L p F P
0 g
s
.679 .768 .918 r
.64469 .24499 m .6343 .24937 L .62693 .24019 L p F P
0 g
s
.997 .77 .456 r
.74078 .07332 m .74605 .08359 L .74458 .09689 L p F P
0 g
s
.984 .716 .337 r
.74605 .08359 m .74078 .07332 L .74074 .0606 L p F P
0 g
s
.995 .868 .559 r
.81529 .13432 m .81805 .14507 L .81371 .15958 L p F P
0 g
s
.993 .84 .48 r
.81762 .1234 m .81892 .1228 L p .81805 .14507 L F P
0 g
s
.993 .84 .48 r
.81805 .14507 m .81529 .13432 L .81762 .1234 L p F P
0 g
s
.861 .86 .838 r
.71669 .20643 m .71404 .19576 L p .69547 .21825 L F P
0 g
s
.861 .86 .838 r
.69547 .21825 m .70053 .2231 L .71669 .20643 L p F P
0 g
s
.899 .891 .813 r
.72257 .18562 m .71404 .19576 L .71669 .20643 L p F P
0 g
s
.764 .858 .919 r
.71746 .29336 m .71007 .29762 L .70939 .30889 L p F P
0 g
s
.764 .858 .919 r
.70939 .30889 m .72434 .29977 L .71746 .29336 L p F P
0 g
s
.742 .834 .921 r
.68769 .30993 m .71007 .29762 L .70939 .30889 L p F P
0 g
s
.981 .75 .343 r
.81318 .07241 m .81723 .08301 L .81662 .09609 L p F P
0 g
s
.95 .69 .232 r
.81723 .08301 m .81318 .07241 L .8127 .05977 L p F P
0 g
s
.024 .375 .841 r
.52605 .23811 m .51546 .23229 L .50761 .22216 L p F P
0 g
s
.975 .906 .678 r
.80995 .18546 m .80792 .17463 L p .80175 .19695 L F P
0 g
s
.975 .906 .678 r
.80175 .19695 m .80411 .19781 L .80995 .18546 L p F P
0 g
s
.987 .897 .616 r
.80995 .18546 m .80792 .17463 L .81371 .15958 L p F P
0 g
s
.785 .85 .9 r
.69547 .21825 m .69668 .22617 L p .664 .23658 L F P
0 g
s
.815 .859 .881 r
.69668 .22617 m .69547 .21825 L .70053 .2231 L closepath p F P
0 g
s
.849 .816 .817 r
.64888 .14351 m .63992 .15312 L .63259 .14443 L p F P
0 g
s
.849 .816 .817 r
.63259 .14443 m .64279 .13362 L .64888 .14351 L p F P
0 g
s
.888 .822 .777 r
.64888 .14351 m .64279 .13362 L .65554 .11638 L p F P
0 g
s
.484 .635 .921 r
.61328 .3078 m .60886 .30769 L .60725 .29921 L closepath p F P
0 g
s
.511 .608 .886 r
.60577 .29709 m .60725 .29921 L .60886 .30769 L p F P
0 g
s
.994 .838 .477 r
.81762 .1234 m .81827 .1203 L .81892 .1228 L closepath p F P
0 g
s
.915 .929 .806 r
.78177 .24566 m .78169 .24424 L .78252 .2447 L closepath p F P
0 g
s
.159 .415 .856 r
.55062 .26621 m .5606 .27062 L .55287 .25921 L p F P
0 g
s
.159 .415 .856 r
.55287 .25921 m .54658 .25602 L .55062 .26621 L p F P
0 g
s
.891 .917 .835 r
.78169 .24424 m .78177 .24566 L .76558 .2642 L p F P
0 g
s
.986 .711 .364 r
.73477 .05046 m .74074 .0606 L .74078 .07332 L p F P
0 g
s
.445 .587 .9 r
.57378 .28323 m .56829 .2826 L .5606 .27062 L p F P
0 g
s
.679 .768 .918 r
.62693 .24019 m .64009 .23502 L .64469 .24499 L p F P
0 g
s
.697 .792 .923 r
.65675 .22832 m .64009 .23502 L .64469 .24499 L p F P
0 g
s
.697 .792 .923 r
.64469 .24499 m .664 .23658 L .65675 .22832 L p F P
0 g
s
.39 .59 .924 r
.54462 .20932 m .56304 .21262 L .56871 .22245 L p F P
0 g
s
.345 .59 .936 r
.56304 .21262 m .54462 .20932 L .53688 .1996 L p F P
0 g
s
.808 .877 .897 r
.74398 .28449 m .72434 .29977 L .71746 .29336 L p F P
0 g
s
.944 .795 .666 r
.66311 .10098 m .66133 .1054 L .65408 .09649 L p F P
0 g
s
.944 .795 .666 r
.65408 .09649 m .65623 .09121 L .66311 .10098 L p F P
0 g
s
.971 .773 .58 r
.66311 .10098 m .65623 .09121 L .6596 .07732 L p F P
0 g
s
.966 .695 .267 r
.80803 .04927 m .8127 .05977 L .81318 .07241 L p F P
0 g
s
.985 .838 .614 r
.74611 .12117 m .74356 .12904 L .73693 .12477 L p F P
0 g
s
.985 .838 .614 r
.73693 .12477 m .74151 .11081 L .74611 .12117 L p F P
0 g
s
.998 .817 .535 r
.74611 .12117 m .74151 .11081 L .74458 .09689 L p F P
0 g
s
.913 .919 .807 r
.77608 .24064 m .78071 .23474 L .78169 .24424 L closepath p F P
0 g
s
.932 .921 .779 r
.79273 .21753 m .78071 .23474 L .78169 .24424 L p F P
0 g
s
.891 .917 .835 r
.77608 .24064 m .78169 .24424 L p .76558 .2642 L F P
0 g
s
.94 .872 .743 r
.73386 .15125 m .73759 .16175 L .72792 .17803 L p F P
0 g
s
.967 .872 .689 r
.73759 .16175 m .73386 .15125 L .74114 .13579 L p F P
0 g
s
.57 .712 .938 r
.61328 .3078 m .64325 .30329 L .6506 .31256 L p F P
0 g
s
.561 .673 .913 r
.63584 .29379 m .64325 .30329 L .61328 .3078 L p F P
0 g
s
.561 .673 .913 r
.6076 .29687 m .63584 .29379 L p .61328 .3078 L F P
0 g
s
.561 .673 .913 r
.61328 .3078 m .60725 .29921 L .6076 .29687 L p F P
0 g
s
.865 .903 .857 r
.76558 .2642 m .75369 .27623 L .74701 .27089 L p F P
0 g
s
.865 .903 .857 r
.74701 .27089 m .76485 .25323 L .76558 .2642 L p F P
0 g
s
.891 .917 .835 r
.76558 .2642 m .76485 .25323 L .77608 .24064 L p F P
0 g
s
.999 .832 .499 r
.81827 .1203 m .81486 .10964 L p .81199 .12403 L F P
0 g
s
.999 .832 .499 r
.81199 .12403 m .81762 .1234 L .81827 .1203 L p F P
0 g
s
.99 .798 .413 r
.81827 .1203 m .81486 .10964 L .81662 .09609 L p F P
0 g
s
.808 .877 .897 r
.71746 .29336 m .74403 .27333 L .74398 .28449 L p F P
0 g
s
.835 .898 .884 r
.74701 .27089 m .74403 .27333 L .74398 .28449 L p F P
0 g
s
.835 .898 .884 r
.74398 .28449 m .75369 .27623 L .74701 .27089 L p F P
0 g
s
.583 .693 .917 r
.58962 .23483 m .61665 .23121 L .62208 .24097 L p F P
0 g
s
.563 .69 .925 r
.61665 .23121 m .58962 .23483 L .58203 .22468 L p F P
0 g
s
.97 .915 .694 r
.80244 .20111 m .80175 .19695 L .80411 .19781 L closepath p F P
0 g
s
.922 .805 .713 r
.65554 .11638 m .66133 .1054 L .65408 .09649 L p F P
0 g
s
.348 .578 .927 r
.56871 .22245 m .58203 .22468 L .5744 .21482 L p F P
0 g
s
.348 .578 .927 r
.5744 .21482 m .56304 .21262 L .56871 .22245 L p F P
0 g
s
.953 .916 .74 r
.80175 .19695 m .80244 .20111 L .79273 .21753 L p F P
0 g
s
.999 .834 .502 r
.81529 .13432 m .81199 .12403 L .81762 .1234 L closepath p F P
0 g
s
.399 .566 .902 r
.57378 .28323 m .5982 .28639 L .59058 .27582 L p F P
0 g
s
.399 .566 .902 r
.59058 .27582 m .5718 .27245 L .57378 .28323 L p F P
0 g
s
.445 .587 .9 r
.5606 .27062 m .5718 .27245 L .57378 .28323 L p F P
0 g
s
.988 .886 .626 r
.81098 .14884 m .81371 .15958 L .80792 .17463 L p F P
0 g
s
.995 .868 .559 r
.81371 .15958 m .81098 .14884 L .81529 .13432 L p F P
0 g
s
.982 .847 .631 r
.74114 .13579 m .74356 .12904 L .73693 .12477 L p F P
0 g
s
.553 .701 .938 r
.62208 .24097 m .62693 .24019 L .61949 .23085 L p F P
0 g
s
.553 .701 .938 r
.61949 .23085 m .61665 .23121 L .62208 .24097 L p F P
0 g
s
.993 .804 .548 r
.73929 .08664 m .74458 .09689 L .74151 .11081 L p F P
0 g
s
.997 .77 .456 r
.74458 .09689 m .73929 .08664 L .74078 .07332 L p F P
0 g
s
.737 .779 .887 r
.61447 .15623 m .6031 .16274 L .59558 .15336 L p F P
0 g
s
.732 .834 .928 r
.71007 .29762 m .68769 .30993 L .68055 .30203 L p F P
0 g
s
.663 .787 .94 r
.6506 .31256 m .68055 .30203 L .68769 .30993 L p F P
0 g
s
.997 .793 .436 r
.81256 .08551 m .81662 .09609 L .81486 .10964 L p F P
0 g
s
.981 .75 .343 r
.81662 .09609 m .81256 .08551 L .81318 .07241 L p F P
0 g
s
.648 .773 .939 r
.68055 .30203 m .6506 .31256 L .64325 .30329 L p F P
0 g
s
.88 .807 .773 r
.6487 .10662 m .65554 .11638 L .64279 .13362 L p F P
0 g
s
.922 .805 .713 r
.65408 .09649 m .6487 .10662 L .65554 .11638 L p F P
0 g
s
.785 .85 .9 r
.664 .23658 m .69353 .21634 L .69547 .21825 L p F P
0 g
s
.774 .835 .899 r
.69353 .21634 m .664 .23658 L .65675 .22832 L p F P
0 g
s
.912 .868 .782 r
.72792 .17803 m .72257 .18562 L .71569 .17936 L p F P
0 g
s
.912 .868 .782 r
.71569 .17936 m .72411 .1676 L .72792 .17803 L p F P
0 g
s
.94 .872 .743 r
.72792 .17803 m .72411 .1676 L .73386 .15125 L p F P
0 g
s
.669 .762 .92 r
.64009 .23502 m .62693 .24019 L .61949 .23085 L p F P
0 g
s
.837 .855 .859 r
.69353 .21634 m .69462 .21536 L .69547 .21825 L closepath p F P
0 g
s
.861 .86 .838 r
.71404 .19576 m .69462 .21536 L .69547 .21825 L p F P
0 g
s
.96 .855 .692 r
.7367 .1254 m .74114 .13579 L .73386 .15125 L p F P
0 g
s
.982 .847 .631 r
.73693 .12477 m .7367 .1254 L .74114 .13579 L p F P
0 g
s
.024 .375 .841 r
.50761 .22216 m .51915 .22868 L .52605 .23811 L p F P
0 g
s
.737 .779 .887 r
.59558 .15336 m .60739 .14665 L .61447 .15623 L p F P
0 g
s
.762 .789 .876 r
.62518 .13516 m .60739 .14665 L .61447 .15623 L p F P
0 g
s
.762 .789 .876 r
.61447 .15623 m .63259 .14443 L .62518 .13516 L p F P
0 g
s
.889 .872 .815 r
.71404 .19576 m .72257 .18562 L .71569 .17936 L p F P
0 g
s
.975 .906 .678 r
.80792 .17463 m .8005 .19029 L .80175 .19695 L p F P
0 g
s
.961 .911 .72 r
.7979 .19501 m .8005 .19029 L .80175 .19695 L closepath p F P
0 g
s
.953 .916 .74 r
.7979 .19501 m .80175 .19695 L p .79273 .21753 L F P
0 g
s
.93 .912 .779 r
.79092 .20671 m .79273 .21753 L .78071 .23474 L p F P
0 g
s
.953 .916 .74 r
.79273 .21753 m .79092 .20671 L .7979 .19501 L p F P
0 g
s
.064 .382 .845 r
.54658 .25602 m .54087 .24628 L .52605 .23811 L p F P
0 g
s
0 .359 .83 r
.51915 .22868 m .52605 .23811 L .54087 .24628 L p F P
0 g
s
.993 .759 .473 r
.73479 .06319 m .74078 .07332 L .73929 .08664 L p F P
0 g
s
.986 .711 .364 r
.74078 .07332 m .73479 .06319 L .73477 .05046 L p F P
0 g
s
.401 .578 .911 r
.5718 .27245 m .5606 .27062 L .55287 .25921 L p F P
0 g
s
.563 .674 .914 r
.60725 .29921 m .60577 .29709 L .6076 .29687 L closepath p F P
0 g
s
.996 .857 .572 r
.81199 .12403 m .81529 .13432 L .81098 .14884 L p F P
0 g
s
.989 .748 .369 r
.8085 .06193 m .81318 .07241 L .81256 .08551 L p F P
0 g
s
.966 .695 .267 r
.81318 .07241 m .8085 .06193 L .80803 .04927 L p F P
0 g
s
.852 .852 .841 r
.71062 .18524 m .71404 .19576 L .69462 .21536 L p F P
0 g
s
.889 .872 .815 r
.71569 .17936 m .71062 .18524 L .71404 .19576 L p F P
0 g
s
.843 .804 .813 r
.64279 .13362 m .63259 .14443 L .62518 .13516 L p F P
0 g
s
.843 .804 .813 r
.62518 .13516 m .63584 .12393 L .64279 .13362 L p F P
0 g
s
.88 .807 .773 r
.64279 .13362 m .63584 .12393 L .6487 .10662 L p F P
0 g
s
.974 .896 .682 r
.80521 .16392 m .80792 .17463 L .8005 .19029 L p F P
0 g
s
.988 .886 .626 r
.80792 .17463 m .80521 .16392 L .81098 .14884 L p F P
0 g
s
.345 .59 .936 r
.53688 .1996 m .55597 .20316 L .56304 .21262 L p F P
0 g
s
.984 .704 .387 r
.7281 .04046 m .73477 .05046 L .73479 .06319 L p F P
0 g
s
.829 .843 .857 r
.69462 .21536 m .69353 .21634 L .68645 .20886 L p F P
0 g
s
.774 .835 .899 r
.65675 .22832 m .68645 .20886 L .69353 .21634 L p F P
0 g
s
.829 .843 .857 r
.68645 .20886 m .69077 .20504 L .69462 .21536 L p F P
0 g
s
.852 .852 .841 r
.69462 .21536 m .69077 .20504 L .71062 .18524 L p F P
0 g
s
.562 .675 .915 r
.6076 .29687 m .60577 .29709 L .5982 .28639 L p F P
0 g
s
.752 .841 .919 r
.71007 .29762 m .7107 .28661 L .71746 .29336 L closepath p F P
0 g
s
.732 .834 .928 r
.7107 .28661 m .71007 .29762 L p .68055 .30203 L F P
0 g
s
.065 .383 .846 r
.54658 .25602 m .55287 .25921 L .54509 .2486 L p F P
0 g
s
.065 .383 .846 r
.54509 .2486 m .54087 .24628 L .54658 .25602 L p F P
0 g
s
.669 .762 .92 r
.61949 .23085 m .63518 .22505 L .64009 .23502 L p F P
0 g
s
.683 .78 .924 r
.64944 .2197 m .63518 .22505 L .64009 .23502 L p F P
0 g
s
.683 .78 .924 r
.64009 .23502 m .65675 .22832 L .64944 .2197 L p F P
0 g
s
.535 .662 .918 r
.6076 .29687 m .63584 .29379 L .62837 .28416 L p F P
0 g
s
.535 .662 .918 r
.62837 .28416 m .60731 .28563 L .6076 .29687 L p F P
0 g
s
.562 .675 .915 r
.5982 .28639 m .60731 .28563 L .6076 .29687 L p F P
0 g
s
.975 .696 .297 r
.80274 .03889 m .80803 .04927 L .8085 .06193 L p F P
0 g
s
.907 .905 .809 r
.78071 .23474 m .77608 .24064 L .76952 .23571 L p F P
0 g
s
.907 .905 .809 r
.76952 .23571 m .77888 .22397 L .78071 .23474 L p F P
0 g
s
.93 .912 .779 r
.78071 .23474 m .77888 .22397 L .79092 .20671 L p F P
0 g
s
.563 .69 .925 r
.58203 .22468 m .61049 .22158 L .61665 .23121 L p F P
0 g
s
.545 .691 .935 r
.61049 .22158 m .58203 .22468 L .5744 .21482 L p F P
0 g
s
.978 .823 .621 r
.74151 .11081 m .7362 .10059 L p .73594 .12391 L F P
0 g
s
.978 .823 .621 r
.73594 .12391 m .73693 .12477 L .74151 .11081 L p F P
0 g
s
.993 .804 .548 r
.74151 .11081 m .7362 .10059 L .73929 .08664 L p F P
0 g
s
.803 .85 .886 r
.7107 .28661 m .71746 .29336 L .74403 .27333 L p F P
0 g
s
.889 .908 .834 r
.76485 .25323 m .77608 .24064 L .76952 .23571 L p F P
0 g
s
.933 .857 .743 r
.72937 .14091 m .73386 .15125 L .72411 .1676 L p F P
0 g
s
.96 .855 .692 r
.73386 .15125 m .72937 .14091 L .7367 .1254 L p F P
0 g
s
.999 .832 .499 r
.81486 .10964 m .81188 .12367 L .81199 .12403 L p F P
0 g
s
1 .824 .515 r
.8108 .09908 m .81486 .10964 L .81188 .12367 L p F P
0 g
s
.997 .793 .436 r
.81486 .10964 m .8108 .09908 L .81256 .08551 L p F P
0 g
s
.32 .58 .936 r
.56304 .21262 m .5744 .21482 L .56671 .20532 L p F P
0 g
s
.32 .58 .936 r
.56671 .20532 m .55597 .20316 L .56304 .21262 L p F P
0 g
s
.86 .881 .852 r
.76485 .25323 m .76344 .24238 L p .74373 .268 L F P
0 g
s
.86 .881 .852 r
.74373 .268 m .74701 .27089 L .76485 .25323 L p F P
0 g
s
.889 .908 .834 r
.76952 .23571 m .76344 .24238 L .76485 .25323 L p F P
0 g
s
.803 .85 .886 r
.74403 .27333 m .74373 .268 L p .7107 .28661 L F P
0 g
s
.826 .882 .885 r
.74403 .27333 m .74373 .268 L .74701 .27089 L closepath p F P
0 g
s
.957 .898 .726 r
.8005 .19029 m .7979 .19501 L .79152 .19089 L p F P
0 g
s
.957 .898 .726 r
.79152 .19089 m .79781 .17961 L .8005 .19029 L p F P
0 g
s
.974 .896 .682 r
.8005 .19029 m .79781 .17961 L .80521 .16392 L p F P
0 g
s
.986 .873 .634 r
.80759 .13822 m .81098 .14884 L .80521 .16392 L p F P
0 g
s
.996 .857 .572 r
.81179 .12397 m .81199 .12403 L p .81098 .14884 L F P
0 g
s
.996 .857 .572 r
.81098 .14884 m .80759 .13822 L .81179 .12397 L p F P
0 g
s
.985 .79 .558 r
.73329 .07654 m .73929 .08664 L .7362 .10059 L p F P
0 g
s
.993 .759 .473 r
.73929 .08664 m .73329 .07654 L .73479 .06319 L p F P
0 g
s
.536 .696 .942 r
.61665 .23121 m .61949 .23085 L .612 .22144 L p F P
0 g
s
.536 .696 .942 r
.612 .22144 m .61049 .22158 L .61665 .23121 L p F P
0 g
s
.351 .559 .914 r
.5718 .27245 m .59058 .27582 L .58291 .26553 L p F P
0 g
s
.351 .559 .914 r
.58291 .26553 m .5678 .26223 L .5718 .27245 L p F P
0 g
s
.401 .578 .911 r
.55287 .25921 m .5678 .26223 L .5718 .27245 L p F P
0 g
s
.648 .773 .939 r
.64325 .30329 m .67333 .29374 L .68055 .30203 L p F P
0 g
s
.633 .76 .939 r
.67333 .29374 m .64325 .30329 L .63584 .29379 L p F P
0 g
s
.732 .834 .928 r
.68055 .30203 m .71048 .28639 L .7107 .28661 L p F P
0 g
s
.721 .821 .927 r
.71048 .28639 m .68055 .30203 L .67333 .29374 L p F P
0 g
s
.95 .903 .743 r
.79092 .20671 m .7979 .19501 L .79152 .19089 L p F P
0 g
s
.352 .571 .922 r
.5678 .26223 m .55287 .25921 L .54509 .2486 L p F P
0 g
s
.999 .786 .456 r
.80787 .07505 m .81256 .08551 L .8108 .09908 L p F P
0 g
s
.989 .748 .369 r
.81256 .08551 m .80787 .07505 L .8085 .06193 L p F P
0 g
s
.764 .821 .897 r
.68645 .20886 m .65675 .22832 L .64944 .2197 L p F P
0 g
s
.662 .758 .922 r
.63518 .22505 m .61949 .23085 L .612 .22144 L p F P
0 g
s
.904 .854 .782 r
.72411 .1676 m .71569 .17936 L .7087 .17227 L p F P
0 g
s
.904 .854 .782 r
.7087 .17227 m .71956 .15731 L .72411 .1676 L p F P
0 g
s
.933 .857 .743 r
.72411 .1676 m .71956 .15731 L .72937 .14091 L p F P
0 g
s
.974 .831 .64 r
.7367 .1254 m .73594 .12391 L .73693 .12477 L closepath p F P
0 g
s
.952 .839 .696 r
.73594 .12391 m .7367 .1254 L .72937 .14091 L p F P
0 g
s
0 .359 .83 r
.54087 .24628 m .53372 .23691 L .51915 .22868 L p F P
0 g
s
.986 .747 .488 r
.7281 .05321 m .73479 .06319 L .73329 .07654 L p F P
0 g
s
.984 .704 .387 r
.73479 .06319 m .7281 .05321 L .7281 .04046 L p F P
0 g
s
.54 .67 .922 r
.60731 .28563 m .5982 .28639 L .59058 .27582 L p F P
0 g
s
.997 .854 .566 r
.81179 .12397 m .81188 .12367 L .81199 .12403 L closepath p F P
0 g
s
.992 .743 .392 r
.8032 .05156 m .8085 .06193 L .80787 .07505 L p F P
0 g
s
.975 .696 .297 r
.8085 .06193 m .8032 .05156 L .80274 .03889 L p F P
0 g
s
.927 .899 .779 r
.78842 .196 m .79092 .20671 L .77888 .22397 L p F P
0 g
s
.95 .903 .743 r
.79152 .19089 m .78842 .196 L .79092 .20671 L p F P
0 g
s
.96 .833 .673 r
.73009 .11821 m .73138 .11521 L .73594 .12391 L closepath p F P
0 g
s
.952 .839 .696 r
.73009 .11821 m .73594 .12391 L p .72937 .14091 L F P
0 g
s
.978 .823 .621 r
.7362 .10059 m .73138 .11521 L .73594 .12391 L p F P
0 g
s
.879 .856 .815 r
.71062 .18524 m .71569 .17936 L .7087 .17227 L p F P
0 g
s
.995 .844 .58 r
.81188 .12367 m .81179 .12397 L .80559 .12086 L p F P
0 g
s
.995 .844 .58 r
.80559 .12086 m .80782 .11314 L .81188 .12367 L p F P
0 g
s
1 .824 .515 r
.81188 .12367 m .80782 .11314 L .8108 .09908 L p F P
0 g
s
.994 .846 .584 r
.80759 .13822 m .81179 .12397 L .80559 .12086 L p F P
0 g
s
.879 .856 .815 r
.7087 .17227 m .70641 .17489 L .71062 .18524 L p F P
0 g
s
.847 .84 .838 r
.70641 .17489 m .71062 .18524 L .69077 .20504 L p F P
0 g
s
.841 .878 .869 r
.74022 .26482 m .74284 .26247 L .74373 .268 L closepath p F P
0 g
s
.86 .881 .852 r
.76344 .24238 m .74284 .26247 L .74373 .268 L p F P
0 g
s
.803 .85 .886 r
.74373 .268 m .74022 .26482 L p .7107 .28661 L F P
0 g
s
.971 .882 .687 r
.80183 .15333 m .80521 .16392 L .79781 .17961 L p F P
0 g
s
.986 .873 .634 r
.80521 .16392 m .80183 .15333 L .80759 .13822 L p F P
0 g
s
.545 .691 .935 r
.5744 .21482 m .60372 .21207 L .61049 .22158 L p F P
0 g
s
.531 .696 .944 r
.60372 .21207 m .5744 .21482 L .56671 .20532 L p F P
0 g
s
.823 .832 .856 r
.69077 .20504 m .68645 .20886 L .67927 .20086 L p F P
0 g
s
.764 .821 .897 r
.64944 .2197 m .67927 .20086 L .68645 .20886 L p F P
0 g
s
.823 .832 .856 r
.67927 .20086 m .68617 .19486 L .69077 .20504 L p F P
0 g
s
.847 .84 .838 r
.69077 .20504 m .68617 .19486 L .70641 .17489 L p F P
0 g
s
0 .36 .831 r
.54087 .24628 m .54509 .2486 L .53728 .23892 L p F P
0 g
s
0 .36 .831 r
.53728 .23892 m .53372 .23691 L .54087 .24628 L p F P
0 g
s
.98 .694 .323 r
.79683 .02861 m .80274 .03889 L .8032 .05156 L p F P
0 g
s
.662 .758 .922 r
.612 .22144 m .63058 .21488 L .63518 .22505 L p F P
0 g
s
.672 .77 .924 r
.64205 .2108 m .63058 .21488 L .63518 .22505 L p F P
0 g
s
.672 .77 .924 r
.63518 .22505 m .64944 .2197 L .64205 .2108 L p F P
0 g
s
.97 .808 .626 r
.73017 .09052 m .7362 .10059 L .73138 .11521 L p F P
0 g
s
.985 .79 .558 r
.7362 .10059 m .73017 .09052 L .73329 .07654 L p F P
0 g
s
.782 .845 .899 r
.71048 .28639 m .71065 .28627 L .7107 .28661 L closepath p F P
0 g
s
.803 .85 .886 r
.74022 .26482 m .71065 .28627 L .7107 .28661 L p F P
0 g
s
.775 .834 .898 r
.71065 .28627 m .71048 .28639 L .70341 .2789 L p F P
0 g
s
.721 .821 .927 r
.67333 .29374 m .70341 .2789 L .71048 .28639 L p F P
0 g
s
.798 .861 .896 r
.73333 .2581 m .70811 .27581 L .71065 .28627 L p F P
0 g
s
.798 .861 .896 r
.71065 .28627 m .74022 .26482 L .73333 .2581 L p F P
0 g
s
.775 .834 .898 r
.70341 .2789 m .70811 .27581 L .71065 .28627 L p F P
0 g
s
.901 .891 .811 r
.77888 .22397 m .76952 .23571 L .76285 .23001 L p F P
0 g
s
.901 .891 .811 r
.76285 .23001 m .77635 .21332 L .77888 .22397 L p F P
0 g
s
.927 .899 .779 r
.77888 .22397 m .77635 .21332 L .78842 .196 L p F P
0 g
s
.925 .841 .742 r
.72412 .13072 m .72937 .14091 L .71956 .15731 L p F P
0 g
s
.952 .839 .696 r
.72937 .14091 m .72412 .13072 L .73009 .11821 L p F P
0 g
s
.998 .814 .529 r
.8061 .08865 m .8108 .09908 L .80782 .11314 L p F P
0 g
s
.999 .786 .456 r
.8108 .09908 m .8061 .08865 L .80787 .07505 L p F P
0 g
s
.511 .661 .929 r
.60731 .28563 m .62837 .28416 L .62084 .27449 L p F P
0 g
s
.511 .661 .929 r
.62084 .27449 m .60448 .2751 L .60731 .28563 L p F P
0 g
s
.54 .67 .922 r
.59058 .27582 m .60448 .2751 L .60731 .28563 L p F P
0 g
s
.633 .76 .939 r
.63584 .29379 m .66605 .28512 L .67333 .29374 L p F P
0 g
s
.621 .75 .939 r
.66605 .28512 m .63584 .29379 L .62837 .28416 L p F P
0 g
s
.881 .892 .835 r
.76344 .24238 m .76952 .23571 L .76285 .23001 L p F P
0 g
s
.352 .571 .922 r
.54509 .2486 m .56214 .25245 L .5678 .26223 L p F P
0 g
s
.302 .569 .932 r
.56214 .25245 m .54509 .2486 L .53728 .23892 L p F P
0 g
s
.977 .775 .566 r
.72656 .06658 m .73329 .07654 L .73017 .09052 L p F P
0 g
s
.986 .747 .488 r
.73329 .07654 m .72656 .06658 L .7281 .05321 L p F P
0 g
s
.855 .875 .854 r
.76133 .23164 m .76344 .24238 L .74284 .26247 L p F P
0 g
s
.881 .892 .835 r
.76285 .23001 m .76133 .23164 L .76344 .24238 L p F P
0 g
s
.524 .693 .946 r
.61049 .22158 m .612 .22144 L .60444 .21201 L p F P
0 g
s
.524 .693 .946 r
.60444 .21201 m .60372 .21207 L .61049 .22158 L p F P
0 g
s
.983 .86 .64 r
.80354 .12772 m .80759 .13822 L .80183 .15333 L p F P
0 g
s
.994 .846 .584 r
.80559 .12086 m .80354 .12772 L .80759 .13822 L p F P
0 g
s
.951 .881 .729 r
.79781 .17961 m .79444 .16904 L p .78544 .18613 L F P
0 g
s
.951 .881 .729 r
.78544 .18613 m .79152 .19089 L .79781 .17961 L p F P
0 g
s
.971 .882 .687 r
.79781 .17961 m .79444 .16904 L .80183 .15333 L p F P
0 g
s
.71 .808 .926 r
.70341 .2789 m .67333 .29374 L .66605 .28512 L p F P
0 g
s
.834 .865 .868 r
.74284 .26247 m .74022 .26482 L .73333 .2581 L p F P
0 g
s
.834 .865 .868 r
.73333 .2581 m .7404 .2519 L .74284 .26247 L p F P
0 g
s
.855 .875 .854 r
.74284 .26247 m .7404 .2519 L .76133 .23164 L p F P
0 g
s
.657 .756 .923 r
.63058 .21488 m .612 .22144 L .60444 .21201 L p F P
0 g
s
.308 .555 .922 r
.5678 .26223 m .58291 .26553 L .5752 .25561 L p F P
0 g
s
.308 .555 .922 r
.5752 .25561 m .56214 .25245 L .5678 .26223 L p F P
0 g
s
.757 .809 .894 r
.67927 .20086 m .64944 .2197 L .64205 .2108 L p F P
0 g
s
.997 .778 .472 r
.80256 .0647 m .80787 .07505 L .8061 .08865 L p F P
0 g
s
.992 .743 .392 r
.80787 .07505 m .80256 .0647 L .8032 .05156 L p F P
0 g
s
.897 .839 .78 r
.71956 .15731 m .7087 .17227 L .70162 .16441 L p F P
0 g
s
.897 .839 .78 r
.70162 .16441 m .71424 .14718 L .71956 .15731 L p F P
0 g
s
.925 .841 .742 r
.71956 .15731 m .71424 .14718 L .72412 .13072 L p F P
0 g
s
.518 .668 .93 r
.60448 .2751 m .59058 .27582 L .58291 .26553 L p F P
0 g
s
.952 .818 .676 r
.73138 .11521 m .73009 .11821 L .72312 .11028 L p F P
0 g
s
.952 .818 .676 r
.72312 .11028 m .72532 .10517 L .73138 .11521 L p F P
0 g
s
.97 .808 .626 r
.73138 .11521 m .72532 .10517 L .73017 .09052 L p F P
0 g
s
.943 .888 .748 r
.78842 .196 m .78544 .18613 L .79152 .19089 L closepath p F P
0 g
s
.943 .824 .696 r
.72412 .13072 m .73009 .11821 L .72312 .11028 L p F P
0 g
s
.992 .737 .412 r
.79727 .04131 m .8032 .05156 L .80256 .0647 L p F P
0 g
s
.98 .694 .323 r
.8032 .05156 m .79727 .04131 L .79683 .02861 L p F P
0 g
s
.99 .832 .59 r
.80782 .11314 m .80559 .12086 L .7992 .11617 L p F P
0 g
s
.99 .832 .59 r
.7992 .11617 m .80312 .10273 L .80782 .11314 L p F P
0 g
s
.998 .814 .529 r
.80782 .11314 m .80312 .10273 L .8061 .08865 L p F P
0 g
s
.531 .696 .944 r
.56671 .20532 m .59637 .20265 L .60372 .21207 L p F P
0 g
s
.922 .885 .778 r
.78544 .18613 m .78842 .196 L .77635 .21332 L p F P
0 g
s
.87 .84 .813 r
.70641 .17489 m .7087 .17227 L .70162 .16441 L p F P
0 g
s
.841 .829 .835 r
.70136 .16471 m .70641 .17489 L .68617 .19486 L p F P
0 g
s
.87 .84 .813 r
.70162 .16441 m .70136 .16471 L .70641 .17489 L p F P
0 g
s
.817 .822 .853 r
.68617 .19486 m .67927 .20086 L .67202 .19238 L p F P
0 g
s
.757 .809 .894 r
.64205 .2108 m .67202 .19238 L .67927 .20086 L p F P
0 g
s
.981 .69 .346 r
.7903 .01846 m .79683 .02861 L .79727 .04131 L p F P
0 g
s
.966 .867 .689 r
.79779 .14285 m .80183 .15333 L .79444 .16904 L p F P
0 g
s
.983 .86 .64 r
.80183 .15333 m .79779 .14285 L .80354 .12772 L p F P
0 g
s
.817 .822 .853 r
.67202 .19238 m .68079 .18485 L .68617 .19486 L p F P
0 g
s
.841 .829 .835 r
.68617 .19486 m .68079 .18485 L .70136 .16471 L p F P
0 g
s
.961 .793 .629 r
.72342 .08059 m .73017 .09052 L .72532 .10517 L p F P
0 g
s
.977 .775 .566 r
.73017 .09052 m .72342 .08059 L .72656 .06658 L p F P
0 g
s
.657 .756 .923 r
.60444 .21201 m .62864 .20371 L .63058 .21488 L p F P
0 g
s
.663 .763 .924 r
.6346 .20166 m .62864 .20371 L .63058 .21488 L p F P
0 g
s
.663 .763 .924 r
.63058 .21488 m .64205 .2108 L .6346 .20166 L p F P
0 g
s
.768 .825 .897 r
.70811 .27581 m .70341 .2789 L .69627 .27099 L p F P
0 g
s
.71 .808 .926 r
.66605 .28512 m .69627 .27099 L .70341 .2789 L p F P
0 g
s
.918 .826 .74 r
.7181 .1207 m .72412 .13072 L .71424 .14718 L p F P
0 g
s
.943 .824 .696 r
.72312 .11028 m .7181 .1207 L .72412 .13072 L p F P
0 g
s
.99 .834 .595 r
.80354 .12772 m .80559 .12086 L .7992 .11617 L p F P
0 g
s
.994 .802 .54 r
.80078 .07832 m .8061 .08865 L .80312 .10273 L p F P
0 g
s
.997 .778 .472 r
.8061 .08865 m .80078 .07832 L .80256 .0647 L p F P
0 g
s
.621 .75 .939 r
.62837 .28416 m .65869 .27626 L .66605 .28512 L p F P
0 g
s
.61 .743 .94 r
.65869 .27626 m .62837 .28416 L .62084 .27449 L p F P
0 g
s
.789 .847 .895 r
.72634 .25085 m .70493 .26545 L .70811 .27581 L p F P
0 g
s
.789 .847 .895 r
.70811 .27581 m .73333 .2581 L .72634 .25085 L p F P
0 g
s
.768 .825 .897 r
.69627 .27099 m .70493 .26545 L .70811 .27581 L p F P
0 g
s
.895 .873 .808 r
.77635 .21332 m .77312 .20279 L p .76024 .22756 L F P
0 g
s
.895 .873 .808 r
.76024 .22756 m .76285 .23001 L .77635 .21332 L p F P
0 g
s
.922 .885 .778 r
.785 .18576 m .78544 .18613 L p .77635 .21332 L F P
0 g
s
.922 .885 .778 r
.77635 .21332 m .77312 .20279 L .785 .18576 L p F P
0 g
s
.302 .569 .932 r
.53728 .23892 m .55504 .24305 L .56214 .25245 L p F P
0 g
s
.489 .661 .938 r
.60448 .2751 m .62084 .27449 L .61326 .26487 L p F P
0 g
s
.489 .661 .938 r
.61326 .26487 m .59988 .26504 L .60448 .2751 L p F P
0 g
s
.518 .668 .93 r
.58291 .26553 m .59988 .26504 L .60448 .2751 L p F P
0 g
s
.518 .694 .948 r
.60372 .21207 m .60444 .21201 L .59683 .20262 L p F P
0 g
s
.518 .694 .948 r
.59683 .20262 m .59637 .20265 L .60372 .21207 L p F P
0 g
s
.655 .756 .924 r
.62864 .20371 m .60444 .21201 L .59683 .20262 L p F P
0 g
s
.701 .797 .925 r
.69627 .27099 m .66605 .28512 L .65869 .27626 L p F P
0 g
s
.752 .798 .89 r
.67202 .19238 m .64205 .2108 L .6346 .20166 L p F P
0 g
s
.977 .846 .645 r
.79885 .11733 m .80354 .12772 L .79779 .14285 L p F P
0 g
s
.99 .834 .595 r
.7992 .11617 m .79885 .11733 L .80354 .12772 L p F P
0 g
s
.873 .877 .836 r
.76133 .23164 m .76024 .22756 L .76285 .23001 L closepath p F P
0 g
s
.497 .669 .94 r
.59988 .26504 m .58291 .26553 L .5752 .25561 L p F P
0 g
s
.849 .864 .853 r
.76024 .22756 m .76133 .23164 L .7404 .2519 L p F P
0 g
s
.275 .557 .929 r
.56214 .25245 m .5752 .25561 L .56743 .24614 L p F P
0 g
s
.275 .557 .929 r
.56743 .24614 m .55504 .24305 L .56214 .25245 L p F P
0 g
s
.951 .881 .729 r
.79444 .16904 m .78521 .18542 L .78544 .18613 L p F P
0 g
s
.946 .87 .731 r
.7904 .1586 m .79444 .16904 L .78521 .18542 L p F P
0 g
s
.966 .867 .689 r
.79444 .16904 m .7904 .1586 L .79779 .14285 L p F P
0 g
s
.993 .768 .487 r
.79661 .05447 m .80256 .0647 L .80078 .07832 L p F P
0 g
s
.992 .737 .412 r
.80256 .0647 m .79661 .05447 L .79727 .04131 L p F P
0 g
s
.828 .855 .866 r
.7404 .2519 m .73333 .2581 L .72634 .25085 L p F P
0 g
s
.828 .855 .866 r
.72634 .25085 m .73726 .24145 L .7404 .2519 L p F P
0 g
s
.849 .864 .853 r
.75606 .22352 m .76024 .22756 L p .7404 .2519 L F P
0 g
s
.849 .864 .853 r
.7404 .2519 m .73726 .24145 L .75606 .22352 L p F P
0 g
s
.89 .824 .776 r
.71424 .14718 m .70816 .13721 L p .7001 .16261 L F P
0 g
s
.89 .824 .776 r
.7001 .16261 m .70162 .16441 L .71424 .14718 L p F P
0 g
s
.918 .826 .74 r
.71424 .14718 m .70816 .13721 L .7181 .1207 L p F P
0 g
s
.943 .803 .676 r
.72532 .10517 m .72312 .11028 L .71601 .10111 L p F P
0 g
s
.943 .803 .676 r
.71601 .10111 m .71853 .09528 L .72532 .10517 L p F P
0 g
s
.961 .793 .629 r
.72532 .10517 m .71853 .09528 L .72342 .08059 L p F P
0 g
s
.989 .728 .429 r
.79072 .03117 m .79727 .04131 L .79661 .05447 L p F P
0 g
s
.981 .69 .346 r
.79727 .04131 m .79072 .03117 L .7903 .01846 L p F P
0 g
s
.934 .807 .697 r
.7181 .1207 m .72312 .11028 L .71601 .10111 L p F P
0 g
s
.984 .819 .598 r
.80312 .10273 m .79778 .09243 L p .79734 .11442 L F P
0 g
s
.984 .819 .598 r
.79734 .11442 m .7992 .11617 L .80312 .10273 L p F P
0 g
s
.994 .802 .54 r
.80312 .10273 m .79778 .09243 L .80078 .07832 L p F P
0 g
s
.935 .883 .758 r
.785 .18576 m .78521 .18542 L .78544 .18613 L closepath p F P
0 g
s
.878 .872 .827 r
.75606 .22352 m .7582 .22113 L .76024 .22756 L closepath p F P
0 g
s
.895 .873 .808 r
.77312 .20279 m .7582 .22113 L .76024 .22756 L p F P
0 g
s
.862 .826 .811 r
.70136 .16471 m .7001 .16261 L .70162 .16441 L closepath p F P
0 g
s
.836 .818 .832 r
.7001 .16261 m .70136 .16471 L .68079 .18485 L p F P
0 g
s
.929 .869 .759 r
.78521 .18542 m .785 .18576 L .77833 .17944 L p F P
0 g
s
.929 .869 .759 r
.77833 .17944 m .78116 .17502 L .78521 .18542 L p F P
0 g
s
.946 .87 .731 r
.78521 .18542 m .78116 .17502 L .7904 .1586 L p F P
0 g
s
.918 .874 .777 r
.77312 .20279 m .785 .18576 L .77833 .17944 L p F P
0 g
s
.813 .813 .85 r
.68079 .18485 m .67202 .19238 L .66469 .18345 L p F P
0 g
s
.752 .798 .89 r
.6346 .20166 m .66469 .18345 L .67202 .19238 L p F P
0 g
s
.813 .813 .85 r
.66469 .18345 m .67462 .17499 L .68079 .18485 L p F P
0 g
s
.836 .818 .832 r
.69443 .15575 m .7001 .16261 L p .68079 .18485 L F P
0 g
s
.836 .818 .832 r
.68079 .18485 m .67462 .17499 L .69443 .15575 L p F P
0 g
s
.96 .853 .691 r
.79309 .13249 m .79779 .14285 L .7904 .1586 L p F P
0 g
s
.977 .846 .645 r
.79779 .14285 m .79309 .13249 L .79885 .11733 L p F P
0 g
s
.61 .743 .94 r
.62084 .27449 m .65128 .26721 L .65869 .27626 L p F P
0 g
s
.601 .738 .941 r
.65128 .26721 m .62084 .27449 L .61326 .26487 L p F P
0 g
s
.89 .824 .776 r
.70816 .13721 m .69523 .15479 L .7001 .16261 L p F P
0 g
s
.871 .823 .799 r
.69443 .15575 m .69523 .15479 L .7001 .16261 L closepath p F P
0 g
s
.91 .811 .738 r
.7113 .11084 m .7181 .1207 L .70816 .13721 L p F P
0 g
s
.934 .807 .697 r
.71601 .10111 m .7113 .11084 L .7181 .1207 L p F P
0 g
s
.762 .818 .896 r
.70493 .26545 m .69627 .27099 L .68905 .26272 L p F P
0 g
s
.701 .797 .925 r
.65869 .27626 m .68905 .26272 L .69627 .27099 L p F P
0 g
s
.988 .79 .55 r
.79481 .06811 m .80078 .07832 L .79778 .09243 L p F P
0 g
s
.993 .768 .487 r
.80078 .07832 m .79481 .06811 L .79661 .05447 L p F P
0 g
s
.655 .756 .924 r
.62848 .19405 m .62864 .20371 L p .59683 .20262 L F P
0 g
s
.657 .757 .924 r
.62864 .20371 m .62848 .19405 L .6346 .20166 L closepath p F P
0 g
s
.891 .865 .807 r
.76919 .19239 m .77312 .20279 L .7582 .22113 L p F P
0 g
s
.918 .874 .777 r
.77833 .17944 m .76919 .19239 L .77312 .20279 L p F P
0 g
s
.762 .818 .896 r
.68905 .26272 m .70108 .2552 L .70493 .26545 L p F P
0 g
s
.781 .835 .893 r
.71927 .24312 m .70108 .2552 L .70493 .26545 L p F P
0 g
s
.781 .835 .893 r
.70493 .26545 m .72634 .25085 L .71927 .24312 L p F P
0 g
s
.655 .756 .924 r
.59683 .20262 m .62708 .19231 L .62848 .19405 L p F P
0 g
s
.473 .663 .945 r
.59988 .26504 m .61326 .26487 L .60563 .25535 L p F P
0 g
s
.473 .663 .945 r
.60563 .25535 m .59391 .25533 L .59988 .26504 L p F P
0 g
s
.497 .669 .94 r
.5752 .25561 m .59391 .25533 L .59988 .26504 L p F P
0 g
s
.694 .789 .924 r
.68905 .26272 m .65869 .27626 L .65128 .26721 L p F P
0 g
s
.479 .674 .95 r
.59391 .25533 m .5752 .25561 L .56743 .24614 L p F P
0 g
s
.749 .787 .884 r
.62848 .19405 m .6346 .20166 L .66469 .18345 L p F P
0 g
s
.983 .821 .604 r
.79885 .11733 m .79734 .11442 L .7992 .11617 L closepath p F P
0 g
s
.97 .832 .65 r
.79734 .11442 m .79885 .11733 L .79309 .13249 L p F P
0 g
s
.988 .757 .499 r
.79004 .04436 m .79661 .05447 L .79481 .06811 L p F P
0 g
s
.989 .728 .429 r
.79661 .05447 m .79004 .04436 L .79072 .03117 L p F P
0 g
s
.94 .856 .73 r
.78569 .14827 m .7904 .1586 L .78116 .17502 L p F P
0 g
s
.96 .853 .691 r
.7904 .1586 m .78569 .14827 L .79309 .13249 L p F P
0 g
s
.872 .859 .825 r
.7582 .22113 m .75606 .22352 L .74916 .21634 L p F P
0 g
s
.872 .859 .825 r
.74916 .21634 m .75418 .2108 L .7582 .22113 L p F P
0 g
s
.891 .865 .807 r
.7582 .22113 m .75418 .2108 L .76919 .19239 L p F P
0 g
s
.884 .812 .774 r
.7013 .1274 m .70816 .13721 L .69523 .15479 L p F P
0 g
s
.91 .811 .738 r
.70816 .13721 m .7013 .1274 L .7113 .11084 L p F P
0 g
s
.847 .859 .851 r
.73726 .24145 m .75606 .22352 L .74916 .21634 L p F P
0 g
s
.822 .844 .865 r
.73726 .24145 m .72634 .25085 L .71927 .24312 L p F P
0 g
s
.822 .844 .865 r
.71927 .24312 m .73341 .23112 L .73726 .24145 L p F P
0 g
s
.847 .859 .851 r
.74916 .21634 m .73341 .23112 L .73726 .24145 L p F P
0 g
s
.973 .83 .641 r
.79258 .10954 m .79349 .10706 L .79734 .11442 L closepath p F P
0 g
s
.984 .819 .598 r
.79778 .09243 m .79349 .10706 L .79734 .11442 L p F P
0 g
s
.97 .832 .65 r
.79258 .10954 m .79734 .11442 L p .79309 .13249 L F P
0 g
s
.978 .806 .603 r
.7918 .08225 m .79778 .09243 L .79349 .10706 L p F P
0 g
s
.988 .79 .55 r
.79778 .09243 m .7918 .08225 L .79481 .06811 L p F P
0 g
s
.865 .812 .795 r
.69523 .15479 m .69443 .15575 L .68715 .14642 L p F P
0 g
s
.865 .812 .795 r
.68715 .14642 m .6883 .14504 L .69523 .15479 L p F P
0 g
s
.884 .812 .774 r
.69523 .15479 m .6883 .14504 L .7013 .1274 L p F P
0 g
s
.832 .809 .828 r
.67462 .17499 m .69443 .15575 L .68715 .14642 L p F P
0 g
s
.809 .804 .846 r
.67462 .17499 m .66469 .18345 L .65728 .17412 L p F P
0 g
s
.749 .787 .884 r
.66469 .18345 m .65728 .17412 L p .62848 .19405 L F P
0 g
s
.922 .856 .759 r
.78116 .17502 m .77833 .17944 L .77154 .17231 L p F P
0 g
s
.922 .856 .759 r
.77154 .17231 m .77643 .16473 L .78116 .17502 L p F P
0 g
s
.94 .856 .73 r
.78116 .17502 m .77643 .16473 L .78569 .14827 L p F P
0 g
s
.809 .804 .846 r
.65728 .17412 m .66763 .16532 L .67462 .17499 L p F P
0 g
s
.832 .809 .828 r
.68715 .14642 m .66763 .16532 L .67462 .17499 L p F P
0 g
s
.953 .839 .692 r
.78773 .12225 m .79309 .13249 L .78569 .14827 L p F P
0 g
s
.97 .832 .65 r
.79309 .13249 m .78773 .12225 L .79258 .10954 L p F P
0 g
s
.601 .738 .941 r
.61326 .26487 m .6438 .25803 L .65128 .26721 L p F P
0 g
s
.596 .735 .941 r
.6438 .25803 m .61326 .26487 L .60563 .25535 L p F P
0 g
s
.911 .859 .778 r
.76919 .19239 m .77833 .17944 L .77154 .17231 L p F P
0 g
s
.757 .811 .895 r
.70108 .2552 m .68905 .26272 L .68175 .25414 L p F P
0 g
s
.694 .789 .924 r
.65128 .26721 m .68175 .25414 L .68905 .26272 L p F P
0 g
s
.981 .778 .557 r
.78822 .05802 m .79481 .06811 L .7918 .08225 L p F P
0 g
s
.988 .757 .499 r
.79481 .06811 m .78822 .05802 L .79004 .04436 L p F P
0 g
s
.736 .783 .891 r
.62708 .19231 m .62713 .19228 L .62848 .19405 L closepath p F P
0 g
s
.749 .787 .884 r
.65728 .17412 m .62713 .19228 L .62848 .19405 L p F P
0 g
s
.479 .674 .95 r
.56743 .24614 m .58675 .24591 L .59391 .25533 L p F P
0 g
s
.688 .782 .922 r
.68175 .25414 m .65128 .26721 L .6438 .25803 L p F P
0 g
s
.886 .853 .804 r
.76455 .18212 m .76919 .19239 L .75418 .2108 L p F P
0 g
s
.911 .859 .778 r
.77154 .17231 m .76455 .18212 L .76919 .19239 L p F P
0 g
s
.462 .668 .952 r
.59391 .25533 m .60563 .25535 L .59794 .24597 L p F P
0 g
s
.462 .668 .952 r
.59794 .24597 m .58675 .24591 L .59391 .25533 L p F P
0 g
s
.757 .811 .895 r
.68175 .25414 m .69652 .24508 L .70108 .2552 L p F P
0 g
s
.774 .824 .891 r
.71212 .23494 m .69652 .24508 L .70108 .2552 L p F P
0 g
s
.774 .824 .891 r
.70108 .2552 m .71927 .24312 L .71212 .23494 L p F P
0 g
s
.965 .816 .645 r
.79349 .10706 m .79258 .10954 L .78581 .10147 L p F P
0 g
s
.965 .816 .645 r
.78581 .10147 m .78749 .0969 L .79349 .10706 L p F P
0 g
s
.978 .806 .603 r
.79349 .10706 m .78749 .0969 L .7918 .08225 L p F P
0 g
s
.934 .842 .73 r
.78031 .13807 m .78569 .14827 L .77643 .16473 L p F P
0 g
s
.953 .839 .692 r
.78569 .14827 m .78031 .13807 L .78773 .12225 L p F P
0 g
s
.963 .818 .653 r
.78773 .12225 m .79258 .10954 L .78581 .10147 L p F P
0 g
s
.867 .848 .823 r
.75418 .2108 m .74916 .21634 L .74217 .20857 L p F P
0 g
s
.867 .848 .823 r
.74217 .20857 m .74945 .2006 L .75418 .2108 L p F P
0 g
s
.886 .853 .804 r
.75418 .2108 m .74945 .2006 L .76455 .18212 L p F P
0 g
s
.817 .835 .862 r
.73341 .23112 m .71927 .24312 L .71212 .23494 L p F P
0 g
s
.84 .846 .849 r
.73341 .23112 m .74916 .21634 L .74217 .20857 L p F P
0 g
s
.817 .835 .862 r
.71212 .23494 m .72882 .22094 L .73341 .23112 L p F P
0 g
s
.84 .846 .849 r
.74217 .20857 m .72882 .22094 L .73341 .23112 L p F P
0 g
s
.97 .793 .608 r
.78518 .07219 m .7918 .08225 L .78749 .0969 L p F P
0 g
s
.981 .778 .557 r
.7918 .08225 m .78518 .07219 L .78822 .05802 L p F P
0 g
s
.596 .735 .941 r
.60563 .25535 m .63625 .24876 L .6438 .25803 L p F P
0 g
s
.594 .735 .942 r
.63625 .24876 m .60563 .25535 L .59794 .24597 L p F P
0 g
s
.916 .843 .758 r
.77643 .16473 m .77154 .17231 L .76464 .1644 L p F P
0 g
s
.916 .843 .758 r
.76464 .1644 m .77102 .15457 L .77643 .16473 L p F P
0 g
s
.934 .842 .73 r
.77643 .16473 m .77102 .15457 L .78031 .13807 L p F P
0 g
s
.946 .825 .692 r
.78171 .11213 m .78773 .12225 L .78031 .13807 L p F P
0 g
s
.963 .818 .653 r
.78581 .10147 m .78171 .11213 L .78773 .12225 L p F P
0 g
s
.753 .805 .894 r
.69652 .24508 m .68175 .25414 L .67439 .24528 L p F P
0 g
s
.688 .782 .922 r
.6438 .25803 m .67439 .24528 L .68175 .25414 L p F P
0 g
s
.903 .845 .777 r
.76455 .18212 m .77154 .17231 L .76464 .1644 L p F P
0 g
s
.685 .776 .92 r
.67439 .24528 m .6438 .25803 L .63625 .24876 L p F P
0 g
s
.881 .841 .801 r
.75919 .17198 m .76455 .18212 L .74945 .2006 L p F P
0 g
s
.903 .845 .777 r
.76464 .1644 m .75919 .17198 L .76455 .18212 L p F P
0 g
s
.768 .814 .889 r
.70489 .22634 m .6912 .23511 L .69652 .24508 L p F P
0 g
s
.768 .814 .889 r
.69652 .24508 m .71212 .23494 L .70489 .22634 L p F P
0 g
s
.753 .805 .894 r
.67439 .24528 m .6912 .23511 L .69652 .24508 L p F P
0 g
s
.957 .803 .648 r
.78749 .0969 m .78581 .10147 L .77888 .09215 L p F P
0 g
s
.957 .803 .648 r
.77888 .09215 m .78083 .08688 L .78749 .0969 L p F P
0 g
s
.97 .793 .608 r
.78749 .0969 m .78083 .08688 L .78518 .07219 L p F P
0 g
s
.946 .825 .692 r
.78031 .13807 m .77425 .12799 L .78171 .11213 L p F P
0 g
s
.927 .829 .728 r
.77425 .12799 m .78031 .13807 L .77102 .15457 L p F P
0 g
s
.955 .804 .655 r
.78171 .11213 m .78581 .10147 L .77888 .09215 L p F P
0 g
s
.861 .837 .82 r
.74945 .2006 m .74217 .20857 L .73509 .20024 L p F P
0 g
s
.861 .837 .82 r
.73509 .20024 m .74401 .19054 L .74945 .2006 L p F P
0 g
s
.881 .841 .801 r
.74945 .2006 m .74401 .19054 L .75919 .17198 L p F P
0 g
s
.813 .825 .86 r
.72882 .22094 m .71212 .23494 L .70489 .22634 L p F P
0 g
s
.834 .834 .846 r
.72882 .22094 m .74217 .20857 L .73509 .20024 L p F P
0 g
s
.813 .825 .86 r
.70489 .22634 m .72346 .2109 L .72882 .22094 L p F P
0 g
s
.834 .834 .846 r
.73509 .20024 m .72346 .2109 L .72882 .22094 L p F P
0 g
s
.594 .735 .942 r
.59794 .24597 m .62865 .23942 L .63625 .24876 L p F P
0 g
s
.909 .83 .756 r
.77102 .15457 m .76464 .1644 L .75763 .15573 L p F P
0 g
s
.909 .83 .756 r
.75763 .15573 m .76492 .14454 L .77102 .15457 L p F P
0 g
s
.927 .829 .728 r
.77102 .15457 m .76492 .14454 L .77425 .12799 L p F P
0 g
s
.939 .811 .692 r
.77502 .10214 m .78171 .11213 L .77425 .12799 L p F P
0 g
s
.955 .804 .655 r
.77888 .09215 m .77502 .10214 L .78171 .11213 L p F P
0 g
s
.75 .799 .891 r
.6912 .23511 m .67439 .24528 L .66695 .23616 L p F P
0 g
s
.685 .776 .92 r
.63625 .24876 m .66695 .23616 L .67439 .24528 L p F P
0 g
s
.683 .772 .918 r
.66695 .23616 m .63625 .24876 L .62865 .23942 L p F P
0 g
s
.896 .831 .775 r
.75919 .17198 m .76464 .1644 L .75763 .15573 L p F P
0 g
s
.876 .829 .797 r
.75312 .16198 m .75919 .17198 L .74401 .19054 L p F P
0 g
s
.896 .831 .775 r
.75763 .15573 m .75312 .16198 L .75919 .17198 L p F P
0 g
s
.75 .799 .891 r
.66695 .23616 m .68505 .2253 L .6912 .23511 L p F P
0 g
s
.763 .805 .886 r
.69757 .21735 m .68505 .2253 L .6912 .23511 L p F P
0 g
s
.763 .805 .886 r
.6912 .23511 m .70489 .22634 L .69757 .21735 L p F P
0 g
s
.92 .816 .727 r
.76752 .11804 m .77425 .12799 L .76492 .14454 L p F P
0 g
s
.939 .811 .692 r
.77425 .12799 m .76752 .11804 L .77502 .10214 L p F P
0 g
s
.809 .817 .856 r
.72346 .2109 m .70489 .22634 L .69757 .21735 L p F P
0 g
s
.856 .826 .817 r
.74401 .19054 m .73509 .20024 L .72791 .19137 L p F P
0 g
s
.856 .826 .817 r
.72791 .19137 m .73785 .18061 L .74401 .19054 L p F P
0 g
s
.876 .829 .797 r
.74401 .19054 m .73785 .18061 L .75312 .16198 L p F P
0 g
s
.828 .823 .843 r
.72346 .2109 m .73509 .20024 L .72791 .19137 L p F P
0 g
s
.809 .817 .856 r
.69757 .21735 m .71733 .20101 L .72346 .2109 L p F P
0 g
s
.828 .823 .843 r
.72791 .19137 m .71733 .20101 L .72346 .2109 L p F P
0 g
s
.903 .818 .754 r
.76492 .14454 m .75763 .15573 L .75052 .1463 L p F P
0 g
s
.903 .818 .754 r
.75052 .1463 m .75814 .13464 L .76492 .14454 L p F P
0 g
s
.92 .816 .727 r
.76492 .14454 m .75814 .13464 L .76752 .11804 L p F P
0 g
s
.749 .793 .889 r
.68505 .2253 m .66695 .23616 L .65945 .22682 L p F P
0 g
s
.683 .772 .918 r
.62865 .23942 m .65945 .22682 L .66695 .23616 L p F P
0 g
s
.889 .818 .772 r
.75312 .16198 m .75763 .15573 L .75052 .1463 L p F P
0 g
s
.871 .818 .794 r
.7463 .15212 m .75312 .16198 L .73785 .18061 L p F P
0 g
s
.889 .818 .772 r
.75052 .1463 m .7463 .15212 L .75312 .16198 L p F P
0 g
s
.759 .797 .883 r
.69018 .20798 m .67803 .21568 L .68505 .2253 L p F P
0 g
s
.759 .797 .883 r
.68505 .2253 m .69757 .21735 L .69018 .20798 L p F P
0 g
s
.749 .793 .889 r
.65945 .22682 m .67803 .21568 L .68505 .2253 L p F P
0 g
s
.806 .808 .853 r
.71733 .20101 m .69757 .21735 L .69018 .20798 L p F P
0 g
s
.852 .816 .814 r
.73785 .18061 m .72791 .19137 L .72065 .18196 L p F P
0 g
s
.852 .816 .814 r
.72065 .18196 m .73096 .17082 L .73785 .18061 L p F P
0 g
s
.871 .818 .794 r
.73785 .18061 m .73096 .17082 L .7463 .15212 L p F P
0 g
s
.806 .808 .853 r
.69018 .20798 m .71039 .19129 L .71733 .20101 L p F P
0 g
s
.823 .812 .839 r
.72065 .18196 m .71039 .19129 L .71733 .20101 L p F P
0 g
s
.823 .812 .839 r
.71733 .20101 m .72791 .19137 L .72065 .18196 L p F P
0 g
s
.25 Mabswid
.80629 0 m
.97998 .2604 L
s
.97998 .2604 m
1 .4248 L
s
1 .4248 m
.82064 .17208 L
s
.82064 .17208 m
.80629 0 L
s
.01968 .27973 m
0 .44347 L
s
0 .44347 m
.82064 .17208 L
s
.82064 .17208 m
.80629 0 L
s
.80629 0 m
.01968 .27973 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 370.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001LR000`400?l00000o`00003ooooonf[?
oookJP;o0000L?oonfX00?oooo]Zc?oonfX3o`000003oookJ_l0003ooo]Z06oooo]Z003ooookJ/Wo
oo]Z0ol00004oookJP;o0000KooonfX00?oooo]Za_oonfX3o`0000Oooo]Z00?o0000oookJ_l00000
K_oonfX00?oooo]Z`ooonfX3o`0000[ooo]Z00?o0000oookJ_l00000K_oonfX00?oooo]Z`?oonfX3
o`0000gooo]Z00Co0000oookJ_oonf[o0000KOoonfX00?oooo]Z__oonfX2o`00013ooo]Z00Go0000
oookJ_oonf[ooo]Zo`00001/oookJP00oooonfZkoookJP?o00004ooonfX01?l0003ooo]ZoookJ_l0
001/oookJP00oooonfZhoookJP?o00005_oonfX01Ol0003ooo]ZoookJ_oonf[o000006_ooo]Z003o
oookJ[Gooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0J?oonfX0
0?oooo]Z/_oonfX3o`0001;ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z06Sooo]Z003ooookJ[3ooo]Z0_l0000EoookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP1WoookJP00oooonfZ]oookJP?o0000
5ooonfX2o`0000Sooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP1VoookJP00oooo
nfZZoookJP?o00006_oonfX2o`0000Sooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP1VoookJP00oooonfZWoookJP?o00007OoonfX00ol0003onk1Ho`000007oookJP03o`000?oonf[o
oo]Z00Gooo]Z00?o0000oookJ_oonfX0IOoonfX00?oooo]ZY?oonfX3o`00023ooo]Z00?o0000oo^`
F?l000001ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z06Cooo]Z003ooookJZ7o
oo]Z0ol0000SoookJP04o`000?ok/5Sonk1Ho`0000Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0
003ooo]ZoookJP1ToookJP00oooonfZOoookJP;o00009_oonfX01?l0003onk1Hoo^`F?l00006oook
JP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0HooonfX00?oooo]ZW?oonfX3o`0002So
oo]Z00?o0000oo^`F?ok/5P00_l00005oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oo
nfX0H_oonfX00?oooo]ZVOoonfX3o`0002_ooo]Z00Ko0000oo^`F?ok/5So0000ooZaD_l00004oook
JP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0H_oonfX00?oooo]ZU_oonfX3o`0002ko
oo]Z0_l00002oo^`F0;o00001OoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z067o
oo]Z003ooookJY?ooo]Z0ol0000aoookJP07o`000?om^Vgo0000oo^`F?l0003on[5Bo`000004oook
JP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0H?oonfX00?oooo]ZT?oonfX3o`0003Co
oo]Z00?o0000oofjKOom^Vd00_l00002ooZaDP05o`000?oonf[ooo]ZoookJ_l000002ooonfX00ol0
003ooo]ZoookJP1PoookJP00oooonfZ>oookJP;o00004ooonfX00ol0003ooo]ZoookJP0QoookJP05
o`000?om^VgooKY]oofjKOl000000_oj/E801Ol0003ooo]ZoookJ_oonf[o000000cooo]Z00?o0000
oookJ_oonfX0GooonfX00?oooo]ZRooonfX3o`0001Gooo]Z00?o0000oookJ_oonfX08OoonfX01Ol0
003ooKY]oofjKOom^Vgo000000;on[5B0_l00002oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000
oookJ_oonfX0G_oonfX00?oooo]ZR?oonfX3o`0001Sooo]Z0_l0000RoookJP04o`000?om^VgooKY]
oofjK@;o000000?on[5Bo`000?l000000_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z05kooo]Z003ooookJXGooo]Z0ol0000KoookJP03o`000?ok]6?o0000027ooo]Z00Co0000oofj
KOom^VgooKY]0_l000001_oj/E;o0000ooVbC?l0003ooo]Zo`0000kooo]Z00?o0000oookJ_oonfX0
GOoonfX00?oooo]ZP_oonfX3o`0001kooo]Z00?o0000oo^dHol000008OoonfX2o`0000;ooKY]00So
0000ooflJOl0003o0000ooVbC?l0003ooo]Zo`0000oooo]Z00?o0000oookJ_oonfX0G?oonfX00?oo
oo]ZOooonfX3o`00027ooo]Z00Co0000oo^dHook]6?o00008?oonfX2o`000004oofjKOl0003ooKaY
ooflJ@;o00000_oi/T`2o`0000oooo]Z00?o0000oookJ_oonfX0G?oonfX00?oooo]ZOOoonfX2o`00
02Cooo]Z00Go0000oo^dHook]6?onkASo`00000OoookJP04o`000?ol`Goo0000o`0000?ooKaY00?o
0000ooVbC?oi/T`00_l0000@oookJP03o`000?oonf[ooo]Z05_ooo]Z003ooookJW[ooo]Z0ol0000V
oookJP05o`000?ok]6?onkASoo^dHol000007_oonfX00ol0003oo<5oooc1O`02o`0000?ooKaY00?o
0000ooVbC?oi/T`00_l0000AoookJP03o`000?oonf[ooo]Z05[ooo]Z003ooookJWOooo]Z0ol0000Y
oookJP04o`000?ok]6?onkASoo^dH`;o00007OoonfX01Ol0003oo<5oooc1Oool`Goo000000?ooKaY
0_l000000ooi/Tco0000o`00000AoookJP03o`000?oonf[ooo]Z05[ooo]Z003ooookJWCooo]Z0ol0
000/oookJP;o00000_ok]6<2o`0001gooo]Z00Go0000ooc1Oool`Gooo<5oo`000003ooflJ@;o0000
00ConK9<o`000?og/DCo00004OoonfX00ol0003ooo]ZoookJP1IoookJP00oooonfYaoookJP?o0000
;ooonfX01ol0003oo;mlo`000?ok]6?o0000oobfGOl000007?oonfX01?l0003oo<5oooc1Oool`Gl2
o`0000;ooKaY00Ko0000oofnI?l0003o0000ooNaA?l0000BoookJP03o`000?oonf[ooo]Z05Sooo]Z
003ooookJVoooo]Z0_l0000boookJP07o`000?ol_gco0000oo^dHol0003oo;IMo`00000LoookJP0:
o`000?ol`Gooo<5oooc1Ool0003oo/Alo`000?om_6Wo0000oofnI0;o000000?omk54o`000?l00000
4OoonfX00ol0003ooo]ZoookJP1HoookJP00oooonfY/oookJP?o0000<ooonfX01?l0003oo;mloobo
O?ol_g`2o`0000;oo;IM00?o0000oookJ_oonfX06OoonfX2o`0000;oo<5o00Go0000ook4O?l0003o
oKaYo`000002oofnI004o`000?og/DCo0000o`0001;ooo]Z00?o0000oookJ_oonfX0EooonfX00?oo
oo]ZJOoonfX3o`0003Kooo]Z00?o0000ooboO?ol_g`00_ol_g`01?l0003oo;IMoobfGOl0000Joook
JP05o`000?okahko0000ooc1Ool000000oona7`2o`0000;ooKiT00?o0000ooNaA?l000000_l0000B
oookJP03o`000?oonf[ooo]Z05Kooo]Z003ooookJVKooo]Z0ol0000CoookJP03o`000?oonf[ooo]Z
02?ooo]Z00?o0000ooboO?ol_g`00_ol_g`00ol0003oo;IMoobfG@02o`0001Wooo]Z00?o0000oo_7
S_okahh00_l00004ook4O003o`000?om_VCooKiT00Go00004_oonfX00ol0003ooo]ZoookJP1Foook
JP00oooonfYSoookJP?o00005_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?ol_gcoo;ml00;o
o;ml0_l000001?ol]Ugo0000oo^gE_l0000HoookJP03o`000?okahkonlN>00;o00001?ona7`00ol0
003ooKiToofnI005o`0001?ooo]Z00?o0000oookJ_oonfX0EOoonfX00?oooo]ZH?oonfX3o`0001Wo
oo]Z0_l0000ToookJP03o`000?ol_gcoo;ml00;oo;ml0_l000001?ol]Ugo0000oo^gE_l0000Hoook
JP05o`000?okahkonlN>oo_7S_l000001?ona7`2o`000003oofnI?l0003ooKmN00;o000000?olk0k
o`000?oonfX04_oonfX00ol0003ooo]ZoookJP1DoookJP00oooonfYNoookJP;o00007?oonfX00ol0
003oo;Ubo`00000SoookJP;o00000ool_g`01?l0003oo/9io`000?l00002oo^gEP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oo_7S_okahh00_okahh00ol0003oo/Alook4O002ook4O0;o000000?ooKiT
o`000?om_eh00_l000000ooc/3_o0000oookJP0CoookJP03o`000?oonf[ooo]Z05?ooo]Z003ooook
JU_ooo]Z0ol0000NoookJP04o`000?ol^G;oo;Ubo`00027ooo]Z00Ko0000oo[6T?ojaY3o0000oobo
O?l00002ook2N@;o00000_ok]eH00ol0003ooo]ZoookJP0DoookJP03o`000?okahkonlN>00;onlN>
0_l00003ook4O005o`000?ooagSo0000o`000?om_eh00_l000000ooc/3_o0000oookJP0CoookJP03
o`000?oonf[ooo]Z05?ooo]Z003ooookJUSooo]Z0ol0000QoookJP05o`000?ol^G;oo;UboobiL_l0
00008?oonfX01_l0003on/J@oo[6T?l0003oo;mlo`0000?oo/9i00?o0000oo^gE_ok]eH00_l0000E
oookJP03o`000?okahkonlN>00;onlN>00Go0000ooc:S?l0003oo/Alo`000002ooo7N0;o000000Co
oKmNo`000?l0003olk0k0_l0000DoookJP03o`000?oonf[ooo]Z05;ooo]Z003ooookJUGooo]Z0ol0
000ToookJP05o`000?ol^G;oo;UboobiL_l000008?oonfX01?l0003on/J@oo[6T?ojaY02o`0000?o
o/9i00?o0000oo^gE_ok]eH00_l0000DoookJP03o`000?ohbi_o000000?onlN>00Go0000ooc:S?l0
003oo/Alo`000003ooo7N003o`000?om_eko000000Co00005OoonfX00ol0003ooo]ZoookJP1Aoook
JP00oooonfYBoookJP?o00009ooonfX01?l0003oo;UboobiL_ol^G82o`0001oooo]Z00?o0000oo[6
T?ojaY000_ojaY001?l0003oo/9iook2NOon`WT2o`000004oo^gE_l0003onKM>o`0001?ooo]Z00Ko
0000ooS;Voohbi_o0000oo_7S_l00003ooc:S0;o00000oooagP00ol0003ooKmNoofoGP04o`0001Go
oo]Z00?o0000oookJ_oonfX0DOoonfX00?oooo]ZCooonfX3o`0002[ooo]Z00Co0000oobiL_ol^G;o
o;Ub0_l0000NoookJP03o`000?ojaY3on/J@00?on/J@00Co0000ook2NOon`WWoo/9i0_l000001?ok
]eKo0000ooVgC_l0000CoookJP06o`000?ohbi_on<^Ko`000?okahko00001?olbX`01?l0003oolMh
ooo7N?ooagP2o`000006oofoG_l0003o0000o`000?o][S7o00005OoonfX00ol0003ooo]ZoookJP1@
oookJP00oooonfY=oookJP;o0000;OoonfX2o`0000;oo;Ub00?o0000ooflKOl000007OoonfX00ol0
003on/J@oo[6T003oo[6T0;o00000_on`WT01?l0003oolEdo`000?l00002ooVgCP03o`000?oonf[o
oo]Z00oooo]Z00?o0000ooS;Voohbi/00_ohbi/2o`0000Coo<Z<00Co0000ooo7N?ooagSoolMh0_l0
00001_om_eko0000oo^oEol0003okJhao`0001Kooo]Z00?o0000oookJ_oonfX0CooonfX00?oooo]Z
B_oonfX3o`0002kooo]Z00So0000ooS5U?ohaICo0000oobiL_l0003ooKa]o`0001gooo]Z00?o0000
oo[6T?ojaY000_ojaY001Ol0003oo<Z>o`000?on`WWo000000;oolEd0_l00002ooVgCP03o`000?oo
nf[ooo]Z00oooo]Z00?o0000ooS;Voohbi/00oohbi/00ol0003oo<Z<ooc:S002ooc:S0;o00000_oo
agP02?l0003oolUdo`000?l0003onkmGo`000?o][S7o00005_oonfX00ol0003ooo]ZoookJP1?oook
JP00oooonfY7oookJP?o0000<OoonfX01_l0003on<FDooS5U?l0003oo;Ubo`0000;ooKa]00?o0000
oookJ_oonfX06_oonfX2o`0000?on/J@00?o0000ooc:S_olbXh00_l00003ooo5M004o`000?oi]dko
nKM>o`00017ooo]Z00?o0000ooS;Voohbi/00oohbi/02Ol0003oo<Z<ooc:S?olbXco0000ook=R_l0
003oolMho`000002ooo9M0;o000000ConkmGo`000?o][S7o00005ooonfX00ol0003ooo]ZoookJP1>
oookJP00oooonfY4oookJP?o0000=?oonfX01?l0003on<FDooS5U?ohaI@2o`0000;ooKa]00?o0000
oookJ_oonfX06OoonfX01?l0003om/^QooK;XOl00002oo[6T003o`000?olbXkoo<Z>00;o00000ooo
aG@00ol0003onKM>ooVgCP02o`0000oooo]Z00?o0000ooS;Voohbi/00oohbi/00ol0003on/jJo`00
0002ooc:S003o`000?oncH[oo/f:00;o00000ooobG@01Ol0003onkmGo`000?o][S7o000001Sooo]Z
00?o0000oookJ_oonfX0COoonfX00?oooo]Z@OoonfX3o`0003Oooo]Z00?o0000ooS5U?ohaI@00_oh
aI@00ol0003ooKa]ooflK@02o`0001[ooo]Z00Co0000ooK;XOofbj7o00000_ojaY001Ol0003oo<Z>
ooc:S_olbXko000000?oolEd0_l000000ooi]dko0000o`00000?oookJP03o`000?ohbi_on<^K00?o
n<^K00?o0000oo[>V_l000000_olbX`00ol0003oo/f:ook=RP02o`0000?oolUd00?o0000oo^oEol0
00000ol0000GoookJP03o`000?oonf[ooo]Z04gooo]Z003ooookJSoooo]Z0_l0000ioookJP03o`00
0?ohaICon<FD00?on<FD00?o0000ooflKOom_6d00_l0000JoookJP04o`000?ofbj7om/^QooK;X@;o
00001?olbXh01?l0003oolEdooo5M?ooaG@2o`000003ooVgC_l0003o000000oooo]Z00?o0000ooS;
Voohbi/00oohbi/01_l0003on/jJoo[>V_l0003oo<Z<o`0000?oo/f:00Co0000ooo9M?oobGCoolUd
1_l0000HoookJP03o`000?oonf[ooo]Z04cooo]Z003ooookJScooo]Z0ol0000koookJP03o`000?oh
aICon<FD00?on<FD0_l000001?om_6go0000oojnI_l0000IoookJP03o`000?ofbj7om/^Q00;om/^Q
00?o0000ooc:S_olbXh00_olbXh2o`000004ooo5M?l0003oolM_ooo7K`;o000000?omKI4o`000?oo
nfX03?oonfX00ol0003om<fUo`000003ooS;V`04o`000?ojcY[on/jJoo[>VP;o00001?oncHX01?l0
003oolUdooo9M?oobG@6o`0001Wooo]Z00?o0000oookJ_oonfX0BooonfX00?oooo]Z>OoonfX3o`00
03kooo]Z00?o0000ooS5U?ohaI@00_ohaI@01ol0003onlZBo`000?om_6go0000oojnI_l000006?oo
nfX00ol0003om/^QooK;X@03ooK;X@03o`000?olbXkoo<Z>00;oo<Z>00Co0000ook=S?l0003o0000
0_ooafl2o`000003ooFfA?l0003ooo]Z00cooo]Z00Co0000ooC=YOodcJGo00000_ohbi/00ol0003o
n/jJoo[>VP02oo[>VP03o`000?oncH[oo/f:00;oo/f:0_l00002ooo9M0?o000000?omkm?o`000?l0
00006OoonfX00ol0003ooo]ZoookJP1;oookJP00oooonfXfoookJP?o0000@?oonfX00ol0003olL^Z
o`000003ooS5U003o`000?okbY;onlZB00;o00000_on_VH00ol0003ooo]ZoookJP0EoookJP03o`00
0?ofbj7om/^Q00;om/^Q00?o0000ooS>X?l000000oolbXh01?l0003oo/f<o`000?l00003ooo7K`03
o`000?oe]TCo000000gooo]Z00Oo0000ooC=YOodcJGom<fUo`000?ohbi_o000000Con/jJ00So0000
ook=R_oncH[oo/f:o`000?ood8Oo0000ooo9M0;o000000?ool]_o`000?og_dl00_l0000JoookJP03
o`000?oonf[ooo]Z04[ooo]Z003ooookJS?ooo]Z0ol00013oookJP04o`000?oabj[olL^Zo`0000;o
n<FD00?o0000oo_:T_okbY800_l00002oojnIP03o`000?oonf[ooo]Z01Gooo]Z00?o0000ooK;XOof
bj400_ofbj401_l0003on<jPooS>X?l0003oo<Z>o`0000?oo/f<00Ko0000ooo7KoooafooolM_o`00
0?oe]T@2o`0000_ooo]Z00?o0000ooC=Yol000000oodcJD00ol0003on/jJoo[>VP03oo[>VP;o0000
0_oncHX00ol0003oom27ooo@Q`03o`000003ooo;Kol0003omkm?00?o00006_oonfX00ol0003ooo]Z
oookJP19oookJP00oooonfX`oookJP?o0000A_oonfX01?l0003olL^Zoo7;Z_l00002ooS5U005o`00
0?okbY;onlZBoo_:T_l000000_on_VH2o`0001Gooo]Z00?o0000oo7=[Ol000000oofbj401_l0003o
n<jPooS>X?l0003oo<Z>o`0000?oo/f<00Co0000ooo7KoooafooolM_1?l0000;oookJP04o`000?od
cJOom<fWo`0000;om<fU00?o0000oo[>V_ojcYX00_ojcYX00ol0003onm6Io`000002ook=RP03o`00
0?ood8Ooom2700?o000000?ool]_o`000?og_dl00ol0000JoookJP03o`000?oonf[ooo]Z04Wooo]Z
003ooookJRkooo]Z0_l00018oookJP03o`000?o/c[Ko000000;olL^Z0_l00004oo_:TP03o`000?on
_VKoo[iV00;o00005OoonfX00ol0003olLf]o`000002ooK;X@03o`000?ohcZ3on<jP00;on<jP0_l0
0003ook=S0;o00000_ooafl4o`0000_ooo]Z00Co0000ooC=YoodcJOom<fW0_l000000oogd:Go0000
oo[>VP02oo[>VP06o`000?okdIWonm6Io`000?oncH[o00000oood8L00ol0003ool]_o`000005o`00
01_ooo]Z00?o0000oookJ_oonfX0B?oonfX00?oooo]Z:ooonfX3o`0004Wooo]Z00Go0000onc>]_o/
c[Kok<jfo`000002oo7;ZP03o`000?okbY;onlZB00;onlZB0_l000001?on_VKo0000oog0G_l0000C
oookJP07o`000?oacJgolLf]oo7=[Ol0003om/^Qo`000005ooS>X004o`000?oncHcoo/f<ook=S0;o
000000?oolM_o`000?onb6P00_l000000oo_]3Wo0000oookJP08oookJP03o`000?odcJOom<fW00?o
m<fW00Co0000ooO@YOogd:Go00000_ojcYX00ol0003onm6Ioo_AV@02o`0000Coom2700?o0000ooo;
Kol000001_l0000KoookJP03o`000?oonf[ooo]Z04Oooo]Z003ooookJRSooo]Z0ol0001<oookJP03
o`000?o/c[Kok<jf00;ok<jf00?o0000oo7;Z_l000000ookbY800ol0003ooLj?oog>S`02o`000003
oog0G_l0003ooo]Z01;ooo]Z00Oo0000oo7=[OoacJgolLf]o`000?ofbj7o000000Gon<jP00Ko0000
ook=S?oncHcoo/f<o`000?oodHP2o`0000;oo/QX00?o0000onnd>Ol000002OoonfX00ol0003om<fW
ooC=Y`03ooC=Y`04o`000?ogd:Gomm2Uo`0000;on/jJ00Go0000oo_AVOokdIWonm6Io`000004ooo@
Q`Ko000000?ol[e6o`000?l000006ooonfX00ol0003ooo]ZoookJP17oookJP00oooonfXUoookJP?o
0000C_oonfX00ol0003ok<jfonc>]P04onc>]P03o`000?odcjWo000000;onlZB00?o0000oog>Soom
cXl00_l00002oog0GP03o`000?oonf[ooo]Z00oooo]Z00?o0000ono>/_l000000ooacJd00ol0003o
n<jPooS>X003ooS>X005o`000?ojdYko0000ook=S?l000000_oodHP2o`0000;oo/QX00?o0000onnd
>Ol000002?oonfX00ol0003ol<nao`000003ooC=Y`03o`000?ofdJOo000000;omm2U0_l00004oo_A
V@06o`000?ood8Ooom27ooo@Qol0003oom:30_l00002oog<J@04o`000?ob_DKo0000o`0001cooo]Z
00?o0000oookJ_oonfX0A_oonfX00?oooo]Z8_oonfX3o`00053ooo]Z00?o0000onc>]_o/c[H01Oo/
c[H01_l0003om<nYooC?ZOl0003onlZBo`0000?ooLj?00Co0000oog0G_om`5ko00004?oonfX01Ol0
003okljbono>/_o_c[;o000000;olLf]00?o0000ooS>X?ohcZ000oohcZ000ol0003on]:Noo[BWP02
o`0000?oom6800Ko0000ook8J?onb6So0000onnd>Ol00008oookJP04o`000?o`ck7ol<nao`0000;o
m<fW00Co0000ooKAYoofdJOo00000_ogd:D00ol0003onm6Ioo_AV@02oo_AV@;o00000_ood8L01?l0
003oom:3o`000?l00002oog<J@04o`000?ob_DKo0000o`0001gooo]Z00?o0000oookJ_oonfX0AOoo
nfX00?oooo]Z7ooonfX3o`0005?ooo]Z00?o0000onc>]_o/c[H01?o/c[H01?l0003okm>fo`000?od
cjT2o`0000CooLj?00?o0000oog0G_om`5h00_l0000?oookJP03o`000?o_c[;okljb00;okljb0_l0
00000oocdJgo0000ooS>X003ooS>X003o`000?ojdYkon]:N00;o00000ooodHP00ol0003oo/QXook8
J004o`0000Oooo]Z00Co0000oo3?/Oo`ck7o00000_odcJL01ol0003om]6WooKAYoofdJOo0000ooO@
YOl000000ookdIT00ol0003ooMBGo`000002ooo@Q`04o`000?oodX?oom:3o`0000;ooLaY00Co0000
oo:mA_l0003o00007OoonfX00ol0003ooo]ZoookJP15oookJP00oooonfXMoookJP;o0000EOoonfX0
0ol0003ohLk5o`000005onc>]P06o`000?o_dkKokm>fo`000?odcjWo00001?omcXl2o`000003oog0
G_l0003o000000kooo]Z00?o0000ono>/_o_c[801?o_c[801?l0003olm6]oo?A[Ol00002ooS>X003
o`000?ojdYkon]:N00;on]:N00Co0000oooAR?oodHSoom680_l000000oonb6So0000o`000002o`00
00Kooo]Z00?o0000oo3?/Oo`ck400_o`ck42o`0000Gom]6W0ol00002oo_AV@06o`000?ome9OooMBG
o`000?ood8Oo00000_oodX<01Ol0003ooLaYoog<JOl0003ol[e600?o00007OoonfX00ol0003ooo]Z
oookJP14oookJP00oooonfXJoookJP?o0000E_oonfX01Ol0003ohLk5on7>aOoQc/Go000000?ok<jf
00?o0000onoC]_o_dkH00_o_dkH2o`0000CooLj?0_l000000oom`5ko0000o`00000>oookJP03o`00
0?o_c[;okljb00Cokljb00Co0000oo?A[OocdJgo00000_ohcZ000ol0003on]:Noo[BWP02oo[BWP05
o`000?oodHSoom68o`000?oodhD00_l000001?okbF3o0000o`000?l00006oookJP03o`000?o`ck7o
l<na00?ol<na00?o0000ooKAYoofdJL00oofdJL00ol0003on=BVo`000002oo_AV@03o`000?ome9Oo
oMBG00;o00000ooodX<00ol0003ooLaYoog<J@05o`0001kooo]Z00?o0000oookJ_oonfX0@ooonfX0
0?oooo]Z5ooonfX3o`0005Wooo]Z00Go0000on7>aOoQc/GohLk5o`000002onc>]P03o`000?o_dkKo
km>f00Cokm>f0_l00002oog>S`03o`000?oodX_oom:;00;o000000?om/9Ao`000?oonfX02ooonfX0
0ol0003oj<nlo`000004ono>/P03o`000?oad[;o000000;olm6]00?o0000ooS>X?l000000oojdYh0
1_l0003oo=JMo`000?oodHSo0000oooCQ@;o00000_okbF02o`0000Gooo]Z00?o0000oo3?/Oo`ck40
1?o`ck400ol0003om]6WooKAY`02ooKAY`04o`000?ohe:Kon=BVooSDYP;o00001?ome9L01?l0003o
om:3oooBPooodX<2o`000004oog<JOl0003o0000on^j?0;o00007_oonfX00ol0003ooo]ZoookJP13
oookJP00oooonfXDoookJP?o00004OoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oQc/GohLk5
00?ohLk500?o0000onc>]_l000001_o_dkH5o`0000;oom:;0_l000000oof`U7o0000oookJP0;oook
JP04o`000?oXckcoj<nlo`0000?okljb00Co0000oo7B/_oad[;o00000_ocdJd00ol0003on]:Noo[B
WP02oo[BWP05o`000?oleYgo0000oooAR?l000000_oodhD00ol0003onlUPoo_9H002o`0000Gooo]Z
00?o0000oo3?/Oo`ck400oo`ck400ol0003ol]>ao`000003ooKAY`04o`000?ohe:Kon=BVooSDYP?o
00000oome9L00ol0003oom:3oooBP`04o`000003oo[<Hol0003ojkXl00;o00007ooonfX00ol0003o
oo]ZoookJP12oookJP00oooonfXAoookJP?o00005?oonfX00ol0003ooo]ZoookJP16oookJP03o`00
0?oQc/GohLk500GohLk500?o0000onoC]_o_dkH01?o_dkH00ol0003olMRfo`000002oocDV@?o0000
00Coom:;o`000?of`U7o00002ooonfX01Ol0003oj<nlonS?_?oXckco000000;okljb00?o0000oo7B
/_oad[800_oad[800ol0003olm6]o`000004oo[BWP05o`000?oleYgo0000oooAR?l000000_oodhD0
0ol0003onlUPoo_9H002o`0000Gooo]Z00?o0000oo3?/Oo`ck400oo`ck400ol0003ol]>ao`000002
ooKAY`03o`000?ohe:Kon=BV00?on=BV00?o0000oogEV?l000000_ome9L2o`000003oooBPol0003o
000000;o000000?on/aSo`000?o[^S`00_l0000PoookJP03o`000?oonf[ooo]Z047ooo]Z003ooook
JPkooo]Z0ol0000GoookJP;o0000A_oonfX00ol0003ohLk5on7>a@06on7>a@03o`000?o_dkKokm>f
00Cokm>f00Ko0000oo7H]_oaf;Ko0000oocDVOl00002ookHU0;o000000?om/9Ao`000?oonfX02_oo
nfX00ol0003oj<nlonS?_002onS?_003o`000?o_c[;o000000GolM:b0ol00002oo[BWP05o`000?ol
eYgoo=JMoocFWOl000000ooodhD00ol0003onlUPoo_9H002o`0000Cooo]Z00?o0000oo3?/Oo`ck40
0oo`ck401ol0003ol]>aoo;C/Oobdk7o0000ooKAYol000001Oohe:H00ol0003ooMFHoogEV002o`00
0003ookHU?l0003oom:300;o000000GoomAoo`000?ojc6?o0000on^j?002o`00023ooo]Z00?o0000
oookJ_oonfX0@OoonfX00?oooo]Z3?oonfX2o`0001[ooo]Z00?o0000oo:J=?l00000AOoonfX00ol0
003ohLk5on7>a@05on7>a@03o`000?oSd/Ko000000Cokm>f00?o0000oo7H]_oaf;H00_oaf;H00ol0
003oo]RDookHU002ookHU003o`000?of`U7o000000[ooo]Z00?o0000onS?_?oXck`01?oXck`00ol0
003olM:boo7B/P04oo7B/P06o`000?oce[;o0000o`000?ojdYko00000ooleYd01Ol0003oom>5oooC
QOoodhGo000000;onlUP0ol00003oookJP03o`000?o`ck7ol<na00?ol<na00Oo0000oo;C/Oobdk7o
l]>ao`000?ofdJOo000000Con=BV00?o0000oo[HYOl000000_omeIP3o`000003oooBPol0003oomAo
00Co000000?ojkXlo`000?l000008OoonfX00ol0003ooo]ZoookJP10oookJP00oooonfX9oookJP?o
00007OoonfX2o`0004Cooo]Z00?o0000on7>aOoQc/D01OoQc/D01Ol0003ohm;6on?Ba_oSd/Ko0000
00;okm>f00?o0000oo7H]_oaf;H00ooaf;H01?l0003oo]RDookHU?onf9@3o`000003onjoA?l0003o
oo]Z00Sooo]Z00?o0000onS?_?oXck`01?oXck`00ol0003olM:boo7B/P03oo7B/P07o`000?oce[;o
lmJboo?F/_l0003on]:No`000003oocFW@04o`000?oodhGoom>5oooCQ@;o000000ConlUPo`000?l0
003o00000_oonfX00ol0003ojm2jo`000004oo3?/@03o`000?obdk7ol]>a00;ol]>a00?o0000ooSD
Y_ohe:H00oohe:H00ol0003on]RUo`000002oogEV004o`000?onf9Go0000o`0000;oomAo0_l00000
0oojc6?o0000o`000002o`0002;ooo]Z00?o0000oookJ_oonfX0?ooonfX00?oooo]Z1_oonfX3o`00
023ooo]Z00?o0000oo:J=?l00000@_oonfX00ol0003ohLk5on7>a@05on7>a@03o`000?oSd/Kohm;6
00?ohm;600?o0000onoC]_l000001?oaf;H00ol0003om=beo`000002ookHU005o`000?oog8oo0000
onjoA?l000002?oonfX00ol0003oj<nlonS?_004onS?_003o`000?o[dkgo000000ColM:b00?o0000
oo?F/_oce[800_oce[82o`0000?oo=JM0_l00002oooCQ@?o000000Gom/QGo`000?l0003ooo]Zo`00
0003on_@^P04o`000?o`ck7ol<nao`0000Gol]>a00?o0000ooSDY_ohe:H00_ohe:H01_l0003on]RU
oo[HYOl0003ooMFHo`0000?oo]RE1Ol000000oojc6?o0000o`000002o`0002;ooo]Z00?o0000oook
J_oonfX0?ooonfX00?oooo]Z0ooonfX3o`0002?ooo]Z00Co0000oo:J=?obVSCo0000@?oonfX2o`00
00KohLk500?o0000on?Ba_oSd/H01OoSd/H00ol0003olMRfoo7H]P03oo7H]P05o`000?odg;Go0000
ookHU?l000000_oog8l00ol0003ok[m4o`000008oookJP03o`000?oXckcoj<nl00Coj<nl00Co0000
on_C_Oo[dkgo00000_oad[800ol0003olmJboo?F/P03oo?F/P0:o`000?okf:7o0000oocFWOl0003o
oMZJo`000?oodhGo0000oooFO`Go000000?ooo]Zo`000?o[d;X00oo[d;X00ol0003ol<nao`000004
oo;C/@03o`000?oce[7o000000?on=BV00Co0000oo[HYOojf:Gon]RU0_l00003ookHU@03o`000?oo
eH3oomF000;o000000?on/aSooG;F_l000000_l0000SoookJP03o`000?oonf[ooo]Z03kooo]Z003o
oookJP?o00004ooonfX00ol0003ooo]ZoookJP0@oookJP04o`000?obVSColYXdo`0003oooo]Z00Co
0000omO=d?oGcM3o00001OoQc/D00ol0003ohm;6on?BaP05on?BaP03o`000?oaf;KolMRf00;olMRf
00Ko0000ooCL]Oodg;Go0000ookHU?l00002oooLS`03o`000?o^_dCo000000Oooo]Z00?o0000onS?
_?oXck`01?oXck`01Ol0003ojm>mon_C_Oo[dkgo000000;olM:b00?o0000oo?F/_oce[800ooce[80
0ol0003onmRQoo_HX@02o`0000;ooMZJ0_l00002oooFO`Go00001_o[d;X00ol0003ol]>aoo;C/@03
oo;C/@03o`000?oce[7o000000?on=BV00Go0000oo[HYOojf:Gon]RUo`000004ookHU@;o000000Co
omF0o`000?oneg[o00000_oebeX2o`0002Cooo]Z00?o0000oookJ_oonfX0?OoonfX00?gooo]Z0_l0
000FoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oo:J=?obVS@00_l0000moookJP03o`000?oG
cM3oelg@00;oelg@00Go0000on7>aOoQc/GohLk5o`000007on?BaP03o`000?oUe/Oo000000?olMRf
00Co0000ooCL]Oodg;Gom=be0_l00002oooLS`03o`000?o^_dCo000000Oooo]Z00?o0000onS?_?oX
ck`01?oXck`00ol0003ojm>mon_C_@02on_C_@03o`000?oad[;o000000ColmJb00?o0000ooGJ/Ol0
00000_okf:45o`000004oooFOol0003o0000ooG9E`;o00001oo[d;X00ol0003ol]>aoo;C/@02oo;C
/@07o`000?oce[7olmJaoo?F/Ol0003on=BVo`000004oo[HY@0;o`000?onf9Goo]REookHUOl0003o
o]^Bo`000?ooeH3o0000ookGN_l000000_oebeX2o`0002Cooo]Z00?o0000oookJ_oonfX0?OoonfX0
0?[ooo]Z0ol0000HoookJP;o00004_oonfX01?l0003olYXdo`000?l0000loookJP03o`000?oGcM3o
elg@00Coelg@00?o0000on7>aOl000001ooSd/H01?l0003oiMK7onGFaol00003oo7H]P05o`000?od
g;Gom=beooCL]Ol000000ooog8l00ol0003ok[m4o`000006oookJP03o`000?oRclKo000000Coj<nl
00?o0000on_C_Oo[dkd01?o[dkd00ol0003olmJboo?F/P03oo?F/P03o`000?oef[7o000000;onmRQ
00?o0000oocLWoolg9l00ol000000ooof8;o0000ooG9E`02o`0000Kojm2j00?o0000ongD^_l00000
0oobdk401ol0003olmJaoo?F/Ooce[7o0000ooSDY_l000000oojf:D00ol0003onmbSo`000002ookH
U@03o`000?onfi;o000000;o000000Coo]Mjo`000?oebe[omL]J0_l0000UoookJP03o`000?oonf[o
oo]Z03cooo]Z003goookJP?o00006ooonfX2o`0001?ooo]Z00Co0000oo:J=?l0003o0000>_oonfX0
0ol0003oelg@omO=d006omO=d003o`000?oSd/Kohm;600Kohm;600Oo0000onGFaooUe/OoiMK7o`00
0?oaf;Ko000000Com=be00Go0000oooLSooog8oo0000ookNR003o`0000Cooo]Z00Go0000on;?a_oR
clKoh/o6o`000003onS?_003o`000?o[dkgojm>m00Cojm>m00?o0000oo?F/_oce[800ooce[83ooGJ
/@03o`000?okf:7o000000?oo=bO00Ko0000oooHP_oof8;o0000ooG9Eol00006on_@^P04o`000?o]
e;[okMBjo`0000?ol]>a00?o0000oo?F/Ooce[400_oce[400ol0003on]RUoo[HY@02oo[HY@03o`00
0?okg:?o000000;oo]RE00?o0000ookKT_onfi800_l000001?oneg[o0000ooG;F_oebeX2o`0002Ko
oo]Z00?o0000oookJ_oonfX0>ooonfX00?Cooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z00Wooo]Z
00?o0000ooNVAOl000004_oonfX01?l0003olYXdo`000?l0000hoookJP;o00002OoGcM000ol0003o
hm;6on?BaP05on?BaP03o`000?oUe/OoiMK700;oiMK700?o0000oo7H]_l000000oodg;D2o`0000;o
omb?00?o0000ookNR?l000000_l00003oookJP03o`000?oRclKoh/o600;oh/o600Co0000onS?_?oX
ckco00001_o[dkd00ol0003ok=Nmo`000003oo?F/P04o`000?oef[7omMZaooGJ/@;o00001?olg9l0
0ol0003oomR2o`000002o`0000Oojm2j00Oo0000ongD^_o]e;[okMBjo`000?obdk7o000000GolmJa
00?o0000oo[HYOojf:D00_ojf:D01_l0003onmbSoo_LXol0003oo]REo`0000;oo]^B0_l000001?on
eg[o0000o`000?oebeX2o`0002Kooo]Z00?o0000oookJ_oonfX0>ooonfX00?7ooo]Z0ol0000Eoook
JP03o`000?oonf[ooo]Z00Wooo]Z00?o0000ooNVAOl000004ooonfX2o`000003on6B3ol0003ooo]Z
03Gooo]Z00?o0000ol?9h?l000002?oGcM000ol0003ofM3Ao`000005on?BaP03o`000?oUe/OoiMK7
00CoiMK700?o0000ooCL]Oodg;D00_odg;D01_l0003omn6co`000?oog8oo0000ookNR0?o00000_oo
nfX00ol0003oh/o6on;?aP04on;?aP03o`000?oXckco000000Gojm>m00Co0000oncG_Oo/ekgo0000
0ooce[800ol0003omMZaooGJ/@02ooGJ/@04o`000?olg9ooo=bOoocLW`;o000000CoomR2o`000?ol
fG_o00001_o[d;X00ol0003okMBjongD^P02ongD^P03o`000?obdk7o000000ColmJa00?o0000ooGJ
/?l000000_ojf:D01?l0003onmbSoo_LXookg:<2o`0000?oo]^B0_l000001_oneg[o0000o`000?l0
003oklUAo`0002Oooo]Z00?o0000oookJ_oonfX0>_oonfX00>kooo]Z0ol0000HoookJP;o00002_oo
nfX01?l0003omjI5ooNVAOl0000CoookJP03o`000?oQTPoo000003Cooo]Z0_l00003ol?9h003o`00
0?oGcM3oelg@00Coelg@00Go0000omW@dOoId=7ofM3Ao`000003on?BaP03o`000?oUe/OoiMK700Go
iMK700Go0000ooCL]Oodg;Gom=beo`000002ooOQ/`03o`000?oog8oo000000;oo]j80_l00002oook
JP03o`000?oRclKoh/o600Goh/o600?o0000on_C_Oo[dkd01?o[dkd01ol0003ok=NmoncG_Oo/ekgo
0000oo?F/_l000001Ooef[401_l0003oo=bOoocLWoolg9oo0000oogOV`?o000000?oim71o`000?o[
d;X01?o[d;X00ol0003okMBjongD^P03ongD^P03o`000?oce[7olmJa00?olmJa00?o0000ooGJ/?l0
00000_ojf:D00ol0003onmbSoo_LX`02oo_LX`04o`000?onfi;oo]^BookKTP;o000000Koo]Mjo`00
0?l0003o0000ono9DOl0000XoookJP03o`000?oonf[ooo]Z03Wooo]Z003/oookJP;o00006ooonfX0
0ol0003onJa>o`000009oookJP04o`000?ogYTGomjI5o`0001?ooo]Z00?o0000on6B3ol00000<ooo
nfX00ol0003o`lWPol?9h004ol?9h003o`000?oGcM3oelg@00;oelg@00?o0000omW@dOoId=400_oI
d=401Ol0003ohm;6on?Ba_oSd/Ko000000KoiMK700?o0000onOJaol000000_odg;D01_l0003omn6c
ooOQ/ol0003oomb?o`0000;oo]j80_l000000ooonf[o0000on;?aP07on;?aP03o`000?o[dkgojm>m
00?ojm>m00?o0000oncG_Oo/ekd00_o/ekd00ol0003olmJbo`000004ooGJ/@03o`000?oggk3o0000
00;oo=bO0_omgi/3o`0000;oim7100Go0000on_@^_o[d;[ojm2jo`000006ongD^P03o`000?oce[7o
lmJa00;olmJa00Oo0000ooGJ/?oef[3omMZ`o`000?ojf:Go000000ConmbS00Go0000ookKT_onfi;o
0000ookNS`02o`0000;onmMd00?o0000ono9DOl00000:?oonfX00ol0003ooo]ZoookJP0ioookJP00
jOoonfX3o`0001kooo]Z0_l00009oookJP03o`000?ogYTGomjI500;o00004ooonfX2o`0003;ooo]Z
00?o0000ol?9h?o3bN001Oo3bN001Ol0003oelg@omO=d?oGcM3o000000KofM3A00?o0000on?Ba_l0
00001_oUe/L01?l0003oim[7onOJaol00002ooCL]@05o`000?oghK?omn6cooOQ/ol000000oongXP3
o`0000Soh/o600?o0000on?Ba_l000000oo[dkd00ol0003ok=NmoncG_@04oncG_@03o`000?oef[7o
mMZa00?omMZa00Go0000ooOO/?l0003oo=bOo`000002oogOV`;o00000ooWdL401?l0003ojm2jon_@
^_l00006ongD^P03o`000?o_ek[o000000?olmJa00Co0000ooGJ/?oef[3omMZ`0_l00004oo_LX`06
o`000?olgj;o0000ookKT_l0003oo]j?0_l00002oo_GM003o`000?o_bE7o000002Wooo]Z00?o0000
oookJ_oonfX0>?oonfX00>Kooo]Z0ol0000QoookJP03o`000?oi[4ko000000Wooo]Z00Co0000ooNV
AOl0003o00004ooonfX00ol005oo0000o`00000_oookJP;o00002Oo3bN000ol0003oelg@o`000008
omW@d@03o`000?oUe/OoiMK700GoiMK700Ko0000onOJaooWf/Oo0000ooCL]Ol00004ooOQ/`03o`00
0?ongXSoo]j800?o00002?oRclH01Ol0003ohm;6on?Ba_oSd/Ko000000;ojm>m00?o0000oncG_Oo/
ekd01?o/ekd00ol0003omMZaooGJ/@02ooGJ/@06o`000?oggk3ommn`o`000?olg9oo00000_omgi/0
0ol0003oim71onOA`@03onOA`@03o`000?o[d;[o000000KokMBj00?o0000onoG^_l000000ooce[40
0ol0003omMZ`ooGJ/002ooGJ/003o`000?okg:?onmbS00;onmbS00Go0000oocOX_l0003oo]^Bo`00
0002ookNS`06o`000?okegConmMdo`000?o_bE7o0000:_oonfX00ol0003ooo]ZoookJP0goookJP00
hooonfX3o`0002Cooo]Z00Co0000ooV/C_oi[4ko00002?oonfX2o`000003ooNVAOl0003o000001?o
oo]Z0_l0000^oookJP03o`000?o3bN3o`lWP00Wo`lWP0_l00008omW@d@;o00001_oUe/L00ol0003o
im[7onOJa`02onOJa`;o00001?oghK<00ol0003oo]j8ookNR002o`0000Soh/o600?o0000on?Ba_oS
d/H00_oSd/H00ol0003ojm>mo`000006oncG_@03o`000?o^fkko000000;omMZa00?o0000ooOO/?og
gk000_oggk001Ol0003ooMnKoogOVoomgi_o000000Koim7100?o0000ongD^_o]e;X01?o]e;X01ol0
003okmNjonoG^_o_ek[o0000oo?F/Ol000001Ooef[001Ol0003onmbSoo_LXookg:?o000000;oo=nR
00?o0000ookKT_l000000_ongXl00ol0003onmMdoo_GM003o`0002[ooo]Z00?o0000oookJ_oonfX0
=ooonfX00>3ooo]Z0ol0000WoookJP04o`000?oi[4konJa>o`0000Sooo]Z00?o0000omml0_l00000
0_l0000CoookJP;o0000;?oonfX2o`0000[o`lWP0_l000000oo5cN7o0000omW@d@06omW@d@04o`00
0?oKe=7ofmCAo`0000CoiMK700?o0000onOJaooWf/L00ooWf/L00ol0003omn6cooOQ/`02ooOQ/`;o
00000_ongXP2o`0000Ooh/o600?o0000on?Ba_oSd/H01?oSd/H00ol0003ok=NmoncG_@04oncG_@04
o`000?o^fkkok]^no`0000;omMZa00?o0000ooOO/?oggk000_oggk001?l0003ooMnKoogOVol00007
onOA`@03o`000?o]e;[okMBj00CokMBj00Oo0000onoG^_o_ek[okmNjo`000?oce[7o000000ComMZ`
00?o0000ooOM/?l000000_okg:<01Ol0003oo=nRoocOX_olgj;o000000?oo]j?00?o0000oo_GM?l0
00000ol0000[oookJP03o`000?oonf[ooo]Z03Kooo]Z003MoookJP?o0000:_oonfX01?l0003onJa>
ooV/C_l00009oookJP05o`000?oOO0;o0000oo:Y=_l000004ooonfX3o`0002Sooo]Z0_l000000onl
an?o0000ol?9h008ol?9h003o`000?o5cN7oaLgQ00;oaLgQ00?o0000omW@dOoId=400ooId=401Ol0
003ofmCAom_DdOoKe=7o000000?oiMK700?o0000onOJaooWf/L01?oWf/L00ol0003omn6cooOQ/`02
ooOQ/`;o000000?oo]j8o`000?oDcm<00_l00006on;?aP03o`000?oSd/Kohm;600Cohm;600?o0000
oncG_Oo/ekd01?o/ekd01_l0003ok]^nonkK__l0003omMZao`0000Gommn`00Co0000oogOVol0003o
00001_oWdL400ol0003oj=C1o`000004ongD^P03o`000?o_ek[okmNj00?okmNj00?o0000ooGJ/?oe
f[000ooef[000ol0003ommf`o`000002oo_LX`05o`000?olgj;oo=nRoocOX_l000000_ongXl2o`00
0003oo_GM?l0003o000000;o0000;?oonfX00ol0003ooo]ZoookJP0eoookJP00fooonfX2o`0002go
oo]Z0_l000000ooi[4ko0000oookJP08oookJP03o`000?oonf[o000000;o00004ooonfX2o`000003
o`0W[_l0003ooo]Z02Gooo]Z00?o0000okc7honlan<00_nlan<00ol0003o`lWPol?9h004ol?9h0;o
00001_o5cN401Ol0003ofM3AomW@dOoId=7o000000GofmCA00Co0000onGFaooUe/Oo00001OoWf/L0
0ol0003ojMk7o`000002ooOQ/`04o`000?ohiK3on>F`o`0000?oe<oC0_l00004on;?aP03o`000?oS
d/Kohm;600Cohm;600?o0000onGFaol000001?o/ekd00ol0003ok]^nonkK_P02onkK_P;o00001?og
gk03o`0000;ohm7500?o0000onOA`OoWdL400_oWdL401Ol0003oj=C1onSD`OoXe<7o000000?okMBj
00?o0000onoG^_o_ekX00oo_ekX00ol0003omMZ`ooGJ/002ooGJ/006o`000?oggK3ommf`o`000?ok
g:?o00001?olgj800ol0003oo]j?ookNS`02o`000003oo_GM?l0003o000000;o0000;?oonfX00ol0
003ooo]ZoookJP0eoookJP00f?oonfX3o`0002oooo]Z00?o0000onfC9?l000000_l00008oookJP03
o`000?oonf[o000000;o00004ooonfX3o`000003o`0W[_l0003ooo]Z02;ooo]Z0_l00006okc7h`04
o`000?o3bN3o`lWPol?9h0;o00002Oo5cN400ol0003ofM3Ao`000006om_Dd@03o`000?oUe/Oo0000
00Goim[700Co0000onWNaooYg/Oo00000_oghK<00ol0003on>F`o`000005omC?d`05o`000?oRclKo
h/o6on;?a_l000001_oSd/H01?l0003oiMK7onGFaol00003oncG_@03o`000?o^fkkok]^n00?ok]^n
00?o0000ooOO/?oggk000ooggk02o`0000Cohm7500Go0000onOA`OoWdL7oim71o`000003onSD`@04
o`000?o]e;[okMBjo`0000GokmNj00?o0000oo3K^_l000000ooef[001?l0003ommf`ooOM/?oggK02
o`0000?oo=nR0_l00002ookNS`Go000000?oiLE6o`000?oonfX0;?oonfX00ol0003ooo]ZoookJP0d
oookJP00eOoonfX3o`0003?ooo]Z1?l00009oookJP04o`000?oonf[o0000o`0001?ooo]Z00Go000W
o`0AW_l0003o0000o`0W[P04o`0001_ooo]Z1?l00009okc7h`03o`000?o3bN3o000000_oaLgQ0_l0
0008om_Dd@03o`000?oWf/Ooim[700Coim[700So0000onWNaooYg/Oo0000ooOQ/ol0003on>F`o`00
00Ooe<oC00?o0000on;?a_l000001ooSd/H01Ol0003oiMK7onGFaooUe/Oo000000;ok=Nm00?o0000
onkK__o^fkh00oo^fkh00ol0003ommn`ooOO/002ooOO/003o`000?oihjoo000000Gohm7500?o0000
onOA`Ol000001OoXe<400ol0003okMBjo`000005onoG^P03o`000?o`fk[o000000?omMZ`00Go0000
ooOM/?oggK3ommf`o`000004oocOXP;o000000?oo]j?o`000?omh8X00_l000001?ogefgo0000onG5
A_l0000^oookJP03o`000?oonf[ooo]Z03?ooo]Z003BoookJP?o0000=_oonfX01?l0003okI<To`00
0?l00009oookJP03oka?0?l0003o000000;o00004ooonfX00ol04Iko0000o`0=V`02o`0000?oCXk/
1?l0000AoookJPKo00000onI^Nh00ol0003o_<OSokc7h`08okc7h`03o`000?o5cN7oaLgQ00WoaLgQ
00Go0000olSAhOo8dN7ob=7Qo`000005om_Dd@;o00001OoWf/L00ol0003ojMk7onWNa`02onWNa`?o
00002?oDcm<2o`0000Oohm;600?o0000onGFaooUe/L00_oUe/L00ol0003ok=Nmo`000005onkK_P03
o`000?o`gkko000000;ommn`00Go0000ooWS[ol0003og]7;o`000005on?Aa@03o`000?oXe<7oj=C1
00Goj=C100?o0000onoG^_o_ekX00oo_ekX01ol0003ol=^joo3K^_o`fk[o0000ooGJ/?l000001?og
gK001Ol0003oo=nRoocOX_olgj;o000000;oo>:P0_l000001oomh8[o0000o`000?ogefgo0000onG5
A_l00000;_oonfX00ol0003ooo]ZoookJP0coookJP00cooonfX3o`0003Wooo]Z00Co0000onfC9?l0
003o00002_oonfX4o`0001?ooo]Z00Co0000o`0AW_l0003o00fK0_l00003odj>k003o`000?mBT^ko
DY;^00Co00002OoonfX4o`0000[oVKW^00?o0000okc7honlan<01?nlan<2o`000003okg8hol0003o
aLgQ00SoaLgQ0_l00005olSAh@05o`000?oKe=7ofmCAom_DdOl000000_oMem801Ol0003oim[7onOJ
aooWf/Oo000000GojMk70_l00008omC?d`03o`000?oFdMCo000000Kohm;600?o0000onGFaooUe/L0
1?oUe/L00ol0003ok]^nonkK_P04onkK_P03o`000?o`gkko000000;ommn`0_l00003omkAb`03o`00
0?oSdLGohm7500;ohm7500?o0000onSD`OoXe<401OoXe<400ol0003okmNjonoG^P02onoG^P03o`00
0?o`fk[ol=^j00;ol=^j00?o0000ooGJ/?l000000ooggK000ol0003on>6_o`000002oocOXP03o`00
0?olhZ3oo>:P00;o000000OooN2:o`000?l0003ommM]o`000?oUaDKo000002oooo]Z00?o0000oook
J_oonfX0<_oonfX00<gooo]Z0_l0000loookJP04o`000?o]TbCo0000o`0000_ooo]Z0ol0000Coook
JP;o016N00Go02Nbo`000?l0003o03Fko`000003odj>k003o`000?mBT^koDY;^00?oDY;^1?l00002
oookJP?o000000?oVKW^o`000?nI^Nh03?nI^Nh00ol0003o_<OSokc7h`02okc7h`03o`000?nmb>?o
_LSS00;o_LSS00?o0000olG=hOo5cN401?o5cN42o`0000Sob=7Q00?o0000om_DdOl000000ooMem80
1?l0003oim[7onOJaol00006onWNa`03o`000?oDcm?oe<oC00Koe<oC00Go0000omKAe?oFdMCoe]7D
o`000004on?BaP03o`000?oUe/OoiMK700GoiMK700?o0000onkK__o^fkh00oo^fkh01Ol0003ol=nn
oo3O__l0003ommn`00;o00001?oNdL/01ol0003ohm75on?AaOoSdLGo0000onGDa_l000001OoXe<40
0ol0003oj]O2o`000003onoG^P03o`000?o`fk[ol=^j00?ol=^j00?o0000ooOM/?oggK000_oggK00
0ol0003on>6_o`000002oocOXP04o`000?olhZ3oo>:Po`0000;ooN2:0_l000001?ogefgo0000o`00
0?l0000`oookJP03o`000?oonf[ooo]Z037ooo]Z003:oookJP?o0000?_oonfX2o`000003onfC9?l0
003ooo]Z00[ooo]Z00?o_4l0o`000?l000004ooonfX01?l0003o016No`000?l09k82o`000003o`0e
^ol0003oCXk/00;oCXk/00?o0000oe:Bk_mBT^h01_mBT^h2o`0000GoVKW^00?o0000oiVik_nI^Nh0
2onI^Nh01?l0003o_<OSo`000?l00005okg8h`03o`000?o5cN7oaLgQ00?oaLgQ00?o0000olSAhOo8
dN402?o8dN42o`0000CogMOB00Co0000onOJaooWf/Oo00001OoYg/L00ol0003oe<oComC?d`06omC?
d`03o`000?oFdMCoe]7D00?oe]7D00Go0000on?Ba_oSd/Kohm;6o`000006onGFa`03o`000?oWf/So
000000?ok]^n00?o0000oo3O__o`gkh00_o`gkh3o`0000Gog]7;00?o0000on?AaOl000000ooUe<H0
1Ol0003oj=C1onSD`OoXe<7o000000?oj]O200?o0000onoG^_l000001_o`fkX01Ol0003ommf`ooOM
/?oggK3o000000;on>6_00?o0000oocOX_l000000oolhZ000ol0003ooN2:oogPRP02o`000004ooOG
KOl0003o0000o`00033ooo]Z00?o0000oookJ_oonfX0<OoonfX00<Oooo]Z0ol00012oookJPCo0000
2ooonfX2o`0001?ooo]Z00So0000o`0AW_l04Iko0000o`0W/_l03I_o0000o`0e^`Go00002?mBT^h0
0ol0003oVKW^oiVikP04oiVikP03o`000?nI^NkoVKW^00WoVKW^0ol00008okg8h`03o`000?o5cN7o
aLgQ00;o00002_o8dN400ol0003oc=KQo`000005omgGdP;o00001OoYg/L00ol0003oe<oComC?d`06
omC?d`03o`000?oFdMCoe]7D00Goe]7D00?o0000on?Ba_l000001_oUe/L01?l0003oim[8onOJb?l0
0003onkK_P03o`000?o`gkkol=nn00;ol=nn0_l00007omkAb`03o`000?oUe<KoiMC600?oiMC600?o
0000onSD`Ol000001?oZel800ol0003okmNjo`000005oo3K^P03o`000?obg[_o000000;ommf`00Co
0000ooSQ[oohhJoon>6_0_l00002oocRX0;o00000_omh8X01?l0003onn65o`000?oaeVD2o`00037o
oo]Z00?o0000oookJ_oonfX0<?oonfX00<Cooo]Z0ol00015oookJPCo00002ooonfX00onlC`3o0000
oookJP0AoookJP?o000000Oo016No`000?l09k;o02Nbo`000?l0=K_o000000?oGY3Y0_l000000omB
T^ko0000oe:BkP05oe:BkP03o`000?nI^NkoVKW^00?oVKW^00?o0000oiVik_nI^Nh01OnI^Nh4o`00
00;oV[O/00?o0000okg8honmb><01_nmb><00ol0003oaLgQo`00000;olSAh@05o`000?o<e^7oc=KQ
olcFhOl000001?oMem800ol0003ojMk7onWNa`03onWNa`03o`000?oDcm?oe<oC00Koe<oC00?o0000
omKAe?oFdM@01ooFdM@00ol0003oiMK7onGFa`05onGFa`07o`000?oWf/Soim[8onOJb?l0003ok]^n
o`000005oo3O_P03o`000?oNdL_og]7;00Kog]7;00?o0000onGDa_oUe<H01?oUe<H00ol0003oj]O2
on[G`P04on[G`P03o`000?o`fk[ol=^j00?ol=^j00Co0000oo;N^oobg[_o00000_oggK001Ol0003o
n>6_ooSQ[oohhJoo000000?oo>:P0_l000000oomh8[o0000oo_QQ@02o`000003oo7FIOl0003o0000
03;ooo]Z00?o0000oookJ_oonfX0;ooonfX00<7ooo]Z0ol00018oookJP04o`000?oNN`7o0000o`00
00_ooo]Z0_l0000BoookJP03o`000?l004So000000;o00000ol09k800ol0003o03Fko`000003oej@
j@03o`000?mLTN[oG97Z00Co00000omBT^h00ol0003oVKW^oiVikP03oiVikP03o`000?nI^NkoVKW^
00Co00001onJ]n`00ol0003o_LSSokg8h`06okg8h`03o`000?o8dN7ob=7Q00Sob=7Q0_l00005olcF
h@05o`000?oMem;ogMOBomgGd_l000000ooYg/L2o`0000Soe<oC00?o0000omKAe?oFdM@01ooFdM@2
o`0000KoiMK700?o0000onOJb?oWf/P00_oWf/P00ol0003ok]^no`000004oo3O_P;o00001ooNdL/0
0ol0003oh=C<o`000005onGDaP03o`000?oZel;oj]O200Coj]O200?o0000oo3K^_o`fkX00oo`fkX0
1_l0003ol]jkoo;N^ol0003ommf`o`0000Con>6_00Ko0000oocRX?olhZ3oo>:Po`000?oliId2o`00
0004oo_QQOl0003o0000oo7FI@;o0000<_oonfX00ol0003ooo]ZoookJP0_oookJP00__oonfX3o`00
04cooo]Z00?o0000omik0Ol000002ooonfX3o`00017ooo]Z00Ko0000o`00B?l0003o01^Ro`0AW_l0
0003o`0W/P?o00000omNT>T00ol0003oG97ZoebAjP03oebAjPGo00000onI^Nh4o`0000coV[O/00?o
0000okg8honmb><00onmb><00ol0003o_/[So`000009olSAh@03o`000?o<e^7oc=KQ00Koc=KQ00Wo
0000omgGd_l0003ogm_Ao`000?oYg/Oo0000olo=f?l000001ooDcm<00ol0003oe]7DomKAe007omKA
e004o`000?oGe=GoemCEo`0000CoiMK700?o0000onOJb?oWf/P01?oWf/P00ol0003ol=nnoo3O_P03
oo3O_P03o`000?oNdL_og]7;00Gog]7;00Go0000on3Dc?oPe<coh=C<o`000003onGDaP03o`000?oW
f<Ko000000Coj]O200?o0000oncK`_l000000oo`fkX00ol0003ol]jkoo;N^`02oo;N^`;o00000ooh
hJl01Ol0003onNF^o`000?olhZ3o000000;oo>FM0_l000001?okhHGo0000o`000?oaeVD2o`0003?o
oo]Z00?o0000oookJ_oonfX0;_oonfX00;cooo]Z0_l0001?oookJP03o`000?oNN`7o000000[ooo]Z
00Co0000o`00@ol0003o00004OoonfX01Ol0003o0018o`000?l0003o01^R00;o00000_l09k82o`1>
c0;o00000_mNT>T00ol0003oG97ZoebAjP07oebAjPCo00000_nM]n/00ol0003oV[O/oiZgk00<oiZg
k005o`000?nmb>?o_LSSokg8hol000000onnb^<00ol0003ob=7QolSAh@05olSAh@03o`000?o<e^7o
c=KQ00Ooc=KQ0_l00002omoKd@;o00000oo?cMP00ol0003oe<oComC?d`03omC?d`03o`000?oFdMCo
e]7D00Ooe]7D00Co0000omODeOoGe=GoemCE0_l00003onGFa`03o`000?oWf/Soim[800Coim[800?o
0000oo3O__o`gkh00_o`gkh00ol0003og]7;omkAb`05omkAb`03o`000?oPe<coh=C<00;oh=C<00Co
0000onGDa_oUe<Ko00000ooWf<H01?l0003oj]O2on[G`_l00002oncK`P04o`000?o`fk[ol=^jo`00
00Gol]jk00?o0000ooSQ[oohhJl00_ohhJl01Ol0003onNF^o`000?olhZ3o000000;oo>FM00?o0000
oo_QQOokhHD01Ol0000doookJP03o`000?oonf[ooo]Z02gooo]Z002ioookJP?o0000D?oonfX2o`00
00;ogW/100?o0000oookJ_oonfX01ooonfX00ol0003o0013o`000002o`00013ooo]Z00Go0000o`00
B?l0003o0000o`0KXP02ocaIaP03o`000?l09k;o02Nb00;o04k<00Go0000oej@jOmNT>WoGY3Yo`00
0009oebAjP03o`000?nM]n_oWKO[00?oWKO[00?o0000oiZgk?nJ]n`03?nJ]n`00ol0003o_LSSo`00
0005okk:h`03o`000?o8dN7ob=7Q00;ob=7Q0_l00009olcFh@06o`000?o@fn7od=_Qom3KhOoOfm7o
00001Oo?cMP01Ol0003oe<oComC?dooDcm?o000000Woe]7D00?o0000omODeOoGe=D00ooGe=D2o`00
0003onGFaol0003oim[800Goim[800?o0000onWNb?l000000_o`gkh00ol0003og]7;omkAb`05omkA
b`03o`000?oPe<coh=C<00Coh=C<00?o0000onGDa_l000001?oWf<H00ol0003oj]O2o`000002oncK
`P04o`000?o`fk[ol=^jo`0000Gol]jk00Go0000ooSQ[oohhJoon>6_o`000002ooWU[P03o`000?ol
hZ3o000000;oo>FM00?o0000oo_QQOokhHD01Ol0000doookJP03o`000?oonf[ooo]Z02gooo]Z002f
oookJP?o0000D_oonfX01_l0003o1@1[o`000?l0003ogW/1o`0000Wooo]Z00?o0000o`00@ol00000
0_l0000?oookJP;o000000?o0018o`00P_l007000_l00002ocaIaP03o`000?l09k;o000000;o04k<
00Co0000oej@jOmNT>Wo00002_mLTNX00ol0003oWKO[oifgj`02oifgj`03o`000?nJ]ncoV[O/00_o
V[O/0ol00006okk:h`05o`000?o8dN7ob=7QolSAhOl000002Oo<e^42o`0000Cod=_Q00?o0000olo=
f?o?cMP01Oo?cMP00ol0003oe<oCo`000009omKAe003o`000?oGe=GoemCE00CoemCE00?o0000omkG
d?l000001_oWf/P01Ol0003ojMk8onWNb?l0003ol=nn00;o00001ooNdL/00ol0003oh=C<on3Dc005
on3Dc003o`000?oWf<KoimS600CoimS600?o0000oncK`_o/fl800_o/fl82o`0000Gol]jk00?o0000
oo?Q^_l000000_ohhJl01Ol0003onNF^ooWU[_oiiJko000000?oo>FM2?l0000eoookJP03o`000?oo
nf[ooo]Z02cooo]Z002coookJP?o0000EOoonfX00ol0003o1@1[o`D0J`03o`0000Sooo]Z0_l00000
0ooonf[o001[o`000002o`0000kooo]Z00?o0000obTEPol004P01?l00003ocaIaP03o`0W/_l0003o
04k<00;o04k<1?l000000omLTN[o0000oebAjP07oebAjP05o`000?nM]n_oWKO[oifgjol000002?nJ
]n`5o`0000;oW[OZ00?o0000okk:honnb^<01Onnb^<00ol0003ob=7Qo`000009olcFh@03o`000?o@
fn7od=_Q00;od=_Q0_l00009olo=f003o`000?oFdMCoe]7D00Ooe]7D00?o0000omODeOoGe=D01_oG
e=D00ol0003ohM_@o`000004onOJb004o`000?oYg/SojMk8onWNb0;o00000_oJd=000ol0003og]7;
omkAb`03omkAb`03o`000?oPe<coh=C<00Koh=C<00?o0000onOHa_oWf<H01?oWf<H2o`0000?ok=_2
00?o0000oo;N^oobg[/01?obg[/00ol0003oln6jo`000002ooSQ[`06o`000?oiiJkonNF^ooWU[_l0
003oo>FM0ol00002oo_QQ@Go0000=_oonfX00ol0003ooo]ZoookJP0[oookJP00/?oonfX3o`0005Oo
oo]Z00Co0000o`D0Jol506_o1@1[1?l00007oookJP;o000000Cooo]Zo`00Jol05j3o01NP0_l0000<
oookJP03o`000?lY5H?o:AF300;o000000?o0022o`000?l000001?llFLH01Ol09k;o0000o`1>c?l0
C/co000000;oHhgU00?o0000og:GiombUnL01Ol00004oebAjP05o`000?nM]n_oWKO[oifgjol00000
0_nJ]n`5o`0000SoW[OZ00?o0000okk:honnb^<01Onnb^<00ol0003oc=KQolcFh@07olcFh@04o`00
0?o@fn7od=_Qom3Kh@;o00000_nobN800ol0003oclgHolo=f005olo=f0;o00002?oFdM@00ol0003o
emCEomODe@06omODe@;o00000_oQfm001Ol0003oim[8onOJb?oWf/So000000?ojMk800?o0000om[@
d?oJd=000_oJd=001Ol0003og]7;omkAbooNdL_o000000Soh=C<00?o0000on7GcOl000001?oWf<H0
1?l0003ojM_7onWKaol00002oncK`P03o`000?obg[_ol]jk00?ol]jk00Ko0000oo?Q^_ochK[o0000
ooSQ[ol00003ooWU[P?o000000Soo>FMo`000?l0003onn65o`000?oghWoo0000onSBF`;o0000=_oo
nfX00ol0003ooo]ZoookJP0[oookJP00[OoonfX3o`0005[ooo]Z00Co0000o`D0Jol506_o1@1[0_l0
00000ooAI`3o0000oookJP06oookJP06o`000?l006go0000o`00Jol0003o01NP0ol0000;oookJP03
o`000?lY5H?o:AF300;o000000?o0022o`00L?l000001OllFLH2o`0000;o04k<00?o0000of>=iOl0
00001ombUnL6o`000003oifgjol0003o000000;o00003_nN]nX01?l0003o_/[Sokk:honnb^<2o`00
0003ol7<hol0003oc=KQ00Koc=KQ0_l00003om3Kh@03o`000?nobN;o_lWR00?o_lWR00?o0000olo=
f?o?cMP00oo?cMP01?l0003od=3Iom3@fOl00007omKAe0SoemCE00Co0000omSGe_oHemKo00000_oQ
fm000ol0003oim[8o`000003onWNb003o`000?oJd=3of]3@00Cof]3@00?o0000omkAbol000002?oP
e<`01Ol0003ohMO=on7GcOoQelgo000000;oimS600?o0000onWKaooYflL00_oYflL2o`000003ongN
`_l0003ol]jk00;ol]jk00?o0000oo?Q^_ochKX00_ochKX7o`0000;oo>FM00Go0000oo_XV_l0003o
0000ooORO`04o`0003Oooo]Z00?o0000oookJ_oonfX0:_oonfX00:_ooo]Z0_l0001LoookJP03o`00
0?l506_o1@1[00;o1@1[00Co0000o`00IOl0003o00001_oonfX01?l0003o001]o`00KOl00002o`00
J`;o01NP0ol0000:oookJP05o`000?lY5H?o:AF3obTEPol000000_l008800ol0003o?5W6ocaIaP03
ocaIaP;o5EK?00?o0000o`1>c?l0C/`00_l0000<og:Gi`;o000000?oWKKZo`000?nN]nX04?nN]nX0
0ol0003o_/[So`000004ol7<h`03o`000?o<e^7oc=KQ00?oc=KQ00Co0000om3KhOo@fn7od=_Q0_l0
0007oko9hP05o`000?o?cMSoclgHolo=f?l000001?o@d=T00ol0003oe]7DomKAe003omKAe0SoemCE
00Go0000omSGe_oHemKof=OFo`000003on7Kd0;o00000_oYg/P00ol0003of]3@om[@d006om[@d003
o`000?oPe<coh=C<00Koh=C<00?o0000on7GcOoQeld00_oQeld00ol0003oimS6o`000006onWKa`?o
00000oobg[/01?l0003oln6joo?Q^_ochKX3o`0000?onNF^0_l000001?oliIgo0000oo_XV_okj9X2
o`000003ooOROol0003o000000;o0000>?oonfX00ol0003ooo]ZoookJP0YoookJP00Z?oonfX3o`00
01;ooo]Z0_l00019oookJP03o`000?l506_o1@1[00?o1@1[00Go0000o`00IOl0003odFL0o`000004
oookJP;o00000_l006d00ol0003o001[o`00J`03o`0GX0Co00001ooonfX00ol0003o:AF3obTEP`02
obTEP`03o`000?l008;o002200?o00000ollFLH02?l0003o5EK?oaEFcol0003o04k<o`000?mSSNGo
00003?mbUnL2o`00017oW[OZ0ol00005ol7<h`04o`000?o<e^7oc=KQolcFh@;o00000_o@fn42o`00
00[o_lWR00?o0000olo=f?l000001Oo@d=T00ol0003oe]7DomKAe002omKAe0SoemCE00?o0000omSG
e_oHemH00_oHemH01?l0003ohM_@on7Kd?l00002on?Od0;o00002OoJd=000ol0003oh=C<on3Dc005
on3Dc003o`000?oQelgohMO=00CohMO=00?o0000onWKaooYflL01OoYflL01ol0003ojmo6o`000?l0
003ol]jko`000?ochKX00ol000000oochK[o0000ooWU[P02ooWU[P03o`000?oiijgonNN]00;o0000
0_okj9X00ol0003omn9oooORO`03o`0003Wooo]Z00?o0000oookJ_oonfX0:OoonfX00:Gooo]Z0ol0
000EoookJP03o`000?o][8Oo000004Sooo]Z00?o0000o`D0Jol506/00_l506/00ol0003o4PR1o`00
0003o`0000?ooo]Z00?o0000obhCOOl000000_l006d01?l0003o001[o`00Jol00002o`0GX005o`00
0?l008oo0000o`1Jdol000001_oonfX00ol0003o:AF3obTEP`02obTEP`04o`000?l008;o0022o`00
00;oEfO800Co0000ocaIa_llFLKo00001?lEE/l00ol0C/co0000o`00000=og:Gi`03o`000?nN]n[o
W[OZ00_oW[OZ1?l00002oj30k`03o`000?o1c>?o`LcS00?o`LcS00Co0000olcFhOo<e^7o00000oo@
fn400ol0003o_lWRoko9hP0;oko9hP03o`000?o@d=Wod=3I00God=3I00?o0000omKAe?oFdM@02?oG
e=D00ol0003of=OFomSGeP04omSGeP;o00000ooSgm02o`0000Sof]3@00?o0000om_CdOl000001OoP
e<`00ol0003ohMO=on7Gc@05on7Gc@03o`000?oYflOojM_700CojM_700Co0000on_Oa_o[glKojmo6
1?l00003oo?Q^P03o`000?odiKWo000000;onNF^00?o0000ooWW[Ooiijd00_l00002oo_XVP03o`00
0?oghWoo000000Co0000>OoonfX00ol0003ooo]ZoookJP0XoookJP00X_oonfX3o`0001Sooo]Z00Co
0000onf/Qoo][8Oo0000A_oonfX2o`0000?o1@1[00?o0000oa88POlB28400_l000001OnoD@3o0000
o`000?oonf[o000000;o;Q=m00Co0000o`00KOl006go00000_l006/00ol03ISo01NPo`0GX002o`00
0003o`00Sol0003o05[C00;o00001?oonfX02_l0003o:AF3obTEPolY5H?o0000oaPRW?l0003o0022
o`000?l08ZP2oeMWb004o`000?llFLKo?5W6o`0000Co5EK?00?o04k<o`000?mbUnL03?mbUnL2o`00
00OoW[OZ1Ol00007oj30k`03o`000?o1c>?o`LcS00?o`LcS0_l00002om3Kh@;o00003?nobN800ol0
003o`<cSo`000008om3@f@03o`000?oGe=GoemCE00KoemCE00?o0000omSGe_oHemH01OoHemH01Ol0
003ohmo@on?Od?oSgm3o000000;od/oF00?o0000om[@d?oJd=001?oJd=001?l0003ofm?Aom_CdOl0
0004on3Dc003o`000?oQelgohMO=00GohMO=00?o0000on;JcOl000001?oYflL00ol0003ojmo6on_O
aP04o`0000Coln6j00Co0000ooCU^OodiKWo00000_oiiJh01?l0003onNN]ooWW[Ol00002oo_XVP;o
000000?omn9oo`000?l000000_l000000ooonf[o0000oookJP0hoookJP03o`000?oonf[ooo]Z02Oo
oo]Z002OoookJP?o00006ooonfX01Ol0003okJb7onf/Qoo][8Oo000004?ooo]Z0_l000000old57_o
0000o`D0J`02o`D0J`03o`000?lB287o4PR100;o000000Go00jAo`000?l0003ooo]Zo`000002obhC
O@06o`000?l006go0000ocl^U?l0003o001[0_l000001_l05j3o0000o`0CX_l0003o002?o`0000;o
05[C00?o0000oookJ_oonfX00_l00003obTEP`06o`000?lH8Yco0000o`00P_l0003o02:X1?mGIlP0
0ollFLKo0000oaEFc`04oaEFc`Go00002_mbUnL2o`0000;oW[OZ1?l0000=oj30k`04o`000?o1c>?o
`LcSol7<h`;o000000?od=_Qo`000?l000003?nobN82o`0000?o`<cS00?o0000om3@fOo@d=T00oo@
d=T00ol0003odM;Jo`000007omODe@03o`000?oHemKof=OF00Kof=OF00Co0000on?Od?oSgm3o0000
1?oBcmH00ol0003of]3@om[@d002om[@d003o`000?oKdm7ofm?A00;ofm?A00Co0000on3Dc?oPe<co
00001ooQeld01?l0003oh][=on;JcOl00003onWKa`Co00000oo[glH2o`0000?oln6j00Ko0000ooCU
^OodiKWo0000ooWU[_l00003ooWW[@03o`000?okj9[onnRJ00;o000000Oomn9oo`000?l0003og/iA
o`000?oonf[o000003Wooo]Z00?o0000oookJ_oonfX09ooonfX009cooo]Z0ol0000CoookJP;o0000
2?oonfX00ol0003okJb7onf/Q`03onf/Q`03o`000?oonf[ooo]Z03kooo]Z0_l000001omb@XOo0000
oc@DNold57_o0000o`D0Jol000001?lB28400ol0003o00jAo`000003o`0000;o;Q=m00[o0000o`00
KOl0003o?bjDo`000?l006_o0000o`0=V?l05j3o00000_l04j800ol0003o002?o`000002o`1Jd`;o
000000Go91B4obTEPol0003o:AF3o`000003oaPRW003o`00P_l0003o02:X00GoEfO80_l00004oaEF
c`03o`000?mnVnCoOY_T00KoOY_T1?l00003og:Gi`?o00004_nP`>l01?l0003o`LcSo`000?o3c^<2
o`0000co_lWR0_l00006ol3<h`05o`000?o@d=Wod=3Iom3@fOl000000ooAd]X00ol0003oemCEomOD
e@03omODe@03o`000?oHemKof=OF00Kof=OF00Co0000om[Jeol0003o00001OoBcmH01Ol0003of]3@
om[@d?oJd=3o000000Gofm?A00?o0000on3Dc?l000001ooQeld00ol0003oh][=on;Jc@02on;Jc@Co
00001Oo[glH2o`000004oo7S_ol0003oln6jo`0000Com>Fi0_l00002ooWW[@;o00000_okj9X00ol0
003onNVFo`000004o`0000;ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0Voook
JP00V_oonfX2o`0001Kooo]Z00?o0000onj_S?l000001ooonfX00ol0003okJb7onf/Q`04onf/Q`;o
0000?OoonfX01Ol0003oLT:7og92Qomb@XOo000000;o=1Ak00?o0000o`D0Jol000001?lB28400ol0
003o00jAo`0>T@02o`000003odLSPOl0003o;Q=m00;o00000olo;Y@2o`000003o`0=V?l05j3o0000
00?o01>R0_l008l00ol0003o05[Co`1Jd`02o`000004ob@DQ?l0003o:AF3o`0000?o62:L0_l00002
o`0RZ0CoEfO80_llJMD00ol0003o5EK?oaEFc`02oaEFc`03o`000?mnVnCoOY_T00coOY_T0_l0000D
oj30k`04o`000?o3c^?o0000o`0000co_lWR00?o0000ol3<hoo0c><01oo0c><00ol0003od=3Io`00
0004om7BfP03o`000?oGe=GoemCE00;oemCE00?o0000omSGe_oHemH01_oHemH01?l0003of][Gom[J
eol00007om;?eP03o`000?oJd=3o000000Oofm?A00?o0000on7GcOoQeld01OoQeld01?l0003oh][=
on;JcOoRf/d3o`000003onWKaol0003ojmo600Cojmo600Go0000oncRaoo/h/Oo0000oo7S_`02o`00
00Com>Fi00Co0000ooWW[OoiijgonNN]0_l000001_okj9[o0000ooWYU_oijIKo0000oo;QN0?o0000
0ooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z002GoookJP?o00006?oo
nfX01?l0003okZn<onj_S?l00006oookJP03o`000?o][8OokJb700CokJb700Co0000omfLS?l0003o
0000>OoonfX2o`0000CoLT:700?o0000oc@DNold57/00_l00005oa88P@03o`000?l03Y7o00jA00;o
000000GoAb>1o`000?l^4ggo001]o`000003ocl^U0;o000000?o00fHo`000?l000000ol04j800ol0
003o002?o`000003o`000004o`1Hd_l0003o0000o`0000Go62:L00?o0000o`0RZ?l08ZP01?mGIlP0
0ol0003o?6WEocaYe@02o`0000;o5EK?00?o0000ogjKi?mnVn@03OmnVn@2o`0000koX<3_0ol00002
ojK4k`;o00003?nobN82o`0000_o`<cS00?o0000om7Bf_oAd]X01?oAd]X01?l0003oemCEomODeOl0
0008omSGeP04o`000?oJf]Oo0000o`0000Sod/oF0_l00008om_Cd@03o`000?oQelgohMO=00CohMO=
00?o0000on;JcOl000000_l00003on;Jc@03o`000?o[glKojmo600Cojmo600So0000oncRaoo/h/Oo
0000oo7S_ol0003olnNno`0000?om>Fi00Co0000ooWW[Ooiijgo00000_oijjX2o`0000;onNVF00?o
0000oo;QN?l000000_l00003oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX09Ooo
nfX009Cooo]Z0ol0000KoookJP05o`000?o^[hcokZn<onj_S?l000001OoonfX2o`0000GokJb700Go
0000omfLS?oMW8cogIb<o`00000foookJP;o00001_mb@XL01?l0003o=1Akoc@DNol00005oa88P@;o
00000_l03Y44o`000003obhCOOl0003o?bjD00Co?bjD00Co0000o`0=V?l03ISo00000ol04j82o`00
0003o`00SolTI]Wo96KI00;o00000_l0F=82o`0000Co62:L00?o=e?2o`000?l08ZP00omGIlP00ol0
003o?6WEocaYe@03ocaYe@04o`000?lEE/oo0000o`0000koOY_T00?o0000ofjMkOl000002OnP`>l4
o`0000;oY/C_0ol00002ojO1k003o`000?nobN;o_lWR00Oo_lWR0_l0000;ol3<h`03o`000?o1cnCo
000000KodM;J00?o0000omODeOl000002?oHemH01Ol0003of][Go`000?o>c][o000000Ood/oF00?o
0000om?Beol000001ooKdm400ol0003og=KAo`000004on7Gc@?o00001_oRf/d00ol0003ojmo6on_O
aP03on_OaP04o`000?o/h/Ook>;7oncRa`;o00000oocikh01?l0003om>Fio`000?l00002ooWW[@03
o`000?oijj[onN^Z00;o00000_oijIH01?l0003ol^5ho`000?l00005oookJP03o`000?oonf[ooo]Z
03Oooo]Z00?o0000oookJ_oonfX09?oonfX0097ooo]Z0ol0000MoookJP03o`000?o^[hcokZn<00?o
kZn<00?o0000oookJ_oonfX00_oonfX00ol0003ojk:Fo`000004onf/Q`03o`000?oMW8cogIb<00;o
gIb<0_l0000boookJP;o00002?mb@XL01?l0003o=1Ako`000?l00004oa88P@0;o`000?la;Ygo0000
o`000?l03Y7o0000o`04TOl0003oAb>1obhCOOl000001Olo;Y@00ol0003o00fHo`0=V002o`0000;o
01>R00Co0000o`0MZ_l008oo00000_lTI]T2o`0000?o05SB0_l00002oaPRW004o`000?lgDl;o0000
o`0RZ0;oEfO800?o0000ocaYeOllJMD01OllJMD00olEE/oo0000o`00000>ogjKi0;o00001_nP`>l3
o`0000?oY/C_0ol00005ojO1k003o`000?nobN;o_lWR00Ko_lWR00?o0000ol3<hoo0c><02Oo0c><2
o`0000?o`LoT00?o0000om7Bf_oAd]X01?oAd]X00ol0003of=OFomSGeP06omSGeP03o`000?oJf]Oo
000000?oc/kJ00?o0000om;?e_oBcmH00ooBcmH01Ol0003odm;Gom?BeooCd]Oo000000Gofm?A00Go
0000omcFdOoLe]7o0000on7Gc@04o`0000Ooh][=00?o0000onCMc_l000000oo[glH00ol0003ok>;7
oncRa`03oncRa`03o`000?ocikkolnNn00;olnNn0ol00002ooWW[@04o`000?oijj[onN^Zo`0000;o
nNVF1Ol00006oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX08ooonfX008kooo]Z
0ol0000PoookJP03o`000?o^[hcokZn<00CokZn<0_l00002oookJP04o`000?o[/YKojk:Fo`0000;o
kJb700?o0000omfLS?oMW8`01OoMW8`4o`0002gooo]Z00?o0000og92Qomb@XL02?mb@XL01Old57_o
0000odD/SOm5;8go000000?o4PR100?o0000oc4^WOla;Yd00ol000000ol008Oo00BAo`000002o`00
00Co?bjD00Co0000ob0UW?l0003o00fH0_ldB;T01ol0003o01>Ro`0CX_l0003o01fZo`00Sol00000
0olTI]T00ol0003o05SBo`1HdP02o`1HdP;o00000olgDl801?l0003oEfO8oeMWb?l00008ocaYe@;o
00003_mnVn@00ol0003oKYg]o`000002oj30k`?o00000onVa>l3o`0000SoYl7/0_l00005oko9hP;o
00002oo0c><00ol0003o`LoTol7?i004ol7?i007o`000?oAd][odM;Jom7Bf_l0003od]CKo`000007
omSGeP?o00001Oo>c]X01Ol0003od/oFom;?e_oBcmKo000000Godm;G00Go0000om_CdOoKdm7ofm?A
o`000002omcFd@?o00000_oQeld00ol0003oh][=on;Jc@05on;Jc@04o`000?oTgLkoi=g>o`0000;o
jmo600?o0000oncRaoo/h/L01?o/h/L00ol0003olnNnoo?W_P02oo?W_P03o`000?ocj[go000000Co
000000?onN^Zo`000?l000001_l00007oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oo
nfX08_oonfX008cooo]Z0_l0000CoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000onj_S?o^[h`0
1?o^[h`00ol0003ohJ:?o`000002o`0000?ojk:F00?o0000onf/Qol000001ooMW8`01?l0003od8n>
om2?S_o@Shh3o`0002Sooo]Z0_l0000:og92Q`;o00000om5;8d01?l0003o4PR1oa88POl00003oc4^
W@?o000000?o0027o`000?l019400_l00004ocl^U005o`000?lP9Ico0000o`0=V?l000000_ldB;T0
0ol0003o01>Ro`000002o`0MZP;o00000olTI]T2o`0000;o05SB00?o0000o`1Ke?l000000ol00000
0omGIlSo0000ocaYe@08ocaYe@03o`000?m9M=[o000001;o00000onVa>l3o`0000_oYl7/00?o0000
ojS1k?l000000_nobN82o`0000_o`<cS0_l00008ol7?i003o`000?oAd][o000000?od]CK00?o0000
omSGe_oHemH00ooHemH2o`0000Soc/kJ00?o0000om;?e_l000001ooCd]L00ol0003ofm?Ao`000003
o`0000;og=KA00?o0000on7GcOl000001ooRf/d01Ol0003oi=g>onCMc_oTgLko000000;ojmo600?o
0000oncRaoo/h/L00oo/h/L2o`0000?olnNn00Ko0000oo?Z_Oocj[go0000ooSZ/Ol00002ooS][@;o
000000?on>^Ho`000?odk9801?l00007oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oo
nfX08_oonfX008Wooo]Z0ol0000EoookJP;o00003_oonfX2o`0000GokZn<00Go0000on6RSol0003o
iZF;o`000004on^bUP;o00001ooMW8`00ol0003od8n>om2?SP02om2?SP03o`000?o>SHko000000;o
00008OoonfX4o`0000[oLT:70_l000000omjCi?o0000odD/S@02odD/S@04o`000?lB287o4PR1o`00
00?o<BjM00?o0000o`dETol000000_l008L01?l0003o00BAo`000?l00002ocl^U006o`000?lP9Ico
82FLob0UW?l03ISo00000oldB;T00ol04j;o0000o`0MZP02o`0MZP;o00000_lTI]T00ol0003o3EkF
o`000002o`1HdP;o00000omHUnl5o`0000Ko?6WE00?o0000odUdf_l000003_n9Wn801?l0003oNj;/
o`000?nVa>l3o`0000koYl7/00Go0000ojS1k?l0003o_lWRo`00000;ol3<h`;o00002oo1cn@00ol0
003od]CKom;Df`02om;Df`03o`000?oHemKof=OF00;of=OF0_l0000:olk>fP03o`000?oCd]Oodm;G
00Kodm;G0ol00006omcFd@03o`000?oRf/goh][=00Goh][=00?o0000onCMc_oTgLh00ooTgLh2o`00
00Gok>;700?o0000ongVaol000000_ocikh00ol0003olnZmoo?Z_@02oo?Z_@04o`000?ohkJgon>f]
ooS][@?o00000_odk984o`0000Sooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0Q
oookJP00Q_oonfX3o`0001Sooo]Z00?o0000onjcT_l000003OoonfX00ol0003oj[NNo`000004onj_
S004o`000?oQXXoo0000o`0000Kojk:F0_l00006omfLS003o`000?o@Shkod8n>00;od8n>00?o0000
olj=S_o>SHh00_o>SHh5o`0001Kooo]Z1_l00003oiiUSP03o`000?mb@XOoLT:700OoLT:700Go0000
ogY?TomjCi?oNTnCo`000004odD/S@;o00001?la;Yd00ol0003o3AFCo`000002o`00Q`Co00000_lo
;Y@01?l0003o82FLob0UW?lP9I`2o`000004o`<WZ_ldB;Wo=4RiocA8^@;o00000_l07JX2o`0000?o
96KI00Go0000o`eNe_l0003o0000o`1HdP02o`0000OoF9O_1Ol000001OllJMGo0000odUdf_m9M=[o
000000_oRIoR1_l0000AojO1k004o`000?nX`Nco0000o`0000_o`<cS00?o0000ol7?i?o1cn@02Oo1
cn@00ol0003o`m;Uo`000005om;Df`03o`000?oHemKof=OF00;o00002Oo>c]X00ol0003ocm7Ko`00
0005om?Be`?o000000?oeMGHo`000?oLe]401_oLe]400ol0003oh][=on;Jc@04on;Jc@03o`000?oT
gLkoi=g>00Coi=g>00?o0000oncRaoo/h/L01?o/h/L01_l0003okNK7ongVaol0003olnNno`0000Co
lnZm00Go0000ooS][OohkJgo0000ooO_ZP02o`0000;om>bB00Co0000onSNKol0003o00002OoonfX0
0ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z023ooo]Z0023oookJP?o00006_oonfX01Ol0
003ok[>BonjcT_o^/i;o000000cooo]Z00Co0000onZgW_oZ]iko00000_o^[h`01Ol0003ohJ:?on6R
SooQXXoo000000Kojk:F00Co0000omfSUol0003o00000ooMW8`00ol0003od8n>om2?SP03om2?SP03
o`000?o>SHkocXf>00;ocXf>00?o0000okmoSOnoOhd00_noOhd7o`0000[ooo]Z1Ol00009oiiUSP03
o`000?mb@XOoLT:700GoLT:70_l00004ogY?T`03o`000?m5;8goABb=00;oABb=00?o0000oc4^WOla
;Yd01?la;Yd01Ol0003o6RBMo`000?l008Oo000000;o02Zd00?o0000ocl^U?l000001OlP9I`00ol0
003o0bNZocA8^@02ocA8^@;o43bj00?o0000o`0MZ_l07JX00ol000000olTI]Wo0000o`eNeP02o`eN
eP;o000000?o05_Do`000?mHUnl01omHUnl00ol0003oDIC_oe6Dk`03o`0000;oBGCJ00?o0000ohVO
h_l000002?l00004ohNbl@;o00004OnW`N`2o`0000;oZL?/00?o0000ol3<hoo0c><01_o0c><2o`00
00[o`LoT0_l00003ol?Bi@03o`000?oBe=_od]CK00;od]CK00?o0000omSGe_l000002_o>c]X01_l0
003ocm7KoloAfoo?dM_o0000om?Be`?o000000?odm;Go`000?oEeMP00_oEeMP00ol0003og=KAomcF
d@03omcFd@03o`000?oMfM;o000000Goh][=00?o0000onCMc_oTgLh01?oTgLh00ol0003ok>;7oncR
a`03oncRa`04o`000?o]i/OokNK7ongVa`;o00001?ocj[d2o`0000;on>f]00Co0000ooO_Z_l0003o
00000_odk983o`0000[ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0PoookJP00
P?oonfX3o`0001gooo]Z00?o0000onjcT_o^/i800_o^/i800ol0003ooo]ZoookJP08oookJP03o`00
0?oZ]ikoj[NN00;oj[NN00?o0000onj_S?l000000ooQXXl00ol0003ojk:Fon^bUP04on^bUP05o`00
0?oMXiOogJ>GomfSUol000000_oMW8`00ol0003od8n>om2?SP03om2?SP03o`000?o>SHkocXf>00;o
cXf>00?o0000okmoSOnoOhd02OnoOhd:o`0000koWVF>00?o0000og92Qomb@XL00omb@XL2o`0000Ko
NTnC00?o0000odD/SOm5;8d00_m5;8d00ol0003o<BjMoc4^W@04oc4^W@04o`000?lJ99go0000o`00
Q`;o00000_l0:[@2o`0000Go82FL00?o=4Jfo`000?l000000_ldB;T01_l0003o43bjoa0l^_l0003o
01fZo`0000;o@W3I00?o0000obAVfOl000001?l=G]H00ol0003o05_Do`000008oeRGk`03o`000?mA
U>ooDIC_00;oDIC_1?l0000>ohNbl@;o00003?nW`N`3o`000003ojS1k?l0003oZL?/00?oZL?/00?o
0000ol3<hoo0c><01?o0c><00ol0003o`LoTol7?i009ol7?i003o`000?o3d^Go`m;U00Co`m;U00Co
0000om;DfooBe=_od]CK0_l0000:olk>fP04o`000?o?dM_ocm7KoloAf`?o00000ooCd]L00ol0003o
eMGHomGEf003omGEf005o`000?oLe]7og=KAomcFdOl000000_oMfM800ol0003oh][=on;Jc@02on;J
c@03o`000?oTgLkoi=g>00Coi=g>00?o0000onGOc_l000000oo/h/L00ol0003okNK7ongVa`02ongV
a`03o`000?ocj[golnZm00;olnZm00Go0000ooC^^ol0003on>f]o`000002ooO_ZP04o`000?odk9;o
m>bBooC/TP?o00002ooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01oooo]Z001m
oookJP?o00008?oonfX00ol0003ok[>BonjcTP03onjcTP;o00002?oonfX00ol0003oj[NNonZgWP03
onZgWP;o00000ooQXXl2o`0000Cojk:F00?o0000omfSUooMXiL00ooMXiL3o`0000God8n>00?o0000
olj=S_o>SHh00_o>SHh00ol0003o_gn=okmoS@0;okmoS@03o`000?neMhko]GN>00;o]GN>00?o0000
oiiUS_nNIHh03_nNIHh01?l0003oLT:7og92Qomb@XL2o`0000WoNTnC00Ko0000odD/SOm5;8go0000
odljV?l00005oc4^W@03o`000?lJ99go6RBM00;o000000Go002=o`00JOl0:[Co02Zdo`000004ob0U
W004o`000?ldA[Ko=4Jfo`0000;o=4Ri00Co0000oa0l^_l@?;[o43bj0_l000001Ol0:[Co@W3Iod9`
fOm2L=Wo000000Go3EkF0ol00008oeRGk`03o`000?mAU>ooDIC_00;oDIC_00?o0000ohNblOn7/_40
3on7/_42o`0000SoYl7/0ol00004ojS1k003o`000?nY`ncoZL?/00?oZL?/00Co0000ol3<hoo0c>?o
`<cS0_l0000:ol7?i0;o00002?o3d^D01?l0003od]CKo`000?l0000:olk>fP03o`000?o?dM_o0000
00;o00000_o?dM/01?l0003odm;Gom?Beol00007omGEf003o`000?oLe]7o000000CogMWB00Co0000
on;JcOoRf/go00001_oTgLh01?l0003oiMo>onGOc_l00002oncRa`03o`000?o]i/OokNK700?okNK7
00?o0000oo?Z_Oocj[d00_ocj[d01Ol0003om>jko`000?ohkJgo000000;omnnZ00?o0000ooC/T_od
k9801?l0000<oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX07_oonfX007_ooo]Z
0_l0000RoookJP03o`000?o^/i;ok[>B00Cok[>B00?o0000onBYU?l000001ooonfX00ol0003oj[NN
onZgWP04onZgWP;o00000_oQXXl00ol0003ojKNNo`000003on^bUP03o`000?oMXiOogJ>G00GogJ>G
0ol00003om2?SP05o`000?o>SHkocXf>olj=S_l000003_noOhd00ol0003o]GN>okEgSP02okEgSP03
o`000?nNIHkoWVF>00koWVF>00Co0000og92Qomb@XOo00002omjCi<00ol0003oABb=o`000003odlj
V004o`000?la;Ygo<BjMoc4^W@;o00000_lJ99d2o`000003o`00SOl006Wo02Zd00;o02Zd00Go0000
ob0UW?lP9Ico82FLo`000003ocA6]P;o=4Ri00?o0000oa0l^_l@?;X00_l@?;X00ol07J[o0000o`0Z
]003od9`f@;o00000ol=G]H00ol0003o4F;Hoa5Rf004o`0000CoF9O_00?o0000oe6DkomAU>l00omA
U>l00ol0003oQk;aohNbl@0?ohNbl@03o`000?nW`NcoYl7/00?oYl7/0ol00007ojS1k003o`000?nY
`ncoZL?/00CoZL?/00?o0000ol3<hol000002_o1cn@2o`0000_o`m;U00?o0000ol;<h_l000002?o>
c]X4o`0000Gocm7K00?o0000om?Beol000002?oEeMP2o`0000GogMWB00?o0000on;JcOl000001_oT
gLh01Ol0003oiMo>onGOc_oUglko000000;ok>;700?o0000ongVaoo]i/L00_o]i/L2o`0000?olnZm
00?o0000ooC^^oodk[/00_l00003ooO_ZP03o`000?odk9;om>bB00Co00003OoonfX00ol0003ooo]Z
oookJP0foookJP03o`000?oonf[ooo]Z01kooo]Z001hoookJP?o00009?oonfX2o`0000Gok[>B00?o
0000onBYU?oTZI@00_l00005oookJP03o`000?oZ]ikoj[NN00Coj[NN00Co0000omfXX?l0003o0000
0ooY]ih01?l0003ojk:Fon^bU_l00007omfSU`03o`000?o?UISociFH00Co00000oo>SHh00ol0003o
_gn=okmoS@0<okmoS@03o`000?neMhko]GN>00;o]GN>00?o0000oiiUS_nNIHh03_nNIHh3o`0000co
NTnC00?oABb=o`000?m?>YP00om?>YP01?l0003o<BjMoc4^WOl00002oc`kYP?o6RBM00Co0000o`00
SOl008go00000_l0:[@2o`000003ob0UW?l0003o=4Jf00Co=4Jf00?o=4Rio`000?l@?;X01?l@?;X3
o`0000;o@W3I00Co0000obMXf_l0003o00000_l=G]H00ol0003o4F;Ho`000003of>Gk0Co000000?o
F9O_o`000?mAU>l01?mAU>l00ol0003oQk;aohNbl@0?ohNbl@03o`000?nW`Nco000000;o00002onX
`N`00ol0003oZL?/ojW3k002ojW3k0?o00002_o1cn@00ol0003o`m;Uol?Bi@09ol?Bi@;o00000oo2
c>800ol0003oc/kJolk>fP03olk>fP?o00002Oo?dM/00ol0003oeMGHomGEf006omGEf004o`000?oG
f=WoemSIo`0000GogMWB00?o0000onCMc_oTgLh01?oTgLh00ol0003oiMo>onGOcP03onGOcP;o0000
1?o]i/L00ol0003ok^W7o`000003oo?Z_@03o`000?odk[_om>jk00;o00000_ogkjX2o`000003ooC/
T_l0003o000000;o00003_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01gooo]Z
001eoookJP?o00009ooonfX00ol0003oikbYo`000004onjcTP03o`000?oTZICoi:VD00;oi:VD00Go
0000oookJ_oonf[ooo]Zo`000006onZgWP05o`000?oMZ:3ogJRPomfXX?l000001?oY]ih2o`0000So
gJ>G00?o0000olnEV?o?UIP00oo?UIP3o`000003olj=S_l0003o_gn=00co_gn=00?o0000okEgS_ne
Mhh00oneMhh00ol0003oWVF>oiiUSP0;oiiUSPCo00003OmjCi<2o`0000KoCcZH00?o0000oc4^WOl0
00000_ll>jH01?l0003o6RBMoaXTWOl00002o`00S@05o`0JYol0003o02Zdo`0Z]?l02I<00_l00005
ocA6]P03ocA8^Ol0003o43bj00Co43bj0_lNDl/2o`0000;o@W3I00?o0000obMXf_lWJ=X01?l00000
0olAH]So0000of>Gk006of>Gk0Ko000000?oDIC_o`000?n7/_402?n7/_46o`0000;oQk;a00?o0000
ojS1k?nX`N`03?nX`N`00ol0003oZL?/o`000002o`0000;o[<G/00?o0000ol7?i?o1cn@01_o1cn@2
o`0000[o`m;U0_l00006ol;<hP03o`000?o>c][o000000?o00002Oo?dM/00ol0003od=?Lo`000007
omGEf003o`000?oGf=WoemSI00;oemSI00Co0000omgId_oMfM;ogMWB0_l00005onCMcP03o`000?oU
glkoiMo>00CoiMo>00?o0000ongVaoo]i/L00oo]i/L01_l0003ok^W7onkYaol0003olnZmo`0000?o
m>jk00Co0000ooO_Z_ogkj[omnnZ0_l000000oodk9;o0000o`000002o`0000oooo]Z00?o0000oook
J_oonfX0=ooonfX00ol0003ooo]ZoookJP0LoookJP00L_oonfX3o`0002Wooo]Z00Go0000onNlZOoW
_:WoikbYo`000002onjcTP03o`000?oTZICoi:VD00Coi:VD0_l000000ooonf[o0000onZgWP05onZg
WP05o`000?oMZ:3ogJRPomfXX?l000001OoY]ih2o`0000KogJ>G00?o0000olnEV?o?UIP01?o?UIP0
0ol0003ocIBHolfDV006o`0000Wo_gn=00?o0000okEgS_neMhh00oneMhh00ol0003oWVF>oiiUSP05
oiiUSPKo00000onQKYP00ol0003oNTnCogY?T`09ogY?T`;o000000?oPebKo`000?m?>YP01_m?>YP0
1Ol0003o?3^Voc`kY_ll>jKo000000;o6RBM00[o@T>/o`000?l008go0000o`0JYol0003o02Zdo`0K
ZOl02I?o00001OldA[H3o`0000Co43bj00Co0000oaiCbolNDl_o00000_m2L=T00ol0003o9fSJobMX
fP03obMXfP;o000000?o4F;Ho`000?mSUn`01_mSUn`00ol0003oFI?]oeVCk@02oeVCk@_o00002?n;
/>l00ol0003oZ<7/ojS1k00<ojS1k0;o00001_n/aN`00ol0003o`LoTol7?i004ol7?i003o`000?o3
d^Go`m;U00Wo`m;U0_l00006ol;<hP?o00000_o>c]X00ol0003ocm7KoloAf`07oloAf`05o`000?o@
dmcod=?Lom3Cg?l000001OoEeMP00ol0003oemSIomOHf@04omOHf@03o`000?oMfM;o000000;ogm_C
00?o0000onCMc_oTgLh00_oTgLh00ol0003oiMo>onGOcP04onGOcP03o`000?o]i/OokNK700;okNK7
00Co0000onkYaoo^jLOok^W70_l00004ooC^^`05o`000?ogkj[omnnZo`000?oelJH00_l000001?o_
jh[o0000omgII?l0000@oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX07?oonfX0
06oooo]Z0ol0000/oookJP03o`000?oW_:WoikbY00;oikbY00?o0000onjcT_l000001_oTZI@00ol0
003ofYnEo`000002o`0000Goj[NN00Co0000omfXX?oMZ:3o00001_oY]ih00ol0003ogJVOo`000005
omfSU`03o`000?o?UISociFH00CociFH00Go0000olfDV?o=U9SocIBHo`000004ol67UPOo00000_no
Ohd00ol0003o]GN>okEgSP03okEgSP03o`000?nNIHkoWVF>00Go00002OnQKYP00ol0003oNTnCogY?
T`08ogY?T`05o`000?n3G9_oPebKoh=LVol000001om?>YP01ol0003o?3^Voc`kY_ll>jKo0000oaXT
WOl000000_m2@j`2o`0000;o01ZW00Go02Zdo`000?l06jWo00VCo`000004ocA6]P04o`000?mGHL7o
Ef71o`0000?o43bj00Oo0000oaiCbolNDl_o7U?;o`000?m2L=Wo000000Oo9fSJ0_l00008of>Gk003
o`000?mITngoFI?]00?oFI?]00?o0000oh^`kon;/>l03on;/>l00ol0003oZ<7/ojS1k007ojS1k0?o
000000?oZL;/o`000?n/aN`01on/aN`01?l0003o`LoTol7?i?o1cn@2o`0000[o`m;U0ol00004ol;<
hP?o00000_o2c>800ol0003oc/kJo`000009oloAf`03o`000?o@dmcod=?L00;od=?L00?o0000omGE
f?oEeMP00_oEeMP00ol0003oemSIomOHf@06omOHf@05o`000?oOfm?ogm_ComoKdol000000ooTgLh0
0ol0003oiMo>onGOcP04onGOcP;o00000oo]i/L00ol0003ok^W7onkYa`02onkYa`;o00000oodk[/2
o`0000;omnnZ00Go0000ooGaY_l0003o0000ono[RP02o`00017ooo]Z00?o0000oookJ_oonfX0=ooo
nfX00ol0003ooo]ZoookJP0KoookJP00K?oonfX3o`0002oooo]Z00?o0000onNlZOoW_:T00ooW_:T2
o`0000Koi:VD00?o0000omZOUOl000000_oV^jT01Ol0003oj[NNonZgW_oZ]iko000000?ogJRP00?o
0000onVgW_oY]ih01?oY]ih00ol0003ogJVOomfYW`02o`0000?ogJ>G00?o0000olnEV?o?UIP01?o?
UIP01Ol0003ocIBHolfDV?o=U9So000000_o`HNF2ol0000>oj5^V003o`000?mjCi?oNTnC00KoNTnC
0_l00004oh=LV`03o`000?m?>YSoCcZH00CoCcZH00?o0000of]AX_l000000_ll>jH00ol0003o6RBM
o`000002od93[00:o`000?l008go0000o`0JYol0003o02Zdo`000?l06jWo00VCo`0000?o=4Jf1?mG
HL401?l0003o43bjoa0l^_l00004oaiCb`03o`000?m2L=Wo000000Ko9fSJ00?o0000obUZfol00000
1omSUn`00ol0003oFI?]oeVCk@04oeVCk@03o`000?n;/>ooRk3_00ooRk3_00?o0000ojS1k?nX`N`0
0onX`N`3o`0000GoZL;/00?o0000ojc5k?n/aN`01_n/aN`00ol0003o`LoTo`00000:ol?Bi@?o0000
00?o_l_So`000?l000000ol00005ol;<hP;o00002Oo?dM/00ol0003od=?Lom3Cg004om3Cg004o`00
0?oEeMSoeMGHo`0000SoemSI00?o0000omSKfOl000000_oOfm<01?l0003oi=g>onCMc_l00006onGO
cP03o`000?oVi<oo000000;okNK700?o0000onkYaoo^jLL00oo^jLL00ol0003om>jkooC^^`02ooC^
^`;o00000_ogkjX01?l0003omO6Vo`000?o_jhX3o`0001;ooo]Z00?o0000oookJ_oonfX0=ooonfX0
0ol0003ooo]ZoookJP0JoookJP00J_oonfX2o`00037ooo]Z00?o0000onNlZOoW_:T01OoW_:T2o`00
00Goi:VD00?o0000omZOUOl000000ooV^jT01?l0003oj[NNonZgW_l00003omfXX003o`000?oY]iko
jKNN00?ojKNN00?o0000omfYWooMZIl00ooMZIl01?l0003ogJ>GomfSUol00006olnEV004o`000?o=
U9SocIBHo`0000ko`HNF00?o0000okInUonfOYL00onfOYL00ol0003oXFjHoj5^V00>oj5^V003o`00
0?mjCi?oNTnC00CoNTnC0_l00006oh=LV`03o`000?m?>YSoCcZH00?oCcZH00Go0000of]AX_m[DJ;o
Je6Ro`000002oc`kYP03oaXTWOl0003o@T>/00;o@T>/0_l00002o`0JY`;o00000_l06jT01Ol02I?o
0000ocA6]_ldA[Ko000000CoEf7100?o0000oa0l^_l000001?lNDl/01?l0003oBFoEo`000?l00006
obMXfP03o`000?lYJ]_o000000;o00001OmSUn`00ol0003oFI?]oeVCk@04oeVCk@03o`000?n;/>oo
Rk3_00koRk3_0_l000001?nX`Nco0000o`000?l00008ojW2k003o`000?n/aNco[<G/00Ko[<G/0_l0
000:ol?Bi@;o000000?o_l_So`000?l000000_l00006ol;<hP;o00000_o3c^800ol0003ocm7KoloA
f`05oloAf`03o`000?o@dmcod=?L00God=?L00?o0000omGEf?l000002?oGf=T01Ol0003of=_IomSK
fOoHfmWo000000;ogm_C0_l00006onGOcP07o`000?oVi<ooi^C?onKTcol0003okNK7o`000005onkY
a`05o`000?odk[_om>jkooC^^ol000000_odlKX2o`0000;omO6V00?o0000ono[R_l000000_l0000C
oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX06_oonfX006Oooo]Z0ol0000coook
JP03o`000?oW_:WoikbY00GoikbY00?o0000on2dZOl000001?oTZI@00ol0003ofYnEo`000004onJk
Z@03o`000?oZ]iko000000;ogJRP0_l00005onVgWP03o`000?oMZIoogJVO00CogJVO0_l00008olnE
V003o`000?o=U9So000000go`HNF00?o0000okInUonfOYL01?nfOYL00ol0003oXFjHoj5^V00?oj5^
V004o`000?mjCi?oNTnCogY?T`;o00002On3G9/01Ol0003oCcZHodljV?m?>YSo000000GoJe6R00?o
0000oc`kY_l000001Om2@j`00ol0003o01ZWo`0JY`02o`0000;o01^Y1Ol00005oeMQ`@03oa0l^_l0
003o7U?;00Co7U?;0_l000000omKNmWo0000o`000004obMXfP03o`000?lYJ]_o000000;oKiSY1_l0
0006oeVCk@03o`000?n;/>ooRk3_00_oRk3_0ol000000on;/>oo0000o`00000<ojW2k003o`000?n/
aNco[<G/00;o[<G/0ol000000on^anco0000ol?Bi@07ol?Bi@Go00001?nobn<00ol0003o`/cRol;<
hP02ol;<hP03o`000?o3c^;o`lkR00?o`lkR00?o0000oloAfoo?dM/00oo?dM/00ol0003od=?Lom3C
g007om3Cg003o`000?oGf=WoemSI00KoemSI00?o0000omSKfOoHfmT00ooHfmT00ol0003ogm_Co`00
0006onGOcP03o`000?oVi<ooi^C?00;oi^C?0_l00005onkYa`;o00000_odk[/01?l0003om?6jooCa
^_odlKX2o`000003ooGaY_l0003o000000Co00005?oonfX00ol0003ooo]ZoookJP0foookJP03o`00
0?oonf[ooo]Z01Wooo]Z001ToookJP?o0000=_oonfX00ol0003oikbYonNlZ@04onNlZ@05o`000?oP
]:Woh;BYon2dZOl000000_oTZI@00ol0003ofYnEo`000006onJkZ@;o00000_oMZ:000ol0003oj;ZT
o`000004onVgWP03o`000?oMZIoogJVO00GogJVO0ol00006olnEV003o`000?o=U9So000000go`HNF
00?o0000okInUonfOYL01?nfOYL00ol0003oXFjHoj5^V00?oj5^V004o`000?mjCi?oNTnCo`0000_o
PebK00Co0000odljV?m?>YSo00001om[DJ82o`0000Go@T>/00?o0000o`0JYol06ZL00ol00002o`0K
Z@03o`09Tol0003o1UoG00;o00001OmGHL42o`0000Co7U?;0_l00003oe]kf@?o000000Go9fSJo`00
0?lYJ]_o:F[Ko`000006ofnHj@Ko00000_mITnd00ol0003oRk3_oh^`k`02oh^`k`So00001?n@/>`0
0ol0003oRK;ao`00000;ojW2k003o`000?n/aNco000000;o00001On^an`00ol0003o`m;Uol?Bi@04
ol?Bi@?o00002?nobn<01?l0003o`/cRo`000?l00007ol?>hP05o`000?o?dM_ocm7KoloAfol00000
2?o@dm`00ol0003odMGLo`000007omOHf@03o`000?oHfmWof=_I00Cof=_I0ol00006onGOcP03o`00
0?oVi<ooi^C?00;oi^C?00?o0000onkYaoo^jLL00oo^jLL00ol0003ok^_7o`000002ooC^^`05o`00
0?odlK[om?6jooCa^_l000000_oelJH6o`0001Cooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003o
oo]ZoookJP0HoookJP00HOoonfX3o`0003Sooo]Z00?o0000onNlZOoW_:T01OoW_:T00ol0003oh;BY
on2dZ@02on2dZ@05o`000?oTZICo0000omZOUOl000001_oV^jT01?l0003og[2Xo`000?l00003onRj
Y0;o00000_oY]ih00ol0003ogJVOomfYW`05omfYW`03o`000?o:UZ3obYJP00?o00000oo?UIP00ol0
003ocIBHo`00000=ol67UP03o`000?nfOYOo]WjG00Co]WjG00?o0000oj5^V?nQKYP03onQKYP3o`00
00coPebK00?o0000odljV?l000002Om[DJ800ol0003o@T>/od93[003od93[00;o`/ZZ_l0003o01ZW
o`0JYol0003o8D[2o`000?l06jWo0000o`09Tol000000_l6GmL00ol0003oEf71oeMQ`@02oeMQ`@;o
=5O70_l00003oaiCb`03o`000?mKNmWoFg_I00CoFg_I00Go0000obMXf_l0003o:F[Ko`000007ofnH
j@03o`000?mSU>_oHiC[00;oHiC[1ol0000=oi2`k003o`000?n9/_7o000000_oZL;/00?o0000ojk7
k?n^an`01on^an`00ol0003o`m;Uol?Bi@03o`0000co_l_S00?o0000ol?>h_o3c^802?o3c^800ol0
003ocm7Ko`000008om3Cg005o`000?oAeMcodMGLom7Eg?l000001OoGf=T00ol0003of=_IomSKf@04
omSKf@03o`000?oIgM[ofMgJ00;o00001?oUglh00ol0003oi^C?onKTc`03onKTc`03o`000?o^jLOo
k^W700?ok^W700?o0000onk[aoo^jlL00_l00004ooCa^P05o`000?oelJKo0000o`000?o_jhX01?l0
000EoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX06?oonfX005kooo]Z0ol0000k
oookJP;o00001OoW_:T00ol0003oh;BYon2dZ@04on2dZ@;o000000?ofYnEo`000?oV^jT01?oV^jT0
1Ol0003og[2Xomj`Z?oN/:So000000Goj;ZT0_l00008omfYW`03o`000?o:UZ3obYJP00?obYJP1Ol0
000=ol67UP03o`000?nfOYOo]WjG00Go]WjG00?o0000oj5^V?nQKYP03?nQKYP4o`0000koPebK0_l0
000:of]AXP;o00001?m2@j`01Ol0003o2bZZo`000?l06ZOo000000;o8D[20_l000000ol07JWo0000
o`000002o`IOe`;o00000_mGHL401Ol0003o=5O7ocAGaoldElOo000000;o7U?;00?o0000oe]kfOmK
NmT01_mKNmT2o`000003obUZfol0003oKiSY00KoKiSY00?o0000of>DjomSU>/01?mSU>/00ol0003o
T;3/oi2`k00?oi2`k003o`000?n9/_7o000000KoZL;/0ol000000on[`n_o0000ojk7k008ojk7k0Go
00002_nobn<2o`000003oko<i?l0003o`lkR00Wo`lkR0_l00008om3Cg003o`000?oAeMcodMGL00;o
dMGL00?o0000omOHfOoGf=T00_oGf=T00ol0003of=_IomSKf@04omSKf@03o`000?oIgM[ofMgJ00;o
fMgJ00Go0000onGOc_oUglkoiMo>o`000005onKTc`;o00001?o^jLL01?l0003ok^_7onk[aoo^jlL2
o`0000?om?6j0ol000001?oalZ;o0000o`000?oWj882o`0001Oooo]Z00?o0000oookJ_oonfX0=_oo
nfX00ol0003ooo]ZoookJP0GoookJP00G?oonfX2o`0003gooo]Z00Co0000on;0]_oR`;Ko00001?oW
_:T00ol0003oh;BYon2dZ@05on2dZ@;o00001_oV^jT01Ol0003og[2Xomj`Z?oN/:So000000Koj;ZT
0_l00006omfYW`03o`000?o:UZ3obYJP00OobYJP1Ol0000:ol67UP03o`000?nfOYOo]WjG00Go]WjG
00?o0000oj5^V?nQKYP01_nQKYP6o`0000;oXG>O1?l0000;oh=LV`;o00002_m[DJ82o`000005od53
[?l0003o@T>/od93[?l000000ol;:ZX00ol0003o8D[2ob5:`P02ob5:`P03o`0KZOl0003o01fY00;o
00000ol6GmL2o`0000Go=5O700Co0000oaiCbol0003o00001omKNmT00ol0003o@g?Ko`000002o`00
00OoKiSY00?o0000of>DjomSU>/01?mSU>/00ol0003oT;3/oi2`k00>oi2`k004o`000?n9/_7oRK;a
o`0000;oZL;/0ol00005oj_3j`03o`000?n^anco[/O/00?o[/O/1_l000000on^aN_o0000oko;h`08
oko;h`03o`000?noc>Co_lcT00;o_lcT00?o0000ol?>h_o3c^801_o3c^800ol0003oa=3So`000007
om3Cg003o`000?oAeMcodMGL00CodMGL00Co0000omOHfOoGf=Wo00001_oHfmT00ol0003ofMgJomWM
fP03omWMfP;o000000?oiMo>o`000?oVi<l01?oVi<l00ol0003oj>O?o`000003onkYa`03o`000?o^
jlOok^_700;ok^_700Ko0000ooCa^_odlK[om?6jo`000?oclkT2o`000004oo7bX_l0003o0000onOX
PP;o00005ooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z01Kooo]Z001IoookJP?o
0000?ooonfX01Ol0003oh/2fon;0]_oR`;Ko000000;oikbY00?o0000on2dZOoP]:T01_oP]:T3o`00
00Goi[^Y00Co0000omj`Z?oN/:So00001ooX^Z@01?l0003ogZfTo`000?l00004omfYW`03o`000?o:
UZ3obYJP00SobYJP00Co0000ol:?XOo2Sj7o`XnQ1ol00003ol67UP03o`000?nfOYOo]WjG00Go]WjG
00?o0000oj5^V?nQKYP01_l00007oj5cW`03o`000?nRM9oo000000;oPUjO0ol00006oh=LV`;o0000
00?oQF>To`000?m[DJ802?m[DJ802?l0003oHENaof5G/Ol0003o@D>/o`000?m2@jco00001?l;:ZX0
0ol06ZOo8D[2ob5:`P02ob5:`P;o000000?o01fYo`000?l000000_l6GmL00ol0003o05_Do`000006
ocAGa`;o00001omKNmT01Ol0003o@g?Kod=cfom3Lm_o000000OoKiSY00?o0000of>DjomSU>/01OmS
U>/00ol0003oT;3/oi2`k00>oi2`k003o`000?n9/_7o000000;o00002?n[`n/00ol0003o[/O/ojk7
k003o`000003ojk7k?l0003o000000Go[/G[00?o0000oko;honobn<01?nobn<2o`0000Ko_lcT00?o
0000ol?>h_o3c^800oo3c^82o`0000?oa=3S00?o0000om3Cg?o@dm`00oo@dm`00ol0003odMGLom7E
g005om7Eg003o`000?oGf=Wo000000Kof=_I00?o0000omWMf_oIgMX01OoIgMX3o`0000Coi^C?00Oo
0000onSWcooXilooj>O?o`000?o^jLOo000000Gok^_700Co0000ooCa^_odlK[om?6j0ol00002oo7b
XP03o`000?oWj8;o000000;o00006?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z
01Kooo]Z001FoookJP?o0000@OoonfX00ol0003oh/2fon;0]P03on;0]P03o`000?oW_:Wo000000Oo
h;BY0_l00002onFn[`05o`000?oV^jWoi[^YonJkZOl000000ooN/:P00ol0003oj;ZTonRjY004onRj
Y003o`000?oN[JCogZfT00;ogZfT00Go0000omfYWooMZIoogJVOo`00000:olZFX003o`000?o2Sj7o
`XnQ00So`XnQ3_l0000<oj5cW`04o`000?nRM9ooXWBOo`0000GoPUjO0ol00002oh=LV`05o`000?n5
HjCoQF>TohESY?l000002?m[DJ801Ol0003oHENaof5G/OmQEk7o000000;o@D>/0_l00005o`/ZZP04
o`000?lQB/;o8D[2ob5:`P;o03Jk0_l000001_l08Zgo0000o`000?l6GmOo0000o`1Ke0;o00001?ld
ElL2o`0000OoFg_I00?o0000od=cfom3Lm/00_m3Lm/;o`0000CoHiC[00?o0000oi2`k?n@/>`02on@
/>`3o`000004oi2`k?l0003oSK?`o`0000WoZl?[0ol000001?n^anco0000o`000?l00008ojk5j`04
o`000?nobn?o_l_Soko;h`;o00002?noc>@01?l0003o`lkRol?>h_o3c^82o`0000Koa=3S00Go0000
om3Cg?o@dmcod=?Lo`000009om7Eg003o`000?oHfmWof=_I00Cof=_I00?o0000omWMf_oIgMX01OoI
gMX2o`0000;ohNCE00Go0000onKTcooVi<ooi^C?o`000003onSWc`03o`000?o^jLOo000000Cok^_7
0_l00002ooCa^P04o`000?oclkWo0000o`0000;olO:R00?o0000onOXP_l000000_l0000IoookJP03
o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX05OoonfX005?ooo]Z0ol00013oookJP03o`00
0?oR`;Koh/2f00Goh/2f0_l00007on2dZ@;o00000ooU_Zl01?l0003oi[^YonJkZOl00003omj`Z003
o`000?oX^ZCoj;ZT00Coj;ZT00?o0000omj]Y?oN[J@00ooN[J@3o`0000[obYJP0_l0000<ol:?X@03
o`000?ngPico]h>L00Ko]h>L00?o0000oj5cWonQLil02onQLil01Ol0003oXWBOoj9dWonRM9oo0000
00SoPUjO1Ol00002ohESY003o`000?m[DJ;oJe6R00CoJe6R00?o0000of5G/OmQEk400_mQEk401Ol0
003o@D>/od53[?m1@jco000000Go2bZZ00?o8dFmo`000?lQB/800_lQB/82o`0f^`07o`0MZOl0003o
0000obMZfol0003o1UoGo`000002o`1Ke0;o00000_ldElL00ol0003o>E_:o`000002o`0000GoFg_I
00Go0000od=cfom3Lm_o@g?Ko`000007ogZJiP03o`000?m^U^OoKYKW00Ko00001?n@/>`8o`0000Co
UK7Z00Co0000ohfcl?n=/o3o00001On[`n/3o`000004oj_3jol0003o0000o`0000co[/G[00?o0000
oko;hol000002onoc>@00ol0003o`lkRo`000009olC@h`03o`000?o@dmco000000SodMGL00?o0000
om;HgOl000001OoHfmT00ol0003ofMgJomWMfP05omWMfP03o`000?oJgm[o000000?ohNCE00?o0000
onKTcol000001?oXill2o`0000Cok^_700Go0000ono`a_l0003om?6jo`000002oo?c^@03o`000?oa
lZ;olO:R00Go00006ooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01Cooo]Z001@
oookJP?o0000A_oonfX00ol0003oh/2fon;0]P05on;0]P03o`000?oM^[Go000000Goh;BY0_l00005
onFn[`03o`000?oV^jWo000000;og[2X0_l00006onRjY003o`000?oN[JCogZfT00GogZfT0_l00009
olZFX0;o00002oo2Sj400ol0003o]h>LokN3W007okN3W003o`000?nQLiooXG>O00[oXG>O00?o0000
oj9dWonRM9l00onRM9l00ol0003oPUjOoh9NW`03oh9NW`;o00001On5I:@3o`0000GoJe6R00?o0000
of5G/OmQEk401?mQEk401?l0003o@D>/od53[?l00005o`/ZZP;o000000Co;Dboob5:`_lQB/;o0000
0_l0=[/01?l07JWo0000o`000?lWJ]/2o`0000Co05_D00Co0000ocAGaol0003o>E_:0om/P]L4o`00
0003oe]kfOl0003o@g?K00?o@g?K00?o0000ogZJi_mjV^H01?mjV^H00ol0003oKYKWofjFi`05ofjF
i`Go00003OnE/NX01Ol0003oSK?`ohfcl?l0003oZl?[00?o00000_n[`n/2o`00013o[/G[00?o0000
oko<i?noc>@02onoc>@00ol0003oa=3SolC@h`08olC@h`;o00002?oAeM`01Ol0003od]SMom;HgOoB
f=go000000?of=_I00?o0000omWMf_oIgMX01OoIgMX01?l0003of]oJom[Of_l00004on7Te@;o0000
1?oXill00ol0003ok^_7onk[a`02onk[a`06o`000?o_l<Koko36o`000?odlK[o00000_oclkT00ol0
003olO:Roo7bXP05o`0001_ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0Doook
JP00COoonfX3o`0004Sooo]Z00?o0000on;0]_oR`;H01OoR`;H01Ol0003ogKZeomfj]OoM^[Go0000
00Coh;BY0_l00006onFn[`;o00000_oN/:P00ol0003oikbYo`000004onRjY003o`000?oN[JCogZfT
00KogZfT00Co0000om>QY?l0003o00001_o:UZ000ol0003oai>Oo`00000;ol:?X@03o`000?ngPico
]h>L00So]h>L00?o0000oj5cWonQLil02?nQLil00ol0003oXWBOoj9dW`04oj9dW`03o`000?n2GYoo
PUjO00?o00002On5I:@2o`0000?oJe6R00?o0000of5G/OmQEk401OmQEk401Ol0003o@D>/o`000?mM
Ek?o000000Co2bZZ00Ko0000ob=5_Ol0003o;Dboob5:`_l00003o`0f^`;o00000olWJ]/00ol0003o
05_Do`1Ke002o`1Ke0;o00000_liFlX6ofb2e`Co00000om3Lm/00ol0003oNY[VogZJiP03ogZJiP03
o`000?m^U^OoKYKW00KoKYKW00?o0000oiFaj_nE/NX03onE/NX4o`0000;oZl?[0ol0000?ojk5j`;o
000000?o[lK[o`000?noc>@02Onoc>@2o`000003ol3>i?l0003oa=3S00Soa=3S00Co0000olKBi?o6
d^Co00001OoAeM`2o`0000Cod]SM00Co0000omSKfOoHfmWo00001ooIgMX01Ol0003of]oJom[Of_oJ
gm[o000000?ohNCE00Co0000on?XeOoSj=Go00000ooXill01Ol0003ok^_7onk[aoo^jlOo000000?o
ko360_l00002oo?c^@;o000000ColO:Ro`000?l0003oinR20ol0000LoookJP03o`000?oonf[ooo]Z
03Kooo]Z00?o0000oookJ_oonfX04ooonfX004_ooo]Z0_l0001;oookJP03o`000?oR`;Koh/2f00Go
h/2f00?o0000omfj]OoM^[D00_oM^[D00ol0003oh;BYon2dZ@02o`0000OoiKj_00Co0000omje[_l0
003o00000ooW_:T2o`0000;oj;ZT00?o0000omj]Y?oN[J@01OoN[J@00ol0003odj6Tom>QY002om>Q
Y0?o00000oo:UZ001?l0003oai>OolNCWol00009ol:?X@03o`000?ngPico]h>L00Wo]h>L00?o0000
oj5cWonQLil01onQLil00ol0003oXWBOoj9dW`05oj9dW`?o00003?n5I:@01Ol0003oIU6Uo`000?m[
DJ;o000000SoHENa00?o0000od53[?l000000_mMEk<01?l0003o2bZZo`/ZZ_l00002ob=5_@05o`00
0?l]C;oo;Dboob5:`_l000000ol0=[/2o`0000?o9f[K0_l00002o`1Ke003o`000?l0G=Co000000?o
00001Om/P]L00ol0003oG8SSoeb8h`03o`000003od=cfol0003oNY[V00CoNY[V00?o0000ofjFiom^
U^L01_m^U^L00ol0003oUK7ZoiFajP0<oiFajP?o00000_n=/o03o`0000oo[/G[0ol00004ojo6j`03
o`000?noc>Co_lcT00Ko_lcT00?o0000ol3>i?o0c^@00_o0c^@00ol0003oa=3SolC@h`04olC@h`;o
00001?o6d^@01Ol0003odMGLom7Eg?oAeMco000000Kod]SM00?o0000omSKfOl000001ooIgMX00ol0
003of]oJom[OfP03om[OfP03o`000?oQi=Go000000CohnSE00Co0000onSWcol0003o00000oo^jlL0
1Ol0003oko36ono`a_o_l<Ko000000?olo>i0_l000001_oalZ;o0000o`000?l0003ognEjo`0001ko
oo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0BoookJP00B?oonfX3o`0004cooo]Z
00?o0000on;0]_oR`;H01OoR`;H00ol0003ogKZeomfj]@04omfj]@04o`000?oP]:Wo0000o`0000Ko
iKj_00Go0000omje[_oN]Jkog[F^o`000005onNlZ@03o`000?oX^ZCo000000OogZfT00?o0000om>Q
Y?oCXJ@01OoCXJ@2o`000005olZFX?l0003oai>OolNCWol000002Oo2Sj400ol0003o]h>LokN3W009
okN3W003o`000?nQLiooXG>O00KoXG>O00?o0000oj9dWonRM9l00onRM9l4o`0000ooQFBT00Co0000
ofIAYOl0003o00002OmQEk400ol0003oGENcoeeG/`02oeeG/`03o`000?l;:Z[o000000;o8dFm00Co
0000obe<_ol]C;oo;Dbo0_l00002o`0f^`?o00000_lWJ]/01Ol0003o467Ho`000?l0003o05_D00;o
00000om=TNh6o`0000GoG8SS0ol00004ogZJiP03o`000?m^U^OoKYKW00OoKYKW00?o0000oiFaj_nE
/NX02?nE/NX8o`0000;oV;ca00?o0000ojk5jon^aN/02on^aN/2o`0000So[lK[00?o0000oko<i?no
c>@00onoc>@2o`0000Go`<kT00?o0000olC@hoo4d><00oo4d><00ol0003oa];TolKBi005olKBi003
o`000?oAeMco000000Sod]SM00?o0000omWMf_oIgMX01OoIgMX00ol0003of]oJom[OfP04om[OfP;o
00001_oSj=D2o`000004onW[c_l0003ok^_7o`0000Coko3600Oo0000oo?c^OoclkWo0000oo7f]Ol0
003olO:R00Go00007_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01;ooo]Z0015
oookJP?o0000CooonfX2o`0000Goh/2f00?o0000omfj]OoM^[D01_oM^[D2o`0000OoiKj_00Co0000
omje[_oN]Jko00001ooW_:T2o`0000OogZfT00?o0000om>QY?oCXJ@01ooCXJ@3o`000003olNCWol0
003o`XnQ00Oo`XnQ00?o0000okN3W?ngPi`02_ngPi`00ol0003oXG>Ooj5cW`05oj5cW`03o`000?nR
M9oo000000Co00000onUO:H00ol0003oQFBTohETY00=ohETY0;o00000_mYEZT00ol0003oHENaof5G
/@06of5G/@03o`000?mMEk?oGENc00?oGENc0_l00003ob=5_@03o`000?l]C;oo;Dbo00;oAUg600?o
0000o`0f^ol0=[/00_l00003obMZf`03o`000?l@HMSo467H00Co00001om=TNh5o`0000CoG8SS0ol0
00000omjV^Ko0000ofjFi`09ofjFi`03o`000?nE/N[oUK7Z00CoUK7Z1_l00008oiRll@03o`000?n^
aN_o[/G[00So[/G[0_l0000:ojo6j`04o`000?noc>Co_lcToko<i0;o00002?o0c^@00ol0003oa=3S
olC@h`02o`0000Soa];T0_l00008om;Hg@;o00001_oIgMX00ol0003of]oJom[OfP05om[OfP03o`00
0?oSj=GohnSE00CohnSE00?o0000onCZeOoTj]D00ol00004ono`aP;o000000Colo>io`000?oam[Go
lOJe0_l000000oo^lYgo0000omoUNP02o`0001oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003o
oo]ZoookJP0AoookJP00@_oonfX3o`00057ooo]Z00Co0000omk2_?oN`[co00001?oR`;H00ol0003o
gKZeomfj]@06omfj]@?o00001OoU_Zl01Ol0003og[F^omje[_oN]Jko000000OoikbY00?o0000omna
Yol000001OoN[J@00ol0003odj6Tom>QY008om>QY003o`000?o7UZ?oaiJS00Ko00001?o2Sj400ol0
003o]h>LokN3W00:okN3W003o`000?nQLiooXG>O00?oXG>O1?l00008ojElYP03o`000?n5I:CoQFBT
00coQFBT0_l00004ofUFZ@;o00001OmQEk42o`0000KoGENc0_l00002ob=5_@04o`000?l]C;oo;Dbo
o`0000;oAUg60_l0=[/01?l0003o03Zno`000?l00002obMZf`04o`000?l@HMSo467Hoa1Qf0?o0000
2?m=TNh00ol0003oAXk]odJ>k@03o`000004oeb8hol0003oNiWTog^Ii0Wo00001?m^U^L00ol0003o
UK7ZoiFajP05o`0000goV;ca00?o0000ojk5jon^aN/01On^aN/2o`0000go[lK[00?o0000oko<i?l0
00002_o0c^@00ol0003oa=3So`000009olKBi003o`000?o7eNCo000000Ood]SM00Co0000om?JgOoC
f]go00001?oIgMX00ol0003of]oJom[OfP05om[OfP;o00001OoSj=D00ol0003oi>[EonCZe@02onCZ
e@;o00000oo_l<H01Ol0003oko?3o`000?oclkWo000000;olOJe0_l000001?o^lYgo0000o`000?l0
000QoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX04?oonfX003oooo]Z0ol0000D
oookJP;o0000?OoonfX00ol0003og/:lomk2_002omk2_004o`000?oR`;Koh/2fo`0000SogKZe0_l0
0002on?0/`03o`000?oU_ZooiKj_00;oiKj_00Go0000omje[_oN]Jkog[F^o`000006onNlZ@04o`00
0?oO/JOogk6WomnaY`;o00000ooN[J@00ol0003odj6Tom>QY007om>QY003o`000?o7UZ?oaiJS00;o
aiJS00?o0000ol6BY_o1TZH00_o1TZH<o`0000Ko]h>L00?o0000oj5cWol000000ol0000<ojElYP03
o`000?n5I:CoQFBT00WoQFBT0_l000000on<JjOo0000ofUFZ@05ofUFZ@05o`000?mQEk7oHENaof5G
/Ol000000_mSFk<00ol0003oGENcoeeG/`03oeeG/`;o>4Rg00Ko0000ob=5_OlSAKgo0000obe<_ol0
0003odIMaP03o`0f^ol0003o03Zn00;o@g?K0ol00005oa1Qf0;o00002?m=TNh00ol0003oAXk]odJ>
k@02odJ>kACo00004_nH_?400ol0003o[/G[ojk5j`02ojk5j`?o00004?n_a^/00ol0003o`<kTol3>
i00:ol3>i003o`000?o6d^Coa];T00Koa];T0_l00003olOEi003o`000?oBf=god]SM00?od]SM00Go
0000om?JgOoCf]godm[Mo`000004omWMfPOof]oJ00?o0000omcQf_l000001?oSj=D00ol0003oi>[E
onCZe@03onCZe@07o`000?o[lLco0000o`000?o_l<Ko0000onoc``02o`0000?olOJe00?o0000onkb
WOl000000ol0000QoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX04?oonfX003co
oo]Z0ol0000GoookJP03o`000?oaYg?o000003cooo]Z00?o0000omk2_?oN`[`00ooN`[`00ol0003o
h/2fo`000007omfj]@03o`000?oH];Go000000?ohl2c00Co0000onFn[ooU_Zoo00000ooN]Jh00ol0
003oikbYonNlZ@05onNlZ@03o`000?oO/JOogk6W00?ogk6W00Co0000omj]Y?oN[JCo00002OoCXJ@0
0ol0003oaiJSolNFX`02olNFX`03o`000?o1TZKo`I:V00Go`I:V00?o0000ok21XOn`PJ401_n`PJ48
o`0000;oXWRS00?o0000ojElY_nUO:H02onUO:H00ol0003oQFBTohETY007ohETY0;o00000on<JjL0
0ol0003oJEJYofUFZ@05ofUFZ@03o`000?mQEk7o000000?oHe^c00?o0000oeeG/omMEk<00_mMEk<0
1_l0003o>4RgocQ8]olhB;Oo0000ob=5_@;o00001Om6GLH00ol0=[_o0000o`0j_P04od=cf`;o0000
0ol@HMP00ol0003o46;Ho`000008odfAkP03o`000?m6S^goAXk]00;oAXk]00?o0000ogZ/lomj[?<0
2?mj[?<00ol0003oMZ_co`000002o`0000;oMZ_c00?o0000oiRllOnH_?404OnH_?401?l0003o[/G[
o`000?l0000?ojo6j`?o000000?o/<S/o`000?o0c^@02?o0c^@2o`000003ol7?iOl0003oa];T00Go
a];T0_l00006olOEi005o`000?oBf=god]SMom;HgOl000001?oCf]d01?l0003ofMgJomWMf_oIgMX7
om[OfP04o`000?oLhM[og>7Jo`0000?ohnSE00?o0000onCZeOoTj]D01?oTj]D01?l0003ojo7<on_a
c?o[lL`5o`0000?olOJe1_l0000RoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0
3ooonfX003[ooo]Z0_l0000JoookJP04o`000?oaYg?olJMco`0003[ooo]Z00?o0000omk2_?oN`[`0
1OoN`[`2o`0000OogKZe0_l00005on?0/`03o`000?oU_Zoo000000?og[F^0_l00005onNlZ@03o`00
0?oO/JOogk6W00Gogk6W0_l00009om>QY003o`000?o7UZ?oaiJS00CoaiJS00?o0000ol6BY_o1TZH0
0oo1TZH00ol0003o/86Qok21X@0=ok21X@04o`000?nRN:?oXWRSo`0000koYGbV00?o0000ohETY?n5
I:@01On5I:@2o`0000KoS6^W00?o0000ofUFZOmYEZT01?mYEZT3o`0000?oHe^c00?o0000oeeG/omM
Ek<00_mMEk<00ol0003o>4RgocQ8]`02ocQ8]`?o00001_m6GLH2o`000006o`0j__m3Lm_o@g?Kod=c
fol0003o:6[K0_l00002oa1Qf003o`000?l@H]So000000?o00001?m=TNh00ol0003oAXk]odJ>k@03
odJ>k@03o`000?mj[??oNZcc00KoNZcc0ol00006ogJ[l`03o`000?nH_?7oV;ca017oV;ca00?o0000
ojo6jon_a^/03On_a^/2o`0000Go/<S/00?o0000ol3>i?o0c^@01?o0c^@2o`0000Co`LoU00?o0000
olKBi?o6d^@00_o6d^@00ol0003oamGTolOEi007olOEi003o`000?oBf=go000000Kodm[M00?o0000
omWMf_oJgmX01_oJgmX00ol0003og>7JomcQfP02omcQfP03o`000?oSj=Go000000Koi>[E0_l00003
on_ac003o`000?o[m<_ojoC;00Oo000000?oho:Go`000?l000009?oonfX00ol0003ooo]ZoookJP0f
oookJP03o`000?oonf[ooo]Z00kooo]Z000goookJP?o00007?oonfX01Ol0003olJMcoo6WLooaYg?o
000003Sooo]Z0_l00007omk2_003o`000?oJ_;_o000000GogKZe0_l00007on?0/`;o00000ooN]Jh2
omnn]P03o`000?oW_:WoikbY00;oikbY00?o0000omnaYooO/JL01_oO/JL2o`0000Sodj6T00?o0000
olNFXoo7UZ<01?o7UZ<00ol0003o`I:Vol6BYP03ol6BYP03o`000?n`PJ7o/86Q00go/86Q00?o0000
oj9hXol000003onUO:H00ol0003oQFBTohETY003ohETY0;o00002?n<JjL00ol0003oJEJYofUFZ@03
ofUFZ@04o`000?mjHjgoNV>]ogYS[@;o000000?oHe^co`000?mMEk<00_mMEk<00ol0003o>4RgocQ8
]`04ocQ8]`03ob=5_Ol0003oAUg600GoAUg60_l[G]42o`0000;o@g?K00Co0000obQZfolXJ]_o:6[K
0_l000000ol@HMSo0000o`000003oeZBk0Co000000?oCI7^o`000?m6S^d01?m6S^d00ol0003oNZcc
ogZ/l`02ogZ/l`?o00000omj[?<00ol0003oMZ_cogJ[l`04ogJ[l`03o`000?nH_?7oV;ca00OoV;ca
1_l00004oiRll003o`000?n_a^_o[lK[00Wo[lK[0ol00008ok38k003o`000?o0c^Co`<kT00;o`<kT
00?o0000ol7?iOo1cnD01?o1cnD00ol0003oa];TolKBi002o`0000[oamGT0_l00007om?Jg@03o`00
0?oJgm[of]oJ00Gof]oJ00?o0000omcQf_oLhMX00ooLhMX2o`0000Koi>[E00?o0000onG^e?l00000
0_o[lL`01Ol0003ojoC;on_dboo[m<_o000000?ok_Ri1_l0000UoookJP03o`000?oonf[ooo]Z03Go
oo]Z00?o0000oookJ_oonfX03_oonfX003Cooo]Z0ol0000OoookJP03o`000?oaYg?olJMc00;olJMc
00?o0000oookJ_oonfX0=?oonfX01?l0003oc/??olk3col00005omk2_004o`000?oJ_;_of[bkomZl
^`;o00000ooM^[D2o`0000Oohl2c00Go0000omji/_l0003og[F^o`000002omnn]P03o`000?oW_:Wo
ikbY00;oikbY00?o0000omnaYooO/JL01_oO/JL00ol0003oeJJWo`000002o`0000Codj6T00?o0000
olNFXoo7UZ<01Oo7UZ<00ol0003o`I:Vol6BYP02ol6BYP03o`000?n`PJ7o/86Q00ko/86Q0_l0000@
ojElYP04o`000?n5I:CoQFBTohETY0;o00002_n<JjL00ol0003oJEJYofUFZ@02ofUFZ@03o`000?mj
HjgoNV>]00CoNV>]0ol000000omMEk?o0000ocQ8]`07ocQ8]`03o`000?m6GLKoAUg600CoAUg600Co
0000ob]NdOl[G]7o00000_m3Lm/00ol0003o:6[KobQZf`03obQZf`;o000000?o46;Ho`000?mJT^`0
1_mJT^`4o`0000;oAXk]00?o0000ogZ/lol000000_l00007ogZ/l`03o`000?mfZo?oMZ_c00CoMZ_c
00Co0000oiRllOnH_?7oV;ca1Ol0000;oiRll003o`000?n_a^_o[lK[00Ko[lK[0_l0000<ok38k004
o`000?o0c^Co0000o`0000Oo`LoU00?o0000olKBi?l000002oo7eN@01?l0003obMSUolWHiOl00005
om?Jg@;o00001_oJgmX00ol0003og>7JomcQfP04omcQfP03o`000?oTj]Goi>[E00Coi>[E00Ko0000
onG^e?oUk]Co0000on_ac?l00004on_db`07o`000?o^n;Wok_Rio`000?o[nKCo0000on?bU`02o`00
02Kooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0=oookJP00<OoonfX3o`0002;o
oo]Z00?o0000oo6WLooaYg<00_oaYg<2o`0003Cooo]Z00?o0000olk3coo>`ll00_o>`ll00ol0003o
g/:lomk2_002omk2_003o`000?oJ_;_of[bk00?of[bk00Co0000omfj]Ol0003o00001ooS`;<01?l0
003og[Vbomji/_oN^K82o`0000?ogkjf00Co0000onNlZOoW_:Wo00002?oO/JL00ol0003oeJJWomFV
Y`03omFVY`?o000000?odj6To`000?o7UZ<01_o7UZ<00ol0003o`I:Vol6BYP02ol6BYP03o`000?n`
PJ7o/86Q00ko/86Q00?o0000ojElY_nUO:H04?nUO:H00ol0003oQFBTo`00000<oha[Y`05o`000?mY
EZWoJEJYofUFZOl000002OmjHjd00ol0003oGENco`000008ocQ8]`?o00001?m6GLH01Ol0003o:ekA
ob]NdOl[G]7o000000;o@g?K00?o0000obQZfolXJ]/00olXJ]/2o`000003oa1Rf?l0003oFY;/00Ko
FY;/00?o0000odj>k?m>S^`01?l00006ogZ/l`oo00004OnH_?000ol0003o[lK[ojo6j`03ojo6j`;o
00003on`b>`00ol0003o`LoUol7?i@08ol7?i@03o`000?o7eNCoamGT00SoamGT0_l00004olWHi@07
o`000?oCf]godm[Mom?JgOl0003oeMgNo`000005om[OfP03o`000?oLhM[og>7J00Cog>7J0_l00006
onCZe@?oiNkD0_l00004on_db`;o000000?ok_Rio`000?o[nK@00_l000000ooSlYOo0000o`00000W
oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX03?oonfX002kooo]Z0ol0000Uoook
JP03o`000?oaYg?olJMc00;olJMc00?o0000onjSM_l00000<_oonfX00ol0003oc/??olk3c`04olk3
c`04o`000?oN`[cog/:lo`0000Oof[bk0ol00007on?0/`05o`000?oN^K;og[Vbomji/_l000001OoO
_[H00ol0003oikbYo`000008omnaY`03o`000?oEYZOoeJJW00KoeJJW1?l00005olNFX`03o`000?o1
TZKo`I:V00;o`I:V00?o0000ok21XOn`PJ403_n`PJ400ol0003oYGbVojElYP0>ojElYP?o00003_n<
JjL01?l0003oJEJYofUFZOl0000:ogYS[@?o00002?lhB;L01?l0003oG6W7oeaYaol00003odIMaP03
o`000?l[G]7o:ekA00;o:ekA00?o0000od=cfol000001olXJ]/2o`0000SoFY;/0ol00002odj>k0Oo
00001OmoZo000ol0003oNJWaogVYl@04ogVYl@03o`000?nH_?3oV;c`01;oV;c`00?o0000ojo6jol0
00000_l0000=ok38k0?o00000_nabN`00ol0003o`LoUol7?i@05ol7?i@03o`000?o3dNGo000000Wo
amGT00?o0000olWHiOo9f>D01Oo9f>D00ol0003odm[Mo`000002omGMgP03o`000?oJgm[of]oJ00;o
f]oJ00?o0000omcQf_oLhMX01?oLhMX00ol0003ogNOKo`000005onCZe@CoiNkD00?o0000on_dboo[
m</00_o[m</01?l0003ojoO7o`000?l00002on_i]0Co0000:OoonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z00cooo]Z000[oookJP?o0000:?oonfX2o`0000?olJMc00Co0000onjSM_o^
XgKo0000;ooonfX2o`0000Soc/??00?o0000omk2_?l000001ooJ_;/2o`0000Oohl2c00Go0000omji
/_oN^K;og[Vbo`000006omnn]P?o00001ooO/JL00ol0003oeJJWomFVY`07omFVY`04o`000?o1U:So
`IBXol6DZ0Go000000GoaiJSo`000?o1TZKo`I:Vo`00000@ok21X@;o00002onUO:H5o`0000;oXWbY
00?o0000oha[Yon<JjL03On<JjL00omYEZWo0000ogYS[@0:ogYS[@04o`000?mLF[OoG5Zgo`0000Ko
>4Rg00?o0000oc];^OlkBkT00_mLJLL01?l0003oAUg6odIMa_l00005ob]Nd@?o00001_lXJ]/00ol0
003o:6[Ko`000004oeZBk0?o000000?oFY;/o`000?m>S^`01?m>S^`00ol0003oOj_`ogn[l008ogn[
l003o`000?miZO7oNJWa00CoNJWa00?o0000oiRll?nH_?004_nH_?000ol0003o/<S/ok38k00<ok38
k0;o00001_nabN`00ol0003o`LoUol7?i@03ol7?i@05o`000?o3dNGo`m7Uol?AiOl000001_o7eN@2
o`0000SobMSU0_l00004omGMgP04o`000?oJgm[of]oJo`0000Kog>7J00Co0000omgWfooMim_o0000
1?oTj]D00ol0003oiNkDonG^e002onG^e009o`000?o[m<_ojoC;on_dbol0003ojoO7o`000?o^n;Wo
000000;ojoVd00Co0000on?bUol0003o0000:OoonfX00ol0003ooo]ZoookJP0foookJP03o`000?oo
nf[ooo]Z00_ooo]Z000YoookJP;o0000:ooonfX00ol0003oki5;o`000002oo6WL`05o`000?o^XgKo
kZ=fonjSM_l00000;OoonfX01?l0003oc/CAolk4dOl00007olk3c`;o00001ooJ_;/01?l0003oek^n
o`000?l00005on?0/`03o`000?oN^K;og[Vb00;og[Vb00?o0000omnn]_oO_[H01OoO_[H01?l0003o
g[:Zo`000?l00005omnaY`03o`000?oEYZOoeJJW00KoeJJW00?o0000ol6DZ?o1U:P01oo1U:P3o`00
0003ol6BY_l0003o/86Q00ko/86Q00Co0000okB6Y?ndQZCo00001_nUO:H4o`0000OoXWbY00?o0000
oha[Yon<JjL03?n<JjL2o`0000coNV>]00Co0000oeaJ]omLF[OoG5Zg0_l00004ocQ8]`03o`000?lk
BkWo>d^i00CoG6W700?oAUg6o`000?l[G]401?l[G]42o`000003oeQjfOl0003o000000Go:6[K00?o
0000obQZfol000001Ol00002oeZBk003o`000?m>S^coCXk/00CoCXk/00?o0000ogn[l?moZo001omo
Zo000ol0003oNJWaogVYl@05ogVYl@03o`000?nH_?3oV;c`00[oV;c`1Ol00002oiVll003o`000?n`
b>co/<S/00Wo/<S/0ol00009ok79k005o`000?o1cnGo`LoUol7?iOl000001?o3dND00ol0003oamGT
olOEi003olOEi003o`000?o9f>GobMSU00OobMSU00Co0000olcLiOo<g>Go00000ooEgMh00ol0003o
f]oJo`000006omcQfP03o`000?oMim_ogNOK00;ogNOK00Co0000onCZeOoTj]Go00001?oUk]@2o`00
00?ojoC;0_o[mlL2o`0000?ojoVd1?l0000ZoookJP03o`000?oonf[ooo]Z03Cooo]Z0ol0000<oook
JP009_oonfX3o`0002gooo]Z00Ko0000onnABoo_TD_o0000oo6WLol00004onjSMP;o0000:_oonfX0
0ol0003oc/CAolk4d@02olk4d@03o`000?o>`looc/??00?oc/??00?o0000olZmc_l000001_oJ_;/0
1_l0003oek^nomNk__l0003oh/6fo`0000Cohl2c00Go0000omji/_oN^K;og[Vbo`000008omnn]P05
o`000?oN/Z[og[:ZomjbZ_l000000ooO/JL00ol0003oeJJWomFVY`07omFVY`03o`000?o1U:So`IBX
00So`IBX00?o0000ol6DZ?l000002?l00008ok21X@05o`000?ndQZCo]8JTo`000?nUO:H01Ol0000;
oj9lZ@03o`000?n<JjOoS6^W00[oS6^W0_l000000on=L:go0000ogYS[@0:ogYS[@;o00001OmLF[L2
o`0000;o>4Rg00?o0000oc];^OlkBkT01OmLJLL2o`0000Go:ekA00Co0000oeQjfOmHN]WoF7[I0_l0
0003obQZf`?o00001OmVTnT6o`0000CoCXk/00?o0000ogn[l?moZo001omoZo000ol0003oNJWaogVY
l@04ogVYl@03o`000?nH_?3oV;c`00KoV;c`1?l00008oiVll003o`000?n`b>co/<S/00Ko/<S/0_l0
000=ok79k003o`000?o1cnGo000000Ko`m7U00?o0000olOEi?o7eN@00_l00008olWHi@;o00001?o<
g>D01Ol0003oeMgNomGMg_l0003of]oJ00Kog>7J00?o0000omgWfooMim/00ooMim/00ol0003oi>[E
onCZe@04onG^e003o`000?oVkmCo000000;ojoC;00Co0000on_gaoo[mlOo00000oo[nK@01?l0003o
ho:GomW^SOl0000/oookJP03o`000?oonf[ooo]Z033ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z
00[ooo]Z000SoookJP?o0000<OoonfX00ol0003oki5;onnAB`02o`0000CokZ=f00?o0000on^PNOl0
0000:?oonfX00ol0003oc/CAolk4d@04olk4d@05o`000?o>`looc/??olk3col000000oo:_Lh00ol0
003of[bkomZl^`03omZl^`07o`000?oG^kko0000omS2a?l0003oh/6fo`000002on?0/`03o`000?oN
^K;og[Vb00;og[Vb00?o0000omnn]_oO_[H01OoO_[H00ol0003oe[:eo`000003omjbZP;o000000?o
gk6Wo`000?oEYZL01ooEYZL00ol0003o`IBXol6DZ00:ol6DZ003o`000?njT:_o^Y2[00Oo^Y2[3Ol0
000@oj9lZ@03o`000?n<JjOoS6^W00SoS6^W0_l00003ohe`[@03o`000?mjHjgoNV>]00SoNV>]00Co
0000ogI[^OmfJkWo00001_mLF[L2o`0000Co>d^i1?mLJLL2ocaNb`03o`000?l[G]7o:ekA00;o:ekA
00?o0000oeQjfOmHN]T00_mHN]T5o`0000;o:6[K00?o0000ofJCjOmVTnT01OmVTnT00ol0003oFHoY
oeV?j@06o`0000SoOj_`00?o0000ogVYlOmiZO401OmiZO400ol0003oV;c`oiRll005o`0000goVKc`
00?o0000ok38k?n`b>`00on`b>`2o`00013o/LW/00?o0000ol?AiOo3dND01Oo3dND00ol0003oamGT
o`000009olWHi@03o`000?o<g>Goc=cU00Goc=cU00?o0000omGMg_l000001_oLhMX00ol0003ogNOK
omgWf`04omgWf`03o`000?oTj]GoiNkD00?oiNkD00?o0000onK_e?l000000_o[m</01Ol0003ojoO7
on_gaoo[mlOo000000;ojoVd1Ol0000]oookJP03o`000?oonf[ooo]Z02cooo]Z0ol00005oookJP03
o`000?oonf[ooo]Z00[ooo]Z000PoookJP?o00004_oonfX00ol0003ooo]ZoookJP0OoookJP04o`00
0?o_TD_oki5;onnAB`;o00000oo^XgH00ol0003ojj1ion^PN@02o`0002Gooo]Z00?o0000olk4dOo>
a=401_o>a=400ol0003oc/??o`000005olZmcP07o`000?oJ_;_of[bkomZl^ol0003oek^no`000003
omS2a005o`000?oR`KKo0000on?0/ol000000ooN^K82o`0000Oogkjf00Co0000omJb]OoF/[Go0000
1?oN/ZX2o`0000SoeJJW00?o0000ol6DZ?o1U:P02_o1U:P00ol0003o^Y2[okZ@Z`0>okZ@Z`05o`00
0?ndR:Ko]8RVokB8Y_l000004_nRO:T00ol0003oS6^Woha[Y`05oha[Y`;o00001On=L:d00ol0003o
NV>]ogYS[@07ogYS[@05o`000?mfJkWoMV^iogI[^Ol000001omLF[L2o`0000?o>d^i1?mLJLL00ol0
003o?5k;ocaNb`02o`0000;o:ekA00?o0000oeQjfOl000000_l00003oeQjf@03o`000?lXJ]_o0000
00;o:6[K00?o0000ofJCjOmVTnT01OmVTnT00ol0003oFHoYoeV?j@04oeV?jACo00004onI_?000ol0
003o/<S/o`000002o`0000ko/LW/0ol00002ok?<k003o`000?o3dNGo`m7U00Go`m7U00?o0000olWH
iOo9f>D01oo9f>D00ol0003oc=cUolcLi@06olcLi@?o00001OoLhMX00ol0003ogNOKomgWf`05omgW
f`03o`000?oUk]CoiNkD00;oiNkD00Co0000onK_e?oVkmCo00000_o[m</3on_ga`;o00000_o[nK@2
o`000003omW^SOl0003ooo]Z02gooo]Z00?o0000oookJ_oonfX0:OoonfX3o`0000Sooo]Z00?o0000
oookJ_oonfX02_oonfX001gooo]Z0ol0000EoookJP;o00008?oonfX01ol0003oki5;onnABoo_TD_o
0000onf@D?l000000_o^XgH00ol0003ojj1ion^PN@02on^PN@03o`000?oonf[ooo]Z027ooo]Z00?o
0000olk4dOo>a=402?o>a=42o`0000Gob[g>00Co0000omZl^ooJ_;_of[bk0_l00005omS2a004o`00
0?oR`KKo0000o`0000?og[Vb00?o0000on70]ol000001OoO_[H01Ol0003oe[:eomJb]OoF/[Go0000
00Cog[:Z00Co0000omF/[ol0003o00001_oEYZL00ol0003o`IBXol6DZ009ol6DZ0;o00003onjT:/0
0ol0003o]8RVokB8YP02okB8YP03o`000?nRO:WoXWbY013oXWbY00?o0000oha[Yon<JjL00on<JjL2
o`0000SoSG2]00?o0000ogYS[OmjHjd01OmjHjd00ol0003oMV^iogI[^@02ogI[^@03o`000?mLF[Oo
G5Zg00GoG5Zg0_m_IkT00ol0003o>d^ioc];^@03oeaYa`03o`000?llG/_o?5k;00?o?5k;1?l00008
oeQjf@?o000000?o:6[Ko`000?mVTnT01OmVTnT00ol0003oFHoYoeV?j@05oeV?j@03o`000?n4Znko
Q:_^00KoQ:_^00?o0000ogfYl?mmZO001OmmZO000ol0003oVKc`oiVll00CoiVll003o`000?nabNco
/LW/00go/LW/0_l00006ok?<k004o`000?o3dNGo`m7Uol?Ai@;o000000?oa=?Uo`000?o9f>D01_o9
f>D2o`0000Soc=cU00?o0000olgIh_o=fN800_l00003omcQfP03o`000?oMim_ogNOK00CogNOK00?o
0000omoZfol000000ooUk]@01_l0003oi^oDonK_e?oVkmCo0000on_db`?ojoO700Co0000on[iaol0
003ojoVd0ol000000ooIkXgo0000oookJP0^oookJP03o`000?oonf[ooo]Z02Gooo]Z0ol0000;oook
JP03o`000?oonf[ooo]Z00[ooo]Z000KoookJP;o00006?oonfX00ol0003ol:Ymo`00000OoookJP;o
00000_o_TD/01_l0003okI1@onf@D?l0003okZ=fo`0000Gojj1i0_l0000PoookJP03o`000?o>a=7o
c/CA00Ooc/CA00Co0000ol^ocoo;_loobko?0_l00004olZmcP04o`000?oJ_;_o0000o`0000Oof<;4
00Ko0000omfj]OoM^[Go0000omji/_l00003on70]`;o00000_oO_[H00ol0003oe[:eomJb]@03omJb
]@04o`000?oN/Z[og[:Zo`0000CoeJb_0_l00003omFVY`03o`000?o1U:So`IBX00[o`IBX00?o0000
ol:EZ?l000003OnjT:/00ol0003o]8RVokB8YP04okB8YP03o`000?nRO:WoXWbY00ooXWbY00Co0000
oha[Yon<JjOoS6^W0_l0000:ohe`[@03o`000?mjHjgoNV>]00CoNV>]00?o0000ogI[^OmfJkT01?mf
JkT00ol0003oG5ZgoeaJ]`03oeaJ]`04o`000?m_IkWoKfNiofmW^@;o000000Co>d^ioeaYaomLJLOo
00000ollG//3o`000004ocaNbol[G]7o0000o`0000OoF7[I00?o0000od5bfom1L]/00ol00005ofJC
j@03o`000?mISnWoFHoY00KoFHoY00?o0000ohB[k_n4Znh01_n4Znh00ol0003oOJW`ogfYl005ogfY
l003o`000?nI_?3oVKc`00_oVKc`1Ol00002oibnl003o`000?nabNco/LW/00[o/LW/0ol00009ok?<
k003o`000?o3dNGo000000Coa=?U00?o0000olWHiOo9f>D00oo9f>D00ol0003oc=cUolcLi@06olcL
i@;o00001?o=fN82o`000003omcQf_l0003ogNOK00GogNOK00Co0000omoZfooOj]_o00000ooUk]@0
1Ol0003oi^oDonK_e?oVkmCo000000?ojoO700So0000on[iaol0003ojoVdo`000?oWnJoo0000omW^
S@;o0000<?oonfX00ol0003ooo]ZoookJP0PoookJPCo00003ooonfX00ol0003ooo]ZoookJP09oook
JP006?oonfX3o`0001[ooo]Z00Co0000oo2ZOOo`ZWgo00007_oonfX01Ol0003ogVd?o`000?o_TD_o
000000?okI1@0_l00005on^PN@03o`000?oXWG[o000001kooo]Z00?o0000olk4dOo>a=401oo>a=40
0ol0003obko?ol^oc`04ol^oc`03o`000?o:_Lkob[g>00;ob[g>00?o0000omNk__l000001ooH`/@0
1?l0003ogKZeomfj]OoM^[D2o`0000GohL2g00?o0000omnn]_l000001OoF/[D01?l0003og[:Zomjb
Z_l00006omF/[`;o000000?oeJJWo`000?o1U:P02_o1U:P01?l0003o`YFXol:EZ?l0000<okZ@Z`03
o`000?ndR:Ko]8RV00Go]8RV00?o0000oj9lZOnRO:T03onRO:T01?l0003oS6^Wo`000?l00005ohe`
[@Wo00001OmjHjd7ogI[^@03o`000?mLF[OoG5Zg00;oG5Zg00?o0000ofmW^Om_IkT01?m_IkT00ol0
003oG6W7oeaYa`04o`0000Go?5k;0_l00007oeQjf@03o`000?m1L]_o@G;K00?o@G;K1?l00002ofJC
j@03o`000?mISnWoFHoY00KoFHoY00?o0000ohB[k_n4Znh01On4Znh00ol0003oOJW`ogfYl006ogfY
l003o`000?nI_?3oVKc`00KoVKc`1?l00008oibnl003o`000?nabNco/LW/00Ko/LW/0ol0000=ok?<
k003o`000?o4dnGoa=?U00?oa=?U00Co0000olWHiOo9f>GobMSU0_l00008olcLi@03o`000?o=fN;o
cMWR00CocMWR00Co0000om?Qh_l0003o00001OoMim/01Ol0003ogn[KomoZfooOj]_o000000;oiNkD
00?o0000onK_e?oVkm@00_oVkm@01?l0003ojoO7on_gaol00002on[ia`07o`000?o[nKCo0000onOi
[ol0003ofNj=o`00000aoookJP03o`000?oonf[ooo]Z01gooo]Z0ol0000CoookJP03o`000?oonf[o
oo]Z00Wooo]Z000EoookJP?o00007OoonfX01Ol0003ol:Ymoo2ZOOo`ZWgo000001kooo]Z0ol00000
0oo_TD_o0000onf@D002onf@D0;o00001?o[X7T00ol0003oj9ejonRMNP02o`0001_ooo]Z00?o0000
olk4dOo>a=401oo>a=400ol0003obko?ol^oc`06ol^oc`;o000000Cob[g>o`000?l0003o00001ooH
`/@00ol0003od[[2o`000002omfj]@03o`000?oQ`;OohL2g00GohL2g0_l00006omJb]@03o`000?oN
/Z[o000000SoeJb_1?l00008ol6DZ005o`000?o2UJSo`YFXol:EZ?l000002onjT:/00ol0003o]8RV
okB8YP06okB8YP03o`000?nRO:WoXWbY00ooXWbY2Ol00007ohea[`04o`000?mgI[;o0000o`0000;o
NV>]2?mfJkT00ol0003oG5ZgoeaJ]`02oeaJ]`03o`000?m_IkWoKfNi00GoKfNi0ol00008ocaNb`04
o`000?lmGlco0000o`0000GoF7[I00?o0000od5bfom1L]/00om1L]/01?l0003oLIKVog6Fi_maU^H6
o`0000GoFHoY00?o0000ohB[k_n4Znh01_n4Znh00ol0003oOJW`ogfYl006ogfYl003o`000?nI_?3o
VKc`00Go00003OnL__000ol0003o/LW/ok79k003ok79k0;o00003Oncc>`2o`000003okG>kOl0003o
a=?U00Coa=?U00Co0000olWHiOo9f>Go00002Oo<g>D00ol0003ocMWRolgIhP05olgIhP;o00000_oE
iN801Ol0003ogNOKomgWfooMim_o000000Cogn[K00?o0000onG^e?l000001?oVkm@2o`0000;ojoO7
00?o0000on[iaooZnLL00_l000000ooWnJoo0000o`000002o`0003;ooo]Z00?o0000oookJ_oonfX0
6OoonfX3o`0001Kooo]Z00?o0000oookJ_oonfX02OoonfX001;ooo]Z0ol0000PoookJP03o`000?o`
ZWgol:Ym00;ol:Ym0_l0000LoookJP03o`000?o1@P3o000000;o00000oo]T5000ol0003ojXiFo`00
0003on^PN@03o`000?oXWG[oj9ej00;oj9ej00?o0000oookJ_oonfX05ooonfX00ol0003oc/CAolk4
d@07olk4d@03o`000?o;_loobko?00Wobko?0ol00007omS2a004o`000?oB^/;od[[2om:j`P;o0000
2?oQ`;L00ol0003of[Neo`000006omJb]@03o`000?oE[:ooeJb_00OoeJb_00Co0000olfQZoo=XJ_o
cJ6[1Ol00003ol6DZ005o`000?o2UJSo`YFXol:EZ?l000002onjT:/00ol0003o]8RVokB8YP06okB8
YP03o`000?nRO:WoXWbY00_oXWbY1Ol0000?ohea[`06o`000?mgI[;oMfJbo`000?mjHjgo00002Omf
JkT3oeaJ]`03o`000?m_IkWoKfNi00?oKfNi0ol000000om_IkWo0000o`000008ocaNb`04o`000?lm
GlcoJ87HofR1f0?o00000omHN]T00ol0003o@G;Kod5bf`03od5bf`03o`000?maU^KoLIKV00;oLIKV
00Co0000ofJ@i_mVT>KoIY3V1Ol000000omISnWo0000ohB[kP06ohB[kP03o`000?mmZO3oOJW`00?o
OJW`1_l0000Coibnl003o`000?nabNco000000;o00003Oncc>`2o`0000Co]Lk]00?o0000olCCiOo4
dnD00oo4dnD2o`0000Soc=cU0_l00008olgIhP03o`000?oEiN;oeNGR00;oeNGR00?o0000omgWfol0
00001OoOj]/2o`0000Coi^oD00Go0000onKedol0003ojoO7o`000003on[ia`03o`000?oWnJoo0000
00Co0000<ooonfX00ol0003ooo]ZoookJP0EoookJP?o00006OoonfX00ol0003ooo]ZoookJP09oook
JP003ooonfX3o`0002?ooo]Z00?o0000oo2ZOOo`ZWd00_o`ZWd00ol0003okZMoo`00000LoookJP03
o`000?o1@P3o000000;o00000_o]T5001?l0003ojXiFonZ>E_l00002on^PN@03o`000?oXWG[oj9ej
00?oj9ej0_l0000EoookJP;o00002Oo>a=400ol0003obko?ol^oc`09ol^oc`;ob/;B0_l00006omS2
a003o`000?oB^/;od[[200?od[[200?o0000on70]ooQ`;L01OoQ`;L01Ol0003of[NeomZg]OoJ]kGo
000000Goe[:e00?o0000omF/[ooE[:l01_oE[:l00ol0003ocJ6[olfQZ`07olfQZ`Go00000_o2UJP0
0ol0003o^Y2[okZ@Z`08okZ@Z`03o`000?ndR:Ko]8RV00Oo]8RV00?o0000oj9lZOnRO:T01_nRO:T7
o`0000;oYH>_00?o0000ohea[on=LJl03_n=LJl2o`0000?oN6Rc0ol00006ogI[^@?oG5Zg00?o0000
ofmW^Om_IkT00ol00004ofmW^@;oKGC90ol00005ocaNb`03o`000?lmGlco?Eo<00CoJ87H0_l00000
0omHN]Wo0000od5bf`04od5bf`03o`000?maU^KoLIKV00;oLIKV00?o0000ofJ@i_mVT>H01_mVT>H?
o`0000CoPZW]00?o0000oibnl?nL__004onL__000ol0003o/lc/ok?<k00<ok?<k0;o00001onec^d0
1?l0003oa=?UolCCiOo4dnD2o`0000Soc=cU00?o0000olgIh_o=fN801oo=fN800oo>h>Go0000omGU
hP03omGUhP;o00001_oOj]/00ol0003oi^oDonK_e002onK_e005o`000?oVmM?o0000on_gaol00000
1?oZnLL00ol0003oioV_o`000003o`0003Gooo]Z00?o0000oookJ_oonfX04OoonfX3o`0001cooo]Z
00?o0000oookJ_oonfX02OoonfX000cooo]Z0ol0000VoookJP03o`000?o`ZWgol:Ym00;ol:Ym00?o
0000onjWOoo^Ygl00_l0000KoookJP?o000000GogfhJo`000?o]T53okI1@o`000002onZ>EP03o`00
0?o[X7Wo000000Goj9ej00?o0000onFJO?l000004OoonfX3o`0000;o]<;T00?o0000olk4dOo>a=40
1Oo>a=400ol0003obko?ol^oc`08ol^oc`07o`000?o:`];ob/;Bol[2d_l0003ofLC5o`000005omS2
a003o`000?oB^/;od[[200;od[[200?o0000on70]ooQ`;L01OoQ`;L00ol0003of[NeomZg]@03omZg
]@07o`000?oF/[Goe[:eomJb]Ol0003odJ^bo`000006omF/[`03o`000?o=XJ_ocJ6[00[ocJ6[00?o
0000okbB[?nlTZ`01?l00008okZ@Z`03o`000?ndR:Ko]8RV00Wo]8RV00?o0000oj9lZOnRO:T01Ol0
0004oj9nZ`03o`000?nUPjooYH>_00?oYH>_00?o0000ohea[on=LJl03?n=LJl2o`0000OoN6Rc0ol0
0003ogI[^@03o`000?mLF[Oo000000?o00001om_IkT00omTK/SoKGC9ofedb@02ofedb@;o00000oll
G//01?l0003o?Eo<oceOc?l00006ofR1f0?o00001?m1L]/01Ol0003oLIKVog6Fi_maU^Ko000000[o
IY3V00?o0000ohZ[k?n:Zn`01On:Zn`00ol0003oPZW]oh:Yk@07oh:Yk@03o`000?nL__3oW;k`00go
W;k`0ol00002oijol003o`000?ncc>co/lc/00[o/lc/0_l0000:okG>k@05o`000?o4dnGo0000olKE
iOl000001_o<g>D2o`0000SocMWR00Co0000olkPiOo>h>Go00000ooEiN801?l0003of>[QomSZhOl0
0003omoZf`03o`000?oPk][o000000?oi^oD00?o0000onKedooVmM<00_l00004on[ia`?o000000Co
hoVYo`000?l0003o0000=OoonfX00ol0003ooo]ZoookJP0=oookJPCo00007ooonfX00ol0003ooo]Z
oookJP09oookJP002ooonfX2o`0002Sooo]Z0_l00003oo2ZO@03o`000?o^YgookZMo00;okZMo00?o
0000oookJ_oonfX06_oonfX4o`000003onf@D?l0003ojXiF00;ojXiF0_l00005onRMNP03o`000?oU
VWcoiIYl00;o00003OoonfX3o`0000Go]<;T00?o0000olk4dOo>a=400oo>a=400ol0003obko?ol^o
c`08ol^oc`05o`000?o:`];ob/;Bol[2d_l000000ooIa<D01Ol0003of<;4omS2a?oH`/Co000000Go
d[[200?o0000on70]ooQ`;L01OoQ`;L00ol0003of[NeomZg]@04omZg]@03o`000?oF/[Go000000;o
dJ^b00?o0000omF/[ooE[:l01?oE[:l00ol0003ocJ6[olfQZ`09olfQZ`03o`000?nlTZco_9:/00Co
_9:/6?l00007oj9nZ`;o00001_nUPjl00ol0003oSG6_ohea[`0:ohea[`;o000000?oTWF`o`000?mh
J;<02OmhJ;<6o`0000WoKfNi00?o0000ofA^b?m]M<T01Om]M<T2o`000003ocaNbol0003o?Eo<00;o
?Eo<00?o0000ofR1f?mXPMP00omXPMP00ol0003oFhOSoe^7h`03o`0000;o@G;K00Go0000og6Fi_ma
U^KoLIKVo`00000:ofJ@iP03o`000?n:ZncoRZ_/00GoRZ_/00?o0000oh:YkOn2ZNd01on2ZNd00ol0
003oW;k`oibnl008oibnl0Co00001_nN_o000ol0003o/lc/ok?<k007ok?<k0;o00003Onec^d01?l0
003oa]GUolKEiOl00005olcLi@03o`000?o=fN;ocMWR00KocMWR0_l00003olkPi@04o`000?oEiN;o
eNGRo`0000Cof>[Q00?o0000omoZfol000000_oPk]X01?l0003oi^oDonK_e?l00003onKed`03o`00
0?oZnLOoj_W700;oj_W70_l000000ooWnJoo0000o`000002o`0003Oooo]Z00?o0000oookJ_oonfX0
2OoonfX3o`0002?ooo]Z00?o0000oookJ_oonfX02OoonfX000_ooo]Z00?o0000oookJ_l000009ooo
nfX00ol0003olJ5[o`000002oo2ZO@03o`000?o^YgookZMo00?okZMo00?o0000oookJ_oonfX06_oo
nfX5o`0000CojXiF0_l00004onRMNP05o`000?oUVWcoiIYlo`000?oRUW/00_l00009oookJP;o0000
0ond`^@00ol0003o]<;TokC2i003okC2i005o`000?o>a=7oc/CAolk4dOl000002Oo;_ll2o`0000?o
b/;B00?o0000omW4aOoIa<D00ooIa<D00ol0003of<;4o`000005om:j`P;o00001_oQ`;L00ol0003o
f[NeomZg]@06omZg]@;o00000_oAZk800ol0003oeJb_omF/[`03omF/[`03o`000?o=XJ_ocJ6[00Wo
cJ6[00?o0000okbB[?nlTZ`01OnlTZ`00ol0003o^Y6]okZA[@05okZA[@03o`000?neT;3o]I2`00[o
]I2`00?o0000oj9nZonROZ/01OnROZ/2o`0000SoYH>_00?o0000ohea[on=LJl02?n=LJl2o`0000?o
TWF`00?o0000ogQX/omhJ;<02?mhJ;<6o`0000WoKfNi00?o0000ofA^b?l000002?m]M<T2o`0000?o
?Eo<00?o0000ofR1f?mXPMP00_mXPMP00ol0003oFhOSoe^7h`03oe^7h`?o00000omaU^H00ol0003o
IY3VofJ@iP09ofJ@iP03o`000?n:ZncoRZ_/00CoRZ_/00?o0000oh:YkOn2ZNd02?n2ZNd00ol0003o
W;k`oibnl004oibnl0?o00002onN_o000ol0003o/lc/ok?<k004ok?<k0;o00003?nec^d2o`0000;o
^=;]0_o6eND00ol0003oc=cUolcLi@02olcLi@03o`000?o=fN;ocMWR00KocMWR00?o0000olkPiOo>
h>D00oo>h>D00ol0003oeNGRo`000006omSZh@;o000000Goh>kJo`000?oVkmCoi^oDo`000004onKe
d`06o`000?oZnLOoj_W7on[iaol0003oioc20_l000001?oSnJWo0000o`000?l0000hoookJP03o`00
0?oonf[ooo]Z00Gooo]Z0ol0000VoookJP03o`000?oonf[ooo]Z00Wooo]Z000;oookJP04o`000?oo
nf[ooo]Zo`0000Wooo]Z00?o0000oookJ_oonfX06_oonfX01_l0003olJ5[oo6QJol0003ol:Ymo`00
00GokZMo0_l0000LoookJP03o`0RW_l0003o000000;o00000ooZSUH00ol0003oihaKo`000003onRM
NP03o`000?oUVWco000000CohYIk0_l00004oookJP?o00001_nd`^@00ol0003o]<;TokC2i003okC2
i003o`000?o>a=7o000000Wobko?00?o0000ol[2d_o:`]800_o:`]800ol0003ofLC5omW4a@05omW4
a@;o00001OoB^/800ol0003ohL:io`000004on70]`03o`000?oJ]kGof[Ne00Oof[Ne00?o0000oljZ
]Ol000000ol00004omF/[`03o`000?o=XJ_ocJ6[00WocJ6[00?o0000okbB[?nlTZ`01OnlTZ`00ol0
003o^Y6]okZA[@04okZA[@03o`000?neT;3o]I2`00_o]I2`00?o0000oj9nZonROZ/01?nROZ/00ol0
003oYH>_ojF3[`09ojF3[`SoSG6_0_l00006oi9e/003o`000?mhJ;?oN6Rc00CoN6Rc0ol000001_mh
J;?o0000oh=`]?n3L;Co0000ofaY_@;o00001om_IkT3ofA^b003o`000?m]M<WoKGC900GoKGC90_mP
O=L2o`000003oceOc?l0003oJ87H00?oJ87H00?o0000oe^7homKQn<01_mKQn<8o`0000OoIY3V00?o
0000ohZ[k?n:Zn`01?n:Zn`00ol0003oPZW]oh:Yk@09oh:Yk@03o`000?nL__3oW;k`00?o00003_nN
_o000ol0003o/lc/ok?<k002ok?<k0;o00003?nec^d2o`0000Go^=;]0_o6eND01?l0003oc=cUo`00
0?l00007olgIhP;o00001_o>h>D2o`0000Kof>[Q00?o0000omS[hOoHjn400_l000000ooVkmCo0000
onKed`03onKed`;o00000_oZnLL01?l0003oioc2onOl`_l00002on?iZ@;o0000>OoonfX00ol0003o
oo]ZoookJP02oookJP?o0000:OoonfX00ol0003ooo]ZoookJP09oookJP002ooonfX01Ol0003ooo]Z
oookJ_oonf[o000000Sooo]Z0_l0000KoookJP04o`000?oaXF_olJ5[oo6QJ`;o00001Oo^Ygl00ol0
003ojjB0o`00000LoookJP04o`0RW_l0003o0000o`0000?ojXiF00?o0000onN<FooWS5/00_l00000
0ooXWG[o0000o`000005on:FN`03o`000?oNTggo000000?o00002_nd`^@00ol0003o]<;TokC2i002
okC2i0;o00002Oo;_ll00ol0003ob/;Bol[2dP02ol[2dP03o`000?oIa<GofLC500KofLC500?o0000
omJo`ol000000ooB^/801Ol0003ohL:ion72^OoQ`[Wo000000?ohL2g00?o0000omZg]OoJ]kD01_oJ
]kD00ol0003ocZZeoljZ]@03oljZ]@?o000000?oeJb_o`000?o=XJ/02_o=XJ/00ol0003o_9:/okbB
[007okbB[003o`000?njTJgo^Y6]00;o^Y6]00?o0000okF@/?neT;003?neT;000ol0003oXWj[oj9n
Z`02oj9nZ`;o00003?nUPjl6ohea[`;o00002?nBMK001?l0003oN6RcogQX/omhJ;<3o`0000?oN6Rc
00Go0000oh=`]?n3L;CoPg2do`000003ofaY_@?o00000om_IkT01Ol0003oI6k8ofA^b?mTK/So0000
00KoKGC900?o0000of1leomPO=L00_mPO=L00ol0003o?Eo<o`000003ofR1f003o`000?mKQn?oFhOS
00KoFhOS00Co0000og>Di?mcU>Co00001?mbU>@7o`000003ofJ@i_l0003oRZ_/00GoRZ_/00?o0000
oh:YkOn2ZNd00on2ZNd8o`0001;oW[o`00Co0000ok?<k?l0003o00003?nec^d2o`0000So^=;]00?o
a]GUo`000?l000002?o=fN800ol0003oc^3UolkPi@06olkPi@03o`000?oHj^7of>[Q00Cof>[Q00?o
0000omS[hOoHjn400_oHjn43o`0000?oi_GC0_l00002on[ia`03o`000?oWo<;oioc200;o000000Co
hoVYo`000?l0003o0000>_oonfX4o`0002gooo]Z00?o0000oookJ_oonfX02?oonfX000_ooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?o_Zh;o000001[ooo]Z00?o
0000oo6QJooaXF/00_oaXF/2o`0000CokZMo00Co0000on^TP?o[Y83o00007?oonfX01?l08Yko0000
o`000?l00003onZ>EP04o`000?oWS5_oihaKonN<F`?o00001OoRUW/01?l0003ogY=mo`000?l0000=
okC2i006o`000?nd`^Co0000o`000?na_^Co00001oo;_ll2o`0000Cob/;B00?o0000omW4aOoIa<D0
1_oIa<D01ol0003oe[o3omJo`ooF_l?o0000om:j`_l000001OoQ`[T00ol0003ohL2go`000009omZg
]@03o`000?o>Z[GocZZe00?ocZZe00?o0000omB]/?oD[K000ol00009olfQZ`03o`000?nlTZco_9:/
00So_9:/00Go0000okZA[OnjTJgo^Y6]o`00000@okF@/004o`000?nROZ_o0000o`0000koYH>_00Co
0000ohea[on=LJooSG6_0_l0000:oi9e/0Co00001OmhJ;<00ol0003oPg2doh=`]003oh=`]003o`00
0?m/JKgoK6Vm00?oK6Vm0_l000000om_IkWo0000ofA^b002ofA^b003o`000?m]M<WoKGC900CoKGC9
00?o0000of1leomPO=L00omPO=L2o`0000?oJ87H00?o0000oe^7homKQn<01omKQn<00ol0003oLiCT
o`00000;og:Di0ko00001_n8ZN/00ol0003oW[o`oijol00Boijol003o`000?nec^go]Lk]00Wo]Lk]
0ol0000;okSBk@03o`000?o=fN;ocMWR00KocMWR00?o0000olkPiOo>h>D01_o>h>D00oo@hnGo0000
omSZh@04omSZh@03o`000?oHjn7of>_Q00?of>_Q00?o0000on3ffOoPm]T00_l000001OoVmM?o0000
o`000?oZnLOo000000?oioc21Ol0000hoookJPGo0000;ooonfX00ol0003ooo]ZoookJP08oookJP00
2_oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Cooo]Z00Co0000onn[P_o_Zh;o
00006OoonfX00ol0003olJ5[oo6QJ`02oo6QJ`03o`000?o^WVgo000000;okZMo00?o0000on^TP?o[
Y8000_o[Y8000ol0003ooo]ZoookJP0KoookJPco00000ooRUW/4o`00013o]<;T0_l00003ok6ni003
o`000?o;_loobko?00?obko?00?o0000ol[2d_o:`]800oo:`]800ol0003ofLC5omW4a@06omW4a@03
o`000?oF_l?oe[o300?oe[o30_l00006on72^@;o00002?oJ]kD00ol0003ocZZeoljZ]@05oljZ]@03
o`000?oD[K3o000000;ocJNb0ol00006olfQZ`03o`000?nlTZco_9:/00So_9:/00Co0000okZA[Onj
TJgo00004OneT;02o`00017oYH>_00?oSG6_o`000?l000002_nBMK04o`0000GoN6Rc0_l00006oh=`
]003o`000?m/JKgoK6Vm00GoK6Vm00?oKfNio`000?mTK/P00omTK/P00ol0003oKGC9ofedb@03ofed
b@03o`000?mPO=OoH7cG00GoH7cG1_l00008oe^7h`;o00003OmbU>@00ol0003oSjcZohn/jP03ohn/
jP03o`000?n8ZN_oR:W[00[oR:W[00?o0000oijol?nN_o002onN_o04o`0000CoX/;`00?o0000okG>
kOnec^d01Onec^d2o`0000_o^=;]0_l000000onkeNgo0000o`000005olgIhP;o00001oo>h>D01?l0
003od>?Uom3SiOl00004omSZh@03o`000?oHjn7of>_Q00?of>_Q00?of^cOo`000?oPm]T00ooPm]T9
o`000004omcj[Ol0003o0000o`0003Gooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02cooo]Z00?o
0000oookJ_oonfX02?oonfX000[ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP02
oookJP03o`000?o_Zh;okj^200;okj^200?o0000oookJ_oonfX05_oonfX2o`0000?olJ5[00Ko0000
onjNKOo^WVgo0000onjWOol00005on^TP0;o00007?oonfX00ol0003o0FcLo`5/g00;o`0000CoQkGc
00?o0000okC2i?nd`^@02Ond`^@3o`0000?o/l3S00Go0000ok6ni?na_^Co/KkTo`000003ol^oc`03
o`000?o:`];ob/;B00?ob/;B00?o0000omW4aOoIa<D01_oIa<D00ol0003oe[o3omJo``04omJo``03
o`000?oQ`[WohL:i00GohL:i00?o0000ombj]ol000001_oJ]kD00ol0003ocZZeoljZ]@06oljZ]@;o
00001_o=Yk83o`0000;ocJ6[00?o0000okbB[?nlTZ`02_nlTZ`2o`0001;o]I2`00?o0000ojF3[onU
Pjl03_nUPjl3o`0000WoTWF`0ol00003oi9e/003o`000?mhJ;?oN6Rc00;oN6Rc00?o0000oh=`]?n3
L;@01_n3L;@00ol0003oK6VmofaY_@04ofaY_@03o`000?mjL[koNW:n00?o000000?oI6k8o`000?m]
M<T00om]M<T00ol0003oH7cGof1le`06of1le`04o`000?mYPMSoJH7Ho`0000;oM8OH0ol00005oe^7
h`;o00003_mbU>@00ol0003oSjcZohn/jP02ohn/jP03o`000?n8ZN_oR:W[00_oR:W[00?o0000oijo
l?nN_o001OnN_o05o`0000WoX/;`00?o0000okG>kOnec^d00_nec^d2o`0000_o^=;]0_l00003ok_E
k@03o`000?o0en_o000000?ocMWR00?o0000olkPiOo>h>D01_o>h>D01Ol0003od>?Uom3SiOo@hnGo
000000?of>[Q00?o0000omS[hOoHjn400ooHjn42om[/g`05o`000?oPm]Woh?KIon3ffOl000000_oO
n=T2o`0000?oh_g700?o0000omcj[Ol000000_l0000coookJP?o00002?oonfX00ol0003ooo]Zoook
JP0/oookJP03o`000?oonf[ooo]Z00Sooo]Z000:oookJP03o`000?oonf[ooo]Z00Kooo]Z00Go0000
oookJ_oonf[ooo]Zo`000005onn[PP;o00005_oonfX00ol0003okiABo`000002oo6QJ`04o`000?o^
WVgokYi]onjNK@;o00001Oo[Y8000ol0003oj::2o`00000LoookJP04o`000?l1K=co0FcLo`0000So
MZof00?o0000ohNelon7]O<00on7]O<00ol0003o]<;TokC2i006okC2i0;o00001onc`><2o`0000;o
/KkT00?o0000ol^ocol000001Oo:`]800ol0003ofLC5omW4a@06omW4a@03o`000?oF_l?oe[o300Co
e[o300?o0000on72^OoQ`[T01OoQ`[T01?l0003og;Zgombj]ooL^[L2o`0000Cof[Ne00?o0000oljZ
]Oo>Z[D01oo>Z[D00ol0003ocJNbolfW/P07olfW/PCo00002onlTZ`00ol0003o]I2`okF@/00@okF@
/0;o00002onUPjl5o`0000;oXX:a00?o0000oi9e/?nBMK001?nBMK03o`0000KoTWF`00Go0000ogQX
/omhJ;?oN6Rco`00000:oh=`]003o`000?m/JKgoK6Vm00;oK6Vm00?o0000ogYb__mjL[h01?mjL[h2
o`0000CoKGC900?o0000of1leomPO=L01omPO=L00ol0003oJH7Ho`000005ogB7f0?o00000omKQn<0
0ol0003oLYCTog:Di00=og:Di005o`000?n?[>[oSjcZohn/j_l000003_n8ZN/00ol0003oW[o`oijo
l004o`0000ooX/;`00Co0000okG>kOl0003o00002onhd^d2o`0000Go^mG]00Ko0000ol3Gjoo0en_o
0000olgIh_l00007olkPi@;o00001?o@hnD01?l0003of>[QomSZhOl00005omS[h@?of^cO00Co0000
on3ffOoPm]Wo00000ooOn=T02?l0003oh_g7on;maooRoLOo0000omcj[Ol0003odoNT0_l0000`oook
JP?o00003?oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Sooo]Z000:oookJP03
o`000?oonf[ooo]Z00Oooo]Z00Co0000oookJ_oonf[o00001Oo_Zh800ol0003okJV3o`00000Eoook
JP06o`000?o_U5;okiABo`000?oaXF_o00001?o^WVd2o`0000CojjB000?o0000onRRP_oXXX800_l0
000KoookJP04o`000?l1K=co0FcLo`0000SoMZof00?o0000ohNelon7]O<00on7]O<00ol0003o]<;T
okC2i003okC2i0;o00002onc`><01?l0003o/KkTo`000?l00006ol[2dP;o00001ooIa<D00ol0003o
e[o3omJo``04omJo``03o`000?oQ`[WohL:i00GohL:i00?o0000ombj]ooL^[L00ooL^[L01?l0003o
f[NeomZg]Ol0000:oljZ]@03o`000?o=Yk;ocJNb00SocJNb00?o0000olNN[oo7WZl01?l00007okbB
[003o`000?neT;3o]I2`00oo]I2`00?o0000ok6;[Ol000001onUPjl4o`0000OoXX:a00Co0000oi9e
/?nBMK3oTWF`0ol00009oi9e/004o`000?mhJ;?oN6Rco`0000_oPg2d00Go0000ofaY_Om/JKgoK6Vm
o`000009ogYb_P;o00000_m]M<T00ol0003oH7cGof1le`07of1le`;o00002OmdQmP5o`0000ooLYCT
00Co0000ohn/j_n?[>[o00002on8ZN/6o`0001CoX/;`00?o0000okSBkOnhd^d02Onhd^d2o`0000Oo
^mG]00?o0000ol3Gjoo0en/00_l00007olkPi@03o`000?o@hnGod>?U00Cod>?U00?o0000omSZhOl0
00001OoHjn43om[/g`04o`000?oPm]Woh?KIo`0000CogoSI00?o0000on;maooRoLL00ol000000ooC
mjCo0000o`00000]oookJPCo00004?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z
00Sooo]Z000:oookJP03o`000?oonf[ooo]Z00Sooo]Z00Co0000oookJ_l0003o00001?o_Zh801?l0
003okJV3onfYPol0000EoookJP03o`000?o_U5;okiAB00;o00001?o^WVd00ol0003ok9a`o`000003
on^TP003o`000?oXXX;oj::200;oj::200?o0000oookJ_oonfX06OoonfX2o`000003o`5/g?l0003o
MZof00OoMZof00?o0000ohNelon7]O<00on7]O<00ol0003o]<;To`000002o`0000ko/l3S0_l00000
0ona_N?o0000ol[2dP03ol[2dP04o`000?oIa<GofLC5o`0000GofLC500?o0000omJo`ooF_l<01?oF
_l<00ol0003ohL:ion72^@05on72^@03o`000?oL^[Oog;Zg00Gog;Zg00?o0000omZg]Ol000002Oo>
Z[D00ol0003objJco`000008olfW/P03o`000?o7WZooaij_00Goaij_1?l00002okbB[003o`000?nm
UJgo000000oo]I2`00Ko0000ok6;[OnaRjgo/H^]o`000?nUPjl5o`0000_oXX:a1?l0000=oi9e/003
ogQX/ol0003oPg2d00_oPg2d00Co0000ofaY_Om/JKgo00002_mjL[h00ol0003oJgG;of]eb`03o`00
00WoH7cG00?o0000ogB7f?mdQmP02_mdQmP<o`0000KoLYCT00?o0000ohn/j_l000000on8ZN/8o`00
00CoSjcY00?o0000oj;2l?nR`_003onR`_03o`000003ojG5l?l0003o^=;]00Wo^=;]00?o0000ok_E
kOnkeNd01onkeNd00ol0003o`=O[o`000002ol?Kj`03o`000?o>h>Goc^3U00?oc^3U00?o0000om3S
iOo@hnD01Oo@hnD2o`0000Gof>_Q1?oJk=l00ol0003oh?KIo`000004omohf@;o000000?oh_g7o`00
0?oNo/<00_l000000ooCmjCo0000o`00000ZoookJP?o00005?oonfX00ol0003ooo]ZoookJP0Zoook
JP03o`000?oonf[ooo]Z00Sooo]Z000:oookJP03o`000?oonf[ooo]Z00Wooo]Z0_l000000oo`YWKo
0000onn[PP02onn[PP05o`000?o]ZH?okJV3onfYPol000005?oonfX01?l0003okiABonnDD_o_U582
o`0000?okYi]00?o0000onbLL?o/W7000_l000000oo[Y83o0000onRRPP04onRRPP;o00006ooonfX3
o`0000SoMZof00Co0000ohNelon7]O?oQkGc0ol0000>ok?0h`;o00000ona_N<3o`000003ol[2d_l0
003o000000CofLC500Go0000omW4aOoIa<GofLC5o`000006omJo``;o00001_oQ`[T00ol0003og;Zg
ombj]`07ombj]`;o00002?o>Z[D01?l0003objJcol^V/ol00007olfW/P03o`000?o7WZooaij_00[o
aij_6_l0000>oj:2/@?o00003onBMK02o`0000koPg2d0_l0000<ogYb_P03o`000?m[ML_oNGg;00;o
NGg;1?l00005of1le`03o`000?mdQmSoM8OH00_oM8OH0_l00009oh:KhPco00003On?[>T00ol0003o
X/;`oj;2l00;oj;2l0?o00001OnUaO000ol0003o^=;]okSBk@05okSBk@;o00002_nkeNd2o`0000Co
`m_[00Go0000olkPiOo>h>Goc^3Uo`000008om3Si@03o`000?oHjn7of>_Q00?of>_Q1OoJk=l2o`00
00CogoSI0_l000000ooRoLOo0000omkn``02o`000003om?gY?l0003o000002Sooo]Z0ol0000Hoook
JP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX02?oonfX000[ooo]Z00?o0000oookJ_oo
nfX02_oonfX01?l0003ol:Ifoo2VM_l00002onn[PP03o`000?o]ZH?okJV300;okJV30_l0000Boook
JP07o`000?o_U5;okiABonnDD_l0003okI9Go`000002onjNK@03o`000?o/W73ok9a`00;ok9a`0_l0
0005onRRPP03o`000?oUWh?o000001_ooo]Z00?o0000o`1Xeol000002ol00003ohFfm003o`000?nc
`>?o/l3S00Wo/l3S0_l00008ok6mh`04o`000?o<aM?oc<GCo`0000CofLC500?o0000omW4aOl00000
1_oF_l<01?l0003oh<:jon32^_l00005on72^@03o`000?oL^[Oog;Zg00Oog;Zg00?o0000omFc]ol0
00000_l00005oljZ]@05o`000?o;Y[?objJcol^V/ol000001_o=Yk800ol0003oaij_olNN[`0;olNN
[`04o`000?nmUZko_IJ^o`0000ko]I6a00?o0000ok6<[_naS:h00_naS:h00ol0003oXX:aoj:2/@0:
oj:2/@?o00000onRP[400ol0003oTWF`oi9e/009oi9e/0?o000000?oTWVdo`000?n3L;@03On3L;@0
0ol0003oNW:nogYb_P0<ogYb_P03o`000?miOL_oNGg;00GoNGg;0ol000001?mPO=Oo0000of1keol0
000<ogB7f003o`000?mOPmko000000ooPY_R0_l0000Aohn/j@03o`000?nR`_3oX/;`00OoX/;`0ol0
0009ojG5l003o`000?nhd^go^=;]00;o^=;]0_l0000<ok_Ek@03o`000?o3fn_o`m_[00Co`m_[00?o
0000olkPiOl000001oo@hnD00ol0003od^KUo`000004omS[h@Gof^cO0_l00004omohf@08o`000?oQ
nMKo0000on;maol0003og_k3o`000?oCmj@2o`0002Kooo]Z0ol0000LoookJP03o`000?oonf[ooo]Z
02Sooo]Z00?o0000oookJ_oonfX02?oonfX000[ooo]Z00?o0000oookJ_oonfX02_oonfX01ol0003o
l:Ifoo2VM_o`YWKo0000onn[P_l000001?o]ZH<00ol0003ojjJ4o`00000AoookJP;o00000_o_U580
1?l0003okI9GonfBEol00002onjNK@03o`000?o/W73ok9a`00;ok9a`0_l00004onRRPP03o`000?oU
Wh?oiIn300;o00006_oonfX01?l0003o06SGo`1Xeol00008ofn_n003o`000?n5]_CoQKKd00;oQKKd
00?o0000ok?0honc`><01Onc`><3o`0000Wo/KgS00?o0000olc5doo<aM<00_o<aM<00ol0003ofLC5
omW4a@02omW4a@;o00001_oF_l<01?l0003oh<:jon32^_oP`[X2o`0000;ohL:i00?o0000ombj]ooL
^[L01ooL^[L00ol0003oeK>gomFc]`03omFc]`?o000000?ocZZeo`000?o;Y[<00oo;Y[<00ol0003o
cJNbolfW/P03olfW/P03o`000?o7WZooaij_00_oaij_00Go0000okfF[_nmUZko_IJ^o`00000=okFA
/@03o`000?naS:ko/Hb^00?o/Hb^00?o0000oj:2/OnRP[401onRP[43o`0000KoXX:a00?o0000oi9e
/?nBMK001_nBMK0;o`0000[oPg2d0_l0000>ogYb_P03o`000?miOL_oNGg;00SoNGg;1?l0000<ogB7
f003o`000?mOPmko0000013oPY_R00?o0000ohn/jOn?[>T03on?[>T00ol0003oX/;`oj;2l004oj;2
l0?o00003OnUaO001?l0003o^=;]o`000?l0000;ok_Ek@;o000000?o_MG[o`000?o3fn/01Oo3fn/2
o`0000Kod>?U0_l00002om;Vi@04o`000?oHjn7of>_QomS[h@Gof^cO00?o0000om[ch?l000000ooO
n=T00ol0003ohOWFon7ieP02o`0000;og_k300Co0000om?gY?l0003o00008ooonfX3o`00023ooo]Z
00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP07oookJP002_oonfX00ol0003ooo]Zoook
JP0:oookJP03o`000?o`YWKol:If00;ol:If0_l00004onfYP`04o`000?o[YXCojjJ4o`00013ooo]Z
00Go0000onV1<Ol0003okiABo`000003onfBE`03o`000?o^WVgo000000Cok9a`00?o0000onVJL_l0
00000ooXXX800ol0003oiIn3onFOP`02onFOP`03o`000?oonf[ooo]Z01Sooo]Z0_l000000ol0J=Oo
0000ofn_n007ofn_n003o`000?n5]_CoQKKd00;oQKKd00?o0000ok?0honc`><00_nc`><2o`0000_o
/KgS00?o0000olc5doo<aM<01?o<aM<01ol0003ofLC5omW4aOoIa<Go0000omJoa?l000001?oF_l<0
0ol0003oel?6o`000004on32^P03o`000?oQ`[Wo000000Sog;Zg00?o0000omFc]ooE/kL01ooE/kL2
o`0000CobjJc00?o0000olfW/_o=Yk800oo=Yk800ol0003oaij_olNN[`0:olNN[`03o`000?nmUZko
_IJ^00?o_IJ^00?o0000okFA/OneTK402OneTK400ol0003o/Hb^ok6<[P05ok6<[P03o`000?nRP[7o
XX:a00?oXX:a0ol00009oj:2/@04o`000?nBMK3oTWF`oi9e/0So00001?nCO;L01?l0003oPW>joh9c
^_n2LkX6o`0000?oPg2d00Co0000oh9g__n2Mkko00003?mjL[h00ol0003oM7[;o`00000:ogUmb`03
o`000?mWMlooIgO?00Co00002?mdQmP01?l0003oGh?Noen3g_l0000?oh:KhP03o`000?n?[>WoSjcY
013oSjcY00?o0000oj;2l?nR`_000ol0000AojG5l003o`000?nkeNgo^mG]00Wo^mG]0_l00003okgE
j`03o`000?o3fn_o`m_[00;o`m_[0_l00003olKPj`05o`000?o@hnGod>?Uom3SiOl000001?oBi^D0
0ol0003of>_QomS[h@05om[/g`04o`000?oJln3of_?Po`0000;ogoSI00?o0000on7ie_oQnMH00_l0
0002omkn``04o`000?oCmjCo0000o`00023ooo]Z1?l0000SoookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX01ooonfX000Wooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ol:Ifoo2V
MP03oo2VMP;o00000oo]ZH<01Ol0003ojjJ4on^VQ?o[YXCo0000013ooo]Z00Go0000onV1<Ol0003o
kiABo`000003onfBE`;o00001?o/W7001?l0003ojIYbonVJL_l00002onRRPP03o`000?oUWh?oiIn3
00?oiIn30_l0000JoookJP?o00002?m_[oP00ol0003oQKKdohFfm002ohFfm004o`000?nc`>?o0000
o`0000co/KgS00?o0000olc5doo<aM<01_o<aM<00ol0003ofLC5o`000003omJoa004o`000?oF_l?o
e[o3o`0000?oel?600?o0000on32^_oP`[X00_oP`[X2o`0000Sog;Zg00?o0000omFc]ooE/kL01ooE
/kL00ol0003oajFfo`000002o`0000;objJc00Go0000olfW/_o=Yk;ocJNbo`00000<olNN[`03o`00
0?nmUZko_IJ^00Co_IJ^00?o0000okFA/OneTK402?neTK400ol0003o/Hb^ok6<[P06ok6<[P03o`00
0?nRP[7oXX:a00?o00002onRP[48o`0000[oTgbg00?o0000oh9c^_n2LkX01_n2LkX9o`0000WoNW:n
00Co0000ogAjbomdN/_o00002OmiOL/01Ol0003oIgO?ofMgcomWMloo000000?oOhkH1_l00002ogB7
f005o`000?mOPmkoGh?Noen3g_l000003_n2Vn82o`0000ooSjcY1Ol0000@ojG5l0?o000000?oZLW`
o`000?nkeNd02?nkeNd2o`0000Go_MG[00?o0000ol?Kjoo3fn/00_l00006olKPj`03o`000?o@hnGo
000000Cod^KU00?o0000omS[hOoHjn401OoJk=l01?l0003of_?Pom[ch?l00002omohf@05o`000?oQ
nMKohOWFon7ie_l000000_oNo/<5o`0001gooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX01ooonfX000Wooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ol:Ifoo2V
MP03oo2VMP03o`000?o^XgSo000000;okJV300?o0000on^VQ?o[YX@00_o[YX@00ol0003ooo]Zoook
JP0=oookJP03o`000?oYPC7ojH4a00;o00001?o]TUL2o`0000?ok9a`00Oo0000onVJL_oYVW;ojIYb
o`000?oXXX;o000000GoiIn300Co0000on>LQ?l0003o00006OoonfX00ol0003o067@o`000007o`00
0003ofn_n?l0003o000000Co00003Ona_N<00ol0003oc<GColc5d`07olc5d`;o00001OoF_l@2o`00
00Goel?600Oo0000on32^_oP`[[oh<:jo`000?oK^kSo000000Kog;Zg00?o0000omFc]ooE/kL01ooE
/kL00ol0003oajFfolNU]P03olNU]P?o00000_o=Yk800ol0003oaij_olNN[`0:olNN[`03o`000?nm
UZko_IJ^00Go_IJ^00?o0000okFA/OneTK401oneTK400ol0003o/Hb^ok6<[P07ok6<[P?o00003?nR
P[42o`000003ojB5/ol0003oTW^f00;o00003OnCO;L00ol0003oPW>joh9c^P06oh9c^P03o`000?n:
NK[oRWVj00?oRWVj00?o0000ogQe`omhML<00ol00006ogYb_P05o`000?mdN/_oM7[;ogAjbol00000
2?miOL/00ol0003oIgO?ofMgc`02ofMgc`03o`000?moS]SoOhkH00KoOhkH1ol0000?oh:KhP;o0000
2?n?[>T6o`0000CoTKK`00?o0000ojG5l?nUaO002onUaO03o`0000GoZLW`00?o0000ok_EkOnkeNd0
1OnkeNd00ol0003o_MG[okgEj`04okgEj`04o`000?o3fn_o`m_[o`0000Soa^3[0_l00005om;Vi@03
o`000?oHjn7of^cO00Cof^cO00Oo0000om[ch?oJln3of_?Po`000?oOn=Wo000000CohOWF00Oo0000
omkn`ol0003o0000om?gY?l0003o[=M/01_ooo]Z0ol0000/oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX01ooonfX000Wooo]Z00?o0000oookJ_oonfX02ooonfX2o`0000Col:If00Ko
0000onjSN?o^XgSo0000onfYPol00005on^VQ0;o00003OoonfX01?l0003ojH4aonV1<OoYPC42o`00
00?okI9G00?o0000on^AF_l000000_o/W7000ol0003ojIYbonVJLP02onVJLP;o00001OoUWh<01Ol0
003ohib4on>LQ?oSW8Co000001Wooo]Z00?o0000o`1Qd?l000002OmR[OT01Ol0003oP[Gfoh:em_n2
]OKo000000[o/KgS0_l00009olc5d`04o`000?o9_m7obKoAo`0000Goe[o400?o0000omO3a_oG`lH0
1?oG`lH00ol0003oh<:jo`000003om^k^003o`000?oL^[Oog;Zg00;og;Zg00?o0000omFc]ooE/kL0
1ooE/kL00ol0003oajFfolNU]P07olNU]P03o`000?o=Yk;o000000coaij_00?o0000okfF[_nmUZh0
1_nmUZh00ol0003o]I6aokFA/@05okFA/@03o`000?naS:ko/Hb^00Co/Hb^1?l000000onaS:ko0000
oj:2/@0;oj:2/@03o`000?nTQK?oY8Fc00?o00003onCO;L00ol0003oPW>joh9c^P05oh9c^P03o`00
0?n:NK[oRWVj00GoRWVj00?o0000ogQe`omhML<00_mhML<2o`0000?oNW:n00?o0000ogAjbomdN//0
0_mdN//00ol0003oNGg;ogUmb`06ogUmb`03o`000?mWMlooIgO?00;oIgO?00?o0000ogn>f?moS]P0
2?moS]P01?l0003oL8SKog28fom`R=/Bo`0000?oSjcY1Ol0000;oi6fl003o`000?nUaO3oYLG`00Oo
YLG`0ol00009ojW9l003o`000?nkeNgo^mG]00;o^mG]0_l00007okgEj`?o00002?o6h>/01Ol0003o
bMcWolWLioo9g>Oo000000?od^KU00?o0000om[/gooJk=l00ooJk=l00ol0003of_?Pom[ch002om[c
h003o`000?oOn=WohOWF00?ohOWF00Co0000omkn`ol0003ogOjo0ol0000IoookJP?o0000;ooonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z00Oooo]Z0009oookJP03o`000?oonf[ooo]Z
00_ooo]Z00?o0000oo2OJ?l000000oo`YWH01?l0003okZ=honjSN?o^XgP2o`0000GojjJ400?o0000
onRTQOl000003OoonfX01_l0003ojH4aonV1<Ol0003oj84ho`0000;okI9G00Ko0000on^AF_o[TE[o
0000onbLL?l00005onVJLP;o00001?oUWh<00ol0003ohib4on>LQ002on>LQ0;o00006?oonfX00ol0
003o067@o`000009of:]n@05o`000?n2]OKoP[Gfoh:em_l000001ona_N<3o`0000Woc<GC00?o0000
olVodOo9_m400_o9_m401Ol0003oe[o4omJoa?oF_lCo000000Soel?600?o0000om^k^?oK^kP00ooK
^kP01Ol0003og;Zgombj]ooL^[Oo000000WoeK>g00?o0000olNU]_o7YKH01oo7YKH5o`0000Woaij_
00?o0000okfF[_nmUZh01onmUZh00ol0003o]I6aokFA/@04okFA/@03o`000?naS:ko/Hb^00;o/Hb^
0ol00005ok6<[P03o`000?nRP[7oXX:a00SoXX:a1Ol00002ojF9]`03o`000?nCO;OoTgbg00koTgbg
00?o0000oh9c^_n2LkX00_n2LkX2o`0000SoRWVj00?o0000ogQe`omhML<01OmhML<6o`000003ogAj
bol0003oNGg;00KoNGg;00?o0000ofMgcomWMll01?mWMll00ol0003oOhkHogn>f007ogn>f003o`00
0?m`R=_oL8SK00;oL8SK00?o0000ohZOh_n:Wn803?n:Wn800ol0003oOYoXo`000002o`00017oTKK`
00?o0000ojG5l?nUaO000onUaO03o`0000goZLW`00Co0000ok_EkOl0003o00002OnmeN/00ol0003o
a^3[olKPj`06olKPj`;o00001Oo9g>L01?l0003od^KUo`000?l00004om[/g`03o`000?oJln3of_?P
00;of_?P00?o0000omohfOoQnMH00ooQnMH2o`000003omkn`ol0003ogOjo00;o000000?o[=M/oook
J_oonfX05?oonfX3o`0003?ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP07oook
JP002OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?o`WfSol9mX00;o000000?ol:Ifo`000?o^
XgP00oo^XgP2o`0000CojjJ400?o0000onRTQOoXY8D00_l0000;oookJP04o`000?oYPC7ojH4ao`00
00;oj84h00?o0000onfBEol000000oo[TEX2o`0000GojIYb00?o0000onJGM?l000000ooUWh<00ol0
003ohib4on>LQ004on>LQ0;o00005ooonfX3o`0000WoHZgi00Go0000oh:em_n2]OKoP[Gfo`000004
ok6mh`;o000000?o[[cTo`000?o<aM<02?o<aM<00ol0003obKoAolVod@04olVod@03o`000?oF_lCo
000000Woel?600?o0000om^k^?oK^kP01?oK^kP00ol0003og;Zgo`000009omFc]`03o`000?o7YKKo
ajFf00SoajFf00?o0000olJO[oo6Wjl00_o6Wjl5o`0000?oaij_00?o0000okfF[_nmUZh02?nmUZh0
0ol0003o]I6aokFA/@03okFA/@03o`000?naS:ko/Hb^00?o00002?naS:h00ol0003oXX:aoj:2/@05
oj:2/@Co00001_nURKL00ol0003oTgbgoi=l]`0>oi=l]`05o`000?n2Lk[oPW>joh9c^_l000002on:
NKX00ol0003oN7G3ogQe``04ogQe``03o`000?n3O<?oPgc300?oPgc31Ol00004ogUmb`03o`000?mW
MlooIgO?00CoIgO?00?o0000ogn>f?moS]P01_moS]P00ol0003oL8SKog28f`04og28f`03o`000?n:
Wn;oRYoR00_oRYoR00?o0000ogjOj?l000005?nA]_000ol0003oYLG`o`000002o`00017oZLW`00?o
0000okgEjonmeN/01onmeN/00ol0003o`=S[o`000007olKPj`03o`000?o9g>OobMcW00KobMcW0ol0
0003om[/g`03o`000?oJln3of_?P00?of_?P00?o0000on7ie_oQnMH00_oQnMH2o`000006omkn`ol0
003ogOjoo`000?o=ligo00004ooonfX4o`0003Oooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003o
oo]ZoookJP07oookJP002OoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?o`WfSol9mX00;ol9mX
0_l00004onjSN003o`000?o[XGWo000000?ojjJ400?o0000onRTQOoXY8D00_oXY8D00ol0003ooo]Z
oookJP08oookJP;o00000_oYPC401_l0003oj84honR1>?l0003okI9Go`0000?oji5J0_l00004onVJ
LP03o`000?oVUgCoiYMd00;o000000?oiIn3o`000?oSW8@01OoSW8@01?l0003oh9Z4o`000?l0000G
oookJPSo00000omR[OT01_l0003oP[Gfoh:em_n2]OKo0000ok6mh`;o000000Co[[cTo`000?l0003o
00001oo<aM<2o`0000SobKoA00?o0000omO3a_oG`lH01ooG`lH00ol0003od[_4o`000006om^k^0;o
00002?oE/kL00ol0003oajFfolNU]P09olNU]P03o`000?o6WjooaYn_00OoaYn_1_l00008okfF[P03
o`000?neTK7o]I6a00;o]I6a1?l0000<ok6<[P03o`000?nRP[7o000000Go00002_nURKL00ol0003o
Tgbgoi=l]`0=oi=l]`04o`000?n2Lk[oPW>jo`0000coRWVj00?o0000ogQe`omhML<00omhML<00ol0
003oPgc3oh=l``06oh=l``03o`000?mgOlkoMgo>00;o00000_miOL/00ol0003oIgO?ofMgc`04ofMg
c`03o`000?moS]SoOhkH00KoOhkH00?o0000og28fom`R=/01?m`R=/00ol0003oRYoRohZOhP0;ohZO
hP04o`000?mnWnSoOYoXo`0001CoTKK`00?o0000ojW9l?nYbO003_nYbO03o`0000;o[Lga00?o0000
okgEjonmeN/01?nmeN/2o`0000;o`=S[00?o0000olKPjoo6h>/00oo6h>/2o`0000SobMcW0oo9j^d0
1?l0003of^cOom[/gol00005om[ch003om_gg_l0003ohOWF00;ohOWF00Co0000omgmdol0003o0000
0_oMo[l3o`00013ooo]Z0ol0000koookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
1ooonfX000Wooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ol9mXoo2OJ002oo2OJ003o`000?o^
XgSokZ=h00;okZ=h00Co0000on^QNOo[XGWo00000_o[YX@00ol0003oj:B5onRTQ@03onRTQ@;o0000
2OoonfX2o`000003onV1<Ol0003oj84h00;oj84h0_l00003on^AFP03o`000?oXSeko000000?ojIYb
00?o0000onJGM?oVUg@00_oVUg@2o`0000Kohib400Go0000on2JQ?oPVXCoh9Z4o`00000GoookJP?o
00001?m?Z?T9o`0000;o[[cT00Go0000olg5d_o=aM;ocLGBo`000005olc5d`03o`000?o9_m7obKoA
00SobKoA0_l00007omO3aP05o`000?oB^lCod[_4om:ka?l000001OoK^kP01?l0003oeK>go`000?l0
0005omFc]`03o`000?o7YKKoajFf00WoajFf00?o0000ol:Q^?l000002_o6Wjl01?l0003o`:6iol2Q
^Oo0XKT7o`0000;o_IJ^00?o0000okFA/Ol000000_l00006ok6<[P_o00000_nSPk82o`0000coYHVg
00?o0000oi=l]onCO;L03_nCO;L2o`0000goRWVj00?o0000ogQe`omhML<00_mhML<00ol0003oPgc3
oh=l``08oh=l``03o`000?mgOlkoMgo>00;oMgo>1?l00005ofMgc`03o`000?moS]SoOhkH00GoOhkH
00?o0000og28fom`R=/01Om`R=/00ol0003oRYoRohZOhP09ohZOhP03o`000?mnWnSoOYoX00;oOYoX
00?o0000oi6fl?nA]_002_nA]_05o`0000;oUk[`00?o0000ojW9l?nYbO002onYbO03o`0000Ko[Lga
00Co0000okgEjonmeN_o_MG[0_l00004ol3Hj`03o`000?o6h>_oa^3[00;oa^3[00?o0000olWLioo9
g>L01oo9g>L4olWZk@03o`000?oJk=oo000000Cof_?P00?o0000om_gg_l000000ooQnMH01?l0003o
gOgComgmdol00002omgn_`?o00003_oonfX3o`0003oooo]Z00?o0000oookJ_oonfX09?oonfX00ol0
003ooo]ZoookJP06oookJP002OoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?o`WfSol9mX00;o
l9mX0_l00003onjSN007o`000?o[XGWojj5ion^QNOl0003ojjJ4o`000005onRTQ@03o`000?oVXHKo
000000Sooo]Z1?l00004onR1>0;o00000oo[TEX01_l0003oj8mNo`000?l0003ojIYbo`0000GoiYMd
0_l00005on>LQ003o`000?oPVXCoh9Z400;oh9Z40_l0000GoookJP;o00002Om?Z?T01Ol0003oO;Cg
ogbdmoml]?Oo000000GocLGB00Go0000olc5doo<aM?oc<GCo`00000:olVod@04o`000?oIaLKofLG6
o`0000Goel?600?o0000om:ka?oB^l@00ooB^l@01Ol0003ofk^hom^k^?oK^kSo000000CoeK>g00?o
0000omFc]ooE/kL00_oE/kL00ol0003oajFfolNU]P08olNU]P04o`000?o2XKSo`Z6ho`0000WoaYn_
00?o0000ol2Q^Oo0XKT02Oo0XKT=o`0000Wo/I:f00Co0000oj>3/_l0003o00003_nURKL00ol0003o
Tgbgoi=l]`0=oi=l]`;o00003on:NKX01?l0003oN7G3ogQe`ol0000;oh=l``03o`000?mgOlkoMgo>
00;oMgo>00Co0000oh:5c_n2QLkoPXG>1_l00006ogn>f003o`000?m`R=_oL8SK00OoL8SK00?o0000
ohZOh_n:Wn802?n:Wn800ol0003oOYoXogjOj002ogjOj003o`000?nA]_3oTKK`00KoTKK`1?l00008
oiNjl003o`000?nYbO3oZLW`00OoZLW`0ol0000:ojg=l@03o`000?nmeN_o000000Ko`=S[00Go0000
olKPjoo6h>_oa^3[o`000008olWLi`GobN[]0ol000001OoJln3o0000om[ch?oJln3o000000;ofoON
00Co0000on7ie_oQnMKo00000_oMoM<00ol0003ogOjoomgn_`04o`0000_ooo]Z0ol00013oookJP03
o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX01_oonfX000Sooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ol9mXoo2OJ002oo2OJ003o`000?o^WF_o000000;okZ=h00?o0000on^QNOo[XGT0
0_o[XGT2o`0000Goj:B500?o0000onJQQ_oVXHH00_l00007oookJPCo00000ooXPCP00ol0003oiX0n
o`000002on^AFP04o`000?oXSekoj8mNonR?GP;o00001OoVUg@01?l0003ohiAfo`000?l00003on>L
Q003o`000?oPVXCoh9Z400;oh9Z400Co0000omnIQ?l0003o00005_oonfX2o`0000WoCjSi0ol00007
olg5dP03o`000?o<aM?o000000[obKoA00?o0000omW5a_oIaLH00_oIaLH01Ol0003oel?6omO3a_oG
`lKo000000Ood[_400?o0000om^k^?l000001_oE/kL2o`000003omFc]ol0003oajFf00WoajFf00?o
0000ol:Q^?o2XKP00_o2XKP00ol0003oaYn_olJO[`05olJO[`03o`000?o0XKWo`:6i00So`:6i0ol0
00000oo0XKWo0000ok6B]P0Bok6B]P;o00004OnURKL00ol0003oTgbgoi=l]`09oi=l]`?o000000?o
U7fgo`000?n:NKX03_n:NKX00ol0003oN7G3o`00000=oh=l``04o`000?mgOlkoMgo>o`0000WoPXG>
3_l00003og28f`03o`000?n:Wn;oRYoR00SoRYoR00?o0000ogjOj?mnWnP00omnWnP00ol0003oTKK`
oi6fl005o`0000goUk[`00?o0000ojW9l?nYbO000onYbO03o`0000ko[Lga00?o0000ol3Hjoo0f>/0
1Oo0f>/01?l0003oa^3[o`000?l00007olWLi`03o`000?o9j^gobN[]00CobN[]00?o0000om?bi_oC
l^H00_oCl^H4o`000004om_gg_l0003ohOWFo`0000;ogOgC0_l000001OoMo[oo0000o`000?l0003o
/nZA00Wooo]Z0ol00017oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX01_oonfX0
00Sooo]Z00?o0000oookJ_oonfX03OoonfX2o`0000?ol9mX00Ko0000onjMJoo^WF_o0000onjSN?l0
0005on^QN@;o00001?oXY8D00ol0003oiZ66onJQQP02onJQQP03o`000?oonf[ooo]Z00Cooo]Z00?o
0000om5H0?l000000_l00003onR1>003o`000?oVP3ko000000;o00001?oXSeh2o`0000CoiYMd00Go
0000on>DM_oSU7KohiAfo`000002on>LQ003o`000?oPVXCoh9Z400;oh9Z400Co0000omnIQ?l0003o
g9J50ol0000EoookJPOo00000om?Z?T00ol0003ocLGBolg5dP07olg5dP;o00002Oo9_m400ol0003o
fLG6omW5aP04omW5aP03o`000?oG`lKo000000Wod[_400?o0000omFc]ooE/kL01ooE/kL3o`0000Wo
ajFf00?o0000ol:Q^?o2XKP00_o2XKP00ol0003oaYn_olJO[`05olJO[`03o`000?o0XKWo`:6i00Go
`:6i0ol00004ol2Q^@03o`000?naT[Ko/I:f013o/I:f00?o0000ok2?]?l000004OnURKL00ol0003o
Tgbgoi=l]`07oi=l]`;o00001OnDOKL00ol0003oRWVjohYi^P0<ohYi^P;o00003_n3O<<00ol0003o
Mgo>o`00000;oh:5cP03o`000?mnSm[oOXoJ00?oOXoJ00?o0000ogf>fOmmS]T01?mmS]TGo`0001?o
Uk[`00?o0000ojW9l?l000000_l0000=ojg=l@?o00000_nbd_400ol0003o`=S[ol3Hj`04ol3Hj`;o
00002?o9g>L00ol0003obN[]olWZk@04olWZk@03o`000?oCl^Kodo;V00;odo;V00?o0000om?ci_oC
lnH00_oClnH00ol0003ohOWFo`000002omgmd`;o000000GogOjoo`000?o<oKgo0000ok?ZT@06oook
JPCo0000B_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z00Kooo]Z0008oookJP03
o`000?oonf[ooo]Z00gooo]Z00?o0000onnFEol000000_o`WfP01?l0003okYe[onjMJoo^WF/2o`00
00Gojj5i00?o0000onVONol000000ooXY8D00ol0003oiZ66onJQQP03onJQQP;o00001OoonfX3o`00
0005omaY4ol0003oj84honR1>?l000000ooVP3h2o`0000?oj8mN00Co0000onF=HOl0003o00000_oV
Ug@00ol0003ohiAfon>DMP02on>DMP?o00001?oPVX@00ol0003ogiV4o`000004ombFQ@;o00005Ooo
nfX00ol0003o<ikboc>NlP02oc>NlP?o00002Oo=aM801?l0003oc<;Aolc2dOl00007olVod@03o`00
0?oIaLKofLG600KofLG60_l00009om:ka003o`000?oE/kOoeK>g00OoeK>g00?o0000olnb_Oo?/[d0
0ol00005olNU]P03o`000?o2XKSo`Z6h00Co`Z6h00?o0000olJO[oo6Wjl00oo6Wjl00ol0003o`:6i
ol2Q^@03ol2Q^@?o00001_o0XKT00ol0003o^YNcok6B]P0@ok6B]P04o`000?n`SkCo/8ndo`00017o
YHVg00?o0000oi=l]onCO;L01?nCO;L3o`0000OoU7fg00?o0000ohYi^_n:NKX02_n:NKX2o`000003
ohUo`_l0003oPgc300goPgc300?o0000ogMoc_l000003?n2QLh01Ol0003oOXoJogj?f_mnSm[o0000
00_oOHkI00?o0000oi6Th_nAY>801onAY>800ol0003oR:7UohRQi@04ohRQi@03o`000?nG^_3oUk[`
01?oUk[`00?o0000ojg=lOn]cO403?n]cO42o`0000Ko/];a00?o0000ol3Hjoo0f>/00oo0f>/00ol0
003obMcWolWLi`05olWLi`03o`000?o9j^gobN[]00GobN[]00?oc>[Zo`000?oCl^H00_oCl^H00ol0
003odo?Vom?ciP03om?ciPOo000000God_k3o`000?o<oKgo/nZAo`000003oookJP?o0000CooonfX0
0ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00Kooo]Z0008oookJP03o`000?oonf[ooo]Z
00gooo]Z00Ko0000onnFEoo_UUOo0000oo2OJ?l00004onjMJ`;o00001?o[XGT00ol0003ojImkonVO
N`02o`000003onRTQOl0003oiZ6600CoiZ6600?o0000on>OQ_l000001OoonfX7o`0000CoiX0n0_l0
0003onR?GP04o`000?oUSF7oiHeQo`0000;oiYMd00?o0000on>DM_oSU7H00ooSU7H2o`0000;oh9Z4
00Co0000omnIQ?oOVHCo00001_oLUXD2o`0001Cooo]Z0_l000000olcW_;o0000o`000002okg4h003
o`000?o=aM;ocLGB00GocLGB00?o0000olc2dOo<`]400_o<`]400ol0003obKoAolVod@03olVod@;o
00002?oIaLH01?l0003oe/34o`000?l00006om:ka003o`000?o<]L?o000000OoeK>g00?o0000olnb
_Oo?/[d01?o?/[d3o`000003olNU]_l0003o`Z6h00Ko`Z6h00?o0000olJO[oo6Wjl00_o6Wjl01?l0
003o`:6iol2Q^Oo0XKT3o`0000So`:6i00Co0000okZG/onjUk?o00003onaT[H00ol0003o/8ndok2?
]002ok2?]003o`000?nURKOoYHVg00koYHVg00?o0000oi=l]onCO;L00_nCO;L2o`0000[oU7fg00?o
0000ohYi^_n:NKX02On:NKX01Ol0003oRGo2ohUo`_n9Ol;o000000ooPgc300?o0000oh:5c_n2QLh0
3?n2QLh00ol0003oOXoJo`00000=ogf>f@03o`000?nAY>;oTJCR00KoTJCR00?o0000ohRQiOn8XND0
1On8XND00ol0003oUk[`oiNjl00=oiNjl0?o00000_nM_o000ol0003o[Lgaojg=l@09ojg=l@?o0000
2Onbd_401_l0003o`=S[o`000?l0003o`m_[o`0000GobMcW0_l00006olWZk@04o`000?o<j^[oc>[Z
o`0000;odo;V00?o0000om?ci_oClnH00ooClnH2o`0000;oeokI00?o0000omGoeooEomL00_l00000
1?o<oKgo/nZAo`000?oonfX3o`0005?ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]Zoook
JP06oookJP002?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?o_UUOokiIG00;o00001?o^WF/0
0ol0003ok9]]o`000003on^QN@03o`000?oYWg_ojImk00;ojImk0_l00005onJQQP03o`000?oSWhKo
hin600;o00001?oonfX2o`000003omAK0?l0003o000000;o00000ooVP3h00ol0003oi7m3o`000002
onR?GP04o`000?oUSF7oiHeQonF=H@?o00001OoSU7H00ol0003ohI9go`000002o`0000;ogiV400?o
0000ombFQOoLUXD01?oLUXD01?l0003ofYB6o`000?l0000DoookJP03o`000?nma>3o_LCP00?o_LCP
00?o0000olg5d_o=aM800oo=aM800ol0003oc<;Aolc2d@04olc2d@04o`000?o9_m7obKoAolVod@;o
00002?oIaLH00ol0003oe/34omK0a002omK0a003o`000?oB^lCod[_400;od[_400Go0000olbe`oo<
]L?oc;G3o`000005omFc]`03o`000?o?/[gock:m00Sock:m0ol00006ol:Q^006o`000?o6WjooaYn_
olJO[ol0003o`:6i0ol0000:ol2Q^@05o`000?njUk?o^YNcokZG/ol000003_naT[H00ol0003o/8nd
ok2?]003ok2?]003o`000?nURKOoYHVg00ooYHVg00Co0000oi=l]ol0003o00002_nDOKLAo`0000;o
RGo200?o0000oh=l`on3O<<02on3O<<2o`0000koPXG>00?o0000ogj?f_l000003_mmS]T00ol0003o
TJCRoi6ThP04oi6ThP03o`000?n8XNGoR:7U00OoR:7U00?o0000oiNjl?nG^_002?nG^_04o`0000Ko
WKo`00?o0000ojg=lOn]cO401_n]cO42o`0000go/];a00Go0000ol?Kjoo3fn_o`m_[o`000004olWL
i`03o`000?o9j^gobN[]00CobN[]0_l00002olcZjP04o`000?oCl^Kodo;Vo`0000Godo?V00Go0000
omKfhol0003oeokIo`000003omGoe`04o`000?o<oKgo0000ok?ZT@;o0000E_oonfX00ol0003ooo]Z
oookJP0PoookJP03o`000?oonf[ooo]Z00Kooo]Z0008oookJP03o`000?oonf[ooo]Z00kooo]Z00Co
0000onnFEoo_UUOokiIG0_l00003onjMJ`03o`000?o/Vfgok9]]00;o000000?ojj5io`000?oYWg/0
1?oYWg/2o`0000CoiZ6600?o0000on>OQ_oSWhH00_oSWhH00ol0003ooo]ZoookJP02oookJP;o0000
0_oDF`03o`0000?oiX0n00?o0000onAo@ol000000_l00005onF=H@;o00001?oSU7H01?l0003ohI9g
on6BMooQTWL4o`0000Kog9J500Co0000omZDQ_oJU8KofYB60_l0000@oookJP;o00001onma>001Ol0
003ocLGBolg5d_o=aM;o000000Soc<;A00Co0000olVodOl0003o00002?oIaLH00ol0003oe/34omK0
a004omK0a0;o000000?od[_4o`000?o<]L<00oo<]L<00ol0003oeK>gomFc]`03omFc]`03o`000?o?
/[gock:m00Sock:m00?o0000ol^[^Oo;ZkT01?l00003ol:Q^003o`000?o6Wjoo000000;o00003?o0
XKT00ol0003o^YNcokZG/`03okZG/`03o`000?naT[Ko/I:f00Wo/I:f0_l00006ok2?]003o`000?nU
RKOoYHVg00goYHVg0_l000000onCO;OoU7fgoiAm]`06oiAm]`Go00000onGQ;d00ol0003oRWk1ohYn
`@05ohYn`@03o`000?n@P/3oT8;000?oT8;02Ol00006oh=l``03o`000?moQ<ko000000ooPXG>00?o
0000ogf>fOmmS]T03_mmS]T00ol0003oTJCRoi6ThP03oi6ThP03o`000?n8XNGoR:7U00SoR:7U00?o
0000oiNjl?nG^_001?nG^_03o`0000_oWKo`00?o0000ojg=lOn]cO400on]cO42o`0000co/];a0_l0
0002okKHl@03o`000?o3fn_o000000CobMcW00?o0000olWZkOo9j^d01?o9j^d00ol0003oc>[ZolcZ
jP02olcZjP03o`000?oCl^Ko000000Godo?V00Go0000omKfhol0003oeokIo`000003omGoe`04o`00
0?o<oKgo0000ok?ZTE[ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP06oookJP00
2?oonfX00ol0003ooo]ZoookJP0>oookJP07o`000?o_UUOokiIGonnFEol0003okIAJo`000002onjM
J`03o`000?o/Vfgok9]]00;ok9]]0_l00005onVON`03o`000?oWW7co000000?oiZ6600?o0000on>O
Q_oSWhH00ooSWhH2o`0000?ooo]Z0ol000001?oDF`3o0000o`000?l00002onJ0?P04o`000?oTOd?o
i7m3onAo@`;o00001?oUSF400ol0003ohh]To`000003on>DMP05o`000?oQTWOohI9gon6BMol00000
0_oOTGH2o`0000Gog9J500?o0000omZDQ_oJU8H00ooJU8H2o`0000cooo]Z0_l0000:okg4h003o`00
0?o=aM;o000000[oc<;A0_l00008omW5aP03o`000?oF`<Coe/3400Ooe/340_l00005olbe``05o`00
0?oE/kOoeK>gomFc]ol000002_o?/[d00ol0003obj^iol^[^@05ol^[^@Ko00003_o0XKT6okZG/`03
o`000?naT[Ko/I:f00So/I:f00?o0000ok2?]?n`Sk@01_n`Sk@00ol0003oYHVgojF9]`09ojF9]`Co
00000_nSR;L01?l0003oU7fgoiAm]onDOKL5o`0000WoUhBm00?o0000ohYn`On:O/400on:O/400ol0
003oT8;0oi22`006oi22`003o`000?n2P<SoPX3800CoPX382?l000000omoQ<ko0000oh:5cP0=oh:5
cP03o`000?mmS]WoOHkI00koOHkI00?o0000oi6Th_nAY>800onAY>800ol0003oR:7UohRQi@09ohRQ
i@03o`000?nG^_3oUk[`00?o00003onM_o000ol0003o[Lgao`000002o`0000co/];a0_l00005okKH
l@;o00000_o9g>L2o`0000KobN[]00?o0000olcZj_o<j^X00oo<j^X2o`0000Godo?V00?o0000omKf
hooFm^<00_l00003omGoe`03o`000?o<oKgo000000;o0000FooonfX00ol0003ooo]ZoookJP0Noook
JP03o`000?oonf[ooo]Z00Kooo]Z0008oookJP03o`000?oonf[ooo]Z00kooo]Z0_l00002onnFE`03
o`000?o]U5[okIAJ00;o000000?okYe[o`000?o/Vfd00oo/Vfd2o`0000CojImk00?o0000onNLO?oW
W7`00_l000000ooVXHKo0000on>OQP04on>OQP04o`000?oQWHOo0000o`0000;ooo]Z1?l000001OoF
G@Wo0000o`000?oVP3ko000000Coi7m30_l00003onF=H@03o`000?oSRfCohh]T00;o000000GohiAf
o`000?oQTWOohI9go`000003omnAMP04o`000?oMSgSo0000o`0000?og9J500?o0000omZDQ_oJU8H0
1OoJU8H2o`0000Wooo]Z00?o0000okg4h?nma>002_nma>02o`0000Woc<;A00?o0000olVnd?l00000
2?oIaLH00ol0003oe/34omK0a008omK0a004o`000?oB^lCo0000o`0000?oc;G300Go0000omFc]ooE
/kOoeK>go`000009olnb_@03o`000?o;ZkWobj^i00Gobj^i0ol000000oo;ZkWo0000o`000003o`00
00_o`:6i2?njUk<00ol0003o/I:fok6B]P06ok6B]P03o`000?n`SkCo/8nd00Oo/8nd00?o0000ojF9
]onURKL01?nURKL5o`0000KoXhRg1?l0000>oiN4_@04o`000?n:O/7oRWk1ohYn`@;o00002_n@P/00
0ol0003oPX38oh:0b007oh:0b004o`000?n2OlSoPWo8oh9ob0Wo00001_n2QLh00ol0003oO8kIo`00
000@ogf>f@05o`000?nAY>;oTJCRoi6Th_l000001_n8XND9o`0001?oWKo`00?o0000ok;BlOnbd_40
2onbd_42o`0000So]]Sa00?o0000olWLiol000001oo9j^d00ol0003oc>[ZolcZjP03olcZjP;o0000
1?oClnH2o`0000;oe_KS0_l00003omGoe`Go0000GOoonfX00ol0003ooo]ZoookJP0NoookJP03o`00
0?oonf[ooo]Z00Gooo]Z0008oookJP03o`000?oonf[ooo]Z00kooo]Z00Go0000onb9@Ol0003okiIG
o`000004onfDFP;o00001?o/Vfd00ol0003ojIQ_o`000003onVON`03o`000?oWW7coiial00;oiial
0_l00005on>OQP05o`000?oQWHOohIf7on6MQol000000_oonfX4o`0000;oeUd900?o0000onJ0?_l0
00000ooTOd<00ol0003ohWm9o`000002onF=H@03o`000?oSRfCohh]T00;ohh]T0_l000000ooQTWOo
0000omnAMP03omnAMP05o`000?oMSgSogHmhomf?N?l000000_oLUXD00ol0003ofYB6omZDQP05omZD
QP03o`000?oGTHKo000000;o00001?oonfX2o`0000_o_LCP0_l00002ok_1g`03o`000?o<`]7oc<;A
00Goc<;A00?o0000olVnd?o9_]000_l00007omW5aP03o`000?oF`<Coe/3400Ooe/3400?o0000om:k
a?oB^l@00_oB^l@01ol0003oc;G3olbe`oo<]L?o0000omFc]ol000002Oo?/[d00ol0003obj^iol^[
^@03ol^[^@?o00001Oo;ZkT01?l0003o`:6iol2Q^Oo0XKT6o`0000Co`:6i2OnjUk<00ol0003o/I:f
ok6B]P05ok6B]P03o`000?n`SkCo/8nd00Wo/8nd00?o0000ojF9]ol000000ol00009oj>8]`;o0000
00?oYHjlo`000?nGQ;d03onGQ;d01?l0003oRWk1ohYn`Ol0000<oi22`003o`000?n2P<SoPX3800Ko
PX3800?o0000oh9ob?n2OlP00on2OlP8ohZ=dBCo00001on@Y^@00ol0003oWKo`oifol00=oifol0?o
00000_nRa?400ol0003o/];aok;Bl@08ok;Bl@?o00002_nff?43o`0000GobN[]0_l00006olcZjP03
o`000?oClnKodo?V00;odo?V00Co0000omKfhooFm^?oe_KS0_l00003omGoe`Co000000?o/nZAoook
J_oonfX0G?oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z00Gooo]Z0007oookJP03
o`000?oonf[ooo]Z013ooo]Z00Go0000onb9@Ol0003okiIGo`000004onfDFP03o`000?o/Vfgok9]]
00;ok9]]00?o0000onVHKooYV6l00_l000000ooYWg_o0000onNLO004onNLO0;o00001?oSWhH00ol0
003ohIf7on6MQ`02on6MQ`;o000000?ooo]Zo`000?l000000_l00002omIM2@?o00000_oTOd<00ol0
003ohWm9on9oB@02o`000003onF=HOl0003ohh]T00;ohh]T1?l00004omnAMP03o`000?oMSgSogHmh
00;ogHmh0ol00007omZDQP03o`000?oGTHKoei6600;oei661?l0000<okg4h003o`000?nk`Moo^l7O
00?o^l7O00?o0000olc2dOo<`]400oo<`]401?l0003obKk@olVnd?l00002omW5aP03o`000?oIaLKo
fLG600?ofLG600?o0000omK0a?oF`<@01ooF`<@00ol0003od[_4om:ka004om:ka0;o000000?oc;G3
o`000?l000002Oo?/[d01?l0003obj^iol^[^Oo;ZkT3o`0000Oobj^i00?o0000okfP^ol000002?o0
XKT9o`0000Co^YNc00?o0000ok6B]_naT[H01?naT[H00ol0003o/8ndok2?]003ok2?]0Wo00002onS
R;L2o`0000CoYHjl00?o0000oiN4_OnGQ;d03_nGQ;d2o`0000koT8;000?o0000oh:0b?n2P<P01?n2
P<P00ol0003oPWo8oh9ob005oh9ob0goRXgA00Co0000ogn9domoRM?o00004?n>V]/01?l0003oTJKT
oi6Vi?l0000>oi2Vi003o`000?nM_o3oWKo`00SoWKo`1?l00006oj;4l@03o`000?nbd_7o/];a00Go
/];a0_l0000;okKHl@03o`000?njf>oo000000;o`>3_00Go0000olWZkOo9j^gobN[]o`000006olcZ
jP03o`000?o?k^Wo000000?odo?V00?o0000omKfhooFm^<00_oFm^<01?l0003oeOoGomGoeooEomL2
o`000004olcm_Oo7n[Co0000o`0005oooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP05oookJP001ooonfX00ol0003ooo]ZoookJP0@oookJP03o`000?o/RD7ok8U100;o00001?o]U5X2
o`0000?ok9]]00?o0000onVHKooYV6l00_oYV6l2o`0000Goiial00?o0000onBJOOl000000ooSWhH0
0ol0003ohIf7on6MQ`04on6MQ`Go00000ooFG@T00ol0003oef0Do`000003o`0000?ohWm91Ol00000
1OoRR6;o0000omn6I?oOQVCo000000?ogi5f00?o0000omf?N?oMSgP01?oMSgP2o`0000KofYB600?o
0000omNAQ_oGTHH00ooGTHH00ol0003o_LCPokg4h00:okg4h0;o00001onk`Ml01_l0003oc<;Aolc2
dOo<`]7o0000olVnd0;o00001?oIaLH01Ol0003ofLG6omW5a_oIaLKo000000Woe/3400?o0000om:k
a?oB^l@01ooB^l@3o`0000Wock:m1?l00009ol^[^@04o`000?nmX;_o_J2ko`0000Wo`:6i00?o0000
okbQ_OnlXKd01OnlXKdAo`0000Oo[iBk00?o0000oj>8]onSR;L02?nSR;L2o`0000KoYHjl00?o0000
oiN4_OnGQ;d03OnGQ;d2o`0000ooT8;000?o0000oh:0b?n2P<P00on2P<P00ol0003oPWo8oh9ob006
oh9ob003o`000?n:SM7oRXgA00WoRXgA00?o0000ogn9domoRM<00_moRM<00ol0003oSY[KohjJf`0>
ohjJf`;o00004?n@Y^@00ol0003oWKo`oifol004oifol0?o00002onRa?400ol0003o/];aok;Bl@02
ok;Bl@;o00002_nff?42o`0000;o^]S_00?o0000ol3Pkoo0h>l00_o0h>l00ol0003obN[]o`000005
olcZjP;o000000?ocnkYo`000?oClnH00_oClnH00ol0003oe_KSomKfh`02omKfh`04o`000?oEomOo
eOoGomGoe`;o000000Coc?fmolOj]?l0003o0000HOoonfX00ol0003ooo]ZoookJP0LoookJP03o`00
0?oonf[ooo]Z00Gooo]Z0007oookJP03o`000?oonf[ooo]Z013ooo]Z00Co0000onb9@Oo/RD7ok8U1
0_l00003onfDFP03o`000?o[TUgo000000;ok9]]00?o0000onVHKooYV6l00ooYV6l2o`0000Coiial
00?o0000onBJOOoTVWd00_l000000ooSWhKo0000on6MQ`05on6MQ`03o`000?oOVhSo000000Co0000
0_oFG@T01?l0003oef0Do`000?oRNS`6o`0000GohXQR00?o0000omn6I?oOQV@00_l000000ooOTGKo
0000omf?N005omf?N003o`000?oJS7Wo000000;o00000_oJU8H01?l0003oei66omNAQ_oGTHH3o`00
00_o_LCP0_l0000:ok_1g`05o`000?o<`]7o0000olVnd?l000000_o>aM800ol0003ofLG6omW5aP02
omW5aP03o`000?oIaLKo000000Woe/3400?o0000om:ka?oB^l@02?oB^l@00ol0003oak33olN```02
o`0000Gock:m0ol0000;ol^[^@05o`000?nmX;_o_J2kokfP^ol000002?o0XKT00ol0003o_:6mokbQ
_@0;okbQ_@04o`000?naT[Oo/I:go`00013o[iBk00?o0000oj>8]onSR;L01OnSR;L2o`0000SoYHjl
00?o0000oiN4_OnGQ;d02_nGQ;d3o`000003oiR4_Ol0003oT8;000koT8;000?o0000oh:0b?n2P<P0
0_n2P<P00ol0003oPWo8oh9ob008oh9ob003o`000?n:SM7oRXgA00OoRXgA00?o0000ogn9domoRM<0
0omoRM<00ol0003oSY[KohjJf`0?ohjJf`03o`000?n@Y^CoT:KT00ooT:KT00?o0000oifol?nM_o00
0ol0000?oj;4l@04o`000?nbd_7o0000o`0000[o]]Sa0_l00004ok[Hk`03o`000?o0h>oo`>3_00;o
`>3_0_l00005olcZjP05o`000?o?k^WocnkYolo^jOl000000_oClnH00ol0003oe_KSomKfh`02omKf
h`07om?kh?l0003oeOoGomGoeol0003oe?oAo`000002olOj]003o`000?oonf[ooo]Z063ooo]Z00?o
0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP05oookJP001ooonfX00ol0003ooo]ZoookJP0A
oookJP06o`000?o/RD7ok8U1o`000?oZR4Ko00000_o]U5X01_l0003oji9Mon^BGOl0003ok9]]o`00
00GojIQ_00?o0000onNFL?l000000ooWW7`00ol0003oi9YmonBJO@02onBJO@;o00001_oQWHL00ol0
003ogi^8omnKR005o`000004omIM2Ol0003oef0DomMP50;o00001?oPND82o`0000CohXQR00?o0000
omn6I?oOQV@00_oOQV@2o`0000KogHmh00?o0000omZ<NOoJS7T00_oJS7T6o`0000;oY/7]0_l00009
okg4h003o`000?nk`Moo^l7O00[o^l7O0_l000000oo9_]3o0000olk5dP03olk5dP03o`000?oIaLKo
fLG600;ofLG60_l00008omK0a003o`000?oB^lCod[_400Sod[_400Ko0000olN``oo7/<?oak33o`00
0?o?/[d6o`0000cobj^i00?o0000okfP^onmX;/00onmX;/00ol0003o`:6iol2Q^@04ol2Q^@03o`00
0?nlXKgo_:6m00go_:6m0_l0000AojnD^`03o`000?nSR;OoXhRg00?oXhRg0_l0000;ojF>_003o`00
0?nGQ;goUhBm00OoUhBm0_l00004oiR4_@03o`000?n@P/3oT8;000koT8;000Co0000oh:0b?n2P<So
00003?n2OlP00ol0003oRXgAohZ=d@05ohZ=d@03o`000?moRM?oOhWC00GoOhWC00?o0000ohjJfon>
V]/03_n>V]/00ol0003oT:KToi2Vi00=oi2Vi0Go00004onRa?400ol0003o]]SaokKHl@08okKHl@;o
00001Onjf>l01?l0003o`>3_ol3Pkoo0h>l2o`0000?o`nK_0_l000000oo<j^[o0000olo^j@02olo^
j@03o`000?oClnKodo?V00Coe_KS00?o0000om?kh?l000000ooEomL01OoDom7o0000olOj]?o7n[Co
000006Cooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP05oookJP001ooonfX00ol0
003ooo]ZoookJP0AoookJP04o`000?o/RD7ok8U1o`0000;ojXQ600Co0000onfDF_o]U5[o00000_o[
TUd2o`0000GojIQ_00?o0000onNFL?oWUW000_l000000ooWW7co0000onBJO@04onBJO@;o00001OoQ
WHL01Ol0003ogi^8omnKR?l0003ogiZ800Ko00000_oGH1@2o`0000?oh7U200?o0000omiiB?l00000
0_l000000ooRR6;o0000omn6I004omn6I0;o00001OoMSgP00ol0003ofXaiomZ<N@02omZ<N@?o0000
1_nV`Nd2o`0000Ko_LCP0_l0000;ok_1g`;o00000_ni_mh00ol0003oc/GBolk5dP04olk5dP07o`00
0?oIaLKofLG6omW5a_l0003oe/35o`000006omK0a003o`000?oB^lCod[_400Sod[_400?o0000olN`
`oo7/<<00oo7/<<4o`000003olnb_Ol0003obj^i00_obj^i00?o0000okfP^onmX;/01?nmX;/00ol0
003o`:6iol2Q^@03ol2Q^@03o`000?nlXKgo_:6m00go_:6m0_l0000BojnD^`04o`000?nSR;OoXhRg
oj>8]`;o00003OnUS[`00ol0003oUhBmoiN4_@04oiN4_@?o00001onHQ;d00ol0003oT8;0oi22`00=
oi22`003o`000?n2P<So000000goPWo800?o0000ohZ=dOn:SM401On:SM400ol0003oOhWCogn9d`05
ogn9d`03o`000?n>V]_oSY[K00goSY[K00?o0000ohZSiOl000002?n@Y^@6o`0000?oU;G^00?o0000
oj;4lOnRa?403_nRa?43o`0000;oYl[b00?o0000okKHlOnff?401Onff?42o`0000Oo^]S_00Co0000
ol3Pkol0003o00001_o3i^l2o`0000CocnkY00?o0000om?ci_oFm^<00ooFm^<01?l0003odo_Pom?k
h?l00002omGoe`05omCodOl0003oaoZdolOj]?l00000I_oonfX00ol0003ooo]ZoookJP0JoookJP03
o`000?oonf[ooo]Z00Gooo]Z0007oookJP03o`000?oonf[ooo]Z017ooo]Z0_l00002onb9@@06o`00
0?oZR4KojXQ6o`000?o]U5[o00000oo[TUd2o`0000CojIQ_00?o0000onNFL?oWUW000_oWUW02o`00
00Goi9Ym00Co0000on:HO_l0003o00000ooQWHL01?l0003ogi^8omnKR?l00003omnJR003o`000?lC
N^Co000000;o00000_oGH1@2o`0000?oh7U200Co0000omiiB?oNNDSogWU80ol00004omn6I003o`00
0?oLQ6Oo000000;o00000ooMSgP4o`0000[oY/7]0_l00003okg4h0;o00002onk`Ml2o`0000;o^KoN
0_l00008olk5dP03o`000?oIaLKo000000?oe/350_l00003omK0a003o`000?oB^lCod[_400Sod[_4
00Co0000olN``oo7/<?oak331?l00003olnb_@?o00002_o;ZkT00ol0003o_J2kokfP^`06okfP^`05
o`000?o0XKWo`:6iol2Q^Ol000003onlXKd00ol0003o]iVho`00000CojnD^`?o00003onUS[`00ol0
003oUhBmoiN4_@02oiN4_@;o00002_nHQ;d00ol0003oT8;0oi22`00=oi22`0;o00003on2OlP00ol0
003oRXgAohZ=d@03ohZ=d@03o`000?moRM?oOhWC00OoOhWC00?o0000ohjJfon>V]/03?n>V]/00ol0
003oRZ?Uo`000003oi2Vi0Go00002_nD]Nh00ol0003oX/Caoj;4l@0:oj;4l@?o00001_nWb_800ol0
003o]]SaokKHl@02okKHl@;o00002Onjf>l2o`0000Ko`nK_0_l00003olOSk0?ocnkY00?o0000omKf
hooFm^<00_oFm^<01?l0003odo_Pom?kh?l00002omGoe`04omCodOl0003o0000olOj]0;o0000Iooo
nfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00Gooo]Z0007oookJP03o`000?oonf[o
oo]Z017ooo]Z0ol000000oo/RD7o0000onZ8AP02onZ8AP;o00000oo[TUd00ol0003oj91Po`000003
onVHK`03o`000?oWUW3oiiI`00?oiiI`0_l00004onBJO@05o`000?oRV7kohYQnon:HO_l000000_oQ
WHL01?l0003ogi^8omnKR?l00003omnJR0;o00000olCN^@3o`000005omIQ7?l0003oh7U2on1i@_l0
00001OoNNDP2o`0000CoghIT00Co0000omb4IooLQ6Oog8AW1?l0000>ojK1k@;o000000?o_LCPo`00
0?nk`Ml02_nk`Ml2o`0000?o^KoN00?o0000olk5d_o>aM802?o>aM82o`0000Koe/3500?o0000omK0
a?l000002_oB^l@00ol0003oak33o`000002o`0000Coak3300Co0000olnb_Oo?/[go00000_o;ZkX3
o`0000Kobj^i00?o0000okfP^onmX;/01onmX;/01?l0003o`:6iol2Q^Ol0000?okbQ_@05o`000?ng
VKSo]iVhokNI^?l000004On_U;/2o`0001;oYHjl00Co0000oiN4_Ol0003o00003?nHQ;d00ol0003o
T8;0oi22`00<oi22`003o`000?n@QlKo000000ooPWo800?o0000ohZ=dOn:SM400_n:SM400ol0003o
OhWCogn9d`08ogn9d`03o`000?n>V]_oSY[K00GoSY[K3Ol0000@oiBekP03o`000?nRa?7oX/Ca00Ko
X/Ca0ol0000:ojO:lP04o`000?nff?7o0000o`0000[o^]S_00?o0000ol?Vkoo3i^l01Oo3i^l00ol0
003oan?/olOSk004olOSk0;o00001?oFm^<01ol0003odo_Pom?kh?oCnn3o0000omGoeooDom400_l0
00000oo7n[Co0000o`00001XoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX01?oo
nfX000Oooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ohgLRo`000002o`0000CojXQ60_l00002
on^BG@03o`000?oXT63oj91P00;o000000?ojIQ_o`000?oWUW001?oWUW000ol0003oi9Abo`000003
onBJO@03o`000?oRV7kohYQn00;ohYQn0ol000000ooOVhSo0000omnJR003omnJR003o`000?oLV8So
000000Co4g[T1_l00005omiiB003o`000?oLN4go000000So00004_nV`Nd3o`0000[o^l7O00?o0000
okVog_ni_mh00_ni_mh00ol0003oc/GBolk5dP08olk5dP03o`000?o;`=3o000000Ooe/350_l00009
om:ka0?o00001oo7/<<00ol0003ock:mo`000006ol^[^P?o00000_o;ZkT00ol0003o_J2kokfP^`08
okfP^`03o`000?o0XKWo000000oo_:6m00?o0000okNI^?ngVKP00_ngVKP00ol0003o[iBkojnD^`0=
ojnD^`;o000000?o[Y>jo`000?nUS[`03onUS[`3o`00013oV8Bm00?o0000oi22`?n@P/001?n@P/0a
o`0000KoU:7M00Go0000ohbNh?n<W^3oS9kPo`00000BoiBekP03o`000?nRa?7oX/Ca00?oX/Ca0ol0
000>ojO:lP03o`000?njf>oo^]S_00Oo^]S_0_l000000onng>oo0000ol?Vk`04ol?Vk`;o00001_o7
hn`2olCbk`?o000000?oe_KSo`000?oCnn000ooCnn001?l0003oe?oAo`000?o9o/H3o`0006[ooo]Z
00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP04oookJP001_oonfX00ol0003ooo]Zoook
JP0CoookJP03o`000?oSMb;o000000;o00000ooZR4H01Ol0003oj8M:o`000?o[TUgo000000Coj91P
0_l00005onNFL003o`000?oTU7;oi9Ab00;o000000?oi9Ymo`000?oRV7h01OoRV7h3o`0000CogiZ8
00?o0000ombHR?oLV8P00ol00003oa=ji003o`000?llT_3o000000So00002?mm/_H2o`0000goY/7]
0ol00002ojK1k@03o`000?nnaMoo000000Oo^l7O0_l00004okVogP03o`000?o>aM;oc/GB00Soc/GB
00Go0000ol_0d?o;`=3obl3@o`000006omK0a@03o`000?oB^lCo000000God[_41?l0000:olN```03
o`000?o;Zk[obj^j00Sobj^j1?l0000:okfP^`03o`000?nlXKgo_:6m00go_:6m00?o0000okNI^?ng
VKP00ongVKP00ol0003o[iBkojnD^`0<ojnD^`03o`000?n^Tk[o[Y>j00;o[Y>j00?o0000ojF>_?nU
S[`02OnUS[`4o`0000;oY8fm00?o0000oiR4_OnHQ;d02onHQ;d:o`0000?oT8O60_l00004oi27aP03
o`000?n@SLcoT8g<00koT8g<00?o0000ohVAe_l000003On8TMD00ol0003oU:7MoiBQg@09oiBQg@03
o`000?n<W^3oS9kP00?oS9kP00?o0000oiBek_nD]Nh04?nD]Nh00ol0003oX/Cao`000002o`0000go
Yl[b0ol00002ojc@l`03o`000?njf>oo^]S_00Co^]S_0_l00002okkLk`03o`000?o3i^oo`nK_00;o
`nK_0_l00006olOSk006o`000?o4l^ooa?;_olCbkol0003oboKZ0_l00004om?kh0Ko000000?o[O6[
oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00Cooo]Z0006oook
JP03o`000?oonf[ooo]Z01?ooo]Z00Co0000on=g8_oSMb;ohgLR0_l00002onZ8AP06o`000?oXQd[o
j8M:o`000?o[TUgo00001?oXT602o`0000CoiiI`00?o0000onBDL_oTU7800_oTU782o`0000KohYQn
00Co0000omnFOol0003o00000_oOVXP00ol0003og9R8ombHR003ombHR005o`aih_l0003o0000o`00
0?lCN^@00_l00002ocbBl003o`000?mm/_KoOK;f00coOK;f1?l00007ojK1k@?o00001_nV`Nd00ol0
003o_/GOo`000004ok_1g`;o00001Oni_mh2o`0000Woc/GB00?o0000ol_0d?o;`=000oo;`=000ol0
003oe/35omK0a@02omK0a@04o`000?oB^lCod[_4om:ka0Go00000_oB^l@00ol0003oak33olN```08
olN```;o00002oo;ZkX00ol0003oaJg2olF]`P04o`0000Ko_J2k00?o0000okbQ_OnlXKd03?nlXKd0
0ol0003o]iVhokNI^005okNI^003o`000?n_U;_o[iBk00Wo[iBk0_l00005ojjC^P03o`000?nUS[co
YHjl00CoYHjl1Ol00006ojB=_@03o`000?nHQ;goV8Bm00KoV8Bm1Ol00003oiZ;``03o`000?n@QlKo
T8O600GoT8O60_l00007oi27aP03o`000?n@SLcoT8g<00goT8g<0_l0000?ohRAe@03o`000?nDXMgo
U:7M00SoU:7M00?o0000ohbNh?n<W^001?n<W^000ol0003oU;G^oiBekP0=oiBekP04o`000?nD]Nko
U;G^o`0000koYl[b0_l00006ojc@l`03o`000?njf>oo^]S_00;o^]S_00?o0000okkLkonng>l00_nn
g>l01Ol0003o`nK_ol?Vkoo3i^oo000000Koan?/00?o0000olCbkoo4l^l00_o4l^l00ol0003oboKZ
o`000004ol[kiP?o00000oo9om@00ol0003o[O6[oookJP1/oookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX01?oonfX000Kooo]Z00?o0000oookJ_oonfX05?oonfX01?l0003ohgLRon=g
8_oSMb82o`000003onZ8A_l0003oj8M:00;oj8M:0_l00004onR@H003o`000?oVSV;o000000?oiiI`
00?o0000onBDL_oTU7800ooTU782o`0000GohYQn00Co0000omnFOol0003ogiIo0ol00006ombHR003
o`000?l<NN;o37WR00;o000000Go4g[To`000?llT_3o?9;`o`00000>ogfbmP03o`000?nV`NgoY/7]
00;o00000_nV`Nd3o`0000[oY/7]00Co0000okk5gol0003o^l7O0_l00007okVogP03o`000?o?a]7o
000000Ooc/GB00?o0000ol_0d?o;`=001Oo;`=001?l0003oe/35omK0aOl00003om:ka0Co00000ooB
^l@00ol0003oak33olN```08olN```04o`000?o3[LCo`jg4o`0000Wobj^j00?o0000olF]`_o5[L80
1Oo5[L83o`0000;o_J2k00?o0000okjR_?l000003OnlXKd8okNI^003o`000?n_U;_o[iBk00Oo[iBk
0_l00007ojjC^P03o`000?nUS[coYHjl00Co00003?nTSKd00ol0003oV8BmoiR4_@05o`0000WoVX_3
00?o0000oi27a_n@QlH00on@QlH00ol0003oT8O6oi27aP07oi27aP03o`000?n@SLcoT8g<00coT8g<
00?o0000ohnDe?l000003on8TMD00ol0003oU:7MoiBQg@07oiBQg@03o`000?n<W^3oS9kP00GoS9kP
00?o0000oiBek_nD]Nh01onD]Nh6o`0000?oVk__00?o0000ojO:l_nWb_802OnWb_83o`0000Wo[=3c
00Co0000ok[Hkol0003o00001?nng>l00ol0003o`nK_ol?Vk`02o`0000Goan?/0_l00004olCbk`?o
00001?o:nnH00ol0003oco[Uo`000003olWoe003o`000?n]lJ_o000006kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP04oookJP001_oonfX00ol0003ooo]ZoookJP0DoookJP;o0000
0_oSMb801Ol0003ohgLYo`000?oZR4Ko000000?oj8M:0_l00003onR@H003o`000?oVSV;oiXiR00;o
000000?oiiI`o`000?oTU7801?oTU7801?l0003ohY9co`000?l00003on:HOP;o00001?oOUWl2o`00
00Kog9R800?o0000o`aih_l<NN800_l<NN85o`0000koOK;f00?o0000ojK1kOnV`Nd00ol0000>ojK1
k@04o`000?nnaMoo0000o`0000Oo^KoN00Go0000olo6dOo?a]7oclKAo`000005olk5dP03o`000?o;
`=3obl3@00Oobl3@00?o0000omK0aOl000000ol00004om:ka003o`000?oB^lCo000000[oak3300?o
0000ol>]a?o3[L@00_o3[L@00ol0003obj^jol^[^P05ol^[^P03o`000?o5[L;oaJg200WoaJg22ol0
0006okbQ_@Wo]iVh00?o0000ojnD^on_U;/01on_U;/4ojjC^PSo00003onTSKd4o`0000koVX_300Co
0000oi27a_n@QlKoT8O60_l0000;oi27aP03o`000?n@SLcoT8g<00[oT8g<00Go0000ohnDe?n?U=Co
SiCDo`00000?ohRAe@03o`000?nDXMgoU:7M00KoU:7M00?o0000ohbNh?n<W^001_n<W^001?l0003o
U;G^oiBek_nD]Nh5o`0000[oVk__00?o0000ojO:l_nWb_801_nWb_82o`0000go[=3c00?o0000okkL
konng>l01?nng>l3o`0000Koan?/00?o0000olCbkoo4l^l01?o4l^l00ol0003ob__Vol[kiP03ol[k
iP03o`000?o?n^Go000000?obOoD00?o0000ojgaZol00000L?oonfX00ol0003ooo]ZoookJP0Foook
JP03o`000?oonf[ooo]Z00Cooo]Z0006oookJP03o`000?oonf[ooo]Z01Gooo]Z0_l000001?oSMb;o
0000on=g:OoSMbT2o`0000?oj8M:00?o0000onJ6C_l000000_oXT6000ol0003oiXiRonJ>HP02onJ>
HP;o00001OoTU7801Ol0003ohY9con:BLooRTW?o000000;ohYQn0_l00004omnFO`04o`000?oMTh3o
0000o`0000Cog9R80_l00005o`aihP03o`000?lgT_3o0000017o00000onT`Nh2o`0000coY/7]0_l0
0002okc4h003o`000?ni_mko^KoN00?o^KoN00?o0000olo6dOo?a]400oo?a]401Ol0003oc/GBolk5
d_o>aM;o000000Wobl3@0ol00009om:ka0;o00002Oo7/<<00ol0003o`jg4ol>]a003ol>]a003o`00
0?o;Zk[obj^j00Cobj^j00?o0000olF]`_o5[L802Oo5[L800ol0003o^Z2nokZP_P03okZP_P03o`00
0?nlXKgo_:6m00?o_:6m2ol00005okNI^004o`000?n_U;_o[iBkojnD^`?o000000?o[iBko`000?l0
00000ol00006ojjH`003o`000?nTSKgoY8fm00coY8fm0_l000000onVTl;o0000oiZ;``0?oiZ;``04
o`000?n@QlKo0000o`0000goT8O600?o0000oi2=c?n@SL`02On@SL`00ol0003oSiCDohnDe002ohnD
e003o`000?n8TMGoR97E00koR97E00?o0000oiBQgOnDXMd01?nDXMd00ol0003oS9kPohbNh005ohbN
h0Ko00004?nK^nl00ol0003oYl[bojO:lP03ojO:lP;o00003?n/d?<2o`0000?o/MSd00?o0000okkL
konng>l00_nng>l00ol0003oan?/olOSk005olOSk003o`000?o4l^ooa?;_00Coa?;_00?o0000ol[k
i_o:nnH00_o:nnH2o`000003olojiOl0003obOoD00;obOoD00?o0000ojgaZol00000L_oonfX00ol0
003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00Cooo]Z0006oookJP03o`000?oonf[ooo]Z01Go
oo]Z00Go0000omIO0?l0003ohgLRo`000002on=g:@;o00000ooXQdX01_l0003oiXI>o`000?l0003o
j91Po`0000CoiXiR0_l00004onBDLP03o`000?oRTW?ohY9c00;ohY9c1?l00004omnFO`04o`000?oM
Th3ogI>0omfCP0;o00000_oLV8P01?l0003ofYJ9omZFROl00004o`aihP04o`000?lgT_3o=i;`o`00
00ooO;;f00?o0000ojC1k_nT`Nh00_nT`Nh2o`0000OoY/7]0ol00003ojC0k@;o_<CP00Go0000okVo
g_ni_mko^KoNo`000007olo6d@03o`000?o>aM;o000000Oobl3@1?l000000oo7_=3o0000om:ka007
om:ka003o`000?o=]/?ocKK300?o00001Oo7/<<00ol0003o`jg4ol>]a005ol>]a003o`000?o;Zk[o
bj^j00;obj^j00?o0000olF]`_o5[L802Oo5[L800ol0003o^Z2nokZP_P05okZP_P03o`000?nlXKgo
_:6m00Go_:6m00?o0000okRQ`_nhXL801OnhXL89o`000003ojnD^ol0003o[YS000co[YS000?o0000
ojB=_OnTSKd02OnTSKd3o`0000CoYY?200?o0000oiZ;`onJRl<03OnJRl<2o`00013oT8O600?o0000
oi2=c?n@SL`01on@SL`00ol0003oSiCDohnDe004ohnDe003o`000?n8TMGoR97E00goR97E00?o0000
oiBQgOnDXMd01?nDXMd00ol0003oS9kPo`000005o`0000?oU:CQ00?o0000oi^kkonK^nl04OnK^nl0
0ol0003oYl[bo`000002o`0000_o[=3c0_l00007ok7Hm004o`000?nng>oo0000o`0000Koan?/0_l0
0006olCbk`03o`000?o:nnKob__V00;ob__V00Co0000olojiOo?n^Go00000oo9om@00onjnlGo0000
o`00001coookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX01?oonfX000Kooo]Z00?o
0000oookJ_oonfX05_oonfX01?l0003oeUl0o`000?l00003on=g:@;o00000_oXQdX01?l0003oiXI>
onJ6C_oVQTh2o`0000CoiXiR00Co0000onB=IOl0003o00000ooTU7800ol0003ohY9con:BL`02on:B
L`?o00001?oOUWl00ol0003ogI>0omfCP003omfCP0?o00000ooJUXT00ol0003o0WGNo`000002o`ai
hP04o`000?lgT_3o=i;`o`0000ooO;;f00?o0000ojC1k_nT`Nh00onT`Nh2o`0000;oY/7]0ol00007
ojC0k@05o`000?nla>3o0000okVog_l000002Oo?a]42o`0000Cobl3@0ol00002ol_0d005o`000?o7
_=3oakc@olNld?l000001_oB^l@00ol0003ocKK3olff``04olff``?o000000?oak33o`000?o3[L@0
1oo3[L@01Ol0003obj^jol^[^_o;Zk[o000000_oaJg200?o0000okZP__njX;h01_njX;h00ol0003o
_:6mokbQ_@04okbQ_@03o`000?nhXL;o^:7200_o^:7200?o0000ojnD^on_U;/00_l0000?ojjH`003
o`000?nTSKgoY8fm00KoY8fm0_l00007ojJC`P03o`000?nJRl?oVX_300[oVX_30ol000000onKS<?o
0000oi27aP0?oi27aP03o`000?n@SLcoT8g<00KoT8g<00?o0000ohnDe?n?U=@01On?U=@00ol0003o
R97EohRAe@06ohRAeA3o00002_nDY>400ol0003oVk__oi^kk`0Aoi^kk`03o`000?n/d??o[=3c00Wo
[=3c0ol0000:ok7Hm003o`000?o1hNoo000000Goan?/00?o0000olCbkoo4l^l01?o4l^l00ol0003o
b?;]o`000002ol[kiP;o00000_o?n^D01Ol0003obOoDolWoe?o9omCo^__500;o0000MOoonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00Cooo]Z0006oookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000omIO0?oFG`000_l00002on=g:@05o`000?oSMc3o0000onR7B_l000001?oVQTh2o`00
00CoiXiR00Co0000onB=IOoTSFGo00000_oTU7802?l0003ohY9con:BLooRTW?o0000on:BLol0003o
gi1e0_l00003omnFO`03o`000?oMTh3ogI>000CogI>00_l00003omZFR@;o000000Co0WGNo`000?l<
NN;o00000_lgT_000ol0003oO;;fogbbmP0=ogbbmP04o`000?nT`NkoY<7^ojC1kP;o000000?oY<7^
o`000?l000002onT`>d00ol0003o_<CPo`000009olo6d@03o`000?o=`]3ocL;@00Co00001?o;`=00
0ol0003oakc@olNld003olNld003o`000?oB^lCod[_400;od[_400?o0000olff`oo=]/<02?o=]/<2
o`0000Wo`jg400?o0000ol^[^_l000002oo5[L800ol0003o^Z2nokZP_P07okZP_P03o`000?nlXKgo
_:6m00?o_:6m00?o0000okRQ`_nhXL803OnhXL82o`00017o[YS000?o0000ojB=_OnTSKd01?nTSKd2
o`0000WoYY?200?o0000oiZ;`onJRl<02?nJRl<2o`0000GoVhc300?o0000oi27a_n@QlH03_n@QlH0
0ol0003oT8g<oi2=c004oi2=c003o`000?n?U=CoSiCD00;oSiCD3Ol00008oiJLf005o`000?nDYN7o
U:GQoiBUhOl000003_nDY>400ol0003oVk__oi^kk`0:oi^kk`Co00000onQ`o400ol0003o[=3cojc@
l`06ojc@l`;o00002_naf?@2o`0000;o]Mke0_l00003olOSk0;o00001_o4l^l00ol0003ob?;]o`00
0002ol[kiP05o`000?o?n^Goco[UolojiOl000000oo9om@00onjnlGo0000ojgaZ`1goookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX00ooonfX000Kooo]Z00?o0000oookJ_oonfX05ooo
nfX3o`000006omMP1ol0003ohgLYon=g:Ol0003ohgL`0ol00003onJ6CP04o`000?oUQE;o0000o`00
00;oiXiR00Co0000onB=IOoTSFGoi8eU0ol00002on:BL`04o`000?oRTW?ohY9co`0000?ogi1e00Co
0000omnFOooOUWoo00001_oMTh000ol0003ofY61o`000002o`000004omZFROl0003o0000o`0000;o
0WGN1?l00008ogbbmPKo000000CoO;;fo`000?l0003o00001OnQ`O000ol0003oY<3]ojC0k@08ojC0
k@;o00002Oo?a]400ol0003ocL;@o`000003o`0000Gobl3@00?o0000olNld?o7_=001?o7_=001Ol0
003od[_4om:ka?oB^lCo000000[ocKK300?o0000olVhb_o9^<X00_l00008ol>]a003o`000?o5[L;o
aJg200WoaJg200?o0000okZP__njX;h02OnjX;h01Ol0003o_:6mokbQ_OnlXKgo000000oo^:720_l0
000BojjH`004o`000?nTSKgoY8fmojB=_@?o00003?nVTl800ol0003oVX_3oiZ;``04oiZ;``?o0000
1onKS<<00ol0003oT8O6oi27aP0>oi27aP04o`000?n@SLcoT8g<oi2=c0So00001On@T]400ol0003o
UYcHoiJLf00>oiJLf003o`000?nDYN7o000000ooU:CQ00?o0000oi^kkonK^nl01OnK^nl5o`0000So
XL?a00?o0000ojc@lon/d?<00on/d?<2o`0000[o/MSd0_l00004okGNm@05o`000?nkh_;o0000olOS
k?l000001_o4l^l2o`0000;ob?;]00?o0000ol[ki_l000000oo?n^D01oo6o]ko0000olWoe?o9omCo
^__5o`000?n]lJ/0N?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00?ooo]Z0005
oookJP03o`000?oonf[ooo]Z01Sooo]Z00Go0000okhm0?l0003o0000omMP1`03o`0000?ohgL`1?l0
00001ooVQTko0000onF5D_oUQE;o0000onJ>H_l000001OoTSFD00ol0003ohY9co`000003on:BL`03
o`000?oOT7Gogi1e00;ogi1e0ol00006omfCP003o`000?oJTH7ofY6100;ofY610ol000000ol0>JCo
0000o`000002o`9egP[o00002?mh/_L00ol0003oXL7`oj71l005oj71l0;o00001OnT`>d3o`0000;o
`/KM00?o0000olo6dOo?a]401Oo?a]43o`0000CocL;@00Go0000ol_0d?o;`=3obl3@o`000008olNl
d003o`000?oB^lCo000000[ocKK300?o0000olVhb_o9^<X00oo9^<X3o`0000Co`jg40_l0000:olF]
`P03o`000?njX;ko^Z2n00[o^Z2n00Co0000okbQ_OnlXKgo00003onhXL800ol0003o]I^nojjH`00C
ojjH`003o`000?nTSKgo000000ooYY?200?o0000oiZ;`onJRl<00_nJRl<2o`0000[oVhc300?o0000
oi27a_n@QlH02on@QlH8o`0000goT9;A00?o0000oiJLf?nFW=P03_nFW=P00ol0003oU:CQoiBTh@0?
oiBTh@03o`000?nK^nooVk__00Co00003_nQ`o400ol0003o[=3co`000002o`0000[o/MSd0_l00005
okGNm@03o`000?nkh_;o^n;b00;o00001_o4l^l01?l0003ob?;]olSbkOo8l^d3o`0000;oco[U00?o
0000olKng_l000000_o9om@2ok[ka@03o`000?oonf[ooo]Z07Sooo]Z00?o0000oookJ_oonfX04ooo
nfX00ol0003ooo]ZoookJP03oookJP001OoonfX00ol0003ooo]ZoookJP0IoookJP04o`000?nn?@3o
0000o`0000;oef0700So0000on=g<?oSMc3ohgL`o`000?oRMcKo0000onJ5C0So00000_oTSFD5o`00
00?ohY9c00?o0000omn@MOoOT7D01?oOT7D2o`0000GogI>000?o0000omZAPOoJTH401?oJTH42o`00
0005omRDROl0>JCo073Io`000?l2MMh00_l000000ol`TNoo0000ogRbm`0=ogRbm`03o`000?nQ`O3o
XL7`00KoXL7`00?o0000ojC0kOl000000ol00005ol;6g@04o`000?o?a]7oclKAolo6d@?o00002?o=
`]000ol0003obl3@o`000009olNld0;o00002_o=]/<00ol0003obKS:olVhbP07olVhbP;o000000Go
`jg4o`000?o3[<Co`jc4o`000008olF]`P03o`000?njX;ko^Z2n00_o^Z2n00?o0000okbQ_Ol00000
3onhXL801?l0003o]I^nokFK__neVkhBojjH`0;o00004OnVTl800ol0003oVX_3oiZ;``02o`0000go
Vhc300Co0000oi27a_n@QlKoT8O62Ol00004oiF@c003o`000?n@T];o000000koT9;A00?o0000oiJL
f?nFW=P03OnFW=P2o`0000ooU:CQ1Ol0000Coj73l@03o`000?naf?Co/MSd00So/MSd0ol00006okGN
m@04o`000?nkh_;o0000o`0000?o_^Wc00Go0000olCbkoo4l^ooa?;_o`000003olSbk@;o00000oo?
n^D01Ol0003oa_kNo`000?o9omCo000000;o^__500?o0000oookJ_oonfX0N_oonfX00ol0003ooo]Z
oookJP0BoookJP03o`000?oonf[ooo]Z00?ooo]Z0005oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o
0000okhm0?l000000ooGH0L2o`0000;ohgL`00?o0000on9g=_l000000_l00003onB4D0Go00000_oT
S6@00ol0003ohH]Von6;IP02o`000003on:BLol0003ogi1e00Gogi1e00?o0000omf>M_l000000_l0
0002omfCP003o`000?oJTH7ofY6100CofY6100?o0000omR?POl000000ol000001_l0L=Wo0000o`9e
g_l0003o<97_o`0000koN;;g00?o0000oj71l?nQ`O001?nQ`O000ol0003oXL7`o`000002o`0000So
`/KM0ol000000oo?a]7o0000olg2d009olg2d0;o00002?o7_=000ol0003o`kS@o`000009olff``03
o`000?o9^<[obKS:00WobKS:1_l00007olF]`P03o`000?njX;ko^Z2n00co^Z2n0_l0000>okRQ`P;o
00001?neVkh00ol0003o[YS0ojjH`00=ojjH`0;o000000?o[YS0o`000?nVTl803onVTl83o`0000ko
Vhc31_l0000=oiF@c0;o00004?n@T]400ol0003oUYcHoiJLf00;oiJLf004o`000?nDYN3oU:GPo`00
00WoU:CQ1Ol00004oiRek003o`000?nQ`o7oXL?a00coXL?a0ol00003ojK:l`03o`000?naf?Co/MSd
00Go/MSd0_l00009okGNm@;o00001_nnjO<00ol0003oa?;_o`000004olSbk@09o`000?o?n^Goco[U
olojiOl0003oa_kNo`000?o9omCo000000;o^__500?o0000oookJ_oonfX0NooonfX00ol0003ooo]Z
oookJP0BoookJP03o`000?oonf[ooo]Z00?ooo]Z0005oookJP03o`000?oonf[ooo]Z01_ooo]Z00[o
0000okhm0?l0003o0000omMP1ol0003of68?o`000?oSMc3o00000ooRMcH2o`0000Coi8A@00?o0000
on:3E?l000000_oTS6@00ol0003ohH]Von6;IP02on6;IP;o00001_oOT7D00ol0003ogHifomf>MP02
omf>MP?o00001_oJTH401?l0003of8n1omR?POoHSh42o`000004ofP00?l0003o073Io`1`f@?o0000
3_mh/_L00ol0003oXL7`oj71l003o`0000;oWL;b0_l00006ol;6g@?o000000Co`/KMo`000?o?a]7o
00002Oo=`]001Ol0003ob[k?olZncoo:_/oo000000Koakc@00Go0000ol>hd?o3^=3o`kS@o`000007
olff``03o`000?o9^<[obKS:00WobKS:00?o0000okn[a_noZlH00onoZlH5o`0000;oaJg200?o0000
okZP__njX;h03?njX;h00ol0003o^j?0o`00000=okRQ`P03o`000?neVkko]I^n00Co]I^n00?o0000
ojjH`?n^V<003?n^V<000ol0003o[YS0ojjH`002ojjH`003o`000?nVTl;oYY?200[oYY?20ol00002
ojFC`P03o`000?nKS<?oVhc300SoVhc31?l00002oijCb003o`000?nET<coUI3<00coUI3<0_l00000
0onFT<_o0000oi2Bd@0?oi2Bd@03o`000?nFW=SoUYcH00[oUYcH00?o0000oiBUh?nDYN000_nDYN00
1?l0003oU:CQoiBThOnDY>45o`0000[oV;G/00?o0000oj73lOnQ`o402?nQ`o43o`0000OoY/[c00?o
0000ok7Hm?naf?@00_naf?@2o`0000[o]Mke0_l00007okkYl`;o00001?o8l^d01Ol0003oco[Uoloj
iOo?n^Go000000;oa_kN0_l00002ok[ka@03o`000?oonf[ooo]Z07gooo]Z00?o0000oookJ_oonfX0
4OoonfX00ol0003ooo]ZoookJP03oookJP001OoonfX00ol0003ooo]ZoookJP0LoookJP;o000000Go
`T00o`000?oGH0Oo0000omQR3`02o`0000CohWLf0_l00003onB4D003o`000?oRPeCohX=D00;o0000
00?oi8aTo`000?oQRfH00ooQRfH2o`0000Gogi1e00?o0000omf>M_oMSWH01?oMSWH2o`0000GofY61
00?o0000omR?POoHSh400ooHSh42o`000004ofP00?l0003o073Io`1`f@oo000000?oN;;go`000?l0
00000onM`_82o`0000Go`/KM0ol00004ol;6g@;o00002Oo=`]000ol0003ob[k?olZnc`03olZnc`;o
00000oo7_=000ol0003o`kS@ol>hd003ol>hd003o`000?o=]/?ocKK300?ocKK300?o0000olVhb_o9
^<X02Oo9^<X00ol0003o_j_6okn[aP05okn[aP04o`000?o5[L;oaJg2olF]`PCo00003?njX;h01Ol0
003o^j?0ok^S`?nkXl3o000000_o^:7200?o0000okFK__neVkh01_neVkh00ol0003o[YS0ojjH`009
ojjH`0;o00001On^V<000ol0003oYY?2ojJC`P07ojJC`P?o00001OnUTl800ol0003oVhc3oi^<``04
oi^<``Co00001onNTlP00ol0003oUI3<oiF@c00:oiF@c003o`000?nFT<_oUY3;00;oUY3;00?o0000
oi2BdOn@T]403_n@T]400ol0003oUYcHoiJLf008oiJLf003o`000?nDYN3oU:GP00Oo00004?nH]N`0
0ol0003oXL?aoj73l@04oj73l@?o00002onVb_<01?l0003o/MSdo`000?l0000;okGNm@03o`000?nn
jO?o_^Wc00Go_^Wc0_l00004ol?Xl0Co000000Coco[Uo`000?o6o]koa_kN0_l00002ok[ka@03o`00
0?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP03oookJP001Ooo
nfX00ol0003ooo]ZoookJP0LoookJP?o000000?o`T00o`000?l000000_oHHPl2o`0000?ohWLf00?o
0000on1f>_l000000_oTQ5000ol0003ohX=Don:3E002on:3E0;o00001?oQRfH00ol0003oghUXo`00
0002o`0000;ogi1e00?o0000omf>M_oMSWH01?oMSWH01?l0003ofXago`000?l00003omZAP@03o`00
0?oHSh7of8n100Gof8n11?l000001?l0L=Wo0000o`000?l0000>og>an0Co00000oo2a]d3o`0000Go
`/KM0_l000000oo0`mco0000olg2d006olg2d0;o00002?o:_/l00ol0003oakc@o`000007ol>hd005
o`000?o=]/?ocKK3olff`ol000002oo9^<X00ol0003o_j_6okn[aP07okn[aP04o`000?o5[L;oaJg2
o`0000?o`JJn1?l00007okZP_P03o`000?nkXl3o^j?000;o^j?000?o0000okRQ`_nhXL802?nhXL80
0ol0003o]I^nokFK_P07okFK_P03o`000?n^V<3o[YS000Oo[YS00_l00008ojjH`003o`000?nVTl;o
YY?200?oYY?20ol00009ojFC`P03o`000?nKS<?o000000?o00002onNTlP00ol0003oUI3<oiF@c008
oiF@c0;o00001OnFT</00ol0003oT9;Aoi2Bd@0>oi2Bd@03o`000?nFW=SoUYcH00?oUYcH2?l00004
oiFQg@03o`000?nH]NcoV;G/017oV;G/00?o0000oj73lOnQ`o400ol0000?ojK:l`03o`000?neg_Go
]Mke00So]Mke0_l000000onjg_;o0000okkYl`04okkYl`;o00001Oo3j?02okcfl003o`000?o2n^_o
000000Ko000000?o[_S3oookJ_oonfX0P_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[o
oo]Z00?ooo]Z0005oookJP03o`000?oonf[ooo]Z01gooo]Z0ol000000oo2@03o0000o`000002omQR
3`;o00000ooRMcH01_l0003oh7Hjo`000?l0003oi8A@o`0000CohX=D0_l00004on6;IP04o`000?oO
RFSoghUXomn9J0?o00001_oMSWH01Ol0003ofXagomZ<MooJS7Oo000000;ofY6100?o0000omR?POoH
Sh401OoHSh401ol0003oeXf2o`000?mX003o0000o`1ZdOl0L=T00_l0000=og>an004o`000?o3a]co
`lKLol?6g0?o00001oo2a]d00ol0003o`<?Lol33g002ol33g003o`000?o=`]3ocL;@00?ocL;@00?o
0000olZncoo:_/l02Oo:_/l2o`0000So`kS@00?o0000olff`ol000002oo9^<X00ol0003o_j_6okn[
aP08okn[aP03o`000?o5[L;o000000So`JJn1?l00002okZP_P03o`000?nkXl3o^j?000Co^j?000?o
0000okRQ`_nhXL801_nhXL8<okFK_P03o`000?n^V<3o[YS000Go[YS000?o0000ojjH`?n^V<002?n^
V<000ol0003oYY?2ojJC`P03o`0000_oYI?20ol0000@oijCb003o`000?nET<coUI3<00GoUI3<0_l0
0008oiJ@b`03o`000?n@T]7oT9;A00_oT9;A2?l00003oiJRg@03o`000?nEXMgoUJ7M00OoUJ7M00?o
0000oiRek?nH]N`04OnH]N`2o`0000koY/[c0ol00002oj_Bm@03o`000?neg_Go]Mke00Go]Mke0_l0
0002ok[NlP03o`000?nnjO?o_^Wc00;o_^Wc0_l00004ol?Xl0;o00000_nlm_000ol0003o`_[[o`00
0003olKjj@04o`000?n^n<Oo0000ojkh`hGooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Z
oookJP03oookJP001OoonfX00ol0003ooo]ZoookJP0NoookJP;o00000_o2@0001_l0003of68?omQR
3ol0003of68Fo`0000;ohWLf00Co0000on1f>_oPMS[oh7Hj0_l00004on:3E004o`000?oPPEOo0000
o`0000;ohH]V00?o0000omn9J?oORFP00ooORFP2o`0000GogHif00?o0000omZ<MooJS7L00_oJS7L3
o`0000Oof8n100?o0000omJ=P_oFSH800_oFSH82o`000003o`1ZdOl0003o000000_oLk7h00?o0000
ol?6g?l000000_l000000oo3a]co0000ol;6g@05ol;6g@;o00001_o0`m`01Ol0003ocL;@olg2d?o=
`]3o000000[ob[k?00Co0000olNjc_o7^/koak[>0ol00005ol>hd0;o00002oo9^<X00ol0003o_j_6
okn[aP09okn[aP;o00003Oo1Y[h7o`0000;o^j?000?o0000okRQ`_nhXL801OnhXL8=okFK_P03o`00
0?n^V<3o[YS000Co[YS000?o0000ojjH`?n^V<000on^V<09o`0000_oYI?20ol000000onUV<So0000
oijCb00@oijCb003o`000?nET<coUI3<00CoUI3<00?o0000oiJ@bonFT</02?nFT</00ol0003oT9;A
oi2Bd@06oi2Bd@Go00000onJWMH00ol0003oUZ;MoiJRg@04oiJRg@03o`000?nEXMgoUJ7M00WoUJ7M
00?o0000oiRek?nH]N`02_nH]N`4o`0000;oW[g^00?o0000ojK:lonVb_<02_nVb_<3o`0000KoZm;e
00?o0000okGNmOneg_D00_neg_D2o`0000?o^]kb00Co0000okkYlonnjO?o_^Wc0_l00004ol?Xl0;o
00000onlm_03o`0000?oa_[Y0ol000000on^n<?ooo]ZoookJP25oookJP03o`000?oonf[ooo]Z00oo
oo]Z00?o0000oookJ_oonfX00_oonfX000Gooo]Z00?o0000oookJ_oonfX07ooonfX2o`0000;o`T00
0_l000000ooHHPoo0000omQR5P03o`0000Coh7Hj0_l00004on:3E006o`000?oPPEOoh85Go`000?oQ
RfKo00001OoORFP01?l0003og8MZo`000?l00003omf>MP03o`000?oJS7OofXag00CofXag0_l00006
omR?P@03o`000?oFSH;oeXf200CoeXf20_l000000ol0J]7o0000o`00000;o`0000Go`lKL00Co0000
ol;6gOo2a]go`/KM0_l00009ol33g003o`000?o=`]3o000000[ob[k?00?o0000olNjc_o7^/h01Oo7
^/h3o`000004ol>hd?l0003o`[K>o`0000[obKS:00?o0000okn[a_noZlH02OnoZlH00ol0003o^j[8
o`00000<ol6V_P03o`000?nm[<Wo_Jc900Go_Jc94Ol00006okFK_P03o`000?n^V<3o[YS000;o0000
00?o[YS0o`000?l000001Ol00007ojjG`003o`000?nUTl;oYI?200SoYI?20_l00005ojFHb003o`00
0?nNTlSoWY?800ooWY?800Go0000oiF@c?nET<coUI3<o`00000<oiJ@b`04o`000?n@T]7oT9;Aoi2B
d@Go00002OnJWMH00ol0003oUZ;MoiJRg@02oiJRg@03o`000?nEXMgoUJ7M00[oUJ7M00?o0000oiRe
k?nH]N`01OnH]N`5o`0000OoW[g^00?o0000ojK:lonVb_<01onVb_<2o`0000[oZm;e00Co0000okGN
mOl0003o00001?njg_800ol0003o_^WcokkYl`02o`0000Go`nS`00?o0000okcfl?nlm_000_nlm_02
o`0000Coa_[Y0_l00002ojkh`hWooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP02
oookJP001?oonfX00ol0003ooo]ZoookJP0QoookJPCo000000CoaD<0o`000?oHHPoo00000_oHHQH2
o`0000?oh7Hj00Co0000omie?ol0003o00000_oRPe@01?l0003oh85Gon21EooPPEL3o`0000CoghUX
00Go0000omb7J_oLQf[og8MZo`000002omf>MP03o`000?oJS7OofXag00CofXag00?o0000omR9N?l0
00000_l00003omR?P@03o`000?oFSH;oeXf200CoeXf200Go0000og`00?l0003o0000o`1Zd@02o`00
00?oK;3i0ol00009ol?6g003o`000?o2a]go000000_o`<?L0_l0000:olZnc`03o`000?o7^/koak[>
00Woak[>0_l00002ol:fcP03o`000?o9^<[obKS:00KobKS:00?o0000okn[a_noZlH02OnoZlH01Ol0
003o^j[8ok^Zb?nkZ/So000000[o`JJn00?o0000okf/bOnm[<T02Onm[<T01?l0003o^:71okRQ`Ol0
000:okFK_@[o00004On^Ul000ol0003oYI?2ojFC`P04ojFC`P?o00001onUV<P00ol0003oWY?8oijC
b00?oijCb004o`000?nET<coUI3<o`0000[oUY3;1ol0000?oiZMeP04o`000?nFX]goUZ;Mo`0000ko
UJ7M00?o0000oiRek?nH]N`01?l0000=oijmkP03o`000?nVb_?oY/[c00?oY/[c0ol0000=oj_Bm@03
o`000?njg_;o^]kb00Co^]kb0ol00005ol?Xl0;o00001?nlm_02o`0000?oa_[Y0ol000000on^n<?o
0000oookJP29oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX00_oonfX000Cooo]Z
00?o0000oookJ_oonfX08_oonfX4o`000003olE30?l0003o000000?of68F0_l00003on1f>P06o`00
0?oNMCoogWDoo`000?oRPeCo00001OoPPEL2o`0000CoghUX00Co0000omb7J_oLQf[og8MZ0ol00006
omZ<M`03o`000?oHRGSof8Uh00;of8Uh1?l00006omJ=PP03o`000?oCRh;odh^200So00000_nba>L0
0ol0003o`lKLol?6g007ol?6g0;o00002_o0`m`01?l0003o_KoKokfofol00007olZnc`;o00002_o7
^/h01?l0003o`kK>ol>fc_o3]/h2o`000003ol:fc_l0003obKS:00GobKS:00?o0000okn[a_noZlH0
2OnoZlH00ol0003o^j[8ok^Zb003ok^Zb003o`000?o1Y[ko`JJn00Ko`JJn00?o0000okf/bOnm[<T0
2onm[<T2o`0001;o]I^m00?o0000ojjG`?n^Ul004On^Ul000ol0003oYI?2ojFC`P02ojFC`P;o0000
2onUV<P00ol0003oWY?8oijCb00>oijCb0;o00001?nFT</8o`0000CoVIgF00?o0000oiZMe_nJWMH0
3onJWMH00ol0003oUZ;Mo`00000>oiFQg@Co00004_nN_Nh00ol0003oY/[co`000002o`0000goZm;e
0_l00003ojoKm`Co^]kb0_l00006ol?Xl003o`000?nlm_3o_?K`00?o_?K`00?o0000olKjjOo6n^T0
0_o6n^T3o`000003ojkh`ol0003ooo]Z08_ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP02oookJP001?oonfX00ol0003ooo]ZoookJP0ToookJP?o00000_o5@`001Ol0003of68FomQR
5_l0003of6<M00;o000000?oh7Hjo`000?oNMCl00_oNMCl3o`0000Coh85G00Co0000omeoFOl0003o
00000_oORFP00ol0003og8MZomb7JP03omb7JP;o00001OoJS7L00ol0003of8UhomR9N005omR9N0;o
00001OoFSH800ol0003odh^2om>;PP06o`0000Go//CW00?o0000ol?6g?o3a]`01?o3a]`01Ol0003o
`/CKol;4foo2a=_o000000Oo`<?L0_l00004okfof`03o`000?o:_/oob[k?00?ob[k?00?o0000olNj
c_o7^/h02Oo7^/h00ol0003o`kK>ol>fcP04ol>fcP;o00001Oo9^<X00ol0003o_j_6okn[aP09okn[
aP03o`000?nkZ/So^j[800Co^j[800?o0000ol6V__o1Y[h01?o1Y[h2o`0000go_Jc90_l0000AokFK
_@03o`000?ncYL_o000001?o[YO000?o0000ojFC`_nUTl800_l0000=ojFHb003o`000?nNTlSoWY?8
00_oWY?82Ol0000=oiVMeP03o`000?nJWMKoVYgF00koVYgF0_l0000;oiFQg@Co00000_nJ/^P00ol0
003oW[g^oijmkP0BoijmkP03o`000?n[d_GoZm;e00_oZm;e0ol00006ojoKm`03o`000?njg_;o0000
00Ko`nS`0_l00005okcfl006o`000?o6n^Woa_[YolKjjOl0003o^_gP0_l000000on^n<?o0000oook
JP2=oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX00_oonfX000Cooo]Z00?o0000
oookJ_oonfX09OoonfX00ol0<j_o0000o`000002olE300;o000000Oof68Fo`000?oHHagof6<Mo`00
0?oPMS[o000000CogWDo0_l00004on21E`06o`000?oMOeWogGmIo`000?oORFSo00001OoLQfX00ol0
003ofXE/o`000002o`0000?ofXag00?o0000omR9N?oHRGP01?oHRGP00ol0003oeXMio`000002o`00
00?oeXf21Ol00009ok;4i`04o`000?o3a]co`lKLol?6g0;o00001Oo2a=/2o`0000?o`<?L0_l00007
okfof`05o`000?o:_/oob[k?olZncol000002oo7^/h00ol0003o`kK>ol>fcP07ol>fcP?o000000?o
bKS:o`000?noZlH02_noZlH00ol0003o^j[8ok^Zb006ok^Zb003o`000?o1Y[ko`JJn00;o`JJn00?o
0000okf/bOnm[<T03?nm[<T00ol0003o]:;6o`00000?okFK_@;o00000oncYL/00ol0003o[YO0ojjG
`00AojjG`003o`000?nUV<SoYIS800ooYIS800?o0000oijCb?nNTlP01onNTlP6o`0000;oWi[?00?o
0000oiVMe_nIWMH03_nIWMH00ol0003oVYgFoiZMeP0=oiZMeP03o`000?nJXmco000000OoUJ7M1?l0
0007oiZbj003o`000?nN_NkoW[g^00coW[g^0ol00002oj?5l@03o`000?n[d_GoZm;e00WoZm;e0_l0
000:ojoKm`?o00000oo3j?02o`0000Go_?K`00?o0000ol3gk_l000000_o6n^T00ol0003o^_gPo`00
0002ojkh``03o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP02oookJP001?oonfX00ol0003ooo]ZoookJP0VoookJP03o`0cZol0003o000000;o000000CoadH0
o`000?oHHQKo00000_oHHad2o`0000CogWDo00Co0000omad@ol0003o00000_oPPEL01?l0003ogGmI
omeoFOoMOeT3o`0000Gog8MZ00Co0000omZ5K?oJQFcofXE/1?l00006omR9N003o`000?oFQgWoeXMi
00;oeXMi1_l0000<ok;4i`03o`000?o3a]co000000Wo`/CK00?o0000ol33g?l000002_nm_m/00ol0
003ob[k?o`00000;olNjcP03o`000?o3]/ko`kK>00Wo`kK>00?o0000olVhbOl000000_l00009okn[
aP03o`000?nkZ/So^j[800Oo^j[800Go0000ol6V__o1Y[ko`JJno`00000>okf/b@05o`000?ndX/Ko
]:;6okBRa_l000003OneVkd00ol0003o/jG;ok>Ub`03ok>Ub`03o`000?n^Ul3o[YO000ko[YO00_l0
00000on_X/[o0000ojFHb00@ojFHb003o`000?nNTlSoWY?800CoWY?81Ol00007oinJc`03o`000?nI
WMKoVIgF00koVIgF00?o0000oiZMe_nJWMH02onJWMH01Ol0003oVZ?LoiZSg?nJXmco000000;oUJ7M
1?l0000<oiZbj003o`000?nN_NkoW[g^00OoW[g^1?l00006oj?5l@03o`000?n[d_GoZm;e00KoZm;e
0_l0000:ojoKm`03o`000?nbhoOo000000;o^>Ke00?o0000ol?Xl?l000001Onlm_02o`000007ol3g
k_l0003oa_[YolKjjOl0003o^_gPo`000002ojkh``03o`000?oonf[ooo]Z08oooo]Z00?o0000oook
J_oonfX02ooonfX00ol0003ooo]ZoookJP02oookJP001?oonfX00ol0003ooo]ZoookJP0XoookJP05
o`0cZol0003o0000o`000?o7AP000_l00004omQS7@;o00000ooNMCl01_l0003og7A3omad@ol0003o
h85Go`0000GogGmI0_l00004omb7JP03o`000?oJQFcofXE/00CofXE/0_l00005omR9N003o`000?oF
QgWo000000;o000000CoeXMio`000?l0003o00003onba>L00ol0003o`/CKol;4f`09ol;4f`;o0000
2_nm_m/2o`0000[oak[>0_l0000=ol>fcP04o`000?o7/lOoak?7olNca`?o00001OnoZlH00ol0003o
^j[8ok^Zb009ok^Zb003o`000?o1Y[ko000000go_Jc90_l00004okBRaP03o`000?neVkgo]I^m00Wo
]I^m0_l00007ok>Ub`03o`000?n^Ul3o[YO000_o[YO00_l00004ojnRbP03o`000?nUV<SoYIS800oo
YIS800Oo0000oijCb?nNTlSoWY?8o`000?nNTlSo000000_oWi[?00?o0000oiVMe_nIWMH03_nIWMH0
0ol0003oVYgFoiZMeP0:oiZMeP03o`000?nJXmcoVZ?L00Go00004?nJ/^P00ol0003oW[g^oijmkP04
oijmkP?o00002onSaO400ol0003oZm;eoj_Bm@02oj_Bm@?o00002?n_foL3o`0000;o/^?g00Co0000
okSVmOnhi_Go^>Ke0_l00005okcfl006o`000?o0mnko`?O^o`000?o6n^Wo00000_njoN001?l0003o
[_S3ojkh`ol0002CoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX00_oonfX000Co
oo]Z00?o0000oookJ_oonfX0:OoonfX01?l0<j_o0000o`000?l00002olM60007o`000?oHHagof6<M
omQS7Ol0003oef<So`000002omie?`04o`000?oLM4?og7A3omad@`?o00001?oMOeT00ol0003ofgeL
o`000002o`000003omb7J_l0003ofXE/00GofXE/00Co0000omN3KOl0003o00000_oHRGP3o`0000;o
eXMi0_l0000?ok;4i`;o00000_nb`^H00ol0003o`/CKol;4f`06ol;4f`05o`000?o1`]_o`L;Kol72
fol000002?nm_m/00ol0003o^kgLo`000009olNjcP03o`000?o3]/ko`kK>00_o`kK>00?o0000ol2m
eol000001_o7/lL3o`000003okn[a_l0003o^j[800_o^j[80_l0000=okf/b@03o`000?ndX/Ko]:;6
00Go]:;600?o0000okFK_OneVkd01oneVkd00ol0003o/jG;ok>Ub`07ok>Ub`03o`000?n^Ul3o[YO0
00Wo[YO00_l00006ojnRbP03o`000?nUV<SoYIS800ooYIS800Co0000oijCb?l0003o00003onOV/l0
0ol0003oVIgFoiVMeP0>oiVMeP03o`000?nJWMKoVYgF00KoVYgF1_l00003oiZSf`03o`000?nJ/^So
V[;X013oV[;X00?o0000oijmk_nN_Nh00ol0000?oj?5l@04o`000?n[d_Go0000o`0000Wo[m_g0_l0
0004ok;Sm`03o`000?nhi_Go^>Ke00;o00000onmi_<2o`000007okcfl?l0003o`?O^ol3gk_l0003o
a_[Yo`000002ok[mh0;o000000?o[_S3o`000?oonfX0U?oonfX00ol0003ooo]ZoookJP0:oookJP03
o`000?oonf[ooo]Z007ooo]Z0004oookJP03o`000?oonf[ooo]Z02[ooo]Z00Co03>[o`000?l0FLco
00000_o7AP02o`0000;of6<M00?o0000omMS8ol000000_l00005omad@`;o00000ooMOeT00ol0003o
fgeLom]mG002om]mG0?o00001OoJQF`00ol0003oeh=]omN3K@03o`0000;of8Uh0ol0000>ok;4i`?o
00001Onb`^H00ol0003o`/CKol;4f`03ol;4f`;o00001Oo1`]/00ol0003o_KoKokfof`03okfof`;o
00000onk_M`00ol0003oak[>olNjcP05olNjcP03o`000?o3]/ko`kK>00[o`kK>0_l00003ol2me`03
o`000?o7/lOoak?700Koak?70ol0000:ok^Zb003o`000?nl[<Wo000000co_Jc900?o0000okBRa_nd
X/H01ondX/H00ol0003o]I^mokFK_@04okFK_@;o00002oncYL/00ol0003o[YO0ojjG`006ojjG`0;o
00002?n_X/X00ol0003oYIS8ojFHb00>ojFHb0?o00004OnOV/l00ol0003oVIgFoiVMeP0>oiVMeP04
o`000?nJWMKoVYgFoiZMePKo00002OnJXm/00ol0003oV[;XoiZbj00@oiZbj0;o00004onSaO400ol0
003o[m_gojoKm`07ojoKm`;o00001OnbhoL01?l0003o^>Keo`000?l00007okgVl`;o000000Co`?O^
o`000?o6n^Wo00000_njoN04o`0009Kooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Zoook
JP01oookJP000ooonfX00ol0003ooo]ZoookJP0/oookJP;o000000?o05W<o`000?l000000ol00000
0ooHHago0000omMS8`02omMS8`;o00001?oLM4<00ol0003ofW=6o`000002omeoF@03o`000?oKOEco
fgeL00CofgeL0_l00004omZ5K0?o000000?oeh=]o`000?l000000_l00003oibnl003o`000?nba>Oo
//CW00Wo//CW0_l00009ok;2iP05o`000?o2a=_o`/CKol;4fol000002?o1`]/01Ol0003o_KoKokfo
fonm_m_o000000Ko^kgL00?o0000olNjc_o7^/h00oo7^/h00ol0003o`kK>ol>fcP0:ol>fcP03o`00
0?o0_MOo`;gG00Co`;gG00?o0000olNcaoo7/lL00oo7/lL00ol0003o`Jo7ol6_a`02ol6_a`?o0000
1_nkZ/P01Ol0003o_:c9okb/bOnl[<Wo000000[o_Jc900?o0000okBRa_ndX/H02?ndX/H00ol0003o
]I^mokFK_@03okFK_@03o`000?ncYL_o/jG;00_o/jG;00?o0000ojjG`?n^Ul001?n^Ul02o`0000_o
[j;:00?o0000ojFHb?nUV<P02OnUV<P01?l0003oYIS8o`000?l00002ojJMc@03o`000?nOV/ooWi[?
00ooWi[?00?o0000oiVMe_nIWMH03?nIWMH2o`000004oiVMe_l0003o0000o`0000?oVZCL0_l0000;
oiZSf`03o`000?nJ/^SoV[;X00WoV[;X1?l00002oinkk003o`000?nSaO7oXlGa00goXlGa0ol00004
ojO>m003o`000?n_foOo[m_g00;o[m_g0ol00006ok;Sm`?o00002?nmi_<3ok;dl`So0000VOoonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z007ooo]Z0003oookJP03o`000?oonf[ooo]Z
02gooo]Z0_l00002o`1Ic0;o7h?Y1?l00003omMS8`;o00001?oLM4<01_l0003ofW=6o`000?l0003o
gGmIo`0000GofgeL00?o0000omQlG_l000000ol000001?oJQFco0000o`000?l00008oibnl003o`00
0?nba>Oo//CW00Ko//CW0_l0000<ok;2iP03o`000?o2a=_o000000[o`L;K00?o0000okfofol00000
2?nk_M`01Ol0003oak[>olNjc_o7^/ko000000_o`kK>0_l00007ol2me`04o`000?o7/lOoak?7olNc
a`;o00002?o1[lL3o`0000;o^j[800?o0000okb/bOnl[<T00onl[<T00ol0003o_Jc9okf/b@06okf/
b@03o`000?ndX/Ko]:;600[o]:;600?o0000okFK_OneVkd00_l0000?ok>Ub`04o`000?n^Ul3o[YO0
ojjG`0;o00003On_X/X00ol0003oYIS8ojFHb004ojFHb0Ko00001_nVWLd00ol0003oWi[?oinJc`0?
oinJc`03o`000?nIWMKoVIgF00KoVIgF1Ol00003oifQe`04o`000?nJY=coVZCLoiZTg0;o00003OnJ
Xm/00ol0003oV[;XoiZbj005oiZbj0Co00001onO^n`00ol0003oXlGaoj?5l@08oj?5l@Co00002?nW
c_@01?l0003o[m_go`000?l00008ok;Sm`;o00002?nmi_<4ok;dl`;o00000onjn^/00onMm=?o0000
o`00002KoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00OoonfX000?ooo]Z00?o
0000oookJ_oonfX0;_oonfX3o`000006o`1Ic?l0003o7h?Yoan3jOl0003o?9Ca1ol00002omad@`04
o`000?oJLdKofW=6omYcAP;o00001OoKOE`7o`0000coW;k`00?o0000ok;4ionba>L00_nba>L3o`00
00oo//;V00?o0000ol72foo1`]/02_o1`]/2o`0000Wo^kgL00?o0000olNjc_l000002oo3]/h00ol0
003o`;gGol2me`08ol2me`03o`000?o7/lOo000000go`Jo71_l00002okb/b@03o`000?nm[<Wo_Jc9
00Go_Jc93_ndX/H00ol0003o]I^mo`00000Aok>Ub`04o`000?n^Ul3o0000o`0000oo[j;:00?o0000
ojFHb?nUV<P01ol00009ojJMc@03o`000?nOV/ooWi[?00ooWi[?00Co0000oiVMe_nIWMKoVIgF1Ol0
0009oifQe`03o`000?nJY=co0000013oVZ?K00?o0000oiZbj?nJ/^P01?l0000<oinkk003o`000?nS
aO7oXlGa00CoXlGa0ol0000=ojO>m003o`000?nbhoOo/^?g00Oo/^?g00?o0000okgVlonmi_<01Onm
i_<2o`0000?o/_Cc00?o0000ok[jjonjn^/00onjn^/2o`000003oiK]^_oonf[ooo]Z09_ooo]Z00?o
0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP01oookJP000ooonfX00ol0003ooo]ZoookJP0`
oookJPCo00000_lOPnT00ol0003o?9CaocbDl@03ocbDlA;o00004OnL__001?l0003o//CWo`000?l0
000?ok;2iP;o00000_na`NH00ol0003o`L;Kol72f`07ol72f`04o`000?nn_m[o_[oJokjofP?o0000
1_nk_M`2o`0000_o`kK>00?o0000ol2meoo0_ML02Oo0_ML2o`0000go`Jo700?o0000okb/bOnl[<T0
1?nl[<T6o`0000?o_Jc93ondX/H2o`0001;o/jG;0_l0000?ojnRbPGo000000CoYIS8o`000?l0003o
00003OnVWLd00ol0003oWi[?oinJc`0=oinJc`Go00003_nMXML2o`00013oVZ?K1?l0000Aoinkk003
o`000?nSaO7oXlGa00?o00003?nWc_@3o`0000?oZmSg00?o0000ok;SmonbhoL00_nbhoL2o`000003
okOTmOl0003o_NKc00Co_NKc0_l00004ok;dl`03o`000?njn^_o^_[[00;o^_[[00CoWOCCo`000?nF
kK[o0000W_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z007ooo]Z0003oookJP03
o`000?oonf[ooo]Z037ooo]Z00?o02RJo`000?l000000_l000000olOPnWo0000ocbDl@05ocbDl@03
o`000?ma[oOoLJog00?oLJog0ol00006ogVbm`03o`000?nL__3oW;k`013oW;k`00?o0000ok;2i_nb
`^H03?nb`^H3o`0000Go/L7V00?o0000ol72foo1`]/01?o1`]/2o`0000Oo_[oJ0_l000001?nk_Mco
0000o`000?l00002okRkg003o`000?o3]/ko`kK>00Ko`kK>0_l0000;ol2me`03o`000?ni/m?o0000
00co`Jo700?o0000okb/bOnl[<T02?nl[<T00ol0003o_Jc9okf/b@06o`0000_o]:;600?o0000okJW
bOl000004?ncYL/2o`000003ok:SbOl0003o[j;:00So[j;:1_l00003ojbPb`?o00004?nVWLd00ol0
003oWi[?oinJc`09oinJc`Co00000_nRX]@00ol0003oWJ7GoifQe`0<oifQe`;o000000?oWZ7Fo`00
0?nJXm/02onJXm/4o`0000;oW[;V00?o0000oinkk?nO^n`04OnO^n`2o`0000coYlkd0ol00007oj_H
m`04o`000?nbhoOo0000o`0000;o]nCe00?o0000okgVlonmi_<00_nmi_<2o`0000?o/_Cc00?o0000
okKfl?l000000onjn^/01?nMm=?o0000o`000?nFkKZQoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX00OoonfX000?ooo]Z00?o0000oookJ_oonfX0<ooonfX2o`000004o`1Eaol0003o
0000o`0000Ko?9Ca00?o0000og6_mol000000_l000000oma[oOo0000ogVbm`07ogVbm`03o`000?nL
__3oW;k`00WoW;k`1?l00003oi^nl@03o`000?nb`^Ko//;V00Wo//;V0_l00009ok71iP04o`000?o1
`]_o`L;Kol72f`;o00002onn_mX2o`0000Go^;_L00?o0000ol>fc_o3]/h01?o3]/h00ol0003o`;gG
ol2me`09ol2me`;o00000oni/m<00ol0003o`Jo7ol6_a`07ol6_a`;o00003?nl[<T2o`0000Ko^ZK5
1ol00003okBRaP05o`000?nfYlWo]ZO9okJWbOl000003OncYL/2o`0000Co/Z?900?o0000ojnRb_n_
X/X01_l00007ojbPb`;o000000?o[:7<o`000?nVWLd04OnVWLd00ol0003oWi[?oinJc`04oinJc`Co
00001onRX]@00ol0003oWJ7GoifQe`09oifQe`;o00001?nNXMH00ol0003oVZ?KoiZSf`04oiZSf`Go
00001onN/^H00ol0003oWk_/oinkk00;oinkk0?o00000onSa?000ol0003oYlkdojO>m007ojO>m0?o
00002on[f?L01Ol0003o]nCeokOTmOngi?Go000000?o_NKc0_l00003ok;dl`;o000000?o]_K`o`00
0?njn^/00_njn^/01?nMm=?o0000oiK]^_nFkKZSoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX00OoonfX000?ooo]Z00?o0000oookJ_oonfX0=?oonfX01Ol0:9[o0000o`000?l0003o
5X7V00?o00000_llU?43o`0000GoLJog00?o0000ogVbmomi/_L01_mi/_L00ol0003oW;k`oibnl005
oibnl0?o00002?nK__400ol0003o//;Vok;2iP06ok;2iP;o00003?na`NH00ol0003o`L;Ko`00000;
okjofP04o`000?nk_=[o^kcJok^lfP;o00001?nh^m`01?l0003o`kK>ol>fc_o3]/h2o`0000_o`;gG
00?o0000okVcdoni/m<01?ni/m<00ol0003o`Jo7ol6_a`05ol6_a`03o`000?nl[<Wo_:c900co_:c9
00?o0000okZVaOnjY/D03?njY/DCo`000003ok>Ubol0003o000000So00002on/X</2o`0000Co[:7<
00?o0000ojJMcOnVWLd03onVWLd00ol0003oWi[?oinJc`04o`0000_oXZ;D00?o0000oifQeonMXML0
1onMXML2o`0000KoWZ7F00?o0000oiZSfonJXm/01?l0000=oijbiP03o`000?nO^ncoWk_/00OoWk_/
0ol00007oj?4l003o`000?nWc_CoYlkd00?oYlkd0ol0000;oj_Hm`;o00000_n]hOT00ol0003o]nCe
o`000003okgVl`04o`000?nbm??o/_Ccok;dl`;o00000_nfm_000ol0003o^_[[ok[jj`02oigdd`03
o`000?nFkK[o00000:Cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP01oookJP00
0ooonfX00ol0003ooo]ZoookJP0foookJP03o`0XV_l0003o000000;o5X7V1ol00005og6_m`03o`00
0?mi/_OoNK;g00KoNK;g00?o0000oibnl?nL__001?l0000<oi^nl@03o`000?nb`^Ko//;V00;o//;V
0ol0000?ok71iP03o`000?nn_m[o_[oJ00So_[oJ0_l00006ok^lfP?o00000_nh^m`00ol0003o`kK>
o`00000;ol2me`;o00002?ni/m<00ol0003o`Jo7ol6_a`02ol6_a`;o00003Onl[<T00ol0003o^KKF
o`00000>okZVa@03o`000?ngY/Wo]jK900Co]jK900?o0000ok>UboncYL/01oncYL/2o`0000So/Z;8
00?o0000ojbPbon/X</02On/X</2o`0000Ko[:7<00?o0000ojJMcOnVWLd04?nVWLd2o`00013oXZ;D
00?o0000oifQeonMXML01?nMXML2o`0000OoWZ7F1?l0000AoijbiP03o`000?nO^ncoWk_/00CoWk_/
0ol0000;oj?4l003o`000?nWc_Co000000;o00002on[f?L2o`0000Ko[N7i0_l000000onmi_?o0000
o`000003ok;dl`05o`000?nfm_3o]_K`okKfl?l000000_njn^/2oigdd`03o`000?nFkK[ooo]Z0:Ko
oo]Z00?o0000oookJ_oonfX01OoonfX1o`00007ooo]Z0OoonfX000?ooo]Z00?o0000oookJ_oonfX0
=ooonfX01Ol0:9[o0000o`000?l0003o5X7V00;o00000olgU?4Bo`00017oVkka00Co0000ok;2i_l0
003o00003_na`NH3o`000003ojo0i_l0003o_[oJ00Oo_[oJ0_l0000;ok^lfP;o000000?o^;_Lo`00
0?o0_ML02_o0_ML00ol0003o^K?CokVcd`08okVcd`05o`000?o1[lOo`Jo7ol6_aol000003_nl[<T0
1Ol0003o^KKFokVfe_ni]]Ko000000_o^ZK50_l00008okNVb@03o`000?ncYL_o/jG;00Go/jG;00?o
0000ok:Rb?nbX/P02OnbX/P00ol0003o[:3;ojbPb`06ojbPb`;o00002On/XL`00ol0003oYYg=ojJM
c@0;ojJMc@?o000000?oYZGDo`000?nRX]@04OnRX]@01?l0003oWJ7GoifQeonMXML2o`0000GoWZ7F
1?l00002oj2]h@03o`000?nN/^KoW[;V017oW[;V00?o0000oinkk?nO^n`00ol0000?oj?4l003o`00
0?n[f?OoZmSg00WoZmSg0ol00006ojgQn@03o`000?nbi?Oo/^Cg00Co000000?o/_Cco`000?l00000
0onfm_001?l0003o^_[[oigddonMm=<2o`000003oiK]^_oonf[ooo]Z0:Oooo]Z00?o0000oookJ_oo
nfX01?oonfX1o`00007ooo]Z0OoonfX000;ooo]Z00?o0000oookJ_oonfX0=_oonfX3o`000007o`0X
V_l0003o0530o`]mh_l0003o5X7Vo`000005ocNDl@03o`000?m][oSoKJoh00?oKJoh00?o0000ogRc
n?mh/oP01_mh/oP00ol0003oVkkaoi^nl@0?oi^nl@03o`000?na`NKo/L7V00_o/L7V0ol00005ojo0
iP03o`000?nn_m[o_[oJ00Co_[oJ00?o0000ok^lf_nk_=X03Onk_=X4o`0000So`;gG00?o0000okVc
doni/m<02_ni/m<00ol0003o`Jo7o`00000=okb/b@;o00001Oni]]H00ol0003o^ZK5okZVa@07okZV
a@03o`000?ngY/Wo]jK900So]jK900?o0000ok>UboncYL/00oncYL/2o`0000co/Z;800?o0000ojbP
bon/X</01On/X</00ol0003o[:7<ojbQc009ojbQc003o`000?nVWLgoYYg=00SoYYg=0ol00005ojJU
e003o`000?nRX]CoXZ;D00ooXZ;D00Co0000oifQeonMXMOo00000onNXMH4o`0000OoX:gQ00?o0000
oijbi_nN/^H04OnN/^H2o`0000koXlC`0ol00002ojK=m003o`000?n[f?OoZmSg00KoZmSg0_l00007
ojgQn@Go00001?nfioH3o`0000;o]_K`00Co0000oigddonMm=?oWOCC0ol0002[oookJP03o`000?oo
nf[ooo]Z00?ooo]Z0Ol00001oookJP7ooo]Z0002oookJP03o`000?oonf[ooo]Z03?ooo]Z0ol00005
oookJP03o`000?l0D<3o000000;o2ggR0ol00003ocNDl@03o`000?m][oSoKJoh00?oKJoh0_l00007
ogRcn003o`000?nK__7oVkka00OoVkka1Ol00004oiZnl@03o`000?na`NKo/L7V00Oo/L7V0_l00009
ojo0iP04o`000?nn_m[o_[oJokjofP;o00003Onk_=X2o`0000?o^;_K00Co0000ol6meol0003o0000
1?o0_ML2o`0000go^K?C0_l0000=okb/b@03o`000?ni]]Ko^KKF00Go^KKF00?o0000okZVaOnjY/D0
1OnjY/D2o`0000co]jK900?o0000ok>UboncYL/00_l0000?ok:Rb003o`000?n/X<_o[:3;00;o[:3;
00?o0000ojbQc?n/XL`02on/XL`00ol0003oYYg=ojJMc@06ojJMc@;o00002?nVYM@00ol0003oXZ;D
oj:Re00?oj:Re0;o00000_nNXMH3o`0000coX:gQ00?o0000oijbi_nN/^H02_nN/^H4o`0000;oX[_[
00?o0000oj?4l?nSa?002_nSa?03o`0000KoY/gd00?o0000oj_Hmon[f?L00on[f?L2o`0000So[N7i
0ol00006okKWmPCoZ??c1ol0002]oookJP03o`000?oonf[ooo]Z00?ooo]Z0Ol00001oookJP7ooo]Z
0002oookJP03o`000?oonf[ooo]Z033ooo]Z0ol00009oookJP?o00000ol;ON86o`0000KoKJoh00?o
0000ogRcn?mh/oP01Omh/oP01?l0003oVkkaoi^nlOnK__45o`0000[oV[ka00?o0000ok71i_na`NH0
0ona`NH3o`0000co[l3V00?o0000okjof_l000003Onk_=X2o`0000Ko^;_K00?o0000ol6meoo1_ML0
0_l000000oo0_MOo0000okVcd`0=okVcd`03o`000?ne/mOo000000_o_:c90_l00009okVfeP03o`00
0?njY/Go^ZK500?o^ZK500?o0000okNVbOngY/T03?ngY/T00ol0003o/jG;o`00000Aok:Rb004o`00
0?n/X<_o[:3;o`00013o[:7<00?o0000ojJMcOnVWLd00_nVWLd3o`0000_oYZGD00?o0000oj:Re?nR
X]@02onRX]@6o`00017oX:gQ00?o0000oijbi_nN/^H01OnN/^H4o`0000OoX[_[00?o0000oj?4l?nS
a?001onSa?02o`0000[oY/gd00?o0000oj_Hmol000000_l00009ojgQn@03o`000?nfioKo]^Of00Co
]^Of00?o0000ojSclonXlo<01?nXlo<4ojchjP03ohOZb_l0003ooo]Z0:kooo]Z00?o0000oookJ_oo
nfX00_oonfX1o`00007ooo]Z0OoonfX000;ooo]Z00?o0000oookJ_oonfX0;OoonfX3o`0000kooo]Z
0ol00002o`]mhP04o`000?laTo3o<I?`oc6Cl1?o00004?nJ__400ol0003o/L7Vo`000002o`00013o
[l3V00?o0000ok^lf_nk_=X02_nk_=X2o`0000Wo^;_K00Co0000ol6meoo1_MOo`KgG0_l0000<okVc
d`;o00000one/mL00ol0003o_:c9okb/b@07okb/b@03o`000?ni]]Ko^KKF00Wo^KKF00Co0000okZV
aOnjY/Go^ZK50_l0000@okNVb@03o`000?nbX/So/Z;8017o/Z;800?o0000ojbQc?n/XL`04?n/XL`0
0ol0003oYYg=o`000002o`0000koYZGD00?o0000oj:Re?nRX]@02?nRX]@5o`0000;oXjWK00?o0000
oj2]hOnP[N404OnP[N400ol0003oW[;VoijbiP04o`0000coX[_[00?o0000oj?4l?nSa?000onSa?03
o`0000goY/gd00?o0000ojgQnOn]hOT01on]hOT2o`0000Ko]^Of00?o0000ojSclonXlo<01?nXlo<4
ojchjP03ohOZb_l0003ooo]Z0;7ooo]Z00Go0000oookJ_oonf[ooo]Zo`000002oookJP000_oonfX0
0ol0003ooo]ZoookJP0ZoookJP?o00004_oonfX2o`000004o`1gg?l0003o2ggRo`0000Go<I?`1omX
[oT00ol0003oMK?iogFcn@04ogFcn@03o`000?nJ__7oV[ka013oV[ka00?o0000ojo0i_n_`>H03On_
`>H3o`0000;o[KoW00?o0000ok^lf_nk_=X02?nk_=X00ol0003o^;_KokRkf`0:okRkf`03o`000?o1
_MOo000000;o_kWD0_l00009okVcd`03o`000?ne/mOo]K?G00Co]K?G00?o0000okb/bOnl[<T01Onl
[<T00ol0003o^KKFokVfeP0;okVfeP03o`000?njY/Go000000oo]jK90_l000000onc/MOo0000ok:R
b00?ok:Rb0;o000000?o[jgFo`000?n/XL`04_n/XL`00ol0003oYZGDojJUe00@ojJUe003o`000?nR
X]CoXZ;D00CoXZ;D0_l000000onRX]Co0000oj>Yf`06oj>Yf`03o`000?nP[N7oX:gQ017oX:gQ0_l0
000Aoj:kj`03o`000?nSa?3o000000;o00003?nVcO@3o`0000?oZ=Sh00?o0000ojgQnOn]hOT00_n]
hOT4o`0000Co]^Of0_l00005ojScl`;o00000on/n>X2o`000003ogKJYooonf[ooo]Z0;7ooo]Z00Go
0000oookJ_oonf[ooo]Zo`000002oookJP000_oonfX00ol0003ooo]ZoookJP0WoookJP?o00005ooo
nfX2o`0000;o07OL0ol00003oc6Cl003o`000?mX[oWoJ:oi00CoJ:oi00?o0000ogFcnOme/oT01?me
/oT00ol0003oV[kaoiZnl@09oiZnl@Co00000onH_O800ol0003o[l3Vojo0iP0:ojo0iP;o00001_n]
_nL00ol0003o^kcJok^lfP05ok^lfP;o00003_nh^m/00ol0003o_kWDoknie003oknie0?o00001?ni
/m<2o`0000So]K?G00?o0000okb/bOnl[<T00_nl[<T2o`0000ko^KKF0_l0000?okNVb@03o`000?nc
/MOo/k7G00;o/k7G00?o0000ok:Rb?nbX/P02_nbX/P3o`0000Co[jgF00?o0000ojbQc?n/XL`03?n/
XL`3o`000003ojf/e_l0003oYZGD017oYZGD00?o0000oj:Re?nRX]@01Ol0000;oj>Yf`03o`000?nP
[N7oX:gQ00[oX:gQ1?l00002oj:fiP03o`000?nR^n_oX[_[017oX[_[00?o0000ojK=m?nVcO@02_nV
cO@3o`0000OoZ=Sh00Co0000ojgQnOl0003o00000_nai?P01?l0003o]^OfokKWm_nfioH2o`0000Go
Z??c0ol00002ojchjP?o0000]_oonfX01?l0003ooo]ZoookJ_l00002oookJP000_oonfX00ol0003o
oo]ZoookJP0ToookJP?o00006ooonfX2o`0000?o07OL1_l00006ofR_n@03o`000?me/oWoMK?i00Co
MK?i00?o0000oiZnlOnJ__401OnJ__43o`0000SoV;gb00?o0000ojo0i_n_`>H01_n_`>H3o`0000Wo
[KoW00?o0000ok^lf_nk_=X00_nk_=X2o`0000go^;_K0_l000000one^mko0000oknie007oknie0;o
000000?o^K?Co`000?ne/mL02One/mL01Ol0003o_:c9okb/bOnl[<Wo000000ko^KKF0_l000000onb
[M?o0000okNVb@0<okNVb@;o00001Onc/ML00ol0003o/Z;8ok:Rb008ok:Rb0;o00002?n_[MH00ol0
003o[:7<ojbQc009ojbQc0;o00001On][=H00ol0003oYZGDojJUe00?ojJUe0Go00003onSZM/00ol0
003oX:gQoj2]h@05oj2]h@Co00001onR]^H00ol0003oX[_[oj:kj`0:oj:kj`Co00000onTaO000ol0
003oY/gdojK=m007ojK=m0;o00002onXf?P3o`000004ok7Tn?l0003o]^OfokKWmP;o00001OnXlo<3
o`0000;o[?SZ00?o0000ohOZb_l00000^OoonfX00ol0003ooo]Zo`000002oookJP000_oonfX00ol0
003ooo]ZoookJP0QoookJP?o00008?oonfX2o`0000;o07OL0_l00002obVAkPKo00000_mX[oT00ol0
003oMK?iogFcn@04ogFcn@03o`000?nJ__7oV[ka00Co00003?nH_O800ol0003o[l3Vojo0iP03ojo0
iP;o00003On]_nL01?l0003o^kcJo`000?l0000=okRkf`;o00001?ne^mh00ol0003o_kWDoknie007
oknie0Co00002One/mL00ol0003o_:c9o`00000>okVfeP03o`000?nb[M?o/ZgC00;o/ZgC00?o0000
okNVbOngY/T02?ngY/T2o`0000So/k7G00?o0000ok:Rb?nbX/P01OnbX/P2o`0000_o[jgF00?o0000
ojbQc?n/XL`01On/XL`3o`0000Oo[JcF00?o0000ojJUe?nVYM@03?nVYM@6o`0001;oXjWK00?o0000
oj2]hOnP[N401?l0000<oj:fiP03o`000?nR^n_oX[_[00GoX[_[1?l00008ojC5l003o`000?nVcOCo
Y/gd00?oY/gd0ol0000:ojSHn0;o00001?nYh_X01?l0003o]^Ofo`000?l00005ojScl`Co00000_n/
n>X2ohOZbP03o`000?oonf[ooo]Z0;Wooo]Z00?o0000oookJ_l000000OoonfX00003oookJ_l0003o
oo]Z023ooo]Z0ol0000ToookJP?o00000_l0Mm`00ol0003o:I7^obVAkP02obVAkP?oHZoj3?l0000A
oiRmlP03o`000?n_`>Ko000000;o00004?n]_nL00ol0003o^;_KokRkf`0;okRkf`;o00001one^mh0
0ol0003o_kWDoknie002oknie0?o00001Onj]]D5o`0000?o]K?G0ol0000=okVfeP;o00001Onb[M<0
0ol0003o]jK9okNVb@06okNVb@;o00002onc/ML01?l0003o/Z;8ok:Rb?nbX/P3o`0000go[jgF00?o
0000ojbQc?n/XL`00on/XL`2o`0000_o[JcF00?o0000ojJUe?nVYM@02OnVYM@5o`0000;oYj_J00?o
0000oj>YfonSZM/03onSZM/4o`00017oX[KV00?o0000oj:kjonR^n/01?l0000=ojC5l003o`000?nV
cOCo000000;o00002OnXf?P3o`0000GoZN;j00Co0000ojgUnOl0003o00001_nXlo<00ol0003oZ_G`
o`000002ojchjP?oQn[:00?o0000oookJ_oonfX0^_oonfX00ol0003ooo]Zo`000001oookJP0000?o
oo]Zo`000?oonfX07OoonfX3o`0002Wooo]Z00Go0000o`1_dol0003o07OLo`000004obVAkP03o`00
0?mR[o[oHZoj00CoHZoj00?o0000og:dnOmb]?T01?mb]?T00ol0003oV;gboiRmlP0?oiRmlP03o`00
0?n]_nOo[KoW00go[KoW0ol00002ojZoj@03o`000?nh^m_o^;_K00So^;_K0_l0000:okFkgP04o`00
0?no^MCo0000o`0000go^[KE1Ol000000onf]MSo0000okVfeP09okVfeP;o00002?nb[M<00ol0003o
]jK9okNVb@03okNVb@;o00003Onc/ML01?l0003o/Z;8o`000?l0000Aojn]eP03o`000?n/XLco0000
00;o00003_n][=H00ol0003oYZGDojJUe005ojJUe0Co00001onWZmX00ol0003oXjWKoj>Yf`0;oj>Y
f`?o00000_nU/n<00ol0003oX[KVoj:fiP0Aoj:fiP;o00004_nTaO000ol0003oZ=ShojSHn008ojSH
n0;o00001_nYh_X4o`0000?o[nWi0_l000001onXlo?o0000o`000?nZmO3o0000ojchj_l000000_n7
j/X00ol0003ooo]ZoookJP2moookJP;o00000OoonfX00003oookJ_l0003ooo]Z01[ooo]Z0ol0000]
oookJP;o00000_l0Km<4o`000003obVAk_l0003oHZoj00GoHZoj0_l00005og:dn@03o`000?nH_O;o
V;gb00OoV;gb1Ol00004oiFml`03o`000?n]_nOo[KoW00So[KoW0ol00006ojZoj@03o`000?nh^m_o
^;_K00Go^;_K0_l0000=okFkgP03o`000?nj]]Go^[KE00_o^[KE0_l00005okJde`Go00001_ni]]H0
0ol0003o/ZgCok:]d`09ok:]d`05o`000?ngY/Wo]jK9okNVbOl000003onc/ML2o`0001?o[jgF0_l0
000Aojf/eP03o`000?nVYMCoYZGD00Go00003?nWZmX00ol0003oXjWKoj>Yf`07oj>Yf`?o00001_nU
/n<00ol0003oX[KVoj:fiP0;oj:fiP?o00000_nT_n`00ol0003oY<G`ojC5l00<ojC5l0?o00001?nV
coH00ol0003oZ=ShojSHn003ojSHn0?o00001onYh_X3o`0000Oo[nWi2Ol0002ooookJP?o00000Ooo
nfX00003oookJ_l0003ooo]Z01Oooo]Z0ol0000boookJP;o00000_l0Km<00ol0003o7hg[o`000007
o`0000;oHZoj00?o0000og:dnOmb]?T00omb]?T01?l0003oV;gboiRml_nH_O85o`0000[oUKgc00?o
0000ojfoion]_nL01?n]_nL3o`0000[oZ[oY00?o0000okRkfonh^m/00_nh^m/2o`0000co]K_N0_l0
00000onb^n3o0000okZfe@0;okZfe@03o`000?nf]=Oo][CG00Oo][CG00?o0000okVfe_ni]]H00ol0
00000oni]]Ko0000o`00000<ok:]d`04o`000?ngY/Wo0000o`0000oo/k7G00?o0000ok:^e?l00000
4On_[MH2o`000003ojn/e_l0003o[JcF00ko[JcF1_l0000@ojN[fP03o`000?nSZM_oXjWK00CoXjWK
0ol0000:ojFch`03o`000?nR]^KoX[KV00OoX[KV0ol00006ojBok003o`000?nTaO3oY<G`00SoY<G`
0ol00008ojK?mP03o`000?nXf?So000000;o00002OnYh_X2o`0000So[nWi0onLlO400ol0003oUo;S
oiObh`02oiObhkkooo]Z0ol00004oookJP0000?ooo]Zo`000?oonfX05?oonfX3o`0003Sooo]Z00Co
0000o`1_dol0003o00000olOSN/01?l0003oFJgjoeV]n_mI[OX<o`00013oUKgc00?o0000ojfoion]
_nL00ol0000>ojZoj@04o`000?nh^m_o0000o`0000co]K_N0_l00004ok:kh003o`000?nj]]Go^[KE
00Oo^[KE0_l0000;okJde`04o`000?ni]]Ko^KKFokVfePGo00002onb[M<2o`0000oo/k7G0_l00003
ok:^e003o`000?n_[MKo[jgF00co[jgF0_l00004ojn/eP03o`000?n][=Ko[JcF00Ko[JcF1_l00002
ojZZe`03o`000?n[[]Wo000001;oYj_J00?o0000oj>YfonSZM/00ol0000=ojFch`03o`000?nR]^Ko
X[KV00CoX[KV0ol0000:ojBok003o`000?nTaO3oY<G`00CoY<G`0ol0000<ojK?mP03o`000?nYh_[o
ZN;j00WoZN;j00?o0000ojoYnOn_jOT01On_jOT01Ol0003oW?7aoicalOnLlO7o000000CoUo;S_?oo
nfX4o`0000Oooo]Z00000ooonf[o0000oookJP0AoookJP?o0000?OoonfX00ol0K]7o06oCo`000003
oan=j`;o00001_mI[OX2o`0000CoKK?j00?o0000oiFmlonE_O<03onE_O<2o`0001;oZ[oY00?o0000
okFkg_ne^mh02One^mh3o`0000Oo/[_P00?o0000okZfeOnj]]D01?nj]]D2o`0000go][CG00Co0000
okVfe_l0003o00001Onh/M86o`0000?o/ZgC0_l00002ok>be`03o`000?nc/MOo/k7G00[o/k7G0_l0
0006ok:^e003o`000?n_[MKo[jgF00Wo[jgF0_l00006ojn/eP04o`000?n][=Ko[JcFojf/ePGo0000
1OnZZ]L00ol0003oZjkIoj^^f@03oj^^f@03o`000?nWZm[oYj_J013oYj_J0_l0000AojFch`03o`00
0?nR]^KoX[KV00?o00003_nT_n`00ol0003oY<G`ojC5l003o`0000_oY/of0ol00003ojKJnP03o`00
0?nYh_[oZN;j00?oZN;j0ol00006ojoYn@03o`000?nLlO7oW?7a00;oW?7a00Go0000oiObhonGl^?o
Uo;So`00002koookJP?o00002ooonfX00003oookJ_l0003ooo]Z00kooo]Z0ol00012oookJPGo0000
00?o7hg[o`000?mI[OX01_mI[OX00ol0003oKK?joffcnP02offcnP03o`000?nE_O?oUKgc00OoUKgc
1Ol00003oi6mm@03o`000?nZ_nWoZ[oY00coZ[oY0ol00003ojJnj`03o`000?ne^mko]K_N00Go]K_N
0_l0000;ok:kh003o`000?nj]]Go^[KE00;o^[KE00?o0000okJdeonf]=L03_nf]=L00ol0003o^;7B
okRadP0;okRadPko00001Onc/ML00ol0003o/ZkDok:^e006ok:^e003o`000?n_[MKo[jgF00Oo[jgF
0_l00003ojn/ePWo00002?nZZ]L8oj^^f@03o`000?nWZm[oYj_J00_oYj_J0ol00002ojNch@03o`00
0?nU/n?oYK?S017oYK?S0_l0000BojBok0;o00002onVcoH3o`0000OoY][j00?o0000ojWRn_l00000
1?l00004ojoYn@;o00000onLlO42o`0000?oUo;S0_l0002hoookJPCo00003_oonfX00003oookJ_l0
003ooo]Z00_ooo]Z0ol00017oookJP03o`1Uaol0003o000000So00000_mI[OX2o`0000?oKK?j00Co
0000oiFmlonE_O?oUKgc1Ol00009oi6mm@03o`000?nZ_nWoZ[oY00SoZ[oY0ol00007ojJnj`03o`00
0?ne^mko]K_N00;o]K_N0_l0000>ok:kh004o`000?nj]]Go0000o`0000ko][CG0_l000000onc]mco
0000okRadP0;okRadP;o00001ond/MH00ol0003o/k7Gok>ae`03ok>aeaOo000000?o[jgFo`000?l0
00000ol00006ojn/e@03o`000?nZZ]OoZZ[G00GoZZ[G00?o0000oj^^fOn[[]T02On[[]T00ol0003o
Yj_JojN[fP07ojN[fP?o00001_nW/n400ol0003oYK?SojFch`0;ojFch`?o00000_nU_>T00ol0003o
Y;o/ojBok00<ojBok0?o00000onUbO800ol0003oY/ofojK?mP07ojK?mP;o00002onVf_X2o`000003
oj_Vn_l0003o[nWi00;o[nWi0ol00003oical@?o00000_nGl^<2o`000;Oooo]Z0ol0000BoookJP00
00?ooo]Zo`000?oonfX02?oonfX3o`0004_ooo]Z00?o0000o`1Uaol0K]400_l000000olDRNOo0000
odf[n@02odf[n@?o000000?oFJgjo`000?l000001Ol0000?oi6mm@03o`000?nZ_nWoZ[oY00CoZ[oY
0ol0000;ojJnj`04o`000?ne^mko0000o`00017o/[_P00?o0000okJdeonf]=L03?nf]=L2o`0000Co
/kOL00?o0000okRad_nh/M801onh/M82o`0000[o];7F00?o0000ok>aeonc/ML00_nc/ML3o`0000go
/ZgD00?o0000ojn/eOn_[=D00ol0000>ojn/e@03o`000?nZZ]OoZZ[G00;oZZ[G3on[[]T00ol0003o
Yj_JojN[fP03ojN[fP?o00002_nW/n400ol0003oYK?SojFch`07ojFch`?o00001_nU_>T00ol0003o
Y;o/ojBok008ojBok0?o00001onUbO800ol0003oY/ofojK?mP03ojK?mP?o00002_nVf_X2o`0000?o
Z>3k00?o0000ojoYnOn_jOT00_l00004oical@?o00000_nGl^<2o`000;Gooo]Z1?l0000EoookJP00
00?o0000oookJ_oonfX01OoonfX3o`00053ooo]Z00?oK`00o`1Uaol0ILL01?l00007odf[n@?o0000
00?oIk;ko`000?nA_OD03onA_OD00ol0003oZ[oYojZoj@03o`0000ooY[k[00?o0000ok:kh?nb^n00
3Onb^n03o`0000;o[[cT00?o0000okJdeonf]=L02?nf]=L3o`0000Oo/kOL00?o0000okRad_nh/M80
1Onh/M800ol0003o];7FokBaeP0;okBaeP04o`000?nc/MOo0000o`00017o/ZgD0_l0000Bojn/e@03
o`000?n[[]WoZjkI013oZjkI00?o0000ojN[f_nWZmX00ol0000=ojNch@03o`000?nU/n?oYK?S00Co
YK?S0ol0000:ojFlj@03o`000?nT_ncoY;o/00CoY;o/0ol0000;ojG9lP03o`000?nVcoKo000000;o
00002OnVf_X3o`0000CoZ>3k00Oo0000ojWSn_nYho[oZN?jo`000?nLlO7o000000;oW?7a0ol00000
0onGl^?o0000o`000002o`000;?ooo]Z0ol0000IoookJP0000?o0000oookJ_oonfX00_oonfX3o`00
05Gooo]Z00?oK`00o`000?l0ILL02Ol00003odf[n@?o00004?nA_OD2o`0000koY[k[0ol00002oj:o
kP03o`000?nb^n3o/[_P00[o/[_P0_l00006ojjli003o`000?nf]=Oo][CG00Go][CG0_l0000;ok>g
g003o`000?nh/M;o^;7B00;o^;7B0_l0000?okBaeP03o`000?nb[MCo/ZgD00ko/ZgD0_l000000on_
/][o0000ojn/e@0?ojn/e@;o000000?o[K;Lo`000?n[[]T04_n[[]T2o`00017oYk?Q00?o0000ojFc
honU/n<00ol0000>ojFlj@03o`000?nT_ncoY;o/00?o00003onUbO800ol0003oY][jojKJnP08ojKJ
nP;o00001?nXh?/2o`0000CoZN?j1?nIk?P8o`000;7ooo]Z1?l0000LoookJP0000?o0000oookJ_l0
00000_l0001JoookJP06ofl00?l0003o06G7o`000?l6P^3o00001?loY_H4o`000003odf[nOl0003o
000000CoTKge1ol00006oh^mm`03o`000?nV_^_oY[k[00SoY[k[0ol00006oj:okP03o`000?nb^n3o
/[_P00Ko/[_P0ol00009ojjli003o`000?nf]=Oo][CG00;o][CG0_l0000>ok>gg004o`000?nh/M;o
0000o`0000ko];7F0_l000000ona]Mco0000ok:]e00<ok:]e0?o00001?n_/]X00ol0003o[jcEojn/
e@0:ojn/e@?o00001?n]/]`00ol0003oZjkIoj^^f@0<oj^^f@?o000000?oZ[GQo`000?nW/n404_nW
/n42o`0001;oYKcY0_l0000=ojG9lP?o00001?nUe?P00ol0003oY][jojKJnP03ojKJnP?o00001?nX
h?/2o`0000?oZN?j1_nIk?P00ol0003oTnk`oi?^l002ohg^j0;o0000/?oonfX3o`00023ooo]Z0002
o`0005oooo]Z00Ko0000o`1N_?l0003o0000o`J2h?l00009ocnVmPCo00003_n;_OL00ol0003oY[k[
ojJnj`04ojJnj`?o00002_nR_nh00ol0003o/[_Pok:kh003ok:kh0;o00003On^_>@01?l0003o][CG
o`000?l0000Aok>gg003o`000?nd/MKo];7F00_o];7F0ol00004ok6eg003o`000?nb[MCo/ZgD00So
/ZgD0_l00007ojnbfP03o`000?n_[=Go[jcE00So[jcE0_l00007ojfbg003o`000?n[[]WoZjkI00Wo
ZjkI0ol00005ojZeh@03o`000?nW/n7oYk?Q00_oYk?Q0ol00002ojNkj003o`000?nU_>WoYKcY00co
YKcY0ol00003ojG6l003o`000?nUbO;oYLWb00SoYLWb0ol00008ojGDn003o`000?nVf_[o000000;o
00001OnXh?/2o`0000;oZN?j1OnIk?P3o`000004oi?^l?l0003oSNkXohg^j0;o0000[_oonfX4o`00
02?ooo]Z0002oookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000o`1N_?l000001_l00006ocnVmP;o
00003on;_OL00ol0003oY[k[ojJnj`03o`0000koX[o^00?o0000ok:kh?l000000_l0000@ojjli003
o`000?nc]mco/kOL00go/kOL0ol000000on_^N7o0000okBaeP0:okBaeP;o00002?na]M`00ol0003o
/ZgDok:]e005ok:]e0;o00002_n_/]X00ol0003o[jcEojn/e@05ojn/e@;o00002_n]/]`00ol0003o
ZjkIoj^^f@06oj^^f@;o00002OnZ]N400ol0003oYk?QojNch@07ojNch@?o00001_nW^nP00ol0003o
YKcYojFlj@08ojFlj@?o00001onUa_000ol0003oYLWbojG9lP04ojG9lP?o00003?nUe?P00ol0003o
Z>3kojSPn`04ojSPn`;o00000_nYhoX5oiW/n0;o00000_nCk_001?l0003oSNkXof;F_ol0002^oook
JP?o00009ooonfX000?ooo]Z00?o0000oookJ_oonfX0GooonfX01?l0003o05jlo`000?l00003od>V
m`Co00000oloY_H2o`0000SoRkgg0ol00004oh^mm`;o00004_nR_nh00ol0003o[[cTojjli00=ojjl
i0?o000000?oZKgXo`000?nc]m`02onc]m`3o`0000Go[kWQ00?o0000okBae_nd/MH01_nd/MH2o`00
00[o/KGL00?o0000ok:]e?nb[M@00_nb[M@3o`0000go[k;J00Co0000ojn/eOn_[=Go[jcE0ol0000=
ojfbg003o`000?n[[]WoZjkI00;oZjkI0ol0000;ojZeh@03o`000?nW/n7oYk?Q00CoYk?Q0ol0000:
ojNkj003o`000?nU_>WoYKcY00CoYKcY0ol0000;ojG6l003o`000?nUbO;oYLWb00?o00002_nUe?P3
o`0000CoXMkl0_l000001?nXh?_o0000o`000?nYhoX6oiW/n0;o000000CoTnk`o`000?l0003oSNkX
0_l0002/oookJPCo0000:_oonfX000Cooo]Z00?o0000oookJ_oonfX0HOoonfX2o`0000Wo@jKg00?o
0000ocnVm_l000001ol00009ogBmo@03o`000?nR_nkoX[o^00WoX[o^1?l00004oig0l@03o`000?n^
_>Co[[cT00So[[cT0ol00005ojVmj003o`000?nc]mco/kOL00Oo/kOL0_l00009ojnih@03o`000?nd
/MKo];7F00;o];7F0ol0000=ok6eg004o`000?nb[MCo0000o`00013o[k;J00Co0000ojn/eOl0003o
00004?n]/]`00ol0003oZjkIo`000002o`0000ooZ[GQ00?o0000ojNchOnW/n400ol0000>ojNkj003
o`000?nU_>WoYKcY00?o00003onUa_02o`0000[oYMCh0ol00009oj7No003o`000?nIk?SoVNch00Co
VNch0ol000001?nCk_3o0000o`000?n=k^P2o`000:_ooo]Z0ol0000^oookJP001OoonfX00ol0003o
oo]ZoookJP1SoookJP;o00002_m3Y_L2o`0000koM;gm00?o0000oj:ok_nR_nh01OnR_nh3o`0000Wo
WL3a00?o0000ojjli?n^_>@01?n^_>@3o`0000WoZKgX00?o0000ok>gg?nc]m`00onc]m`3o`0000co
[kWQ00Co0000okBae_l0003o00004Ona]M`00ol0003o[k;JojnbfP0AojnbfP03o`000?n]/]co[K;L
017o[K;L00?o0000ojZehOnZ]N404OnZ]N42o`0001;oYk_X0_l0000=ojG6l0?o00001?nTd?L00ol0
003oYMChojGDn004ojGDn0?o00002OnQg_`2o`0000?oW^Ol0_l000000onIk?So0000o`000002oi?^
l0;o000000?oH]Joo`000?l00000ZOoonfX4o`00037ooo]Z0006oookJP;o0000IOoonfX01?l0003o
@jKgo`000?l00007od>Vm`03o`000?m`_?goL;cm00?o00002_md_Od00ol0003oX[o^oj:okP04o`00
00goWL3a00?o0000ojjli?n^_>@00ol0000=ojVmj003o`000?nc]mco000000;o00004?n_^N400ol0
003o/KGLok6eg00=ok6eg0?o00000_n]^N800ol0003o[k;JojnbfP0<ojnbfP?o00000_n/^>400ol0
003o[K;Lojfbg00<ojfbg0?o00000_n[^N@00ol0003oZ[GQojZeh@0<ojZeh@?o00000_nX_NP00ol0
003oYk_XojNkj00<ojNkj0?o00000_nVaNl00ol0003oYLK`ojG6l008ojG6l0?o00002?nTd?L00ol0
003oYMChojGDn003o`0000[oXMkl00?o0000oikWo?nNio`01_nNio`6o`000003ofWLd?m3`:Sooo]Z
0:Oooo]Z0ol0000eoookJP002?oonfX00ol0003ooo]ZoookJP1ToookJPWo000000Co@jKgo`000?m`
_?goL;cm2ol00002ogBmo@;o00004_nM`?42o`00017oZKgX00?o0000ojnihOn_^N403On_^N43o`00
00;oZkcV00?o0000ok6eg?na]M`02_na]M`2o`0000Ko[KWR00?o0000ojnbf_n_/]X02?n_/]X3o`00
00Ko[;SQ00?o0000ojfbg?n]/]`02?n]/]`3o`0000KoZkWT00?o0000ojZehOnZ]N402?nZ]N43o`00
00KoZ;gX00?o0000ojNkj?nW^nP02?nW^nP3o`0000KoY/G_00?o0000ojG6l?nUa_001?nUa_03o`00
00coY=3g0_l00009oj7No0?o00002?nNio`4ohGXk`03o`000?mYg=3o@l2X0:Oooo]Z1?l0000hoook
JP002OoonfX00ol0003ooo]ZoookJP1UoookJPCo00000ol/Wo04o`0000CoH[[m0_l00009ogVno003
o`000?nM`?7oWL3a00OoWL3a1Ol00004oiK1m@03o`000?nY_NSoZKgX00WoZKgX1?l00004ojBok@03
o`000?n_^N7o[kWQ00So[kWQ0ol00006oj^liP03o`000?na]Mco/KGL00Ko/KGL0ol00009ojfihP03
o`000?n_/][o[k;J00Co[k;J0ol0000:ojbhh@03o`000?n]/]co[K;L00Co[K;L0ol0000:oj^ii003
o`000?nZ]N7oZ[GQ00CoZ[GQ0ol0000:ojRmj003o`000?nW^nSoYk_X00CoYk_X0ol0000:ojK5k`03
o`000?nUa_3oYLK`00?o00002onTd?L3o`0000?oWm_l00?o0000oj7No?nQg_`00onQg_`3o`0000Ko
W^Ol0_l00003ohGXk`;o000000?oJMc@od?0Z?oonfX0Y_oonfX3o`0003cooo]Z000:oookJP03o`00
0?oonf[ooo]Z06Kooo]Z0ol00002obbOl005o`000?l/Wo3o;9o`obbOl?l000001OmR^_d2o`0000So
NKkl00Co0000oig0lOnM`?7oWL3a1Ol0000:oiK1m@03o`000?nY_NSoZKgX00GoZKgX0ol00009ojBo
k@03o`000?n_^N7o[kWQ00Co[kWQ0ol0000:oj^liP03o`000?na]Mco/KGL00?o/KGL0_l0000=ojfi
hP03o`000?n_/][o[k;J00?o00003_n/^>400ol0003o[K;Lojfbg003o`0000koZkWT00?o0000ojZe
hOnZ]N400ol0000>ojRmj003o`000?nW^nSoYk_X00?o00003_nVaNl2o`0000_oY=3g0ol00007oioK
o003o`000?nQg_co000000?o00001?nNio`3o`0000?oQNS_1?l0002VoookJPCo0000?ooonfX000_o
oo]Z00?o0000oookJ_oonfX0IooonfX2o`000003o`1_`Ol0003o000000Go00001OmR^_d2o`0000Co
NKkl1_l0000@oiK1m@03o`000?nY_NSoZKgX00Co00003OnT_nd00ol0003o[kWQojnih@03o`0000ko
ZkcV00?o0000ok6eg?l000000_l0000@ojfihP;o00004_n/^>42o`0001;oZkWT0_l0000BojRmj0;o
00003OnVaNl3o`0000?oXlog0_l00006ojC@m`?o00002onOfo`2o`000004oikWo?l0003oW^OloikW
o0?o00000on5j>l3o`000003ofWLd?l0003ooo]Z0:Cooo]Z0ol00013oookJP003?oonfX2o`0006[o
oo]Z0_l000000ol0Kl7o0000o`000008o`000003of:joOl0003o000000;o00001Om__?d00ol0003o
U/7eoiK1m@0?oiK1m@;o00004_nT_nd2o`0001;oZkcV00?o0000ojfih_n]^N803?n]^N83o`0000;o
Z;kY00?o0000ojbhhOn/^>403?n/^>43o`0000;oZKkY00?o0000oj^ii?n[^N@03?n[^N@3o`0000?o
Yl3[00?o0000ojRmj?nX_NP02_nX_NP4o`0000?oYLK`00?o0000ojK5konVaNl02?nVaNl3o`0000So
Xlog00?o0000ojC@monTd?L00ol0000:oioKo0Co00001?nFi?d3o`0000;oQNS_1_l0002SoookJPCo
0000A_oonfX000kooo]Z00?o0000oookJ_oonfX0J_oonfX2o`1^_`03o`1_`Ol0003o000000?o0000
1_m@]OX3o`0000CoKkcm00?o0000oiK1mOnF`OD01onF`OD5o`0000CoN/Cn00?o0000ojBokOnT_nd0
2OnT_nd4o`0000?oWL;b00?o0000oj^li_n[_>H03?n[_>H3o`0000;oYL3/00?o0000ojfih_n]^N80
2?n]^N83o`0000KoZ;kY00?o0000ojbhhOn/^>402?n/^>43o`0000KoZKkY00?o0000oj^ii?n[^N@0
2?n[^N@3o`0000OoYl3[00?o0000ojRmj?nX_NP01OnX_NP4o`0000SoYLK`00?o0000ojK5konVaNl0
1?nVaNl3o`0000coXlog0_l0000:oioKo0Co00001OnFi?d00ol0003oOnCbogoTlP02ogoTlPGo0000
XooonfX3o`0004[ooo]Z000?oookJP03o`000?oonf[ooo]Z06gooo]Z00?o06joo`000?l000001_l0
0004oe2enP?o00000_m__?d01?l0003oU/7eoiK1mOnF`OD5o`0000[oN/Cn00?o0000ojBokOnT_nd0
1OnT_nd3o`0000SoWL;b00?o0000oj^li_n[_>H02?n[_>H3o`0000KoYL3/00?o0000ojfih_n]^N80
1?n]^N83o`0000[oZ;kY00?o0000ojbhhOn/^>401?n/^>43o`0000[oZKkY00?o0000oj^ii?n[^N@0
1?n[^N@3o`0000_oYl3[00?o0000ojRmj?nX_NP01?l0000=ojG6l003o`000?nVaNooY/G_00?o0000
2_nScoL3o`0000CoW=Wl00?o0000oioKo?nOfo`01?nOfo`4o`0000?oU^Cm0ol00006ogoTlP?o0000
X_oonfX4o`0004gooo]Z000@oookJP03o`000?oonf[ooo]Z06kooo]Z00?o0000o`1^_ol000001?l0
0003oeFen`;o00000_m@]OX6o`00013oN/Cn00?o0000ojBokOnT_nd01?l0000<oig2lP03o`000?n[
_>KoZkcV00CoZkcV0ol0000:ojG0k003o`000?n]^N;o[KWR00?o00003_nX_^T00ol0003o[;SQojbh
h@03o`0000koZKkY00?o0000oj^ii?n[^N@00ol0000?ojO0j`;o00004_nUa_02o`0000[oXlog0ol0
0008oicIo003o`000?nOfocoWm_l00Co00000onFi?d3o`0000CoOnCb1Ol0002RoookJP?o0000DOoo
nfX0017ooo]Z00?o0000oookJ_oonfX0K_oonfX01?l0003ooo]ZoookJ_l0K[l3o`0000WoEKGk1?l0
000@og[4oP;o00004OnM`_800ol0003oZkcVoj^liP03o`0000koYL3/0_l0000BojRnj@;o00004_nY
_^T2o`0000goYl3[0ol00003oj?8l`03o`000?nUa_3oYLK`00[oYLK`1?l00004oj3?n003o`000?nS
coOoXlog00CoXlog0ol0000<oicIo0Co00000_nFi?d3o`0000CoOnCb1Ol0002QoookJPCo0000E?oo
nfX001;ooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP02oookJP;o00002omE]O/3
o`0000CoN/Cn1ol00005ogg5oP03o`000?nM`_;oWL;b00ooWL;b0_l0000;ojG0k0Co00001?nNa?<0
0ol0003oZ;kYojRnj@09ojRnj@Co00001?nRa?400ol0003oZKkYojVnj@09ojVnj@Co00000onTaO40
0ol0003oYl3[ojO0j`08ojO0j`?o00001onSb?<00ol0003oYLK`ojG6l005ojG6l0Co00002OnPcoP0
0ol0003oXlogoj??m`03o`0000[oW=Wl0ol000000on@h?koS>7mohcQo@03ohcQo@?o00000omoi?86
o`000:3ooo]Z0ol0001HoookJP004ooonfX2o`0006oooo]Z0_l00005oookJP;o00001?lBUn0;o`00
00goOLGn00?o0000oig2l_nM`_801onM`_85o`0000CoU<Ch00?o0000ojG0k?nU`>`01OnU`>`3o`00
00WoW/Cc00?o0000ojRnjOnX_^T01OnX_^T3o`0000WoX/Ca00?o0000ojVnjOnY_^T01OnY_^T3o`00
00SoY<Ga00?o0000ojO0jonW`>/01?nW`>/3o`0000_oXlSc00?o0000ojG6l?nUa_001?l0000>oj3?
n0;o00002?nLfO`4o`000003oi3Po_l0003oS>7m00GoS>7m1Omfgo86o`0009oooo]Z1?l0001Koook
JP005OoonfX00ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z00Kooo]Z1Ol00005oa:Gh0;o
000000?oIL3no`000?l000000ol00009ogg5oP04o`000?nM`_;oWL;boig2lPGo00002_nDa?P00ol0
003oYL3/ojG0k004o`0000goW/Cc00?o0000ojRnjOnX_^T01?l0000=oj;4l@03o`000?nY_^WoZKkY
00Co00003?nTaO400ol0003oYl3[ojO0j`03o`0000ooXlSc0_l0000<oj3?n0Co00001?nBfOh2o`00
00;oW=Wl1ol00004ohcQo@;o00001omfgo801?mDd=Oo?l;1oco2`Olo`/6OoookJP?o0000GooonfX0
01Kooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP08oookJPSo00000_lBUn0Bo`00
013oU<Ch0_l0000Boik4l`;o00004_nRa?42o`00017oY<Ga0_l0000<oj?8l`Co00001?nKdO/00ol0
003oX<ohoj3?n005oj3?n0Co00002_nBfOh2o`000004oi3Po_l0003o0000o`0000?oS>7m0ol00005
ogKOlP05o`000?mDd=Oo?l;1oco2`Ol00000WooonfX4o`0006;ooo]Z000GoookJP03o`000?oonf[o
oo]Z06kooo]Z00?o0000oookJ_oonfX02_oonfX2o`1c]`[o00001_m=^_P5o`000003og72o_l0003o
000000CoU<Ch1ol00006og;8o`;o00002OnNa?<5o`0000?oU<Si00?o0000oj;4lOnRa?402_nRa?44
o`0000?oV/[h00?o0000ojC5lOnTaO402OnTaO44o`0000CoW<ch0_l00007oj?8l`?o00002OnKdO/0
0ol0003oX<ohoj3?n004o`0000WoT]Wn2Ol00002ohcQo@?o00000omfgo83o`000003oco2`Ol0003o
00000:3ooo]Z0ol0001VoookJP006?oonfX00ol0003ooo]ZoookJP1^oookJP03o`000?oonf[ooo]Z
00kooo]Z0ol0LkL=o`0000;oCK[h1ol0000?og;8o`04o`000?nNa??oW/Ccoik4l`Go00002OnDb?T0
0ol0003oX/Caoj;4l@05oj;4l@Co00002?nJb_P00ol0003oY<GaojC5l@05ojC5l@?o00002_nLc?P0
0ol0003oXlScoj?8l`04o`0000goVm7k0_l00009oi;IoPOo00001?n6gOd4o`000003ogKOl_l0003o
000000Go0000X?oonfX4o`0006Wooo]Z000IoookJP;o0000KooonfX00ol0003ooo]ZoookJP0@oook
JP03o`000?l0LkOo07>g00Go00002omB^_X7o`0000coL/So0ol0000?oiC8n@03o`000?nRa?7oX/Ca
00Co00003OnJb_P00ol0003oY<GaojC5l@04o`0000koW<ch0_l0000;oi_An`Co00001?n4fOl2o`00
00GoT]Wn0ol00005ohKMo@Go00000omKdnH5o`000:7ooo]Z0ol0001]oookJP006ooonfX00ol0003o
oo]ZoookJP1]oookJP03o`000?oonf[ooo]Z00cooo]Z0ol00006oookJP?o00001OmB^_X3o`0000Go
D[[j00Co0000ofg7oom]aoooKLOo2?l00006ogK8o`03o`000?nDb?WoU<Si00koU<Si0_l0000Boi[:
n0;o00002onLc?P5o`0000CoP]Co00?o0000oi_AnonKdO/01OnKdO/3o`0000[oQ=Wo0ol00007ohKM
o@?o00000_mKdnH6o`000:;ooo]Z1?l0001`oookJP007?oonfX00ol0003ooo]ZoookJP1]oookJP03
o`000?oonf[ooo]Z00Sooo]Z0ol0000?oookJPGo1IC@2Ol00007oe?1n@Ko00000_mfb?l00ol0003o
U<SioiC8n@02oiC8n@Oo00001_mac?l2o`0000WoV/[h1Ol00004ogc@o`?o00000onLc?P5o`0000[o
P]Co00?o0000oi_AnonKdO/01?l00008ohCIo`03o`000?mof?ko000000KoM=Wj0_l000000on6gOgo
0000oe_CiP02oe_CiPGo0000Y?oonfX3o`0007Cooo]Z000MoookJP03o`000?oonf[ooo]Z06gooo]Z
00?o0000oookJ_oonfX01?oonfX3o`0001Oooo]Z00?o1IC@o`000?l5U=001Ol5U=03o`0000_oDl7i
1ol0000?og7<o`04o`000?nJb_SoV/[hoi[:n0Go00003?mld?l3o`00013oP]Co0_l00003ohCIo`03
o`000?mof?ko000000Co00001omdfOX3o`0000Go?L7E00?oFm?Vo`000?l00000YOoonfX4o`0007Oo
oo]Z000NoookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX00ol0000PoookJP?o0000
0_l5U=07o`0000[oE/7j0_l00003of[;oP03og7<ool0003o000000WoLLco0ol0000:ogc@o`Go0000
0omjdOl00ol0003oP]Cooh;Do`08oh;Do`Go00000_mheOh7o`0000GoM=Wj1Ol00006ocg1e@03o`00
0?oonf[ooo]Z0:Kooo]Z0ol0001koookJP007ooonfX2o`0006kooo]Z0_l0000YoookJPCo00000_mF
`OXAo`0000WoJ/_m2?l00004ogc@oa7o00001_mheOh5o`0000So>[kL1?l00002ocg1e@?o0000Zooo
nfX4o`0007kooo]Z000QoookJP03o`000?oonf[ooo]Z06_ooo]Z00?o0000oookJ_oonfX0<ooonfX3
o`0000So1iO90_l00005of[;o@co00002omdd?h00ol0003o<KOLoc6gg005oc6gg0;o000000?oN=Gn
o`000?l000001_lj_]`6o`0000;o5jFj/_oonfX3o`0008;ooo]Z000RoookJP03o`000?oonf[ooo]Z
06[ooo]Z00?o0000oookJ_oonfX0?_oonfX<o`0000Oo8:[F0_l00002ogC@oP03o`000?la]mco<KOL
00Co<KOL4?l00002oaNU^[Oooo]Z1?l00025oookJP008ooonfX00ol0003ooo]ZoookJP1YoookJP03
o`000?oonf[ooo]Z0?oooo]Z8ooonfX3o`0008Wooo]Z000ToookJP03o`000?oonf[ooo]Z06Sooo]Z
00?o0000oookJ_oonfX0oooonfXOoookJPCo0000S?oonfX002Gooo]Z0_l0001XoookJP03o`000?oo
nf[ooo]Z0?oooo]Z7?oonfX3o`00093ooo]Z000WoookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000
oookJ_oonfX0oooonfXHoookJPCo0000TooonfX002Sooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0
003ooo]ZoookJP3ooookJQGooo]Z0ol0002GoookJP00:OoonfX00ol0003ooo]ZoookJP1RoookJP03
o`000?oonf[ooo]Z0?oooo]Z4_oonfX4o`0009[ooo]Z000ZoookJP03o`000?oonf[ooo]Z067ooo]Z
00?o0000oookJ_oonfX0oooonfX?oookJP?o0000W_oonfX002_ooo]Z00?o0000oookJ_oonfX0H?oo
nfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z1?l0002QoookJP00;?oonfX2o`00063ooo]Z00?o0000
oookJ_oonfX0oooonfX8oookJP?o0000YOoonfX002kooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0
003ooo]ZoookJP3ooookJPCooo]Z1?l0002XoookJP00;ooonfX00ol0003ooo]ZoookJP1LoookJP03
o`000?oonf[ooo]Z0?oooo]Z0OoonfX3o`000:cooo]Z000`oookJP03o`000?oonf[ooo]Z05_ooo]Z
00?o0000oookJ_oonfX0o?oonfX4o`000:oooo]Z000aoookJP03o`000?oonf[ooo]Z05[ooo]Z00?o
0000oookJ_oonfX0nOoonfX3o`000;?ooo]Z000boookJP;o0000F_oonfX00ol0003ooo]ZoookJP3e
oookJPCo0000]_oonfX003Cooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP3boook
JP?o0000^_oonfX003Gooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP3^oookJPCo
0000_OoonfX003Kooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP3[oookJP?o0000
`OoonfX003Oooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP3WoookJPCo0000a?oo
nfX003Sooo]Z0_l0001DoookJP03o`000?oonf[ooo]Z0>Cooo]Z0ol00038oookJP00>_oonfX00ol0
003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z0>3ooo]Z1?l0003;oookJP00>ooonfX00ol0003o
oo]ZoookJP1?oookJP03o`000?oonf[ooo]Z0=kooo]Z0ol0003?oookJP00??oonfX00ol0003ooo]Z
oookJP1>oookJP03o`000?oonf[ooo]Z0=[ooo]Z1?l0003BoookJP00?OoonfX00ol0003ooo]Zoook
JP1=oookJP03o`000?oonf[ooo]Z0=Oooo]Z0ol0003FoookJP00?_oonfX2o`0004gooo]Z00?o0000
oookJ_oonfX0dooonfX4o`000=Wooo]Z0010oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oook
J_oonfX0d?oonfX3o`000=gooo]Z0011oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oo
nfX0cOoonfX3o`000>3ooo]Z0012oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0
bOoonfX4o`000>?ooo]Z0013oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0a_oo
nfX3o`000>Oooo]Z0014oookJP;o0000AooonfX00ol0003ooo]ZoookJP32oookJPCo0000j_oonfX0
04Kooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP2ooookJP?o0000k_oonfX004Oo
oo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP2koookJPCo0000lOoonfX004Sooo]Z
00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP2hoookJP?o0000mOoonfX004Wooo]Z00?o
0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP2doookJPCo0000n?oonfX004[ooo]Z00?o0000
oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP2aoookJP?o0000o?oonfX004_ooo]Z0_l00010oook
JP03o`000?oonf[ooo]Z0:gooo]Z1?l0003ooookJP00COoonfX00ol0003ooo]ZoookJP0loookJP03
o`000?oonf[ooo]Z0:_ooo]Z0ol0003ooookJPCooo]Z001>oookJP03o`000?oonf[ooo]Z03_ooo]Z
00?o0000oookJ_oonfX0YooonfX4o`000?oooo]Z1ooonfX004oooo]Z00?o0000oookJ_oonfX0>_oo
nfX00ol0003ooo]ZoookJP2ToookJP?o0000oooonfX;oookJP00D?oonfX00ol0003ooo]ZoookJP0i
oookJP03o`000?oonf[ooo]Z0:3ooo]Z1?l0003ooookJPkooo]Z001AoookJP;o0000>OoonfX00ol0
003ooo]ZoookJP2MoookJP?o0000oooonfXBoookJP00DooonfX00ol0003ooo]ZoookJP0foookJP03
o`000?oonf[ooo]Z09Wooo]Z1?l0003ooookJQGooo]Z001DoookJP03o`000?oonf[ooo]Z03Gooo]Z
00?o0000oookJ_oonfX0U_oonfX3o`000?oooo]Z6OoonfX005Gooo]Z00?o0000oookJ_oonfX0=?oo
nfX00ol0003ooo]ZoookJP2BoookJPCo0000oooonfXLoookJP00E_oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z08oooo]Z0ol0003ooookJR3ooo]Z001GoookJP;o0000<ooonfX00ol0
003ooo]ZoookJP2;oookJPCo0000oooonfXSoookJP00FOoonfX00ol0003ooo]ZoookJP0`oookJP03
o`000?oonf[ooo]Z08Sooo]Z0ol0003ooookJROooo]Z001JoookJP03o`000?oonf[ooo]Z02oooo]Z
00?o0000oookJ_oonfX0Q?oonfX4o`000?oooo]Z:_oonfX005_ooo]Z00?o0000oookJ_oonfX0;_oo
nfX00ol0003ooo]ZoookJP21oookJP?o0000oooonfX^oookJP00G?oonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z07gooo]Z1?l0003ooookJS7ooo]Z001MoookJP;o0000;OoonfX00ol0
003ooo]ZoookJP1joookJP?o0000oooonfXeoookJP00GooonfX00ol0003ooo]ZoookJP0YoookJP03
o`000?oonf[ooo]Z07Oooo]Z1?l0003ooookJSSooo]Z001PoookJP03o`000?oonf[ooo]Z02Sooo]Z
00?o0000oookJ_oonfX0M?oonfX3o`000?oooo]Z??oonfX0067ooo]Z00?o0000oookJ_oonfX09ooo
nfX00ol0003ooo]ZoookJP1`oookJPCo0000oooonfXooookJP00H_oonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z06gooo]Z0ol0003ooookJT?ooo]Z001SoookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX0JOoonfX4o`000?oooo]ZA_oonfX006Cooo]Z0_l0000UoookJP03
o`000?oonf[ooo]Z06Kooo]Z0ol0003ooookJT[ooo]Z001VoookJP03o`000?oonf[ooo]Z02;ooo]Z
00?o0000oookJ_oonfX0H_oonfX4o`000?oooo]ZCOoonfX006Oooo]Z00?o0000oookJ_oonfX08Ooo
nfX00ol0003ooo]ZoookJP1OoookJP?o0000oooonfYAoookJP00J?oonfX00ol0003ooo]ZoookJP0P
oookJP03o`000?oonf[ooo]Z05_ooo]Z1?l0003ooookJUCooo]Z001YoookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX0F?oonfX3o`000?oooo]ZF?oonfX006[ooo]Z0_l0000OoookJP03
o`000?oonf[ooo]Z05Cooo]Z1?l0003ooookJU_ooo]Z001/oookJP03o`000?oonf[ooo]Z01cooo]Z
00?o0000oookJ_oonfX0DOoonfX3o`000?oooo]ZGooonfX006gooo]Z00?o0000oookJ_oonfX06ooo
nfX00ol0003ooo]ZoookJP1=oookJPCo0000oooonfYRoookJP00K_oonfX00ol0003ooo]ZoookJP0J
oookJP03o`000?oonf[ooo]Z04[ooo]Z0ol0003ooookJVKooo]Z001_oookJP03o`000?oonf[ooo]Z
01Wooo]Z00?o0000oookJ_oonfX0A_oonfX4o`000?oooo]ZJOoonfX0073ooo]Z0_l0000HoookJP03
o`000?oonf[ooo]Z04Cooo]Z0ol0003ooookJVgooo]Z001boookJP03o`000?oonf[ooo]Z01Gooo]Z
00?o0000oookJ_oonfX0@?oonfX4o`000?oooo]ZL?oonfX007?ooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0moookJP?o0000oooonfYdoookJP00M?oonfX00ol0003ooo]ZoookJP0C
oookJP03o`000?oonf[ooo]Z03Wooo]Z1?l0003ooookJWOooo]Z001eoookJP03o`000?oonf[ooo]Z
01;ooo]Z00?o0000oookJ_oonfX0=_oonfX3o`000?oooo]ZNooonfX007Kooo]Z0_l0000BoookJP03
o`000?oonf[ooo]Z03;ooo]Z1?l0003ooookJWkooo]Z001hoookJP03o`000?oonf[ooo]Z00oooo]Z
00?o0000oookJ_oonfX0;ooonfX3o`000?oooo]ZP_oonfX007Wooo]Z00?o0000oookJ_oonfX03_oo
nfX00ol0003ooo]ZoookJP0[oookJPCo0000oooonfZ5oookJP00N_oonfX00ol0003ooo]ZoookJP0=
oookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0003ooookJXWooo]Z001koookJP03o`000?oonf[ooo]Z
00cooo]Z00?o0000oookJ_oonfX09?oonfX4o`000?oooo]ZS?oonfX007cooo]Z00?o0000oookJ_oo
nfX02ooonfX00ol0003ooo]ZoookJP0QoookJP?o0000oooonfZ@oookJP00OOoonfX2o`0000_ooo]Z
00?o0000oookJ_oonfX07OoonfX4o`000?oooo]ZTooonfX007oooo]Z00?o0000oookJ_oonfX02?oo
nfX00ol0003ooo]ZoookJP0JoookJP?o0000oooonfZGoookJP00P?oonfX00ol0003ooo]ZoookJP07
oookJP03o`000?oonf[ooo]Z01Kooo]Z1?l0003ooookJY[ooo]Z0021oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX04ooonfX3o`000?oooo]ZW_oonfX008;ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP0@oookJPCo0000oooonfZQoookJP00PooonfX2o`0000Cooo]Z
00?o0000oookJ_oonfX03OoonfX3o`000?oooo]ZYOoonfX008Gooo]Z00Go0000oookJ_oonf[ooo]Z
o`00000;oookJPCo0000oooonfZXoookJP00Q_oonfX01?l0003ooo]ZoookJ_l00008oookJP?o0000
oooonfZ/oookJP00QooonfX00ol0003ooo]Zo`000004oookJPCo0000oooonfZ_oookJP00R?oonfX2
o`000004oookJ_l0003o0000o`000?oooo]Z/ooonfX008Wooo]Z0_l0003ooookJ[Kooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {369.75, 0}} -> {0.00390792, 0.151075, \
0.00173327, 0.00173327}},
  CellTags->"mmtag:26:ContourPlot3D[]__example_of_hydrogen_orbitals"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellTags->"mmtag:26:ContourPlot3D[]__example_of_hydrogen_orbitals"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(epsilon\  = \ 10^\((\(-6\))\)\)], "Input"],

Cell[BoxData[
    \(1\/1000000\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pdens = 
      NMaximize[
        Abs[HAtom[3, 2, 1, SphericalCoords[x, y, z]]], {x, y, z}]\)], "Input"],

Cell[BoxData[
    \({0.00004804484923849476`, {x \[Rule] \(-2.0751797601104656`\), 
        y \[Rule] 0.4400326483545185`, 
        z \[Rule] 2.1213203050671967`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(p1 = 
      ContourPlot3D[
        Abs[HAtom[3, 2, 1, SphericalCoords[x, y, z]]], {x, \(-10\), 10}, {y, 
          epsilon, 10}, {z, epsilon, 10}, MaxRecursion \[Rule] 2, 
        PlotPoints -> {7, 7}, Contours -> {0.95  pdens[\([1]\)]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .65926 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00445854 1.00446 -0.143979 1.00446 [
[ 0 0 0 0 ]
[ 1 .65926 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02168 .27949 m
0 .45986 L
s
0 .45986 m
.23973 .65926 L
s
.23973 .65926 m
.24993 .48772 L
s
.24993 .48772 m
.02168 .27949 L
s
.80488 0 m
.97794 .26024 L
s
.97794 .26024 m
1 .44134 L
s
1 .44134 m
.82069 .18956 L
s
.82069 .18956 m
.80488 0 L
s
.02168 .27949 m
0 .45986 L
s
0 .45986 m
.82069 .18956 L
s
.82069 .18956 m
.80488 0 L
s
.80488 0 m
.02168 .27949 L
s
.24993 .48772 m
.97794 .26024 L
s
.97794 .26024 m
1 .44134 L
s
1 .44134 m
.23973 .65926 L
s
.23973 .65926 m
.24993 .48772 L
s
0 0 m
1 0 L
1 .65926 L
0 .65926 L
closepath
clip
newpath
.5 Mabswid
.702 .568 .701 r
.41083 .46777 m .41326 .46552 L .41016 .46557 L closepath p F P
0 g
s
.702 .576 .709 r
.41326 .46552 m .41016 .46557 L .40792 .45861 L p F P
0 g
s
.707 .572 .701 r
.41016 .46557 m .41083 .46777 L .40543 .47296 L p F P
0 g
s
.707 .572 .701 r
.40028 .46557 m .41016 .46557 L p .40543 .47296 L F P
0 g
s
.707 .578 .708 r
.41016 .46557 m .40792 .45861 L .40028 .46557 L closepath p F P
0 g
s
.707 .572 .701 r
.39717 .46858 m .40028 .46557 L p .40543 .47296 L F P
0 g
s
.708 .573 .701 r
.39717 .46858 m .40028 .46557 L .39625 .46555 L closepath p F P
0 g
s
.708 .58 .71 r
.40771 .45798 m .40792 .45861 L .40028 .46557 L p F P
0 g
s
.708 .58 .71 r
.39597 .45792 m .40771 .45798 L p .40028 .46557 L F P
0 g
s
.708 .58 .71 r
.39426 .45949 m .39597 .45792 L p .40028 .46557 L F P
0 g
s
.708 .58 .71 r
.40028 .46557 m .39625 .46555 L .39426 .45949 L p F P
0 g
s
.713 .577 .701 r
.39625 .46555 m .39717 .46858 L .3929 .47287 L p F P
0 g
s
.713 .577 .701 r
.38807 .46538 m .39625 .46555 L p .3929 .47287 L F P
0 g
s
.713 .583 .708 r
.39625 .46555 m .39426 .45949 L .38807 .46538 L closepath p F P
0 g
s
.702 .576 .709 r
.40792 .45861 m .40865 .45796 L p .41326 .46552 L F P
0 g
s
.704 .576 .709 r
.40792 .45861 m .40865 .45796 L .40771 .45798 L closepath p F P
0 g
s
.704 .584 .718 r
.40865 .45796 m .40771 .45798 L .40501 .45012 L p F P
0 g
s
.708 .586 .716 r
.40494 .45012 m .40501 .45012 L .40771 .45798 L p F P
0 g
s
.708 .586 .716 r
.40771 .45798 m .39597 .45792 L .40494 .45012 L p F P
0 g
s
.702 .576 .709 r
.40865 .45796 m .42139 .45776 L p .41326 .46552 L F P
0 g
s
.703 .582 .717 r
.42139 .45776 m .40865 .45796 L .41829 .44996 L p F P
0 g
s
.704 .584 .718 r
.40501 .45012 m .41829 .44996 L .40865 .45796 L p F P
0 g
s
.701 .567 .701 r
.41326 .46552 m .42379 .46531 L p .41877 .47281 L F P
0 g
s
.701 .567 .701 r
.41083 .46777 m .41326 .46552 L p .41877 .47281 L F P
0 g
s
.701 .573 .708 r
.42379 .46531 m .42156 .4583 L .41326 .46552 L closepath p F P
0 g
s
.702 .576 .709 r
.42139 .45776 m .42156 .4583 L .41326 .46552 L p F P
0 g
s
.701 .567 .701 r
.41877 .47281 m .41238 .47294 L .41083 .46777 L p F P
0 g
s
.706 .57 .699 r
.41238 .47294 m .41083 .46777 L .40543 .47296 L closepath p F P
0 g
s
.71 .581 .71 r
.39426 .45949 m .39597 .45792 L .39374 .4579 L closepath p F P
0 g
s
.709 .588 .718 r
.3925 .45 m .40494 .45012 L .39597 .45792 L p F P
0 g
s
.709 .588 .718 r
.39134 .45102 m .3925 .45 L p .39597 .45792 L F P
0 g
s
.709 .588 .718 r
.39597 .45792 m .39374 .4579 L .39134 .45102 L p F P
0 g
s
.714 .585 .71 r
.39374 .4579 m .39426 .45949 L .38807 .46538 L p F P
0 g
s
.707 .572 .701 r
.40543 .47296 m .39851 .47296 L .39717 .46858 L p F P
0 g
s
.712 .575 .699 r
.39851 .47296 m .39717 .46858 L .3929 .47287 L closepath p F P
0 g
s
.714 .585 .71 r
.38403 .45764 m .39374 .4579 L p .38807 .46538 L F P
0 g
s
.714 .591 .717 r
.39374 .4579 m .39134 .45102 L .38403 .45764 L closepath p F P
0 g
s
.707 .565 .692 r
.40006 .47847 m .40543 .47296 L .39851 .47296 L closepath p F P
0 g
s
.712 .569 .692 r
.39851 .47296 m .40006 .47847 L .3985 .48013 L p F P
0 g
s
.712 .569 .692 r
.3929 .47287 m .39851 .47296 L p .3985 .48013 L F P
0 g
s
.706 .564 .692 r
.40543 .47296 m .41238 .47294 L p .41141 .48011 L F P
0 g
s
.706 .564 .692 r
.40006 .47847 m .40543 .47296 L p .41141 .48011 L F P
0 g
s
.713 .577 .701 r
.3835 .46999 m .38807 .46538 L p .3929 .47287 L F P
0 g
s
.714 .578 .701 r
.3835 .46999 m .38807 .46538 L .38202 .46523 L closepath p F P
0 g
s
.714 .585 .71 r
.38059 .46093 m .38403 .45764 L p .38807 .46538 L F P
0 g
s
.714 .585 .71 r
.38807 .46538 m .38202 .46523 L .38059 .46093 L p F P
0 g
s
.701 .56 .692 r
.41372 .47775 m .41877 .47281 L .41238 .47294 L closepath p F P
0 g
s
.706 .564 .692 r
.41238 .47294 m .41372 .47775 L .41141 .48011 L p F P
0 g
s
.698 .579 .718 r
.42224 .45773 m .42139 .45776 L .41874 .44996 L p F P
0 g
s
.703 .582 .717 r
.41829 .44996 m .41874 .44996 L .42139 .45776 L p F P
0 g
s
.698 .572 .709 r
.42156 .4583 m .42224 .45773 L .42139 .45776 L closepath p F P
0 g
s
.697 .571 .709 r
.42156 .4583 m .42224 .45773 L p .4272 .46518 L F P
0 g
s
.697 .571 .709 r
.4272 .46518 m .42379 .46531 L .42156 .4583 L p F P
0 g
s
.696 .563 .701 r
.42447 .46759 m .4272 .46518 L .42379 .46531 L closepath p F P
0 g
s
.701 .567 .701 r
.42379 .46531 m .42447 .46759 L .41877 .47281 L p F P
0 g
s
.697 .577 .717 r
.43479 .45725 m .43229 .44978 L .42224 .45773 L closepath p F P
0 g
s
.698 .579 .718 r
.43219 .4495 m .43229 .44978 L .42224 .45773 L p F P
0 g
s
.698 .579 .718 r
.41874 .44996 m .43219 .4495 L p .42224 .45773 L F P
0 g
s
.697 .571 .709 r
.42224 .45773 m .43479 .45725 L p .4272 .46518 L F P
0 g
s
.712 .569 .692 r
.38639 .47983 m .3929 .47287 L p .3985 .48013 L F P
0 g
s
.713 .57 .692 r
.38639 .47983 m .3929 .47287 L .38434 .4727 L closepath p F P
0 g
s
.713 .577 .701 r
.3929 .47287 m .38434 .4727 L .3835 .46999 L p F P
0 g
s
.704 .591 .726 r
.41829 .44996 m .40501 .45012 L .405 .45008 L p F P
0 g
s
.708 .593 .725 r
.40501 .45012 m .405 .45008 L .40494 .45012 L closepath p F P
0 g
s
.708 .593 .725 r
.40206 .44205 m .3925 .45 L .40494 .45012 L p F P
0 g
s
.708 .593 .725 r
.40494 .45012 m .405 .45008 L .40206 .44205 L p F P
0 g
s
.704 .591 .726 r
.405 .45008 m .41528 .4419 L p .41829 .44996 L F P
0 g
s
.705 .59 .725 r
.41528 .4419 m .405 .45008 L .40206 .44205 L p F P
0 g
s
.7 .559 .692 r
.41877 .47281 m .42597 .47263 L p .42518 .47982 L F P
0 g
s
.7 .559 .692 r
.41372 .47775 m .41877 .47281 L p .42518 .47982 L F P
0 g
s
.7 .565 .699 r
.42597 .47263 m .42447 .46759 L .41877 .47281 L closepath p F P
0 g
s
.695 .562 .701 r
.42447 .46759 m .4272 .46518 L p .43313 .47234 L F P
0 g
s
.695 .562 .701 r
.43313 .47234 m .42597 .47263 L .42447 .46759 L p F P
0 g
s
.719 .582 .702 r
.38202 .46523 m .3835 .46999 L .38102 .47258 L p F P
0 g
s
.719 .582 .702 r
.37648 .46499 m .38202 .46523 L p .38102 .47258 L F P
0 g
s
.719 .588 .708 r
.38202 .46523 m .38059 .46093 L .37648 .46499 L closepath p F P
0 g
s
.715 .593 .718 r
.39097 .44998 m .39134 .45102 L .38403 .45764 L p F P
0 g
s
.715 .593 .718 r
.38076 .44966 m .39097 .44998 L p .38403 .45764 L F P
0 g
s
.715 .593 .718 r
.37766 .45249 m .38076 .44966 L p .38403 .45764 L F P
0 g
s
.715 .593 .718 r
.38403 .45764 m .37945 .45751 L .37766 .45249 L p F P
0 g
s
.715 .586 .71 r
.38059 .46093 m .38403 .45764 L .37945 .45751 L closepath p F P
0 g
s
.695 .562 .701 r
.4272 .46518 m .43715 .46477 L p .43313 .47234 L F P
0 g
s
.695 .569 .708 r
.43715 .46477 m .4352 .45856 L .4272 .46518 L closepath p F P
0 g
s
.697 .571 .709 r
.43479 .45725 m .4352 .45856 L .4272 .46518 L p F P
0 g
s
.711 .589 .718 r
.39134 .45102 m .3925 .45 L .39097 .44998 L closepath p F P
0 g
s
.718 .58 .7 r
.38434 .4727 m .3835 .46999 L .38102 .47258 L closepath p F P
0 g
s
.71 .596 .726 r
.40204 .44201 m .40206 .44205 L .3925 .45 L p F P
0 g
s
.71 .596 .726 r
.38985 .44183 m .40204 .44201 L p .3925 .45 L F P
0 g
s
.71 .596 .726 r
.3884 .44305 m .38985 .44183 L p .3925 .45 L F P
0 g
s
.71 .596 .726 r
.3925 .45 m .39097 .44998 L .3884 .44305 L p F P
0 g
s
.72 .59 .71 r
.37945 .45751 m .38059 .46093 L .37648 .46499 L p F P
0 g
s
.715 .598 .725 r
.39097 .44998 m .3884 .44305 L .38076 .44966 L closepath p F P
0 g
s
.717 .572 .691 r
.38434 .4727 m .38102 .47258 L p .3863 .47994 L F P
0 g
s
.717 .572 .691 r
.3863 .47994 m .38639 .47983 L .38434 .4727 L p F P
0 g
s
.703 .588 .725 r
.41874 .44996 m .41864 .44968 L .41829 .44996 L closepath p F P
0 g
s
.704 .591 .726 r
.41584 .4419 m .41864 .44968 L .41829 .44996 L p F P
0 g
s
.704 .591 .726 r
.41528 .4419 m .41584 .4419 L p .41829 .44996 L F P
0 g
s
.699 .586 .726 r
.42936 .44154 m .43219 .4495 L .41874 .44996 L p F P
0 g
s
.699 .586 .726 r
.41874 .44996 m .41864 .44968 L .42936 .44154 L p F P
0 g
s
.706 .564 .692 r
.41141 .48011 m .40054 .48015 L .40006 .47847 L p F P
0 g
s
.71 .567 .69 r
.40054 .48015 m .40006 .47847 L .3985 .48013 L closepath p F P
0 g
s
.699 .587 .726 r
.42934 .4415 m .42936 .44154 L .41864 .44968 L p F P
0 g
s
.699 .587 .726 r
.41864 .44968 m .41584 .4419 L .42934 .4415 L p F P
0 g
s
.72 .596 .717 r
.37945 .45751 m .37766 .45249 L .37267 .45719 L closepath p F P
0 g
s
.72 .59 .71 r
.37267 .45719 m .37945 .45751 L p .37648 .46499 L F P
0 g
s
.7 .559 .692 r
.42518 .47982 m .41437 .48008 L .41372 .47775 L p F P
0 g
s
.704 .562 .69 r
.41437 .48008 m .41372 .47775 L .41141 .48011 L closepath p F P
0 g
s
.695 .555 .692 r
.42736 .4777 m .43313 .47234 L .42597 .47263 L closepath p F P
0 g
s
.7 .559 .692 r
.42597 .47263 m .42736 .4777 L .42518 .47982 L p F P
0 g
s
.717 .572 .691 r
.38102 .47258 m .37484 .47951 L .3863 .47994 L p F P
0 g
s
.719 .574 .691 r
.36985 .47213 m .38102 .47258 L .37484 .47951 L p F P
0 g
s
.719 .582 .702 r
.36981 .47198 m .37648 .46499 L p .38102 .47258 L F P
0 g
s
.719 .582 .702 r
.38102 .47258 m .36985 .47213 L .36981 .47198 L p F P
0 g
s
.705 .555 .681 r
.40054 .48015 m .41141 .48011 L .40507 .48709 L p F P
0 g
s
.705 .555 .681 r
.40507 .48709 m .40233 .4871 L .40054 .48015 L p F P
0 g
s
.71 .558 .68 r
.3985 .48013 m .40054 .48015 L .40233 .4871 L p F P
0 g
s
.72 .583 .701 r
.36981 .47198 m .37648 .46499 L .36746 .46458 L closepath p F P
0 g
s
.72 .59 .71 r
.36689 .46291 m .37267 .45719 L p .37648 .46499 L F P
0 g
s
.72 .59 .71 r
.37648 .46499 m .36746 .46458 L .36689 .46291 L p F P
0 g
s
.71 .558 .68 r
.40233 .4871 m .39258 .48699 L .3985 .48013 L p F P
0 g
s
.711 .56 .681 r
.38642 .47994 m .3985 .48013 L .39258 .48699 L p F P
0 g
s
.712 .569 .692 r
.3985 .48013 m .38642 .47994 L .38639 .47983 L p F P
0 g
s
.704 .553 .68 r
.41141 .48011 m .41437 .48008 L .41613 .487 L p F P
0 g
s
.704 .553 .68 r
.41613 .487 m .40507 .48709 L .41141 .48011 L p F P
0 g
s
.699 .55 .681 r
.41437 .48008 m .42518 .47982 L .41838 .48695 L p F P
0 g
s
.699 .55 .681 r
.41838 .48695 m .41613 .487 L .41437 .48008 L p F P
0 g
s
.692 .574 .718 r
.437 .45713 m .43479 .45725 L .43229 .44978 L p F P
0 g
s
.692 .567 .71 r
.4352 .45856 m .437 .45713 L .43479 .45725 L closepath p F P
0 g
s
.716 .594 .718 r
.37766 .45249 m .38076 .44966 L .3766 .44952 L closepath p F P
0 g
s
.721 .598 .719 r
.3766 .44952 m .37766 .45249 L .37267 .45719 L p F P
0 g
s
.691 .566 .71 r
.4352 .45856 m .437 .45713 L p .44236 .46446 L F P
0 g
s
.691 .566 .71 r
.44236 .46446 m .43715 .46477 L .4352 .45856 L p F P
0 g
s
.716 .601 .727 r
.38793 .44179 m .3884 .44305 L .38076 .44966 L p F P
0 g
s
.716 .601 .727 r
.37826 .44144 m .38793 .44179 L p .38076 .44966 L F P
0 g
s
.716 .601 .727 r
.37471 .44453 m .37826 .44144 L p .38076 .44966 L F P
0 g
s
.716 .601 .727 r
.38076 .44966 m .3766 .44952 L .37471 .44453 L p F P
0 g
s
.716 .572 .691 r
.38642 .47994 m .38639 .47983 L .3863 .47994 L closepath p F P
0 g
s
.711 .56 .681 r
.39258 .48699 m .38823 .48692 L .38642 .47994 L p F P
0 g
s
.717 .563 .679 r
.3863 .47994 m .38642 .47994 L .38823 .48692 L p F P
0 g
s
.717 .563 .679 r
.38823 .48692 m .38074 .48668 L .3863 .47994 L p F P
0 g
s
.718 .565 .682 r
.37484 .47951 m .3863 .47994 L .38074 .48668 L p F P
0 g
s
.69 .559 .701 r
.43811 .46801 m .44236 .46446 L .43715 .46477 L closepath p F P
0 g
s
.695 .562 .701 r
.43715 .46477 m .43811 .46801 L .43313 .47234 L p F P
0 g
s
.721 .598 .719 r
.36958 .44915 m .3766 .44952 L p .37267 .45719 L F P
0 g
s
.721 .598 .719 r
.36396 .45445 m .36958 .44915 L p .37267 .45719 L F P
0 g
s
.721 .598 .719 r
.37267 .45719 m .36481 .45679 L .36396 .45445 L p F P
0 g
s
.721 .591 .71 r
.36689 .46291 m .37267 .45719 L .36481 .45679 L closepath p F P
0 g
s
.693 .554 .692 r
.43313 .47234 m .4393 .47206 L p .44003 .4792 L F P
0 g
s
.693 .554 .692 r
.42736 .4777 m .43313 .47234 L p .44003 .4792 L F P
0 g
s
.694 .56 .7 r
.4393 .47206 m .43811 .46801 L .43313 .47234 L closepath p F P
0 g
s
.706 .592 .726 r
.40206 .44205 m .40212 .44201 L .40204 .44201 L closepath p F P
0 g
s
.705 .59 .725 r
.40206 .44205 m .40212 .44201 L .41528 .4419 L p F P
0 g
s
.706 .599 .734 r
.40212 .44201 m .40204 .44201 L .39911 .43444 L p F P
0 g
s
.71 .601 .733 r
.40204 .44201 m .39911 .43444 L .38985 .44183 L closepath p F P
0 g
s
.706 .599 .734 r
.41266 .43356 m .41277 .43386 L .40212 .44201 L p F P
0 g
s
.706 .599 .734 r
.4002 .4336 m .41266 .43356 L p .40212 .44201 L F P
0 g
s
.706 .599 .734 r
.39911 .43444 m .4002 .4336 L p .40212 .44201 L F P
0 g
s
.704 .596 .733 r
.41277 .43386 m .40212 .44201 L .41528 .4419 L p F P
0 g
s
.693 .554 .692 r
.44003 .4792 m .42792 .47974 L .42736 .4777 L p F P
0 g
s
.698 .557 .69 r
.42792 .47974 m .42736 .4777 L .42518 .47982 L closepath p F P
0 g
s
.691 .572 .717 r
.44794 .45649 m .44593 .45043 L .437 .45713 L closepath p F P
0 g
s
.692 .574 .718 r
.44538 .44877 m .44593 .45043 L .437 .45713 L p F P
0 g
s
.692 .574 .718 r
.43269 .44948 m .44538 .44877 L p .437 .45713 L F P
0 g
s
.692 .574 .718 r
.43229 .44978 m .43269 .44948 L p .437 .45713 L F P
0 g
s
.691 .566 .71 r
.437 .45713 m .44794 .45649 L p .44236 .46446 L F P
0 g
s
.721 .603 .725 r
.3766 .44952 m .37471 .44453 L .36958 .44915 L closepath p F P
0 g
s
.698 .548 .68 r
.42518 .47982 m .42792 .47974 L .42965 .48663 L p F P
0 g
s
.698 .548 .68 r
.42965 .48663 m .41838 .48695 L .42518 .47982 L p F P
0 g
s
.693 .575 .718 r
.43229 .44978 m .43269 .44948 L .43219 .4495 L closepath p F P
0 g
s
.693 .582 .726 r
.43269 .44948 m .43219 .4495 L .42936 .44154 L p F P
0 g
s
.689 .558 .701 r
.43811 .46801 m .44236 .46446 L p .44878 .47148 L F P
0 g
s
.689 .558 .701 r
.44878 .47148 m .4393 .47206 L .43811 .46801 L p F P
0 g
s
.704 .596 .733 r
.41584 .4419 m .41571 .44158 L .41528 .4419 L closepath p F P
0 g
s
.704 .596 .733 r
.41528 .4419 m .41571 .44158 L .41277 .43386 L p F P
0 g
s
.693 .582 .726 r
.44258 .44081 m .44301 .44203 L .43269 .44948 L p F P
0 g
s
.693 .582 .726 r
.42943 .44149 m .44258 .44081 L p .43269 .44948 L F P
0 g
s
.693 .582 .726 r
.42936 .44154 m .42943 .44149 L p .43269 .44948 L F P
0 g
s
.692 .58 .725 r
.44538 .44877 m .44301 .44203 L .43269 .44948 L closepath p F P
0 g
s
.7 .594 .734 r
.42643 .43374 m .42934 .4415 L .41584 .4419 L p F P
0 g
s
.7 .594 .734 r
.41584 .4419 m .41571 .44158 L .42643 .43374 L p F P
0 g
s
.712 .597 .726 r
.3884 .44305 m .38985 .44183 L .38793 .44179 L closepath p F P
0 g
s
.7 .593 .733 r
.42643 .43374 m .41571 .44158 L .41277 .43386 L p F P
0 g
s
.693 .545 .681 r
.42792 .47974 m .44003 .4792 L .43271 .48649 L p F P
0 g
s
.693 .545 .681 r
.43271 .48649 m .42965 .48663 L .42792 .47974 L p F P
0 g
s
.724 .585 .7 r
.36746 .46458 m .36539 .46446 L p .36968 .47212 L F P
0 g
s
.724 .585 .7 r
.36968 .47212 m .36981 .47198 L .36746 .46458 L p F P
0 g
s
.724 .593 .709 r
.36746 .46458 m .36689 .46291 L .36539 .46446 L closepath p F P
0 g
s
.711 .604 .735 r
.39879 .4336 m .39911 .43444 L .38985 .44183 L p F P
0 g
s
.711 .604 .735 r
.38804 .43339 m .39879 .4336 L p .38985 .44183 L F P
0 g
s
.711 .604 .735 r
.38544 .43548 m .38804 .43339 L p .38985 .44183 L F P
0 g
s
.711 .604 .735 r
.38985 .44183 m .38793 .44179 L .38544 .43548 L p F P
0 g
s
.724 .585 .7 r
.36985 .47213 m .36981 .47198 L .36968 .47212 L closepath p F P
0 g
s
.719 .574 .691 r
.37484 .47951 m .37196 .4794 L .36985 .47213 L p F P
0 g
s
.724 .577 .69 r
.36968 .47212 m .36985 .47213 L .37196 .4794 L p F P
0 g
s
.725 .58 .692 r
.359 .47145 m .36968 .47212 L .36387 .47894 L p F P
0 g
s
.724 .585 .7 r
.36539 .46446 m .359 .47145 L .36968 .47212 L p F P
0 g
s
.724 .577 .69 r
.37196 .4794 m .36387 .47894 L .36968 .47212 L p F P
0 g
s
.725 .593 .709 r
.36539 .46446 m .36689 .46291 L .36481 .45679 L p F P
0 g
s
.716 .606 .733 r
.38793 .44179 m .38544 .43548 L .37826 .44144 L closepath p F P
0 g
s
.688 .55 .692 r
.441 .47831 m .44878 .47148 L .4393 .47206 L closepath p F P
0 g
s
.693 .554 .692 r
.4393 .47206 m .441 .47831 L .44003 .4792 L p F P
0 g
s
.689 .558 .701 r
.44236 .46446 m .45027 .46397 L p .44878 .47148 L F P
0 g
s
.689 .564 .709 r
.45027 .46397 m .44884 .45939 L .44236 .46446 L closepath p F P
0 g
s
.691 .566 .71 r
.44794 .45649 m .44884 .45939 L .44236 .46446 L p F P
0 g
s
.726 .588 .701 r
.35483 .46375 m .36539 .46446 L .359 .47145 L p F P
0 g
s
.725 .593 .709 r
.36178 .45658 m .35483 .46375 L .36539 .46446 L p F P
0 g
s
.725 .593 .709 r
.36481 .45679 m .36178 .45658 L p .36539 .46446 L F P
0 g
s
.705 .546 .67 r
.40292 .48969 m .40507 .48709 L .40233 .4871 L closepath p F P
0 g
s
.71 .551 .671 r
.40233 .4871 m .40292 .48969 L .39966 .4938 L p F P
0 g
s
.71 .551 .671 r
.39258 .48699 m .40233 .4871 L p .39966 .4938 L F P
0 g
s
.725 .601 .717 r
.36481 .45679 m .36396 .45445 L .36178 .45658 L closepath p F P
0 g
s
.718 .565 .682 r
.37269 .48212 m .37484 .47951 L p .38074 .48668 L F P
0 g
s
.719 .567 .681 r
.37269 .48212 m .37484 .47951 L .37196 .4794 L closepath p F P
0 g
s
.703 .545 .67 r
.40507 .48709 m .41613 .487 L p .41264 .49376 L F P
0 g
s
.703 .545 .67 r
.40292 .48969 m .40507 .48709 L p .41264 .49376 L F P
0 g
s
.722 .599 .719 r
.36396 .45445 m .36958 .44915 L .36188 .44872 L closepath p F P
0 g
s
.721 .606 .727 r
.37347 .44125 m .37471 .44453 L .36958 .44915 L p F P
0 g
s
.721 .606 .727 r
.36721 .44088 m .37347 .44125 L p .36958 .44915 L F P
0 g
s
.721 .606 .727 r
.36101 .44647 m .36721 .44088 L p .36958 .44915 L F P
0 g
s
.721 .606 .727 r
.36958 .44915 m .36188 .44872 L .36101 .44647 L p F P
0 g
s
.698 .541 .67 r
.41659 .48902 m .41838 .48695 L .41613 .487 L closepath p F P
0 g
s
.703 .545 .67 r
.41613 .487 m .41659 .48902 L .41264 .49376 L p F P
0 g
s
.717 .602 .727 r
.37471 .44453 m .37826 .44144 L .37347 .44125 L closepath p F P
0 g
s
.71 .551 .671 r
.38924 .4912 m .39258 .48699 L p .39966 .4938 L F P
0 g
s
.711 .552 .671 r
.38924 .4912 m .39258 .48699 L .38823 .48692 L closepath p F P
0 g
s
.724 .571 .683 r
.37196 .4794 m .37269 .48212 L .36944 .48621 L p F P
0 g
s
.724 .571 .683 r
.36387 .47894 m .37196 .4794 L p .36944 .48621 L F P
0 g
s
.694 .583 .726 r
.42936 .44154 m .42943 .44149 L .42934 .4415 L closepath p F P
0 g
s
.695 .59 .734 r
.42943 .44149 m .42934 .4415 L .42643 .43374 L p F P
0 g
s
.693 .588 .733 r
.44258 .44081 m .44008 .43409 L .42943 .44149 L closepath p F P
0 g
s
.695 .59 .734 r
.43952 .43258 m .44008 .43409 L .42943 .44149 L p F P
0 g
s
.695 .59 .734 r
.42723 .43318 m .43952 .43258 L p .42943 .44149 L F P
0 g
s
.695 .59 .734 r
.42643 .43374 m .42723 .43318 L p .42943 .44149 L F P
0 g
s
.726 .601 .717 r
.36178 .45658 m .36396 .45445 L .36188 .44872 L p F P
0 g
s
.697 .54 .67 r
.41838 .48695 m .42965 .48663 L p .4265 .49345 L F P
0 g
s
.697 .54 .67 r
.41659 .48902 m .41838 .48695 L p .4265 .49345 L F P
0 g
s
.715 .554 .67 r
.38823 .48692 m .38074 .48668 L p .3874 .49362 L F P
0 g
s
.715 .554 .67 r
.3874 .49362 m .38924 .4912 L .38823 .48692 L p F P
0 g
s
.717 .608 .735 r
.38459 .4333 m .38544 .43548 L .37826 .44144 L p F P
0 g
s
.717 .608 .735 r
.37654 .43297 m .38459 .4333 L p .37826 .44144 L F P
0 g
s
.717 .608 .735 r
.37176 .43696 m .37654 .43297 L p .37826 .44144 L F P
0 g
s
.717 .608 .735 r
.37826 .44144 m .37347 .44125 L .37176 .43696 L p F P
0 g
s
.727 .596 .71 r
.35135 .45583 m .36178 .45658 L .35483 .46375 L p F P
0 g
s
.726 .601 .717 r
.35884 .44849 m .35135 .45583 L .36178 .45658 L p F P
0 g
s
.726 .601 .717 r
.36188 .44872 m .35884 .44849 L p .36178 .45658 L F P
0 g
s
.686 .562 .71 r
.44884 .45939 m .45324 .45608 L .44794 .45649 L closepath p F P
0 g
s
.686 .57 .718 r
.45324 .45608 m .44794 .45649 L .44593 .45043 L p F P
0 g
s
.688 .55 .692 r
.44123 .47914 m .441 .47831 L .44878 .47148 L p F P
0 g
s
.692 .552 .691 r
.44123 .47914 m .441 .47831 L .44003 .4792 L closepath p F P
0 g
s
.691 .543 .68 r
.44003 .4792 m .44123 .47914 L .44293 .486 L p F P
0 g
s
.691 .543 .68 r
.44293 .486 m .43271 .48649 L .44003 .4792 L p F P
0 g
s
.703 .545 .67 r
.41264 .49376 m .40388 .49383 L .40292 .48969 L p F P
0 g
s
.709 .548 .669 r
.40388 .49383 m .40292 .48969 L .39966 .4938 L closepath p F P
0 g
s
.718 .565 .682 r
.38074 .48668 m .37383 .48644 L .37269 .48212 L p F P
0 g
s
.723 .568 .68 r
.37383 .48644 m .37269 .48212 L .36944 .48621 L closepath p F P
0 g
s
.685 .562 .71 r
.44884 .45939 m .45324 .45608 L p .45909 .46327 L F P
0 g
s
.685 .562 .71 r
.45909 .46327 m .45027 .46397 L .44884 .45939 L p F P
0 g
s
.707 .6 .734 r
.39911 .43444 m .4002 .4336 L .39879 .4336 L closepath p F P
0 g
s
.702 .543 .669 r
.41765 .49369 m .41659 .48902 L .41264 .49376 L closepath p F P
0 g
s
.697 .54 .67 r
.4265 .49345 m .41765 .49369 L .41659 .48902 L p F P
0 g
s
.721 .61 .733 r
.37347 .44125 m .37176 .43696 L .36721 .44088 L closepath p F P
0 g
s
.686 .54 .681 r
.44123 .47914 m .45429 .47829 L p .44833 .48565 L F P
0 g
s
.686 .54 .681 r
.44833 .48565 m .44293 .486 L .44123 .47914 L p F P
0 g
s
.688 .55 .692 r
.45239 .47124 m .45429 .47829 L .44123 .47914 L p F P
0 g
s
.688 .55 .692 r
.44878 .47148 m .45239 .47124 L p .44123 .47914 L F P
0 g
s
.684 .554 .701 r
.45175 .46904 m .45909 .46327 L .45027 .46397 L closepath p F P
0 g
s
.689 .558 .701 r
.45027 .46397 m .45175 .46904 L .44878 .47148 L p F P
0 g
s
.686 .57 .718 r
.44593 .45043 m .44855 .44854 L p .45324 .45608 L F P
0 g
s
.687 .571 .718 r
.44593 .45043 m .44855 .44854 L .44538 .44877 L closepath p F P
0 g
s
.715 .554 .67 r
.38074 .48668 m .37573 .49326 L .3874 .49362 L p F P
0 g
s
.717 .557 .671 r
.37383 .48644 m .38074 .48668 L .37573 .49326 L p F P
0 g
s
.688 .578 .727 r
.44855 .44854 m .44538 .44877 L .44301 .44203 L p F P
0 g
s
.706 .604 .741 r
.41266 .43356 m .40983 .42651 L .4002 .4336 L closepath p F P
0 g
s
.707 .606 .742 r
.40919 .42492 m .40983 .42651 L .4002 .4336 L p F P
0 g
s
.707 .606 .742 r
.39918 .4249 m .40919 .42492 L p .4002 .4336 L F P
0 g
s
.707 .606 .742 r
.39616 .42715 m .39918 .4249 L p .4002 .4336 L F P
0 g
s
.707 .606 .742 r
.4002 .4336 m .39879 .4336 L .39616 .42715 L p F P
0 g
s
.711 .609 .74 r
.39879 .4336 m .39616 .42715 L .38804 .43339 L closepath p F P
0 g
s
.701 .595 .734 r
.41277 .43386 m .41319 .43355 L .41266 .43356 L closepath p F P
0 g
s
.7 .593 .733 r
.42623 .43322 m .42643 .43374 L p .41277 .43386 L F P
0 g
s
.7 .593 .733 r
.41277 .43386 m .41319 .43355 L .42623 .43322 L p F P
0 g
s
.688 .556 .7 r
.45239 .47124 m .45175 .46904 L .44878 .47148 L closepath p F P
0 g
s
.692 .536 .67 r
.43023 .48919 m .43271 .48649 L .42965 .48663 L closepath p F P
0 g
s
.697 .54 .67 r
.42965 .48663 m .43023 .48919 L .4265 .49345 L p F P
0 g
s
.701 .602 .742 r
.41319 .43355 m .41266 .43356 L .40983 .42651 L p F P
0 g
s
.726 .608 .725 r
.36188 .44872 m .36101 .44647 L .35884 .44849 L closepath p F P
0 g
s
.701 .602 .742 r
.42283 .42465 m .42349 .42629 L .41319 .43355 L p F P
0 g
s
.701 .602 .742 r
.41212 .42487 m .42283 .42465 L p .41319 .43355 L F P
0 g
s
.701 .602 .742 r
.40983 .42651 m .41212 .42487 L p .41319 .43355 L F P
0 g
s
.7 .6 .741 r
.42623 .43322 m .42349 .42629 L .41319 .43355 L closepath p F P
0 g
s
.725 .58 .692 r
.35607 .47488 m .359 .47145 L p .36387 .47894 L F P
0 g
s
.726 .581 .692 r
.35607 .47488 m .359 .47145 L .35497 .47119 L closepath p F P
0 g
s
.726 .588 .701 r
.35317 .46558 m .35483 .46375 L p .359 .47145 L F P
0 g
s
.726 .588 .701 r
.359 .47145 m .35497 .47119 L .35317 .46558 L p F P
0 g
s
.712 .604 .734 r
.38544 .43548 m .38804 .43339 L .38459 .4333 L closepath p F P
0 g
s
.724 .571 .683 r
.35895 .48511 m .36387 .47894 L p .36944 .48621 L F P
0 g
s
.725 .572 .682 r
.35895 .48511 m .36387 .47894 L .35716 .47853 L closepath p F P
0 g
s
.725 .58 .692 r
.36387 .47894 m .35716 .47853 L .35607 .47488 L p F P
0 g
s
.684 .554 .701 r
.45239 .47124 m .45175 .46904 L .45909 .46327 L p F P
0 g
s
.691 .535 .67 r
.43271 .48649 m .44293 .486 L p .44146 .49281 L F P
0 g
s
.691 .535 .67 r
.43023 .48919 m .43271 .48649 L p .44146 .49281 L F P
0 g
s
.727 .589 .701 r
.35317 .46558 m .35483 .46375 L .35252 .46358 L closepath p F P
0 g
s
.727 .596 .71 r
.35024 .45699 m .35135 .45583 L p .35483 .46375 L F P
0 g
s
.727 .596 .71 r
.35483 .46375 m .35252 .46358 L .35024 .45699 L p F P
0 g
s
.712 .611 .742 r
.39523 .42488 m .39616 .42715 L .38804 .43339 L p F P
0 g
s
.712 .611 .742 r
.38706 .42467 m .39523 .42488 L p .38804 .43339 L F P
0 g
s
.712 .611 .742 r
.38248 .42822 m .38706 .42467 L p .38804 .43339 L F P
0 g
s
.712 .611 .742 r
.38804 .43339 m .38459 .4333 L .38248 .42822 L p F P
0 g
s
.686 .57 .718 r
.44855 .44854 m .45832 .44778 L p .45324 .45608 L F P
0 g
s
.686 .576 .726 r
.45832 .44778 m .45666 .443 L .44855 .44854 L closepath p F P
0 g
s
.688 .578 .727 r
.45556 .43986 m .45666 .443 L .44855 .44854 L p F P
0 g
s
.688 .578 .727 r
.44501 .44064 m .45556 .43986 L p .44855 .44854 L F P
0 g
s
.688 .578 .727 r
.44301 .44203 m .44501 .44064 L p .44855 .44854 L F P
0 g
s
.717 .557 .671 r
.37573 .49326 m .37546 .49326 L .37383 .48644 L p F P
0 g
s
.723 .561 .67 r
.36944 .48621 m .37383 .48644 L .37546 .49326 L p F P
0 g
s
.723 .607 .727 r
.36101 .44647 m .36721 .44088 L .35865 .44035 L closepath p F P
0 g
s
.726 .608 .725 r
.35884 .44849 m .36101 .44647 L .35865 .44035 L p F P
0 g
s
.71 .551 .671 r
.39966 .4938 m .38982 .49369 L .38924 .4912 L p F P
0 g
s
.715 .554 .67 r
.38982 .49369 m .38924 .4912 L .3874 .49362 L closepath p F P
0 g
s
.685 .562 .71 r
.45324 .45608 m .46085 .45547 L p .45909 .46327 L F P
0 g
s
.685 .568 .717 r
.46085 .45547 m .45957 .45159 L .45324 .45608 L closepath p F P
0 g
s
.686 .57 .718 r
.45832 .44778 m .45957 .45159 L .45324 .45608 L p F P
0 g
s
.682 .545 .692 r
.45239 .47124 m .46526 .47018 L p .45643 .47812 L F P
0 g
s
.682 .545 .692 r
.45643 .47812 m .45429 .47829 L .45239 .47124 L p F P
0 g
s
.684 .554 .701 r
.46316 .46293 m .46526 .47018 L .45239 .47124 L p F P
0 g
s
.684 .554 .701 r
.45909 .46327 m .46316 .46293 L p .45239 .47124 L F P
0 g
s
.727 .604 .719 r
.34857 .44769 m .35884 .44849 L .35135 .45583 L p F P
0 g
s
.726 .608 .725 r
.35658 .44018 m .34857 .44769 L .35884 .44849 L p F P
0 g
s
.726 .608 .725 r
.35865 .44035 m .35658 .44018 L p .35884 .44849 L F P
0 g
s
.716 .613 .74 r
.38459 .4333 m .38248 .42822 L .37654 .43297 L closepath p F P
0 g
s
.722 .613 .735 r
.37004 .43267 m .37176 .43696 L .36721 .44088 L p F P
0 g
s
.722 .613 .735 r
.36556 .43238 m .37004 .43267 L p .36721 .44088 L F P
0 g
s
.722 .613 .735 r
.35805 .43887 m .36556 .43238 L p .36721 .44088 L F P
0 g
s
.722 .613 .735 r
.36721 .44088 m .35865 .44035 L .35805 .43887 L p F P
0 g
s
.689 .579 .727 r
.44301 .44203 m .44501 .44064 L .44258 .44081 L closepath p F P
0 g
s
.73 .583 .691 r
.35497 .47119 m .34869 .47067 L p .3533 .47824 L F P
0 g
s
.73 .583 .691 r
.3533 .47824 m .35607 .47488 L .35497 .47119 L p F P
0 g
s
.731 .591 .7 r
.35497 .47119 m .35317 .46558 L .34869 .47067 L closepath p F P
0 g
s
.731 .594 .702 r
.35252 .46358 m .35317 .46558 L .34869 .47067 L p F P
0 g
s
.696 .591 .735 r
.42643 .43374 m .42723 .43318 L .42623 .43322 L closepath p F P
0 g
s
.731 .594 .702 r
.34474 .46289 m .35252 .46358 L p .34869 .47067 L F P
0 g
s
.732 .599 .709 r
.35252 .46358 m .35024 .45699 L .34474 .46289 L closepath p F P
0 g
s
.689 .586 .735 r
.44501 .44064 m .44258 .44081 L .44008 .43409 L p F P
0 g
s
.696 .597 .742 r
.42723 .43318 m .42623 .43322 L .42349 .42629 L p F P
0 g
s
.691 .535 .67 r
.44146 .49281 m .43116 .4933 L .43023 .48919 L p F P
0 g
s
.696 .538 .669 r
.43116 .4933 m .43023 .48919 L .4265 .49345 L closepath p F P
0 g
s
.703 .536 .659 r
.40388 .49383 m .41264 .49376 L .40772 .50032 L p F P
0 g
s
.703 .536 .659 r
.40772 .50032 m .40521 .50034 L .40388 .49383 L p F P
0 g
s
.708 .539 .658 r
.39966 .4938 m .40388 .49383 L .40521 .50034 L p F P
0 g
s
.694 .595 .741 r
.43952 .43258 m .43714 .42651 L .42723 .43318 L closepath p F P
0 g
s
.696 .597 .742 r
.43619 .42407 m .43714 .42651 L .42723 .43318 L p F P
0 g
s
.696 .597 .742 r
.4261 .42452 m .43619 .42407 L p .42723 .43318 L F P
0 g
s
.696 .597 .742 r
.42349 .42629 m .4261 .42452 L p .42723 .43318 L F P
0 g
s
.718 .609 .735 r
.37176 .43696 m .37654 .43297 L .37004 .43267 L closepath p F P
0 g
s
.73 .583 .69 r
.35716 .47853 m .35607 .47488 L .3533 .47824 L closepath p F P
0 g
s
.708 .539 .658 r
.40521 .50034 m .39506 .50027 L .39966 .4938 L p F P
0 g
s
.709 .541 .659 r
.38982 .49369 m .39966 .4938 L .39506 .50027 L p F P
0 g
s
.723 .561 .67 r
.37546 .49326 m .36473 .4927 L .36944 .48621 L p F P
0 g
s
.724 .562 .671 r
.35909 .48564 m .36944 .48621 L .36473 .4927 L p F P
0 g
s
.724 .571 .683 r
.36944 .48621 m .35909 .48564 L .35895 .48511 L p F P
0 g
s
.701 .534 .658 r
.41264 .49376 m .41765 .49369 L .41897 .50018 L p F P
0 g
s
.701 .534 .658 r
.41897 .50018 m .40772 .50032 L .41264 .49376 L p F P
0 g
s
.727 .604 .719 r
.34728 .44895 m .34857 .44769 L p .35135 .45583 L F P
0 g
s
.727 .604 .719 r
.35135 .45583 m .34979 .45571 L .34728 .44895 L p F P
0 g
s
.728 .597 .71 r
.35024 .45699 m .35135 .45583 L .34979 .45571 L closepath p F P
0 g
s
.688 .584 .733 r
.45556 .43986 m .45373 .43488 L .44501 .44064 L closepath p F P
0 g
s
.689 .586 .735 r
.45255 .43167 m .45373 .43488 L .44501 .44064 L p F P
0 g
s
.689 .586 .735 r
.44263 .43238 m .45255 .43167 L p .44501 .44064 L F P
0 g
s
.689 .586 .735 r
.44008 .43409 m .44263 .43238 L p .44501 .44064 L F P
0 g
s
.729 .575 .681 r
.35716 .47853 m .3533 .47824 L p .35857 .4856 L F P
0 g
s
.729 .575 .681 r
.35857 .4856 m .35895 .48511 L .35716 .47853 L p F P
0 g
s
.696 .53 .659 r
.41765 .49369 m .4265 .49345 L .42123 .50012 L p F P
0 g
s
.696 .53 .659 r
.42123 .50012 m .41897 .50018 L .41765 .49369 L p F P
0 g
s
.709 .541 .659 r
.39506 .50027 m .39117 .50022 L .38982 .49369 L p F P
0 g
s
.715 .544 .657 r
.3874 .49362 m .38982 .49369 L .39117 .50022 L p F P
0 g
s
.732 .602 .711 r
.34979 .45571 m .35024 .45699 L .34474 .46289 L p F P
0 g
s
.715 .544 .657 r
.39117 .50022 m .38307 .5 L .3874 .49362 L p F P
0 g
s
.716 .546 .658 r
.37573 .49326 m .3874 .49362 L .38307 .5 L p F P
0 g
s
.717 .615 .742 r
.38093 .4245 m .38248 .42822 L .37654 .43297 L p F P
0 g
s
.717 .615 .742 r
.37559 .42424 m .38093 .4245 L p .37654 .43297 L F P
0 g
s
.717 .615 .742 r
.36879 .4297 m .37559 .42424 L p .37654 .43297 L F P
0 g
s
.717 .615 .742 r
.37654 .43297 m .37004 .43267 L .36879 .4297 L p F P
0 g
s
.732 .607 .717 r
.34979 .45571 m .34728 .44895 L .34144 .45491 L closepath p F P
0 g
s
.732 .602 .711 r
.34144 .45491 m .34979 .45571 L p .34474 .46289 L F P
0 g
s
.685 .562 .71 r
.46085 .45547 m .46249 .46076 L .45909 .46327 L p F P
0 g
s
.683 .56 .709 r
.46316 .46293 m .46249 .46076 L .45909 .46327 L closepath p F P
0 g
s
.685 .531 .671 r
.44388 .49021 m .44833 .48565 L .44293 .486 L closepath p F P
0 g
s
.691 .535 .67 r
.44293 .486 m .44388 .49021 L .44146 .49281 L p F P
0 g
s
.681 .536 .681 r
.45464 .47972 m .45643 .47812 L .45429 .47829 L closepath p F P
0 g
s
.686 .54 .681 r
.45429 .47829 m .45464 .47972 L .44833 .48565 L p F P
0 g
s
.695 .528 .658 r
.4265 .49345 m .43116 .4933 L .43246 .49976 L p F P
0 g
s
.695 .528 .658 r
.43246 .49976 m .42123 .50012 L .4265 .49345 L p F P
0 g
s
.727 .615 .733 r
.35865 .44035 m .35805 .43887 L .35658 .44018 L closepath p F P
0 g
s
.708 .607 .742 r
.39616 .42715 m .39918 .4249 L .39523 .42488 L closepath p F P
0 g
s
.73 .583 .691 r
.34869 .47067 m .34311 .47741 L .3533 .47824 L p F P
0 g
s
.732 .586 .692 r
.33972 .4699 m .34869 .47067 L .34311 .47741 L p F P
0 g
s
.731 .594 .702 r
.3394 .46894 m .34474 .46289 L p .34869 .47067 L F P
0 g
s
.731 .594 .702 r
.34869 .47067 m .33972 .4699 L .3394 .46894 L p F P
0 g
s
.729 .575 .681 r
.3533 .47824 m .34829 .48481 L .35857 .4856 L p F P
0 g
s
.731 .577 .682 r
.34311 .47741 m .3533 .47824 L .34829 .48481 L p F P
0 g
s
.68 .565 .719 r
.47144 .45444 m .46085 .45547 L .45957 .45159 L p F P
0 g
s
.679 .558 .71 r
.46249 .46076 m .47144 .45444 L .46085 .45547 L closepath p F P
0 g
s
.69 .586 .735 r
.44008 .43409 m .44263 .43238 L .43952 .43258 L closepath p F P
0 g
s
.702 .603 .742 r
.40983 .42651 m .41212 .42487 L .40919 .42492 L closepath p F P
0 g
s
.68 .565 .719 r
.45957 .45159 m .46629 .44703 L p .47144 .45444 L F P
0 g
s
.681 .566 .719 r
.45957 .45159 m .46629 .44703 L .45832 .44778 L closepath p F P
0 g
s
.722 .617 .74 r
.37004 .43267 m .36879 .4297 L .36556 .43238 L closepath p F P
0 g
s
.68 .535 .681 r
.45464 .47972 m .45643 .47812 L p .46559 .48431 L F P
0 g
s
.68 .535 .681 r
.46559 .48431 m .45597 .48512 L .45464 .47972 L p F P
0 g
s
.685 .538 .68 r
.45597 .48512 m .45464 .47972 L .44833 .48565 L closepath p F P
0 g
s
.679 .558 .71 r
.46316 .46293 m .46249 .46076 L .47144 .45444 L p F P
0 g
s
.69 .525 .659 r
.43116 .4933 m .44146 .49281 L .43579 .4996 L p F P
0 g
s
.69 .525 .659 r
.43579 .4996 m .43246 .49976 L .43116 .4933 L p F P
0 g
s
.682 .573 .727 r
.46629 .44703 m .45832 .44778 L .45666 .443 L p F P
0 g
s
.68 .535 .681 r
.45643 .47812 m .46712 .4772 L p .46559 .48431 L F P
0 g
s
.68 .542 .69 r
.46712 .4772 m .46539 .4707 L .45643 .47812 L closepath p F P
0 g
s
.682 .545 .692 r
.46526 .47018 m .46539 .4707 L .45643 .47812 L p F P
0 g
s
.728 .612 .728 r
.34647 .43932 m .35658 .44018 L .34857 .44769 L p F P
0 g
s
.727 .615 .733 r
.35499 .43166 m .34647 .43932 L .35658 .44018 L p F P
0 g
s
.727 .615 .733 r
.35511 .43167 m .35499 .43166 L p .35658 .44018 L F P
0 g
s
.727 .615 .733 r
.35658 .44018 m .35805 .43887 L .35511 .43167 L p F P
0 g
s
.713 .612 .742 r
.38248 .42822 m .38706 .42467 L .38093 .4245 L closepath p F P
0 g
s
.678 .549 .702 r
.46316 .46293 m .47583 .46166 L p .46616 .47009 L F P
0 g
s
.678 .549 .702 r
.46616 .47009 m .46526 .47018 L .46316 .46293 L p F P
0 g
s
.679 .558 .71 r
.47355 .45422 m .47583 .46166 L .46316 .46293 L p F P
0 g
s
.679 .558 .71 r
.47144 .45444 m .47355 .45422 L p .46316 .46293 L F P
0 g
s
.716 .546 .658 r
.37553 .49356 m .37573 .49326 L p .38307 .5 L F P
0 g
s
.717 .547 .658 r
.37553 .49356 m .37573 .49326 L .37546 .49326 L closepath p F P
0 g
s
.729 .574 .681 r
.35909 .48564 m .35895 .48511 L .35857 .4856 L closepath p F P
0 g
s
.722 .552 .66 r
.37546 .49326 m .37553 .49356 L .37164 .49957 L p F P
0 g
s
.722 .552 .66 r
.36473 .4927 m .37546 .49326 L p .37164 .49957 L F P
0 g
s
.69 .593 .742 r
.44263 .43238 m .43952 .43258 L .43714 .42651 L p F P
0 g
s
.723 .614 .735 r
.35805 .43887 m .36556 .43238 L .35511 .43167 L closepath p F P
0 g
s
.685 .53 .671 r
.44833 .48565 m .45597 .48512 L p .44443 .49265 L F P
0 g
s
.685 .53 .671 r
.44443 .49265 m .44388 .49021 L .44833 .48565 L p F P
0 g
s
.733 .595 .702 r
.3394 .46894 m .34474 .46289 L .33717 .4622 L closepath p F P
0 g
s
.732 .602 .711 r
.33647 .46022 m .34144 .45491 L p .34474 .46289 L F P
0 g
s
.732 .602 .711 r
.34474 .46289 m .33717 .4622 L .33647 .46022 L p F P
0 g
s
.724 .562 .671 r
.36473 .4927 m .36074 .49248 L .35909 .48564 L p F P
0 g
s
.729 .565 .669 r
.35857 .4856 m .35909 .48564 L .36074 .49248 L p F P
0 g
s
.716 .546 .658 r
.38307 .5 m .37683 .49981 L .37553 .49356 L p F P
0 g
s
.721 .549 .657 r
.37683 .49981 m .37553 .49356 L .37164 .49957 L closepath p F P
0 g
s
.729 .605 .719 r
.34728 .44895 m .34857 .44769 L .34676 .44754 L closepath p F P
0 g
s
.728 .612 .728 r
.34432 .44135 m .34647 .43932 L p .34857 .44769 L F P
0 g
s
.728 .612 .728 r
.34857 .44769 m .34676 .44754 L .34432 .44135 L p F P
0 g
s
.73 .568 .672 r
.34829 .48481 m .35857 .4856 L .35413 .49201 L p F P
0 g
s
.729 .565 .669 r
.36074 .49248 m .35413 .49201 L .35857 .4856 L p F P
0 g
s
.702 .609 .75 r
.41212 .42487 m .40919 .42492 L .40687 .41943 L p F P
0 g
s
.706 .611 .748 r
.40919 .42492 m .40687 .41943 L .39918 .4249 L closepath p F P
0 g
s
.707 .613 .75 r
.4054 .41596 m .40687 .41943 L .39918 .4249 L p F P
0 g
s
.707 .613 .75 r
.39906 .41591 m .4054 .41596 L p .39918 .4249 L F P
0 g
s
.707 .613 .75 r
.39319 .42013 m .39906 .41591 L p .39918 .4249 L F P
0 g
s
.707 .613 .75 r
.39918 .4249 m .39523 .42488 L .39319 .42013 L p F P
0 g
s
.733 .609 .72 r
.34676 .44754 m .34728 .44895 L .34144 .45491 L p F P
0 g
s
.712 .616 .748 r
.39523 .42488 m .39319 .42013 L .38706 .42467 L closepath p F P
0 g
s
.701 .607 .748 r
.42283 .42465 m .42054 .41913 L .41212 .42487 L closepath p F P
0 g
s
.702 .609 .75 r
.41913 .41576 m .42054 .41913 L .41212 .42487 L p F P
0 g
s
.702 .609 .75 r
.41203 .41588 m .41913 .41576 L p .41212 .42487 L F P
0 g
s
.702 .609 .75 r
.40687 .41943 m .41203 .41588 L p .41212 .42487 L F P
0 g
s
.697 .598 .742 r
.42349 .42629 m .4261 .42452 L .42283 .42465 L closepath p F P
0 g
s
.682 .573 .727 r
.45666 .443 m .46241 .43923 L p .46629 .44703 L F P
0 g
s
.683 .574 .727 r
.45666 .443 m .46241 .43923 L .45556 .43986 L closepath p F P
0 g
s
.722 .62 .743 r
.36628 .42376 m .36879 .4297 L .36556 .43238 L p F P
0 g
s
.722 .62 .743 r
.36462 .42365 m .36628 .42376 L p .36556 .43238 L F P
0 g
s
.722 .62 .743 r
.35507 .43159 m .36462 .42365 L p .36556 .43238 L F P
0 g
s
.722 .62 .743 r
.36556 .43238 m .35511 .43167 L .35507 .43159 L p F P
0 g
s
.689 .591 .741 r
.45255 .43167 m .4508 .42715 L .44263 .43238 L closepath p F P
0 g
s
.69 .593 .742 r
.44928 .42322 m .4508 .42715 L .44263 .43238 L p F P
0 g
s
.69 .593 .742 r
.44141 .42375 m .44928 .42322 L p .44263 .43238 L F P
0 g
s
.69 .593 .742 r
.43714 .42651 m .44141 .42375 L p .44263 .43238 L F P
0 g
s
.733 .609 .72 r
.33878 .44673 m .34676 .44754 L p .34144 .45491 L F P
0 g
s
.733 .614 .725 r
.34676 .44754 m .34432 .44135 L .33878 .44673 L closepath p F P
0 g
s
.689 .533 .67 r
.44443 .49265 m .44388 .49021 L .44146 .49281 L closepath p F P
0 g
s
.683 .581 .735 r
.46241 .43923 m .45556 .43986 L .45373 .43488 L p F P
0 g
s
.712 .618 .75 r
.39134 .41582 m .39319 .42013 L .38706 .42467 L p F P
0 g
s
.712 .618 .75 r
.38691 .41569 m .39134 .41582 L p .38706 .42467 L F P
0 g
s
.712 .618 .75 r
.37951 .42122 m .38691 .41569 L p .38706 .42467 L F P
0 g
s
.712 .618 .75 r
.38706 .42467 m .38093 .4245 L .37951 .42122 L p F P
0 g
s
.676 .54 .691 r
.46539 .4707 m .46616 .47009 L .46526 .47018 L closepath p F P
0 g
s
.718 .616 .742 r
.36879 .4297 m .37559 .42424 L .36628 .42376 L closepath p F P
0 g
s
.696 .605 .75 r
.4261 .42452 m .42283 .42465 L .42054 .41913 L p F P
0 g
s
.676 .539 .691 r
.46539 .4707 m .46616 .47009 L p .47495 .47639 L F P
0 g
s
.676 .539 .691 r
.47495 .47639 m .46712 .4772 L .46539 .4707 L p F P
0 g
s
.676 .539 .691 r
.46616 .47009 m .47789 .46887 L p .47495 .47639 L F P
0 g
s
.676 .547 .7 r
.47789 .46887 m .47614 .46275 L .46616 .47009 L closepath p F P
0 g
s
.678 .549 .702 r
.47583 .46166 m .47614 .46275 L .46616 .47009 L p F P
0 g
s
.733 .609 .72 r
.33352 .45207 m .33878 .44673 L p .34144 .45491 L F P
0 g
s
.733 .609 .72 r
.34144 .45491 m .33433 .45422 L .33352 .45207 L p F P
0 g
s
.734 .603 .711 r
.33647 .46022 m .34144 .45491 L .33433 .45422 L closepath p F P
0 g
s
.688 .523 .657 r
.44146 .49281 m .44443 .49265 L .4457 .49909 L p F P
0 g
s
.688 .523 .657 r
.4457 .49909 m .43579 .4996 L .44146 .49281 L p F P
0 g
s
.695 .603 .748 r
.43619 .42407 m .4342 .41923 L .4261 .42452 L closepath p F P
0 g
s
.696 .605 .75 r
.43256 .41525 m .4342 .41923 L .4261 .42452 L p F P
0 g
s
.696 .605 .75 r
.42602 .41552 m .43256 .41525 L p .4261 .42452 L F P
0 g
s
.696 .605 .75 r
.42054 .41913 m .42602 .41552 L p .4261 .42452 L F P
0 g
s
.717 .62 .748 r
.38093 .4245 m .37951 .42122 L .37559 .42424 L closepath p F P
0 g
s
.702 .525 .646 r
.40574 .50336 m .40772 .50032 L .40521 .50034 L closepath p F P
0 g
s
.707 .53 .646 r
.40521 .50034 m .40574 .50336 L .4037 .50662 L p F P
0 g
s
.707 .53 .646 r
.39506 .50027 m .40521 .50034 L p .4037 .50662 L F P
0 g
s
.7 .524 .646 r
.40772 .50032 m .41897 .50018 L p .41696 .5065 L F P
0 g
s
.7 .524 .646 r
.40574 .50336 m .40772 .50032 L p .41696 .5065 L F P
0 g
s
.679 .526 .671 r
.45597 .48512 m .46559 .48431 L .45783 .49174 L p F P
0 g
s
.679 .526 .671 r
.45783 .49174 m .45747 .49177 L .45597 .48512 L p F P
0 g
s
.685 .53 .671 r
.45597 .48512 m .45747 .49177 L .44443 .49265 L p F P
0 g
s
.722 .552 .66 r
.36176 .49724 m .36473 .4927 L p .37164 .49957 L F P
0 g
s
.724 .553 .66 r
.36176 .49724 m .36473 .4927 L .36074 .49248 L closepath p F P
0 g
s
.707 .53 .646 r
.39203 .5051 m .39506 .50027 L p .4037 .50662 L F P
0 g
s
.708 .531 .646 r
.39203 .5051 m .39506 .50027 L .39117 .50022 L closepath p F P
0 g
s
.732 .586 .692 r
.34311 .47741 m .34197 .47732 L .33972 .4699 L p F P
0 g
s
.737 .589 .691 r
.33867 .46979 m .33972 .4699 L .34197 .47732 L p F P
0 g
s
.736 .596 .7 r
.33972 .4699 m .3394 .46894 L .33867 .46979 L closepath p F P
0 g
s
.683 .519 .658 r
.44443 .49265 m .45747 .49177 L p .45167 .49869 L F P
0 g
s
.683 .519 .658 r
.45167 .49869 m .4457 .49909 L .44443 .49265 L p F P
0 g
s
.737 .597 .701 r
.33867 .46979 m .3394 .46894 L .33717 .4622 L p F P
0 g
s
.713 .534 .645 r
.39117 .50022 m .38307 .5 L p .39118 .50652 L F P
0 g
s
.713 .534 .645 r
.39118 .50652 m .39203 .5051 L .39117 .50022 L p F P
0 g
s
.691 .594 .743 r
.43714 .42651 m .44141 .42375 L .43619 .42407 L closepath p F P
0 g
s
.684 .582 .735 r
.45373 .43488 m .45981 .43103 L .45255 .43167 L closepath p F P
0 g
s
.683 .581 .735 r
.45373 .43488 m .45981 .43103 L p .46241 .43923 L F P
0 g
s
.695 .519 .645 r
.41941 .50277 m .42123 .50012 L .41897 .50018 L closepath p F P
0 g
s
.7 .524 .646 r
.41897 .50018 m .41941 .50277 L .41696 .5065 L p F P
0 g
s
.731 .577 .682 r
.3423 .47849 m .34311 .47741 L p .34829 .48481 L F P
0 g
s
.733 .578 .682 r
.3423 .47849 m .34311 .47741 L .34197 .47732 L closepath p F P
0 g
s
.737 .589 .691 r
.34197 .47732 m .33342 .47644 L .33867 .46979 L p F P
0 g
s
.738 .592 .693 r
.32915 .46875 m .33867 .46979 L .33342 .47644 L p F P
0 g
s
.737 .597 .701 r
.33491 .46195 m .32915 .46875 L .33867 .46979 L p F P
0 g
s
.737 .597 .701 r
.33717 .4622 m .33491 .46195 L p .33867 .46979 L F P
0 g
s
.68 .565 .719 r
.46629 .44703 m .47105 .44656 L p .47144 .45444 L F P
0 g
s
.68 .572 .726 r
.47105 .44656 m .47031 .44443 L .46629 .44703 L closepath p F P
0 g
s
.682 .573 .727 r
.46832 .43866 m .47031 .44443 L .46629 .44703 L p F P
0 g
s
.682 .573 .727 r
.46241 .43923 m .46832 .43866 L p .46629 .44703 L F P
0 g
s
.737 .604 .709 r
.33717 .4622 m .33647 .46022 L .33491 .46195 L closepath p F P
0 g
s
.694 .518 .645 r
.42123 .50012 m .43246 .49976 L p .43114 .5061 L F P
0 g
s
.694 .518 .645 r
.41941 .50277 m .42123 .50012 L p .43114 .5061 L F P
0 g
s
.718 .622 .75 r
.37694 .41535 m .37951 .42122 L .37559 .42424 L p F P
0 g
s
.718 .622 .75 r
.3754 .41526 m .37694 .41535 L p .37559 .42424 L F P
0 g
s
.718 .622 .75 r
.3658 .4227 m .3754 .41526 L p .37559 .42424 L F P
0 g
s
.718 .622 .75 r
.37559 .42424 m .36628 .42376 L .3658 .4227 L p F P
0 g
s
.736 .58 .68 r
.34197 .47732 m .33342 .47644 L p .33832 .48392 L F P
0 g
s
.736 .58 .68 r
.33832 .48392 m .3423 .47849 L .34197 .47732 L p F P
0 g
s
.728 .556 .658 r
.36074 .49248 m .35413 .49201 L p .36065 .499 L F P
0 g
s
.728 .556 .658 r
.36065 .499 m .36176 .49724 L .36074 .49248 L p F P
0 g
s
.737 .604 .709 r
.33491 .46195 m .33647 .46022 L .33433 .45422 L p F P
0 g
s
.73 .613 .727 r
.34432 .44135 m .34647 .43932 L .34341 .43905 L closepath p F P
0 g
s
.728 .619 .736 r
.34505 .43074 m .35499 .43166 L .34647 .43932 L p F P
0 g
s
.728 .619 .736 r
.34133 .43409 m .34505 .43074 L p .34647 .43932 L F P
0 g
s
.728 .619 .736 r
.34647 .43932 m .34341 .43905 L .34133 .43409 L p F P
0 g
s
.736 .58 .68 r
.34395 .48447 m .3423 .47849 L .33832 .48392 L closepath p F P
0 g
s
.731 .577 .682 r
.34829 .48481 m .34395 .48447 L .3423 .47849 L p F P
0 g
s
.713 .534 .645 r
.38307 .5 m .37936 .5062 L .39118 .50652 L p F P
0 g
s
.715 .536 .646 r
.37683 .49981 m .38307 .5 L .37936 .5062 L p F P
0 g
s
.733 .617 .728 r
.34341 .43905 m .34432 .44135 L .33878 .44673 L p F P
0 g
s
.73 .568 .672 r
.34515 .4893 m .34829 .48481 L p .35413 .49201 L F P
0 g
s
.731 .569 .672 r
.34515 .4893 m .34829 .48481 L .34395 .48447 L closepath p F P
0 g
s
.708 .614 .75 r
.39319 .42013 m .39906 .41591 L .39134 .41582 L closepath p F P
0 g
s
.679 .564 .718 r
.47355 .45422 m .47323 .45324 L .47144 .45444 L closepath p F P
0 g
s
.68 .565 .719 r
.47105 .44656 m .47323 .45324 L .47144 .45444 L p F P
0 g
s
.674 .531 .682 r
.46829 .48194 m .47495 .47639 L .46712 .4772 L closepath p F P
0 g
s
.68 .535 .681 r
.46712 .4772 m .46829 .48194 L .46559 .48431 L p F P
0 g
s
.684 .589 .743 r
.45981 .43103 m .45255 .43167 L .4508 .42715 L p F P
0 g
s
.727 .622 .741 r
.35511 .43167 m .35507 .43159 L .35499 .43166 L closepath p F P
0 g
s
.703 .61 .75 r
.40687 .41943 m .41203 .41588 L .4054 .41596 L closepath p F P
0 g
s
.728 .623 .741 r
.35208 .42467 m .34505 .43074 L .35499 .43166 L p F P
0 g
s
.728 .623 .741 r
.35499 .43166 m .35507 .43159 L .35208 .42467 L p F P
0 g
s
.691 .6 .75 r
.44141 .42375 m .43619 .42407 L .4342 .41923 L p F P
0 g
s
.724 .621 .742 r
.36462 .42365 m .35507 .43159 L .35208 .42467 L p F P
0 g
s
.682 .579 .734 r
.46832 .43866 m .46739 .43612 L .46241 .43923 L closepath p F P
0 g
s
.683 .581 .735 r
.46535 .43051 m .46739 .43612 L .46241 .43923 L p F P
0 g
s
.683 .581 .735 r
.45981 .43103 m .46535 .43051 L p .46241 .43923 L F P
0 g
s
.738 .6 .703 r
.3255 .46087 m .33491 .46195 L .32915 .46875 L p F P
0 g
s
.737 .604 .709 r
.33176 .45392 m .3255 .46087 L .33491 .46195 L p F P
0 g
s
.737 .604 .709 r
.33433 .45422 m .33176 .45392 L p .33491 .46195 L F P
0 g
s
.734 .61 .719 r
.33352 .45207 m .33878 .44673 L .33119 .44593 L closepath p F P
0 g
s
.733 .617 .728 r
.33676 .43833 m .34341 .43905 L p .33878 .44673 L F P
0 g
s
.733 .617 .728 r
.33055 .44435 m .33676 .43833 L p .33878 .44673 L F P
0 g
s
.733 .617 .728 r
.33878 .44673 m .33119 .44593 L .33055 .44435 L p F P
0 g
s
.714 .619 .75 r
.37951 .42122 m .38691 .41569 L .37694 .41535 L closepath p F P
0 g
s
.715 .536 .646 r
.37936 .5062 m .37796 .50616 L .37683 .49981 L p F P
0 g
s
.721 .54 .645 r
.37164 .49957 m .37683 .49981 L .37796 .50616 L p F P
0 g
s
.688 .514 .646 r
.43307 .50333 m .43579 .4996 L .43246 .49976 L closepath p F P
0 g
s
.694 .518 .645 r
.43246 .49976 m .43307 .50333 L .43114 .5061 L p F P
0 g
s
.733 .621 .733 r
.34341 .43905 m .34133 .43409 L .33676 .43833 L closepath p F P
0 g
s
.675 .561 .719 r
.48398 .44641 m .48602 .45272 L .47355 .45422 L p F P
0 g
s
.675 .561 .719 r
.47355 .45422 m .47323 .45324 L .48398 .44641 L p F P
0 g
s
.673 .553 .711 r
.47355 .45422 m .48602 .45272 L p .47809 .46139 L F P
0 g
s
.673 .553 .711 r
.47809 .46139 m .47583 .46166 L .47355 .45422 L p F P
0 g
s
.738 .612 .718 r
.33433 .45422 m .33352 .45207 L .33176 .45392 L closepath p F P
0 g
s
.675 .562 .719 r
.48356 .44509 m .48398 .44641 L .47323 .45324 L p F P
0 g
s
.675 .562 .719 r
.47323 .45324 m .47105 .44656 L .48356 .44509 L p F P
0 g
s
.697 .606 .75 r
.42054 .41913 m .42602 .41552 L .41913 .41576 L closepath p F P
0 g
s
.7 .524 .646 r
.41696 .5065 m .4063 .50663 L .40574 .50336 L p F P
0 g
s
.706 .527 .645 r
.4063 .50663 m .40574 .50336 L .4037 .50662 L closepath p F P
0 g
s
.676 .569 .727 r
.48106 .43781 m .48356 .44509 L .47105 .44656 L p F P
0 g
s
.676 .569 .727 r
.47105 .44656 m .47031 .44443 L .48106 .43781 L p F P
0 g
s
.735 .571 .67 r
.34395 .48447 m .33832 .48392 L p .34386 .49122 L F P
0 g
s
.735 .571 .67 r
.34386 .49122 m .34515 .4893 L .34395 .48447 L p F P
0 g
s
.722 .624 .748 r
.36628 .42376 m .3658 .4227 L .36462 .42365 L closepath p F P
0 g
s
.699 .522 .644 r
.42004 .50645 m .41941 .50277 L .41696 .5065 L closepath p F P
0 g
s
.694 .518 .645 r
.43114 .5061 m .42004 .50645 L .41941 .50277 L p F P
0 g
s
.69 .598 .749 r
.44928 .42322 m .44787 .41973 L .44141 .42375 L closepath p F P
0 g
s
.691 .6 .75 r
.44572 .41446 m .44787 .41973 L .44141 .42375 L p F P
0 g
s
.691 .6 .75 r
.44135 .41474 m .44572 .41446 L p .44141 .42375 L F P
0 g
s
.691 .6 .75 r
.4342 .41923 m .44135 .41474 L p .44141 .42375 L F P
0 g
s
.687 .513 .646 r
.43579 .4996 m .4457 .49909 L p .44647 .50536 L F P
0 g
s
.687 .513 .646 r
.43307 .50333 m .43579 .4996 L p .44647 .50536 L F P
0 g
s
.73 .558 .659 r
.34567 .49138 m .35413 .49201 L .3502 .49826 L p F P
0 g
s
.73 .568 .672 r
.35413 .49201 m .34567 .49138 L .34515 .4893 L p F P
0 g
s
.728 .556 .658 r
.35413 .49201 m .3502 .49826 L .36065 .499 L p F P
0 g
s
.672 .545 .701 r
.47614 .46275 m .47809 .46139 L .47583 .46166 L closepath p F P
0 g
s
.677 .57 .727 r
.48086 .43722 m .48106 .43781 L .47031 .44443 L p F P
0 g
s
.677 .57 .727 r
.47031 .44443 m .46832 .43866 L .48086 .43722 L p F P
0 g
s
.722 .552 .66 r
.37164 .49957 m .36216 .4991 L .36176 .49724 L p F P
0 g
s
.721 .54 .645 r
.37796 .50616 m .36814 .5057 L .37164 .49957 L p F P
0 g
s
.722 .541 .646 r
.36216 .4991 m .37164 .49957 L .36814 .5057 L p F P
0 g
s
.738 .612 .718 r
.33176 .45392 m .33352 .45207 L .33119 .44593 L p F P
0 g
s
.671 .544 .701 r
.47614 .46275 m .47809 .46139 L p .48641 .46783 L F P
0 g
s
.671 .544 .701 r
.48641 .46783 m .47789 .46887 L .47614 .46275 L p F P
0 g
s
.724 .621 .742 r
.35208 .42467 m .35424 .42286 L .36462 .42365 L p F P
0 g
s
.723 .625 .749 r
.36281 .41598 m .35424 .42286 L .36462 .42365 L p F P
0 g
s
.723 .625 .749 r
.36462 .42365 m .3658 .4227 L .36281 .41598 L p F P
0 g
s
.684 .589 .743 r
.4508 .42715 m .45848 .42243 L p .45981 .43103 L F P
0 g
s
.685 .59 .743 r
.4508 .42715 m .45848 .42243 L .44928 .42322 L closepath p F P
0 g
s
.677 .523 .67 r
.46559 .48431 m .4688 .48402 L .47027 .49064 L p F P
0 g
s
.677 .523 .67 r
.47027 .49064 m .45783 .49174 L .46559 .48431 L p F P
0 g
s
.678 .533 .681 r
.4688 .48402 m .46829 .48194 L .46559 .48431 L closepath p F P
0 g
s
.719 .623 .749 r
.3754 .41526 m .3658 .4227 L .36281 .41598 L p F P
0 g
s
.738 .612 .718 r
.32921 .44569 m .32248 .45279 L .33176 .45392 L p F P
0 g
s
.738 .612 .718 r
.33119 .44593 m .32921 .44569 L p .33176 .45392 L F P
0 g
s
.739 .608 .712 r
.32248 .45279 m .33176 .45392 L .3255 .46087 L p F P
0 g
s
.674 .531 .682 r
.4688 .48402 m .46829 .48194 L .47495 .47639 L p F P
0 g
s
.703 .616 .757 r
.41203 .41588 m .4054 .41596 L .4039 .41257 L p F P
0 g
s
.707 .618 .755 r
.4054 .41596 m .4039 .41257 L .39906 .41591 L closepath p F P
0 g
s
.708 .62 .757 r
.40127 .40664 m .4039 .41257 L .39906 .41591 L p F P
0 g
s
.708 .62 .757 r
.39984 .40662 m .40127 .40664 L p .39906 .41591 L F P
0 g
s
.708 .62 .757 r
.39022 .41332 m .39984 .40662 L p .39906 .41591 L F P
0 g
s
.708 .62 .757 r
.39906 .41591 m .39134 .41582 L .39022 .41332 L p F P
0 g
s
.727 .556 .658 r
.36216 .4991 m .36176 .49724 L .36065 .499 L closepath p F P
0 g
s
.678 .577 .735 r
.47814 .42969 m .48086 .43722 L .46832 .43866 L p F P
0 g
s
.678 .577 .735 r
.46832 .43866 m .46739 .43612 L .47814 .42969 L p F P
0 g
s
.677 .514 .658 r
.45753 .49207 m .45783 .49174 L .45747 .49177 L closepath p F P
0 g
s
.683 .519 .658 r
.45747 .49177 m .45753 .49207 L .45167 .49869 L p F P
0 g
s
.702 .614 .756 r
.41913 .41576 m .41758 .4122 L .41203 .41588 L closepath p F P
0 g
s
.703 .616 .757 r
.4151 .40653 m .41758 .4122 L .41203 .41588 L p F P
0 g
s
.703 .616 .757 r
.41291 .40656 m .4151 .40653 L p .41203 .41588 L F P
0 g
s
.703 .616 .757 r
.4039 .41257 m .41291 .40656 L p .41203 .41588 L F P
0 g
s
.671 .544 .701 r
.47809 .46139 m .48828 .46013 L p .48641 .46783 L F P
0 g
s
.672 .551 .71 r
.48828 .46013 m .4869 .45559 L .47809 .46139 L closepath p F P
0 g
s
.673 .553 .711 r
.48602 .45272 m .4869 .45559 L .47809 .46139 L p F P
0 g
s
.683 .587 .741 r
.46535 .43051 m .46447 .4282 L .45981 .43103 L closepath p F P
0 g
s
.684 .589 .743 r
.46213 .4221 m .46447 .4282 L .45981 .43103 L p F P
0 g
s
.684 .589 .743 r
.45848 .42243 m .46213 .4221 L p .45981 .43103 L F P
0 g
s
.676 .513 .658 r
.45783 .49174 m .47027 .49064 L p .46926 .49727 L F P
0 g
s
.676 .513 .658 r
.45753 .49207 m .45783 .49174 L p .46926 .49727 L F P
0 g
s
.712 .622 .755 r
.39134 .41582 m .39022 .41332 L .38691 .41569 L closepath p F P
0 g
s
.676 .513 .658 r
.46926 .49727 m .45872 .49818 L .45753 .49207 L p F P
0 g
s
.681 .517 .657 r
.45872 .49818 m .45753 .49207 L .45167 .49869 L closepath p F P
0 g
s
.692 .601 .75 r
.4342 .41923 m .44135 .41474 L .43256 .41525 L closepath p F P
0 g
s
.707 .53 .646 r
.4037 .50662 m .39229 .50654 L .39203 .5051 L p F P
0 g
s
.712 .533 .645 r
.39229 .50654 m .39203 .5051 L .39118 .50652 L closepath p F P
0 g
s
.697 .612 .757 r
.42602 .41552 m .41913 .41576 L .41758 .4122 L p F P
0 g
s
.67 .536 .692 r
.47905 .47322 m .48641 .46783 L .47789 .46887 L closepath p F P
0 g
s
.676 .539 .691 r
.47789 .46887 m .47905 .47322 L .47495 .47639 L p F P
0 g
s
.736 .58 .68 r
.33342 .47644 m .32859 .48296 L .33832 .48392 L p F P
0 g
s
.738 .584 .683 r
.32634 .47569 m .33342 .47644 L .32859 .48296 L p F P
0 g
s
.738 .592 .693 r
.32558 .47324 m .32915 .46875 L p .33342 .47644 L F P
0 g
s
.738 .592 .693 r
.33342 .47644 m .32634 .47569 L .32558 .47324 L p F P
0 g
s
.678 .578 .735 r
.47793 .4291 m .47814 .42969 L .46739 .43612 L p F P
0 g
s
.678 .578 .735 r
.46739 .43612 m .46535 .43051 L .47793 .4291 L p F P
0 g
s
.672 .52 .671 r
.4688 .48402 m .48142 .48269 L p .47651 .48998 L F P
0 g
s
.672 .52 .671 r
.47651 .48998 m .47027 .49064 L .4688 .48402 L p F P
0 g
s
.674 .531 .682 r
.47976 .47588 m .48142 .48269 L .4688 .48402 L p F P
0 g
s
.674 .531 .682 r
.47495 .47639 m .47976 .47588 L p .4688 .48402 L F P
0 g
s
.735 .571 .67 r
.34567 .49138 m .34515 .4893 L .34386 .49122 L closepath p F P
0 g
s
.713 .624 .757 r
.38723 .40669 m .39022 .41332 L .38691 .41569 L p F P
0 g
s
.713 .624 .757 r
.37652 .41443 m .38723 .40669 L p .38691 .41569 L F P
0 g
s
.713 .624 .757 r
.38691 .41569 m .37694 .41535 L .37652 .41443 L p F P
0 g
s
.674 .538 .691 r
.47976 .47588 m .47905 .47322 L .47495 .47639 L closepath p F P
0 g
s
.685 .596 .75 r
.45848 .42243 m .44928 .42322 L .44787 .41973 L p F P
0 g
s
.739 .593 .693 r
.32558 .47324 m .32915 .46875 L .324 .46818 L closepath p F P
0 g
s
.738 .6 .703 r
.32266 .46423 m .3255 .46087 L p .32915 .46875 L F P
0 g
s
.738 .6 .703 r
.32915 .46875 m .324 .46818 L .32266 .46423 L p F P
0 g
s
.735 .571 .67 r
.33832 .48392 m .33405 .49028 L .34386 .49122 L p F P
0 g
s
.737 .574 .671 r
.32859 .48296 m .33832 .48392 L .33405 .49028 L p F P
0 g
s
.722 .541 .646 r
.36814 .5057 m .3633 .50546 L .36216 .4991 L p F P
0 g
s
.727 .545 .645 r
.36065 .499 m .36216 .4991 L .3633 .50546 L p F P
0 g
s
.681 .509 .646 r
.44672 .50501 m .45167 .49869 L .4457 .49909 L closepath p F P
0 g
s
.687 .513 .646 r
.4457 .49909 m .44672 .50501 L .44647 .50536 L p F P
0 g
s
.73 .62 .735 r
.34133 .43409 m .34505 .43074 L .33971 .43023 L closepath p F P
0 g
s
.734 .624 .736 r
.33971 .43023 m .34133 .43409 L .33676 .43833 L p F P
0 g
s
.738 .619 .726 r
.33119 .44593 m .33055 .44435 L .32921 .44569 L closepath p F P
0 g
s
.735 .618 .728 r
.33055 .44435 m .33676 .43833 L .32771 .43733 L closepath p F P
0 g
s
.734 .624 .736 r
.33538 .42973 m .33971 .43023 L p .33676 .43833 L F P
0 g
s
.734 .624 .736 r
.32756 .43698 m .33538 .42973 L p .33676 .43833 L F P
0 g
s
.734 .624 .736 r
.33676 .43833 m .32771 .43733 L .32756 .43698 L p F P
0 g
s
.729 .626 .743 r
.35119 .42262 m .35208 .42467 L .34505 .43074 L p F P
0 g
s
.729 .626 .743 r
.34431 .42193 m .35119 .42262 L p .34505 .43074 L F P
0 g
s
.729 .626 .743 r
.33833 .4271 m .34431 .42193 L p .34505 .43074 L F P
0 g
s
.729 .626 .743 r
.34505 .43074 m .33971 .43023 L .33833 .4271 L p F P
0 g
s
.699 .511 .631 r
.4063 .50663 m .41696 .5065 L .4136 .5126 L p F P
0 g
s
.699 .511 .631 r
.4136 .5126 m .40715 .51268 L .4063 .50663 L p F P
0 g
s
.704 .515 .63 r
.4037 .50662 m .4063 .50663 L .40715 .51268 L p F P
0 g
s
.704 .515 .63 r
.40715 .51268 m .40054 .51266 L .4037 .50662 L p F P
0 g
s
.706 .517 .631 r
.39229 .50654 m .4037 .50662 L .40054 .51266 L p F P
0 g
s
.696 .61 .756 r
.43256 .41525 m .43125 .4122 L .42602 .41552 L closepath p F P
0 g
s
.697 .612 .757 r
.42862 .40611 m .43125 .4122 L .42602 .41552 L p F P
0 g
s
.697 .612 .757 r
.42702 .40617 m .42862 .40611 L p .42602 .41552 L F P
0 g
s
.697 .612 .757 r
.41758 .4122 m .42702 .40617 L p .42602 .41552 L F P
0 g
s
.727 .545 .645 r
.3633 .50546 m .35736 .50507 L .36065 .499 L p F P
0 g
s
.728 .547 .647 r
.3502 .49826 m .36065 .499 L .35736 .50507 L p F P
0 g
s
.687 .513 .646 r
.44647 .50536 m .43353 .50601 L .43307 .50333 L p F P
0 g
s
.692 .516 .645 r
.43353 .50601 m .43307 .50333 L .43114 .5061 L closepath p F P
0 g
s
.73 .558 .659 r
.3502 .49826 m .34711 .49804 L .34567 .49138 L p F P
0 g
s
.735 .562 .658 r
.34386 .49122 m .34567 .49138 L .34711 .49804 L p F P
0 g
s
.706 .517 .631 r
.40054 .51266 m .39314 .51261 L .39229 .50654 L p F P
0 g
s
.711 .521 .63 r
.39118 .50652 m .39229 .50654 L .39314 .51261 L p F P
0 g
s
.711 .521 .63 r
.39314 .51261 m .38821 .5125 L .39118 .50652 L p F P
0 g
s
.713 .523 .631 r
.37936 .5062 m .39118 .50652 L .38821 .5125 L p F P
0 g
s
.697 .51 .63 r
.41696 .5065 m .42004 .50645 L .42088 .51249 L p F P
0 g
s
.697 .51 .63 r
.42088 .51249 m .4136 .5126 L .41696 .5065 L p F P
0 g
s
.738 .619 .726 r
.32921 .44569 m .33055 .44435 L .32771 .43733 L p F P
0 g
s
.67 .536 .692 r
.47976 .47588 m .47905 .47322 L .48641 .46783 L p F P
0 g
s
.725 .622 .743 r
.35208 .42467 m .35424 .42286 L .35119 .42262 L closepath p F P
0 g
s
.692 .506 .631 r
.42004 .50645 m .43114 .5061 L .42755 .51228 L p F P
0 g
s
.692 .506 .631 r
.42755 .51228 m .42088 .51249 L .42004 .50645 L p F P
0 g
s
.717 .626 .755 r
.37694 .41535 m .37652 .41443 L .3754 .41526 L closepath p F P
0 g
s
.709 .621 .757 r
.39984 .40662 m .39022 .41332 L .38723 .40669 L p F P
0 g
s
.704 .617 .757 r
.4039 .41257 m .41291 .40656 L .40127 .40664 L closepath p F P
0 g
s
.679 .585 .743 r
.47522 .42196 m .47793 .4291 L .46535 .43051 L p F P
0 g
s
.679 .585 .743 r
.46535 .43051 m .46447 .4282 L .47522 .42196 L p F P
0 g
s
.74 .616 .721 r
.32007 .44452 m .32921 .44569 L .32248 .45279 L p F P
0 g
s
.738 .619 .726 r
.32726 .43727 m .32007 .44452 L .32921 .44569 L p F P
0 g
s
.738 .619 .726 r
.32771 .43733 m .32726 .43727 L p .32921 .44569 L F P
0 g
s
.74 .601 .702 r
.32266 .46423 m .3255 .46087 L .32135 .46038 L closepath p F P
0 g
s
.739 .608 .712 r
.31971 .45588 m .32248 .45279 L p .3255 .46087 L F P
0 g
s
.739 .608 .712 r
.3255 .46087 m .32135 .46038 L .31971 .45588 L p F P
0 g
s
.735 .562 .658 r
.34711 .49804 m .34015 .4974 L .34386 .49122 L p F P
0 g
s
.736 .564 .66 r
.33405 .49028 m .34386 .49122 L .34015 .4974 L p F P
0 g
s
.724 .628 .751 r
.36214 .41447 m .36281 .41598 L .35424 .42286 L p F P
0 g
s
.724 .628 .751 r
.35423 .41381 m .36214 .41447 L p .35424 .42286 L F P
0 g
s
.724 .628 .751 r
.34908 .41797 m .35423 .41381 L p .35424 .42286 L F P
0 g
s
.724 .628 .751 r
.35424 .42286 m .35119 .42262 L .34908 .41797 L p F P
0 g
s
.719 .623 .749 r
.36281 .41598 m .36455 .41462 L .3754 .41526 L p F P
0 g
s
.718 .628 .756 r
.37353 .40791 m .36455 .41462 L .3754 .41526 L p F P
0 g
s
.718 .628 .756 r
.3754 .41526 m .37652 .41443 L .37353 .40791 L p F P
0 g
s
.692 .608 .757 r
.44135 .41474 m .43256 .41525 L .43125 .4122 L p F P
0 g
s
.681 .508 .646 r
.45167 .49869 m .45872 .49818 L p .44678 .50534 L F P
0 g
s
.681 .508 .646 r
.44678 .50534 m .44672 .50501 L .45167 .49869 L p F P
0 g
s
.685 .596 .75 r
.44787 .41973 m .45844 .41341 L p .45848 .42243 L F P
0 g
s
.686 .597 .75 r
.44787 .41973 m .45844 .41341 L .44572 .41446 L closepath p F P
0 g
s
.715 .626 .757 r
.38723 .40669 m .37652 .41443 L .37353 .40791 L p F P
0 g
s
.668 .526 .682 r
.47976 .47588 m .49219 .47434 L p .48543 .4822 L F P
0 g
s
.668 .526 .682 r
.48543 .4822 m .48142 .48269 L .47976 .47588 L p F P
0 g
s
.67 .536 .692 r
.49034 .46734 m .49219 .47434 L .47976 .47588 L p F P
0 g
s
.67 .536 .692 r
.48641 .46783 m .49034 .46734 L p .47976 .47588 L F P
0 g
s
.698 .613 .757 r
.41758 .4122 m .42702 .40617 L .4151 .40653 L closepath p F P
0 g
s
.679 .585 .743 r
.47474 .42071 m .47522 .42196 L .46447 .4282 L p F P
0 g
s
.679 .585 .743 r
.46447 .4282 m .46213 .4221 L .47474 .42071 L p F P
0 g
s
.713 .523 .631 r
.37828 .50837 m .37936 .5062 L p .38821 .5125 L F P
0 g
s
.714 .524 .631 r
.37828 .50837 m .37936 .5062 L .37796 .50616 L closepath p F P
0 g
s
.719 .527 .63 r
.37796 .50616 m .36814 .5057 L p .37647 .51216 L F P
0 g
s
.719 .527 .63 r
.37647 .51216 m .37828 .50837 L .37796 .50616 L p F P
0 g
s
.734 .628 .741 r
.33971 .43023 m .33833 .4271 L .33538 .42973 L closepath p F P
0 g
s
.743 .595 .691 r
.324 .46818 m .31986 .46764 L p .32392 .47539 L F P
0 g
s
.743 .595 .691 r
.32392 .47539 m .32558 .47324 L .324 .46818 L p F P
0 g
s
.744 .603 .701 r
.324 .46818 m .32266 .46423 L .31986 .46764 L closepath p F P
0 g
s
.729 .63 .749 r
.35119 .42262 m .34908 .41797 L .34431 .42193 L closepath p F P
0 g
s
.69 .504 .63 r
.43114 .5061 m .43353 .50601 L .43436 .51204 L p F P
0 g
s
.69 .504 .63 r
.43436 .51204 m .42755 .51228 L .43114 .5061 L p F P
0 g
s
.743 .595 .691 r
.32634 .47569 m .32558 .47324 L .32392 .47539 L closepath p F P
0 g
s
.738 .584 .683 r
.32859 .48296 m .32841 .48294 L .32634 .47569 L p F P
0 g
s
.744 .587 .681 r
.32392 .47539 m .32634 .47569 L .32841 .48294 L p F P
0 g
s
.744 .603 .701 r
.31986 .46764 m .32266 .46423 L .32135 .46038 L p F P
0 g
s
.685 .5 .63 r
.43353 .50601 m .44647 .50536 L .44262 .51162 L p F P
0 g
s
.685 .5 .63 r
.44262 .51162 m .43436 .51204 L .43353 .50601 L p F P
0 g
s
.684 .594 .749 r
.46213 .4221 m .46154 .42062 L .45848 .42243 L closepath p F P
0 g
s
.685 .596 .75 r
.45863 .4134 m .46154 .42062 L .45848 .42243 L p F P
0 g
s
.685 .596 .75 r
.45844 .41341 m .45863 .4134 L p .45848 .42243 L F P
0 g
s
.74 .616 .721 r
.31674 .44804 m .32007 .44452 L p .32248 .45279 L F P
0 g
s
.74 .616 .721 r
.32248 .45279 m .3184 .45228 L .31674 .44804 L p F P
0 g
s
.741 .609 .711 r
.31971 .45588 m .32248 .45279 L .3184 .45228 L closepath p F P
0 g
s
.744 .603 .701 r
.32135 .46038 m .31638 .4597 L p .31986 .46764 L F P
0 g
s
.744 .61 .71 r
.32135 .46038 m .31971 .45588 L .31638 .4597 L closepath p F P
0 g
s
.669 .557 .719 r
.49307 .45175 m .48602 .45272 L .48398 .44641 L p F P
0 g
s
.668 .549 .711 r
.4869 .45559 m .49307 .45175 L .48602 .45272 L closepath p F P
0 g
s
.72 .625 .751 r
.36281 .41598 m .36455 .41462 L .36214 .41447 L closepath p F P
0 g
s
.692 .608 .757 r
.43125 .4122 m .44198 .40565 L p .44135 .41474 L F P
0 g
s
.693 .608 .757 r
.44186 .40538 m .44198 .40565 L .43125 .4122 L p F P
0 g
s
.693 .608 .757 r
.43125 .4122 m .42862 .40611 L .44186 .40538 L p F P
0 g
s
.73 .549 .647 r
.34792 .50242 m .3502 .49826 L .34711 .49804 L closepath p F P
0 g
s
.728 .547 .647 r
.34792 .50242 m .3502 .49826 L p .35736 .50507 L F P
0 g
s
.692 .608 .757 r
.44198 .40565 m .44492 .41258 L .44135 .41474 L p F P
0 g
s
.691 .605 .756 r
.44572 .41446 m .44492 .41258 L .44135 .41474 L closepath p F P
0 g
s
.669 .557 .719 r
.48398 .44641 m .48694 .44463 L p .49307 .45175 L F P
0 g
s
.67 .558 .72 r
.48398 .44641 m .48694 .44463 L .48356 .44509 L closepath p F P
0 g
s
.671 .565 .728 r
.48694 .44463 m .48356 .44509 L .48106 .43781 L p F P
0 g
s
.67 .51 .659 r
.47118 .49525 m .47651 .48998 L .47027 .49064 L closepath p F P
0 g
s
.676 .513 .658 r
.47027 .49064 m .47118 .49525 L .46926 .49727 L p F P
0 g
s
.668 .549 .711 r
.48828 .46013 m .4869 .45559 L .49307 .45175 L p F P
0 g
s
.67 .543 .701 r
.49034 .46734 m .48982 .4655 L .48641 .46783 L closepath p F P
0 g
s
.671 .544 .701 r
.48828 .46013 m .48982 .4655 L .48641 .46783 L p F P
0 g
s
.674 .503 .646 r
.45872 .49818 m .46926 .49727 L .46357 .50408 L p F P
0 g
s
.674 .503 .646 r
.46357 .50408 m .45978 .50441 L .45872 .49818 L p F P
0 g
s
.681 .508 .646 r
.45872 .49818 m .45978 .50441 L .44678 .50534 L p F P
0 g
s
.744 .587 .681 r
.32841 .48294 m .31937 .48183 L .32392 .47539 L p F P
0 g
s
.744 .59 .684 r
.31481 .47422 m .32392 .47539 L .31937 .48183 L p F P
0 g
s
.743 .595 .691 r
.31986 .46764 m .31481 .47422 L .32392 .47539 L p F P
0 g
s
.719 .63 .758 r
.37254 .40578 m .37353 .40791 L .36455 .41462 L p F P
0 g
s
.719 .63 .758 r
.36538 .40531 m .37254 .40578 L p .36455 .41462 L F P
0 g
s
.719 .63 .758 r
.3598 .40949 m .36538 .40531 L p .36455 .41462 L F P
0 g
s
.719 .63 .758 r
.36455 .41462 m .36214 .41447 L .3598 .40949 L p F P
0 g
s
.737 .574 .671 r
.32846 .48315 m .32859 .48296 L p .33405 .49028 L F P
0 g
s
.739 .575 .671 r
.32846 .48315 m .32859 .48296 L .32841 .48294 L closepath p F P
0 g
s
.743 .578 .67 r
.32841 .48294 m .31937 .48183 L p .32455 .48924 L F P
0 g
s
.743 .578 .67 r
.32455 .48924 m .32846 .48315 L .32841 .48294 L p F P
0 g
s
.719 .527 .63 r
.36814 .5057 m .36527 .51166 L .37647 .51216 L p F P
0 g
s
.721 .531 .632 r
.3633 .50546 m .36814 .5057 L .36527 .51166 L p F P
0 g
s
.737 .574 .671 r
.33405 .49028 m .33017 .48989 L .32846 .48315 L p F P
0 g
s
.743 .577 .67 r
.33017 .48989 m .32846 .48315 L .32455 .48924 L closepath p F P
0 g
s
.666 .541 .702 r
.48982 .4655 m .48828 .46013 L .50056 .45841 L p F P
0 g
s
.668 .549 .711 r
.49831 .451 m .50056 .45841 L .48828 .46013 L p F P
0 g
s
.668 .549 .711 r
.49307 .45175 m .49831 .451 L p .48828 .46013 L F P
0 g
s
.738 .626 .734 r
.32771 .43733 m .32756 .43698 L .32726 .43727 L closepath p F P
0 g
s
.736 .624 .735 r
.33538 .42973 m .32756 .43698 L .32455 .42999 L p F P
0 g
s
.736 .624 .735 r
.32455 .42999 m .32602 .42862 L .33538 .42973 L p F P
0 g
s
.734 .628 .741 r
.33462 .42092 m .32602 .42862 L .33538 .42973 L p F P
0 g
s
.734 .628 .741 r
.33566 .42105 m .33462 .42092 L p .33538 .42973 L F P
0 g
s
.734 .628 .741 r
.33538 .42973 m .33833 .4271 L .33566 .42105 L p F P
0 g
s
.744 .611 .71 r
.31638 .4597 m .31971 .45588 L .3184 .45228 L p F P
0 g
s
.734 .552 .646 r
.34711 .49804 m .34015 .4974 L p .34691 .50433 L F P
0 g
s
.734 .552 .646 r
.34691 .50433 m .34792 .50242 L .34711 .49804 L p F P
0 g
s
.73 .627 .743 r
.33833 .4271 m .34431 .42193 L .33566 .42105 L closepath p F P
0 g
s
.68 .592 .75 r
.47229 .41456 m .47474 .42071 L .46213 .4221 L p F P
0 g
s
.68 .592 .75 r
.46213 .4221 m .46154 .42062 L .47229 .41456 L p F P
0 g
s
.739 .627 .734 r
.32726 .43727 m .32756 .43698 L .32455 .42999 L p F P
0 g
s
.713 .523 .631 r
.38821 .5125 m .37883 .51226 L .37828 .50837 L p F P
0 g
s
.718 .527 .63 r
.37883 .51226 m .37828 .50837 L .37647 .51216 L closepath p F P
0 g
s
.74 .623 .729 r
.31827 .43604 m .32726 .43727 L .32007 .44452 L p F P
0 g
s
.739 .627 .734 r
.32455 .42999 m .31827 .43604 L .32726 .43727 L p F P
0 g
s
.745 .598 .694 r
.31085 .46643 m .31986 .46764 L .31481 .47422 L p F P
0 g
s
.744 .603 .701 r
.31638 .4597 m .31085 .46643 L .31986 .46764 L p F P
0 g
s
.724 .633 .756 r
.36214 .41447 m .3598 .40949 L .35423 .41381 L closepath p F P
0 g
s
.671 .565 .728 r
.48106 .43781 m .48244 .43701 L p .48694 .44463 L F P
0 g
s
.671 .566 .728 r
.48106 .43781 m .48244 .43701 L .48086 .43722 L closepath p F P
0 g
s
.686 .603 .757 r
.45844 .41341 m .44572 .41446 L .44492 .41258 L p F P
0 g
s
.672 .573 .736 r
.48244 .43701 m .48086 .43722 L .47814 .42969 L p F P
0 g
s
.666 .516 .671 r
.48196 .48512 m .48543 .4822 L .48142 .48269 L closepath p F P
0 g
s
.672 .52 .671 r
.48142 .48269 m .48196 .48512 L .47651 .48998 L p F P
0 g
s
.729 .632 .751 r
.3469 .41318 m .34908 .41797 L .34431 .42193 L p F P
0 g
s
.729 .632 .751 r
.34424 .4129 m .3469 .41318 L p .34431 .42193 L F P
0 g
s
.729 .632 .751 r
.33532 .42032 m .34424 .4129 L p .34431 .42193 L F P
0 g
s
.729 .632 .751 r
.34431 .42193 m .33566 .42105 L .33532 .42032 L p F P
0 g
s
.736 .564 .66 r
.33128 .49485 m .33405 .49028 L p .34015 .4974 L F P
0 g
s
.738 .566 .66 r
.33128 .49485 m .33405 .49028 L .33017 .48989 L closepath p F P
0 g
s
.721 .531 .632 r
.36527 .51166 m .3642 .5116 L .3633 .50546 L p F P
0 g
s
.727 .535 .631 r
.35736 .50507 m .3633 .50546 L .3642 .5116 L p F P
0 g
s
.68 .592 .75 r
.47128 .41203 m .47229 .41456 L .46154 .42062 L p F P
0 g
s
.68 .592 .75 r
.46154 .42062 m .45863 .4134 L .47128 .41203 L p F P
0 g
s
.745 .618 .718 r
.3184 .45228 m .31674 .44804 L .31348 .45158 L closepath p F P
0 g
s
.744 .611 .71 r
.3184 .45228 m .31348 .45158 L p .31638 .4597 L F P
0 g
s
.666 .54 .702 r
.49034 .46734 m .48982 .4655 L .50059 .45852 L p F P
0 g
s
.666 .541 .702 r
.50056 .45841 m .50059 .45852 L .48982 .4655 L p F P
0 g
s
.685 .511 .645 r
.44678 .50534 m .44672 .50501 L .44647 .50536 L closepath p F P
0 g
s
.669 .557 .719 r
.48694 .44463 m .49585 .44337 L p .49307 .45175 L F P
0 g
s
.669 .564 .727 r
.49585 .44337 m .49475 .44014 L .48694 .44463 L closepath p F P
0 g
s
.671 .565 .728 r
.49318 .43552 m .49475 .44014 L .48694 .44463 L p F P
0 g
s
.671 .565 .728 r
.48244 .43701 m .49318 .43552 L p .48694 .44463 L F P
0 g
s
.703 .623 .764 r
.41291 .40656 m .40127 .40664 L .40093 .4059 L p F P
0 g
s
.707 .625 .762 r
.40127 .40664 m .40093 .4059 L .39984 .40662 L closepath p F P
0 g
s
.671 .572 .735 r
.49318 .43552 m .49183 .43177 L .48244 .43701 L closepath p F P
0 g
s
.672 .573 .736 r
.49027 .42743 m .49183 .43177 L .48244 .43701 L p F P
0 g
s
.672 .573 .736 r
.47956 .42889 m .49027 .42743 L p .48244 .43701 L F P
0 g
s
.672 .573 .736 r
.47814 .42969 m .47956 .42889 L p .48244 .43701 L F P
0 g
s
.709 .621 .757 r
.38723 .40669 m .38763 .40642 L .39984 .40662 L p F P
0 g
s
.708 .626 .764 r
.39794 .39949 m .38763 .40642 L .39984 .40662 L p F P
0 g
s
.708 .626 .764 r
.39984 .40662 m .40093 .4059 L .39794 .39949 L p F P
0 g
s
.683 .498 .629 r
.44647 .50536 m .44678 .50534 L .4476 .51135 L p F P
0 g
s
.683 .498 .629 r
.4476 .51135 m .44262 .51162 L .44647 .50536 L p F P
0 g
s
.678 .494 .63 r
.44678 .50534 m .45978 .50441 L p .45909 .51054 L F P
0 g
s
.678 .494 .63 r
.45909 .51054 m .4476 .51135 L .44678 .50534 L p F P
0 g
s
.664 .531 .693 r
.49034 .46734 m .50259 .46559 L p .49667 .4737 L F P
0 g
s
.664 .531 .693 r
.49667 .4737 m .49219 .47434 L .49034 .46734 L p F P
0 g
s
.666 .54 .702 r
.50059 .45852 m .50259 .46559 L .49034 .46734 L p F P
0 g
s
.687 .603 .756 r
.45566 .40635 m .44492 .41258 L .44198 .40565 L p F P
0 g
s
.686 .603 .757 r
.44492 .41258 m .45566 .40635 L p .45844 .41341 L F P
0 g
s
.702 .621 .763 r
.4151 .40653 m .41461 .40546 L .41291 .40656 L closepath p F P
0 g
s
.703 .623 .764 r
.41164 .39898 m .41461 .40546 L .41291 .40656 L p F P
0 g
s
.703 .623 .764 r
.40093 .4059 m .41164 .39898 L p .41291 .40656 L F P
0 g
s
.741 .617 .72 r
.31674 .44804 m .32007 .44452 L .3151 .44386 L closepath p F P
0 g
s
.74 .623 .729 r
.31374 .44059 m .31827 .43604 L p .32007 .44452 L F P
0 g
s
.74 .623 .729 r
.32007 .44452 m .3151 .44386 L .31374 .44059 L p F P
0 g
s
.746 .607 .703 r
.30748 .45845 m .31638 .4597 L .31085 .46643 L p F P
0 g
s
.744 .611 .71 r
.31348 .45158 m .30748 .45845 L .31638 .4597 L p F P
0 g
s
.698 .619 .764 r
.42702 .40617 m .4151 .40653 L .41461 .40546 L p F P
0 g
s
.725 .629 .75 r
.34908 .41797 m .35423 .41381 L .3469 .41318 L closepath p F P
0 g
s
.704 .624 .764 r
.41164 .39898 m .40093 .4059 L .39794 .39949 L p F P
0 g
s
.715 .626 .757 r
.3871 .40641 m .38723 .40669 L p .37353 .40791 L F P
0 g
s
.71 .623 .758 r
.38723 .40669 m .38763 .40642 L .3871 .40641 L closepath p F P
0 g
s
.67 .51 .659 r
.47651 .48998 m .48288 .48929 L p .47154 .49706 L F P
0 g
s
.67 .51 .659 r
.47154 .49706 m .47118 .49525 L .47651 .48998 L p F P
0 g
s
.67 .518 .67 r
.48288 .48929 m .48196 .48512 L .47651 .48998 L closepath p F P
0 g
s
.709 .629 .765 r
.39672 .39689 m .39794 .39949 L .38763 .40642 L p F P
0 g
s
.709 .629 .765 r
.38963 .39672 m .39672 .39689 L p .38763 .40642 L F P
0 g
s
.709 .629 .765 r
.38424 .40036 m .38963 .39672 L p .38763 .40642 L F P
0 g
s
.709 .629 .765 r
.38763 .40642 m .3871 .40641 L .38424 .40036 L p F P
0 g
s
.715 .626 .757 r
.37353 .40791 m .37623 .40595 L .3871 .40641 L p F P
0 g
s
.714 .631 .764 r
.3871 .40641 m .38424 .40036 L .37623 .40595 L closepath p F P
0 g
s
.666 .515 .671 r
.48288 .48929 m .48196 .48512 L .48543 .4822 L p F P
0 g
s
.673 .574 .736 r
.47814 .42969 m .47956 .42889 L .47793 .4291 L closepath p F P
0 g
s
.697 .498 .615 r
.40715 .51268 m .4136 .5126 L .41105 .51848 L p F P
0 g
s
.697 .498 .615 r
.41105 .51848 m .40776 .51852 L .40715 .51268 L p F P
0 g
s
.703 .502 .614 r
.40054 .51266 m .40715 .51268 L .40776 .51852 L p F P
0 g
s
.742 .568 .659 r
.33017 .48989 m .32455 .48924 L p .33033 .49647 L F P
0 g
s
.742 .568 .659 r
.33033 .49647 m .33128 .49485 L .33017 .48989 L p F P
0 g
s
.727 .535 .631 r
.3642 .5116 m .35464 .51097 L .35736 .50507 L p F P
0 g
s
.728 .536 .631 r
.3483 .50445 m .35736 .50507 L .35464 .51097 L p F P
0 g
s
.728 .547 .647 r
.35736 .50507 m .3483 .50445 L .34792 .50242 L p F P
0 g
s
.703 .502 .614 r
.40776 .51852 m .39814 .51849 L .40054 .51266 L p F P
0 g
s
.704 .504 .615 r
.39314 .51261 m .40054 .51266 L .39814 .51849 L p F P
0 g
s
.674 .581 .744 r
.47956 .42889 m .47793 .4291 L .47522 .42196 L p F P
0 g
s
.698 .619 .764 r
.41461 .40546 m .42533 .39883 L p .42702 .40617 L F P
0 g
s
.699 .619 .764 r
.42533 .39883 m .41461 .40546 L .41164 .39898 L p F P
0 g
s
.745 .618 .718 r
.31348 .45158 m .31674 .44804 L .3151 .44386 L p F P
0 g
s
.704 .504 .615 r
.39814 .51849 m .39375 .51846 L .39314 .51261 L p F P
0 g
s
.71 .508 .614 r
.38821 .5125 m .39314 .51261 L .39375 .51846 L p F P
0 g
s
.696 .496 .614 r
.4136 .5126 m .42088 .51249 L .42149 .51831 L p F P
0 g
s
.696 .496 .614 r
.42149 .51831 m .41105 .51848 L .4136 .5126 L p F P
0 g
s
.736 .564 .66 r
.34015 .4974 m .33167 .49661 L .33128 .49485 L p F P
0 g
s
.734 .552 .646 r
.34015 .4974 m .33696 .50344 L .34691 .50433 L p F P
0 g
s
.736 .554 .646 r
.33167 .49661 m .34015 .4974 L .33696 .50344 L p F P
0 g
s
.666 .515 .671 r
.48543 .4822 m .49384 .48113 L p .48288 .48929 L F P
0 g
s
.666 .524 .681 r
.49384 .48113 m .49273 .47657 L .48543 .4822 L closepath p F P
0 g
s
.668 .526 .682 r
.49219 .47434 m .49273 .47657 L .48543 .4822 L p F P
0 g
s
.674 .513 .658 r
.47154 .49706 m .47118 .49525 L .46926 .49727 L closepath p F P
0 g
s
.715 .627 .758 r
.37353 .40791 m .37623 .40595 L .37254 .40578 L closepath p F P
0 g
s
.724 .635 .758 r
.35759 .40476 m .3598 .40949 L .35423 .41381 L p F P
0 g
s
.724 .635 .758 r
.35494 .40453 m .35759 .40476 L p .35423 .41381 L F P
0 g
s
.724 .635 .758 r
.34606 .41143 m .35494 .40453 L p .35423 .41381 L F P
0 g
s
.724 .635 .758 r
.35423 .41381 m .3469 .41318 L .34606 .41143 L p F P
0 g
s
.668 .556 .719 r
.49831 .451 m .49767 .44902 L .49307 .45175 L closepath p F P
0 g
s
.669 .557 .719 r
.49585 .44337 m .49767 .44902 L .49307 .45175 L p F P
0 g
s
.697 .616 .763 r
.42862 .40611 m .42829 .40538 L .42702 .40617 L closepath p F P
0 g
s
.698 .619 .764 r
.42533 .39883 m .42829 .40538 L .42702 .40617 L p F P
0 g
s
.71 .508 .614 r
.39375 .51846 m .38595 .51828 L .38821 .5125 L p F P
0 g
s
.711 .51 .614 r
.37883 .51226 m .38821 .5125 L .38595 .51828 L p F P
0 g
s
.69 .492 .615 r
.42088 .51249 m .42755 .51228 L .42483 .51821 L p F P
0 g
s
.69 .492 .615 r
.42483 .51821 m .42149 .51831 L .42088 .51249 L p F P
0 g
s
.693 .614 .764 r
.43902 .39903 m .44186 .40538 L .42862 .40611 L p F P
0 g
s
.693 .614 .764 r
.42862 .40611 m .42829 .40538 L .43902 .39903 L p F P
0 g
s
.672 .5 .644 r
.46926 .49727 m .47154 .49706 L .47258 .50326 L p F P
0 g
s
.672 .5 .644 r
.47258 .50326 m .46357 .50408 L .46926 .49727 L p F P
0 g
s
.672 .579 .743 r
.49027 .42743 m .48891 .4238 L .47956 .42889 L closepath p F P
0 g
s
.674 .581 .744 r
.48712 .41907 m .48891 .4238 L .47956 .42889 L p F P
0 g
s
.674 .581 .744 r
.47832 .42025 m .48712 .41907 L p .47956 .42889 L F P
0 g
s
.674 .581 .744 r
.47522 .42196 m .47832 .42025 L p .47956 .42889 L F P
0 g
s
.734 .551 .645 r
.3483 .50445 m .34792 .50242 L .34691 .50433 L closepath p F P
0 g
s
.745 .618 .718 r
.31116 .44327 m .30471 .45028 L .31348 .45158 L p F P
0 g
s
.745 .618 .718 r
.3151 .44386 m .31116 .44327 L p .31348 .45158 L F P
0 g
s
.746 .615 .713 r
.30471 .45028 m .31348 .45158 L .30748 .45845 L p F P
0 g
s
.662 .521 .682 r
.49273 .47657 m .49667 .4737 L .49219 .47434 L closepath p F P
0 g
s
.693 .615 .764 r
.43902 .39903 m .42829 .40538 L .42533 .39883 L p F P
0 g
s
.714 .633 .765 r
.38241 .39652 m .38424 .40036 L .37623 .40595 L p F P
0 g
s
.714 .633 .765 r
.37803 .39631 m .38241 .39652 L p .37623 .40595 L F P
0 g
s
.714 .633 .765 r
.37052 .40158 m .37803 .39631 L p .37623 .40595 L F P
0 g
s
.714 .633 .765 r
.37623 .40595 m .37254 .40578 L .37052 .40158 L p F P
0 g
s
.688 .49 .614 r
.42755 .51228 m .43436 .51204 L .43497 .51785 L p F P
0 g
s
.688 .49 .614 r
.43497 .51785 m .42483 .51821 L .42755 .51228 L p F P
0 g
s
.711 .51 .614 r
.38595 .51828 m .37944 .51812 L .37883 .51226 L p F P
0 g
s
.717 .514 .614 r
.37647 .51216 m .37883 .51226 L .37944 .51812 L p F P
0 g
s
.667 .497 .645 r
.47154 .49706 m .48414 .4957 L p .48283 .50217 L F P
0 g
s
.667 .497 .645 r
.48283 .50217 m .47258 .50326 L .47154 .49706 L p F P
0 g
s
.67 .51 .659 r
.48288 .48929 m .48414 .4957 L .47154 .49706 L p F P
0 g
s
.745 .625 .727 r
.3151 .44386 m .31374 .44059 L .31116 .44327 L closepath p F P
0 g
s
.734 .635 .749 r
.33566 .42105 m .33532 .42032 L .33462 .42092 L closepath p F P
0 g
s
.743 .578 .67 r
.31937 .48183 m .31526 .48813 L .32455 .48924 L p F P
0 g
s
.745 .581 .673 r
.31237 .48095 m .31937 .48183 L .31526 .48813 L p F P
0 g
s
.744 .59 .684 r
.31169 .47861 m .31481 .47422 L p .31937 .48183 L F P
0 g
s
.744 .59 .684 r
.31937 .48183 m .31237 .48095 L .31169 .47861 L p F P
0 g
s
.746 .591 .683 r
.31169 .47861 m .31481 .47422 L .31022 .47362 L closepath p F P
0 g
s
.745 .598 .694 r
.30878 .46913 m .31085 .46643 L p .31481 .47422 L F P
0 g
s
.745 .598 .694 r
.31481 .47422 m .31022 .47362 L .30878 .46913 L p F P
0 g
s
.737 .626 .736 r
.32455 .42999 m .32602 .42862 L .32384 .42834 L closepath p F P
0 g
s
.735 .632 .744 r
.32545 .41974 m .33462 .42092 L .32602 .42862 L p F P
0 g
s
.735 .632 .744 r
.32153 .42325 m .32545 .41974 L p .32602 .42862 L F P
0 g
s
.735 .632 .744 r
.32602 .42862 m .32384 .42834 L .32153 .42325 L p F P
0 g
s
.685 .601 .756 r
.45863 .4134 m .4586 .41332 L .45844 .41341 L closepath p F P
0 g
s
.686 .603 .757 r
.45566 .40635 m .4586 .41332 L .45844 .41341 L p F P
0 g
s
.74 .63 .737 r
.32384 .42834 m .32455 .42999 L .31827 .43604 L p F P
0 g
s
.72 .631 .758 r
.3598 .40949 m .36538 .40531 L .35759 .40476 L closepath p F P
0 g
s
.681 .599 .757 r
.46935 .40742 m .47128 .41203 L .45863 .4134 L p F P
0 g
s
.681 .599 .757 r
.45863 .4134 m .4586 .41332 L .46935 .40742 L p F P
0 g
s
.717 .514 .614 r
.37944 .51812 m .37433 .5179 L .37647 .51216 L p F P
0 g
s
.718 .516 .615 r
.36527 .51166 m .37647 .51216 L .37433 .5179 L p F P
0 g
s
.681 .598 .756 r
.46935 .40742 m .4586 .41332 L .45566 .40635 L p F P
0 g
s
.719 .635 .763 r
.37254 .40578 m .37052 .40158 L .36538 .40531 L closepath p F P
0 g
s
.735 .636 .749 r
.3323 .41384 m .32545 .41974 L .33462 .42092 L p F P
0 g
s
.735 .636 .749 r
.33462 .42092 m .33532 .42032 L .3323 .41384 L p F P
0 g
s
.663 .504 .659 r
.48288 .48929 m .4953 .48773 L p .48962 .49501 L F P
0 g
s
.663 .504 .659 r
.48962 .49501 m .48414 .4957 L .48288 .48929 L p F P
0 g
s
.666 .515 .671 r
.49384 .48113 m .4953 .48773 L .48288 .48929 L p F P
0 g
s
.731 .634 .751 r
.34424 .4129 m .33532 .42032 L .3323 .41384 L p F P
0 g
s
.662 .521 .682 r
.49384 .48113 m .49273 .47657 L .49667 .4737 L p F P
0 g
s
.728 .536 .631 r
.35464 .51097 m .3492 .5106 L .3483 .50445 L p F P
0 g
s
.733 .54 .63 r
.34691 .50433 m .3483 .50445 L .3492 .5106 L p F P
0 g
s
.741 .568 .659 r
.33167 .49661 m .33128 .49485 L .33033 .49647 L closepath p F P
0 g
s
.682 .486 .614 r
.43436 .51204 m .44262 .51162 L .43971 .51761 L p F P
0 g
s
.682 .486 .614 r
.43971 .51761 m .43497 .51785 L .43436 .51204 L p F P
0 g
s
.742 .568 .659 r
.32455 .48924 m .32097 .49539 L .33033 .49647 L p F P
0 g
s
.744 .571 .66 r
.31526 .48813 m .32455 .48924 L .32097 .49539 L p F P
0 g
s
.742 .624 .728 r
.31374 .44059 m .31827 .43604 L .31145 .43509 L closepath p F P
0 g
s
.74 .63 .737 r
.31707 .42737 m .32384 .42834 L p .31827 .43604 L F P
0 g
s
.74 .63 .737 r
.31073 .43346 m .31707 .42737 L p .31827 .43604 L F P
0 g
s
.74 .63 .737 r
.31827 .43604 m .31145 .43509 L .31073 .43346 L p F P
0 g
s
.747 .599 .693 r
.30878 .46913 m .31085 .46643 L .30778 .46601 L closepath p F P
0 g
s
.746 .607 .703 r
.30584 .46046 m .30748 .45845 L p .31085 .46643 L F P
0 g
s
.746 .607 .703 r
.31085 .46643 m .30778 .46601 L .30584 .46046 L p F P
0 g
s
.674 .582 .744 r
.47522 .42196 m .47832 .42025 L .47474 .42071 L closepath p F P
0 g
s
.672 .49 .631 r
.46037 .50861 m .46357 .50408 L .45978 .50441 L closepath p F P
0 g
s
.678 .494 .63 r
.45978 .50441 m .46037 .50861 L .45909 .51054 L p F P
0 g
s
.729 .637 .756 r
.3469 .41318 m .34606 .41143 L .34424 .4129 L closepath p F P
0 g
s
.734 .542 .632 r
.33696 .50344 m .34691 .50433 L .34434 .51019 L p F P
0 g
s
.733 .54 .63 r
.3492 .5106 m .34434 .51019 L .34691 .50433 L p F P
0 g
s
.74 .634 .742 r
.32384 .42834 m .32153 .42325 L .31707 .42737 L closepath p F P
0 g
s
.675 .589 .751 r
.47832 .42025 m .47474 .42071 L .47229 .41456 L p F P
0 g
s
.745 .626 .727 r
.31116 .44327 m .31374 .44059 L .31145 .43509 L p F P
0 g
s
.687 .603 .756 r
.45481 .40434 m .45566 .40635 L p .44198 .40565 L F P
0 g
s
.687 .603 .756 r
.44198 .40565 m .44253 .40533 L .45481 .40434 L p F P
0 g
s
.688 .606 .759 r
.44198 .40565 m .44253 .40533 L .44186 .40538 L closepath p F P
0 g
s
.736 .554 .646 r
.33696 .50344 m .33288 .50306 L .33167 .49661 L p F P
0 g
s
.742 .558 .645 r
.33033 .49647 m .33167 .49661 L .33288 .50306 L p F P
0 g
s
.663 .553 .72 r
.50846 .443 m .51039 .44905 L .49831 .451 L p F P
0 g
s
.663 .553 .72 r
.49831 .451 m .49767 .44902 L .50846 .443 L p F P
0 g
s
.662 .545 .712 r
.49831 .451 m .51039 .44905 L p .50085 .45836 L F P
0 g
s
.662 .545 .712 r
.50085 .45836 m .50056 .45841 L .49831 .451 L p F P
0 g
s
.663 .554 .72 r
.50796 .44144 m .50846 .443 L .49767 .44902 L p F P
0 g
s
.663 .554 .72 r
.49767 .44902 m .49585 .44337 L .50796 .44144 L p F P
0 g
s
.688 .612 .766 r
.44253 .40533 m .44186 .40538 L .43902 .39903 L p F P
0 g
s
.665 .561 .728 r
.50554 .43428 m .50796 .44144 L .49585 .44337 L p F P
0 g
s
.665 .561 .728 r
.49585 .44337 m .49475 .44014 L .50554 .43428 L p F P
0 g
s
.687 .61 .764 r
.45481 .40434 m .45271 .39959 L .44253 .40533 L closepath p F P
0 g
s
.688 .612 .766 r
.45065 .39493 m .45271 .39959 L .44253 .40533 L p F P
0 g
s
.688 .612 .766 r
.44553 .39533 m .45065 .39493 L p .44253 .40533 L F P
0 g
s
.688 .612 .766 r
.43902 .39903 m .44553 .39533 L p .44253 .40533 L F P
0 g
s
.662 .521 .682 r
.49667 .4737 m .50443 .47257 L p .49384 .48113 L F P
0 g
s
.662 .529 .692 r
.50443 .47257 m .50351 .4691 L .49667 .4737 L closepath p F P
0 g
s
.664 .531 .693 r
.50259 .46559 m .50351 .4691 L .49667 .4737 L p F P
0 g
s
.719 .637 .765 r
.36772 .39578 m .37052 .40158 L .36538 .40531 L p F P
0 g
s
.719 .637 .765 r
.36698 .39572 m .36772 .39578 L p .36538 .40531 L F P
0 g
s
.719 .637 .765 r
.35679 .40314 m .36698 .39572 L p .36538 .40531 L F P
0 g
s
.719 .637 .765 r
.36538 .40531 m .35759 .40476 L .35679 .40314 L p F P
0 g
s
.731 .634 .751 r
.3323 .41384 m .3347 .41183 L .34424 .4129 L p F P
0 g
s
.729 .638 .757 r
.34304 .40512 m .3347 .41183 L .34424 .4129 L p F P
0 g
s
.729 .638 .757 r
.34424 .4129 m .34606 .41143 L .34304 .40512 L p F P
0 g
s
.671 .49 .631 r
.46357 .50408 m .47258 .50326 L p .46063 .51043 L F P
0 g
s
.671 .49 .631 r
.46063 .51043 m .46037 .50861 L .46357 .50408 L p F P
0 g
s
.665 .562 .728 r
.50532 .43361 m .50554 .43428 L .49475 .44014 L p F P
0 g
s
.665 .562 .728 r
.49475 .44014 m .49318 .43552 L .50532 .43361 L p F P
0 g
s
.742 .558 .645 r
.33288 .50306 m .32732 .50245 L .33033 .49647 L p F P
0 g
s
.743 .56 .647 r
.32097 .49539 m .33033 .49647 L .32732 .50245 L p F P
0 g
s
.746 .622 .721 r
.30253 .44192 m .31116 .44327 L .30471 .45028 L p F P
0 g
s
.745 .626 .727 r
.30941 .43477 m .30253 .44192 L .31116 .44327 L p F P
0 g
s
.745 .626 .727 r
.31145 .43509 m .30941 .43477 L p .31116 .44327 L F P
0 g
s
.718 .516 .615 r
.36444 .51386 m .36527 .51166 L p .37433 .5179 L F P
0 g
s
.72 .517 .615 r
.36444 .51386 m .36527 .51166 L .3642 .5116 L closepath p F P
0 g
s
.747 .608 .703 r
.30584 .46046 m .30748 .45845 L .30501 .4581 L closepath p F P
0 g
s
.746 .615 .713 r
.30287 .45241 m .30471 .45028 L p .30748 .45845 L F P
0 g
s
.746 .615 .713 r
.30748 .45845 m .30501 .4581 L .30287 .45241 L p F P
0 g
s
.75 .593 .682 r
.31022 .47362 m .30593 .47298 L p .31028 .48065 L F P
0 g
s
.75 .593 .682 r
.31028 .48065 m .31169 .47861 L .31022 .47362 L p F P
0 g
s
.75 .601 .692 r
.31022 .47362 m .30878 .46913 L .30593 .47298 L closepath p F P
0 g
s
.681 .484 .613 r
.44262 .51162 m .4476 .51135 L .44821 .51714 L p F P
0 g
s
.681 .484 .613 r
.44821 .51714 m .43971 .51761 L .44262 .51162 L p F P
0 g
s
.75 .601 .692 r
.30593 .47298 m .30878 .46913 L .30778 .46601 L p F P
0 g
s
.75 .601 .692 r
.30778 .46601 m .30215 .46513 L p .30593 .47298 L F P
0 g
s
.751 .609 .701 r
.30778 .46601 m .30584 .46046 L .30215 .46513 L closepath p F P
0 g
s
.66 .536 .702 r
.50059 .45852 m .50085 .45836 L .50056 .45841 L closepath p F P
0 g
s
.725 .521 .614 r
.3642 .5116 m .35464 .51097 L p .36317 .51738 L F P
0 g
s
.725 .521 .614 r
.36317 .51738 m .36444 .51386 L .3642 .5116 L p F P
0 g
s
.659 .535 .702 r
.50059 .45852 m .50085 .45836 L p .51129 .46418 L F P
0 g
s
.659 .535 .702 r
.51129 .46418 m .50259 .46559 L .50059 .45852 L p F P
0 g
s
.726 .636 .758 r
.35494 .40453 m .34606 .41143 L .34304 .40512 L p F P
0 g
s
.659 .535 .702 r
.50085 .45836 m .51262 .45644 L p .51129 .46418 L F P
0 g
s
.66 .543 .711 r
.51262 .45644 m .51138 .45232 L .50085 .45836 L closepath p F P
0 g
s
.662 .545 .712 r
.51039 .44905 m .51138 .45232 L .50085 .45836 L p F P
0 g
s
.659 .511 .672 r
.49384 .48113 m .50608 .47937 L p .49825 .48731 L F P
0 g
s
.659 .511 .672 r
.49825 .48731 m .4953 .48773 L .49384 .48113 L p F P
0 g
s
.662 .521 .682 r
.50443 .47257 m .50608 .47937 L .49384 .48113 L p F P
0 g
s
.667 .569 .736 r
.50262 .42605 m .50532 .43361 L .49318 .43552 L p F P
0 g
s
.667 .569 .736 r
.49318 .43552 m .49183 .43177 L .50262 .42605 L p F P
0 g
s
.704 .624 .764 r
.41067 .39689 m .41164 .39898 L p .39794 .39949 L F P
0 g
s
.704 .624 .764 r
.39794 .39949 m .40193 .3969 L .41067 .39689 L p F P
0 g
s
.705 .626 .766 r
.39794 .39949 m .40193 .3969 L .39672 .39689 L closepath p F P
0 g
s
.674 .587 .75 r
.48712 .41907 m .48598 .41618 L .47832 .42025 L closepath p F P
0 g
s
.675 .589 .751 r
.48371 .41043 m .48598 .41618 L .47832 .42025 L p F P
0 g
s
.675 .589 .751 r
.47873 .41109 m .48371 .41043 L p .47832 .42025 L F P
0 g
s
.675 .589 .751 r
.47229 .41456 m .47873 .41109 L p .47832 .42025 L F P
0 g
s
.749 .593 .682 r
.31237 .48095 m .31169 .47861 L .31028 .48065 L closepath p F P
0 g
s
.71 .63 .765 r
.38424 .40036 m .38963 .39672 L .38241 .39652 L closepath p F P
0 g
s
.751 .61 .701 r
.30215 .46513 m .30584 .46046 L .30501 .4581 L p F P
0 g
s
.745 .581 .673 r
.31526 .48813 m .31422 .48801 L .31237 .48095 L p F P
0 g
s
.751 .585 .671 r
.31028 .48065 m .31237 .48095 L .31422 .48801 L p F P
0 g
s
.699 .619 .764 r
.42429 .39655 m .42533 .39883 L p .41164 .39898 L F P
0 g
s
.699 .619 .764 r
.41164 .39898 m .41515 .39679 L .42429 .39655 L p F P
0 g
s
.7 .622 .766 r
.41164 .39898 m .41515 .39679 L .41067 .39689 L closepath p F P
0 g
s
.675 .48 .614 r
.4476 .51135 m .45909 .51054 L .45596 .5166 L p F P
0 g
s
.675 .48 .614 r
.45596 .5166 m .44821 .51714 L .4476 .51135 L p F P
0 g
s
.667 .57 .736 r
.50244 .42553 m .50262 .42605 L .49183 .43177 L p F P
0 g
s
.667 .57 .736 r
.49183 .43177 m .49027 .42743 L .50244 .42553 L p F P
0 g
s
.751 .61 .701 r
.30501 .4581 m .29893 .4571 L p .30215 .46513 L F P
0 g
s
.751 .617 .71 r
.30501 .4581 m .30287 .45241 L .29893 .4571 L closepath p F P
0 g
s
.715 .634 .765 r
.37052 .40158 m .37803 .39631 L .36772 .39578 L closepath p F P
0 g
s
.658 .527 .693 r
.50351 .4691 m .51129 .46418 L .50259 .46559 L closepath p F P
0 g
s
.724 .639 .763 r
.35759 .40476 m .35679 .40314 L .35494 .40453 L closepath p F P
0 g
s
.676 .59 .751 r
.47229 .41456 m .47873 .41109 L .47128 .41203 L closepath p F P
0 g
s
.745 .632 .734 r
.31145 .43509 m .31073 .43346 L .30941 .43477 L closepath p F P
0 g
s
.746 .622 .721 r
.29988 .44482 m .30253 .44192 L p .30471 .45028 L F P
0 g
s
.746 .622 .721 r
.30471 .45028 m .30191 .44986 L .29988 .44482 L p F P
0 g
s
.748 .616 .712 r
.30287 .45241 m .30471 .45028 L .30191 .44986 L closepath p F P
0 g
s
.683 .602 .759 r
.45566 .40635 m .46025 .4038 L .45481 .40434 L closepath p F P
0 g
s
.681 .598 .756 r
.46752 .40304 m .46935 .40742 L p .45566 .40635 L F P
0 g
s
.681 .598 .756 r
.45566 .40635 m .46025 .4038 L .46752 .40304 L p F P
0 g
s
.751 .585 .671 r
.31422 .48801 m .30639 .48689 L .31028 .48065 L p F P
0 g
s
.751 .588 .674 r
.30155 .47936 m .31028 .48065 L .30639 .48689 L p F P
0 g
s
.75 .593 .682 r
.30593 .47298 m .30155 .47936 L .31028 .48065 L p F P
0 g
s
.693 .615 .764 r
.43761 .39589 m .43902 .39903 L p .42533 .39883 L F P
0 g
s
.693 .615 .764 r
.42533 .39883 m .42956 .39631 L .43761 .39589 L p F P
0 g
s
.695 .617 .766 r
.42533 .39883 m .42956 .39631 L .42429 .39655 L closepath p F P
0 g
s
.668 .577 .744 r
.4997 .41822 m .50244 .42553 L .49027 .42743 L p F P
0 g
s
.668 .577 .744 r
.49027 .42743 m .48891 .4238 L .4997 .41822 L p F P
0 g
s
.734 .542 .632 r
.34434 .51019 m .33433 .50931 L .33696 .50344 L p F P
0 g
s
.736 .544 .633 r
.33288 .50306 m .33696 .50344 L .33433 .50931 L p F P
0 g
s
.737 .633 .744 r
.32153 .42325 m .32545 .41974 L .31958 .41897 L closepath p F P
0 g
s
.74 .635 .742 r
.31707 .42737 m .32153 .42325 L .31958 .41897 L p F P
0 g
s
.742 .631 .736 r
.31707 .42737 m .31073 .43346 L .30771 .42661 L p F P
0 g
s
.742 .631 .736 r
.30771 .42661 m .30826 .42607 L .31707 .42737 L p F P
0 g
s
.74 .635 .742 r
.31647 .41849 m .30826 .42607 L .31707 .42737 L p F P
0 g
s
.74 .635 .742 r
.31958 .41897 m .31647 .41849 L p .31707 .42737 L F P
0 g
s
.751 .597 .684 r
.2973 .47165 m .30593 .47298 L .30155 .47936 L p F P
0 g
s
.75 .601 .692 r
.30215 .46513 m .2973 .47165 L .30593 .47298 L p F P
0 g
s
.725 .521 .614 r
.35464 .51097 m .35255 .51669 L .36317 .51738 L p F P
0 g
s
.727 .523 .615 r
.3492 .5106 m .35464 .51097 L .35255 .51669 L p F P
0 g
s
.735 .639 .752 r
.33116 .41142 m .3323 .41384 L .32545 .41974 L p F P
0 g
s
.735 .639 .752 r
.32552 .41065 m .33116 .41142 L p .32545 .41974 L F P
0 g
s
.735 .639 .752 r
.3185 .41669 m .32552 .41065 L p .32545 .41974 L F P
0 g
s
.735 .639 .752 r
.32545 .41974 m .31958 .41897 L .3185 .41669 L p F P
0 g
s
.726 .636 .758 r
.34304 .40512 m .34501 .40358 L .35494 .40453 L p F P
0 g
s
.725 .64 .764 r
.35376 .397 m .34501 .40358 L .35494 .40453 L p F P
0 g
s
.725 .64 .764 r
.35494 .40453 m .35679 .40314 L .35376 .397 L p F P
0 g
s
.718 .516 .615 r
.37433 .5179 m .36482 .51748 L .36444 .51386 L p F P
0 g
s
.724 .52 .614 r
.36482 .51748 m .36444 .51386 L .36317 .51738 L closepath p F P
0 g
s
.744 .571 .66 r
.31453 .48938 m .31526 .48813 L p .32097 .49539 L F P
0 g
s
.746 .572 .66 r
.31453 .48938 m .31526 .48813 L .31422 .48801 L closepath p F P
0 g
s
.704 .629 .771 r
.41067 .39689 m .40866 .39269 L .40193 .3969 L closepath p F P
0 g
s
.704 .631 .773 r
.40583 .3868 m .40866 .39269 L .40193 .3969 L p F P
0 g
s
.704 .631 .773 r
.40516 .3868 m .40583 .3868 L p .40193 .3969 L F P
0 g
s
.704 .631 .773 r
.39495 .39325 m .40516 .3868 L p .40193 .3969 L F P
0 g
s
.704 .631 .773 r
.40193 .3969 m .39672 .39689 L .39495 .39325 L p F P
0 g
s
.699 .627 .773 r
.41515 .39679 m .41067 .39689 L .40866 .39269 L p F P
0 g
s
.709 .633 .771 r
.39672 .39689 m .39495 .39325 L .38963 .39672 L closepath p F P
0 g
s
.695 .483 .596 r
.40776 .51852 m .41105 .51848 L .40937 .5241 L p F P
0 g
s
.695 .483 .596 r
.40937 .5241 m .40811 .52411 L .40776 .51852 L p F P
0 g
s
.701 .487 .595 r
.39814 .51849 m .40776 .51852 L .40811 .52411 L p F P
0 g
s
.676 .493 .63 r
.46063 .51043 m .46037 .50861 L .45909 .51054 L closepath p F P
0 g
s
.661 .493 .646 r
.48486 .49994 m .48962 .49501 L .48414 .4957 L closepath p F P
0 g
s
.667 .497 .645 r
.48414 .4957 m .48486 .49994 L .48283 .50217 L p F P
0 g
s
.657 .526 .693 r
.50443 .47257 m .50351 .4691 L .51129 .46418 L p F P
0 g
s
.701 .487 .595 r
.40811 .52411 m .39656 .52407 L .39814 .51849 L p F P
0 g
s
.702 .489 .596 r
.39375 .51846 m .39814 .51849 L .39656 .52407 L p F P
0 g
s
.751 .617 .71 r
.29893 .4571 m .30287 .45241 L .30191 .44986 L p F P
0 g
s
.693 .481 .595 r
.41105 .51848 m .42149 .51831 L .42185 .5239 L p F P
0 g
s
.693 .481 .595 r
.42185 .5239 m .40937 .5241 L .41105 .51848 L p F P
0 g
s
.676 .596 .759 r
.47873 .41109 m .47128 .41203 L .46935 .40742 L p F P
0 g
s
.664 .484 .631 r
.47258 .50326 m .48283 .50217 L .47777 .50881 L p F P
0 g
s
.664 .484 .631 r
.47777 .50881 m .47343 .50927 L .47258 .50326 L p F P
0 g
s
.671 .49 .631 r
.47258 .50326 m .47343 .50927 L .46063 .51043 L p F P
0 g
s
.702 .489 .596 r
.39656 .52407 m .39409 .52406 L .39375 .51846 L p F P
0 g
s
.708 .493 .595 r
.38595 .51828 m .39375 .51846 L .39409 .52406 L p F P
0 g
s
.745 .633 .735 r
.30941 .43477 m .31073 .43346 L .30771 .42661 L p F P
0 g
s
.698 .625 .771 r
.42429 .39655 m .42236 .39246 L .41515 .39679 L closepath p F P
0 g
s
.699 .627 .773 r
.41957 .38657 m .42236 .39246 L .41515 .39679 L p F P
0 g
s
.699 .627 .773 r
.41871 .38659 m .41957 .38657 L p .41515 .39679 L F P
0 g
s
.699 .627 .773 r
.40866 .39269 m .41871 .38659 L p .41515 .39679 L F P
0 g
s
.75 .575 .658 r
.31422 .48801 m .30639 .48689 L p .31182 .49424 L F P
0 g
s
.75 .575 .658 r
.31182 .49424 m .31453 .48938 L .31422 .48801 L p F P
0 g
s
.721 .639 .766 r
.36698 .39572 m .35679 .40314 L .35376 .397 L p F P
0 g
s
.746 .629 .73 r
.30092 .43337 m .30941 .43477 L .30253 .44192 L p F P
0 g
s
.745 .633 .735 r
.30771 .42661 m .30092 .43337 L .30941 .43477 L p F P
0 g
s
.683 .608 .766 r
.46025 .4038 m .45481 .40434 L .45271 .39959 L p F P
0 g
s
.732 .635 .751 r
.3323 .41384 m .3347 .41183 L .33116 .41142 L closepath p F P
0 g
s
.709 .635 .772 r
.39195 .38711 m .39495 .39325 L .38963 .39672 L p F P
0 g
s
.709 .635 .772 r
.38123 .39414 m .39195 .38711 L p .38963 .39672 L F P
0 g
s
.709 .635 .772 r
.38963 .39672 m .38241 .39652 L .38123 .39414 L p F P
0 g
s
.752 .605 .695 r
.29362 .46376 m .30215 .46513 L .2973 .47165 L p F P
0 g
s
.751 .61 .701 r
.29893 .4571 m .29362 .46376 L .30215 .46513 L p F P
0 g
s
.668 .578 .744 r
.49931 .41719 m .4997 .41822 L .48891 .4238 L p F P
0 g
s
.668 .578 .744 r
.48891 .4238 m .48712 .41907 L .49931 .41719 L p F P
0 g
s
.687 .476 .596 r
.42149 .51831 m .42483 .51821 L .42305 .52386 L p F P
0 g
s
.687 .476 .596 r
.42305 .52386 m .42185 .5239 L .42149 .51831 L p F P
0 g
s
.752 .625 .719 r
.30191 .44986 m .29988 .44482 L .29626 .44889 L closepath p F P
0 g
s
.751 .617 .71 r
.30191 .44986 m .29626 .44889 L p .29893 .4571 L F P
0 g
s
.708 .493 .595 r
.39409 .52406 m .38445 .52384 L .38595 .51828 L p F P
0 g
s
.709 .494 .596 r
.37944 .51812 m .38595 .51828 L .38445 .52384 L p F P
0 g
s
.73 .641 .759 r
.34216 .4033 m .34304 .40512 L .3347 .41183 L p F P
0 g
s
.73 .641 .759 r
.33552 .40249 m .34216 .4033 L p .3347 .41183 L F P
0 g
s
.73 .641 .759 r
.32926 .40754 m .33552 .40249 L p .3347 .41183 L F P
0 g
s
.73 .641 .759 r
.3347 .41183 m .33116 .41142 L .32926 .40754 L p F P
0 g
s
.736 .544 .633 r
.33433 .50931 m .33382 .50927 L .33288 .50306 L p F P
0 g
s
.742 .548 .631 r
.32732 .50245 m .33288 .50306 L .33382 .50927 L p F P
0 g
s
.744 .571 .66 r
.32097 .49539 m .31576 .49477 L .31453 .48938 L p F P
0 g
s
.749 .574 .658 r
.31576 .49477 m .31453 .48938 L .31182 .49424 L closepath p F P
0 g
s
.694 .623 .773 r
.42956 .39631 m .42429 .39655 L .42236 .39246 L p F P
0 g
s
.727 .523 .615 r
.35255 .51669 m .34983 .51651 L .3492 .5106 L p F P
0 g
s
.733 .528 .614 r
.34434 .51019 m .3492 .5106 L .34983 .51651 L p F P
0 g
s
.685 .474 .595 r
.42483 .51821 m .43497 .51785 L .43533 .52343 L p F P
0 g
s
.685 .474 .595 r
.43533 .52343 m .42305 .52386 L .42483 .51821 L p F P
0 g
s
.743 .56 .647 r
.32732 .50245 m .31789 .50139 L .32097 .49539 L p F P
0 g
s
.744 .562 .648 r
.31576 .49477 m .32097 .49539 L .31789 .50139 L p F P
0 g
s
.655 .517 .683 r
.50443 .47257 m .51649 .4706 L p .50952 .47881 L F P
0 g
s
.655 .517 .683 r
.50952 .47881 m .50608 .47937 L .50443 .47257 L p F P
0 g
s
.657 .526 .693 r
.51466 .46363 m .51649 .4706 L .50443 .47257 L p F P
0 g
s
.657 .526 .693 r
.51129 .46418 m .51466 .46363 L p .50443 .47257 L F P
0 g
s
.714 .637 .77 r
.38241 .39652 m .38123 .39414 L .37803 .39631 L closepath p F P
0 g
s
.689 .613 .766 r
.43902 .39903 m .44553 .39533 L .43761 .39589 L closepath p F P
0 g
s
.657 .499 .659 r
.49565 .48953 m .49825 .48731 L .4953 .48773 L closepath p F P
0 g
s
.663 .504 .659 r
.4953 .48773 m .49565 .48953 L .48962 .49501 L p F P
0 g
s
.673 .478 .613 r
.45909 .51054 m .46063 .51043 L .46123 .51621 L p F P
0 g
s
.673 .478 .613 r
.46123 .51621 m .45596 .5166 L .45909 .51054 L p F P
0 g
s
.709 .494 .596 r
.38445 .52384 m .37977 .52372 L .37944 .51812 L p F P
0 g
s
.716 .499 .595 r
.37433 .5179 m .37944 .51812 L .37977 .52372 L p F P
0 g
s
.667 .473 .613 r
.46063 .51043 m .47343 .50927 L p .47396 .51508 L F P
0 g
s
.667 .473 .613 r
.47396 .51508 m .46123 .51621 L .46063 .51043 L p F P
0 g
s
.714 .639 .772 r
.37822 .38809 m .38123 .39414 L .37803 .39631 L p F P
0 g
s
.714 .639 .772 r
.36751 .39535 m .37822 .38809 L p .37803 .39631 L F P
0 g
s
.714 .639 .772 r
.37803 .39631 m .36772 .39578 L .36751 .39535 L p F P
0 g
s
.693 .621 .771 r
.43761 .39589 m .43606 .39256 L .42956 .39631 L closepath p F P
0 g
s
.694 .623 .773 r
.43309 .38622 m .43606 .39256 L .42956 .39631 L p F P
0 g
s
.694 .623 .773 r
.42236 .39246 m .43309 .38622 L p .42956 .39631 L F P
0 g
s
.748 .623 .721 r
.29988 .44482 m .30253 .44192 L .29844 .44127 L closepath p F P
0 g
s
.746 .629 .73 r
.29686 .43759 m .30092 .43337 L p .30253 .44192 L F P
0 g
s
.746 .629 .73 r
.30253 .44192 m .29844 .44127 L .29686 .43759 L p F P
0 g
s
.753 .613 .704 r
.29051 .45569 m .29893 .4571 L .29362 .46376 L p F P
0 g
s
.751 .617 .71 r
.29626 .44889 m .29051 .45569 L .29893 .4571 L p F P
0 g
s
.669 .585 .751 r
.49677 .41073 m .49931 .41719 L .48712 .41907 L p F P
0 g
s
.669 .585 .751 r
.48712 .41907 m .48598 .41618 L .49677 .41073 L p F P
0 g
s
.716 .499 .595 r
.37977 .52372 m .3729 .52344 L .37433 .5179 L p F P
0 g
s
.717 .5 .595 r
.36482 .51748 m .37433 .5179 L .3729 .52344 L p F P
0 g
s
.735 .643 .757 r
.33116 .41142 m .32926 .40754 L .32552 .41065 L closepath p F P
0 g
s
.683 .608 .766 r
.46347 .39375 m .46641 .4005 L .46025 .4038 L p F P
0 g
s
.683 .608 .766 r
.45271 .39959 m .46347 .39375 L p .46025 .4038 L F P
0 g
s
.682 .606 .764 r
.46752 .40304 m .46641 .4005 L .46025 .4038 L closepath p F P
0 g
s
.679 .47 .595 r
.43497 .51785 m .43971 .51761 L .43782 .5233 L p F P
0 g
s
.679 .47 .595 r
.43782 .5233 m .43533 .52343 L .43497 .51785 L p F P
0 g
s
.74 .641 .749 r
.31958 .41897 m .3185 .41669 L .31647 .41849 L closepath p F P
0 g
s
.66 .492 .646 r
.48962 .49501 m .49655 .49412 L p .48519 .50191 L F P
0 g
s
.66 .492 .646 r
.48519 .50191 m .48486 .49994 L .48962 .49501 L p F P
0 g
s
.661 .502 .658 r
.49655 .49412 m .49565 .48953 L .48962 .49501 L closepath p F P
0 g
s
.656 .499 .659 r
.49655 .49412 m .49565 .48953 L .49825 .48731 L p F P
0 g
s
.727 .638 .759 r
.34304 .40512 m .34501 .40358 L .34216 .4033 L closepath p F P
0 g
s
.676 .596 .759 r
.46935 .40742 m .48012 .40175 L p .47873 .41109 L F P
0 g
s
.677 .597 .759 r
.48001 .40148 m .48012 .40175 L .46935 .40742 L p F P
0 g
s
.677 .597 .759 r
.46935 .40742 m .46752 .40304 L .48001 .40148 L p F P
0 g
s
.734 .529 .615 r
.33433 .50931 m .34434 .51019 L .34237 .51587 L p F P
0 g
s
.733 .528 .614 r
.34983 .51651 m .34237 .51587 L .34434 .51019 L p F P
0 g
s
.752 .625 .719 r
.29626 .44889 m .29988 .44482 L .29844 .44127 L p F P
0 g
s
.656 .499 .659 r
.49825 .48731 m .50752 .48595 L p .49655 .49412 L F P
0 g
s
.657 .509 .67 r
.50752 .48595 m .50644 .48102 L .49825 .48731 L closepath p F P
0 g
s
.659 .511 .672 r
.50608 .47937 m .50644 .48102 L .49825 .48731 L p F P
0 g
s
.725 .643 .766 r
.35256 .39457 m .35376 .397 L .34501 .40358 L p F P
0 g
s
.725 .643 .766 r
.34671 .39395 m .35256 .39457 L p .34501 .40358 L F P
0 g
s
.725 .643 .766 r
.34 .39901 m .34671 .39395 L p .34501 .40358 L F P
0 g
s
.725 .643 .766 r
.34501 .40358 m .34216 .4033 L .34 .39901 L p F P
0 g
s
.706 .633 .773 r
.40516 .3868 m .39495 .39325 L .39195 .38711 L p F P
0 g
s
.742 .548 .631 r
.33382 .50927 m .32483 .50828 L .32732 .50245 L p F P
0 g
s
.742 .549 .632 r
.31789 .50139 m .32732 .50245 L .32483 .50828 L p F P
0 g
s
.677 .468 .595 r
.43971 .51761 m .44821 .51714 L .44858 .52271 L p F P
0 g
s
.677 .468 .595 r
.44858 .52271 m .43782 .5233 L .43971 .51761 L p F P
0 g
s
.67 .585 .752 r
.49592 .40857 m .49677 .41073 L .48598 .41618 L p F P
0 g
s
.67 .585 .752 r
.48598 .41618 m .48371 .41043 L .49592 .40857 L p F P
0 g
s
.711 .637 .773 r
.39195 .38711 m .38123 .39414 L .37822 .38809 L p F P
0 g
s
.744 .562 .648 r
.31789 .50139 m .31703 .50129 L .31576 .49477 L p F P
0 g
s
.75 .566 .646 r
.31182 .49424 m .31576 .49477 L .31703 .50129 L p F P
0 g
s
.689 .619 .773 r
.44553 .39533 m .43761 .39589 L .43606 .39256 L p F P
0 g
s
.675 .594 .757 r
.48371 .41043 m .48305 .40884 L .47873 .41109 L closepath p F P
0 g
s
.676 .596 .759 r
.48012 .40175 m .48305 .40884 L .47873 .41109 L p F P
0 g
s
.7 .628 .773 r
.40866 .39269 m .41871 .38659 L .40583 .3868 L closepath p F P
0 g
s
.665 .495 .645 r
.48519 .50191 m .48486 .49994 L .48283 .50217 L closepath p F P
0 g
s
.684 .609 .766 r
.46345 .3937 m .46347 .39375 L .45271 .39959 L p F P
0 g
s
.684 .609 .766 r
.45271 .39959 m .45065 .39493 L .46345 .3937 L p F P
0 g
s
.657 .549 .72 r
.50846 .443 m .51324 .4405 L p .52104 .44712 L F P
0 g
s
.657 .549 .72 r
.52104 .44712 m .51039 .44905 L .50846 .443 L p F P
0 g
s
.658 .55 .721 r
.50846 .443 m .51324 .4405 L .50796 .44144 L closepath p F P
0 g
s
.659 .557 .729 r
.51324 .4405 m .50796 .44144 L .50554 .43428 L p F P
0 g
s
.656 .541 .712 r
.51138 .45232 m .52104 .44712 L .51039 .44905 L closepath p F P
0 g
s
.719 .641 .77 r
.36772 .39578 m .36751 .39535 L .36698 .39572 L closepath p F P
0 g
s
.717 .5 .595 r
.3729 .52344 m .36514 .52309 L .36482 .51748 L p F P
0 g
s
.723 .505 .595 r
.36317 .51738 m .36482 .51748 L .36514 .52309 L p F P
0 g
s
.721 .639 .766 r
.35376 .397 m .35665 .3949 L .36698 .39572 L p F P
0 g
s
.72 .643 .772 r
.36448 .38939 m .35665 .3949 L .36698 .39572 L p F P
0 g
s
.72 .643 .772 r
.36698 .39572 m .36751 .39535 L .36448 .38939 L p F P
0 g
s
.658 .535 .702 r
.51466 .46363 m .51431 .46239 L .51129 .46418 L closepath p F P
0 g
s
.659 .535 .702 r
.51262 .45644 m .51431 .46239 L .51129 .46418 L p F P
0 g
s
.656 .541 .712 r
.51262 .45644 m .51138 .45232 L .52104 .44712 L p F P
0 g
s
.653 .506 .671 r
.50644 .48102 m .50952 .47881 L .50608 .47937 L closepath p F P
0 g
s
.73 .645 .764 r
.34216 .4033 m .34 .39901 L .33552 .40249 L closepath p F P
0 g
s
.751 .588 .674 r
.29769 .48546 m .30155 .47936 L p .30639 .48689 L F P
0 g
s
.753 .589 .673 r
.29769 .48546 m .30155 .47936 L .2958 .4785 L closepath p F P
0 g
s
.751 .597 .684 r
.29482 .47525 m .2973 .47165 L p .30155 .47936 L F P
0 g
s
.751 .597 .684 r
.30155 .47936 m .2958 .4785 L .29482 .47525 L p F P
0 g
s
.741 .642 .75 r
.31545 .41034 m .30784 .41713 L .31647 .41849 L p F P
0 g
s
.741 .642 .75 r
.31647 .41849 m .3185 .41669 L .31545 .41034 L p F P
0 g
s
.741 .638 .745 r
.30784 .41713 m .31647 .41849 L .30826 .42607 L p F P
0 g
s
.662 .481 .63 r
.48283 .50217 m .48519 .50191 L .48603 .50789 L p F P
0 g
s
.662 .481 .63 r
.48603 .50789 m .47777 .50881 L .48283 .50217 L p F P
0 g
s
.723 .505 .595 r
.36514 .52309 m .36181 .52289 L .36317 .51738 L p F P
0 g
s
.724 .507 .596 r
.35255 .51669 m .36317 .51738 L .36181 .52289 L p F P
0 g
s
.716 .641 .773 r
.37822 .38809 m .36751 .39535 L .36448 .38939 L p F P
0 g
s
.743 .633 .737 r
.30771 .42661 m .30826 .42607 L .30741 .42594 L closepath p F P
0 g
s
.741 .638 .745 r
.30466 .42007 m .30784 .41713 L p .30826 .42607 L F P
0 g
s
.741 .638 .745 r
.30826 .42607 m .30741 .42594 L .30466 .42007 L p F P
0 g
s
.737 .64 .751 r
.32552 .41065 m .3185 .41669 L .31545 .41034 L p F P
0 g
s
.752 .625 .719 r
.29414 .4405 m .28797 .44743 L .29626 .44889 L p F P
0 g
s
.752 .625 .719 r
.29844 .44127 m .29414 .4405 L p .29626 .44889 L F P
0 g
s
.753 .621 .714 r
.28797 .44743 m .29626 .44889 L .29051 .45569 L p F P
0 g
s
.746 .636 .738 r
.30741 .42594 m .30771 .42661 L .30092 .43337 L p F P
0 g
s
.752 .632 .727 r
.29844 .44127 m .29686 .43759 L .29414 .4405 L closepath p F P
0 g
s
.75 .575 .658 r
.30639 .48689 m .30294 .493 L .31182 .49424 L p F P
0 g
s
.752 .578 .66 r
.29774 .48565 m .30639 .48689 L .30294 .493 L p F P
0 g
s
.751 .588 .674 r
.30639 .48689 m .29774 .48565 L .29769 .48546 L p F P
0 g
s
.66 .558 .729 r
.50554 .43428 m .50766 .43319 L .50532 .43361 L closepath p F P
0 g
s
.659 .557 .729 r
.50554 .43428 m .50766 .43319 L p .51324 .4405 L F P
0 g
s
.695 .624 .773 r
.43299 .386 m .43309 .38622 L .42236 .39246 L p F P
0 g
s
.695 .624 .773 r
.42236 .39246 m .41957 .38657 L .43299 .386 L p F P
0 g
s
.753 .598 .684 r
.29482 .47525 m .2973 .47165 L .29355 .47106 L closepath p F P
0 g
s
.752 .605 .695 r
.2919 .46609 m .29362 .46376 L p .2973 .47165 L F P
0 g
s
.752 .605 .695 r
.2973 .47165 m .29355 .47106 L .2919 .46609 L p F P
0 g
s
.653 .532 .704 r
.51431 .46239 m .51262 .45644 L .52453 .45426 L p F P
0 g
s
.656 .541 .712 r
.52231 .44689 m .52453 .45426 L .51262 .45644 L p F P
0 g
s
.656 .541 .712 r
.52104 .44712 m .52231 .44689 L p .51262 .45644 L F P
0 g
s
.661 .566 .737 r
.50766 .43319 m .50532 .43361 L .50262 .42605 L p F P
0 g
s
.746 .636 .738 r
.29989 .42463 m .30741 .42594 L p .30092 .43337 L F P
0 g
s
.747 .641 .743 r
.30741 .42594 m .30466 .42007 L .29989 .42463 L closepath p F P
0 g
s
.737 .64 .751 r
.31545 .41034 m .31655 .40939 L .32552 .41065 L p F P
0 g
s
.735 .643 .757 r
.32621 .40134 m .31655 .40939 L .32552 .41065 L p F P
0 g
s
.735 .643 .757 r
.32622 .40134 m .32621 .40134 L p .32552 .41065 L F P
0 g
s
.735 .643 .757 r
.32552 .41065 m .32926 .40754 L .32622 .40134 L p F P
0 g
s
.677 .604 .766 r
.47719 .39497 m .48001 .40148 L .46752 .40304 L p F P
0 g
s
.677 .604 .766 r
.46752 .40304 m .46641 .4005 L .47719 .39497 L p F P
0 g
s
.653 .506 .671 r
.50752 .48595 m .50644 .48102 L .50952 .47881 L p F P
0 g
s
.672 .463 .595 r
.44821 .51714 m .45596 .5166 L .45393 .52234 L p F P
0 g
s
.672 .463 .595 r
.45393 .52234 m .44858 .52271 L .44821 .51714 L p F P
0 g
s
.656 .477 .63 r
.48603 .50789 m .48519 .50191 L .4976 .50032 L p F P
0 g
s
.66 .492 .646 r
.49655 .49412 m .4976 .50032 L .48519 .50191 L p F P
0 g
s
.748 .63 .729 r
.29686 .43759 m .30092 .43337 L .29459 .43231 L closepath p F P
0 g
s
.746 .636 .738 r
.29383 .43063 m .29989 .42463 L p .30092 .43337 L F P
0 g
s
.746 .636 .738 r
.30092 .43337 m .29459 .43231 L .29383 .43063 L p F P
0 g
s
.75 .566 .646 r
.31703 .50129 m .30891 .50019 L .31182 .49424 L p F P
0 g
s
.75 .568 .648 r
.30294 .493 m .31182 .49424 L .30891 .50019 L p F P
0 g
s
.688 .617 .771 r
.45065 .39493 m .44976 .39299 L .44553 .39533 L closepath p F P
0 g
s
.689 .619 .773 r
.4468 .3866 m .44976 .39299 L .44553 .39533 L p F P
0 g
s
.689 .619 .773 r
.43606 .39256 m .4468 .3866 L p .44553 .39533 L F P
0 g
s
.754 .606 .694 r
.2919 .46609 m .29362 .46376 L .29098 .46333 L closepath p F P
0 g
s
.753 .613 .704 r
.28894 .45768 m .29051 .45569 L p .29362 .46376 L F P
0 g
s
.753 .613 .704 r
.29362 .46376 m .29098 .46333 L .28894 .45768 L p F P
0 g
s
.732 .642 .759 r
.32926 .40754 m .33552 .40249 L .32622 .40134 L closepath p F P
0 g
s
.653 .532 .703 r
.51466 .46363 m .51431 .46239 L .52513 .45641 L p F P
0 g
s
.653 .532 .704 r
.52453 .45426 m .52513 .45641 L .51431 .46239 L p F P
0 g
s
.656 .499 .659 r
.50752 .48595 m .50878 .49234 L .49655 .49412 L p F P
0 g
s
.653 .487 .646 r
.49655 .49412 m .50878 .49234 L p .5059 .49912 L F P
0 g
s
.653 .487 .646 r
.5059 .49912 m .4976 .50032 L .49655 .49412 L p F P
0 g
s
.671 .592 .759 r
.49384 .40351 m .49592 .40857 L .48371 .41043 L p F P
0 g
s
.671 .592 .759 r
.48371 .41043 m .48305 .40884 L .49384 .40351 L p F P
0 g
s
.722 .64 .766 r
.35376 .397 m .35665 .3949 L .35256 .39457 L closepath p F P
0 g
s
.734 .529 .615 r
.33395 .51041 m .33433 .50931 L p .34237 .51587 L F P
0 g
s
.735 .53 .615 r
.33395 .51041 m .33433 .50931 L .33382 .50927 L closepath p F P
0 g
s
.659 .557 .729 r
.50766 .43319 m .51724 .43145 L p .51324 .4405 L F P
0 g
s
.66 .564 .736 r
.51724 .43145 m .51635 .42893 L .50766 .43319 L closepath p F P
0 g
s
.661 .566 .737 r
.51438 .42338 m .51635 .42893 L .50766 .43319 L p F P
0 g
s
.661 .566 .737 r
.50431 .4252 m .51438 .42338 L p .50766 .43319 L F P
0 g
s
.661 .566 .737 r
.50262 .42605 m .50431 .4252 L p .50766 .43319 L F P
0 g
s
.651 .522 .693 r
.51466 .46363 m .52654 .46143 L p .52484 .46907 L F P
0 g
s
.651 .522 .693 r
.52484 .46907 m .51649 .4706 L .51466 .46363 L p F P
0 g
s
.653 .532 .703 r
.52513 .45641 m .52654 .46143 L .51466 .46363 L p F P
0 g
s
.661 .47 .615 r
.47404 .51494 m .47777 .50881 L .47343 .50927 L closepath p F P
0 g
s
.667 .473 .613 r
.47343 .50927 m .47404 .51494 L .47396 .51508 L p F P
0 g
s
.74 .534 .614 r
.33382 .50927 m .32483 .50828 L p .33242 .51498 L F P
0 g
s
.74 .534 .614 r
.33242 .51498 m .33395 .51041 L .33382 .50927 L p F P
0 g
s
.69 .62 .773 r
.4468 .3866 m .43606 .39256 L .43309 .38622 L p F P
0 g
s
.662 .566 .737 r
.50262 .42605 m .50431 .4252 L .50244 .42553 L closepath p F P
0 g
s
.653 .506 .671 r
.50952 .47881 m .51813 .47738 L p .50752 .48595 L F P
0 g
s
.654 .515 .682 r
.51813 .47738 m .51724 .47372 L .50952 .47881 L closepath p F P
0 g
s
.655 .517 .683 r
.51649 .4706 m .51724 .47372 L .50952 .47881 L p F P
0 g
s
.663 .574 .745 r
.50431 .4252 m .50244 .42553 L .4997 .41822 L p F P
0 g
s
.752 .632 .727 r
.29414 .4405 m .29686 .43759 L .29459 .43231 L p F P
0 g
s
.671 .591 .757 r
.49384 .40351 m .48305 .40884 L .48012 .40175 L p F P
0 g
s
.757 .6 .682 r
.29355 .47106 m .28891 .47024 L p .29298 .47802 L F P
0 g
s
.757 .6 .682 r
.29298 .47802 m .29482 .47525 L .29355 .47106 L p F P
0 g
s
.758 .608 .692 r
.29355 .47106 m .2919 .46609 L .28891 .47024 L closepath p F P
0 g
s
.678 .603 .765 r
.47719 .39497 m .46641 .4005 L .46347 .39375 L p F P
0 g
s
.724 .507 .596 r
.36181 .52289 m .35115 .52222 L .35255 .51669 L p F P
0 g
s
.726 .509 .596 r
.34983 .51651 m .35255 .51669 L .35115 .52222 L p F P
0 g
s
.684 .615 .773 r
.46052 .38732 m .46345 .3937 L .45065 .39493 L p F P
0 g
s
.684 .615 .773 r
.45065 .39493 m .44976 .39299 L .46052 .38732 L p F P
0 g
s
.72 .645 .774 r
.36235 .38521 m .36448 .38939 L .35665 .3949 L p F P
0 g
s
.72 .645 .774 r
.35934 .38494 m .36235 .38521 L p .35665 .3949 L F P
0 g
s
.72 .645 .774 r
.35073 .39102 m .35934 .38494 L p .35665 .3949 L F P
0 g
s
.72 .645 .774 r
.35665 .3949 m .35256 .39457 L .35073 .39102 L p F P
0 g
s
.758 .608 .692 r
.28891 .47024 m .2919 .46609 L .29098 .46333 L p F P
0 g
s
.73 .647 .766 r
.33695 .39297 m .34 .39901 L .33552 .40249 L p F P
0 g
s
.73 .647 .766 r
.32621 .40134 m .33695 .39297 L p .33552 .40249 L F P
0 g
s
.73 .647 .766 r
.33552 .40249 m .32622 .40134 L .32621 .40134 L p F P
0 g
s
.757 .6 .682 r
.2958 .4785 m .29482 .47525 L .29298 .47802 L closepath p F P
0 g
s
.742 .549 .632 r
.31727 .50284 m .31789 .50139 L p .32483 .50828 L F P
0 g
s
.744 .55 .632 r
.31727 .50284 m .31789 .50139 L .31703 .50129 L closepath p F P
0 g
s
.67 .461 .594 r
.45596 .5166 m .46123 .51621 L .4616 .52177 L p F P
0 g
s
.67 .461 .594 r
.4616 .52177 m .45393 .52234 L .45596 .5166 L p F P
0 g
s
.753 .629 .723 r
.28599 .43899 m .29414 .4405 L .28797 .44743 L p F P
0 g
s
.752 .632 .727 r
.29256 .43193 m .28599 .43899 L .29414 .4405 L p F P
0 g
s
.752 .632 .727 r
.29459 .43231 m .29256 .43193 L p .29414 .4405 L F P
0 g
s
.657 .549 .72 r
.51324 .4405 m .51988 .43928 L p .52104 .44712 L F P
0 g
s
.658 .556 .728 r
.51988 .43928 m .51927 .43747 L .51324 .4405 L closepath p F P
0 g
s
.659 .557 .729 r
.51724 .43145 m .51927 .43747 L .51324 .4405 L p F P
0 g
s
.758 .608 .692 r
.29098 .46333 m .28539 .4623 L p .28891 .47024 L F P
0 g
s
.758 .616 .702 r
.29098 .46333 m .28894 .45768 L .28539 .4623 L closepath p F P
0 g
s
.754 .615 .704 r
.28894 .45768 m .29051 .45569 L .28807 .45527 L closepath p F P
0 g
s
.753 .621 .714 r
.28595 .44984 m .28797 .44743 L p .29051 .45569 L F P
0 g
s
.753 .621 .714 r
.29051 .45569 m .28807 .45527 L .28595 .44984 L p F P
0 g
s
.734 .529 .615 r
.34237 .51587 m .33445 .51519 L .33395 .51041 L p F P
0 g
s
.74 .533 .614 r
.33445 .51519 m .33395 .51041 L .33242 .51498 L closepath p F P
0 g
s
.756 .591 .672 r
.2958 .4785 m .29298 .47802 L p .29759 .48562 L F P
0 g
s
.756 .591 .672 r
.29759 .48562 m .29769 .48546 L .2958 .4785 L p F P
0 g
s
.662 .572 .744 r
.51438 .42338 m .51343 .42082 L .50431 .4252 L closepath p F P
0 g
s
.663 .574 .745 r
.51128 .41506 m .51343 .42082 L .50431 .4252 L p F P
0 g
s
.663 .574 .745 r
.5032 .41651 m .51128 .41506 L p .50431 .4252 L F P
0 g
s
.663 .574 .745 r
.4997 .41822 m .5032 .41651 L p .50431 .4252 L F P
0 g
s
.749 .553 .631 r
.31703 .50129 m .30891 .50019 L p .31548 .50719 L F P
0 g
s
.749 .553 .631 r
.31548 .50719 m .31727 .50284 L .31703 .50129 L p F P
0 g
s
.732 .514 .596 r
.34237 .51587 m .34983 .51651 L .35017 .52215 L p F P
0 g
s
.726 .509 .596 r
.35115 .52222 m .35017 .52215 L .34983 .51651 L p F P
0 g
s
.691 .463 .573 r
.40811 .52411 m .40937 .5241 L .40866 .52944 L p F P
0 g
s
.691 .463 .573 r
.40866 .52944 m .40818 .52945 L .40811 .52411 L p F P
0 g
s
.698 .469 .573 r
.39656 .52407 m .40811 .52411 L .40818 .52945 L p F P
0 g
s
.69 .462 .572 r
.40937 .5241 m .42185 .5239 L .42193 .52923 L p F P
0 g
s
.69 .462 .572 r
.42193 .52923 m .40866 .52944 L .40937 .5241 L p F P
0 g
s
.698 .469 .573 r
.40818 .52945 m .39587 .5294 L .39656 .52407 L p F P
0 g
s
.699 .47 .573 r
.39409 .52406 m .39656 .52407 L .39587 .5294 L p F P
0 g
s
.699 .47 .573 r
.39587 .5294 m .39414 .52939 L .39409 .52406 L p F P
0 g
s
.705 .475 .573 r
.38445 .52384 m .39409 .52406 L .39414 .52939 L p F P
0 g
s
.661 .469 .615 r
.47777 .50881 m .48603 .50789 L p .47405 .51507 L F P
0 g
s
.661 .469 .615 r
.47405 .51507 m .47404 .51494 L .47777 .50881 L p F P
0 g
s
.65 .495 .66 r
.50752 .48595 m .51957 .48396 L p .51457 .4914 L F P
0 g
s
.65 .495 .66 r
.51457 .4914 m .50878 .49234 L .50752 .48595 L p F P
0 g
s
.653 .506 .671 r
.51813 .47738 m .51957 .48396 L .50752 .48595 L p F P
0 g
s
.725 .647 .771 r
.35256 .39457 m .35073 .39102 L .34671 .39395 L closepath p F P
0 g
s
.727 .644 .766 r
.34671 .39395 m .34 .39901 L .33695 .39297 L p F P
0 g
s
.758 .616 .702 r
.28539 .4623 m .28894 .45768 L .28807 .45527 L p F P
0 g
s
.683 .457 .572 r
.42185 .5239 m .42305 .52386 L .42231 .52922 L p F P
0 g
s
.683 .457 .572 r
.42231 .52922 m .42193 .52923 L .42185 .5239 L p F P
0 g
s
.684 .615 .772 r
.46052 .38732 m .44976 .39299 L .4468 .3866 L p F P
0 g
s
.649 .512 .683 r
.51724 .47372 m .52484 .46907 L .51649 .4706 L closepath p F P
0 g
s
.681 .455 .572 r
.42305 .52386 m .43533 .52343 L .43543 .52875 L p F P
0 g
s
.681 .455 .572 r
.43543 .52875 m .42231 .52922 L .42305 .52386 L p F P
0 g
s
.663 .575 .745 r
.4997 .41822 m .5032 .41651 L .49931 .41719 L closepath p F P
0 g
s
.705 .475 .573 r
.39414 .52939 m .38379 .52916 L .38445 .52384 L p F P
0 g
s
.707 .476 .573 r
.37977 .52372 m .38445 .52384 L .38379 .52916 L p F P
0 g
s
.664 .457 .594 r
.46123 .51621 m .47396 .51508 L .47178 .52087 L p F P
0 g
s
.664 .457 .594 r
.47178 .52087 m .4616 .52177 L .46123 .51621 L p F P
0 g
s
.7 .634 .779 r
.41871 .38659 m .40583 .3868 L .40567 .38649 L p F P
0 g
s
.704 .636 .778 r
.40583 .3868 m .40567 .38649 L .40516 .3868 L closepath p F P
0 g
s
.706 .633 .773 r
.39195 .38711 m .39262 .38669 L .40516 .3868 L p F P
0 g
s
.705 .638 .78 r
.40267 .38056 m .39262 .38669 L .40516 .3868 L p F P
0 g
s
.705 .638 .78 r
.40516 .3868 m .40567 .38649 L .40267 .38056 L p F P
0 g
s
.706 .635 .775 r
.39195 .38711 m .39262 .38669 L .39173 .38667 L closepath p F P
0 g
s
.711 .637 .773 r
.39173 .38667 m .39195 .38711 L p .37822 .38809 L F P
0 g
s
.742 .549 .632 r
.32483 .50828 m .31798 .50752 L .31727 .50284 L p F P
0 g
s
.748 .553 .631 r
.31798 .50752 m .31727 .50284 L .31548 .50719 L closepath p F P
0 g
s
.758 .616 .702 r
.28807 .45527 m .28241 .45418 L p .28539 .4623 L F P
0 g
s
.758 .624 .711 r
.28807 .45527 m .28595 .44984 L .28241 .45418 L closepath p F P
0 g
s
.664 .582 .752 r
.5032 .41651 m .49931 .41719 L .49677 .41073 L p F P
0 g
s
.701 .635 .78 r
.41639 .3802 m .40567 .38649 L .40267 .38056 L p F P
0 g
s
.7 .634 .779 r
.40567 .38649 m .41639 .3802 L p .41871 .38659 L F P
0 g
s
.707 .476 .573 r
.38379 .52916 m .37981 .52906 L .37977 .52372 L p F P
0 g
s
.713 .482 .573 r
.3729 .52344 m .37977 .52372 L .37981 .52906 L p F P
0 g
s
.756 .591 .672 r
.29774 .48565 m .29769 .48546 L .29759 .48562 L closepath p F P
0 g
s
.752 .578 .66 r
.30294 .493 m .29935 .49248 L .29774 .48565 L p F P
0 g
s
.757 .582 .658 r
.29759 .48562 m .29774 .48565 L .29935 .49248 L p F P
0 g
s
.705 .64 .781 r
.40042 .37612 m .40267 .38056 L .39262 .38669 L p F P
0 g
s
.705 .64 .781 r
.39734 .37608 m .40042 .37612 L p .39262 .38669 L F P
0 g
s
.705 .64 .781 r
.38894 .38123 m .39734 .37608 L p .39262 .38669 L F P
0 g
s
.705 .64 .781 r
.39262 .38669 m .39173 .38667 L .38894 .38123 L p F P
0 g
s
.743 .639 .745 r
.30466 .42007 m .30784 .41713 L .30291 .41634 L closepath p F P
0 g
s
.741 .645 .753 r
.31488 .40914 m .31545 .41034 L .30784 .41713 L p F P
0 g
s
.741 .645 .753 r
.30801 .40799 m .31488 .40914 L p .30784 .41713 L F P
0 g
s
.741 .645 .753 r
.30161 .41369 m .30801 .40799 L p .30784 .41713 L F P
0 g
s
.741 .645 .753 r
.30784 .41713 m .30291 .41634 L .30161 .41369 L p F P
0 g
s
.756 .591 .672 r
.29298 .47802 m .28924 .48421 L .29759 .48562 L p F P
0 g
s
.758 .594 .673 r
.28471 .47658 m .29298 .47802 L .28924 .48421 L p F P
0 g
s
.757 .6 .682 r
.28891 .47024 m .28471 .47658 L .29298 .47802 L p F P
0 g
s
.716 .641 .773 r
.37725 .38614 m .37822 .38809 L p .36448 .38939 L F P
0 g
s
.711 .637 .773 r
.37822 .38809 m .38096 .38629 L .39173 .38667 L p F P
0 g
s
.711 .639 .774 r
.37822 .38809 m .38096 .38629 L .37725 .38614 L closepath p F P
0 g
s
.71 .642 .779 r
.39173 .38667 m .38894 .38123 L .38096 .38629 L closepath p F P
0 g
s
.747 .641 .743 r
.29989 .42463 m .30466 .42007 L .30291 .41634 L p F P
0 g
s
.757 .582 .658 r
.29935 .49248 m .29433 .49167 L .29759 .48562 L p F P
0 g
s
.758 .584 .66 r
.28924 .48421 m .29759 .48562 L .29433 .49167 L p F P
0 g
s
.752 .639 .735 r
.29459 .43231 m .29383 .43063 L .29256 .43193 L closepath p F P
0 g
s
.699 .632 .778 r
.41957 .38657 m .41938 .38619 L .41871 .38659 L closepath p F P
0 g
s
.7 .634 .779 r
.41639 .3802 m .41938 .38619 L .41871 .38659 L p F P
0 g
s
.738 .642 .752 r
.31545 .41034 m .31655 .40939 L .31488 .40914 L closepath p F P
0 g
s
.694 .63 .78 r
.43012 .38016 m .43299 .386 L .41957 .38657 L p F P
0 g
s
.694 .63 .78 r
.41957 .38657 m .41938 .38619 L .43012 .38016 L p F P
0 g
s
.749 .637 .737 r
.29989 .42463 m .29383 .43063 L .29078 .42396 L p F P
0 g
s
.749 .637 .737 r
.29078 .42396 m .29158 .42316 L .29989 .42463 L p F P
0 g
s
.747 .641 .743 r
.29941 .4157 m .29158 .42316 L .29989 .42463 L p F P
0 g
s
.747 .641 .743 r
.30291 .41634 m .29941 .4157 L p .29989 .42463 L F P
0 g
s
.736 .647 .76 r
.31746 .4 m .32621 .40134 L .31655 .40939 L p F P
0 g
s
.736 .647 .76 r
.31239 .40422 m .31746 .4 L p .31655 .40939 L F P
0 g
s
.736 .647 .76 r
.31655 .40939 m .31488 .40914 L .31239 .40422 L p F P
0 g
s
.755 .623 .713 r
.28595 .44984 m .28797 .44743 L .28478 .44686 L closepath p F P
0 g
s
.753 .629 .723 r
.28293 .44242 m .28599 .43899 L p .28797 .44743 L F P
0 g
s
.753 .629 .723 r
.28797 .44743 m .28478 .44686 L .28293 .44242 L p F P
0 g
s
.759 .604 .685 r
.28074 .46876 m .28891 .47024 L .28471 .47658 L p F P
0 g
s
.758 .608 .692 r
.28539 .4623 m .28074 .46876 L .28891 .47024 L p F P
0 g
s
.649 .512 .683 r
.51813 .47738 m .51724 .47372 L .52484 .46907 L p F P
0 g
s
.74 .534 .614 r
.32483 .50828 m .3229 .51394 L .33242 .51498 L p F P
0 g
s
.742 .536 .616 r
.31798 .50752 m .32483 .50828 L .3229 .51394 L p F P
0 g
s
.695 .631 .78 r
.43012 .38016 m .41938 .38619 L .41639 .3802 L p F P
0 g
s
.733 .514 .596 r
.33445 .51519 m .34237 .51587 L .34103 .52137 L p F P
0 g
s
.732 .514 .596 r
.35017 .52215 m .34103 .52137 L .34237 .51587 L p F P
0 g
s
.75 .568 .648 r
.30046 .498 m .30294 .493 L p .30891 .50019 L F P
0 g
s
.752 .569 .648 r
.30046 .498 m .30294 .493 L .29935 .49248 L closepath p F P
0 g
s
.713 .482 .573 r
.37981 .52906 m .37226 .52874 L .3729 .52344 L p F P
0 g
s
.714 .482 .573 r
.36514 .52309 m .3729 .52344 L .37226 .52874 L p F P
0 g
s
.675 .45 .572 r
.43533 .52343 m .43782 .5233 L .43704 .52867 L p F P
0 g
s
.675 .45 .572 r
.43704 .52867 m .43543 .52875 L .43533 .52343 L p F P
0 g
s
.716 .641 .773 r
.36448 .38939 m .36992 .38569 L .37725 .38614 L p F P
0 g
s
.716 .642 .774 r
.36448 .38939 m .36992 .38569 L .36235 .38521 L closepath p F P
0 g
s
.726 .648 .772 r
.34768 .38515 m .33702 .39292 L .34671 .39395 L p F P
0 g
s
.726 .648 .772 r
.34671 .39395 m .35073 .39102 L .34768 .38515 L p F P
0 g
s
.727 .644 .766 r
.33695 .39297 m .33702 .39292 L .34671 .39395 L p F P
0 g
s
.752 .639 .736 r
.29256 .43193 m .29383 .43063 L .29078 .42396 L p F P
0 g
s
.742 .649 .758 r
.31488 .40914 m .31239 .40422 L .30801 .40799 L closepath p F P
0 g
s
.671 .591 .757 r
.49225 .39963 m .49384 .40351 L p .48012 .40175 L F P
0 g
s
.671 .591 .757 r
.48012 .40175 m .48094 .40134 L .49225 .39963 L p F P
0 g
s
.672 .595 .76 r
.48012 .40175 m .48094 .40134 L .48001 .40148 L closepath p F P
0 g
s
.71 .644 .781 r
.38617 .37586 m .38894 .38123 L .38096 .38629 L p F P
0 g
s
.71 .644 .781 r
.38523 .37582 m .38617 .37586 L p .38096 .38629 L F P
0 g
s
.71 .644 .781 r
.3752 .38221 m .38523 .37582 L p .38096 .38629 L F P
0 g
s
.71 .644 .781 r
.38096 .38629 m .37725 .38614 L .3752 .38221 L p F P
0 g
s
.673 .448 .572 r
.43782 .5233 m .44858 .52271 L .44868 .52804 L p F P
0 g
s
.673 .448 .572 r
.44868 .52804 m .43704 .52867 L .43782 .5233 L p F P
0 g
s
.673 .601 .767 r
.48094 .40134 m .48001 .40148 L .47719 .39497 L p F P
0 g
s
.753 .636 .731 r
.28455 .43037 m .29256 .43193 L .28599 .43899 L p F P
0 g
s
.752 .639 .736 r
.29078 .42396 m .28455 .43037 L .29256 .43193 L p F P
0 g
s
.758 .624 .711 r
.28241 .45418 m .28595 .44984 L .28478 .44686 L p F P
0 g
s
.656 .548 .72 r
.52231 .44689 m .5222 .44653 L .52104 .44712 L closepath p F P
0 g
s
.657 .549 .72 r
.51988 .43928 m .5222 .44653 L .52104 .44712 L p F P
0 g
s
.759 .612 .696 r
.27732 .46078 m .28539 .4623 L .28074 .46876 L p F P
0 g
s
.758 .616 .702 r
.28241 .45418 m .27732 .46078 L .28539 .4623 L p F P
0 g
s
.715 .646 .779 r
.37725 .38614 m .3752 .38221 L .36992 .38569 L closepath p F P
0 g
s
.671 .599 .766 r
.49225 .39963 m .49091 .39652 L .48094 .40134 L closepath p F P
0 g
s
.673 .601 .767 r
.48827 .39036 m .49091 .39652 L .48094 .40134 L p F P
0 g
s
.673 .601 .767 r
.48588 .39072 m .48827 .39036 L p .48094 .40134 L F P
0 g
s
.673 .601 .767 r
.47719 .39497 m .48588 .39072 L p .48094 .40134 L F P
0 g
s
.735 .649 .764 r
.32622 .40134 m .32621 .40134 L .32621 .40134 L closepath p F P
0 g
s
.736 .651 .765 r
.32315 .39543 m .31746 .4 L .32621 .40134 L p F P
0 g
s
.736 .651 .765 r
.32621 .40134 m .32621 .40134 L .32315 .39543 L p F P
0 g
s
.733 .65 .767 r
.33695 .39297 m .32621 .40134 L .32315 .39543 L p F P
0 g
s
.65 .474 .632 r
.4976 .50032 m .5059 .49912 L .49947 .50618 L p F P
0 g
s
.65 .474 .632 r
.49947 .50618 m .49845 .50633 L .4976 .50032 L p F P
0 g
s
.656 .477 .63 r
.4976 .50032 m .49845 .50633 L .48603 .50789 L p F P
0 g
s
.678 .603 .765 r
.47596 .39215 m .47719 .39497 L p .46347 .39375 L F P
0 g
s
.678 .603 .765 r
.46347 .39375 m .46361 .39368 L .47596 .39215 L p F P
0 g
s
.679 .607 .768 r
.46347 .39375 m .46361 .39368 L .46345 .3937 L closepath p F P
0 g
s
.679 .613 .774 r
.46361 .39368 m .46345 .3937 L .46052 .38732 L p F P
0 g
s
.653 .463 .614 r
.48603 .50789 m .49845 .50633 L p .49515 .51261 L F P
0 g
s
.653 .463 .614 r
.49515 .51261 m .48665 .51368 L .48603 .50789 L p F P
0 g
s
.661 .469 .615 r
.48603 .50789 m .48665 .51368 L .47405 .51507 L p F P
0 g
s
.678 .61 .773 r
.47596 .39215 m .47424 .38836 L .46361 .39368 L closepath p F P
0 g
s
.679 .613 .774 r
.47156 .38244 m .47424 .38836 L .46361 .39368 L p F P
0 g
s
.679 .613 .774 r
.46972 .38267 m .47156 .38244 L p .46361 .39368 L F P
0 g
s
.679 .613 .774 r
.46052 .38732 m .46972 .38267 L p .46361 .39368 L F P
0 g
s
.663 .58 .751 r
.51128 .41506 m .51051 .41307 L .5032 .41651 L closepath p F P
0 g
s
.664 .582 .752 r
.50793 .40647 m .51051 .41307 L .5032 .41651 L p F P
0 g
s
.664 .582 .752 r
.50436 .4071 m .50793 .40647 L p .5032 .41651 L F P
0 g
s
.664 .582 .752 r
.49677 .41073 m .50436 .4071 L p .5032 .41651 L F P
0 g
s
.69 .62 .773 r
.4461 .3851 m .4468 .3866 L p .43309 .38622 L F P
0 g
s
.69 .62 .773 r
.43309 .38622 m .43354 .38597 L .4461 .3851 L p F P
0 g
s
.691 .623 .775 r
.43309 .38622 m .43354 .38597 L .43299 .386 L closepath p F P
0 g
s
.714 .482 .573 r
.37226 .52874 m .36517 .52843 L .36514 .52309 L p F P
0 g
s
.721 .488 .572 r
.36181 .52289 m .36514 .52309 L .36517 .52843 L p F P
0 g
s
.646 .501 .672 r
.51813 .47738 m .53001 .47519 L p .52645 .48271 L F P
0 g
s
.646 .501 .672 r
.52645 .48271 m .51957 .48396 L .51813 .47738 L p F P
0 g
s
.649 .512 .683 r
.52838 .46842 m .53001 .47519 L .51813 .47738 L p F P
0 g
s
.649 .512 .683 r
.52484 .46907 m .52838 .46842 L p .51813 .47738 L F P
0 g
s
.69 .628 .782 r
.43354 .38597 m .43299 .386 L .43012 .38016 L p F P
0 g
s
.665 .582 .753 r
.49677 .41073 m .50436 .4071 L .49592 .40857 L closepath p F P
0 g
s
.651 .546 .722 r
.5222 .44653 m .51988 .43928 L .53162 .43689 L p F P
0 g
s
.653 .553 .73 r
.53011 .4324 m .53162 .43689 L .51988 .43928 L p F P
0 g
s
.653 .553 .73 r
.51988 .43928 m .51927 .43747 L .53011 .4324 L p F P
0 g
s
.651 .545 .722 r
.52231 .44689 m .5222 .44653 L .53304 .44136 L p F P
0 g
s
.651 .546 .722 r
.53162 .43689 m .53304 .44136 L .5222 .44653 L p F P
0 g
s
.651 .545 .722 r
.53304 .44136 m .53404 .44449 L .52231 .44689 L p F P
0 g
s
.649 .536 .712 r
.52231 .44689 m .53404 .44449 L p .53244 .45266 L F P
0 g
s
.649 .536 .712 r
.53244 .45266 m .52453 .45426 L .52231 .44689 L p F P
0 g
s
.749 .553 .631 r
.30891 .50019 m .30649 .50599 L .31548 .50719 L p F P
0 g
s
.751 .556 .632 r
.30067 .49906 m .30891 .50019 L .30649 .50599 L p F P
0 g
s
.75 .568 .648 r
.30891 .50019 m .30067 .49906 L .30046 .498 L p F P
0 g
s
.689 .626 .78 r
.4461 .3851 m .44384 .38043 L .43354 .38597 L closepath p F P
0 g
s
.69 .628 .782 r
.44109 .37478 m .44384 .38043 L .43354 .38597 L p F P
0 g
s
.69 .628 .782 r
.43988 .37485 m .44109 .37478 L p .43354 .38597 L F P
0 g
s
.69 .628 .782 r
.43012 .38016 m .43988 .37485 L p .43354 .38597 L F P
0 g
s
.758 .624 .711 r
.28478 .44686 m .27995 .44589 L p .28241 .45418 L F P
0 g
s
.758 .631 .72 r
.28478 .44686 m .28293 .44242 L .27995 .44589 L closepath p F P
0 g
s
.722 .647 .774 r
.35934 .38494 m .35073 .39102 L .34768 .38515 L p F P
0 g
s
.653 .554 .73 r
.529 .42907 m .53011 .4324 L .51927 .43747 L p F P
0 g
s
.653 .554 .73 r
.51927 .43747 m .51724 .43145 L .529 .42907 L p F P
0 g
s
.756 .572 .647 r
.29935 .49248 m .29433 .49167 L p .29999 .49896 L F P
0 g
s
.756 .572 .647 r
.29999 .49896 m .30046 .498 L .29935 .49248 L p F P
0 g
s
.747 .647 .75 r
.30291 .41634 m .30161 .41369 L .29941 .4157 L closepath p F P
0 g
s
.721 .488 .572 r
.36517 .52843 m .36119 .52819 L .36181 .52289 L p F P
0 g
s
.722 .489 .573 r
.35115 .52222 m .36181 .52289 L .36119 .52819 L p F P
0 g
s
.655 .562 .737 r
.52719 .42395 m .529 .42907 L .51724 .43145 L p F P
0 g
s
.655 .562 .737 r
.51724 .43145 m .51635 .42893 L .52719 .42395 L p F P
0 g
s
.647 .482 .646 r
.50938 .49588 m .51457 .4914 L .50878 .49234 L closepath p F P
0 g
s
.653 .487 .646 r
.50878 .49234 m .50938 .49588 L .5059 .49912 L p F P
0 g
s
.733 .514 .596 r
.34103 .52137 m .33478 .52083 L .33445 .51519 L p F P
0 g
s
.739 .519 .595 r
.33242 .51498 m .33445 .51519 L .33478 .52083 L p F P
0 g
s
.647 .528 .704 r
.52513 .45641 m .53244 .45266 L .52453 .45426 L closepath p F P
0 g
s
.666 .589 .76 r
.50436 .4071 m .49592 .40857 L .49384 .40351 L p F P
0 g
s
.715 .648 .781 r
.37217 .37643 m .3752 .38221 L .36992 .38569 L p F P
0 g
s
.715 .648 .781 r
.36145 .3835 m .37217 .37643 L p .36992 .38569 L F P
0 g
s
.715 .648 .781 r
.36992 .38569 m .36235 .38521 L .36145 .3835 L p F P
0 g
s
.755 .63 .722 r
.28293 .44242 m .28599 .43899 L .28111 .43807 L closepath p F P
0 g
s
.753 .636 .731 r
.2799 .43534 m .28455 .43037 L p .28599 .43899 L F P
0 g
s
.753 .636 .731 r
.28599 .43899 m .28111 .43807 L .2799 .43534 L p F P
0 g
s
.742 .536 .616 r
.3229 .51394 m .31864 .51347 L .31798 .50752 L p F P
0 g
s
.749 .541 .614 r
.31548 .50719 m .31798 .50752 L .31864 .51347 L p F P
0 g
s
.666 .473 .614 r
.47405 .51507 m .47404 .51494 L .47396 .51508 L closepath p F P
0 g
s
.76 .621 .705 r
.27444 .45261 m .28241 .45418 L .27732 .46078 L p F P
0 g
s
.758 .624 .711 r
.27995 .44589 m .27444 .45261 L .28241 .45418 L p F P
0 g
s
.667 .443 .572 r
.44858 .52271 m .45393 .52234 L .45312 .52773 L p F P
0 g
s
.667 .443 .572 r
.45312 .52773 m .44868 .52804 L .44858 .52271 L p F P
0 g
s
.655 .562 .738 r
.52615 .42101 m .52719 .42395 L .51635 .42893 L p F P
0 g
s
.655 .562 .738 r
.51635 .42893 m .51438 .42338 L .52615 .42101 L p F P
0 g
s
.662 .455 .593 r
.47396 .51508 m .47405 .51507 L .47443 .52062 L p F P
0 g
s
.662 .455 .593 r
.47443 .52062 m .47178 .52087 L .47396 .51508 L p F P
0 g
s
.655 .449 .594 r
.47443 .52062 m .47405 .51507 L .48665 .51368 L p F P
0 g
s
.647 .527 .703 r
.52654 .46143 m .52513 .45641 L .53244 .45266 L p F P
0 g
s
.739 .519 .595 r
.33478 .52083 m .33114 .52046 L .33242 .51498 L p F P
0 g
s
.74 .521 .596 r
.3229 .51394 m .33242 .51498 L .33114 .52046 L p F P
0 g
s
.684 .615 .772 r
.45895 .38391 m .46052 .38732 L p .4468 .3866 L F P
0 g
s
.684 .615 .772 r
.4468 .3866 m .45034 .38473 L .45895 .38391 L p F P
0 g
s
.685 .618 .775 r
.4468 .3866 m .45034 .38473 L .4461 .3851 L closepath p F P
0 g
s
.759 .632 .72 r
.27995 .44589 m .28293 .44242 L .28111 .43807 L p F P
0 g
s
.749 .541 .614 r
.31864 .51347 m .31365 .51283 L .31548 .50719 L p F P
0 g
s
.749 .543 .616 r
.30649 .50599 m .31548 .50719 L .31365 .51283 L p F P
0 g
s
.728 .646 .768 r
.33695 .39297 m .33702 .39292 L .33692 .39291 L closepath p F P
0 g
s
.733 .65 .767 r
.33692 .39291 m .33695 .39297 L p .32315 .39543 L F P
0 g
s
.726 .652 .775 r
.34697 .3838 m .34768 .38515 L .33702 .39292 L p F P
0 g
s
.726 .652 .775 r
.33975 .38293 m .34697 .3838 L p .33702 .39292 L F P
0 g
s
.726 .652 .775 r
.33389 .3872 m .33975 .38293 L p .33702 .39292 L F P
0 g
s
.726 .652 .775 r
.33702 .39292 m .33692 .39291 L .33389 .3872 L p F P
0 g
s
.657 .57 .745 r
.52427 .41593 m .52615 .42101 L .51438 .42338 L p F P
0 g
s
.657 .57 .745 r
.51438 .42338 m .51343 .42082 L .52427 .41593 L p F P
0 g
s
.733 .65 .767 r
.32315 .39543 m .32796 .39168 L .33692 .39291 L p F P
0 g
s
.731 .654 .772 r
.33692 .39291 m .33389 .3872 L .32796 .39168 L closepath p F P
0 g
s
.65 .521 .693 r
.52838 .46842 m .52807 .46723 L .52484 .46907 L closepath p F P
0 g
s
.651 .522 .693 r
.52654 .46143 m .52807 .46723 L .52484 .46907 L p F P
0 g
s
.645 .518 .695 r
.52807 .46723 m .52654 .46143 L .53827 .45904 L p F P
0 g
s
.647 .527 .703 r
.53626 .45188 m .53827 .45904 L .52654 .46143 L p F P
0 g
s
.647 .527 .703 r
.53244 .45266 m .53626 .45188 L p .52654 .46143 L F P
0 g
s
.665 .442 .571 r
.45393 .52234 m .4616 .52177 L .46172 .5271 L p F P
0 g
s
.665 .442 .571 r
.46172 .5271 m .45312 .52773 L .45393 .52234 L p F P
0 g
s
.743 .646 .752 r
.30801 .40799 m .30161 .41369 L .29854 .40748 L p F P
0 g
s
.747 .648 .751 r
.29941 .4157 m .30161 .41369 L .29854 .40748 L p F P
0 g
s
.747 .648 .751 r
.29854 .40748 m .29128 .41416 L .29941 .4157 L p F P
0 g
s
.748 .645 .747 r
.29128 .41416 m .29941 .4157 L .29158 .42316 L p F P
0 g
s
.72 .65 .778 r
.36235 .38521 m .36145 .3835 L .35934 .38494 L closepath p F P
0 g
s
.758 .584 .66 r
.29433 .49167 m .28591 .49028 L .28924 .48421 L p F P
0 g
s
.759 .585 .661 r
.28089 .48279 m .28924 .48421 L .28591 .49028 L p F P
0 g
s
.758 .594 .673 r
.28924 .48421 m .28089 .48279 L .28471 .47658 L p F P
0 g
s
.76 .596 .674 r
.27861 .47549 m .28471 .47658 L .28089 .48279 L p F P
0 g
s
.759 .604 .685 r
.27785 .47308 m .28074 .46876 L p .28471 .47658 L F P
0 g
s
.759 .604 .685 r
.28471 .47658 m .27861 .47549 L .27785 .47308 L p F P
0 g
s
.743 .646 .752 r
.29854 .40748 m .29958 .40655 L .30801 .40799 L p F P
0 g
s
.742 .65 .758 r
.30877 .39864 m .29958 .40655 L .30801 .40799 L p F P
0 g
s
.742 .65 .758 r
.30964 .3988 m .30877 .39864 L p .30801 .40799 L F P
0 g
s
.742 .65 .758 r
.30801 .40799 m .31239 .40422 L .30964 .3988 L p F P
0 g
s
.685 .624 .782 r
.45034 .38473 m .4461 .3851 L .44384 .38043 L p F P
0 g
s
.722 .489 .573 r
.36119 .52819 m .3505 .52752 L .35115 .52222 L p F P
0 g
s
.723 .491 .573 r
.35017 .52215 m .35115 .52222 L .3505 .52752 L p F P
0 g
s
.657 .57 .746 r
.52307 .4127 m .52427 .41593 L .51343 .42082 L p F P
0 g
s
.657 .57 .746 r
.51343 .42082 m .51128 .41506 L .52307 .4127 L p F P
0 g
s
.706 .641 .782 r
.38894 .38123 m .39734 .37608 L .38617 .37586 L closepath p F P
0 g
s
.75 .639 .738 r
.29078 .42396 m .29158 .42316 L .29031 .42293 L closepath p F P
0 g
s
.748 .645 .747 r
.28772 .41757 m .29128 .41416 L p .29158 .42316 L F P
0 g
s
.748 .645 .747 r
.29158 .42316 m .29031 .42293 L .28772 .41757 L p F P
0 g
s
.673 .602 .768 r
.47719 .39497 m .48588 .39072 L .47596 .39215 L closepath p F P
0 g
s
.753 .643 .739 r
.29031 .42293 m .29078 .42396 L .28455 .43037 L p F P
0 g
s
.723 .491 .573 r
.3505 .52752 m .35019 .5275 L .35017 .52215 L p F P
0 g
s
.731 .496 .573 r
.34103 .52137 m .35017 .52215 L .35019 .5275 L p F P
0 g
s
.701 .635 .78 r
.4143 .37602 m .41639 .3802 L p .40267 .38056 L F P
0 g
s
.701 .635 .78 r
.40267 .38056 m .41029 .37606 L .4143 .37602 L p F P
0 g
s
.701 .637 .782 r
.40267 .38056 m .41029 .37606 L .40042 .37612 L closepath p F P
0 g
s
.758 .575 .649 r
.28591 .49028 m .29433 .49167 L .29151 .49759 L p F P
0 g
s
.756 .572 .647 r
.29433 .49167 m .29151 .49759 L .29999 .49896 L p F P
0 g
s
.738 .648 .76 r
.31239 .40422 m .31746 .4 L .30964 .3988 L closepath p F P
0 g
s
.666 .589 .76 r
.49384 .40351 m .50466 .39844 L p .50436 .4071 L F P
0 g
s
.666 .59 .76 r
.50429 .39755 m .50466 .39844 L .49384 .40351 L p F P
0 g
s
.666 .59 .76 r
.49384 .40351 m .49225 .39963 L .50429 .39755 L p F P
0 g
s
.761 .605 .685 r
.27785 .47308 m .28074 .46876 L .27623 .46793 L closepath p F P
0 g
s
.759 .612 .696 r
.27491 .46411 m .27732 .46078 L p .28074 .46876 L F P
0 g
s
.759 .612 .696 r
.28074 .46876 m .27623 .46793 L .27491 .46411 L p F P
0 g
s
.756 .572 .647 r
.30067 .49906 m .30046 .498 L .29999 .49896 L closepath p F P
0 g
s
.712 .647 .783 r
.38523 .37582 m .3752 .38221 L .37217 .37643 L p F P
0 g
s
.722 .647 .774 r
.34768 .38515 m .34929 .38402 L .35934 .38494 L p F P
0 g
s
.721 .652 .78 r
.3584 .37781 m .34929 .38402 L .35934 .38494 L p F P
0 g
s
.721 .652 .78 r
.35934 .38494 m .36145 .3835 L .3584 .37781 L p F P
0 g
s
.759 .632 .72 r
.27801 .43742 m .27211 .44428 L .27995 .44589 L p F P
0 g
s
.759 .632 .72 r
.28111 .43807 m .27801 .43742 L p .27995 .44589 L F P
0 g
s
.76 .628 .715 r
.27211 .44428 m .27995 .44589 L .27444 .45261 L p F P
0 g
s
.65 .495 .66 r
.51957 .48396 m .52019 .48711 L .51457 .4914 L p F P
0 g
s
.643 .49 .66 r
.52019 .48711 m .52645 .48271 L .51957 .48396 L closepath p F P
0 g
s
.646 .482 .646 r
.50983 .49854 m .50938 .49588 L .51457 .4914 L p F P
0 g
s
.652 .485 .645 r
.50983 .49854 m .50938 .49588 L .5059 .49912 L closepath p F P
0 g
s
.648 .471 .63 r
.5059 .49912 m .50983 .49854 L .51067 .50452 L p F P
0 g
s
.648 .471 .63 r
.51067 .50452 m .49947 .50618 L .5059 .49912 L p F P
0 g
s
.753 .643 .739 r
.28365 .42156 m .29031 .42293 L p .28455 .43037 L F P
0 g
s
.753 .647 .744 r
.29031 .42293 m .28772 .41757 L .28365 .42156 L closepath p F P
0 g
s
.695 .631 .78 r
.42785 .37556 m .43012 .38016 L p .41639 .3802 L F P
0 g
s
.695 .631 .78 r
.41639 .3802 m .42435 .37569 L .42785 .37556 L p F P
0 g
s
.696 .633 .782 r
.41639 .3802 m .42435 .37569 L .4143 .37602 L closepath p F P
0 g
s
.751 .556 .632 r
.30649 .50599 m .30166 .50534 L .30067 .49906 L p F P
0 g
s
.757 .56 .631 r
.29999 .49896 m .30067 .49906 L .30166 .50534 L p F P
0 g
s
.736 .653 .767 r
.32068 .39067 m .32315 .39543 L .31746 .4 L p F P
0 g
s
.736 .653 .767 r
.319 .3904 m .32068 .39067 L p .31746 .4 L F P
0 g
s
.736 .653 .767 r
.30932 .39819 m .319 .3904 L p .31746 .4 L F P
0 g
s
.736 .653 .767 r
.31746 .4 m .30964 .3988 L .30932 .39819 L p F P
0 g
s
.758 .638 .728 r
.28111 .43807 m .2799 .43534 L .27801 .43742 L closepath p F P
0 g
s
.646 .482 .646 r
.51457 .4914 m .52083 .49035 L p .50983 .49854 L F P
0 g
s
.648 .493 .659 r
.52083 .49035 m .52019 .48711 L .51457 .4914 L closepath p F P
0 g
s
.684 .622 .78 r
.45895 .38391 m .45756 .38101 L .45034 .38473 L closepath p F P
0 g
s
.685 .624 .782 r
.4546 .37485 m .45756 .38101 L .45034 .38473 L p F P
0 g
s
.685 .624 .782 r
.44384 .38043 m .4546 .37485 L p .45034 .38473 L F P
0 g
s
.644 .518 .694 r
.52838 .46842 m .52807 .46723 L .53892 .46153 L p F P
0 g
s
.645 .518 .695 r
.53827 .45904 m .53892 .46153 L .52807 .46723 L p F P
0 g
s
.686 .44 .544 r
.40818 .52945 m .40866 .52944 L .40901 .53448 L p F P
0 g
s
.686 .44 .544 r
.40901 .53448 m .40793 .53449 L .40818 .52945 L p F P
0 g
s
.693 .446 .544 r
.39587 .5294 m .40818 .52945 L .40793 .53449 L p F P
0 g
s
.685 .439 .544 r
.40866 .52944 m .42193 .52923 L .42171 .53428 L p F P
0 g
s
.685 .439 .544 r
.42171 .53428 m .40901 .53448 L .40866 .52944 L p F P
0 g
s
.717 .651 .782 r
.37217 .37643 m .36145 .3835 L .3584 .37781 L p F P
0 g
s
.68 .614 .775 r
.46052 .38732 m .46972 .38267 L .45895 .38391 L closepath p F P
0 g
s
.757 .56 .631 r
.30166 .50534 m .2977 .50472 L .29999 .49896 L p F P
0 g
s
.758 .563 .632 r
.29151 .49759 m .29999 .49896 L .2977 .50472 L p F P
0 g
s
.755 .637 .73 r
.2799 .43534 m .28455 .43037 L .27702 .42888 L closepath p F P
0 g
s
.753 .643 .739 r
.27685 .42851 m .28365 .42156 L p .28455 .43037 L F P
0 g
s
.753 .643 .739 r
.28455 .43037 m .27702 .42888 L .27685 .42851 L p F P
0 g
s
.693 .446 .544 r
.40793 .53449 m .39618 .53445 L .39587 .5294 L p F P
0 g
s
.694 .447 .544 r
.39414 .52939 m .39587 .5294 L .39618 .53445 L p F P
0 g
s
.659 .437 .571 r
.4616 .52177 m .47178 .52087 L .47092 .52628 L p F P
0 g
s
.659 .437 .571 r
.47092 .52628 m .46172 .5271 L .4616 .52177 L p F P
0 g
s
.694 .447 .544 r
.39618 .53445 m .39388 .53444 L .39414 .52939 L p F P
0 g
s
.701 .453 .544 r
.38379 .52916 m .39414 .52939 L .39388 .53444 L p F P
0 g
s
.641 .507 .683 r
.53001 .47519 m .52838 .46842 L .54009 .46601 L p F P
0 g
s
.644 .518 .694 r
.53892 .46153 m .54009 .46601 L .52838 .46842 L p F P
0 g
s
.658 .577 .753 r
.52135 .40826 m .52307 .4127 L .51128 .41506 L p F P
0 g
s
.658 .577 .753 r
.51128 .41506 m .51051 .41307 L .52135 .40826 L p F P
0 g
s
.761 .614 .695 r
.27491 .46411 m .27732 .46078 L .2735 .46004 L closepath p F P
0 g
s
.76 .621 .705 r
.27194 .45587 m .27444 .45261 L p .27732 .46078 L F P
0 g
s
.76 .621 .705 r
.27732 .46078 m .2735 .46004 L .27194 .45587 L p F P
0 g
s
.674 .608 .774 r
.48588 .39072 m .47596 .39215 L .47424 .38836 L p F P
0 g
s
.678 .433 .544 r
.42193 .52923 m .42231 .52922 L .42271 .53424 L p F P
0 g
s
.678 .433 .544 r
.42271 .53424 m .42171 .53428 L .42193 .52923 L p F P
0 g
s
.676 .431 .544 r
.42231 .52922 m .43543 .52875 L .43522 .5338 L p F P
0 g
s
.676 .431 .544 r
.43522 .5338 m .42271 .53424 L .42231 .52922 L p F P
0 g
s
.691 .629 .782 r
.43012 .38016 m .43988 .37485 L .42785 .37556 L closepath p F P
0 g
s
.733 .65 .767 r
.32315 .39543 m .32796 .39168 L .32068 .39067 L closepath p F P
0 g
s
.646 .457 .614 r
.49857 .50744 m .49947 .50618 L .49845 .50633 L closepath p F P
0 g
s
.653 .463 .614 r
.49845 .50633 m .49857 .50744 L .49515 .51261 L p F P
0 g
s
.74 .521 .596 r
.33114 .52046 m .32159 .51943 L .3229 .51394 L p F P
0 g
s
.741 .522 .597 r
.31864 .51347 m .3229 .51394 L .32159 .51943 L p F P
0 g
s
.667 .597 .767 r
.50173 .39155 m .50429 .39755 L .49225 .39963 L p F P
0 g
s
.667 .597 .767 r
.49225 .39963 m .49091 .39652 L .50173 .39155 L p F P
0 g
s
.701 .453 .544 r
.39388 .53444 m .38405 .53421 L .38379 .52916 L p F P
0 g
s
.702 .453 .544 r
.37981 .52906 m .38379 .52916 L .38405 .53421 L p F P
0 g
s
.659 .578 .753 r
.51973 .4041 m .52135 .40826 L .51051 .41307 L p F P
0 g
s
.659 .578 .753 r
.51051 .41307 m .50793 .40647 L .51973 .4041 L p F P
0 g
s
.643 .489 .66 r
.52083 .49035 m .52019 .48711 L .52645 .48271 L p F P
0 g
s
.702 .453 .544 r
.38405 .53421 m .37953 .5341 L .37981 .52906 L p F P
0 g
s
.71 .46 .545 r
.37226 .52874 m .37981 .52906 L .37953 .5341 L p F P
0 g
s
.759 .639 .728 r
.27801 .43742 m .2799 .43534 L .27702 .42888 L p F P
0 g
s
.646 .457 .613 r
.49947 .50618 m .51067 .50452 L p .49907 .5121 L F P
0 g
s
.646 .457 .613 r
.49907 .5121 m .49857 .50744 L .49947 .50618 L p F P
0 g
s
.666 .589 .76 r
.50466 .39844 m .50758 .40561 L .50436 .4071 L p F P
0 g
s
.665 .587 .759 r
.50793 .40647 m .50758 .40561 L .50436 .4071 L closepath p F P
0 g
s
.642 .466 .63 r
.51067 .50452 m .50983 .49854 L .52188 .49654 L p F P
0 g
s
.646 .482 .646 r
.52083 .49035 m .52188 .49654 L .50983 .49854 L p F P
0 g
s
.722 .649 .775 r
.34768 .38515 m .34929 .38402 L .34697 .3838 L closepath p F P
0 g
s
.731 .496 .573 r
.35019 .5275 m .3404 .52667 L .34103 .52137 L p F P
0 g
s
.731 .497 .573 r
.33478 .52083 m .34103 .52137 L .3404 .52667 L p F P
0 g
s
.655 .449 .594 r
.48665 .51368 m .48704 .51924 L .47443 .52062 L p F P
0 g
s
.649 .445 .594 r
.48665 .51368 m .49515 .51261 L .49246 .51856 L p F P
0 g
s
.649 .445 .594 r
.49246 .51856 m .48704 .51924 L .48665 .51368 L p F P
0 g
s
.765 .607 .683 r
.27623 .46793 m .27274 .46722 L p .27655 .47509 L F P
0 g
s
.765 .607 .683 r
.27655 .47509 m .27785 .47308 L .27623 .46793 L p F P
0 g
s
.765 .615 .693 r
.27623 .46793 m .27491 .46411 L .27274 .46722 L closepath p F P
0 g
s
.76 .636 .724 r
.2703 .43576 m .27801 .43742 L .27211 .44428 L p F P
0 g
s
.759 .639 .728 r
.27658 .42879 m .2703 .43576 L .27801 .43742 L p F P
0 g
s
.759 .639 .728 r
.27702 .42888 m .27658 .42879 L p .27801 .43742 L F P
0 g
s
.648 .536 .713 r
.53626 .45188 m .53597 .45094 L .53244 .45266 L closepath p F P
0 g
s
.649 .536 .712 r
.53404 .44449 m .53597 .45094 L .53244 .45266 L p F P
0 g
s
.764 .607 .683 r
.27861 .47549 m .27785 .47308 L .27655 .47509 L closepath p F P
0 g
s
.731 .655 .775 r
.33105 .38188 m .33389 .3872 L .32796 .39168 L p F P
0 g
s
.731 .655 .775 r
.33039 .38178 m .33105 .38188 L p .32796 .39168 L F P
0 g
s
.731 .655 .775 r
.32008 .38956 m .33039 .38178 L p .32796 .39168 L F P
0 g
s
.731 .655 .775 r
.32796 .39168 m .32068 .39067 L .32008 .38956 L p F P
0 g
s
.749 .543 .616 r
.31365 .51283 m .30461 .51164 L .30649 .50599 L p F P
0 g
s
.751 .544 .616 r
.30166 .50534 m .30649 .50599 L .30461 .51164 L p F P
0 g
s
.76 .596 .674 r
.28089 .48279 m .28066 .48275 L .27861 .47549 L p F P
0 g
s
.766 .599 .672 r
.27655 .47509 m .27861 .47549 L .28066 .48275 L p F P
0 g
s
.651 .461 .613 r
.49907 .5121 m .49857 .50744 L .49515 .51261 L closepath p F P
0 g
s
.721 .654 .782 r
.35635 .37399 m .3584 .37781 L .34929 .38402 L p F P
0 g
s
.721 .654 .782 r
.35315 .37366 m .35635 .37399 L p .34929 .38402 L F P
0 g
s
.721 .654 .782 r
.34462 .37949 m .35315 .37366 L p .34929 .38402 L F P
0 g
s
.721 .654 .782 r
.34929 .38402 m .34697 .3838 L .34462 .37949 L p F P
0 g
s
.762 .622 .705 r
.27194 .45587 m .27444 .45261 L .2704 .4518 L closepath p F P
0 g
s
.76 .628 .715 r
.26893 .44816 m .27211 .44428 L p .27444 .45261 L F P
0 g
s
.76 .628 .715 r
.27444 .45261 m .2704 .4518 L .26893 .44816 L p F P
0 g
s
.765 .616 .693 r
.27274 .46722 m .27491 .46411 L .2735 .46004 L p F P
0 g
s
.669 .426 .543 r
.43543 .52875 m .43704 .52867 L .4375 .53369 L p F P
0 g
s
.669 .426 .543 r
.4375 .53369 m .43522 .5338 L .43543 .52875 L p F P
0 g
s
.71 .46 .545 r
.37953 .5341 m .37249 .53381 L .37226 .52874 L p F P
0 g
s
.71 .46 .545 r
.36517 .52843 m .37226 .52874 L .37249 .53381 L p F P
0 g
s
.68 .62 .781 r
.46972 .38267 m .45895 .38391 L .45756 .38101 L p F P
0 g
s
.741 .522 .597 r
.32159 .51943 m .31897 .51915 L .31864 .51347 L p F P
0 g
s
.748 .527 .595 r
.31365 .51283 m .31864 .51347 L .31897 .51915 L p F P
0 g
s
.686 .625 .782 r
.45402 .37365 m .4546 .37485 L .44384 .38043 L p F P
0 g
s
.686 .625 .782 r
.44384 .38043 m .44109 .37478 L .45402 .37365 L p F P
0 g
s
.667 .424 .543 r
.43704 .52867 m .44868 .52804 L .44849 .53309 L p F P
0 g
s
.667 .424 .543 r
.44849 .53309 m .4375 .53369 L .43704 .52867 L p F P
0 g
s
.667 .597 .768 r
.50033 .38829 m .50173 .39155 L .49091 .39652 L p F P
0 g
s
.667 .597 .768 r
.49091 .39652 m .48827 .39036 L .50033 .38829 L p F P
0 g
s
.765 .616 .693 r
.2735 .46004 m .26946 .45918 L p .27274 .46722 L F P
0 g
s
.765 .623 .703 r
.2735 .46004 m .27194 .45587 L .26946 .45918 L closepath p F P
0 g
s
.726 .656 .78 r
.34697 .3838 m .34462 .37949 L .33975 .38293 L closepath p F P
0 g
s
.701 .643 .788 r
.41029 .37606 m .40042 .37612 L .39966 .37469 L p F P
0 g
s
.705 .644 .786 r
.40042 .37612 m .39966 .37469 L .39734 .37608 L closepath p F P
0 g
s
.674 .608 .774 r
.47424 .38836 m .48504 .3832 L p .48588 .39072 L F P
0 g
s
.674 .609 .775 r
.48389 .38067 m .48504 .3832 L .47424 .38836 L p F P
0 g
s
.674 .609 .775 r
.47424 .38836 m .47156 .38244 L .48389 .38067 L p F P
0 g
s
.639 .497 .673 r
.53102 .47979 m .53001 .47519 L .54173 .4728 L p F P
0 g
s
.641 .507 .683 r
.54009 .46601 m .54173 .4728 L .53001 .47519 L p F P
0 g
s
.646 .501 .672 r
.53001 .47519 m .53102 .47979 L .52645 .48271 L p F P
0 g
s
.759 .585 .661 r
.28073 .48307 m .28089 .48279 L p .28591 .49028 L F P
0 g
s
.761 .587 .661 r
.28073 .48307 m .28089 .48279 L .28066 .48275 L closepath p F P
0 g
s
.705 .646 .788 r
.39665 .36903 m .39966 .37469 L .39734 .37608 L p F P
0 g
s
.705 .646 .788 r
.38592 .37539 m .39665 .36903 L p .39734 .37608 L F P
0 g
s
.705 .646 .788 r
.39734 .37608 m .38617 .37586 L .38592 .37539 L p F P
0 g
s
.744 .648 .753 r
.29854 .40748 m .29958 .40655 L .29792 .40625 L closepath p F P
0 g
s
.748 .651 .754 r
.29792 .40625 m .29854 .40748 L .29128 .41416 L p F P
0 g
s
.7 .641 .787 r
.4143 .37602 m .4134 .37428 L .41029 .37606 L closepath p F P
0 g
s
.701 .643 .788 r
.4104 .36856 m .4134 .37428 L .41029 .37606 L p F P
0 g
s
.701 .643 .788 r
.39966 .37469 m .4104 .36856 L p .41029 .37606 L F P
0 g
s
.742 .653 .762 r
.30056 .39712 m .30877 .39864 L .29958 .40655 L p F P
0 g
s
.742 .653 .762 r
.29545 .40151 m .30056 .39712 L p .29958 .40655 L F P
0 g
s
.742 .653 .762 r
.29958 .40655 m .29792 .40625 L .29545 .40151 L p F P
0 g
s
.748 .651 .754 r
.29154 .40497 m .29792 .40625 L p .29128 .41416 L F P
0 g
s
.748 .651 .754 r
.28464 .4113 m .29154 .40497 L p .29128 .41416 L F P
0 g
s
.748 .651 .754 r
.29128 .41416 m .28553 .41306 L .28464 .4113 L p F P
0 g
s
.75 .646 .746 r
.28772 .41757 m .29128 .41416 L .28553 .41306 L closepath p F P
0 g
s
.657 .435 .571 r
.47178 .52087 m .47443 .52062 L .47455 .52594 L p F P
0 g
s
.657 .435 .571 r
.47455 .52594 m .47092 .52628 L .47178 .52087 L p F P
0 g
s
.766 .589 .659 r
.28066 .48275 m .27294 .48124 L p .27773 .48881 L F P
0 g
s
.766 .589 .659 r
.27773 .48881 m .28073 .48307 L .28066 .48275 L p F P
0 g
s
.766 .599 .672 r
.28066 .48275 m .27294 .48124 L .27655 .47509 L p F P
0 g
s
.696 .639 .788 r
.42435 .37569 m .4143 .37602 L .4134 .37428 L p F P
0 g
s
.639 .476 .646 r
.52188 .49654 m .52083 .49035 L .53271 .48815 L p F P
0 g
s
.643 .489 .66 r
.53146 .48177 m .53271 .48815 L .52083 .49035 L p F P
0 g
s
.643 .489 .66 r
.52645 .48271 m .53146 .48177 L p .52083 .49035 L F P
0 g
s
.731 .497 .573 r
.3404 .52667 m .33478 .52619 L .33478 .52083 L p F P
0 g
s
.738 .502 .573 r
.33114 .52046 m .33478 .52083 L .33478 .52619 L p F P
0 g
s
.759 .585 .661 r
.28591 .49028 m .28234 .48968 L .28073 .48307 L p F P
0 g
s
.765 .589 .659 r
.28234 .48968 m .28073 .48307 L .27773 .48881 L closepath p F P
0 g
s
.766 .601 .673 r
.2687 .4735 m .27655 .47509 L .27294 .48124 L p F P
0 g
s
.765 .607 .683 r
.27274 .46722 m .2687 .4735 L .27655 .47509 L p F P
0 g
s
.645 .5 .672 r
.53146 .48177 m .53102 .47979 L .52645 .48271 L closepath p F P
0 g
s
.71 .46 .545 r
.37249 .53381 m .36486 .53347 L .36517 .52843 L p F P
0 g
s
.718 .467 .545 r
.36119 .52819 m .36517 .52843 L .36486 .53347 L p F P
0 g
s
.753 .647 .744 r
.28365 .42156 m .28772 .41757 L .28553 .41306 L p F P
0 g
s
.66 .585 .76 r
.51842 .40087 m .51973 .4041 L .50793 .40647 L p F P
0 g
s
.66 .585 .76 r
.50793 .40647 m .50758 .40561 L .51842 .40087 L p F P
0 g
s
.758 .575 .649 r
.28351 .49525 m .28591 .49028 L p .29151 .49759 L F P
0 g
s
.76 .577 .649 r
.28351 .49525 m .28591 .49028 L .28234 .48968 L closepath p F P
0 g
s
.741 .655 .765 r
.30964 .3988 m .30932 .39819 L .30877 .39864 L closepath p F P
0 g
s
.727 .652 .775 r
.33389 .3872 m .33975 .38293 L .33105 .38188 L closepath p F P
0 g
s
.646 .542 .722 r
.53304 .44136 m .53162 .43689 L .54319 .43429 L p F P
0 g
s
.648 .55 .73 r
.54098 .42768 m .54319 .43429 L .53162 .43689 L p F P
0 g
s
.648 .55 .73 r
.53162 .43689 m .53011 .4324 L .54098 .42768 L p F P
0 g
s
.645 .541 .722 r
.53404 .44449 m .53304 .44136 L .54391 .43656 L p F P
0 g
s
.646 .542 .722 r
.54319 .43429 m .54391 .43656 L .53304 .44136 L p F P
0 g
s
.643 .533 .714 r
.53597 .45094 m .53404 .44449 L .5456 .44188 L p F P
0 g
s
.645 .541 .722 r
.54391 .43656 m .5456 .44188 L .53404 .44449 L p F P
0 g
s
.765 .624 .703 r
.26946 .45918 m .27194 .45587 L .2704 .4518 L p F P
0 g
s
.71 .648 .786 r
.38617 .37586 m .38592 .37539 L .38523 .37582 L closepath p F P
0 g
s
.66 .583 .758 r
.51842 .40087 m .50758 .40561 L .50466 .39844 L p F P
0 g
s
.755 .644 .738 r
.28365 .42156 m .27685 .42851 L .27377 .42204 L p F P
0 g
s
.755 .644 .738 r
.27377 .42204 m .27582 .41993 L .28365 .42156 L p F P
0 g
s
.753 .647 .744 r
.28329 .41258 m .27582 .41993 L .28365 .42156 L p F P
0 g
s
.753 .647 .744 r
.28553 .41306 m .28329 .41258 L p .28365 .42156 L F P
0 g
s
.712 .647 .783 r
.37217 .37643 m .37399 .37528 L .38523 .37582 L p F P
0 g
s
.711 .651 .788 r
.38289 .3698 m .37399 .37528 L .38523 .37582 L p F P
0 g
s
.711 .651 .788 r
.38523 .37582 m .38592 .37539 L .38289 .3698 L p F P
0 g
s
.648 .55 .731 r
.54058 .42648 m .54098 .42768 L .53011 .4324 L p F P
0 g
s
.648 .55 .731 r
.53011 .4324 m .529 .42907 L .54058 .42648 L p F P
0 g
s
.65 .429 .571 r
.47455 .52594 m .47443 .52062 L .48704 .51924 L p F P
0 g
s
.742 .657 .766 r
.30623 .3924 m .30056 .39712 L .30877 .39864 L p F P
0 g
s
.742 .657 .766 r
.30877 .39864 m .30932 .39819 L .30623 .3924 L p F P
0 g
s
.748 .655 .758 r
.29792 .40625 m .29545 .40151 L .29154 .40497 L closepath p F P
0 g
s
.739 .656 .768 r
.319 .3904 m .30932 .39819 L .30623 .3924 L p F P
0 g
s
.766 .61 .685 r
.26499 .46559 m .27274 .46722 L .2687 .4735 L p F P
0 g
s
.765 .616 .693 r
.26946 .45918 m .26499 .46559 L .27274 .46722 L p F P
0 g
s
.751 .544 .616 r
.30461 .51164 m .30234 .51133 L .30166 .50534 L p F P
0 g
s
.757 .549 .615 r
.2977 .50472 m .30166 .50534 L .30234 .51133 L p F P
0 g
s
.718 .467 .545 r
.36486 .53347 m .36137 .53326 L .36119 .52819 L p F P
0 g
s
.719 .467 .545 r
.3505 .52752 m .36119 .52819 L .36137 .53326 L p F P
0 g
s
.65 .558 .738 r
.53806 .4193 m .54058 .42648 L .529 .42907 L p F P
0 g
s
.65 .558 .738 r
.529 .42907 m .52719 .42395 L .53806 .4193 L p F P
0 g
s
.707 .649 .79 r
.39665 .36903 m .38592 .37539 L .38289 .3698 L p F P
0 g
s
.695 .637 .787 r
.42785 .37556 m .42713 .37416 L .42435 .37569 L closepath p F P
0 g
s
.696 .639 .788 r
.42414 .36839 m .42713 .37416 L .42435 .37569 L p F P
0 g
s
.696 .639 .788 r
.4134 .37428 m .42414 .36839 L p .42435 .37569 L F P
0 g
s
.702 .645 .79 r
.4104 .36856 m .39966 .37469 L .39665 .36903 L p F P
0 g
s
.643 .532 .714 r
.53626 .45188 m .53597 .45094 L .54685 .44606 L p F P
0 g
s
.643 .533 .714 r
.5456 .44188 m .54685 .44606 L .53597 .45094 L p F P
0 g
s
.762 .63 .714 r
.26893 .44816 m .27211 .44428 L .26691 .44319 L closepath p F P
0 g
s
.76 .636 .724 r
.26589 .44085 m .2703 .43576 L p .27211 .44428 L F P
0 g
s
.76 .636 .724 r
.27211 .44428 m .26691 .44319 L .26589 .44085 L p F P
0 g
s
.641 .523 .704 r
.53626 .45188 m .54781 .44926 L p .54917 .4566 L F P
0 g
s
.641 .523 .704 r
.54917 .4566 m .53827 .45904 L .53626 .45188 L p F P
0 g
s
.643 .532 .714 r
.54685 .44606 m .54781 .44926 L .53626 .45188 L p F P
0 g
s
.758 .563 .632 r
.2977 .50472 m .28917 .50337 L .29151 .49759 L p F P
0 g
s
.759 .564 .633 r
.28373 .49633 m .29151 .49759 L .28917 .50337 L p F P
0 g
s
.758 .575 .649 r
.29151 .49759 m .28373 .49633 L .28351 .49525 L p F P
0 g
s
.738 .502 .573 r
.33478 .52619 m .33053 .52575 L .33114 .52046 L p F P
0 g
s
.739 .504 .573 r
.32159 .51943 m .33114 .52046 L .33053 .52575 L p F P
0 g
s
.748 .527 .595 r
.31897 .51915 m .3124 .5183 L .31365 .51283 L p F P
0 g
s
.749 .528 .597 r
.30461 .51164 m .31365 .51283 L .3124 .5183 L p F P
0 g
s
.691 .635 .788 r
.43988 .37485 m .42785 .37556 L .42713 .37416 L p F P
0 g
s
.765 .624 .703 r
.2704 .4518 m .26668 .45098 L p .26946 .45918 L F P
0 g
s
.765 .631 .712 r
.2704 .4518 m .26893 .44816 L .26668 .45098 L closepath p F P
0 g
s
.717 .651 .782 r
.37149 .37515 m .37217 .37643 L p .3584 .37781 L F P
0 g
s
.712 .648 .784 r
.37217 .37643 m .37399 .37528 L .37149 .37515 L closepath p F P
0 g
s
.68 .62 .781 r
.45756 .38101 m .46835 .37569 L p .46972 .38267 L F P
0 g
s
.68 .62 .781 r
.46835 .37569 m .45756 .38101 L .4546 .37485 L p F P
0 g
s
.661 .419 .543 r
.44868 .52804 m .45312 .52773 L .45364 .53274 L p F P
0 g
s
.661 .419 .543 r
.45364 .53274 m .44849 .53309 L .44868 .52804 L p F P
0 g
s
.758 .645 .736 r
.27702 .42888 m .27685 .42851 L .27658 .42879 L closepath p F P
0 g
s
.696 .641 .79 r
.42414 .36839 m .4134 .37428 L .4104 .36856 L p F P
0 g
s
.673 .606 .773 r
.48827 .39036 m .48798 .38972 L .48588 .39072 L closepath p F P
0 g
s
.674 .608 .774 r
.48504 .3832 m .48798 .38972 L .48588 .39072 L p F P
0 g
s
.759 .647 .737 r
.27658 .42879 m .27685 .42851 L .27377 .42204 L p F P
0 g
s
.65 .559 .739 r
.53775 .41842 m .53806 .4193 L .52719 .42395 L p F P
0 g
s
.65 .559 .739 r
.52719 .42395 m .52615 .42101 L .53775 .41842 L p F P
0 g
s
.736 .657 .772 r
.32068 .39067 m .32008 .38956 L .319 .3904 L closepath p F P
0 g
s
.759 .643 .732 r
.26901 .42707 m .27658 .42879 L .2703 .43576 L p F P
0 g
s
.759 .647 .737 r
.27377 .42204 m .26901 .42707 L .27658 .42879 L p F P
0 g
s
.646 .443 .593 r
.49515 .51261 m .49907 .5121 L .49947 .51766 L p F P
0 g
s
.646 .443 .593 r
.49947 .51766 m .49246 .51856 L .49515 .51261 L p F P
0 g
s
.639 .497 .673 r
.53146 .48177 m .53102 .47979 L .54188 .47345 L p F P
0 g
s
.639 .497 .673 r
.54173 .4728 m .54188 .47345 L .53102 .47979 L p F P
0 g
s
.726 .657 .782 r
.34156 .37388 m .34462 .37949 L .33975 .38293 L p F P
0 g
s
.726 .657 .782 r
.33082 .38146 m .34156 .37388 L p .33975 .38293 L F P
0 g
s
.726 .657 .782 r
.33975 .38293 m .33105 .38188 L .33082 .38146 L p F P
0 g
s
.766 .62 .697 r
.26181 .45752 m .26946 .45918 L .26499 .46559 L p F P
0 g
s
.765 .624 .703 r
.26668 .45098 m .26181 .45752 L .26946 .45918 L p F P
0 g
s
.764 .579 .647 r
.28234 .48968 m .27773 .48881 L p .28306 .49621 L F P
0 g
s
.764 .579 .647 r
.28306 .49621 m .28351 .49525 L .28234 .48968 L p F P
0 g
s
.711 .653 .79 r
.3799 .3643 m .38289 .3698 L .37399 .37528 L p F P
0 g
s
.711 .653 .79 r
.37974 .36429 m .3799 .3643 L p .37399 .37528 L F P
0 g
s
.711 .653 .79 r
.36913 .37085 m .37974 .36429 L p .37399 .37528 L F P
0 g
s
.711 .653 .79 r
.37399 .37528 m .37149 .37515 L .36913 .37085 L p F P
0 g
s
.651 .566 .746 r
.53514 .41135 m .53775 .41842 L .52615 .42101 L p F P
0 g
s
.651 .566 .746 r
.52615 .42101 m .52427 .41593 L .53514 .41135 L p F P
0 g
s
.717 .651 .782 r
.3584 .37781 m .36337 .37453 L .37149 .37515 L p F P
0 g
s
.717 .651 .783 r
.3584 .37781 m .36337 .37453 L .35635 .37399 L closepath p F P
0 g
s
.659 .417 .543 r
.45312 .52773 m .46172 .5271 L .46155 .53215 L p F P
0 g
s
.659 .417 .543 r
.46155 .53215 m .45364 .53274 L .45312 .52773 L p F P
0 g
s
.638 .514 .695 r
.53892 .46153 m .54917 .4566 L .53827 .45904 L closepath p F P
0 g
s
.739 .656 .768 r
.30623 .3924 m .31051 .38896 L .319 .3904 L p F P
0 g
s
.737 .659 .773 r
.31699 .38391 m .31051 .38896 L .319 .3904 L p F P
0 g
s
.737 .659 .773 r
.319 .3904 m .32008 .38956 L .31699 .38391 L p F P
0 g
s
.716 .655 .788 r
.37149 .37515 m .36913 .37085 L .36337 .37453 L closepath p F P
0 g
s
.691 .636 .79 r
.43789 .3685 m .42713 .37416 L .42414 .36839 L p F P
0 g
s
.691 .635 .788 r
.42713 .37416 m .43789 .3685 L p .43988 .37485 L F P
0 g
s
.765 .631 .712 r
.26668 .45098 m .26893 .44816 L .26691 .44319 L p F P
0 g
s
.668 .604 .774 r
.4988 .38485 m .50033 .38829 L .48827 .39036 L p F P
0 g
s
.668 .604 .774 r
.48827 .39036 m .48798 .38972 L .4988 .38485 L p F P
0 g
s
.757 .549 .615 r
.30234 .51133 m .29592 .51034 L .2977 .50472 L p F P
0 g
s
.758 .55 .616 r
.28917 .50337 m .2977 .50472 L .29592 .51034 L p F P
0 g
s
.733 .658 .776 r
.33039 .38178 m .32008 .38956 L .31699 .38391 L p F P
0 g
s
.679 .617 .78 r
.47156 .38244 m .4713 .38189 L .46972 .38267 L closepath p F P
0 g
s
.68 .62 .781 r
.46835 .37569 m .4713 .38189 L .46972 .38267 L p F P
0 g
s
.635 .484 .66 r
.53271 .48815 m .53146 .48177 L .54317 .47937 L p F P
0 g
s
.639 .497 .673 r
.54188 .47345 m .54317 .47937 L .53146 .48177 L p F P
0 g
s
.719 .467 .545 r
.36137 .53326 m .35067 .53259 L .3505 .52752 L p F P
0 g
s
.72 .468 .545 r
.35019 .5275 m .3505 .52752 L .35067 .53259 L p F P
0 g
s
.668 .603 .773 r
.4988 .38485 m .48798 .38972 L .48504 .3832 L p F P
0 g
s
.72 .468 .545 r
.35067 .53259 m .34985 .53254 L .35019 .5275 L p F P
0 g
s
.728 .475 .545 r
.3404 .52667 m .35019 .5275 L .34985 .53254 L p F P
0 g
s
.753 .653 .751 r
.28553 .41306 m .28464 .4113 L .28329 .41258 L closepath p F P
0 g
s
.638 .513 .694 r
.54009 .46601 m .53892 .46153 L .54917 .4566 L p F P
0 g
s
.638 .451 .614 r
.51067 .50452 m .52274 .50253 L p .5214 .50865 L F P
0 g
s
.638 .451 .614 r
.5214 .50865 m .51131 .5103 L .51067 .50452 L p F P
0 g
s
.642 .466 .63 r
.52188 .49654 m .52274 .50253 L .51067 .50452 L p F P
0 g
s
.646 .457 .613 r
.51067 .50452 m .51131 .5103 L .49907 .5121 L p F P
0 g
s
.69 .632 .787 r
.44109 .37478 m .44087 .37433 L .43988 .37485 L closepath p F P
0 g
s
.691 .635 .788 r
.43789 .3685 m .44087 .37433 L .43988 .37485 L p F P
0 g
s
.652 .567 .747 r
.53468 .41011 m .53514 .41135 L .52427 .41593 L p F P
0 g
s
.652 .567 .747 r
.52427 .41593 m .52307 .4127 L .53468 .41011 L p F P
0 g
s
.674 .615 .781 r
.4821 .37684 m .48389 .38067 L .47156 .38244 L p F P
0 g
s
.674 .615 .781 r
.47156 .38244 m .4713 .38189 L .4821 .37684 L p F P
0 g
s
.64 .438 .593 r
.49947 .51766 m .49907 .5121 L .51131 .5103 L p F P
0 g
s
.66 .583 .758 r
.51612 .39521 m .51842 .40087 L p .50466 .39844 L F P
0 g
s
.66 .583 .758 r
.50466 .39844 m .50855 .39672 L .51612 .39521 L p F P
0 g
s
.661 .587 .762 r
.50466 .39844 m .50855 .39672 L .50429 .39755 L closepath p F P
0 g
s
.685 .63 .788 r
.45164 .36891 m .45402 .37365 L .44109 .37478 L p F P
0 g
s
.685 .63 .788 r
.44109 .37478 m .44087 .37433 L .45164 .36891 L p F P
0 g
s
.722 .656 .784 r
.35315 .37366 m .34462 .37949 L .34156 .37388 L p F P
0 g
s
.762 .637 .723 r
.26589 .44085 m .2703 .43576 L .26299 .43417 L closepath p F P
0 g
s
.759 .643 .732 r
.26284 .43385 m .26901 .42707 L p .2703 .43576 L F P
0 g
s
.759 .643 .732 r
.2703 .43576 m .26299 .43417 L .26284 .43385 L p F P
0 g
s
.766 .628 .707 r
.25915 .44927 m .26668 .45098 L .26181 .45752 L p F P
0 g
s
.765 .631 .712 r
.26441 .44261 m .25915 .44927 L .26668 .45098 L p F P
0 g
s
.765 .631 .712 r
.26691 .44319 m .26441 .44261 L p .26668 .45098 L F P
0 g
s
.675 .617 .782 r
.4821 .37684 m .4713 .38189 L .46835 .37569 L p F P
0 g
s
.662 .594 .768 r
.50855 .39672 m .50429 .39755 L .50173 .39155 L p F P
0 g
s
.686 .633 .79 r
.45164 .36891 m .44087 .37433 L .43789 .3685 L p F P
0 g
s
.653 .574 .754 r
.53221 .40374 m .53468 .41011 L .52307 .4127 L p F P
0 g
s
.653 .574 .754 r
.52307 .4127 m .52135 .40826 L .53221 .40374 L p F P
0 g
s
.652 .412 .543 r
.46172 .5271 m .47092 .52628 L .47152 .53127 L p F P
0 g
s
.652 .412 .543 r
.47152 .53127 m .46155 .53215 L .46172 .5271 L p F P
0 g
s
.765 .638 .721 r
.26691 .44319 m .26589 .44085 L .26441 .44261 L closepath p F P
0 g
s
.716 .656 .789 r
.36608 .36534 m .36913 .37085 L .36337 .37453 L p F P
0 g
s
.716 .656 .789 r
.35535 .37219 m .36608 .36534 L p .36337 .37453 L F P
0 g
s
.716 .656 .789 r
.36337 .37453 m .35635 .37399 L .35535 .37219 L p F P
0 g
s
.739 .504 .573 r
.33053 .52575 m .32095 .52473 L .32159 .51943 L p F P
0 g
s
.74 .505 .573 r
.31897 .51915 m .32159 .51943 L .32095 .52473 L p F P
0 g
s
.635 .463 .632 r
.52188 .49654 m .53378 .49435 L p .52761 .50164 L F P
0 g
s
.635 .463 .632 r
.52761 .50164 m .52274 .50253 L .52188 .49654 L p F P
0 g
s
.639 .476 .646 r
.53271 .48815 m .53378 .49435 L .52188 .49654 L p F P
0 g
s
.636 .504 .685 r
.54009 .46601 m .55164 .46341 L p .54413 .47226 L F P
0 g
s
.636 .504 .685 r
.54413 .47226 m .54173 .4728 L .54009 .46601 L p F P
0 g
s
.638 .513 .694 r
.54983 .45645 m .55164 .46341 L .54009 .46601 L p F P
0 g
s
.638 .513 .694 r
.54917 .4566 m .54983 .45645 L p .54009 .46601 L F P
0 g
s
.75 .653 .754 r
.29154 .40497 m .28464 .4113 L .28154 .40526 L p F P
0 g
s
.75 .653 .754 r
.28154 .40526 m .28362 .40336 L .29154 .40497 L p F P
0 g
s
.748 .656 .759 r
.29235 .39559 m .28362 .40336 L .29154 .40497 L p F P
0 g
s
.748 .656 .759 r
.29236 .39559 m .29235 .39559 L p .29154 .40497 L F P
0 g
s
.748 .656 .759 r
.29154 .40497 m .29545 .40151 L .29236 .39559 L p F P
0 g
s
.754 .655 .752 r
.28329 .41258 m .28464 .4113 L .28154 .40526 L p F P
0 g
s
.766 .589 .659 r
.27294 .48124 m .26974 .48727 L .27773 .48881 L p F P
0 g
s
.767 .593 .663 r
.26503 .47967 m .27294 .48124 L .26974 .48727 L p F P
0 g
s
.766 .601 .673 r
.27294 .48124 m .26503 .47967 L .2687 .4735 L p F P
0 g
s
.764 .579 .647 r
.28373 .49633 m .28351 .49525 L .28306 .49621 L closepath p F P
0 g
s
.754 .655 .752 r
.28154 .40526 m .27562 .41088 L .28329 .41258 L p F P
0 g
s
.754 .651 .748 r
.27562 .41088 m .28329 .41258 L .27582 .41993 L p F P
0 g
s
.744 .654 .761 r
.29545 .40151 m .30056 .39712 L .29236 .39559 L closepath p F P
0 g
s
.764 .579 .647 r
.27773 .48881 m .27501 .4947 L .28306 .49621 L p F P
0 g
s
.766 .582 .648 r
.26974 .48727 m .27773 .48881 L .27501 .4947 L p F P
0 g
s
.768 .603 .674 r
.26087 .4719 m .2687 .4735 L .26503 .47967 L p F P
0 g
s
.766 .61 .685 r
.2687 .4735 m .26087 .4719 L .26499 .46559 L p F P
0 g
s
.749 .528 .597 r
.3124 .5183 m .30332 .51712 L .30461 .51164 L p F P
0 g
s
.75 .53 .597 r
.30234 .51133 m .30461 .51164 L .30332 .51712 L p F P
0 g
s
.65 .429 .571 r
.48704 .51924 m .48718 .52457 L .47455 .52594 L p F P
0 g
s
.643 .424 .571 r
.48704 .51924 m .49246 .51856 L .49142 .52404 L p F P
0 g
s
.643 .424 .571 r
.49142 .52404 m .48718 .52457 L .48704 .51924 L p F P
0 g
s
.679 .41 .507 r
.40793 .53449 m .40901 .53448 L .41055 .53917 L p F P
0 g
s
.679 .41 .507 r
.41055 .53917 m .40734 .53921 L .40793 .53449 L p F P
0 g
s
.686 .416 .508 r
.39618 .53445 m .40793 .53449 L .40734 .53921 L p F P
0 g
s
.677 .409 .508 r
.40901 .53448 m .42171 .53428 L .42114 .539 L p F P
0 g
s
.677 .409 .508 r
.42114 .539 m .41055 .53917 L .40901 .53448 L p F P
0 g
s
.759 .564 .633 r
.28917 .50337 m .28476 .50266 L .28373 .49633 L p F P
0 g
s
.765 .568 .631 r
.28306 .49621 m .28373 .49633 L .28476 .50266 L p F P
0 g
s
.731 .659 .779 r
.33105 .38188 m .33082 .38146 L .33039 .38178 L closepath p F P
0 g
s
.686 .416 .508 r
.40734 .53921 m .39759 .53918 L .39618 .53445 L p F P
0 g
s
.688 .417 .508 r
.39388 .53444 m .39618 .53445 L .39759 .53918 L p F P
0 g
s
.742 .659 .769 r
.30378 .38782 m .30623 .3924 L .30056 .39712 L p F P
0 g
s
.742 .659 .769 r
.30211 .38749 m .30378 .38782 L p .30056 .39712 L F P
0 g
s
.742 .659 .769 r
.29236 .39558 m .30211 .38749 L p .30056 .39712 L F P
0 g
s
.742 .659 .769 r
.30056 .39712 m .29236 .39559 L .29236 .39558 L p F P
0 g
s
.688 .417 .508 r
.39759 .53918 m .39325 .53915 L .39388 .53444 L p F P
0 g
s
.695 .424 .509 r
.38405 .53421 m .39388 .53444 L .39325 .53915 L p F P
0 g
s
.74 .505 .573 r
.32095 .52473 m .31897 .52451 L .31897 .51915 L p F P
0 g
s
.747 .511 .573 r
.3124 .5183 m .31897 .51915 L .31897 .52451 L p F P
0 g
s
.765 .639 .721 r
.26441 .44261 m .26589 .44085 L .26299 .43417 L p F P
0 g
s
.756 .646 .739 r
.27377 .42204 m .27582 .41993 L .27242 .4192 L closepath p F P
0 g
s
.754 .651 .748 r
.27068 .41573 m .27562 .41088 L p .27582 .41993 L F P
0 g
s
.754 .651 .748 r
.27582 .41993 m .27242 .4192 L .27068 .41573 L p F P
0 g
s
.733 .658 .776 r
.31699 .38391 m .32161 .38043 L .33039 .38178 L p F P
0 g
s
.732 .662 .781 r
.32774 .37595 m .32161 .38043 L .33039 .38178 L p F P
0 g
s
.732 .662 .781 r
.33039 .38178 m .33082 .38146 L .32774 .37595 L p F P
0 g
s
.765 .568 .631 r
.28476 .50266 m .28084 .50195 L .28306 .49621 L p F P
0 g
s
.767 .57 .633 r
.27501 .4947 m .28306 .49621 L .28084 .50195 L p F P
0 g
s
.728 .661 .784 r
.34156 .37388 m .33082 .38146 L .32774 .37595 L p F P
0 g
s
.728 .475 .545 r
.33478 .52619 m .3404 .52667 L .34055 .53174 L p F P
0 g
s
.728 .475 .545 r
.34985 .53254 m .34055 .53174 L .3404 .52667 L p F P
0 g
s
.653 .575 .754 r
.53135 .40151 m .53221 .40374 L .52135 .40826 L p F P
0 g
s
.653 .575 .754 r
.52135 .40826 m .51973 .4041 L .53135 .40151 L p F P
0 g
s
.67 .402 .507 r
.42171 .53428 m .42271 .53424 L .42439 .5389 L p F P
0 g
s
.67 .402 .507 r
.42439 .5389 m .42114 .539 L .42171 .53428 L p F P
0 g
s
.768 .613 .686 r
.25816 .46414 m .26499 .46559 L .26087 .4719 L p F P
0 g
s
.766 .62 .697 r
.25781 .46319 m .26181 .45752 L p .26499 .46559 L F P
0 g
s
.766 .62 .697 r
.26499 .46559 m .25816 .46414 L .25781 .46319 L p F P
0 g
s
.76 .647 .737 r
.26901 .42707 m .27377 .42204 L .27242 .4192 L p F P
0 g
s
.668 .401 .508 r
.42271 .53424 m .43522 .5338 L .43468 .53854 L p F P
0 g
s
.668 .401 .508 r
.43468 .53854 m .42439 .5389 L .42271 .53424 L p F P
0 g
s
.75 .53 .597 r
.30332 .51712 m .30269 .51704 L .30234 .51133 L p F P
0 g
s
.757 .536 .596 r
.29592 .51034 m .30234 .51133 L .30269 .51704 L p F P
0 g
s
.695 .424 .509 r
.39325 .53915 m .38534 .53897 L .38405 .53421 L p F P
0 g
s
.696 .425 .508 r
.37953 .5341 m .38405 .53421 L .38534 .53897 L p F P
0 g
s
.721 .658 .787 r
.35635 .37399 m .35535 .37219 L .35315 .37366 L closepath p F P
0 g
s
.68 .62 .781 r
.46668 .37222 m .46835 .37569 L p .4546 .37485 L F P
0 g
s
.68 .62 .781 r
.4546 .37485 m .45786 .37324 L .46668 .37222 L p F P
0 g
s
.682 .624 .784 r
.4546 .37485 m .45786 .37324 L .45402 .37365 L closepath p F P
0 g
s
.739 .656 .768 r
.30623 .3924 m .31051 .38896 L .30378 .38782 L closepath p F P
0 g
s
.765 .639 .721 r
.26263 .43408 m .25699 .44086 L .26441 .44261 L p F P
0 g
s
.765 .639 .721 r
.26299 .43417 m .26263 .43408 L p .26441 .44261 L F P
0 g
s
.766 .636 .716 r
.25699 .44086 m .26441 .44261 L .25915 .44927 L p F P
0 g
s
.696 .425 .508 r
.38534 .53897 m .37888 .53881 L .37953 .5341 L p F P
0 g
s
.704 .432 .51 r
.37249 .53381 m .37953 .5341 L .37888 .53881 L p F P
0 g
s
.661 .592 .767 r
.51612 .39521 m .5155 .39373 L .50855 .39672 L closepath p F P
0 g
s
.662 .594 .768 r
.51257 .38684 m .5155 .39373 L .50855 .39672 L p F P
0 g
s
.662 .594 .768 r
.50173 .39155 m .51257 .38684 L p .50855 .39672 L F P
0 g
s
.702 .645 .79 r
.4084 .3648 m .4104 .36856 L p .39665 .36903 L F P
0 g
s
.702 .645 .79 r
.39665 .36903 m .40405 .3648 L .4084 .3648 L p F P
0 g
s
.702 .647 .791 r
.39665 .36903 m .40405 .3648 L .39435 .36475 L closepath p F P
0 g
s
.707 .649 .79 r
.39435 .36475 m .39665 .36903 L p .38289 .3698 L F P
0 g
s
.707 .65 .791 r
.38289 .3698 m .39151 .36467 L .3799 .3643 L closepath p F P
0 g
s
.707 .649 .79 r
.38289 .3698 m .39151 .36467 L .39435 .36475 L p F P
0 g
s
.737 .661 .776 r
.31448 .37933 m .31699 .38391 L .31051 .38896 L p F P
0 g
s
.737 .661 .776 r
.31292 .37905 m .31448 .37933 L p .31051 .38896 L F P
0 g
s
.737 .661 .776 r
.30314 .38667 m .31292 .37905 L p .31051 .38896 L F P
0 g
s
.737 .661 .776 r
.31051 .38896 m .30378 .38782 L .30314 .38667 L p F P
0 g
s
.632 .472 .647 r
.53271 .48815 m .54443 .48576 L p .53692 .49372 L F P
0 g
s
.632 .472 .647 r
.53692 .49372 m .53378 .49435 L .53271 .48815 L p F P
0 g
s
.635 .484 .66 r
.54317 .47937 m .54443 .48576 L .53271 .48815 L p F P
0 g
s
.65 .41 .543 r
.47092 .52628 m .47455 .52594 L .47441 .53101 L p F P
0 g
s
.65 .41 .543 r
.47441 .53101 m .47152 .53127 L .47092 .52628 L p F P
0 g
s
.696 .641 .79 r
.4221 .36447 m .42414 .36839 L p .4104 .36856 L F P
0 g
s
.696 .641 .79 r
.4104 .36856 m .4176 .36459 L .4221 .36447 L p F P
0 g
s
.697 .643 .792 r
.4104 .36856 m .4176 .36459 L .4084 .3648 L closepath p F P
0 g
s
.712 .657 .793 r
.37974 .36429 m .36913 .37085 L .36608 .36534 L p F P
0 g
s
.722 .656 .784 r
.34156 .37388 m .34342 .37262 L .35315 .37366 L p F P
0 g
s
.722 .661 .789 r
.35228 .36676 m .34342 .37262 L .35315 .37366 L p F P
0 g
s
.722 .661 .789 r
.35315 .37366 m .35535 .37219 L .35228 .36676 L p F P
0 g
s
.762 .644 .731 r
.26901 .42707 m .26284 .43385 L .25976 .42723 L p F P
0 g
s
.762 .644 .731 r
.25976 .42723 m .26147 .42534 L .26901 .42707 L p F P
0 g
s
.76 .647 .737 r
.26823 .41821 m .26147 .42534 L .26901 .42707 L p F P
0 g
s
.76 .647 .737 r
.27242 .4192 m .26823 .41821 L p .26901 .42707 L F P
0 g
s
.682 .63 .791 r
.45786 .37324 m .45402 .37365 L .45164 .36891 L p F P
0 g
s
.758 .55 .616 r
.29592 .51034 m .28734 .50901 L .28917 .50337 L p F P
0 g
s
.759 .552 .617 r
.28476 .50266 m .28917 .50337 L .28734 .50901 L p F P
0 g
s
.663 .595 .769 r
.5122 .38598 m .51257 .38684 L .50173 .39155 L p F P
0 g
s
.663 .595 .769 r
.50173 .39155 m .50033 .38829 L .5122 .38598 L p F P
0 g
s
.632 .491 .672 r
.54188 .47345 m .54413 .47226 L .54173 .4728 L closepath p F P
0 g
s
.668 .603 .773 r
.49603 .37865 m .4988 .38485 L p .48504 .3832 L F P
0 g
s
.668 .603 .773 r
.48504 .3832 m .49443 .37892 L .49603 .37865 L p F P
0 g
s
.67 .607 .777 r
.48504 .3832 m .49443 .37892 L .48389 .38067 L closepath p F P
0 g
s
.655 .582 .761 r
.52929 .39642 m .53135 .40151 L .51973 .4041 L p F P
0 g
s
.655 .582 .761 r
.51973 .4041 m .51842 .40087 L .52929 .39642 L p F P
0 g
s
.768 .621 .696 r
.25781 .46319 m .26181 .45752 L .25524 .45606 L closepath p F P
0 g
s
.766 .628 .707 r
.25482 .45501 m .25915 .44927 L p .26181 .45752 L F P
0 g
s
.766 .628 .707 r
.26181 .45752 m .25524 .45606 L .25482 .45501 L p F P
0 g
s
.641 .422 .57 r
.49246 .51856 m .49947 .51766 L .49962 .52298 L p F P
0 g
s
.641 .422 .57 r
.49962 .52298 m .49142 .52404 L .49246 .51856 L p F P
0 g
s
.728 .475 .545 r
.34055 .53174 m .33443 .53122 L .33478 .52619 L p F P
0 g
s
.736 .482 .545 r
.33053 .52575 m .33478 .52619 L .33443 .53122 L p F P
0 g
s
.704 .432 .51 r
.37888 .53881 m .37367 .53859 L .37249 .53381 L p F P
0 g
s
.705 .432 .509 r
.36486 .53347 m .37249 .53381 L .37367 .53859 L p F P
0 g
s
.661 .395 .507 r
.43522 .5338 m .4375 .53369 L .43934 .53831 L p F P
0 g
s
.661 .395 .507 r
.43934 .53831 m .43468 .53854 L .43522 .5338 L p F P
0 g
s
.632 .491 .672 r
.54317 .47937 m .54188 .47345 L .54413 .47226 L p F P
0 g
s
.659 .394 .507 r
.4375 .53369 m .44849 .53309 L .44798 .53784 L p F P
0 g
s
.659 .394 .507 r
.44798 .53784 m .43934 .53831 L .4375 .53369 L p F P
0 g
s
.76 .654 .745 r
.27242 .4192 m .27068 .41573 L .26823 .41821 L closepath p F P
0 g
s
.717 .66 .792 r
.36608 .36534 m .35535 .37219 L .35228 .36676 L p F P
0 g
s
.691 .636 .79 r
.43547 .36379 m .43789 .3685 L p .42414 .36839 L F P
0 g
s
.691 .636 .79 r
.42414 .36839 m .43251 .36396 L .43547 .36379 L p F P
0 g
s
.692 .639 .792 r
.42414 .36839 m .43251 .36396 L .4221 .36447 L closepath p F P
0 g
s
.643 .404 .542 r
.47441 .53101 m .47455 .52594 L .48718 .52457 L p F P
0 g
s
.747 .511 .573 r
.31897 .52451 m .31178 .52359 L .3124 .5183 L p F P
0 g
s
.747 .511 .574 r
.30332 .51712 m .3124 .5183 L .31178 .52359 L p F P
0 g
s
.68 .627 .789 r
.46668 .37222 m .46539 .36961 L .45786 .37324 L closepath p F P
0 g
s
.682 .63 .791 r
.46243 .36369 m .46539 .36961 L .45786 .37324 L p F P
0 g
s
.682 .63 .791 r
.45164 .36891 m .46243 .36369 L p .45786 .37324 L F P
0 g
s
.64 .538 .723 r
.54391 .43656 m .54319 .43429 L .5546 .43147 L p F P
0 g
s
.642 .546 .731 r
.55199 .42366 m .5546 .43147 L .54319 .43429 L p F P
0 g
s
.642 .546 .731 r
.54949 .42428 m .55199 .42366 L p .54319 .43429 L F P
0 g
s
.642 .546 .731 r
.54319 .43429 m .54098 .42768 L .54949 .42428 L p F P
0 g
s
.639 .537 .723 r
.5456 .44188 m .54391 .43656 L .55482 .43215 L p F P
0 g
s
.64 .538 .723 r
.5546 .43147 m .55482 .43215 L .54391 .43656 L p F P
0 g
s
.733 .659 .776 r
.31699 .38391 m .32161 .38043 L .31448 .37933 L closepath p F P
0 g
s
.705 .432 .509 r
.37367 .53859 m .36419 .53818 L .36486 .53347 L p F P
0 g
s
.713 .44 .511 r
.36137 .53326 m .36486 .53347 L .36419 .53818 L p F P
0 g
s
.639 .537 .723 r
.55482 .43215 m .557 .43906 L .5456 .44188 L p F P
0 g
s
.637 .529 .714 r
.54685 .44606 m .5456 .44188 L .557 .43906 L p F P
0 g
s
.655 .583 .762 r
.52776 .39262 m .52929 .39642 L .51842 .40087 L p F P
0 g
s
.655 .583 .762 r
.51842 .40087 m .51612 .39521 L .52776 .39262 L p F P
0 g
s
.675 .617 .782 r
.46835 .37569 m .47915 .37059 L .4821 .37684 L p F P
0 g
s
.676 .619 .784 r
.47912 .37053 m .47915 .37059 L .46835 .37569 L p F P
0 g
s
.676 .619 .784 r
.46835 .37569 m .46668 .37222 L .47912 .37053 L p F P
0 g
s
.765 .645 .729 r
.26299 .43417 m .26284 .43385 L .26263 .43408 L closepath p F P
0 g
s
.736 .482 .545 r
.33443 .53122 m .33064 .53083 L .33053 .52575 L p F P
0 g
s
.736 .482 .545 r
.32095 .52473 m .33053 .52575 L .33064 .53083 L p F P
0 g
s
.642 .547 .731 r
.54098 .42768 m .54949 .42428 L .54058 .42648 L closepath p F P
0 g
s
.644 .555 .739 r
.54949 .42428 m .54058 .42648 L .53806 .4193 L p F P
0 g
s
.637 .528 .714 r
.54781 .44926 m .54685 .44606 L .55776 .44159 L p F P
0 g
s
.637 .529 .714 r
.557 .43906 m .55776 .44159 L .54685 .44606 L p F P
0 g
s
.766 .647 .73 r
.26263 .43408 m .26284 .43385 L .25976 .42723 L p F P
0 g
s
.67 .613 .783 r
.49443 .37892 m .48389 .38067 L .4821 .37684 L p F P
0 g
s
.632 .491 .672 r
.54413 .47226 m .55329 .47019 L p .54317 .47937 L F P
0 g
s
.635 .502 .684 r
.55329 .47019 m .55276 .46802 L .54413 .47226 L closepath p F P
0 g
s
.636 .504 .685 r
.55164 .46341 m .55276 .46802 L .54413 .47226 L p F P
0 g
s
.663 .601 .776 r
.50965 .38021 m .5122 .38598 L .50033 .38829 L p F P
0 g
s
.663 .601 .776 r
.50033 .38829 m .4988 .38485 L .50965 .38021 L p F P
0 g
s
.767 .642 .723 r
.25534 .43228 m .26263 .43408 L .25699 .44086 L p F P
0 g
s
.766 .647 .73 r
.25976 .42723 m .25534 .43228 L .26263 .43408 L p F P
0 g
s
.713 .44 .511 r
.36419 .53818 m .36245 .53808 L .36137 .53326 L p F P
0 g
s
.714 .439 .508 r
.35067 .53259 m .36137 .53326 L .36245 .53808 L p F P
0 g
s
.757 .536 .596 r
.30269 .51704 m .2947 .5158 L .29592 .51034 L p F P
0 g
s
.757 .536 .597 r
.28734 .50901 m .29592 .51034 L .2947 .5158 L p F P
0 g
s
.769 .629 .706 r
.25482 .45501 m .25915 .44927 L .25191 .44761 L closepath p F P
0 g
s
.766 .636 .716 r
.2518 .44734 m .25699 .44086 L p .25915 .44927 L F P
0 g
s
.766 .636 .716 r
.25915 .44927 m .25191 .44761 L .2518 .44734 L p F P
0 g
s
.634 .52 .706 r
.54979 .45631 m .54781 .44926 L .5592 .44644 L p F P
0 g
s
.637 .528 .714 r
.55776 .44159 m .5592 .44644 L .54781 .44926 L p F P
0 g
s
.641 .523 .704 r
.54781 .44926 m .54979 .45631 L .54917 .4566 L p F P
0 g
s
.633 .433 .594 r
.51131 .5103 m .5214 .50865 L .5179 .51486 L p F P
0 g
s
.633 .433 .594 r
.5179 .51486 m .51172 .51587 L .51131 .5103 L p F P
0 g
s
.64 .438 .593 r
.51131 .5103 m .51172 .51587 L .49947 .51766 L p F P
0 g
s
.759 .552 .617 r
.28734 .50901 m .28547 .50871 L .28476 .50266 L p F P
0 g
s
.766 .557 .615 r
.28084 .50195 m .28476 .50266 L .28547 .50871 L p F P
0 g
s
.687 .635 .792 r
.44853 .36278 m .44866 .36304 L .43789 .3685 L p F P
0 g
s
.687 .635 .792 r
.43789 .3685 m .43547 .36379 L .44853 .36278 L p F P
0 g
s
.686 .633 .79 r
.43789 .3685 m .44866 .36304 L .45164 .36891 L p F P
0 g
s
.723 .658 .785 r
.34156 .37388 m .34342 .37262 L .34069 .37232 L closepath p F P
0 g
s
.728 .661 .784 r
.34069 .37232 m .34156 .37388 L p .32774 .37595 L F P
0 g
s
.751 .655 .755 r
.28154 .40526 m .28362 .40336 L .28019 .40264 L closepath p F P
0 g
s
.748 .66 .763 r
.28463 .3939 m .29235 .39559 L .28362 .40336 L p F P
0 g
s
.748 .66 .763 r
.27843 .39938 m .28463 .3939 L p .28362 .40336 L F P
0 g
s
.748 .66 .763 r
.28362 .40336 m .28019 .40264 L .27843 .39938 L p F P
0 g
s
.755 .656 .752 r
.27562 .41088 m .28154 .40526 L .28019 .40264 L p F P
0 g
s
.769 .595 .662 r
.26364 .48229 m .26503 .47967 L .26285 .47923 L closepath p F P
0 g
s
.768 .603 .674 r
.26076 .47209 m .26087 .4719 L p .26503 .47967 L F P
0 g
s
.768 .603 .674 r
.26503 .47967 m .26285 .47923 L .26076 .47209 L p F P
0 g
s
.767 .593 .663 r
.26364 .48229 m .26503 .47967 L p .26974 .48727 L F P
0 g
s
.731 .663 .783 r
.32465 .37046 m .32774 .37595 L .32161 .38043 L p F P
0 g
s
.731 .663 .783 r
.3139 .37831 m .32465 .37046 L p .32161 .38043 L F P
0 g
s
.731 .663 .783 r
.32161 .38043 m .31448 .37933 L .3139 .37831 L p F P
0 g
s
.652 .387 .506 r
.44849 .53309 m .45364 .53274 L .45566 .53731 L p F P
0 g
s
.652 .387 .506 r
.45566 .53731 m .44798 .53784 L .44849 .53309 L p F P
0 g
s
.766 .582 .648 r
.27501 .4947 m .26696 .49318 L .26974 .48727 L p F P
0 g
s
.768 .584 .649 r
.26466 .48628 m .26974 .48727 L .26696 .49318 L p F P
0 g
s
.767 .593 .663 r
.26974 .48727 m .26466 .48628 L .26364 .48229 L p F P
0 g
s
.631 .446 .614 r
.52318 .50649 m .52761 .50164 L .52274 .50253 L closepath p F P
0 g
s
.638 .451 .614 r
.52274 .50253 m .52318 .50649 L .5214 .50865 L p F P
0 g
s
.756 .652 .747 r
.27562 .41088 m .27068 .41573 L .26758 .40957 L p F P
0 g
s
.756 .652 .747 r
.26758 .40957 m .26798 .40917 L .27562 .41088 L p F P
0 g
s
.755 .656 .752 r
.27594 .40165 m .26798 .40917 L .27562 .41088 L p F P
0 g
s
.755 .656 .752 r
.28019 .40264 m .27594 .40165 L p .27562 .41088 L F P
0 g
s
.747 .661 .765 r
.29236 .39559 m .29236 .39558 L .29235 .39559 L closepath p F P
0 g
s
.749 .664 .767 r
.28924 .38994 m .28463 .3939 L .29235 .39559 L p F P
0 g
s
.749 .664 .767 r
.29235 .39559 m .29236 .39558 L .28924 .38994 L p F P
0 g
s
.745 .662 .769 r
.30211 .38749 m .29236 .39558 L .28924 .38994 L p F P
0 g
s
.644 .555 .74 r
.53806 .4193 m .54452 .41675 L .53775 .41842 L closepath p F P
0 g
s
.644 .555 .739 r
.53806 .4193 m .54452 .41675 L p .54949 .42428 L F P
0 g
s
.77 .604 .674 r
.26076 .47209 m .26087 .4719 L .2607 .47186 L closepath p F P
0 g
s
.768 .613 .686 r
.26087 .4719 m .2607 .47186 L .25816 .46414 L p F P
0 g
s
.721 .662 .791 r
.34954 .36193 m .35228 .36676 L .34342 .37262 L p F P
0 g
s
.721 .662 .791 r
.34853 .36181 m .34954 .36193 L p .34342 .37262 L F P
0 g
s
.721 .662 .791 r
.33848 .36846 m .34853 .36181 L p .34342 .37262 L F P
0 g
s
.721 .662 .791 r
.34342 .37262 m .34069 .37232 L .33848 .36846 L p F P
0 g
s
.64 .523 .704 r
.54983 .45645 m .54979 .45631 L .54917 .4566 L closepath p F P
0 g
s
.774 .607 .672 r
.2607 .47186 m .25342 .47018 L p .2574 .47801 L F P
0 g
s
.774 .607 .672 r
.2574 .47801 m .26076 .47209 L .2607 .47186 L p F P
0 g
s
.774 .616 .683 r
.2573 .46394 m .25816 .46414 L .2607 .47186 L p F P
0 g
s
.774 .616 .683 r
.2607 .47186 m .25342 .47018 L .2573 .46394 L p F P
0 g
s
.646 .563 .747 r
.54452 .41675 m .53775 .41842 L .53514 .41135 L p F P
0 g
s
.774 .606 .672 r
.26285 .47923 m .26076 .47209 L .2574 .47801 L closepath p F P
0 g
s
.634 .416 .57 r
.49962 .52298 m .49947 .51766 L .51172 .51587 L p F P
0 g
s
.742 .663 .773 r
.30378 .38782 m .30314 .38667 L .30211 .38749 L closepath p F P
0 g
s
.767 .57 .633 r
.28084 .50195 m .27274 .50046 L .27501 .4947 L p F P
0 g
s
.767 .572 .634 r
.26696 .49318 m .27501 .4947 L .27274 .50046 L p F P
0 g
s
.76 .654 .745 r
.26823 .41821 m .27068 .41573 L .26758 .40957 L p F P
0 g
s
.772 .623 .694 r
.25816 .46414 m .25781 .46319 L .2573 .46394 L closepath p F P
0 g
s
.629 .48 .661 r
.54317 .47937 m .55473 .47677 L p .55183 .48411 L F P
0 g
s
.629 .48 .661 r
.55183 .48411 m .54443 .48576 L .54317 .47937 L p F P
0 g
s
.632 .491 .672 r
.55329 .47019 m .55473 .47677 L .54317 .47937 L p F P
0 g
s
.634 .519 .705 r
.54983 .45645 m .54979 .45631 L .56071 .45179 L p F P
0 g
s
.634 .52 .706 r
.5592 .44644 m .56071 .45179 L .54979 .45631 L p F P
0 g
s
.772 .623 .695 r
.2573 .46394 m .25781 .46319 L .25524 .45606 L p F P
0 g
s
.631 .508 .695 r
.55164 .46341 m .54983 .45645 L .56122 .45363 L p F P
0 g
s
.634 .519 .705 r
.56071 .45179 m .56122 .45363 L .54983 .45645 L p F P
0 g
s
.697 .648 .798 r
.4176 .36459 m .4084 .3648 L .40739 .36294 L p F P
0 g
s
.701 .65 .796 r
.4084 .3648 m .40739 .36294 L .40405 .3648 L closepath p F P
0 g
s
.701 .652 .798 r
.40436 .3575 m .40739 .36294 L .40405 .3648 L p F P
0 g
s
.701 .652 .798 r
.39362 .36345 m .40436 .3575 L p .40405 .3648 L F P
0 g
s
.701 .652 .798 r
.40405 .3648 m .39435 .36475 L .39362 .36345 L p F P
0 g
s
.761 .652 .741 r
.26084 .41642 m .26823 .41821 L .26147 .42534 L p F P
0 g
s
.76 .654 .745 r
.26758 .40957 m .26084 .41642 L .26823 .41821 L p F P
0 g
s
.65 .387 .508 r
.45364 .53274 m .46155 .53215 L .46107 .53691 L p F P
0 g
s
.65 .387 .508 r
.46107 .53691 m .45566 .53731 L .45364 .53274 L p F P
0 g
s
.706 .654 .796 r
.39435 .36475 m .39362 .36345 L .39151 .36467 L closepath p F P
0 g
s
.773 .597 .66 r
.26285 .47923 m .2574 .47801 L p .26189 .48569 L F P
0 g
s
.773 .597 .66 r
.26189 .48569 m .26364 .48229 L .26285 .47923 L p F P
0 g
s
.728 .661 .784 r
.32774 .37595 m .33416 .37142 L .34069 .37232 L p F P
0 g
s
.726 .664 .788 r
.34069 .37232 m .33848 .36846 L .33416 .37142 L closepath p F P
0 g
s
.774 .617 .685 r
.24994 .46218 m .2573 .46394 L .25342 .47018 L p F P
0 g
s
.772 .623 .695 r
.25423 .45582 m .24994 .46218 L .2573 .46394 L p F P
0 g
s
.772 .623 .695 r
.25524 .45606 m .25423 .45582 L p .2573 .46394 L F P
0 g
s
.663 .602 .776 r
.50792 .37633 m .50965 .38021 L .4988 .38485 L p F P
0 g
s
.663 .602 .776 r
.4988 .38485 m .49603 .37865 L .50792 .37633 L p F P
0 g
s
.656 .589 .768 r
.52637 .38933 m .52776 .39262 L .51612 .39521 L p F P
0 g
s
.656 .589 .768 r
.51612 .39521 m .5155 .39373 L .52637 .38933 L p F P
0 g
s
.706 .655 .797 r
.39059 .35806 m .39362 .36345 L .39151 .36467 L p F P
0 g
s
.706 .655 .797 r
.37986 .36422 m .39059 .35806 L p .39151 .36467 L F P
0 g
s
.706 .655 .797 r
.39151 .36467 m .3799 .3643 L .37986 .36422 L p F P
0 g
s
.682 .631 .792 r
.46243 .36369 m .45164 .36891 L .44866 .36304 L p F P
0 g
s
.714 .439 .508 r
.36245 .53808 m .35179 .53739 L .35067 .53259 L p F P
0 g
s
.715 .44 .508 r
.34985 .53254 m .35067 .53259 L .35179 .53739 L p F P
0 g
s
.696 .646 .796 r
.4221 .36447 m .42114 .3627 L .4176 .36459 L closepath p F P
0 g
s
.697 .648 .798 r
.41814 .35721 m .42114 .3627 L .4176 .36459 L p F P
0 g
s
.697 .648 .798 r
.40739 .36294 m .41814 .35721 L p .4176 .36459 L F P
0 g
s
.676 .625 .79 r
.4762 .36463 m .47912 .37053 L .46668 .37222 L p F P
0 g
s
.676 .625 .79 r
.46668 .37222 m .46539 .36961 L .4762 .36463 L p F P
0 g
s
.745 .662 .769 r
.28924 .38994 m .29415 .38587 L .30211 .38749 L p F P
0 g
s
.743 .665 .774 r
.30003 .38114 m .29415 .38587 L .30211 .38749 L p F P
0 g
s
.743 .665 .774 r
.30211 .38749 m .30314 .38667 L .30003 .38114 L p F P
0 g
s
.715 .44 .508 r
.35179 .53739 m .34912 .53722 L .34985 .53254 L p F P
0 g
s
.723 .447 .509 r
.34055 .53174 m .34985 .53254 L .34912 .53722 L p F P
0 g
s
.628 .456 .631 r
.53401 .49601 m .53692 .49372 L .53378 .49435 L closepath p F P
0 g
s
.635 .463 .632 r
.53378 .49435 m .53401 .49601 L .52761 .50164 L p F P
0 g
s
.728 .662 .785 r
.33416 .37142 m .32774 .37595 L .32465 .37046 L p F P
0 g
s
.739 .665 .777 r
.31292 .37905 m .30314 .38667 L .30003 .38114 L p F P
0 g
s
.766 .557 .615 r
.28547 .50871 m .27911 .50756 L .28084 .50195 L p F P
0 g
s
.767 .558 .616 r
.27274 .50046 m .28084 .50195 L .27911 .50756 L p F P
0 g
s
.769 .636 .714 r
.25699 .44086 m .2518 .44734 L .24874 .44017 L p F P
0 g
s
.769 .636 .714 r
.24874 .44017 m .2496 .43908 L .25699 .44086 L p F P
0 g
s
.767 .642 .723 r
.25699 .44086 m .2496 .43908 L .25534 .43228 L p F P
0 g
s
.692 .644 .798 r
.43251 .36396 m .4221 .36447 L .42114 .3627 L p F P
0 g
s
.67 .613 .783 r
.4821 .37684 m .49293 .37202 L p .49443 .37892 L F P
0 g
s
.67 .613 .782 r
.49293 .37202 m .4821 .37684 L .47915 .37059 L p F P
0 g
s
.754 .662 .759 r
.28019 .40264 m .27843 .39938 L .27594 .40165 L closepath p F P
0 g
s
.773 .597 .66 r
.26466 .48628 m .26364 .48229 L .26189 .48569 L closepath p F P
0 g
s
.772 .63 .704 r
.25524 .45606 m .25482 .45501 L .25423 .45582 L closepath p F P
0 g
s
.656 .588 .766 r
.52637 .38933 m .5155 .39373 L .51257 .38684 L p F P
0 g
s
.646 .563 .747 r
.53514 .41135 m .54452 .40768 L p .54452 .41675 L F P
0 g
s
.646 .564 .748 r
.53514 .41135 m .54452 .40768 L .53468 .41011 L closepath p F P
0 g
s
.747 .511 .574 r
.30268 .52238 m .30332 .51712 L p .31178 .52359 L F P
0 g
s
.749 .513 .574 r
.30268 .52238 m .30332 .51712 L .30269 .51704 L closepath p F P
0 g
s
.736 .482 .545 r
.33064 .53083 m .32106 .52981 L .32095 .52473 L p F P
0 g
s
.738 .483 .544 r
.31897 .52451 m .32095 .52473 L .32106 .52981 L p F P
0 g
s
.772 .631 .704 r
.25423 .45582 m .25482 .45501 L .25191 .44761 L p F P
0 g
s
.711 .657 .795 r
.3799 .3643 m .37986 .36422 L .37974 .36429 L closepath p F P
0 g
s
.755 .518 .573 r
.30269 .51704 m .2947 .5158 L p .30267 .52242 L F P
0 g
s
.755 .518 .573 r
.30267 .52242 m .30268 .52238 L .30269 .51704 L p F P
0 g
s
.712 .657 .793 r
.36608 .36534 m .36891 .3636 L .37974 .36429 L p F P
0 g
s
.712 .661 .798 r
.37681 .3589 m .36891 .3636 L .37974 .36429 L p F P
0 g
s
.712 .661 .798 r
.37974 .36429 m .37986 .36422 L .37681 .3589 L p F P
0 g
s
.648 .571 .755 r
.54452 .40768 m .53468 .41011 L .53221 .40374 L p F P
0 g
s
.702 .655 .8 r
.40436 .3575 m .39362 .36345 L .39059 .35806 L p F P
0 g
s
.707 .658 .8 r
.39059 .35806 m .37986 .36422 L .37681 .3589 L p F P
0 g
s
.763 .646 .732 r
.25976 .42723 m .26147 .42534 L .25856 .42466 L closepath p F P
0 g
s
.761 .652 .741 r
.25666 .42082 m .26084 .41642 L p .26147 .42534 L F P
0 g
s
.761 .652 .741 r
.26147 .42534 m .25856 .42466 L .25666 .42082 L p F P
0 g
s
.635 .398 .541 r
.48718 .52457 m .49142 .52404 L .4922 .52899 L p F P
0 g
s
.635 .398 .541 r
.4922 .52899 m .48705 .52963 L .48718 .52457 L p F P
0 g
s
.643 .404 .542 r
.48718 .52457 m .48705 .52963 L .47441 .53101 L p F P
0 g
s
.774 .626 .696 r
.24697 .45402 m .25423 .45582 L .24994 .46218 L p F P
0 g
s
.772 .631 .704 r
.25165 .44754 m .24697 .45402 L .25423 .45582 L p F P
0 g
s
.772 .631 .704 r
.25191 .44761 m .25165 .44754 L p .25423 .45582 L F P
0 g
s
.63 .446 .614 r
.52761 .50164 m .53463 .50034 L p .52339 .50832 L F P
0 g
s
.63 .446 .614 r
.52339 .50832 m .52318 .50649 L .52761 .50164 L p F P
0 g
s
.634 .46 .63 r
.53463 .50034 m .53401 .49601 L .52761 .50164 L closepath p F P
0 g
s
.697 .651 .8 r
.41814 .35721 m .40739 .36294 L .40436 .3575 L p F P
0 g
s
.643 .38 .506 r
.46155 .53215 m .47152 .53127 L .47373 .5358 L p F P
0 g
s
.643 .38 .506 r
.47373 .5358 m .46107 .53691 L .46155 .53215 L p F P
0 g
s
.738 .483 .544 r
.32106 .52981 m .31859 .52954 L .31897 .52451 L p F P
0 g
s
.746 .49 .545 r
.31178 .52359 m .31897 .52451 L .31859 .52954 L p F P
0 g
s
.629 .499 .685 r
.55276 .46802 m .55164 .46341 L .56305 .4606 L p F P
0 g
s
.631 .508 .695 r
.56122 .45363 m .56305 .4606 L .55164 .46341 L p F P
0 g
s
.713 .657 .793 r
.36608 .36534 m .36891 .3636 L .36495 .36335 L closepath p F P
0 g
s
.717 .66 .792 r
.36495 .36335 m .36608 .36534 L p .35228 .36676 L F P
0 g
s
.768 .584 .649 r
.26696 .49318 m .26612 .49302 L .26466 .48628 L p F P
0 g
s
.775 .588 .647 r
.26189 .48569 m .26466 .48628 L .26612 .49302 L p F P
0 g
s
.767 .647 .73 r
.25534 .43228 m .25976 .42723 L .25856 .42466 L p F P
0 g
s
.737 .665 .78 r
.31448 .37933 m .3139 .37831 L .31292 .37905 L closepath p F P
0 g
s
.628 .456 .631 r
.53463 .50034 m .53401 .49601 L .53692 .49372 L p F P
0 g
s
.691 .642 .796 r
.43547 .36379 m .4349 .36273 L .43251 .36396 L closepath p F P
0 g
s
.692 .644 .798 r
.43191 .35718 m .4349 .36273 L .43251 .36396 L p F P
0 g
s
.692 .644 .798 r
.42114 .3627 m .43191 .35718 L p .43251 .36396 L F P
0 g
s
.759 .538 .597 r
.28547 .50871 m .28734 .50901 L .28607 .51448 L p F P
0 g
s
.757 .536 .597 r
.2947 .5158 m .28607 .51448 L .28734 .50901 L p F P
0 g
s
.692 .647 .8 r
.43191 .35718 m .42114 .3627 L .41814 .35721 L p F P
0 g
s
.632 .472 .647 r
.54443 .48576 m .54487 .48831 L .53692 .49372 L p F P
0 g
s
.628 .456 .631 r
.53692 .49372 m .5455 .49195 L p .53463 .50034 L F P
0 g
s
.631 .47 .646 r
.5455 .49195 m .54487 .48831 L .53692 .49372 L closepath p F P
0 g
s
.676 .625 .791 r
.4762 .36463 m .46539 .36961 L .46243 .36369 L p F P
0 g
s
.686 .64 .798 r
.44568 .35743 m .44853 .36278 L .43547 .36379 L p F P
0 g
s
.686 .64 .798 r
.43547 .36379 m .4349 .36273 L .44568 .35743 L p F P
0 g
s
.728 .662 .785 r
.32465 .37046 m .32506 .37017 L .33416 .37142 L p F P
0 g
s
.727 .666 .79 r
.33539 .36313 m .32506 .37017 L .33416 .37142 L p F P
0 g
s
.727 .666 .79 r
.33416 .37142 m .33848 .36846 L .33539 .36313 L p F P
0 g
s
.739 .665 .777 r
.30003 .38114 m .30471 .37751 L .31292 .37905 L p F P
0 g
s
.738 .668 .782 r
.31079 .37291 m .30471 .37751 L .31292 .37905 L p F P
0 g
s
.738 .668 .782 r
.31292 .37905 m .3139 .37831 L .31079 .37291 L p F P
0 g
s
.636 .45 .614 r
.52339 .50832 m .52318 .50649 L .5214 .50865 L closepath p F P
0 g
s
.717 .66 .792 r
.35228 .36676 m .35856 .36276 L .34954 .36193 L closepath p F P
0 g
s
.717 .66 .792 r
.35228 .36676 m .35856 .36276 L .36495 .36335 L p F P
0 g
s
.734 .667 .785 r
.32465 .37046 m .3139 .37831 L .31079 .37291 L p F P
0 g
s
.723 .447 .509 r
.34912 .53722 m .34156 .53657 L .34055 .53174 L p F P
0 g
s
.723 .448 .509 r
.33443 .53122 m .34055 .53174 L .34156 .53657 L p F P
0 g
s
.669 .611 .781 r
.49603 .37865 m .49586 .37829 L .49443 .37892 L closepath p F P
0 g
s
.67 .613 .783 r
.49293 .37202 m .49586 .37829 L .49443 .37892 L p F P
0 g
s
.633 .396 .542 r
.49142 .52404 m .49962 .52298 L .49951 .52804 L p F P
0 g
s
.633 .396 .542 r
.49951 .52804 m .4922 .52899 L .49142 .52404 L p F P
0 g
s
.711 .662 .8 r
.37375 .35361 m .37681 .3589 L .36891 .3636 L p F P
0 g
s
.711 .662 .8 r
.36301 .36 m .37375 .35361 L p .36891 .3636 L F P
0 g
s
.711 .662 .8 r
.36891 .3636 m .36495 .36335 L .36301 .36 L p F P
0 g
s
.772 .638 .713 r
.25191 .44761 m .2518 .44734 L .25165 .44754 L closepath p F P
0 g
s
.648 .571 .755 r
.53221 .40374 m .54312 .39952 L p .54452 .40768 L F P
0 g
s
.648 .572 .755 r
.54279 .39869 m .54312 .39952 L .53221 .40374 L p F P
0 g
s
.648 .572 .755 r
.53221 .40374 m .53135 .40151 L .54279 .39869 L p F P
0 g
s
.759 .538 .597 r
.28607 .51448 m .28584 .51444 L .28547 .50871 L p F P
0 g
s
.767 .544 .596 r
.27911 .50756 m .28547 .50871 L .28584 .51444 L p F P
0 g
s
.767 .647 .73 r
.25856 .42466 m .25417 .42353 L p .25534 .43228 L F P
0 g
s
.766 .654 .738 r
.25856 .42466 m .25666 .42082 L .25417 .42353 L closepath p F P
0 g
s
.772 .639 .714 r
.25165 .44754 m .2518 .44734 L .24874 .44017 L p F P
0 g
s
.625 .466 .647 r
.54487 .48831 m .55183 .48411 L .54443 .48576 L closepath p F P
0 g
s
.768 .645 .726 r
.24808 .43045 m .25534 .43228 L .2496 .43908 L p F P
0 g
s
.767 .647 .73 r
.25417 .42353 m .24808 .43045 L .25534 .43228 L p F P
0 g
s
.628 .498 .685 r
.55329 .47019 m .55276 .46802 L .56368 .46323 L p F P
0 g
s
.629 .499 .685 r
.56305 .4606 m .56368 .46323 L .55276 .46802 L p F P
0 g
s
.774 .634 .705 r
.2445 .44569 m .25165 .44754 L .24697 .45402 L p F P
0 g
s
.772 .639 .714 r
.24874 .44017 m .2445 .44569 L .25165 .44754 L p F P
0 g
s
.631 .431 .593 r
.5214 .50865 m .52339 .50832 L .5238 .51387 L p F P
0 g
s
.631 .431 .593 r
.5238 .51387 m .5179 .51486 L .5214 .50865 L p F P
0 g
s
.668 .37 .459 r
.40734 .53921 m .41055 .53917 L .41344 .54348 L p F P
0 g
s
.668 .37 .459 r
.41344 .54348 m .40634 .54357 L .40734 .53921 L p F P
0 g
s
.676 .378 .461 r
.39759 .53918 m .40734 .53921 L .40634 .54357 L p F P
0 g
s
.676 .378 .461 r
.40634 .54357 m .40026 .54355 L .39759 .53918 L p F P
0 g
s
.677 .378 .46 r
.39325 .53915 m .39759 .53918 L .40026 .54355 L p F P
0 g
s
.755 .66 .756 r
.26849 .39987 m .27594 .40165 L .26798 .40917 L p F P
0 g
s
.755 .663 .76 r
.27531 .39362 m .26849 .39987 L .27594 .40165 L p F P
0 g
s
.755 .663 .76 r
.27594 .40165 m .27843 .39938 L .27531 .39362 L p F P
0 g
s
.666 .37 .46 r
.41055 .53917 m .42114 .539 L .42018 .54338 L p F P
0 g
s
.666 .37 .46 r
.42018 .54338 m .41344 .54348 L .41055 .53917 L p F P
0 g
s
.751 .661 .762 r
.28463 .3939 m .27843 .39938 L .27531 .39362 L p F P
0 g
s
.775 .588 .647 r
.26612 .49302 m .25927 .49155 L .26189 .48569 L p F P
0 g
s
.775 .59 .649 r
.25431 .48401 m .26189 .48569 L .25927 .49155 L p F P
0 g
s
.773 .597 .66 r
.2574 .47801 m .25431 .48401 L .26189 .48569 L p F P
0 g
s
.687 .643 .8 r
.44568 .35743 m .4349 .36273 L .43191 .35718 L p F P
0 g
s
.677 .378 .46 r
.40026 .54355 m .39223 .5435 L .39325 .53915 L p F P
0 g
s
.686 .387 .462 r
.38534 .53897 m .39325 .53915 L .39223 .5435 L p F P
0 g
s
.775 .6 .663 r
.24989 .47631 m .2574 .47801 L .25431 .48401 L p F P
0 g
s
.774 .607 .672 r
.25342 .47018 m .24989 .47631 L .2574 .47801 L p F P
0 g
s
.664 .608 .783 r
.50672 .37373 m .50792 .37633 L .49603 .37865 L p F P
0 g
s
.664 .608 .783 r
.49603 .37865 m .49586 .37829 L .50672 .37373 L p F P
0 g
s
.716 .664 .797 r
.36495 .36335 m .36301 .36 L .35856 .36276 L closepath p F P
0 g
s
.751 .661 .762 r
.27531 .39362 m .27693 .39219 L .28463 .3939 L p F P
0 g
s
.749 .664 .767 r
.28613 .38429 m .27693 .39219 L .28463 .3939 L p F P
0 g
s
.749 .664 .767 r
.28463 .3939 m .28924 .38994 L .28613 .38429 L p F P
0 g
s
.755 .66 .756 r
.26446 .40368 m .26849 .39987 L p .26798 .40917 L F P
0 g
s
.755 .66 .756 r
.26798 .40917 m .2673 .40901 L .26446 .40368 L p F P
0 g
s
.758 .655 .748 r
.26758 .40957 m .26798 .40917 L .2673 .40901 L closepath p F P
0 g
s
.76 .658 .749 r
.2673 .40901 m .26758 .40957 L .26084 .41642 L p F P
0 g
s
.649 .579 .762 r
.5402 .39224 m .54279 .39869 L .53135 .40151 L p F P
0 g
s
.649 .579 .762 r
.53135 .40151 m .52929 .39642 L .5402 .39224 L p F P
0 g
s
.767 .572 .634 r
.2664 .49461 m .26696 .49318 L p .27274 .50046 L F P
0 g
s
.769 .573 .633 r
.2664 .49461 m .26696 .49318 L .26612 .49302 L closepath p F P
0 g
s
.665 .61 .784 r
.50672 .37373 m .49586 .37829 L .49293 .37202 L p F P
0 g
s
.658 .362 .458 r
.42114 .539 m .42439 .5389 L .42752 .54315 L p F P
0 g
s
.658 .362 .458 r
.42752 .54315 m .42018 .54338 L .42114 .539 L p F P
0 g
s
.644 .555 .739 r
.54452 .41675 m .54916 .41559 L p .54949 .42428 L F P
0 g
s
.645 .562 .747 r
.54916 .41559 m .54896 .41504 L .54452 .41675 L closepath p F P
0 g
s
.646 .563 .747 r
.54611 .40728 m .54896 .41504 L .54452 .41675 L p F P
0 g
s
.646 .563 .747 r
.54452 .40768 m .54611 .40728 L p .54452 .41675 L F P
0 g
s
.686 .387 .462 r
.39223 .5435 m .38781 .5434 L .38534 .53897 L p F P
0 g
s
.687 .387 .462 r
.37888 .53881 m .38534 .53897 L .38781 .5434 L p F P
0 g
s
.723 .667 .794 r
.34853 .36181 m .33848 .36846 L .33539 .36313 L p F P
0 g
s
.625 .486 .673 r
.55473 .47677 m .55329 .47019 L .56468 .46738 L p F P
0 g
s
.628 .498 .685 r
.56368 .46323 m .56468 .46738 L .55329 .47019 L p F P
0 g
s
.656 .588 .766 r
.52387 .3834 m .52637 .38933 L p .51257 .38684 L F P
0 g
s
.656 .588 .766 r
.51257 .38684 m .51756 .3848 L .52387 .3834 L p F P
0 g
s
.657 .593 .771 r
.51257 .38684 m .51756 .3848 L .5122 .38598 L closepath p F P
0 g
s
.775 .611 .676 r
.246 .46844 m .25342 .47018 L .24989 .47631 L p F P
0 g
s
.774 .617 .685 r
.25342 .47018 m .246 .46844 L .24994 .46218 L p F P
0 g
s
.745 .663 .77 r
.29415 .38587 m .28924 .38994 L .28613 .38429 L p F P
0 g
s
.641 .38 .508 r
.47152 .53127 m .47441 .53101 L .47396 .53578 L p F P
0 g
s
.641 .38 .508 r
.47396 .53578 m .47373 .5358 L .47152 .53127 L p F P
0 g
s
.761 .662 .753 r
.2673 .40901 m .26446 .40368 L .26071 .40733 L closepath p F P
0 g
s
.76 .658 .749 r
.26071 .40733 m .2673 .40901 L p .26084 .41642 L F P
0 g
s
.656 .362 .46 r
.42439 .5389 m .43468 .53854 L .43376 .54293 L p F P
0 g
s
.656 .362 .46 r
.43376 .54293 m .42752 .54315 L .42439 .5389 L p F P
0 g
s
.643 .554 .739 r
.55199 .42366 m .55188 .42334 L .54949 .42428 L closepath p F P
0 g
s
.644 .555 .739 r
.54916 .41559 m .55188 .42334 L .54949 .42428 L p F P
0 g
s
.623 .425 .593 r
.5238 .51387 m .52339 .50832 L .53527 .50611 L p F P
0 g
s
.63 .446 .614 r
.53463 .50034 m .53527 .50611 L .52339 .50832 L p F P
0 g
s
.774 .576 .632 r
.26612 .49302 m .25927 .49155 L p .26476 .49892 L F P
0 g
s
.774 .576 .632 r
.26476 .49892 m .2664 .49461 L .26612 .49302 L p F P
0 g
s
.746 .49 .545 r
.31859 .52954 m .31186 .52867 L .31178 .52359 L p F P
0 g
s
.745 .49 .544 r
.30268 .52242 m .31178 .52359 L .31186 .52867 L p F P
0 g
s
.747 .511 .574 r
.31178 .52359 m .30268 .52242 L .30268 .52238 L p F P
0 g
s
.723 .448 .509 r
.34156 .53657 m .33367 .5359 L .33443 .53122 L p F P
0 g
s
.732 .456 .51 r
.33064 .53083 m .33443 .53122 L .33367 .5359 L p F P
0 g
s
.687 .387 .462 r
.38781 .5434 m .37782 .54315 L .37888 .53881 L p F P
0 g
s
.695 .396 .464 r
.37367 .53859 m .37888 .53881 L .37782 .54315 L p F P
0 g
s
.658 .599 .777 r
.51756 .3848 m .5122 .38598 L .50965 .38021 L p F P
0 g
s
.626 .411 .57 r
.51172 .51587 m .5179 .51486 L .51656 .52044 L p F P
0 g
s
.626 .411 .57 r
.51656 .52044 m .51189 .52119 L .51172 .51587 L p F P
0 g
s
.634 .416 .57 r
.51172 .51587 m .51189 .52119 L .49962 .52298 L p F P
0 g
s
.755 .518 .573 r
.2947 .5158 m .29407 .52109 L .30267 .52242 L p F P
0 g
s
.756 .519 .573 r
.28607 .51448 m .2947 .5158 L .29407 .52109 L p F P
0 g
s
.744 .666 .775 r
.29652 .37595 m .28618 .38425 L .29415 .38587 L p F P
0 g
s
.744 .666 .775 r
.29717 .37609 m .29652 .37595 L p .29415 .38587 L F P
0 g
s
.744 .666 .775 r
.29415 .38587 m .30003 .38114 L .29717 .37609 L p F P
0 g
s
.745 .663 .77 r
.28613 .38429 m .28618 .38425 L .29415 .38587 L p F P
0 g
s
.763 .653 .74 r
.25666 .42082 m .26084 .41642 L .25361 .41465 L closepath p F P
0 g
s
.76 .658 .749 r
.25355 .41455 m .26071 .40733 L p .26084 .41642 L F P
0 g
s
.76 .658 .749 r
.26084 .41642 m .25361 .41465 L .25355 .41455 L p F P
0 g
s
.67 .613 .782 r
.49127 .36851 m .49293 .37202 L p .47915 .37059 L F P
0 g
s
.67 .613 .782 r
.47915 .37059 m .47938 .37049 L .49127 .36851 L p F P
0 g
s
.672 .618 .786 r
.47915 .37059 m .47938 .37049 L .47912 .37053 L closepath p F P
0 g
s
.767 .558 .616 r
.27911 .50756 m .27097 .50608 L .27274 .50046 L p F P
0 g
s
.768 .56 .617 r
.26722 .49943 m .27274 .50046 L .27097 .50608 L p F P
0 g
s
.767 .572 .634 r
.27274 .50046 m .26722 .49943 L .2664 .49461 L p F P
0 g
s
.672 .624 .792 r
.47938 .37049 m .47912 .37053 L .4762 .36463 L p F P
0 g
s
.625 .466 .646 r
.5455 .49195 m .54487 .48831 L .55183 .48411 L p F P
0 g
s
.633 .373 .507 r
.47396 .53578 m .47441 .53101 L .48705 .52963 L p F P
0 g
s
.683 .635 .795 r
.44866 .36304 m .44936 .3627 L .44853 .36278 L closepath p F P
0 g
s
.682 .631 .792 r
.46127 .36141 m .46243 .36369 L p .44866 .36304 L F P
0 g
s
.682 .631 .792 r
.44866 .36304 m .44936 .3627 L .46127 .36141 L p F P
0 g
s
.671 .621 .79 r
.49127 .36851 m .48998 .36586 L .47938 .37049 L closepath p F P
0 g
s
.672 .624 .792 r
.48703 .35986 m .48998 .36586 L .47938 .37049 L p F P
0 g
s
.672 .624 .792 r
.4762 .36463 m .48703 .35986 L p .47938 .37049 L F P
0 g
s
.775 .62 .688 r
.24262 .4604 m .24994 .46218 L .246 .46844 L p F P
0 g
s
.774 .626 .696 r
.24994 .46218 m .24262 .4604 L .24697 .45402 L p F P
0 g
s
.695 .389 .454 r
.36419 .53818 m .37367 .53859 L .37594 .54307 L p F P
0 g
s
.695 .396 .464 r
.37782 .54315 m .37594 .54307 L .37367 .53859 L p F P
0 g
s
.774 .576 .632 r
.26722 .49943 m .2664 .49461 L .26476 .49892 L closepath p F P
0 g
s
.683 .64 .801 r
.44936 .3627 m .44853 .36278 L .44568 .35743 L p F P
0 g
s
.622 .439 .613 r
.53527 .50611 m .53463 .50034 L .54636 .49793 L p F P
0 g
s
.628 .456 .631 r
.5455 .49195 m .54636 .49793 L .53463 .50034 L p F P
0 g
s
.649 .354 .458 r
.43468 .53854 m .43934 .53831 L .44273 .54249 L p F P
0 g
s
.649 .354 .458 r
.44273 .54249 m .43376 .54293 L .43468 .53854 L p F P
0 g
s
.716 .665 .799 r
.35994 .35477 m .36301 .36 L .35856 .36276 L p F P
0 g
s
.716 .665 .799 r
.34921 .36137 m .35994 .35477 L p .35856 .36276 L F P
0 g
s
.716 .665 .799 r
.35856 .36276 m .34954 .36193 L .34921 .36137 L p F P
0 g
s
.683 .64 .801 r
.45648 .35232 m .45946 .35794 L .44936 .3627 L p F P
0 g
s
.683 .64 .801 r
.44568 .35743 m .45648 .35232 L p .44936 .3627 L F P
0 g
s
.681 .637 .799 r
.46127 .36141 m .45946 .35794 L .44936 .3627 L closepath p F P
0 g
s
.633 .534 .724 r
.55482 .43215 m .56248 .42935 L .5546 .43147 L closepath p F P
0 g
s
.636 .543 .732 r
.56248 .42935 m .5546 .43147 L .55199 .42366 L p F P
0 g
s
.732 .456 .51 r
.33367 .5359 m .33156 .53568 L .33064 .53083 L p F P
0 g
s
.733 .455 .508 r
.32106 .52981 m .33064 .53083 L .33156 .53568 L p F P
0 g
s
.633 .533 .723 r
.557 .43906 m .55482 .43215 L .56248 .42935 L p F P
0 g
s
.77 .639 .715 r
.24874 .44017 m .2496 .43908 L .24813 .43872 L closepath p F P
0 g
s
.768 .645 .726 r
.24566 .43333 m .24808 .43045 L p .2496 .43908 L F P
0 g
s
.768 .645 .726 r
.2496 .43908 m .24813 .43872 L .24566 .43333 L p F P
0 g
s
.633 .533 .723 r
.56584 .42843 m .56824 .43603 L .557 .43906 L p F P
0 g
s
.633 .533 .723 r
.56248 .42935 m .56584 .42843 L p .557 .43906 L F P
0 g
s
.631 .525 .715 r
.55776 .44159 m .557 .43906 L .56824 .43603 L p F P
0 g
s
.767 .654 .738 r
.25417 .42353 m .25666 .42082 L .25361 .41465 L p F P
0 g
s
.65 .58 .763 r
.53921 .38979 m .5402 .39224 L .52929 .39642 L p F P
0 g
s
.65 .58 .763 r
.52929 .39642 m .52776 .39262 L .53921 .38979 L p F P
0 g
s
.739 .665 .777 r
.30003 .38114 m .30471 .37751 L .29717 .37609 L closepath p F P
0 g
s
.728 .664 .786 r
.32465 .37046 m .32506 .37017 L .32443 .37007 L closepath p F P
0 g
s
.734 .667 .785 r
.32443 .37007 m .32465 .37046 L p .31079 .37291 L F P
0 g
s
.631 .524 .715 r
.5592 .44644 m .55776 .44159 L .5687 .43757 L p F P
0 g
s
.631 .525 .715 r
.56824 .43603 m .5687 .43757 L .55776 .44159 L p F P
0 g
s
.726 .668 .793 r
.3335 .35991 m .33539 .36313 L .32506 .37017 L p F P
0 g
s
.726 .668 .793 r
.33006 .35937 m .3335 .35991 L p .32506 .37017 L F P
0 g
s
.726 .668 .793 r
.32154 .36519 m .33006 .35937 L p .32506 .37017 L F P
0 g
s
.726 .668 .793 r
.32506 .37017 m .32443 .37007 L .32154 .36519 L p F P
0 g
s
.647 .354 .46 r
.43934 .53831 m .44798 .53784 L .44711 .54225 L p F P
0 g
s
.647 .354 .46 r
.44711 .54225 m .44273 .54249 L .43934 .53831 L p F P
0 g
s
.636 .543 .732 r
.55199 .42366 m .56323 .4206 L p .56248 .42935 L F P
0 g
s
.637 .551 .74 r
.56282 .41944 m .56323 .4206 L .55199 .42366 L p F P
0 g
s
.637 .551 .74 r
.55199 .42366 m .55188 .42334 L .56282 .41944 L p F P
0 g
s
.638 .551 .74 r
.5604 .41253 m .56282 .41944 L .55188 .42334 L p F P
0 g
s
.638 .551 .74 r
.55188 .42334 m .54916 .41559 L .5604 .41253 L p F P
0 g
s
.774 .64 .713 r
.2445 .44569 m .24874 .44017 L .24813 .43872 L p F P
0 g
s
.626 .39 .541 r
.49951 .52804 m .49962 .52298 L .51189 .52119 L p F P
0 g
s
.734 .667 .785 r
.31079 .37291 m .31656 .36871 L .32443 .37007 L p F P
0 g
s
.732 .67 .79 r
.32443 .37007 m .32154 .36519 L .31656 .36871 L closepath p F P
0 g
s
.768 .652 .734 r
.24705 .42165 m .25417 .42353 L .24808 .43045 L p F P
0 g
s
.767 .654 .738 r
.25349 .41462 m .24705 .42165 L .25417 .42353 L p F P
0 g
s
.767 .654 .738 r
.25361 .41465 m .25349 .41462 L p .25417 .42353 L F P
0 g
s
.695 .389 .454 r
.36359 .54062 m .36419 .53818 L p .37594 .54307 L F P
0 g
s
.705 .407 .468 r
.36359 .54062 m .36245 .53808 L .36419 .53818 L closepath p F P
0 g
s
.628 .515 .706 r
.56071 .45179 m .5592 .44644 L .57044 .44341 L p F P
0 g
s
.631 .524 .715 r
.5687 .43757 m .57044 .44341 L .5592 .44644 L p F P
0 g
s
.767 .544 .596 r
.28584 .51444 m .2779 .51301 L .27911 .50756 L p F P
0 g
s
.766 .544 .597 r
.27097 .50608 m .27911 .50756 L .2779 .51301 L p F P
0 g
s
.775 .629 .698 r
.23976 .45219 m .24697 .45402 L .24262 .4604 L p F P
0 g
s
.774 .634 .705 r
.24697 .45402 m .23976 .45219 L .2445 .44569 L p F P
0 g
s
.774 .647 .722 r
.24813 .43872 m .24566 .43333 L .2425 .43721 L closepath p F P
0 g
s
.774 .64 .713 r
.24813 .43872 m .2425 .43721 L p .2445 .44569 L F P
0 g
s
.706 .402 .459 r
.36245 .53808 m .36359 .54062 L .36307 .54249 L p F P
0 g
s
.706 .402 .459 r
.35179 .53739 m .36245 .53808 L p .36307 .54249 L F P
0 g
s
.702 .655 .8 r
.40166 .35268 m .40436 .3575 L p .39059 .35806 L F P
0 g
s
.702 .655 .8 r
.39059 .35806 m .40034 .35266 L .40166 .35268 L p F P
0 g
s
.702 .659 .805 r
.40034 .35266 m .39059 .35806 L .38755 .35272 L p F P
0 g
s
.707 .658 .8 r
.37681 .3589 m .38755 .35272 L .39059 .35806 L p F P
0 g
s
.737 .669 .784 r
.30768 .36753 m .31079 .37291 L .30471 .37751 L p F P
0 g
s
.737 .669 .784 r
.29691 .37564 m .30768 .36753 L p .30471 .37751 L F P
0 g
s
.737 .669 .784 r
.30471 .37751 m .29717 .37609 L .29691 .37564 L p F P
0 g
s
.707 .663 .804 r
.38755 .35272 m .37681 .3589 L .37375 .35361 L p F P
0 g
s
.698 .653 .802 r
.40436 .3575 m .41365 .35254 L .40166 .35268 L closepath p F P
0 g
s
.697 .651 .8 r
.41554 .35251 m .41814 .35721 L p .40436 .3575 L F P
0 g
s
.697 .651 .8 r
.40436 .3575 m .41365 .35254 L .41554 .35251 L p F P
0 g
s
.676 .625 .791 r
.47377 .35976 m .4762 .36463 L p .46243 .36369 L F P
0 g
s
.676 .625 .791 r
.46243 .36369 m .46971 .36032 L .47377 .35976 L p F P
0 g
s
.678 .63 .794 r
.46243 .36369 m .46971 .36032 L .46127 .36141 L closepath p F P
0 g
s
.622 .475 .662 r
.55576 .48197 m .55473 .47677 L .56614 .47397 L p F P
0 g
s
.625 .486 .673 r
.56468 .46738 m .56614 .47397 L .55473 .47677 L p F P
0 g
s
.629 .48 .661 r
.55473 .47677 m .55576 .48197 L .55183 .48411 L p F P
0 g
s
.64 .559 .748 r
.55989 .41115 m .5604 .41253 L .54916 .41559 L p F P
0 g
s
.64 .559 .748 r
.54916 .41559 m .54896 .41504 L .55989 .41115 L p F P
0 g
s
.651 .587 .77 r
.53728 .38519 m .53921 .38979 L .52776 .39262 L p F P
0 g
s
.651 .587 .77 r
.52776 .39262 m .52637 .38933 L .53728 .38519 L p F P
0 g
s
.64 .559 .748 r
.55735 .40421 m .55989 .41115 L .54896 .41504 L p F P
0 g
s
.64 .559 .748 r
.54896 .41504 m .54611 .40728 L .55735 .40421 L p F P
0 g
s
.712 .667 .803 r
.37375 .35361 m .36301 .36 L .35994 .35477 L p F P
0 g
s
.628 .515 .706 r
.56122 .45363 m .56071 .45179 L .57166 .44774 L p F P
0 g
s
.628 .515 .706 r
.57044 .44341 m .57166 .44774 L .56071 .45179 L p F P
0 g
s
.639 .347 .459 r
.44798 .53784 m .45566 .53731 L .45935 .54141 L p F P
0 g
s
.639 .347 .459 r
.45935 .54141 m .44711 .54225 L .44798 .53784 L p F P
0 g
s
.619 .45 .631 r
.54636 .49793 m .5455 .49195 L .55706 .48935 L p F P
0 g
s
.625 .466 .646 r
.556 .48317 m .55706 .48935 L .5455 .49195 L p F P
0 g
s
.625 .466 .646 r
.55183 .48411 m .556 .48317 L p .5455 .49195 L F P
0 g
s
.624 .409 .569 r
.5179 .51486 m .5238 .51387 L .52398 .5192 L p F P
0 g
s
.624 .409 .569 r
.52398 .5192 m .51656 .52044 L .5179 .51486 L p F P
0 g
s
.721 .667 .796 r
.34954 .36193 m .34921 .36137 L .34853 .36181 L closepath p F P
0 g
s
.692 .647 .8 r
.42907 .35198 m .43191 .35718 L p .41814 .35721 L F P
0 g
s
.692 .647 .8 r
.41814 .35721 m .42824 .35201 L .42907 .35198 L p F P
0 g
s
.693 .65 .802 r
.41814 .35721 m .42824 .35201 L .41554 .35251 L closepath p F P
0 g
s
.625 .505 .696 r
.56305 .4606 m .56122 .45363 L .57246 .4506 L p F P
0 g
s
.628 .515 .706 r
.57166 .44774 m .57246 .4506 L .56122 .45363 L p F P
0 g
s
.755 .517 .573 r
.30268 .52242 m .30268 .52238 L .30267 .52242 L closepath p F P
0 g
s
.657 .597 .775 r
.52387 .3834 m .52345 .38244 L .51756 .3848 L closepath p F P
0 g
s
.658 .599 .777 r
.52052 .37582 m .52345 .38244 L .51756 .3848 L p F P
0 g
s
.658 .599 .777 r
.50965 .38021 m .52052 .37582 L p .51756 .3848 L F P
0 g
s
.745 .49 .544 r
.30267 .52247 m .30268 .52242 L p .31186 .52867 L F P
0 g
s
.753 .497 .546 r
.30267 .52247 m .30267 .52242 L .30268 .52242 L closepath p F P
0 g
s
.756 .499 .544 r
.30267 .52242 m .30267 .52247 L .30226 .52744 L p F P
0 g
s
.756 .499 .544 r
.29407 .52109 m .30267 .52242 L p .30226 .52744 L F P
0 g
s
.659 .6 .778 r
.51961 .37376 m .52052 .37582 L .50965 .38021 L p F P
0 g
s
.659 .6 .778 r
.50965 .38021 m .50792 .37633 L .51961 .37376 L p F P
0 g
s
.745 .49 .544 r
.31186 .52867 m .30274 .52751 L .30267 .52247 L p F P
0 g
s
.747 .491 .544 r
.30274 .52751 m .30226 .52744 L .30267 .52247 L closepath p F P
0 g
s
.723 .667 .794 r
.33539 .36313 m .33919 .36063 L .34853 .36181 L p F P
0 g
s
.723 .67 .798 r
.34612 .3562 m .33919 .36063 L .34853 .36181 L p F P
0 g
s
.723 .67 .798 r
.34853 .36181 m .34921 .36137 L .34612 .3562 L p F P
0 g
s
.647 .57 .754 r
.54611 .40728 m .54604 .4071 L .54452 .40768 L closepath p F P
0 g
s
.648 .571 .755 r
.54312 .39952 m .54604 .4071 L .54452 .40768 L p F P
0 g
s
.768 .56 .617 r
.27097 .50608 m .26796 .50552 L .26722 .49943 L p F P
0 g
s
.775 .565 .615 r
.26476 .49892 m .26722 .49943 L .26796 .50552 L p F P
0 g
s
.628 .479 .661 r
.556 .48317 m .55576 .48197 L .55183 .48411 L closepath p F P
0 g
s
.665 .61 .784 r
.49293 .37202 m .50378 .36741 L .50672 .37373 L p F P
0 g
s
.666 .613 .786 r
.50323 .36624 m .50378 .36741 L .49293 .37202 L p F P
0 g
s
.666 .613 .786 r
.49293 .37202 m .49127 .36851 L .50323 .36624 L p F P
0 g
s
.717 .67 .802 r
.35994 .35477 m .34921 .36137 L .34612 .3562 L p F P
0 g
s
.775 .59 .649 r
.25927 .49155 m .25163 .48989 L .25431 .48401 L p F P
0 g
s
.776 .592 .65 r
.24674 .48232 m .25431 .48401 L .25163 .48989 L p F P
0 g
s
.775 .6 .663 r
.25431 .48401 m .24674 .48232 L .24989 .47631 L p F P
0 g
s
.733 .668 .786 r
.31656 .36871 m .31079 .37291 L .30768 .36753 L p F P
0 g
s
.757 .661 .756 r
.26446 .40368 m .26849 .39987 L .26152 .39818 L closepath p F P
0 g
s
.754 .666 .764 r
.27419 .39157 m .27531 .39362 L .26849 .39987 L p F P
0 g
s
.754 .666 .764 r
.26951 .39039 m .27419 .39157 L p .26849 .39987 L F P
0 g
s
.754 .666 .764 r
.26133 .39783 m .26951 .39039 L p .26849 .39987 L F P
0 g
s
.754 .666 .764 r
.26849 .39987 m .26152 .39818 L .26133 .39783 L p F P
0 g
s
.752 .663 .763 r
.27531 .39362 m .27693 .39219 L .27419 .39157 L closepath p F P
0 g
s
.77 .646 .725 r
.24566 .43333 m .24808 .43045 L .24385 .42936 L closepath p F P
0 g
s
.768 .652 .734 r
.24257 .42672 m .24705 .42165 L p .24808 .43045 L F P
0 g
s
.768 .652 .734 r
.24808 .43045 m .24385 .42936 L .24257 .42672 L p F P
0 g
s
.777 .603 .664 r
.24422 .475 m .24989 .47631 L .24674 .48232 L p F P
0 g
s
.775 .611 .676 r
.24351 .47272 m .246 .46844 L p .24989 .47631 L F P
0 g
s
.775 .611 .676 r
.24989 .47631 m .24422 .475 L .24351 .47272 L p F P
0 g
s
.749 .668 .771 r
.28609 .38423 m .28613 .38429 L .27693 .39219 L p F P
0 g
s
.749 .668 .771 r
.2787 .38246 m .28609 .38423 L p .27693 .39219 L F P
0 g
s
.749 .668 .771 r
.27217 .38803 m .2787 .38246 L p .27693 .39219 L F P
0 g
s
.749 .668 .771 r
.27693 .39219 m .27419 .39157 L .27217 .38803 L p F P
0 g
s
.733 .455 .508 r
.33156 .53568 m .322 .53465 L .32106 .52981 L p F P
0 g
s
.733 .455 .508 r
.31859 .52954 m .32106 .52981 L .322 .53465 L p F P
0 g
s
.775 .637 .709 r
.23739 .44382 m .2445 .44569 L .23976 .45219 L p F P
0 g
s
.774 .64 .713 r
.2425 .43721 m .23739 .44382 L .2445 .44569 L p F P
0 g
s
.761 .662 .753 r
.26071 .40733 m .26446 .40368 L .26152 .39818 L p F P
0 g
s
.774 .576 .632 r
.25927 .49155 m .25707 .49728 L .26476 .49892 L p F P
0 g
s
.775 .58 .634 r
.25163 .48989 m .25927 .49155 L .25707 .49728 L p F P
0 g
s
.759 .521 .573 r
.28583 .51653 m .28607 .51448 L .28584 .51444 L closepath p F P
0 g
s
.756 .519 .573 r
.28583 .51653 m .28607 .51448 L p .29407 .52109 L F P
0 g
s
.706 .402 .459 r
.36307 .54249 m .35396 .54189 L .35179 .53739 L p F P
0 g
s
.706 .402 .459 r
.34912 .53722 m .35179 .53739 L .35396 .54189 L p F P
0 g
s
.764 .526 .573 r
.28584 .51444 m .2779 .51301 L p .28545 .51976 L F P
0 g
s
.764 .526 .573 r
.28545 .51976 m .28583 .51653 L .28584 .51444 L p F P
0 g
s
.687 .643 .8 r
.43191 .35718 m .44269 .35186 L .44568 .35743 L p F P
0 g
s
.688 .645 .802 r
.44225 .35105 m .44269 .35186 L .43191 .35718 L p F P
0 g
s
.688 .645 .802 r
.43191 .35718 m .42907 .35198 L .44225 .35105 L p F P
0 g
s
.651 .588 .77 r
.53532 .38056 m .53728 .38519 L .52637 .38933 L p F P
0 g
s
.651 .588 .77 r
.52637 .38933 m .52387 .3834 L .53532 .38056 L p F P
0 g
s
.763 .66 .748 r
.26071 .40733 m .25355 .41455 L .25042 .40859 L p F P
0 g
s
.763 .66 .748 r
.25042 .40859 m .25352 .40546 L .26071 .40733 L p F P
0 g
s
.761 .662 .753 r
.26108 .39806 m .25352 .40546 L .26071 .40733 L p F P
0 g
s
.761 .662 .753 r
.26152 .39818 m .26108 .39806 L p .26071 .40733 L F P
0 g
s
.637 .347 .461 r
.45566 .53731 m .46107 .53691 L .46024 .54135 L p F P
0 g
s
.637 .347 .461 r
.46024 .54135 m .45935 .54141 L .45566 .53731 L p F P
0 g
s
.678 .635 .8 r
.46971 .36032 m .46127 .36141 L .45946 .35794 L p F P
0 g
s
.641 .567 .755 r
.55697 .40323 m .55735 .40421 L .54611 .40728 L p F P
0 g
s
.641 .567 .755 r
.54611 .40728 m .54604 .4071 L .55697 .40323 L p F P
0 g
s
.633 .373 .507 r
.48705 .52963 m .48661 .53439 L .47396 .53578 L p F P
0 g
s
.625 .365 .504 r
.48705 .52963 m .4922 .52899 L .495 .53336 L p F P
0 g
s
.625 .365 .504 r
.495 .53336 m .48661 .53439 L .48705 .52963 L p F P
0 g
s
.641 .564 .752 r
.55697 .40323 m .54604 .4071 L .54312 .39952 L p F P
0 g
s
.777 .613 .676 r
.24351 .47272 m .246 .46844 L .24188 .46745 L closepath p F P
0 g
s
.775 .62 .688 r
.24057 .46365 m .24262 .4604 L p .246 .46844 L F P
0 g
s
.775 .62 .688 r
.246 .46844 m .24188 .46745 L .24057 .46365 L p F P
0 g
s
.706 .402 .459 r
.35396 .54189 m .34795 .5415 L .34912 .53722 L p F P
0 g
s
.716 .412 .462 r
.34156 .53657 m .34912 .53722 L .34795 .5415 L p F P
0 g
s
.746 .665 .771 r
.28613 .38429 m .28618 .38425 L .28609 .38423 L closepath p F P
0 g
s
.743 .67 .779 r
.28883 .37422 m .29652 .37595 L .28618 .38425 L p F P
0 g
s
.743 .67 .779 r
.28299 .3789 m .28883 .37422 L p .28618 .38425 L F P
0 g
s
.743 .67 .779 r
.28618 .38425 m .28609 .38423 L .28299 .3789 L p F P
0 g
s
.733 .455 .508 r
.322 .53465 m .31778 .5342 L .31859 .52954 L p F P
0 g
s
.742 .464 .509 r
.31186 .52867 m .31859 .52954 L .31778 .5342 L p F P
0 g
s
.749 .672 .775 r
.28609 .38423 m .28299 .3789 L .2787 .38246 L closepath p F P
0 g
s
.774 .648 .722 r
.2425 .43721 m .24566 .43333 L .24385 .42936 L p F P
0 g
s
.775 .565 .615 r
.26796 .50552 m .26308 .50451 L .26476 .49892 L p F P
0 g
s
.776 .567 .616 r
.25707 .49728 m .26476 .49892 L .26308 .50451 L p F P
0 g
s
.672 .625 .793 r
.486 .3578 m .48703 .35986 L .4762 .36463 L p F P
0 g
s
.672 .625 .793 r
.4762 .36463 m .47377 .35976 L .486 .3578 L p F P
0 g
s
.622 .494 .685 r
.56368 .46323 m .56305 .4606 L .5743 .45759 L p F P
0 g
s
.625 .505 .696 r
.57246 .4506 m .5743 .45759 L .56305 .4606 L p F P
0 g
s
.723 .666 .794 r
.33539 .36313 m .33919 .36063 L .3335 .35991 L closepath p F P
0 g
s
.766 .66 .746 r
.25361 .41465 m .25355 .41455 L .25349 .41462 L closepath p F P
0 g
s
.767 .662 .747 r
.25349 .41462 m .25355 .41455 L .25042 .40859 L p F P
0 g
s
.768 .657 .74 r
.24651 .41268 m .25349 .41462 L .24705 .42165 L p F P
0 g
s
.767 .662 .747 r
.25042 .40859 m .24651 .41268 L .25349 .41462 L p F P
0 g
s
.733 .668 .786 r
.30768 .36753 m .30807 .36725 L .31656 .36871 L p F P
0 g
s
.733 .672 .791 r
.31843 .35995 m .30807 .36725 L .31656 .36871 L p F P
0 g
s
.733 .672 .791 r
.31656 .36871 m .32154 .36519 L .31843 .35995 L p F P
0 g
s
.66 .606 .784 r
.5176 .3694 m .51961 .37376 L .50792 .37633 L p F P
0 g
s
.66 .606 .784 r
.50792 .37633 m .50672 .37373 L .5176 .3694 L p F P
0 g
s
.621 .475 .661 r
.556 .48317 m .55576 .48197 L .56669 .47675 L p F P
0 g
s
.622 .475 .662 r
.56614 .47397 m .56669 .47675 L .55576 .48197 L p F P
0 g
s
.629 .34 .459 r
.46024 .54135 m .46107 .53691 L .47373 .5358 L p F P
0 g
s
.755 .67 .768 r
.27419 .39157 m .27217 .38803 L .26951 .39039 L closepath p F P
0 g
s
.778 .622 .687 r
.24057 .46365 m .24262 .4604 L .23914 .45953 L closepath p F P
0 g
s
.775 .629 .698 r
.23757 .4554 m .23976 .45219 L p .24262 .4604 L F P
0 g
s
.775 .629 .698 r
.24262 .4604 m .23914 .45953 L .23757 .4554 L p F P
0 g
s
.683 .642 .803 r
.45648 .35232 m .44568 .35743 L .44269 .35186 L p F P
0 g
s
.616 .403 .569 r
.52398 .5192 m .5238 .51387 L .5357 .51167 L p F P
0 g
s
.623 .425 .593 r
.53527 .50611 m .5357 .51167 L .5238 .51387 L p F P
0 g
s
.666 .618 .792 r
.50084 .36134 m .50323 .36624 L .49127 .36851 L p F P
0 g
s
.666 .618 .792 r
.49127 .36851 m .48998 .36586 L .50084 .36134 L p F P
0 g
s
.622 .494 .685 r
.56468 .46738 m .56368 .46323 L .57464 .459 L p F P
0 g
s
.622 .494 .685 r
.5743 .45759 m .57464 .459 L .56368 .46323 L p F P
0 g
s
.743 .671 .781 r
.29717 .37609 m .29691 .37564 L .29652 .37595 L closepath p F P
0 g
s
.621 .475 .661 r
.56669 .47675 m .56741 .48036 L .556 .48317 L p F P
0 g
s
.617 .459 .646 r
.55706 .48935 m .556 .48317 L .56741 .48036 L p F P
0 g
s
.616 .42 .593 r
.5357 .51167 m .53527 .50611 L .54702 .50372 L p F P
0 g
s
.622 .439 .613 r
.54636 .49793 m .54702 .50372 L .53527 .50611 L p F P
0 g
s
.766 .544 .597 r
.2779 .51301 m .26972 .51154 L .27097 .50608 L p F P
0 g
s
.768 .546 .597 r
.26796 .50552 m .27097 .50608 L .26972 .51154 L p F P
0 g
s
.775 .645 .718 r
.23551 .43529 m .2425 .43721 L .23739 .44382 L p F P
0 g
s
.774 .648 .722 r
.24098 .42857 m .23551 .43529 L .2425 .43721 L p F P
0 g
s
.774 .648 .722 r
.24385 .42936 m .24098 .42857 L p .2425 .43721 L F P
0 g
s
.622 .364 .506 r
.4922 .52899 m .49951 .52804 L .4991 .53283 L p F P
0 g
s
.622 .364 .506 r
.4991 .53283 m .495 .53336 L .4922 .52899 L p F P
0 g
s
.744 .674 .783 r
.29377 .37037 m .28883 .37422 L .29652 .37595 L p F P
0 g
s
.744 .674 .783 r
.29652 .37595 m .29691 .37564 L .29377 .37037 L p F P
0 g
s
.721 .671 .8 r
.34303 .35106 m .34612 .3562 L .33919 .36063 L p F P
0 g
s
.721 .671 .8 r
.33229 .35789 m .34303 .35106 L p .33919 .36063 L F P
0 g
s
.721 .671 .8 r
.33919 .36063 m .3335 .35991 L .33229 .35789 L p F P
0 g
s
.716 .412 .462 r
.34795 .5415 m .34355 .54112 L .34156 .53657 L p F P
0 g
s
.714 .404 .452 r
.33367 .5359 m .34156 .53657 L .34355 .54112 L p F P
0 g
s
.74 .674 .786 r
.30768 .36753 m .29691 .37564 L .29377 .37037 L p F P
0 g
s
.756 .519 .573 r
.29407 .52109 m .28581 .51983 L .28583 .51653 L p F P
0 g
s
.764 .525 .573 r
.28581 .51983 m .28583 .51653 L .28545 .51976 L closepath p F P
0 g
s
.618 .384 .54 r
.51189 .52119 m .51656 .52044 L .51761 .52532 L p F P
0 g
s
.618 .384 .54 r
.51761 .52532 m .51179 .52626 L .51189 .52119 L p F P
0 g
s
.626 .39 .541 r
.51189 .52119 m .51179 .52626 L .49951 .52804 L p F P
0 g
s
.641 .564 .752 r
.55406 .39563 m .55697 .40323 L p .54312 .39952 L F P
0 g
s
.641 .564 .752 r
.54312 .39952 m .55389 .39567 L .55406 .39563 L p F P
0 g
s
.642 .569 .757 r
.54312 .39952 m .55389 .39567 L .54279 .39869 L closepath p F P
0 g
s
.773 .654 .731 r
.24385 .42936 m .24257 .42672 L .24098 .42857 L closepath p F P
0 g
s
.635 .542 .732 r
.56584 .42843 m .56576 .42817 L .56248 .42935 L closepath p F P
0 g
s
.636 .543 .732 r
.56323 .4206 m .56576 .42817 L .56248 .42935 L p F P
0 g
s
.728 .672 .795 r
.33006 .35937 m .32154 .36519 L .31843 .35995 L p F P
0 g
s
.652 .594 .777 r
.53436 .37834 m .53532 .38056 L .52387 .3834 L p F P
0 g
s
.652 .594 .777 r
.52387 .3834 m .52345 .38244 L .53436 .37834 L p F P
0 g
s
.77 .653 .733 r
.24705 .42165 m .24257 .42672 L .23945 .42034 L p F P
0 g
s
.77 .653 .733 r
.23945 .42034 m .23997 .41975 L .24705 .42165 L p F P
0 g
s
.768 .657 .74 r
.24705 .42165 m .23997 .41975 L .24651 .41268 L p F P
0 g
s
.644 .576 .764 r
.55389 .39567 m .54279 .39869 L .5402 .39224 L p F P
0 g
s
.756 .499 .544 r
.30226 .52744 m .29411 .52619 L .29407 .52109 L p F P
0 g
s
.755 .498 .544 r
.28581 .51983 m .29407 .52109 L .29411 .52619 L p F P
0 g
s
.659 .605 .783 r
.5176 .3694 m .50672 .37373 L .50378 .36741 L p F P
0 g
s
.778 .63 .698 r
.23757 .4554 m .23976 .45219 L .23597 .45122 L closepath p F P
0 g
s
.775 .637 .709 r
.23453 .44774 m .23739 .44382 L p .23976 .45219 L F P
0 g
s
.775 .637 .709 r
.23976 .45219 m .23597 .45122 L .23453 .44774 L p F P
0 g
s
.695 .389 .454 r
.37594 .54307 m .36466 .54257 L .36359 .54062 L p F P
0 g
s
.696 .39 .453 r
.36466 .54257 m .36307 .54249 L .36359 .54062 L closepath p F P
0 g
s
.742 .464 .509 r
.31778 .5342 m .31271 .53354 L .31186 .52867 L p F P
0 g
s
.742 .463 .507 r
.30274 .52751 m .31186 .52867 L .31271 .53354 L p F P
0 g
s
.781 .615 .674 r
.24188 .46745 m .23874 .46663 L p .24248 .47456 L F P
0 g
s
.781 .615 .674 r
.24248 .47456 m .24351 .47272 L .24188 .46745 L p F P
0 g
s
.781 .623 .685 r
.24188 .46745 m .24057 .46365 L .23874 .46663 L closepath p F P
0 g
s
.697 .658 .808 r
.41365 .35254 m .40166 .35268 L .40134 .35212 L p F P
0 g
s
.701 .66 .806 r
.40166 .35268 m .40134 .35212 L .40034 .35266 L closepath p F P
0 g
s
.676 .632 .798 r
.47377 .35976 m .47324 .35872 L .46971 .36032 L closepath p F P
0 g
s
.678 .635 .8 r
.47028 .35306 m .47324 .35872 L .46971 .36032 L p F P
0 g
s
.678 .635 .8 r
.45946 .35794 m .47028 .35306 L p .46971 .36032 L F P
0 g
s
.702 .659 .805 r
.38755 .35272 m .38805 .35244 L .40034 .35266 L p F P
0 g
s
.703 .665 .809 r
.3983 .34698 m .38805 .35244 L .40034 .35266 L p F P
0 g
s
.703 .665 .809 r
.40034 .35266 m .40134 .35212 L .3983 .34698 L p F P
0 g
s
.678 .637 .801 r
.47028 .35306 m .45946 .35794 L .45648 .35232 L p F P
0 g
s
.618 .482 .674 r
.56614 .47397 m .56468 .46738 L .57593 .46437 L p F P
0 g
s
.622 .494 .685 r
.57464 .459 m .57593 .46437 L .56468 .46738 L p F P
0 g
s
.781 .614 .674 r
.24422 .475 m .24351 .47272 L .24248 .47456 L closepath p F P
0 g
s
.653 .596 .778 r
.53436 .37834 m .52345 .38244 L .52052 .37582 L p F P
0 g
s
.777 .603 .664 r
.24674 .48232 m .24617 .48219 L .24422 .475 L p F P
0 g
s
.783 .606 .661 r
.24248 .47456 m .24422 .475 L .24617 .48219 L p F P
0 g
s
.614 .434 .614 r
.54702 .50372 m .54636 .49793 L .55794 .49534 L p F P
0 g
s
.619 .45 .631 r
.55706 .48935 m .55794 .49534 L .54636 .49793 L p F P
0 g
s
.781 .624 .685 r
.23874 .46663 m .24057 .46365 L .23914 .45953 L p F P
0 g
s
.697 .658 .808 r
.4121 .34659 m .41512 .35178 L .41365 .35254 L p F P
0 g
s
.697 .658 .808 r
.40134 .35212 m .4121 .34659 L p .41365 .35254 L F P
0 g
s
.696 .656 .806 r
.41554 .35251 m .41512 .35178 L .41365 .35254 L closepath p F P
0 g
s
.703 .661 .806 r
.38755 .35272 m .38805 .35244 L .38738 .35242 L closepath p F P
0 g
s
.707 .663 .804 r
.38738 .35242 m .38755 .35272 L p .37375 .35361 L F P
0 g
s
.692 .655 .808 r
.42824 .35201 m .41554 .35251 L .41512 .35178 L p F P
0 g
s
.776 .552 .596 r
.26308 .50451 m .26796 .50552 L .26833 .51128 L p F P
0 g
s
.768 .546 .597 r
.26972 .51154 m .26833 .51128 L .26796 .50552 L p F P
0 g
s
.707 .664 .805 r
.37375 .35361 m .37676 .35189 L .37262 .35168 L closepath p F P
0 g
s
.712 .667 .803 r
.37262 .35168 m .37375 .35361 L p .35994 .35477 L F P
0 g
s
.707 .663 .804 r
.37375 .35361 m .37676 .35189 L .38738 .35242 L p F P
0 g
s
.666 .618 .791 r
.50084 .36134 m .48998 .36586 L .48703 .35986 L p F P
0 g
s
.697 .663 .813 r
.4121 .34659 m .40134 .35212 L .3983 .34698 L p F P
0 g
s
.701 .666 .812 r
.39525 .34189 m .3983 .34698 L .38805 .35244 L p F P
0 g
s
.701 .666 .812 r
.38449 .34761 m .39525 .34189 L p .38805 .35244 L F P
0 g
s
.701 .666 .812 r
.38805 .35244 m .38738 .35242 L .38449 .34761 L p F P
0 g
s
.706 .667 .81 r
.38738 .35242 m .38449 .34761 L .37676 .35189 L closepath p F P
0 g
s
.781 .624 .685 r
.23914 .45953 m .23549 .45855 L p .23874 .46663 L F P
0 g
s
.781 .632 .695 r
.23914 .45953 m .23757 .4554 L .23549 .45855 L closepath p F P
0 g
s
.764 .526 .573 r
.2779 .51301 m .27728 .51829 L .28545 .51976 L p F P
0 g
s
.766 .528 .573 r
.26972 .51154 m .2779 .51301 L .27728 .51829 L p F P
0 g
s
.76 .668 .76 r
.26152 .39818 m .26133 .39783 L .26108 .39806 L closepath p F P
0 g
s
.712 .667 .803 r
.35994 .35477 m .36605 .35116 L .37262 .35168 L p F P
0 g
s
.712 .666 .803 r
.35994 .35477 m .36605 .35116 L .35739 .35047 L closepath p F P
0 g
s
.717 .67 .802 r
.35739 .35047 m .35994 .35477 L p .34612 .3562 L F P
0 g
s
.65 .316 .394 r
.40634 .54357 m .41344 .54348 L .41786 .54736 L p F P
0 g
s
.65 .316 .394 r
.41786 .54736 m .4049 .54752 L .40634 .54357 L p F P
0 g
s
.659 .326 .397 r
.40026 .54355 m .40634 .54357 L .4049 .54752 L p F P
0 g
s
.727 .673 .797 r
.3335 .35991 m .33229 .35789 L .33006 .35937 L closepath p F P
0 g
s
.774 .655 .731 r
.24098 .42857 m .24257 .42672 L .23945 .42034 L p F P
0 g
s
.714 .404 .452 r
.33283 .53897 m .33367 .5359 L p .34355 .54112 L F P
0 g
s
.725 .423 .467 r
.33283 .53897 m .33156 .53568 L .33367 .5359 L closepath p F P
0 g
s
.659 .326 .397 r
.4049 .54752 m .40435 .54751 L .40026 .54355 L p F P
0 g
s
.654 .306 .371 r
.39223 .5435 m .40026 .54355 L .40435 .54751 L p F P
0 g
s
.776 .592 .65 r
.24638 .48313 m .24674 .48232 L p .25163 .48989 L F P
0 g
s
.779 .593 .649 r
.24638 .48313 m .24674 .48232 L .24617 .48219 L closepath p F P
0 g
s
.692 .659 .813 r
.4259 .34644 m .41512 .35178 L .4121 .34659 L p F P
0 g
s
.692 .655 .808 r
.41512 .35178 m .4259 .34644 L p .42824 .35201 L F P
0 g
s
.654 .306 .371 r
.39098 .54683 m .39223 .5435 L p .40435 .54751 L F P
0 g
s
.671 .338 .401 r
.39098 .54683 m .38781 .5434 L .39223 .5435 L closepath p F P
0 g
s
.649 .317 .396 r
.41344 .54348 m .42018 .54338 L .41879 .54734 L p F P
0 g
s
.649 .317 .396 r
.41879 .54734 m .41786 .54736 L .41344 .54348 L p F P
0 g
s
.757 .669 .764 r
.26951 .39039 m .26133 .39783 L .25817 .39225 L p F P
0 g
s
.761 .67 .762 r
.26108 .39806 m .26133 .39783 L .25817 .39225 L p F P
0 g
s
.761 .666 .758 r
.25405 .39613 m .26108 .39806 L .25352 .40546 L p F P
0 g
s
.761 .67 .762 r
.25817 .39225 m .25405 .39613 L .26108 .39806 L p F P
0 g
s
.775 .58 .634 r
.25707 .49728 m .24939 .49564 L .25163 .48989 L p F P
0 g
s
.777 .582 .635 r
.24771 .48902 m .25163 .48989 L .24939 .49564 L p F P
0 g
s
.776 .592 .65 r
.25163 .48989 m .24771 .48902 L .24638 .48313 L p F P
0 g
s
.629 .344 .467 r
.47392 .53601 m .47373 .5358 L .47396 .53578 L closepath p F P
0 g
s
.629 .34 .459 r
.47373 .5358 m .47392 .53601 L p .46024 .54135 L F P
0 g
s
.757 .669 .764 r
.25817 .39225 m .26228 .38851 L .26951 .39039 L p F P
0 g
s
.756 .671 .768 r
.26903 .38255 m .26228 .38851 L .26951 .39039 L p F P
0 g
s
.756 .671 .768 r
.26951 .39039 m .27217 .38803 L .26903 .38255 L p F P
0 g
s
.784 .608 .663 r
.23536 .47272 m .24248 .47456 L .23951 .48052 L p F P
0 g
s
.781 .615 .674 r
.23874 .46663 m .23536 .47272 L .24248 .47456 L p F P
0 g
s
.783 .606 .661 r
.24617 .48219 m .23951 .48052 L .24248 .47456 L p F P
0 g
s
.672 .63 .799 r
.48408 .35406 m .486 .3578 L .47377 .35976 L p F P
0 g
s
.672 .63 .799 r
.47377 .35976 m .47324 .35872 L .48408 .35406 L p F P
0 g
s
.617 .328 .456 r
.47396 .53578 m .48661 .53439 L .48582 .53883 L p F P
0 g
s
.617 .328 .456 r
.47392 .53601 m .47396 .53578 L p .48582 .53883 L F P
0 g
s
.783 .596 .647 r
.24617 .48219 m .23951 .48052 L p .24418 .48817 L F P
0 g
s
.783 .596 .647 r
.24418 .48817 m .24638 .48313 L .24617 .48219 L p F P
0 g
s
.751 .67 .771 r
.2787 .38246 m .27217 .38803 L .26903 .38255 L p F P
0 g
s
.667 .323 .38 r
.38781 .5434 m .39098 .54683 L .39072 .54741 L p F P
0 g
s
.667 .323 .38 r
.37782 .54315 m .38781 .5434 L p .39072 .54741 L F P
0 g
s
.615 .382 .541 r
.51656 .52044 m .52398 .5192 L .5239 .52427 L p F P
0 g
s
.615 .382 .541 r
.5239 .52427 m .51761 .52532 L .51656 .52044 L p F P
0 g
s
.781 .632 .695 r
.23549 .45855 m .23757 .4554 L .23597 .45122 L p F P
0 g
s
.639 .307 .393 r
.42018 .54338 m .42752 .54315 L .4323 .54693 L p F P
0 g
s
.639 .307 .393 r
.4323 .54693 m .41879 .54734 L .42018 .54338 L p F P
0 g
s
.775 .651 .725 r
.23412 .4266 m .24098 .42857 L .23551 .43529 L p F P
0 g
s
.774 .655 .731 r
.23945 .42034 m .23412 .4266 L .24098 .42857 L p F P
0 g
s
.691 .652 .806 r
.42907 .35198 m .42891 .35168 L .42824 .35201 L closepath p F P
0 g
s
.692 .655 .808 r
.4259 .34644 m .42891 .35168 L .42824 .35201 L p F P
0 g
s
.614 .357 .504 r
.4991 .53283 m .49951 .52804 L .51179 .52626 L p F P
0 g
s
.727 .419 .459 r
.33156 .53568 m .33283 .53897 L .33245 .54017 L p F P
0 g
s
.727 .419 .459 r
.322 .53465 m .33156 .53568 L p .33245 .54017 L F P
0 g
s
.734 .67 .787 r
.30768 .36753 m .30807 .36725 L .30744 .36714 L closepath p F P
0 g
s
.74 .674 .786 r
.30744 .36714 m .30768 .36753 L p .29377 .37037 L F P
0 g
s
.777 .638 .708 r
.23453 .44774 m .23739 .44382 L .23234 .44247 L closepath p F P
0 g
s
.775 .645 .718 r
.23146 .4405 m .23551 .43529 L p .23739 .44382 L F P
0 g
s
.775 .645 .718 r
.23739 .44382 m .23234 .44247 L .23146 .4405 L p F P
0 g
s
.686 .65 .808 r
.4397 .34653 m .44225 .35105 L .42907 .35198 L p F P
0 g
s
.686 .65 .808 r
.42907 .35198 m .42891 .35168 L .4397 .34653 L p F P
0 g
s
.783 .596 .647 r
.24771 .48902 m .24638 .48313 L .24418 .48817 L closepath p F P
0 g
s
.732 .674 .794 r
.31679 .35723 m .31843 .35995 L .30807 .36725 L p F P
0 g
s
.732 .674 .794 r
.31291 .35648 m .31679 .35723 L p .30807 .36725 L F P
0 g
s
.732 .674 .794 r
.30454 .36237 m .31291 .35648 L p .30807 .36725 L F P
0 g
s
.732 .674 .794 r
.30807 .36725 m .30744 .36714 L .30454 .36237 L p F P
0 g
s
.617 .328 .456 r
.48582 .53883 m .4783 .53965 L .47392 .53601 L p F P
0 g
s
.619 .327 .453 r
.4783 .53965 m .47312 .54019 L .47392 .53601 L closepath p F P
0 g
s
.629 .34 .459 r
.47392 .53601 m .47312 .54019 L .46024 .54135 L p F P
0 g
s
.717 .67 .802 r
.34612 .3562 m .35572 .35029 L .35739 .35047 L p F P
0 g
s
.717 .673 .806 r
.35572 .35029 m .34612 .3562 L .34303 .35106 L p F P
0 g
s
.627 .53 .725 r
.56824 .43603 m .56584 .42843 L .57692 .42517 L p F P
0 g
s
.629 .539 .733 r
.57674 .42461 m .57692 .42517 L .56584 .42843 L p F P
0 g
s
.629 .539 .733 r
.56584 .42843 m .56576 .42817 L .57674 .42461 L p F P
0 g
s
.706 .668 .811 r
.38143 .34257 m .38449 .34761 L .37676 .35189 L p F P
0 g
s
.706 .668 .811 r
.37068 .34849 m .38143 .34257 L p .37676 .35189 L F P
0 g
s
.706 .668 .811 r
.37676 .35189 m .37262 .35168 L .37068 .34849 L p F P
0 g
s
.629 .539 .733 r
.5743 .41732 m .57674 .42461 L .56576 .42817 L p F P
0 g
s
.629 .539 .733 r
.56576 .42817 m .56323 .4206 L .5743 .41732 L p F P
0 g
s
.764 .661 .749 r
.25042 .40859 m .25352 .40546 L .24799 .40399 L closepath p F P
0 g
s
.761 .666 .758 r
.24728 .4027 m .25405 .39613 L p .25352 .40546 L F P
0 g
s
.761 .666 .758 r
.25352 .40546 m .24799 .40399 L .24728 .4027 L p F P
0 g
s
.644 .577 .764 r
.55047 .38671 m .55113 .38835 L .5402 .39224 L p F P
0 g
s
.644 .577 .764 r
.5402 .39224 m .53921 .38979 L .55047 .38671 L p F P
0 g
s
.644 .576 .764 r
.5402 .39224 m .55113 .38835 L p .55389 .39567 L F P
0 g
s
.688 .656 .813 r
.4397 .34653 m .42891 .35168 L .4259 .34644 L p F P
0 g
s
.776 .568 .617 r
.24939 .49564 m .25707 .49728 L .25535 .50288 L p F P
0 g
s
.776 .567 .616 r
.26308 .50451 m .25535 .50288 L .25707 .49728 L p F P
0 g
s
.751 .67 .771 r
.26903 .38255 m .27125 .38065 L .2787 .38246 L p F P
0 g
s
.75 .673 .776 r
.27984 .37352 m .27125 .38065 L .2787 .38246 L p F P
0 g
s
.75 .673 .776 r
.2787 .38246 m .28299 .3789 L .27984 .37352 L p F P
0 g
s
.627 .53 .725 r
.57692 .42517 m .57933 .43278 L .56824 .43603 L p F P
0 g
s
.624 .521 .716 r
.5687 .43757 m .56824 .43603 L .57933 .43278 L p F P
0 g
s
.74 .674 .786 r
.29377 .37037 m .30012 .3656 L .30744 .36714 L p F P
0 g
s
.738 .676 .791 r
.30744 .36714 m .30454 .36237 L .30012 .3656 L closepath p F P
0 g
s
.784 .618 .675 r
.2317 .46476 m .23874 .46663 L .23536 .47272 L p F P
0 g
s
.781 .624 .685 r
.23549 .45855 m .2317 .46476 L .23874 .46663 L p F P
0 g
s
.638 .308 .396 r
.42752 .54315 m .43376 .54293 L .43242 .54693 L p F P
0 g
s
.638 .308 .396 r
.43242 .54693 m .4323 .54693 L .42752 .54315 L p F P
0 g
s
.667 .323 .38 r
.37724 .54469 m .37782 .54315 L p .39072 .54741 L F P
0 g
s
.683 .352 .409 r
.37724 .54469 m .37594 .54307 L .37782 .54315 L closepath p F P
0 g
s
.673 .634 .802 r
.48408 .35406 m .47324 .35872 L .47028 .35306 L p F P
0 g
s
.624 .52 .716 r
.57044 .44341 m .5687 .43757 L .57968 .43398 L p F P
0 g
s
.624 .521 .716 r
.57933 .43278 m .57968 .43398 L .5687 .43757 L p F P
0 g
s
.768 .663 .747 r
.24651 .41268 m .25042 .40859 L .24799 .40399 L p F P
0 g
s
.728 .672 .795 r
.31843 .35995 m .32136 .35797 L .33006 .35937 L p F P
0 g
s
.728 .676 .799 r
.32917 .35282 m .32136 .35797 L .33006 .35937 L p F P
0 g
s
.728 .676 .799 r
.33006 .35937 m .33229 .35789 L .32917 .35282 L p F P
0 g
s
.632 .547 .741 r
.5738 .41588 m .5743 .41732 L .56323 .4206 L p F P
0 g
s
.632 .547 .741 r
.56323 .4206 m .56282 .41944 L .5738 .41588 L p F P
0 g
s
.68 .338 .389 r
.37594 .54307 m .37724 .54469 L .37623 .54701 L p F P
0 g
s
.68 .338 .389 r
.36466 .54257 m .37594 .54307 L p .37623 .54701 L F P
0 g
s
.781 .632 .695 r
.23597 .45122 m .23271 .45031 L p .23549 .45855 L F P
0 g
s
.781 .64 .705 r
.23597 .45122 m .23453 .44774 L .23271 .45031 L closepath p F P
0 g
s
.711 .67 .808 r
.37262 .35168 m .37068 .34849 L .36605 .35116 L closepath p F P
0 g
s
.632 .548 .742 r
.57148 .40925 m .5738 .41588 L .56282 .41944 L p F P
0 g
s
.632 .548 .742 r
.56282 .41944 m .5604 .41253 L .57148 .40925 L p F P
0 g
s
.745 .672 .779 r
.28883 .37422 m .28299 .3789 L .27984 .37352 L p F P
0 g
s
.612 .445 .632 r
.55794 .49534 m .55706 .48935 L .56848 .48655 L p F P
0 g
s
.617 .459 .646 r
.56741 .48036 m .56848 .48655 L .55706 .48935 L p F P
0 g
s
.629 .299 .393 r
.43242 .54693 m .43376 .54293 L .44273 .54249 L p F P
0 g
s
.621 .511 .707 r
.57166 .44774 m .57044 .44341 L .58153 .44017 L p F P
0 g
s
.624 .52 .716 r
.57968 .43398 m .58153 .44017 L .57044 .44341 L p F P
0 g
s
.646 .584 .771 r
.54821 .38132 m .55047 .38671 L .53921 .38979 L p F P
0 g
s
.646 .584 .771 r
.53921 .38979 m .53728 .38519 L .54821 .38132 L p F P
0 g
s
.614 .47 .661 r
.56669 .47675 m .56614 .47397 L .5774 .47097 L p F P
0 g
s
.618 .482 .674 r
.57593 .46437 m .5774 .47097 L .56614 .47397 L p F P
0 g
s
.769 .661 .743 r
.23957 .41072 m .24651 .41268 L .23997 .41975 L p F P
0 g
s
.768 .663 .747 r
.24644 .40355 m .23957 .41072 L .24651 .41268 L p F P
0 g
s
.768 .663 .747 r
.24799 .40399 m .24644 .40355 L p .24651 .41268 L F P
0 g
s
.742 .463 .507 r
.31271 .53354 m .30361 .53237 L .30274 .52751 L p F P
0 g
s
.743 .464 .507 r
.30226 .52744 m .30274 .52751 L .30361 .53237 L p F P
0 g
s
.755 .498 .544 r
.28545 .52402 m .28581 .51983 L p .29411 .52619 L F P
0 g
s
.763 .506 .545 r
.28545 .52402 m .28545 .51976 L .28581 .51983 L closepath p F P
0 g
s
.723 .676 .804 r
.34303 .35106 m .33229 .35789 L .32917 .35282 L p F P
0 g
s
.776 .552 .596 r
.26833 .51128 m .2619 .50995 L .26308 .50451 L p F P
0 g
s
.776 .553 .597 r
.25535 .50288 m .26308 .50451 L .2619 .50995 L p F P
0 g
s
.783 .627 .687 r
.22854 .45663 m .23549 .45855 L .2317 .46476 L p F P
0 g
s
.781 .632 .695 r
.23271 .45031 m .22854 .45663 L .23549 .45855 L p F P
0 g
s
.743 .464 .507 r
.30361 .53237 m .3014 .53207 L .30226 .52744 L p F P
0 g
s
.753 .473 .508 r
.29411 .52619 m .30226 .52744 L .3014 .53207 L p F P
0 g
s
.683 .642 .803 r
.45511 .34978 m .45648 .35232 L p .44269 .35186 L F P
0 g
s
.683 .642 .803 r
.44269 .35186 m .44493 .35081 L .45511 .34978 L p F P
0 g
s
.684 .646 .806 r
.44269 .35186 m .44493 .35081 L .44225 .35105 L closepath p F P
0 g
s
.766 .507 .544 r
.28545 .51976 m .28545 .52402 L .28537 .52486 L p F P
0 g
s
.766 .507 .544 r
.27728 .51829 m .28545 .51976 L p .28537 .52486 L F P
0 g
s
.634 .556 .749 r
.57087 .40758 m .57148 .40925 L .5604 .41253 L p F P
0 g
s
.634 .556 .749 r
.5604 .41253 m .55989 .41115 L .57087 .40758 L p F P
0 g
s
.781 .64 .705 r
.23271 .45031 m .23453 .44774 L .23234 .44247 L p F P
0 g
s
.621 .511 .707 r
.57246 .4506 m .57166 .44774 L .58265 .44415 L p F P
0 g
s
.621 .511 .707 r
.58153 .44017 m .58265 .44415 L .57166 .44774 L p F P
0 g
s
.745 .672 .779 r
.27984 .37352 m .28114 .37249 L .28883 .37422 L p F P
0 g
s
.744 .675 .783 r
.29063 .36511 m .28114 .37249 L .28883 .37422 L p F P
0 g
s
.744 .675 .783 r
.28883 .37422 m .29377 .37037 L .29063 .36511 L p F P
0 g
s
.653 .596 .778 r
.52052 .37582 m .53143 .37169 L .53436 .37834 L p F P
0 g
s
.654 .598 .78 r
.5311 .37095 m .53143 .37169 L .52052 .37582 L p F P
0 g
s
.654 .598 .78 r
.52052 .37582 m .51961 .37376 L .5311 .37095 L p F P
0 g
s
.659 .605 .783 r
.51496 .36369 m .5176 .3694 L p .50378 .36741 L F P
0 g
s
.659 .605 .783 r
.50378 .36741 m .51076 .36462 L .51496 .36369 L p F P
0 g
s
.661 .611 .788 r
.50378 .36741 m .51076 .36462 L .50323 .36624 L closepath p F P
0 g
s
.777 .582 .635 r
.24939 .49564 m .24891 .49554 L .24771 .48902 L p F P
0 g
s
.784 .586 .633 r
.24418 .48817 m .24771 .48902 L .24891 .49554 L p F P
0 g
s
.634 .556 .749 r
.56843 .40091 m .57087 .40758 L .55989 .41115 L p F P
0 g
s
.634 .556 .749 r
.55989 .41115 m .55735 .40421 L .56843 .40091 L p F P
0 g
s
.711 .671 .809 r
.3676 .34349 m .37068 .34849 L .36605 .35116 L p F P
0 g
s
.711 .671 .809 r
.35686 .34961 m .3676 .34349 L p .36605 .35116 L F P
0 g
s
.711 .671 .809 r
.36605 .35116 m .35739 .35047 L .35686 .34961 L p F P
0 g
s
.68 .338 .389 r
.37623 .54701 m .36833 .54664 L .36466 .54257 L p F P
0 g
s
.68 .338 .389 r
.36307 .54249 m .36466 .54257 L .36833 .54664 L p F P
0 g
s
.68 .338 .389 r
.36833 .54664 m .36141 .54632 L .36307 .54249 L p F P
0 g
s
.691 .35 .393 r
.35396 .54189 m .36307 .54249 L .36141 .54632 L p F P
0 g
s
.629 .303 .401 r
.44623 .54504 m .44273 .54249 L .44711 .54225 L closepath p F P
0 g
s
.629 .299 .393 r
.44273 .54249 m .44623 .54504 L p .43242 .54693 L F P
0 g
s
.778 .645 .716 r
.23551 .43529 m .23146 .4405 L .22837 .4336 L p F P
0 g
s
.778 .645 .716 r
.22837 .4336 m .22856 .43336 L .23551 .43529 L p F P
0 g
s
.775 .651 .725 r
.23551 .43529 m .22856 .43336 L .23412 .4266 L p F P
0 g
s
.618 .501 .697 r
.5743 .45759 m .57246 .4506 L .58355 .44736 L p F P
0 g
s
.621 .511 .707 r
.58265 .44415 m .58355 .44736 L .57246 .4506 L p F P
0 g
s
.684 .651 .812 r
.44493 .35081 m .44225 .35105 L .4397 .34653 L p F P
0 g
s
.662 .617 .794 r
.51076 .36462 m .50323 .36624 L .50084 .36134 L p F P
0 g
s
.614 .47 .661 r
.5774 .47097 m .57766 .47227 L .56669 .47675 L p F P
0 g
s
.614 .469 .661 r
.56741 .48036 m .56669 .47675 L .57766 .47227 L p F P
0 g
s
.727 .419 .459 r
.33245 .54017 m .32389 .53923 L .322 .53465 L p F P
0 g
s
.726 .419 .46 r
.31778 .5342 m .322 .53465 L .32389 .53923 L p F P
0 g
s
.74 .674 .787 r
.30012 .3656 m .29377 .37037 L .29063 .36511 L p F P
0 g
s
.609 .397 .569 r
.5359 .517 m .5357 .51167 L .54746 .50929 L p F P
0 g
s
.616 .42 .593 r
.54702 .50372 m .54746 .50929 L .5357 .51167 L p F P
0 g
s
.616 .403 .569 r
.5357 .51167 m .5359 .517 L .52398 .5192 L p F P
0 g
s
.772 .655 .734 r
.23945 .42034 m .23997 .41975 L .23903 .41949 L closepath p F P
0 g
s
.769 .661 .743 r
.23631 .41425 m .23957 .41072 L p .23997 .41975 L F P
0 g
s
.769 .661 .743 r
.23997 .41975 m .23903 .41949 L .23631 .41425 L p F P
0 g
s
.682 .648 .809 r
.45511 .34978 m .4535 .34687 L .44493 .35081 L closepath p F P
0 g
s
.684 .651 .812 r
.45051 .34158 m .4535 .34687 L .44493 .35081 L p F P
0 g
s
.684 .651 .812 r
.4397 .34653 m .45051 .34158 L p .44493 .35081 L F P
0 g
s
.611 .274 .375 r
.44711 .54225 m .45935 .54141 L p .45893 .54533 L F P
0 g
s
.611 .274 .375 r
.44623 .54504 m .44711 .54225 L p .45893 .54533 L F P
0 g
s
.655 .604 .786 r
.52851 .3653 m .5311 .37095 L .51961 .37376 L p F P
0 g
s
.655 .604 .786 r
.51961 .37376 m .5176 .3694 L .52851 .3653 L p F P
0 g
s
.775 .657 .731 r
.23412 .4266 m .23945 .42034 L .23903 .41949 L p F P
0 g
s
.783 .635 .697 r
.22587 .44835 m .23271 .45031 L .22854 .45663 L p F P
0 g
s
.781 .64 .705 r
.2304 .44191 m .22587 .44835 L .23271 .45031 L p F P
0 g
s
.781 .64 .705 r
.23234 .44247 m .2304 .44191 L p .23271 .45031 L F P
0 g
s
.666 .618 .791 r
.49802 .35557 m .50084 .36134 L p .48703 .35986 L F P
0 g
s
.666 .618 .791 r
.48703 .35986 m .49665 .35584 L .49802 .35557 L p F P
0 g
s
.668 .624 .796 r
.48703 .35986 m .49665 .35584 L .486 .3578 L closepath p F P
0 g
s
.646 .585 .772 r
.54659 .37747 m .54821 .38132 L .53728 .38519 L p F P
0 g
s
.646 .585 .772 r
.53728 .38519 m .53532 .38056 L .54659 .37747 L p F P
0 g
s
.607 .376 .54 r
.5239 .52427 m .52398 .5192 L .5359 .517 L p F P
0 g
s
.766 .528 .573 r
.27728 .51829 m .26907 .51683 L .26972 .51154 L p F P
0 g
s
.768 .529 .573 r
.26833 .51128 m .26972 .51154 L .26907 .51683 L p F P
0 g
s
.728 .672 .795 r
.31843 .35995 m .32136 .35797 L .31679 .35723 L closepath p F P
0 g
s
.678 .637 .801 r
.46772 .34822 m .47028 .35306 L p .45648 .35232 L F P
0 g
s
.678 .637 .801 r
.45648 .35232 m .46468 .34862 L .46772 .34822 L p F P
0 g
s
.679 .641 .805 r
.45648 .35232 m .46468 .34862 L .45511 .34978 L closepath p F P
0 g
s
.636 .564 .756 r
.56795 .39966 m .56843 .40091 L .55735 .40421 L p F P
0 g
s
.636 .564 .756 r
.55735 .40421 m .55697 .40323 L .56795 .39966 L p F P
0 g
s
.609 .321 .454 r
.48582 .53883 m .48661 .53439 L .495 .53336 L p F P
0 g
s
.78 .647 .715 r
.23234 .44247 m .23146 .4405 L .2304 .44191 L closepath p F P
0 g
s
.775 .657 .731 r
.23903 .41949 m .23319 .41774 L p .23412 .4266 L F P
0 g
s
.774 .663 .74 r
.23903 .41949 m .23631 .41425 L .23319 .41774 L closepath p F P
0 g
s
.608 .414 .594 r
.54702 .50372 m .55861 .50114 L p .55637 .50732 L F P
0 g
s
.608 .414 .594 r
.55637 .50732 m .54746 .50929 L .54702 .50372 L p F P
0 g
s
.614 .434 .614 r
.55794 .49534 m .55861 .50114 L .54702 .50372 L p F P
0 g
s
.636 .564 .757 r
.56513 .39231 m .56795 .39966 L .55697 .40323 L p F P
0 g
s
.636 .564 .757 r
.55697 .40323 m .55406 .39563 L .56513 .39231 L p F P
0 g
s
.716 .673 .807 r
.35739 .35047 m .35686 .34961 L .35572 .35029 L closepath p F P
0 g
s
.768 .529 .573 r
.26907 .51683 m .2683 .51669 L .26833 .51128 L p F P
0 g
s
.776 .536 .572 r
.2619 .50995 m .26833 .51128 L .2683 .51669 L p F P
0 g
s
.691 .35 .393 r
.36141 .54632 m .35733 .54605 L .35396 .54189 L p F P
0 g
s
.685 .331 .369 r
.34795 .5415 m .35396 .54189 L .35733 .54605 L p F P
0 g
s
.767 .668 .754 r
.24799 .40399 m .24728 .4027 L .24644 .40355 L closepath p F P
0 g
s
.726 .419 .46 r
.32389 .53923 m .31649 .53843 L .31778 .5342 L p F P
0 g
s
.736 .429 .462 r
.31271 .53354 m .31778 .5342 L .31649 .53843 L p F P
0 g
s
.615 .489 .686 r
.57464 .459 m .5743 .45759 L .58539 .45437 L p F P
0 g
s
.618 .501 .697 r
.58355 .44736 m .58539 .45437 L .5743 .45759 L p F P
0 g
s
.702 .671 .817 r
.39525 .34189 m .38449 .34761 L .38143 .34257 L p F P
0 g
s
.783 .596 .647 r
.23951 .48052 m .23693 .48637 L .24418 .48817 L p F P
0 g
s
.785 .6 .65 r
.23234 .4787 m .23951 .48052 L .23693 .48637 L p F P
0 g
s
.784 .608 .663 r
.23951 .48052 m .23234 .4787 L .23536 .47272 L p F P
0 g
s
.726 .677 .802 r
.32605 .34778 m .32917 .35282 L .32136 .35797 L p F P
0 g
s
.726 .677 .802 r
.3153 .35484 m .32605 .34778 L p .32136 .35797 L F P
0 g
s
.726 .677 .802 r
.32136 .35797 m .31679 .35723 L .3153 .35484 L p F P
0 g
s
.784 .586 .633 r
.24891 .49554 m .24206 .49388 L .24418 .48817 L p F P
0 g
s
.785 .588 .634 r
.23693 .48637 m .24418 .48817 L .24206 .49388 L p F P
0 g
s
.717 .673 .806 r
.34303 .35106 m .34612 .34918 L .35572 .35029 L p F P
0 g
s
.718 .677 .81 r
.35377 .34465 m .34612 .34918 L .35572 .35029 L p F P
0 g
s
.718 .677 .81 r
.35572 .35029 m .35686 .34961 L .35377 .34465 L p F P
0 g
s
.707 .674 .816 r
.38143 .34257 m .37068 .34849 L .3676 .34349 L p F P
0 g
s
.74 .674 .787 r
.29063 .36511 m .29221 .36393 L .30012 .3656 L p F P
0 g
s
.739 .678 .792 r
.3014 .35724 m .29221 .36393 L .30012 .3656 L p F P
0 g
s
.739 .678 .792 r
.30012 .3656 m .30454 .36237 L .3014 .35724 L p F P
0 g
s
.697 .663 .813 r
.3983 .34698 m .40907 .34146 L .4121 .34659 L p F P
0 g
s
.697 .668 .817 r
.40907 .34146 m .3983 .34698 L .39525 .34189 L p F P
0 g
s
.781 .648 .715 r
.2304 .44191 m .23146 .4405 L .22837 .4336 L p F P
0 g
s
.758 .669 .764 r
.26228 .38851 m .25817 .39225 L .25502 .38667 L p F P
0 g
s
.762 .671 .762 r
.25405 .39613 m .25817 .39225 L .25502 .38667 L p F P
0 g
s
.667 .323 .38 r
.39072 .54741 m .37973 .54711 L .37724 .54469 L p F P
0 g
s
.668 .322 .379 r
.37973 .54711 m .37623 .54701 L .37724 .54469 L closepath p F P
0 g
s
.758 .669 .764 r
.25502 .38667 m .25507 .38662 L .26228 .38851 L p F P
0 g
s
.756 .673 .769 r
.26401 .37877 m .25507 .38662 L .26228 .38851 L p F P
0 g
s
.756 .673 .769 r
.26737 .37969 m .26401 .37877 L p .26228 .38851 L F P
0 g
s
.756 .673 .769 r
.26228 .38851 m .26903 .38255 L .26737 .37969 L p F P
0 g
s
.764 .669 .757 r
.25405 .39613 m .24728 .4027 L .24412 .39704 L p F P
0 g
s
.764 .669 .757 r
.24412 .39704 m .24707 .39417 L .25405 .39613 L p F P
0 g
s
.762 .671 .762 r
.25502 .38667 m .24707 .39417 L .25405 .39613 L p F P
0 g
s
.615 .489 .685 r
.57593 .46437 m .57464 .459 L .58564 .45537 L p F P
0 g
s
.615 .489 .686 r
.58539 .45437 m .58564 .45537 L .57464 .459 L p F P
0 g
s
.784 .611 .665 r
.22826 .47086 m .23536 .47272 L .23234 .4787 L p F P
0 g
s
.784 .618 .675 r
.23536 .47272 m .22826 .47086 L .2317 .46476 L p F P
0 g
s
.614 .469 .661 r
.57766 .47227 m .57867 .47736 L .56741 .48036 L p F P
0 g
s
.609 .455 .647 r
.56848 .48655 m .56741 .48036 L .57867 .47736 L p F P
0 g
s
.668 .629 .802 r
.49665 .35584 m .486 .3578 L .48408 .35406 L p F P
0 g
s
.776 .568 .617 r
.24906 .49672 m .24939 .49564 L p .25535 .50288 L F P
0 g
s
.779 .57 .617 r
.24906 .49672 m .24939 .49564 L .24891 .49554 L closepath p F P
0 g
s
.711 .676 .814 r
.3676 .34349 m .35686 .34961 L .35377 .34465 L p F P
0 g
s
.752 .671 .772 r
.26903 .38255 m .27125 .38065 L .26737 .37969 L closepath p F P
0 g
s
.605 .349 .502 r
.51179 .52626 m .51761 .52532 L .52133 .52943 L p F P
0 g
s
.605 .349 .502 r
.52133 .52943 m .51139 .53104 L .51179 .52626 L p F P
0 g
s
.614 .357 .504 r
.51179 .52626 m .51139 .53104 L .4991 .53283 L p F P
0 g
s
.692 .659 .813 r
.4121 .34659 m .42288 .34126 L .4259 .34644 L p F P
0 g
s
.692 .664 .817 r
.42288 .34126 m .4121 .34659 L .40907 .34146 L p F P
0 g
s
.749 .676 .78 r
.27893 .37197 m .27984 .37352 L .27125 .38065 L p F P
0 g
s
.749 .676 .78 r
.27379 .37063 m .27893 .37197 L p .27125 .38065 L F P
0 g
s
.749 .676 .78 r
.26586 .37718 m .27379 .37063 L p .27125 .38065 L F P
0 g
s
.749 .676 .78 r
.27125 .38065 m .26737 .37969 L .26586 .37718 L p F P
0 g
s
.776 .654 .728 r
.22729 .42461 m .23412 .4266 L .22856 .43336 L p F P
0 g
s
.775 .657 .731 r
.23319 .41774 m .22729 .42461 L .23412 .4266 L p F P
0 g
s
.753 .473 .508 r
.3014 .53207 m .2949 .53107 L .29411 .52619 L p F P
0 g
s
.752 .471 .506 r
.28546 .52487 m .29411 .52619 L .2949 .53107 L p F P
0 g
s
.755 .498 .544 r
.29411 .52619 m .28546 .52487 L .28545 .52402 L p F P
0 g
s
.784 .573 .615 r
.24891 .49554 m .24206 .49388 L p .24772 .50122 L F P
0 g
s
.784 .573 .615 r
.24772 .50122 m .24906 .49672 L .24891 .49554 L p F P
0 g
s
.783 .643 .707 r
.22366 .43991 m .2304 .44191 L .22587 .44835 L p F P
0 g
s
.781 .648 .715 r
.22837 .4336 m .22366 .43991 L .2304 .44191 L p F P
0 g
s
.685 .331 .369 r
.3464 .54503 m .34795 .5415 L p .35733 .54605 L F P
0 g
s
.703 .364 .4 r
.3464 .54503 m .34355 .54112 L .34795 .5415 L closepath p F P
0 g
s
.768 .67 .755 r
.24644 .40355 m .24728 .4027 L .24412 .39704 L p F P
0 g
s
.768 .67 .755 r
.24412 .39704 m .23965 .40153 L .24644 .40355 L p F P
0 g
s
.768 .667 .751 r
.23965 .40153 m .24644 .40355 L .23957 .41072 L p F P
0 g
s
.647 .592 .778 r
.5453 .37449 m .54659 .37747 L .53532 .38056 L p F P
0 g
s
.647 .592 .778 r
.53532 .38056 m .53436 .37834 L .5453 .37449 L p F P
0 g
s
.621 .301 .408 r
.46008 .54191 m .45935 .54141 L .46024 .54135 L closepath p F P
0 g
s
.611 .274 .375 r
.45935 .54141 m .46008 .54191 L .45893 .54533 L p F P
0 g
s
.673 .636 .804 r
.48002 .3463 m .48112 .34837 L .47028 .35306 L p F P
0 g
s
.673 .636 .804 r
.47028 .35306 m .46772 .34822 L .48002 .3463 L p F P
0 g
s
.673 .634 .802 r
.47028 .35306 m .48112 .34837 L .48408 .35406 L p F P
0 g
s
.785 .621 .678 r
.2247 .46286 m .2317 .46476 L .22826 .47086 L p F P
0 g
s
.783 .627 .687 r
.2317 .46476 m .2247 .46286 L .22854 .45663 L p F P
0 g
s
.734 .678 .796 r
.31291 .35648 m .30454 .36237 L .3014 .35724 L p F P
0 g
s
.604 .275 .385 r
.46024 .54135 m .47312 .54019 L .47187 .5442 L p F P
0 g
s
.604 .275 .385 r
.46008 .54191 m .46024 .54135 L p .47187 .5442 L F P
0 g
s
.679 .647 .811 r
.46468 .34862 m .45511 .34978 L .4535 .34687 L p F P
0 g
s
.607 .429 .615 r
.55794 .49534 m .56937 .49256 L p .56456 .4997 L F P
0 g
s
.607 .429 .615 r
.56456 .4997 m .55861 .50114 L .55794 .49534 L p F P
0 g
s
.612 .445 .632 r
.56848 .48655 m .56937 .49256 L .55794 .49534 L p F P
0 g
s
.655 .605 .787 r
.52646 .36085 m .52851 .3653 L .5176 .3694 L p F P
0 g
s
.655 .605 .787 r
.5176 .3694 m .51496 .36369 L .52646 .36085 L p F P
0 g
s
.766 .507 .544 r
.28537 .52486 m .27728 .5234 L .27728 .51829 L p F P
0 g
s
.765 .507 .544 r
.26907 .51683 m .27728 .51829 L .27728 .5234 L p F P
0 g
s
.688 .659 .816 r
.43669 .3413 m .4259 .34644 L .42288 .34126 L p F P
0 g
s
.688 .656 .813 r
.4259 .34644 m .43669 .3413 L .4397 .34653 L p F P
0 g
s
.717 .673 .805 r
.34303 .35106 m .34612 .34918 L .34156 .34866 L closepath p F P
0 g
s
.723 .676 .804 r
.34156 .34866 m .34303 .35106 L p .32917 .35282 L F P
0 g
s
.643 .575 .763 r
.55406 .39563 m .55405 .39562 L .55389 .39567 L closepath p F P
0 g
s
.644 .576 .764 r
.55113 .38835 m .55405 .39562 L .55389 .39567 L p F P
0 g
s
.776 .568 .617 r
.25535 .50288 m .24969 .50168 L .24906 .49672 L p F P
0 g
s
.783 .573 .615 r
.24969 .50168 m .24906 .49672 L .24772 .50122 L closepath p F P
0 g
s
.736 .429 .462 r
.31649 .53843 m .31443 .53816 L .31271 .53354 L p F P
0 g
s
.737 .427 .457 r
.30361 .53237 m .31271 .53354 L .31443 .53816 L p F P
0 g
s
.638 .572 .764 r
.56503 .39204 m .56513 .39231 L .55406 .39563 L p F P
0 g
s
.638 .572 .764 r
.55406 .39563 m .55405 .39562 L .56503 .39204 L p F P
0 g
s
.638 .573 .765 r
.56503 .39204 m .55405 .39562 L .55113 .38835 L p F P
0 g
s
.777 .554 .597 r
.24969 .50168 m .25535 .50288 L .25414 .50834 L p F P
0 g
s
.776 .553 .597 r
.2619 .50995 m .25414 .50834 L .25535 .50288 L p F P
0 g
s
.714 .404 .452 r
.34355 .54112 m .33345 .54026 L .33283 .53897 L p F P
0 g
s
.715 .405 .451 r
.33345 .54026 m .33245 .54017 L .33283 .53897 L closepath p F P
0 g
s
.746 .673 .78 r
.27984 .37352 m .28114 .37249 L .27893 .37197 L closepath p F P
0 g
s
.732 .679 .798 r
.31679 .35723 m .3153 .35484 L .31291 .35648 L closepath p F P
0 g
s
.702 .355 .385 r
.34355 .54112 m .3464 .54503 L .34625 .54531 L p F P
0 g
s
.702 .355 .385 r
.33345 .54026 m .34355 .54112 L p .34625 .54531 L F P
0 g
s
.662 .617 .794 r
.50084 .36134 m .51173 .35703 L p .51076 .36462 L F P
0 g
s
.662 .618 .795 r
.50977 .35302 m .51173 .35703 L .50084 .36134 L p F P
0 g
s
.662 .618 .795 r
.50084 .36134 m .49802 .35557 L .50977 .35302 L p F P
0 g
s
.743 .678 .787 r
.28957 .36337 m .29063 .36511 L .28114 .37249 L p F P
0 g
s
.743 .678 .787 r
.28464 .36215 m .28957 .36337 L p .28114 .37249 L F P
0 g
s
.743 .678 .787 r
.27668 .36831 m .28464 .36215 L p .28114 .37249 L F P
0 g
s
.743 .678 .787 r
.28114 .37249 m .27893 .37197 L .27668 .36831 L p F P
0 g
s
.647 .589 .776 r
.5453 .37449 m .53436 .37834 L .53143 .37169 L p F P
0 g
s
.608 .324 .46 r
.49858 .53602 m .495 .53336 L .4991 .53283 L closepath p F P
0 g
s
.609 .321 .454 r
.495 .53336 m .49858 .53602 L p .48582 .53883 L F P
0 g
s
.611 .478 .675 r
.5774 .47097 m .57593 .46437 L .58703 .46115 L p F P
0 g
s
.615 .489 .685 r
.58564 .45537 m .58703 .46115 L .57593 .46437 L p F P
0 g
s
.771 .662 .742 r
.23631 .41425 m .23957 .41072 L .23357 .409 L closepath p F P
0 g
s
.768 .667 .751 r
.23316 .40825 m .23965 .40153 L p .23957 .41072 L F P
0 g
s
.768 .667 .751 r
.23957 .41072 m .23357 .409 L .23316 .40825 L p F P
0 g
s
.785 .63 .689 r
.22163 .4547 m .22854 .45663 L .2247 .46286 L p F P
0 g
s
.783 .635 .697 r
.22854 .45663 m .22163 .4547 L .22587 .44835 L p F P
0 g
s
.661 .614 .791 r
.51496 .36369 m .51466 .36308 L .51076 .36462 L closepath p F P
0 g
s
.662 .617 .794 r
.51173 .35703 m .51466 .36308 L .51076 .36462 L p F P
0 g
s
.604 .275 .385 r
.47187 .5442 m .46565 .54476 L .46008 .54191 L p F P
0 g
s
.605 .272 .379 r
.46565 .54476 m .45893 .54533 L .46008 .54191 L closepath p F P
0 g
s
.683 .654 .815 r
.45051 .34158 m .4397 .34653 L .43669 .3413 L p F P
0 g
s
.715 .677 .812 r
.35066 .33975 m .35377 .34465 L .34612 .34918 L p F P
0 g
s
.715 .677 .812 r
.33992 .34606 m .35066 .33975 L p .34612 .34918 L F P
0 g
s
.715 .677 .812 r
.34612 .34918 m .34156 .34866 L .33992 .34606 L p F P
0 g
s
.723 .676 .804 r
.32917 .35282 m .33684 .34796 L .34156 .34866 L p F P
0 g
s
.722 .678 .807 r
.33684 .34796 m .32917 .35282 L .32605 .34778 L p F P
0 g
s
.775 .663 .74 r
.23319 .41774 m .23631 .41425 L .23357 .409 L p F P
0 g
s
.776 .654 .728 r
.22525 .42711 m .22729 .42461 L p .22856 .43336 L F P
0 g
s
.776 .654 .728 r
.22856 .43336 m .22821 .43326 L .22525 .42711 L p F P
0 g
s
.779 .648 .717 r
.22837 .4336 m .22856 .43336 L .22821 .43326 L closepath p F P
0 g
s
.604 .349 .504 r
.51761 .52532 m .5239 .52427 L .52353 .52907 L p F P
0 g
s
.604 .349 .504 r
.52353 .52907 m .52133 .52943 L .51761 .52532 L p F P
0 g
s
.755 .678 .776 r
.26737 .37969 m .26586 .37718 L .26401 .37877 L closepath p F P
0 g
s
.757 .499 .543 r
.28546 .52487 m .28537 .52486 L .28545 .52402 L closepath p F P
0 g
s
.783 .65 .715 r
.22366 .43991 m .22837 .4336 L .22821 .43326 L p F P
0 g
s
.776 .536 .572 r
.2683 .51669 m .26127 .51524 L .2619 .50995 L p F P
0 g
s
.776 .536 .573 r
.25414 .50834 m .2619 .50995 L .26127 .51524 L p F P
0 g
s
.75 .68 .783 r
.27893 .37197 m .27668 .36831 L .27379 .37063 L closepath p F P
0 g
s
.782 .656 .724 r
.22821 .43326 m .22525 .42711 L .22192 .43131 L closepath p F P
0 g
s
.783 .65 .715 r
.22821 .43326 m .22192 .43131 L p .22366 .43991 L F P
0 g
s
.668 .629 .802 r
.48408 .35406 m .49495 .34959 L p .49665 .35584 L F P
0 g
s
.668 .63 .802 r
.49495 .34959 m .48408 .35406 L .48112 .34837 L p F P
0 g
s
.595 .306 .449 r
.4991 .53283 m .51139 .53104 L .51065 .53548 L p F P
0 g
s
.595 .306 .449 r
.49858 .53602 m .4991 .53283 L p .51065 .53548 L F P
0 g
s
.734 .678 .796 r
.3014 .35724 m .3048 .35487 L .31291 .35648 L p F P
0 g
s
.734 .682 .8 r
.31216 .34986 m .3048 .35487 L .31291 .35648 L p F P
0 g
s
.734 .682 .8 r
.31291 .35648 m .3153 .35484 L .31216 .34986 L p F P
0 g
s
.776 .661 .737 r
.2265 .4157 m .23319 .41774 L .22729 .42461 L p F P
0 g
s
.775 .663 .74 r
.23271 .40873 m .2265 .4157 L .23319 .41774 L p F P
0 g
s
.775 .663 .74 r
.23357 .409 m .23271 .40873 L p .23319 .41774 L F P
0 g
s
.74 .676 .788 r
.29063 .36511 m .29221 .36393 L .28957 .36337 L closepath p F P
0 g
s
.654 .306 .371 r
.40435 .54751 m .39168 .54742 L .39098 .54683 L p F P
0 g
s
.655 .306 .369 r
.39168 .54742 m .39072 .54741 L .39098 .54683 L closepath p F P
0 g
s
.784 .639 .7 r
.21906 .44637 m .22587 .44835 L .22163 .4547 L p F P
0 g
s
.783 .643 .707 r
.22587 .44835 m .21906 .44637 L .22366 .43991 L p F P
0 g
s
.679 .647 .811 r
.4535 .34687 m .46433 .34211 L p .46468 .34862 L F P
0 g
s
.679 .651 .815 r
.46433 .34211 m .4535 .34687 L .45051 .34158 L p F P
0 g
s
.721 .679 .808 r
.34156 .34866 m .33992 .34606 L .33684 .34796 L closepath p F P
0 g
s
.702 .355 .385 r
.34625 .54531 m .33669 .54444 L .33345 .54026 L p F P
0 g
s
.701 .355 .387 r
.33245 .54017 m .33345 .54026 L .33669 .54444 L p F P
0 g
s
.639 .574 .766 r
.56156 .38339 m .56211 .38476 L .55113 .38835 L p F P
0 g
s
.639 .574 .766 r
.55113 .38835 m .55047 .38671 L .56156 .38339 L p F P
0 g
s
.638 .573 .765 r
.55113 .38835 m .56211 .38476 L .56503 .39204 L p F P
0 g
s
.678 .643 .808 r
.46772 .34822 m .46731 .34746 L .46468 .34862 L closepath p F P
0 g
s
.679 .647 .811 r
.46433 .34211 m .46731 .34746 L .46468 .34862 L p F P
0 g
s
.737 .68 .795 r
.29925 .35377 m .3014 .35724 L .29221 .36393 L p F P
0 g
s
.737 .68 .795 r
.29684 .35321 m .29925 .35377 L p .29221 .36393 L F P
0 g
s
.737 .68 .795 r
.28747 .36001 m .29684 .35321 L p .29221 .36393 L F P
0 g
s
.737 .68 .795 r
.29221 .36393 m .28957 .36337 L .28747 .36001 L p F P
0 g
s
.605 .44 .632 r
.56937 .49256 m .56848 .48655 L .57975 .48356 L p F P
0 g
s
.609 .455 .647 r
.57867 .47736 m .57975 .48356 L .56848 .48655 L p F P
0 g
s
.753 .472 .506 r
.28537 .52486 m .28546 .52487 L .28626 .52974 L p F P
0 g
s
.752 .471 .506 r
.2949 .53107 m .28626 .52974 L .28546 .52487 L p F P
0 g
s
.596 .267 .384 r
.47187 .5442 m .47312 .54019 L .4783 .53965 L p F P
0 g
s
.753 .472 .506 r
.28626 .52974 m .28446 .52946 L .28537 .52486 L p F P
0 g
s
.763 .482 .507 r
.27728 .5234 m .28537 .52486 L .28446 .52946 L p F P
0 g
s
.701 .355 .387 r
.33669 .54444 m .33064 .54391 L .33245 .54017 L p F P
0 g
s
.713 .369 .392 r
.32389 .53923 m .33245 .54017 L .33064 .54391 L p F P
0 g
s
.621 .526 .726 r
.57933 .43278 m .57692 .42517 L .58785 .42169 L p F P
0 g
s
.623 .535 .734 r
.58776 .42142 m .58785 .42169 L .57692 .42517 L p F P
0 g
s
.623 .535 .734 r
.57692 .42517 m .57674 .42461 L .58776 .42142 L p F P
0 g
s
.728 .682 .806 r
.32605 .34778 m .3153 .35484 L .31216 .34986 L p F P
0 g
s
.623 .536 .735 r
.58522 .41383 m .58776 .42142 L .57674 .42461 L p F P
0 g
s
.623 .536 .735 r
.57674 .42461 m .5743 .41732 L .58522 .41383 L p F P
0 g
s
.621 .526 .726 r
.58785 .42169 m .59025 .42931 L .57933 .43278 L p F P
0 g
s
.618 .517 .717 r
.57968 .43398 m .57933 .43278 L .59025 .42931 L p F P
0 g
s
.618 .516 .717 r
.58153 .44017 m .57968 .43398 L .59071 .43085 L p F P
0 g
s
.618 .517 .717 r
.59025 .42931 m .59071 .43085 L .57968 .43398 L p F P
0 g
s
.64 .581 .772 r
.55919 .37773 m .56156 .38339 L .55047 .38671 L p F P
0 g
s
.64 .581 .772 r
.55047 .38671 m .54821 .38132 L .55919 .37773 L p F P
0 g
s
.785 .588 .634 r
.24206 .49388 m .23477 .4921 L .23693 .48637 L p F P
0 g
s
.786 .59 .636 r
.22971 .48457 m .23693 .48637 L .23477 .4921 L p F P
0 g
s
.785 .6 .65 r
.23693 .48637 m .22971 .48457 L .23234 .4787 L p F P
0 g
s
.737 .427 .457 r
.31443 .53816 m .3054 .53696 L .30361 .53237 L p F P
0 g
s
.736 .427 .457 r
.3014 .53207 m .30361 .53237 L .3054 .53696 L p F P
0 g
s
.786 .602 .651 r
.22666 .47724 m .23234 .4787 L .22971 .48457 L p F P
0 g
s
.784 .611 .665 r
.22607 .47517 m .22826 .47086 L p .23234 .4787 L F P
0 g
s
.784 .611 .665 r
.23234 .4787 m .22666 .47724 L .22607 .47517 L p F P
0 g
s
.656 .611 .793 r
.52558 .35902 m .52646 .36085 L .51496 .36369 L p F P
0 g
s
.656 .611 .793 r
.51496 .36369 m .51466 .36308 L .52558 .35902 L p F P
0 g
s
.777 .554 .597 r
.25414 .50834 m .25007 .50748 L .24969 .50168 L p F P
0 g
s
.784 .56 .595 r
.24772 .50122 m .24969 .50168 L .25007 .50748 L p F P
0 g
s
.599 .368 .539 r
.53583 .52208 m .5359 .517 L .54767 .51462 L p F P
0 g
s
.609 .397 .569 r
.54746 .50929 m .54767 .51462 L .5359 .517 L p F P
0 g
s
.607 .376 .54 r
.5359 .517 m .53583 .52208 L .5239 .52427 L p F P
0 g
s
.626 .544 .742 r
.58482 .41266 m .58522 .41383 L .5743 .41732 L p F P
0 g
s
.626 .544 .742 r
.5743 .41732 m .5738 .41588 L .58482 .41266 L p F P
0 g
s
.607 .464 .662 r
.57766 .47227 m .5774 .47097 L .58851 .46776 L p F P
0 g
s
.611 .478 .675 r
.58703 .46115 m .58851 .46776 L .5774 .47097 L p F P
0 g
s
.6 .391 .569 r
.54746 .50929 m .55637 .50732 L .55389 .51325 L p F P
0 g
s
.6 .391 .569 r
.55389 .51325 m .54767 .51462 L .54746 .50929 L p F P
0 g
s
.759 .672 .766 r
.25502 .38667 m .25507 .38662 L .25497 .38659 L closepath p F P
0 g
s
.762 .675 .766 r
.25497 .38659 m .25502 .38667 L .24707 .39417 L p F P
0 g
s
.756 .676 .774 r
.25702 .37679 m .26401 .37877 L .25507 .38662 L p F P
0 g
s
.756 .676 .774 r
.25184 .38135 m .25702 .37679 L p .25507 .38662 L F P
0 g
s
.756 .676 .774 r
.25507 .38662 m .25497 .38659 L .25184 .38135 L p F P
0 g
s
.762 .675 .766 r
.24827 .38459 m .25497 .38659 L p .24707 .39417 L F P
0 g
s
.762 .678 .77 r
.25497 .38659 m .25184 .38135 L .24827 .38459 L closepath p F P
0 g
s
.626 .544 .743 r
.58239 .40573 m .58482 .41266 L .5738 .41588 L p F P
0 g
s
.626 .544 .743 r
.5738 .41588 m .57148 .40925 L .58239 .40573 L p F P
0 g
s
.673 .641 .81 r
.47816 .34288 m .48002 .3463 L .46772 .34822 L p F P
0 g
s
.673 .641 .81 r
.46772 .34822 m .46731 .34746 L .47816 .34288 L p F P
0 g
s
.784 .573 .615 r
.24206 .49388 m .24039 .49947 L .24772 .50122 L p F P
0 g
s
.786 .576 .617 r
.23477 .4921 m .24206 .49388 L .24039 .49947 L p F P
0 g
s
.657 .614 .795 r
.52558 .35902 m .51466 .36308 L .51173 .35703 L p F P
0 g
s
.787 .613 .665 r
.22607 .47517 m .22826 .47086 L .22454 .46987 L closepath p F P
0 g
s
.785 .621 .678 r
.22315 .46562 m .2247 .46286 L p .22826 .47086 L F P
0 g
s
.785 .621 .678 r
.22826 .47086 m .22454 .46987 L .22315 .46562 L p F P
0 g
s
.611 .219 .275 r
.4049 .54752 m .41786 .54736 L p .41674 .55071 L F P
0 g
s
.611 .219 .275 r
.40476 .54778 m .4049 .54752 L p .41674 .55071 L F P
0 g
s
.638 .268 .327 r
.40476 .54778 m .40435 .54751 L .4049 .54752 L closepath p F P
0 g
s
.624 .232 .279 r
.40435 .54751 m .40476 .54778 L .40279 .55085 L p F P
0 g
s
.624 .232 .279 r
.39168 .54742 m .40435 .54751 L p .40279 .55085 L F P
0 g
s
.667 .626 .799 r
.49802 .35557 m .4979 .35532 L .49665 .35584 L closepath p F P
0 g
s
.668 .629 .802 r
.49495 .34959 m .4979 .35532 L .49665 .35584 L p F P
0 g
s
.765 .67 .758 r
.24412 .39704 m .24707 .39417 L .24163 .39261 L closepath p F P
0 g
s
.762 .675 .766 r
.24094 .39145 m .24827 .38459 L p .24707 .39417 L F P
0 g
s
.762 .675 .766 r
.24707 .39417 m .24163 .39261 L .24094 .39145 L p F P
0 g
s
.615 .507 .708 r
.58265 .44415 m .58153 .44017 L .59246 .43671 L p F P
0 g
s
.618 .516 .717 r
.59071 .43085 m .59246 .43671 L .58153 .44017 L p F P
0 g
s
.765 .507 .544 r
.27728 .5234 m .26907 .52193 L .26907 .51683 L p F P
0 g
s
.767 .508 .544 r
.2683 .51669 m .26907 .51683 L .26907 .52193 L p F P
0 g
s
.649 .595 .781 r
.53143 .37169 m .5416 .36809 L .5311 .37095 L closepath p F P
0 g
s
.647 .589 .776 r
.5424 .36787 m .5453 .37449 L p .53143 .37169 L F P
0 g
s
.647 .589 .776 r
.53143 .37169 m .5416 .36809 L .5424 .36787 L p F P
0 g
s
.756 .68 .777 r
.26269 .37195 m .25702 .37679 L .26401 .37877 L p F P
0 g
s
.756 .68 .777 r
.26401 .37877 m .26586 .37718 L .26269 .37195 L p F P
0 g
s
.702 .671 .817 r
.39353 .33908 m .39525 .34189 L p .38143 .34257 L F P
0 g
s
.702 .671 .817 r
.38143 .34257 m .3884 .3389 L .39353 .33908 L p F P
0 g
s
.702 .672 .817 r
.38143 .34257 m .3884 .3389 L .37895 .33856 L closepath p F P
0 g
s
.707 .674 .816 r
.37895 .33856 m .38143 .34257 L p .3676 .34349 L F P
0 g
s
.769 .671 .755 r
.23965 .40153 m .24412 .39704 L .24163 .39261 L p F P
0 g
s
.624 .232 .279 r
.40279 .55085 m .39776 .55081 L .39168 .54742 L p F P
0 g
s
.625 .231 .276 r
.39072 .54741 m .39168 .54742 L .39776 .55081 L p F P
0 g
s
.611 .274 .375 r
.45893 .54533 m .44814 .54609 L .44623 .54504 L p F P
0 g
s
.612 .272 .369 r
.44814 .54609 m .44579 .54624 L .44623 .54504 L closepath p F P
0 g
s
.629 .299 .393 r
.44623 .54504 m .44579 .54624 L .43242 .54693 L p F P
0 g
s
.625 .231 .276 r
.39776 .55081 m .38855 .55072 L .39072 .54741 L p F P
0 g
s
.638 .245 .284 r
.37973 .54711 m .39072 .54741 L .38855 .55072 L p F P
0 g
s
.736 .427 .457 r
.3054 .53696 m .30003 .53626 L .3014 .53207 L p F P
0 g
s
.747 .438 .46 r
.2949 .53107 m .3014 .53207 L .30003 .53626 L p F P
0 g
s
.698 .669 .818 r
.39525 .34189 m .4007 .33913 L .39353 .33908 L closepath p F P
0 g
s
.697 .668 .817 r
.40767 .33915 m .40907 .34146 L p .39525 .34189 L F P
0 g
s
.697 .668 .817 r
.39525 .34189 m .4007 .33913 L .40767 .33915 L p F P
0 g
s
.752 .679 .78 r
.27379 .37063 m .26586 .37718 L .26269 .37195 L p F P
0 g
s
.744 .682 .791 r
.28957 .36337 m .28747 .36001 L .28464 .36215 L closepath p F P
0 g
s
.607 .464 .661 r
.57867 .47736 m .57766 .47227 L .58867 .46856 L p F P
0 g
s
.607 .464 .662 r
.58851 .46776 m .58867 .46856 L .57766 .47227 L p F P
0 g
s
.707 .674 .816 r
.3676 .34349 m .37687 .33843 L .37895 .33856 L p F P
0 g
s
.706 .678 .821 r
.37687 .33843 m .3676 .34349 L .36452 .33855 L p F P
0 g
s
.711 .676 .814 r
.35377 .34465 m .36452 .33855 L .3676 .34349 L p F P
0 g
s
.611 .219 .275 r
.41786 .54736 m .41857 .54777 L .41674 .55071 L p F P
0 g
s
.626 .257 .324 r
.41857 .54777 m .41786 .54736 L .41879 .54734 L closepath p F P
0 g
s
.767 .508 .544 r
.26907 .52193 m .26782 .52171 L .2683 .51669 L p F P
0 g
s
.775 .516 .543 r
.26127 .51524 m .2683 .51669 L .26782 .52171 L p F P
0 g
s
.599 .208 .274 r
.41879 .54734 m .4323 .54693 L p .43043 .55032 L F P
0 g
s
.599 .208 .274 r
.41857 .54777 m .41879 .54734 L p .43043 .55032 L F P
0 g
s
.722 .678 .807 r
.32605 .34778 m .32789 .34663 L .33684 .34796 L p F P
0 g
s
.723 .683 .811 r
.3368 .3412 m .32789 .34663 L .33684 .34796 L p F P
0 g
s
.723 .683 .811 r
.33684 .34796 m .33992 .34606 L .3368 .3412 L p F P
0 g
s
.595 .272 .392 r
.48473 .54258 m .4783 .53965 L .48582 .53883 L closepath p F P
0 g
s
.596 .267 .384 r
.4783 .53965 m .48473 .54258 L p .47187 .5442 L F P
0 g
s
.65 .602 .787 r
.5416 .36809 m .5311 .37095 L .52851 .3653 L p F P
0 g
s
.674 .646 .814 r
.47816 .34288 m .46731 .34746 L .46433 .34211 L p F P
0 g
s
.779 .655 .727 r
.22525 .42711 m .22729 .42461 L .22348 .42347 L closepath p F P
0 g
s
.776 .661 .737 r
.22211 .4208 m .2265 .4157 L p .22729 .42461 L F P
0 g
s
.776 .661 .737 r
.22729 .42461 m .22348 .42347 L .22211 .4208 L p F P
0 g
s
.595 .341 .502 r
.52353 .52907 m .5239 .52427 L .53583 .52208 L p F P
0 g
s
.662 .624 .8 r
.50879 .35108 m .50977 .35302 L .49802 .35557 L p F P
0 g
s
.662 .624 .8 r
.49802 .35557 m .4979 .35532 L .50879 .35108 L p F P
0 g
s
.628 .552 .75 r
.58189 .40434 m .58239 .40573 L .57148 .40925 L p F P
0 g
s
.628 .552 .75 r
.57148 .40925 m .57087 .40758 L .58189 .40434 L p F P
0 g
s
.615 .507 .707 r
.58355 .44736 m .58265 .44415 L .59369 .44105 L p F P
0 g
s
.615 .507 .708 r
.59246 .43671 m .59369 .44105 L .58265 .44415 L p F P
0 g
s
.784 .647 .711 r
.21697 .43788 m .22366 .43991 L .21906 .44637 L p F P
0 g
s
.783 .65 .715 r
.22192 .43131 m .21697 .43788 L .22366 .43991 L p F P
0 g
s
.692 .664 .817 r
.42141 .33879 m .42288 .34126 L p .40907 .34146 L F P
0 g
s
.692 .664 .817 r
.40907 .34146 m .41407 .33901 L .42141 .33879 L p F P
0 g
s
.693 .666 .819 r
.40907 .34146 m .41407 .33901 L .40767 .33915 L closepath p F P
0 g
s
.784 .56 .595 r
.25007 .50748 m .24656 .50666 L .24772 .50122 L p F P
0 g
s
.786 .562 .596 r
.24039 .49947 m .24772 .50122 L .24656 .50666 L p F P
0 g
s
.769 .671 .755 r
.24019 .39217 m .23291 .39949 L .23965 .40153 L p F P
0 g
s
.769 .671 .755 r
.24163 .39261 m .24019 .39217 L p .23965 .40153 L F P
0 g
s
.771 .669 .75 r
.23965 .40153 m .23316 .40825 L .22998 .40253 L p F P
0 g
s
.771 .669 .75 r
.22998 .40253 m .23291 .39949 L .23965 .40153 L p F P
0 g
s
.787 .622 .677 r
.22315 .46562 m .2247 .46286 L .22199 .46211 L closepath p F P
0 g
s
.785 .63 .689 r
.22015 .45711 m .22163 .4547 L p .2247 .46286 L F P
0 g
s
.785 .63 .689 r
.2247 .46286 m .22199 .46211 L .22015 .45711 L p F P
0 g
s
.611 .219 .275 r
.41674 .55071 m .41087 .55078 L .40476 .54778 L p F P
0 g
s
.611 .216 .27 r
.41087 .55078 m .40279 .55085 L .40476 .54778 L closepath p F P
0 g
s
.663 .628 .804 r
.50879 .35108 m .4979 .35532 L .49495 .34959 L p F P
0 g
s
.711 .682 .82 r
.36452 .33855 m .35377 .34465 L .35066 .33975 L p F P
0 g
s
.6 .408 .593 r
.5589 .50461 m .56456 .4997 L .55861 .50114 L closepath p F P
0 g
s
.608 .414 .594 r
.55861 .50114 m .5589 .50461 L .55637 .50732 L p F P
0 g
s
.628 .553 .751 r
.57934 .39738 m .58189 .40434 L .57087 .40758 L p F P
0 g
s
.628 .553 .751 r
.57087 .40758 m .56843 .40091 L .57934 .39738 L p F P
0 g
s
.638 .245 .284 r
.38855 .55072 m .38536 .55063 L .37973 .54711 L p F P
0 g
s
.638 .245 .283 r
.37623 .54701 m .37973 .54711 L .38536 .55063 L p F P
0 g
s
.612 .497 .698 r
.58539 .45437 m .58355 .44736 L .59449 .44392 L p F P
0 g
s
.615 .507 .707 r
.59369 .44105 m .59449 .44392 L .58355 .44736 L p F P
0 g
s
.774 .669 .748 r
.23357 .409 m .23316 .40825 L .23271 .40873 L closepath p F P
0 g
s
.752 .679 .78 r
.26269 .37195 m .26661 .36872 L .27379 .37063 L p F P
0 g
s
.751 .682 .784 r
.27351 .36319 m .26661 .36872 L .27379 .37063 L p F P
0 g
s
.751 .682 .784 r
.27379 .37063 m .27668 .36831 L .27351 .36319 L p F P
0 g
s
.734 .678 .796 r
.3014 .35724 m .3048 .35487 L .29925 .35377 L closepath p F P
0 g
s
.638 .245 .283 r
.38536 .55063 m .37401 .55031 L .37623 .54701 L p F P
0 g
s
.651 .261 .291 r
.36833 .54664 m .37623 .54701 L .37401 .55031 L p F P
0 g
s
.782 .657 .724 r
.22192 .43131 m .22525 .42711 L .22348 .42347 L p F P
0 g
s
.688 .659 .816 r
.43478 .33804 m .43669 .3413 L p .42288 .34126 L F P
0 g
s
.688 .659 .816 r
.42288 .34126 m .42893 .3384 L .43478 .33804 L p F P
0 g
s
.689 .663 .819 r
.42288 .34126 m .42893 .3384 L .42141 .33879 L closepath p F P
0 g
s
.615 .25 .326 r
.43239 .54698 m .4323 .54693 L .43242 .54693 L closepath p F P
0 g
s
.599 .208 .274 r
.4323 .54693 m .43239 .54698 L .43043 .55032 L p F P
0 g
s
.588 .203 .279 r
.43242 .54693 m .44579 .54624 L .44387 .54968 L p F P
0 g
s
.588 .203 .279 r
.43239 .54698 m .43242 .54693 L p .44387 .54968 L F P
0 g
s
.713 .369 .392 r
.33064 .54391 m .32686 .54349 L .32389 .53923 L p F P
0 g
s
.71 .356 .375 r
.31649 .53843 m .32389 .53923 L .32686 .54349 L p F P
0 g
s
.588 .203 .279 r
.44387 .54968 m .43996 .54988 L .43239 .54698 L p F P
0 g
s
.588 .198 .27 r
.43996 .54988 m .43043 .55032 L .43239 .54698 L closepath p F P
0 g
s
.641 .582 .773 r
.55768 .37413 m .55919 .37773 L .54821 .38132 L p F P
0 g
s
.641 .582 .773 r
.54821 .38132 m .54659 .37747 L .55768 .37413 L p F P
0 g
s
.717 .684 .817 r
.35066 .33975 m .33992 .34606 L .3368 .3412 L p F P
0 g
s
.599 .208 .274 r
.43043 .55032 m .42487 .55049 L .41857 .54777 L p F P
0 g
s
.599 .204 .267 r
.42487 .55049 m .41674 .55071 L .41857 .54777 L closepath p F P
0 g
s
.746 .681 .788 r
.28464 .36215 m .27668 .36831 L .27351 .36319 L p F P
0 g
s
.775 .671 .749 r
.23271 .40873 m .23316 .40825 L .22998 .40253 L p F P
0 g
s
.776 .666 .742 r
.22616 .40663 m .23271 .40873 L .2265 .4157 L p F P
0 g
s
.775 .671 .749 r
.22998 .40253 m .22616 .40663 L .23271 .40873 L p F P
0 g
s
.787 .631 .688 r
.22015 .45711 m .22163 .4547 L .21898 .45394 L closepath p F P
0 g
s
.784 .639 .7 r
.21711 .44931 m .21906 .44637 L p .22163 .4547 L F P
0 g
s
.784 .639 .7 r
.22163 .4547 m .21898 .45394 L .21711 .44931 L p F P
0 g
s
.776 .536 .573 r
.26127 .51524 m .25349 .51363 L .25414 .50834 L p F P
0 g
s
.777 .538 .573 r
.25007 .50748 m .25414 .50834 L .25349 .51363 L p F P
0 g
s
.63 .561 .758 r
.57896 .39639 m .57934 .39738 L .56843 .40091 L p F P
0 g
s
.63 .561 .758 r
.56843 .40091 m .56795 .39966 L .57896 .39639 L p F P
0 g
s
.651 .261 .291 r
.37401 .55031 m .37351 .55028 L .36833 .54664 L p F P
0 g
s
.638 .225 .243 r
.36141 .54632 m .36833 .54664 L .37351 .55028 L p F P
0 g
s
.731 .682 .803 r
.30901 .34492 m .31216 .34986 L .3048 .35487 L p F P
0 g
s
.731 .682 .803 r
.29825 .35221 m .30901 .34492 L p .3048 .35487 L F P
0 g
s
.731 .682 .803 r
.3048 .35487 m .29925 .35377 L .29825 .35221 L p F P
0 g
s
.791 .615 .663 r
.22454 .46987 m .22133 .46894 L p .22525 .47684 L F P
0 g
s
.791 .615 .663 r
.22525 .47684 m .22607 .47517 L .22454 .46987 L p F P
0 g
s
.791 .624 .674 r
.22454 .46987 m .22315 .46562 L .22133 .46894 L closepath p F P
0 g
s
.683 .654 .815 r
.44784 .33694 m .45051 .34158 L p .43669 .3413 L F P
0 g
s
.683 .654 .815 r
.43669 .3413 m .44583 .33713 L .44784 .33694 L p F P
0 g
s
.684 .658 .818 r
.43669 .3413 m .44583 .33713 L .43478 .33804 L closepath p F P
0 g
s
.791 .624 .675 r
.22133 .46894 m .22315 .46562 L .22199 .46211 L p F P
0 g
s
.63 .561 .758 r
.57604 .38877 m .57896 .39639 L .56795 .39966 L p F P
0 g
s
.63 .561 .758 r
.56795 .39966 m .56513 .39231 L .57604 .38877 L p F P
0 g
s
.576 .242 .367 r
.48582 .53883 m .49834 .53728 L .49714 .5413 L p F P
0 g
s
.576 .242 .367 r
.48473 .54258 m .48582 .53883 L p .49714 .5413 L F P
0 g
s
.609 .321 .454 r
.49858 .53602 m .49834 .53728 L .48582 .53883 L p F P
0 g
s
.791 .624 .675 r
.22199 .46211 m .2179 .46089 L p .22133 .46894 L F P
0 g
s
.79 .633 .686 r
.22199 .46211 m .22015 .45711 L .2179 .46089 L closepath p F P
0 g
s
.668 .63 .802 r
.49212 .34413 m .49495 .34959 L p .48112 .34837 L F P
0 g
s
.668 .63 .802 r
.48112 .34837 m .49085 .34436 L .49212 .34413 L p F P
0 g
s
.67 .636 .807 r
.48112 .34837 m .49085 .34436 L .48002 .3463 L closepath p F P
0 g
s
.608 .484 .687 r
.58564 .45537 m .58539 .45437 L .59634 .45093 L p F P
0 g
s
.612 .497 .698 r
.59449 .44392 m .59634 .45093 L .58539 .45437 L p F P
0 g
s
.763 .482 .507 r
.28446 .52946 m .278 .5283 L .27728 .5234 L p F P
0 g
s
.763 .48 .506 r
.26907 .52193 m .27728 .5234 L .278 .5283 L p F P
0 g
s
.747 .438 .46 r
.30003 .53626 m .29652 .53571 L .2949 .53107 L p F P
0 g
s
.747 .435 .455 r
.28626 .52974 m .2949 .53107 L .29652 .53571 L p F P
0 g
s
.602 .45 .648 r
.57975 .48356 m .57867 .47736 L .58978 .47416 L p F P
0 g
s
.607 .464 .661 r
.58867 .46856 m .58978 .47416 L .57867 .47736 L p F P
0 g
s
.722 .679 .807 r
.32605 .34778 m .32789 .34663 L .32506 .34621 L closepath p F P
0 g
s
.728 .682 .806 r
.32506 .34621 m .32605 .34778 L p .31216 .34986 L F P
0 g
s
.782 .657 .724 r
.22063 .42256 m .21534 .42924 L .22192 .43131 L p F P
0 g
s
.782 .657 .724 r
.22348 .42347 m .22063 .42256 L p .22192 .43131 L F P
0 g
s
.783 .654 .72 r
.21534 .42924 m .22192 .43131 L .21697 .43788 L p F P
0 g
s
.588 .303 .451 r
.51065 .53548 m .51139 .53104 L .52133 .52943 L p F P
0 g
s
.79 .614 .662 r
.22666 .47724 m .22607 .47517 L .22525 .47684 L closepath p F P
0 g
s
.638 .225 .243 r
.3601 .54831 m .36141 .54632 L p .37351 .55028 L F P
0 g
s
.668 .284 .309 r
.3601 .54831 m .35733 .54605 L .36141 .54632 L closepath p F P
0 g
s
.607 .484 .686 r
.58703 .46115 m .58564 .45537 L .59669 .45235 L p F P
0 g
s
.608 .484 .687 r
.59634 .45093 m .59669 .45235 L .58564 .45537 L p F P
0 g
s
.692 .671 .824 r
.41407 .33901 m .40767 .33915 L .40602 .3365 L p F P
0 g
s
.696 .672 .823 r
.40767 .33915 m .40602 .3365 L .4007 .33913 L closepath p F P
0 g
s
.786 .602 .651 r
.22971 .48457 m .22836 .48422 L .22666 .47724 L p F P
0 g
s
.793 .606 .648 r
.22525 .47684 m .22666 .47724 L .22836 .48422 L p F P
0 g
s
.696 .673 .824 r
.40297 .33172 m .40602 .3365 L .4007 .33913 L p F P
0 g
s
.696 .673 .824 r
.39219 .33696 m .40297 .33172 L p .4007 .33913 L F P
0 g
s
.696 .673 .824 r
.4007 .33913 m .39353 .33908 L .39219 .33696 L p F P
0 g
s
.746 .681 .788 r
.27351 .36319 m .27727 .36029 L .28464 .36215 L p F P
0 g
s
.745 .684 .792 r
.2843 .355 m .27727 .36029 L .28464 .36215 L p F P
0 g
s
.745 .684 .792 r
.28464 .36215 m .28747 .36001 L .2843 .355 L p F P
0 g
s
.598 .422 .614 r
.56981 .4963 m .56937 .49256 L .58066 .48957 L p F P
0 g
s
.605 .44 .632 r
.57975 .48356 m .58066 .48957 L .56937 .49256 L p F P
0 g
s
.607 .429 .615 r
.56937 .49256 m .56981 .4963 L .56456 .4997 L p F P
0 g
s
.642 .589 .78 r
.55627 .37089 m .55768 .37413 L .54659 .37747 L p F P
0 g
s
.642 .589 .78 r
.54659 .37747 m .5453 .37449 L .55627 .37089 L p F P
0 g
s
.578 .191 .273 r
.44579 .54624 m .44814 .54609 L .45642 .54887 L p F P
0 g
s
.578 .191 .273 r
.45642 .54887 m .44387 .54968 L .44579 .54624 L p F P
0 g
s
.701 .675 .822 r
.39353 .33908 m .39219 .33696 L .3884 .3389 L closepath p F P
0 g
s
.781 .663 .733 r
.22348 .42347 m .22211 .4208 L .22063 .42256 L closepath p F P
0 g
s
.791 .633 .686 r
.2179 .46089 m .22015 .45711 L .21898 .45394 L p F P
0 g
s
.692 .668 .823 r
.42141 .33879 m .41985 .33625 L .41407 .33901 L closepath p F P
0 g
s
.692 .671 .824 r
.41681 .33142 m .41985 .33625 L .41407 .33901 L p F P
0 g
s
.692 .671 .824 r
.40602 .3365 m .41681 .33142 L p .41407 .33901 L F P
0 g
s
.779 .662 .735 r
.2265 .4157 m .22211 .4208 L .21895 .41469 L p F P
0 g
s
.779 .662 .735 r
.21895 .41469 m .21985 .41364 L .2265 .4157 L p F P
0 g
s
.776 .666 .742 r
.2265 .4157 m .21985 .41364 L .22616 .40663 L p F P
0 g
s
.72 .683 .813 r
.33367 .33639 m .3368 .3412 L .32789 .34663 L p F P
0 g
s
.72 .683 .813 r
.32292 .3429 m .33367 .33639 L p .32789 .34663 L F P
0 g
s
.72 .683 .813 r
.32789 .34663 m .32506 .34621 L .32292 .3429 L p F P
0 g
s
.787 .64 .699 r
.21711 .44931 m .21906 .44637 L .21548 .44531 L closepath p F P
0 g
s
.784 .647 .711 r
.21403 .44201 m .21697 .43788 L p .21906 .44637 L F P
0 g
s
.784 .647 .711 r
.21906 .44637 m .21548 .44531 L .21403 .44201 L p F P
0 g
s
.71 .356 .375 r
.31566 .54021 m .31649 .53843 L p .32686 .54349 L F P
0 g
s
.726 .387 .406 r
.31566 .54021 m .31443 .53816 L .31649 .53843 L closepath p F P
0 g
s
.578 .197 .284 r
.44814 .54609 m .45893 .54533 L .4571 .54882 L p F P
0 g
s
.578 .197 .284 r
.4571 .54882 m .45642 .54887 L .44814 .54609 L p F P
0 g
s
.65 .602 .787 r
.52851 .3653 m .53946 .36144 L p .5416 .36809 L F P
0 g
s
.65 .603 .788 r
.53776 .35775 m .53946 .36144 L .52851 .3653 L p F P
0 g
s
.65 .603 .788 r
.52851 .3653 m .52646 .36085 L .53776 .35775 L p F P
0 g
s
.768 .677 .762 r
.24163 .39261 m .24094 .39145 L .24019 .39217 L closepath p F P
0 g
s
.701 .676 .823 r
.38912 .33221 m .39219 .33696 L .3884 .3389 L p F P
0 g
s
.701 .676 .823 r
.37836 .33763 m .38912 .33221 L p .3884 .3389 L F P
0 g
s
.701 .676 .823 r
.3884 .3389 m .37895 .33856 L .37836 .33763 L p F P
0 g
s
.659 .257 .271 r
.35733 .54605 m .3601 .54831 L .35909 .54954 L p F P
0 g
s
.659 .257 .271 r
.34669 .54534 m .35733 .54605 L p .35909 .54954 L F P
0 g
s
.685 .331 .369 r
.35733 .54605 m .34669 .54534 L .3464 .54503 L p F P
0 g
s
.679 .651 .815 r
.45051 .34158 m .46134 .33682 L .46433 .34211 L p F P
0 g
s
.679 .653 .817 r
.46054 .33544 m .46134 .33682 L .45051 .34158 L p F P
0 g
s
.679 .653 .817 r
.45051 .34158 m .44784 .33694 L .46054 .33544 L p F P
0 g
s
.74 .684 .797 r
.29684 .35321 m .28747 .36001 L .2843 .355 L p F P
0 g
s
.791 .633 .686 r
.21898 .45394 m .21493 .45269 L p .2179 .46089 L F P
0 g
s
.79 .641 .697 r
.21898 .45394 m .21711 .44931 L .21493 .45269 L closepath p F P
0 g
s
.657 .614 .795 r
.51173 .35703 m .52265 .35295 L .52558 .35902 L p F P
0 g
s
.657 .616 .797 r
.52131 .35019 m .52265 .35295 L .51173 .35703 L p F P
0 g
s
.657 .616 .797 r
.51173 .35703 m .50977 .35302 L .52131 .35019 L p F P
0 g
s
.688 .667 .824 r
.42893 .3384 m .42141 .33879 L .41985 .33625 L p F P
0 g
s
.786 .59 .636 r
.22886 .4868 m .22971 .48457 L p .23477 .4921 L F P
0 g
s
.788 .592 .635 r
.22886 .4868 m .22971 .48457 L .22836 .48422 L closepath p F P
0 g
s
.775 .516 .543 r
.26782 .52171 m .26124 .52035 L .26127 .51524 L p F P
0 g
s
.776 .516 .543 r
.25349 .51363 m .26127 .51524 L .26124 .52035 L p F P
0 g
s
.793 .606 .648 r
.22836 .48422 m .22276 .48266 L .22525 .47684 L p F P
0 g
s
.794 .608 .65 r
.21843 .47489 m .22525 .47684 L .22276 .48266 L p F P
0 g
s
.791 .615 .663 r
.22133 .46894 m .21843 .47489 L .22525 .47684 L p F P
0 g
s
.595 .306 .449 r
.51065 .53548 m .50035 .53699 L .49858 .53602 L p F P
0 g
s
.596 .304 .444 r
.50035 .53699 m .49834 .53728 L .49858 .53602 L closepath p F P
0 g
s
.6 .407 .593 r
.55907 .50671 m .5589 .50461 L .56456 .4997 L p F P
0 g
s
.607 .413 .593 r
.55907 .50671 m .5589 .50461 L .55637 .50732 L closepath p F P
0 g
s
.777 .538 .573 r
.25349 .51363 m .25003 .5129 L .25007 .50748 L p F P
0 g
s
.785 .544 .572 r
.24656 .50666 m .25007 .50748 L .25003 .5129 L p F P
0 g
s
.725 .376 .387 r
.31443 .53816 m .31566 .54021 L .3146 .54213 L p F P
0 g
s
.725 .376 .387 r
.3054 .53696 m .31443 .53816 L p .3146 .54213 L F P
0 g
s
.787 .578 .618 r
.22964 .49083 m .23477 .4921 L .23306 .4977 L p F P
0 g
s
.786 .59 .636 r
.23477 .4921 m .22964 .49083 L .22886 .4868 L p F P
0 g
s
.786 .576 .617 r
.24039 .49947 m .23306 .4977 L .23477 .4921 L p F P
0 g
s
.67 .641 .812 r
.49085 .34436 m .48002 .3463 L .47816 .34288 L p F P
0 g
s
.632 .569 .765 r
.57604 .38875 m .57604 .38877 L .56513 .39231 L p F P
0 g
s
.632 .569 .765 r
.56513 .39231 m .56503 .39204 L .57604 .38875 L p F P
0 g
s
.705 .678 .82 r
.37895 .33856 m .37836 .33763 L .37687 .33843 L closepath p F P
0 g
s
.633 .57 .766 r
.57604 .38875 m .56503 .39204 L .56211 .38476 L p F P
0 g
s
.765 .677 .766 r
.24827 .38459 m .24094 .39145 L .23775 .38606 L p F P
0 g
s
.765 .677 .766 r
.23775 .38606 m .24151 .38254 L .24827 .38459 L p F P
0 g
s
.763 .679 .77 r
.24865 .37605 m .24151 .38254 L .24827 .38459 L p F P
0 g
s
.763 .679 .77 r
.24827 .38459 m .25184 .38135 L .24865 .37605 L p F P
0 g
s
.728 .682 .806 r
.31216 .34986 m .3194 .34514 L .32506 .34621 L p F P
0 g
s
.727 .684 .808 r
.3194 .34514 m .31216 .34986 L .30901 .34492 L p F P
0 g
s
.6 .407 .593 r
.56456 .4997 m .57005 .49835 L p .55907 .50671 L F P
0 g
s
.606 .427 .614 r
.57005 .49835 m .56981 .4963 L .56456 .4997 L closepath p F P
0 g
s
.758 .678 .773 r
.25702 .37679 m .25184 .38135 L .24865 .37605 L p F P
0 g
s
.727 .685 .81 r
.32506 .34621 m .32292 .3429 L .3194 .34514 L closepath p F P
0 g
s
.642 .59 .78 r
.55349 .36451 m .55627 .37089 L .5453 .37449 L p F P
0 g
s
.642 .59 .78 r
.5453 .37449 m .5424 .36787 L .55349 .36451 L p F P
0 g
s
.599 .389 .568 r
.55637 .50732 m .55907 .50671 L .55929 .51204 L p F P
0 g
s
.599 .389 .568 r
.55929 .51204 m .55389 .51325 L .55637 .50732 L p F P
0 g
s
.794 .618 .664 r
.2146 .46696 m .22133 .46894 L .21843 .47489 L p F P
0 g
s
.791 .624 .675 r
.2179 .46089 m .2146 .46696 L .22133 .46894 L p F P
0 g
s
.769 .679 .763 r
.24019 .39217 m .24094 .39145 L .23775 .38606 L p F P
0 g
s
.769 .675 .76 r
.23362 .39006 m .24019 .39217 L .23291 .39949 L p F P
0 g
s
.769 .679 .763 r
.23775 .38606 m .23362 .39006 L .24019 .39217 L p F P
0 g
s
.707 .683 .825 r
.37527 .3329 m .36616 .33767 L .37687 .33843 L p F P
0 g
s
.707 .683 .825 r
.37687 .33843 m .37836 .33763 L .37527 .3329 L p F P
0 g
s
.706 .678 .821 r
.36452 .33855 m .36616 .33767 L .37687 .33843 L p F P
0 g
s
.758 .678 .773 r
.24865 .37605 m .25007 .3748 L .25702 .37679 L p F P
0 g
s
.757 .681 .778 r
.25945 .36679 m .25007 .3748 L .25702 .37679 L p F P
0 g
s
.757 .681 .778 r
.25955 .36682 m .25945 .36679 L p .25702 .37679 L F P
0 g
s
.757 .681 .778 r
.25702 .37679 m .26269 .37195 L .25955 .36682 L p F P
0 g
s
.738 .684 .799 r
.29925 .35377 m .29825 .35221 L .29684 .35321 L closepath p F P
0 g
s
.686 .331 .366 r
.34669 .54534 m .34625 .54531 L .3464 .54503 L closepath p F P
0 g
s
.793 .595 .633 r
.22836 .48422 m .22276 .48266 L p .22759 .49028 L F P
0 g
s
.793 .595 .633 r
.22759 .49028 m .22886 .4868 L .22836 .48422 L p F P
0 g
s
.687 .664 .822 r
.43478 .33804 m .43368 .33621 L .42893 .3384 L closepath p F P
0 g
s
.688 .667 .824 r
.43066 .33133 m .43368 .33621 L .42893 .3384 L p F P
0 g
s
.688 .667 .824 r
.41985 .33625 m .43066 .33133 L p .42893 .3384 L F P
0 g
s
.782 .664 .733 r
.22063 .42256 m .22211 .4208 L .21895 .41469 L p F P
0 g
s
.604 .473 .676 r
.58851 .46776 m .58703 .46115 L .59799 .45773 L p F P
0 g
s
.607 .484 .686 r
.59669 .45235 m .59799 .45773 L .58703 .46115 L p F P
0 g
s
.791 .642 .697 r
.21493 .45269 m .21711 .44931 L .21548 .44531 L p F P
0 g
s
.786 .562 .596 r
.24656 .50666 m .23921 .50491 L .24039 .49947 L p F P
0 g
s
.786 .563 .597 r
.23306 .4977 m .24039 .49947 L .23921 .50491 L p F P
0 g
s
.663 .628 .804 r
.49495 .34959 m .50585 .34533 L .50879 .35108 L p F P
0 g
s
.663 .629 .805 r
.50391 .34158 m .50585 .34533 L .49495 .34959 L p F P
0 g
s
.663 .629 .805 r
.49495 .34959 m .49212 .34413 L .50391 .34158 L p F P
0 g
s
.752 .679 .781 r
.26269 .37195 m .26661 .36872 L .25955 .36682 L closepath p F P
0 g
s
.674 .646 .814 r
.46433 .34211 m .47519 .33753 L .47816 .34288 L p F P
0 g
s
.674 .649 .817 r
.47519 .33753 m .46433 .34211 L .46134 .33682 L p F P
0 g
s
.784 .66 .727 r
.21417 .42044 m .22063 .42256 L .21534 .42924 L p F P
0 g
s
.782 .664 .733 r
.21895 .41469 m .21417 .42044 L .22063 .42256 L p F P
0 g
s
.659 .258 .274 r
.34625 .54531 m .34669 .54534 L .35173 .54901 L p F P
0 g
s
.659 .257 .271 r
.35909 .54954 m .35173 .54901 L .34669 .54534 L p F P
0 g
s
.7 .684 .832 r
.38912 .33221 m .37836 .33763 L .37527 .3329 L p F P
0 g
s
.786 .648 .71 r
.21403 .44201 m .21697 .43788 L .21145 .43618 L closepath p F P
0 g
s
.783 .654 .72 r
.21092 .43506 m .21534 .42924 L p .21697 .43788 L F P
0 g
s
.783 .654 .72 r
.21697 .43788 m .21145 .43618 L .21092 .43506 L p F P
0 g
s
.567 .186 .278 r
.4571 .54882 m .45893 .54533 L .46565 .54476 L p F P
0 g
s
.59 .361 .538 r
.54767 .51462 m .55389 .51325 L .55588 .51788 L p F P
0 g
s
.59 .361 .538 r
.55588 .51788 m .54762 .5197 L .54767 .51462 L p F P
0 g
s
.599 .368 .539 r
.54767 .51462 m .54762 .5197 L .53583 .52208 L p F P
0 g
s
.793 .628 .677 r
.21125 .45887 m .2179 .46089 L .2146 .46696 L p F P
0 g
s
.791 .633 .686 r
.21493 .45269 m .21125 .45887 L .2179 .46089 L p F P
0 g
s
.769 .675 .76 r
.2268 .39685 m .23362 .39006 L p .23291 .39949 L F P
0 g
s
.769 .675 .76 r
.23291 .39949 m .22733 .39776 L .2268 .39685 L p F P
0 g
s
.772 .671 .751 r
.22998 .40253 m .23291 .39949 L .22733 .39776 L closepath p F P
0 g
s
.659 .258 .274 r
.35173 .54901 m .34381 .54846 L .34625 .54531 L p F P
0 g
s
.675 .277 .284 r
.33669 .54444 m .34625 .54531 L .34381 .54846 L p F P
0 g
s
.695 .682 .833 r
.40297 .33172 m .39219 .33696 L .38912 .33221 L p F P
0 g
s
.684 .663 .824 r
.44583 .33713 m .43478 .33804 L .43368 .33621 L p F P
0 g
s
.706 .679 .821 r
.36452 .33855 m .36616 .33767 L .36385 .33751 L closepath p F P
0 g
s
.711 .682 .82 r
.36385 .33751 m .36452 .33855 L p .35066 .33975 L F P
0 g
s
.749 .684 .788 r
.27065 .35861 m .27351 .36319 L .26661 .36872 L p F P
0 g
s
.749 .684 .788 r
.26994 .35841 m .27065 .35861 L p .26661 .36872 L F P
0 g
s
.749 .684 .788 r
.2595 .36674 m .26994 .35841 L p .26661 .36872 L F P
0 g
s
.749 .684 .788 r
.26661 .36872 m .25955 .36682 L .2595 .36674 L p F P
0 g
s
.792 .594 .633 r
.22964 .49083 m .22886 .4868 L .22759 .49028 L closepath p F P
0 g
s
.691 .678 .833 r
.41681 .33142 m .40602 .3365 L .40297 .33172 L p F P
0 g
s
.776 .672 .749 r
.22616 .40663 m .22998 .40253 L .22733 .39776 L p F P
0 g
s
.74 .684 .797 r
.2843 .355 m .2893 .3514 L .29684 .35321 L p F P
0 g
s
.739 .687 .801 r
.29508 .34733 m .2893 .3514 L .29684 .35321 L p F P
0 g
s
.739 .687 .801 r
.29684 .35321 m .29825 .35221 L .29508 .34733 L p F P
0 g
s
.585 .332 .5 r
.53547 .52687 m .53583 .52208 L .54762 .5197 L p F P
0 g
s
.595 .341 .502 r
.53583 .52208 m .53547 .52687 L .52353 .52907 L p F P
0 g
s
.791 .642 .697 r
.21548 .44531 m .21242 .44433 L p .21493 .45269 L F P
0 g
s
.79 .649 .707 r
.21548 .44531 m .21403 .44201 L .21242 .44433 L closepath p F P
0 g
s
.747 .435 .455 r
.29652 .53571 m .28794 .53437 L .28626 .52974 L p F P
0 g
s
.747 .435 .456 r
.28446 .52946 m .28626 .52974 L .28794 .53437 L p F P
0 g
s
.59 .382 .567 r
.55929 .51204 m .55907 .50671 L .57051 .50392 L p F P
0 g
s
.6 .407 .593 r
.57005 .49835 m .57051 .50392 L .55907 .50671 L p F P
0 g
s
.651 .609 .794 r
.53653 .35518 m .53776 .35775 L .52646 .36085 L p F P
0 g
s
.651 .609 .794 r
.52646 .36085 m .52558 .35902 L .53653 .35518 L p F P
0 g
s
.598 .422 .614 r
.57005 .49835 m .56981 .4963 L .58079 .49069 L p F P
0 g
s
.598 .422 .614 r
.58066 .48957 m .58079 .49069 L .56981 .4963 L p F P
0 g
s
.711 .682 .82 r
.35066 .33975 m .35617 .33668 L .36385 .33751 L p F P
0 g
s
.711 .68 .819 r
.35066 .33975 m .35617 .33668 L .34816 .33587 L closepath p F P
0 g
s
.717 .684 .817 r
.34816 .33587 m .35066 .33975 L p .3368 .3412 L F P
0 g
s
.785 .544 .572 r
.25003 .5129 m .24593 .51194 L .24656 .50666 L p F P
0 g
s
.787 .546 .572 r
.23921 .50491 m .24656 .50666 L .24593 .51194 L p F P
0 g
s
.597 .435 .633 r
.58066 .48957 m .57975 .48356 L .59088 .48037 L p F P
0 g
s
.602 .45 .648 r
.58978 .47416 m .59088 .48037 L .57975 .48356 L p F P
0 g
s
.734 .688 .807 r
.30901 .34492 m .29825 .35221 L .29508 .34733 L p F P
0 g
s
.763 .48 .506 r
.278 .5283 m .26981 .52683 L .26907 .52193 L p F P
0 g
s
.764 .481 .505 r
.26782 .52171 m .26907 .52193 L .26981 .52683 L p F P
0 g
s
.572 .245 .376 r
.49834 .53728 m .50035 .53699 L .50933 .53959 L p F P
0 g
s
.572 .245 .376 r
.50933 .53959 m .49714 .5413 L .49834 .53728 L p F P
0 g
s
.704 .683 .827 r
.37218 .32827 m .37527 .3329 L .36616 .33767 L p F P
0 g
s
.704 .683 .827 r
.36142 .33381 m .37218 .32827 L p .36616 .33767 L F P
0 g
s
.704 .683 .827 r
.36616 .33767 m .36385 .33751 L .36142 .33381 L p F P
0 g
s
.658 .622 .802 r
.51972 .34703 m .52131 .35019 L .50977 .35302 L p F P
0 g
s
.658 .622 .802 r
.50977 .35302 m .50879 .35108 L .51972 .34703 L p F P
0 g
s
.687 .675 .833 r
.43066 .33133 m .41985 .33625 L .41681 .33142 L p F P
0 g
s
.746 .681 .789 r
.27351 .36319 m .27727 .36029 L .27065 .35861 L closepath p F P
0 g
s
.777 .67 .746 r
.21965 .40451 m .22616 .40663 L .21985 .41364 L p F P
0 g
s
.776 .672 .749 r
.22626 .39741 m .21965 .40451 L .22616 .40663 L p F P
0 g
s
.776 .672 .749 r
.22733 .39776 m .22626 .39741 L p .22616 .40663 L F P
0 g
s
.793 .637 .688 r
.20838 .45062 m .21493 .45269 L .21125 .45887 L p F P
0 g
s
.791 .642 .697 r
.21242 .44433 m .20838 .45062 L .21493 .45269 L p F P
0 g
s
.747 .435 .456 r
.28794 .53437 m .283 .5336 L .28446 .52946 L p F P
0 g
s
.758 .447 .459 r
.278 .5283 m .28446 .52946 L .283 .5336 L p F P
0 g
s
.633 .57 .766 r
.56211 .38476 m .57312 .38146 L .57604 .38875 L p F P
0 g
s
.633 .571 .767 r
.57246 .37982 m .57312 .38146 L .56211 .38476 L p F P
0 g
s
.633 .571 .767 r
.56211 .38476 m .56156 .38339 L .57246 .37982 L p F P
0 g
s
.71 .685 .824 r
.36385 .33751 m .36142 .33381 L .35617 .33668 L closepath p F P
0 g
s
.589 .309 .46 r
.52333 .53046 m .52133 .52943 L .52353 .52907 L closepath p F P
0 g
s
.588 .303 .451 r
.52133 .52943 m .52333 .53046 L p .51065 .53548 L F P
0 g
s
.572 .201 .299 r
.47086 .54635 m .46565 .54476 L .47187 .5442 L closepath p F P
0 g
s
.567 .186 .278 r
.46565 .54476 m .47086 .54635 L p .4571 .54882 L F P
0 g
s
.727 .684 .808 r
.30901 .34492 m .31108 .34359 L .3194 .34514 L p F P
0 g
s
.728 .688 .812 r
.31977 .33812 m .31108 .34359 L .3194 .34514 L p F P
0 g
s
.728 .688 .812 r
.3194 .34514 m .32292 .3429 L .31977 .33812 L p F P
0 g
s
.764 .481 .505 r
.26981 .52683 m .26685 .52629 L .26782 .52171 L p F P
0 g
s
.774 .491 .507 r
.26124 .52035 m .26782 .52171 L .26685 .52629 L p F P
0 g
s
.717 .684 .817 r
.3368 .3412 m .34636 .33562 L .34816 .33587 L p F P
0 g
s
.716 .688 .822 r
.34636 .33562 m .3368 .3412 L .33367 .33639 L p F P
0 g
s
.65 .602 .787 r
.53946 .36144 m .54238 .36781 L .5416 .36809 L p F P
0 g
s
.649 .599 .785 r
.5424 .36787 m .54238 .36781 L .5416 .36809 L closepath p F P
0 g
s
.572 .25 .386 r
.50035 .53699 m .51065 .53548 L .50952 .53956 L p F P
0 g
s
.572 .25 .386 r
.50952 .53956 m .50933 .53959 L .50035 .53699 L p F P
0 g
s
.67 .641 .812 r
.47816 .34288 m .48904 .33849 L p .49085 .34436 L F P
0 g
s
.67 .645 .816 r
.48904 .33849 m .47816 .34288 L .47519 .33753 L p F P
0 g
s
.725 .376 .387 r
.3146 .54213 m .30823 .54126 L .3054 .53696 L p F P
0 g
s
.719 .359 .367 r
.30003 .53626 m .3054 .53696 L .30823 .54126 L p F P
0 g
s
.652 .612 .796 r
.53653 .35518 m .52558 .35902 L .52265 .35295 L p F P
0 g
s
.635 .578 .774 r
.57021 .37441 m .57246 .37982 L .56156 .38339 L p F P
0 g
s
.635 .578 .774 r
.56156 .38339 m .55919 .37773 L .57021 .37441 L p F P
0 g
s
.79 .65 .707 r
.21242 .44433 m .21403 .44201 L .21145 .43618 L p F P
0 g
s
.787 .578 .618 r
.23306 .4977 m .23049 .49706 L .22964 .49083 L p F P
0 g
s
.794 .583 .616 r
.22759 .49028 m .22964 .49083 L .23049 .49706 L p F P
0 g
s
.743 .686 .796 r
.28113 .35002 m .2843 .355 L .27727 .36029 L p F P
0 g
s
.743 .686 .796 r
.27033 .35811 m .28113 .35002 L p .27727 .36029 L F P
0 g
s
.743 .686 .796 r
.27727 .36029 m .27065 .35861 L .27033 .35811 L p F P
0 g
s
.599 .459 .662 r
.58867 .46856 m .58851 .46776 L .59948 .46435 L p F P
0 g
s
.604 .473 .676 r
.59799 .45773 m .59948 .46435 L .58851 .46776 L p F P
0 g
s
.614 .522 .727 r
.59025 .42931 m .58785 .42169 L .59106 .42058 L p F P
0 g
s
.617 .532 .735 r
.58785 .42169 m .58776 .42142 L .59106 .42058 L closepath p F P
0 g
s
.617 .532 .736 r
.59106 .42058 m .58776 .42142 L .58522 .41383 L p F P
0 g
s
.684 .663 .824 r
.43368 .33621 m .4445 .33144 L p .44583 .33713 L F P
0 g
s
.683 .671 .832 r
.4445 .33144 m .43368 .33621 L .43066 .33133 L p F P
0 g
s
.614 .522 .727 r
.59883 .41865 m .60103 .42561 L .59025 .42931 L p F P
0 g
s
.614 .522 .727 r
.59106 .42058 m .59883 .41865 L p .59025 .42931 L F P
0 g
s
.611 .513 .718 r
.59071 .43085 m .59025 .42931 L .60103 .42561 L p F P
0 g
s
.644 .597 .787 r
.55336 .36421 m .55349 .36451 L .5424 .36787 L p F P
0 g
s
.644 .597 .787 r
.5424 .36787 m .54238 .36781 L .55336 .36421 L p F P
0 g
s
.644 .599 .789 r
.55336 .36421 m .54238 .36781 L .53946 .36144 L p F P
0 g
s
.683 .66 .821 r
.44784 .33694 m .44751 .33638 L .44583 .33713 L closepath p F P
0 g
s
.684 .663 .824 r
.4445 .33144 m .44751 .33638 L .44583 .33713 L p F P
0 g
s
.675 .277 .284 r
.34381 .54846 m .34131 .54823 L .33669 .54444 L p F P
0 g
s
.662 .244 .241 r
.33064 .54391 m .33669 .54444 L .34131 .54823 L p F P
0 g
s
.611 .512 .718 r
.59246 .43671 m .59071 .43085 L .60179 .42816 L p F P
0 g
s
.611 .513 .718 r
.60103 .42561 m .60179 .42816 L .59071 .43085 L p F P
0 g
s
.575 .292 .45 r
.52353 .52907 m .53547 .52687 L .53479 .53134 L p F P
0 g
s
.575 .292 .45 r
.52333 .53046 m .52353 .52907 L p .53479 .53134 L F P
0 g
s
.59 .4 .592 r
.57051 .50392 m .57005 .49835 L .58134 .49536 L p F P
0 g
s
.598 .422 .614 r
.58079 .49069 m .58134 .49536 L .57005 .49835 L p F P
0 g
s
.784 .66 .727 r
.21534 .42924 m .20881 .42714 L .21417 .42044 L p F P
0 g
s
.786 .656 .718 r
.21534 .42924 m .21092 .43506 L .20778 .42851 L p F P
0 g
s
.786 .656 .718 r
.20778 .42851 m .20881 .42714 L .21534 .42924 L p F P
0 g
s
.599 .458 .662 r
.58978 .47416 m .58867 .46856 L .59974 .46565 L p F P
0 g
s
.599 .459 .662 r
.59948 .46435 m .59974 .46565 L .58867 .46856 L p F P
0 g
s
.659 .626 .805 r
.51972 .34703 m .50879 .35108 L .50585 .34533 L p F P
0 g
s
.617 .532 .736 r
.58522 .41383 m .59599 .4101 L p .59106 .42058 L F P
0 g
s
.62 .541 .743 r
.59588 .40979 m .59599 .4101 L .58522 .41383 L p F P
0 g
s
.62 .541 .743 r
.58522 .41383 m .58482 .41266 L .59588 .40979 L p F P
0 g
s
.776 .517 .543 r
.25003 .5129 m .25349 .51363 L .25346 .51874 L p F P
0 g
s
.776 .516 .543 r
.26124 .52035 m .25346 .51874 L .25349 .51363 L p F P
0 g
s
.62 .541 .744 r
.59315 .40199 m .59588 .40979 L .58482 .41266 L p F P
0 g
s
.62 .541 .744 r
.58482 .41266 m .58239 .40573 L .59315 .40199 L p F P
0 g
s
.678 .658 .823 r
.45835 .33176 m .46054 .33544 L .44784 .33694 L p F P
0 g
s
.678 .658 .823 r
.44784 .33694 m .44751 .33638 L .45835 .33176 L p F P
0 g
s
.71 .356 .375 r
.32686 .54349 m .31735 .54243 L .31566 .54021 L p F P
0 g
s
.71 .356 .374 r
.31735 .54243 m .3146 .54213 L .31566 .54021 L closepath p F P
0 g
s
.722 .69 .819 r
.33367 .33639 m .32292 .3429 L .31977 .33812 L p F P
0 g
s
.608 .503 .709 r
.59369 .44105 m .59246 .43671 L .60325 .43304 L p F P
0 g
s
.611 .512 .718 r
.60179 .42816 m .60325 .43304 L .59246 .43671 L p F P
0 g
s
.541 .15 .25 r
.47187 .5442 m .48462 .54288 L .48283 .54636 L p F P
0 g
s
.541 .15 .25 r
.47086 .54635 m .47187 .5442 L p .48283 .54636 L F P
0 g
s
.596 .267 .384 r
.48473 .54258 m .48462 .54288 L .47187 .5442 L p F P
0 g
s
.78 .665 .736 r
.21895 .41469 m .21985 .41364 L .21811 .41308 L closepath p F P
0 g
s
.777 .67 .746 r
.21576 .40883 m .21965 .40451 L p .21985 .41364 L F P
0 g
s
.777 .67 .746 r
.21985 .41364 m .21811 .41308 L .21576 .40883 L p F P
0 g
s
.793 .645 .699 r
.20597 .44222 m .21242 .44433 L .20838 .45062 L p F P
0 g
s
.79 .65 .707 r
.21036 .43582 m .20597 .44222 L .21242 .44433 L p F P
0 g
s
.79 .65 .707 r
.21145 .43618 m .21036 .43582 L p .21242 .44433 L F P
0 g
s
.793 .595 .633 r
.22276 .48266 m .22068 .48837 L .22759 .49028 L p F P
0 g
s
.795 .598 .635 r
.21591 .48072 m .22276 .48266 L .22068 .48837 L p F P
0 g
s
.794 .608 .65 r
.22276 .48266 m .21591 .48072 L .21843 .47489 L p F P
0 g
s
.784 .666 .733 r
.21417 .42044 m .21895 .41469 L .21811 .41308 L p F P
0 g
s
.679 .666 .831 r
.45835 .33176 m .44751 .33638 L .4445 .33144 L p F P
0 g
s
.668 .637 .809 r
.49212 .34413 m .492 .3439 L .49085 .34436 L closepath p F P
0 g
s
.67 .641 .812 r
.48904 .33849 m .492 .3439 L .49085 .34436 L p F P
0 g
s
.709 .684 .824 r
.3583 .32919 m .36142 .33381 L .35617 .33668 L p F P
0 g
s
.709 .684 .824 r
.34755 .33494 m .3583 .32919 L p .35617 .33668 L F P
0 g
s
.709 .684 .824 r
.35617 .33668 m .34816 .33587 L .34755 .33494 L p F P
0 g
s
.794 .583 .616 r
.23049 .49706 m .22597 .49585 L .22759 .49028 L p F P
0 g
s
.796 .585 .617 r
.22068 .48837 m .22759 .49028 L .22597 .49585 L p F P
0 g
s
.795 .61 .651 r
.21165 .47292 m .21843 .47489 L .21591 .48072 L p F P
0 g
s
.794 .618 .664 r
.21843 .47489 m .21165 .47292 L .2146 .46696 L p F P
0 g
s
.622 .549 .751 r
.59295 .40143 m .59315 .40199 L .58239 .40573 L p F P
0 g
s
.622 .549 .751 r
.58239 .40573 m .58189 .40434 L .59295 .40143 L p F P
0 g
s
.588 .36 .538 r
.55389 .51325 m .55929 .51204 L .55926 .51713 L p F P
0 g
s
.588 .36 .538 r
.55926 .51713 m .55588 .51788 L .55389 .51325 L p F P
0 g
s
.739 .685 .799 r
.2893 .3514 m .2843 .355 L .28113 .35002 L p F P
0 g
s
.608 .503 .708 r
.59449 .44392 m .59369 .44105 L .60477 .43842 L p F P
0 g
s
.608 .503 .709 r
.60325 .43304 m .60477 .43842 L .59369 .44105 L p F P
0 g
s
.719 .359 .367 r
.29851 .53917 m .30003 .53626 L p .30823 .54126 L F P
0 g
s
.736 .393 .399 r
.29851 .53917 m .29652 .53571 L .30003 .53626 L closepath p F P
0 g
s
.662 .244 .241 r
.32925 .54578 m .33064 .54391 L p .34131 .54823 L F P
0 g
s
.692 .304 .308 r
.32925 .54578 m .32686 .54349 L .33064 .54391 L closepath p F P
0 g
s
.622 .55 .752 r
.59009 .39362 m .59295 .40143 L .58189 .40434 L p F P
0 g
s
.622 .55 .752 r
.58189 .40434 m .57934 .39738 L .59009 .39362 L p F P
0 g
s
.765 .678 .767 r
.24151 .38254 m .23775 .38606 L .23455 .38069 L p F P
0 g
s
.765 .678 .767 r
.23455 .38069 m .23479 .38047 L .24151 .38254 L p F P
0 g
s
.764 .682 .771 r
.24337 .37272 m .23479 .38047 L .24151 .38254 L p F P
0 g
s
.764 .682 .771 r
.24742 .37402 m .24337 .37272 L p .24151 .38254 L F P
0 g
s
.764 .682 .771 r
.24151 .38254 m .24865 .37605 L .24742 .37402 L p F P
0 g
s
.664 .635 .811 r
.5029 .3397 m .50391 .34158 L .49212 .34413 L p F P
0 g
s
.664 .635 .811 r
.49212 .34413 m .492 .3439 L .5029 .3397 L p F P
0 g
s
.759 .68 .774 r
.24865 .37605 m .25007 .3748 L .24742 .37402 L closepath p F P
0 g
s
.77 .68 .764 r
.23362 .39006 m .23775 .38606 L .23455 .38069 L p F P
0 g
s
.756 .684 .782 r
.25273 .3647 m .25945 .36679 L .25007 .3748 L p F P
0 g
s
.756 .684 .782 r
.24544 .37089 m .25273 .3647 L p .25007 .3748 L F P
0 g
s
.756 .684 .782 r
.25007 .3748 m .24742 .37402 L .24544 .37089 L p F P
0 g
s
.786 .563 .597 r
.23921 .50491 m .23185 .50315 L .23306 .4977 L p F P
0 g
s
.788 .565 .598 r
.23049 .49706 m .23306 .4977 L .23185 .50315 L p F P
0 g
s
.605 .492 .699 r
.59634 .45093 m .59449 .44392 L .60529 .44026 L p F P
0 g
s
.608 .503 .708 r
.60477 .43842 m .60529 .44026 L .59449 .44392 L p F P
0 g
s
.794 .621 .667 r
.2079 .46495 m .2146 .46696 L .21165 .47292 L p F P
0 g
s
.793 .628 .677 r
.2146 .46696 m .2079 .46495 L .21125 .45887 L p F P
0 g
s
.665 .641 .816 r
.5029 .3397 m .492 .3439 L .48904 .33849 L p F P
0 g
s
.635 .579 .775 r
.56859 .37054 m .57021 .37441 L .55919 .37773 L p F P
0 g
s
.635 .579 .775 r
.55919 .37773 m .55768 .37413 L .56859 .37054 L p F P
0 g
s
.638 .225 .243 r
.37351 .55028 m .36241 .54971 L .3601 .54831 L p F P
0 g
s
.638 .225 .244 r
.36241 .54971 m .35909 .54954 L .3601 .54831 L closepath p F P
0 g
s
.789 .657 .717 r
.21145 .43618 m .21092 .43506 L .21036 .43582 L closepath p F P
0 g
s
.775 .677 .756 r
.22733 .39776 m .2268 .39685 L .22626 .39741 L closepath p F P
0 g
s
.772 .678 .759 r
.23362 .39006 m .2268 .39685 L .22359 .39142 L p F P
0 g
s
.772 .678 .759 r
.22359 .39142 m .22709 .38793 L .23362 .39006 L p F P
0 g
s
.77 .68 .764 r
.23455 .38069 m .22709 .38793 L .23362 .39006 L p F P
0 g
s
.784 .666 .733 r
.21811 .41308 m .21344 .41148 L p .21417 .42044 L F P
0 g
s
.783 .672 .742 r
.21811 .41308 m .21576 .40883 L .21344 .41148 L closepath p F P
0 g
s
.758 .447 .459 r
.283 .5336 m .27952 .53297 L .278 .5283 L p F P
0 g
s
.758 .445 .454 r
.26981 .52683 m .278 .5283 L .27952 .53297 L p F P
0 g
s
.727 .684 .808 r
.30901 .34492 m .31108 .34359 L .30774 .34296 L closepath p F P
0 g
s
.734 .688 .807 r
.30774 .34296 m .30901 .34492 L p .29508 .34733 L F P
0 g
s
.776 .517 .543 r
.25346 .51874 m .24952 .51791 L .25003 .5129 L p F P
0 g
s
.785 .525 .543 r
.24593 .51194 m .25003 .5129 L .24952 .51791 L p F P
0 g
s
.756 .686 .784 r
.25955 .36682 m .2595 .36674 L .25945 .36679 L closepath p F P
0 g
s
.79 .658 .717 r
.21036 .43582 m .21092 .43506 L .20778 .42851 L p F P
0 g
s
.614 .523 .727 r
.59883 .41865 m .59106 .42058 L .59861 .41797 L closepath p F P
0 g
s
.617 .532 .736 r
.59599 .4101 m .59861 .41797 L .59106 .42058 L p F P
0 g
s
.685 .279 .271 r
.32686 .54349 m .32925 .54578 L .32811 .54701 L p F P
0 g
s
.685 .279 .271 r
.31735 .54243 m .32686 .54349 L p .32811 .54701 L F P
0 g
s
.757 .688 .785 r
.2563 .36176 m .25273 .3647 L .25945 .36679 L p F P
0 g
s
.757 .688 .785 r
.25945 .36679 m .2595 .36674 L .2563 .36176 L p F P
0 g
s
.753 .688 .79 r
.26994 .35841 m .2595 .36674 L .2563 .36176 L p F P
0 g
s
.674 .649 .817 r
.47297 .33362 m .47519 .33753 L p .46134 .33682 L F P
0 g
s
.674 .649 .817 r
.46134 .33682 m .46669 .33457 L .47297 .33362 L p F P
0 g
s
.676 .655 .822 r
.46134 .33682 m .46669 .33457 L .46054 .33544 L closepath p F P
0 g
s
.739 .685 .799 r
.28113 .35002 m .28172 .34959 L .2893 .3514 L p F P
0 g
s
.739 .689 .803 r
.29191 .34249 m .28172 .34959 L .2893 .3514 L p F P
0 g
s
.739 .689 .803 r
.2893 .3514 m .29508 .34733 L .29191 .34249 L p F P
0 g
s
.588 .303 .451 r
.52333 .53046 m .52281 .53351 L .51065 .53548 L p F P
0 g
s
.576 .289 .444 r
.52901 .5324 m .52281 .53351 L .52333 .53046 L closepath p F P
0 g
s
.575 .292 .45 r
.53479 .53134 m .52901 .5324 L .52333 .53046 L p F P
0 g
s
.776 .679 .757 r
.22626 .39741 m .2268 .39685 L .22359 .39142 L p F P
0 g
s
.737 .385 .384 r
.29652 .53571 m .29851 .53917 L .29806 .53991 L p F P
0 g
s
.737 .385 .384 r
.28794 .53437 m .29652 .53571 L p .29806 .53991 L F P
0 g
s
.774 .491 .507 r
.26685 .52629 m .26189 .52526 L .26124 .52035 L p F P
0 g
s
.774 .49 .505 r
.25346 .51874 m .26124 .52035 L .26189 .52526 L p F P
0 g
s
.792 .653 .709 r
.20401 .43367 m .21036 .43582 L .20597 .44222 L p F P
0 g
s
.79 .658 .717 r
.20778 .42851 m .20401 .43367 L .21036 .43582 L p F P
0 g
s
.777 .675 .751 r
.2199 .39522 m .22626 .39741 L .21965 .40451 L p F P
0 g
s
.776 .679 .757 r
.22359 .39142 m .2199 .39522 L .22626 .39741 L p F P
0 g
s
.794 .631 .68 r
.20465 .45682 m .21125 .45887 L .2079 .46495 L p F P
0 g
s
.793 .637 .688 r
.21125 .45887 m .20465 .45682 L .20838 .45062 L p F P
0 g
s
.785 .664 .73 r
.20777 .41829 m .21417 .42044 L .20881 .42714 L p F P
0 g
s
.784 .666 .733 r
.21344 .41148 m .20777 .41829 L .21417 .42044 L p F P
0 g
s
.625 .558 .759 r
.59002 .39343 m .59009 .39362 L .57934 .39738 L p F P
0 g
s
.625 .558 .759 r
.57934 .39738 m .57896 .39639 L .59002 .39343 L p F P
0 g
s
.59 .415 .613 r
.58079 .49069 m .58066 .48957 L .5918 .48639 L p F P
0 g
s
.597 .435 .633 r
.59088 .48037 m .5918 .48639 L .58066 .48957 L p F P
0 g
s
.725 .688 .814 r
.31661 .3334 m .31977 .33812 L .31108 .34359 L p F P
0 g
s
.725 .688 .814 r
.30585 .34012 m .31661 .3334 L p .31108 .34359 L F P
0 g
s
.725 .688 .814 r
.31108 .34359 m .30774 .34296 L .30585 .34012 L p F P
0 g
s
.787 .546 .572 r
.24593 .51194 m .23856 .5102 L .23921 .50491 L p F P
0 g
s
.787 .546 .573 r
.23185 .50315 m .23921 .50491 L .23856 .5102 L p F P
0 g
s
.715 .686 .821 r
.34816 .33587 m .34755 .33494 L .34636 .33562 L closepath p F P
0 g
s
.599 .458 .662 r
.59974 .46565 m .60076 .47075 L .58978 .47416 L p F P
0 g
s
.594 .445 .648 r
.59088 .48037 m .58978 .47416 L .60076 .47075 L p F P
0 g
s
.625 .558 .759 r
.5871 .3858 m .59002 .39343 L .57896 .39639 L p F P
0 g
s
.625 .558 .759 r
.57621 .38871 m .5871 .3858 L p .57896 .39639 L F P
0 g
s
.625 .558 .759 r
.57896 .39639 m .57604 .38877 L .57621 .38871 L p F P
0 g
s
.637 .586 .781 r
.56729 .36755 m .56859 .37054 L .55768 .37413 L p F P
0 g
s
.637 .586 .781 r
.55768 .37413 m .55627 .37089 L .56729 .36755 L p F P
0 g
s
.576 .242 .367 r
.49714 .5413 m .48539 .54279 L .48473 .54258 L p F P
0 g
s
.576 .237 .357 r
.48539 .54279 m .48462 .54288 L .48473 .54258 L closepath p F P
0 g
s
.562 .241 .382 r
.50952 .53956 m .51065 .53548 L .52281 .53351 L p F P
0 g
s
.504 .012 .02 r
.40279 .55085 m .41087 .55078 L p .41387 .55332 L F P
0 g
s
.504 .012 .02 r
.4015 .55217 m .40279 .55085 L p .41387 .55332 L F P
0 g
s
.574 .126 .149 r
.4015 .55217 m .39776 .55081 L .40279 .55085 L closepath p F P
0 g
s
.788 .565 .598 r
.23185 .50315 m .23092 .50292 L .23049 .49706 L p F P
0 g
s
.796 .571 .596 r
.22597 .49585 m .23049 .49706 L .23092 .50292 L p F P
0 g
s
.6 .48 .687 r
.59669 .45235 m .59634 .45093 L .60714 .44728 L p F P
0 g
s
.605 .492 .699 r
.60529 .44026 m .60714 .44728 L .59634 .45093 L p F P
0 g
s
.527 .037 .037 r
.39776 .55081 m .4015 .55217 L .39982 .5534 L p F P
0 g
s
.527 .037 .037 r
.38855 .55072 m .39776 .55081 L p .39982 .5534 L F P
0 g
s
.7 .684 .832 r
.37527 .3329 m .38604 .32755 L .38912 .33221 L p F P
0 g
s
.699 .689 .837 r
.38604 .32755 m .37527 .3329 L .37218 .32827 L p F P
0 g
s
.558 .11 .142 r
.41536 .55218 m .41087 .55078 L .41674 .55071 L closepath p F P
0 g
s
.504 .012 .02 r
.41087 .55078 m .41536 .55218 L .41387 .55332 L p F P
0 g
s
.652 .612 .796 r
.52265 .35295 m .5336 .34909 L .53653 .35518 L p F P
0 g
s
.652 .614 .799 r
.53263 .3471 m .5336 .34909 L .52265 .35295 L p F P
0 g
s
.652 .614 .799 r
.52265 .35295 m .52131 .35019 L .53263 .3471 L p F P
0 g
s
.716 .688 .822 r
.33367 .33639 m .33732 .3343 L .34636 .33562 L p F P
0 g
s
.717 .692 .825 r
.34442 .33033 m .33732 .3343 L .34636 .33562 L p F P
0 g
s
.717 .692 .825 r
.34636 .33562 m .34755 .33494 L .34442 .33033 L p F P
0 g
s
.695 .682 .833 r
.38912 .33221 m .39991 .32704 L .40297 .33172 L p F P
0 g
s
.695 .688 .839 r
.39991 .32704 m .38912 .33221 L .38604 .32755 L p F P
0 g
s
.763 .686 .778 r
.24742 .37402 m .24544 .37089 L .24337 .37272 L closepath p F P
0 g
s
.644 .599 .789 r
.53946 .36144 m .55044 .35782 L .55336 .36421 L p F P
0 g
s
.645 .601 .79 r
.54886 .35439 m .55044 .35782 L .53946 .36144 L p F P
0 g
s
.645 .601 .79 r
.53946 .36144 m .53776 .35775 L .54886 .35439 L p F P
0 g
s
.703 .691 .835 r
.37218 .32827 m .36142 .33381 L .3583 .32919 L p F P
0 g
s
.75 .688 .791 r
.27065 .35861 m .27033 .35811 L .26994 .35841 L closepath p F P
0 g
s
.527 .037 .037 r
.38767 .55161 m .38855 .55072 L p .39982 .5534 L F P
0 g
s
.593 .148 .163 r
.38767 .55161 m .38536 .55063 L .38855 .55072 L closepath p F P
0 g
s
.488 0 .016 r
.41674 .55071 m .42487 .55049 L p .42764 .55297 L F P
0 g
s
.488 0 .016 r
.41536 .55218 m .41674 .55071 L p .42764 .55297 L F P
0 g
s
.589 .415 .613 r
.58134 .49536 m .58079 .49069 L .59182 .4866 L p F P
0 g
s
.59 .415 .613 r
.5918 .48639 m .59182 .4866 L .58079 .49069 L p F P
0 g
s
.6 .48 .687 r
.59799 .45773 m .59669 .45235 L .60779 .44992 L p F P
0 g
s
.6 .48 .687 r
.60714 .44728 m .60779 .44992 L .59669 .45235 L p F P
0 g
s
.691 .678 .833 r
.40297 .33172 m .41377 .32671 L .41681 .33142 L p F P
0 g
s
.69 .685 .84 r
.41377 .32671 m .40297 .33172 L .39991 .32704 L p F P
0 g
s
.554 .072 .065 r
.38536 .55063 m .38767 .55161 L .38549 .55321 L p F P
0 g
s
.554 .072 .065 r
.37401 .55031 m .38536 .55063 L p .38549 .55321 L F P
0 g
s
.676 .66 .827 r
.46669 .33457 m .46054 .33544 L .45835 .33176 L p F P
0 g
s
.537 .153 .261 r
.48283 .54636 m .48462 .54288 L .48539 .54279 L p F P
0 g
s
.708 .693 .833 r
.3583 .32919 m .34755 .33494 L .34442 .33033 L p F P
0 g
s
.753 .688 .79 r
.2563 .36176 m .26307 .35637 L .26994 .35841 L p F P
0 g
s
.751 .69 .793 r
.26713 .35322 m .26307 .35637 L .26994 .35841 L p F P
0 g
s
.751 .69 .793 r
.26994 .35841 m .27033 .35811 L .26713 .35322 L p F P
0 g
s
.794 .64 .691 r
.20187 .44853 m .20838 .45062 L .20465 .45682 L p F P
0 g
s
.793 .645 .699 r
.20838 .45062 m .20187 .44853 L .20597 .44222 L p F P
0 g
s
.779 .671 .744 r
.21965 .40451 m .21576 .40883 L .21257 .40306 L p F P
0 g
s
.779 .671 .744 r
.21257 .40306 m .2132 .40236 L .21965 .40451 L p F P
0 g
s
.777 .675 .751 r
.21965 .40451 m .2132 .40236 L .2199 .39522 L p F P
0 g
s
.734 .688 .807 r
.29508 .34733 m .30314 .34191 L .30774 .34296 L p F P
0 g
s
.733 .69 .809 r
.30314 .34191 m .29508 .34733 L .29191 .34249 L p F P
0 g
s
.746 .691 .798 r
.28113 .35002 m .27033 .35811 L .26713 .35322 L p F P
0 g
s
.546 .101 .145 r
.42922 .55168 m .42487 .55049 L .43043 .55032 L closepath p F P
0 g
s
.488 0 .016 r
.42487 .55049 m .42922 .55168 L .42764 .55297 L p F P
0 g
s
.541 .167 .28 r
.49562 .54454 m .48539 .54279 L .49714 .5413 L closepath p F P
0 g
s
.537 .153 .261 r
.48539 .54279 m .49562 .54454 L p .48283 .54636 L F P
0 g
s
.579 .353 .537 r
.55926 .51713 m .55929 .51204 L .57074 .50925 L p F P
0 g
s
.59 .382 .567 r
.57051 .50392 m .57074 .50925 L .55929 .51204 L p F P
0 g
s
.732 .69 .81 r
.30774 .34296 m .30585 .34012 L .30314 .34191 L closepath p F P
0 g
s
.575 .323 .498 r
.54728 .52449 m .54762 .5197 L .55588 .51788 L p F P
0 g
s
.585 .332 .5 r
.54762 .5197 m .54728 .52449 L .53547 .52687 L p F P
0 g
s
.67 .645 .816 r
.47519 .33753 m .48607 .33314 L .48904 .33849 L p F P
0 g
s
.67 .649 .82 r
.48511 .33146 m .48607 .33314 L .47519 .33753 L p F P
0 g
s
.67 .649 .82 r
.47519 .33753 m .47297 .33362 L .48511 .33146 L p F P
0 g
s
.686 .681 .839 r
.42762 .32657 m .41681 .33142 L .41377 .32671 L p F P
0 g
s
.687 .675 .833 r
.41681 .33142 m .42762 .32657 L .43066 .33133 L p F P
0 g
s
.785 .525 .543 r
.24952 .51791 m .24587 .51706 L .24593 .51194 L p F P
0 g
s
.787 .526 .543 r
.23856 .5102 m .24593 .51194 L .24587 .51706 L p F P
0 g
s
.659 .626 .805 r
.50585 .34533 m .51678 .34127 L .51972 .34703 L p F P
0 g
s
.659 .628 .808 r
.51548 .33877 m .51678 .34127 L .50585 .34533 L p F P
0 g
s
.659 .628 .808 r
.50585 .34533 m .50391 .34158 L .51548 .33877 L p F P
0 g
s
.479 0 .026 r
.43043 .55032 m .43996 .54988 L p .44115 .55236 L F P
0 g
s
.479 0 .026 r
.42922 .55168 m .43043 .55032 L p .44115 .55236 L F P
0 g
s
.554 .072 .065 r
.37386 .55046 m .37401 .55031 L p .38549 .55321 L F P
0 g
s
.614 .176 .185 r
.37386 .55046 m .37351 .55028 L .37401 .55031 L closepath p F P
0 g
s
.577 .1 .086 r
.37351 .55028 m .37386 .55046 L .37084 .55274 L p F P
0 g
s
.577 .1 .086 r
.36241 .54971 m .37351 .55028 L p .37084 .55274 L F P
0 g
s
.637 .587 .782 r
.5644 .3609 m .56729 .36755 L .55627 .37089 L p F P
0 g
s
.637 .587 .782 r
.55627 .37089 m .55349 .36451 L .5644 .3609 L p F P
0 g
s
.715 .686 .821 r
.33367 .33639 m .33732 .3343 L .33178 .33353 L closepath p F P
0 g
s
.722 .69 .819 r
.33178 .33353 m .33367 .33639 L p .31977 .33812 L F P
0 g
s
.627 .566 .766 r
.57604 .38877 m .57604 .38875 L .57621 .38871 L closepath p F P
0 g
s
.627 .567 .768 r
.57621 .38871 m .57604 .38875 L .57312 .38146 L p F P
0 g
s
.783 .673 .742 r
.21344 .41148 m .21576 .40883 L .21257 .40306 L p F P
0 g
s
.785 .664 .73 r
.20462 .42223 m .20777 .41829 L p .20881 .42714 L F P
0 g
s
.785 .664 .73 r
.20881 .42714 m .2068 .42648 L .20462 .42223 L p F P
0 g
s
.788 .658 .719 r
.20778 .42851 m .20881 .42714 L .2068 .42648 L closepath p F P
0 g
s
.625 .559 .761 r
.5871 .3858 m .57621 .38871 L .58678 .38496 L closepath p F P
0 g
s
.627 .567 .768 r
.58418 .37846 m .58678 .38496 L .57621 .38871 L p F P
0 g
s
.627 .567 .768 r
.57312 .38146 m .58418 .37846 L p .57621 .38871 L F P
0 g
s
.685 .279 .271 r
.32811 .54701 m .3218 .54627 L .31735 .54243 L p F P
0 g
s
.665 .237 .22 r
.3146 .54213 m .31735 .54243 L .3218 .54627 L p F P
0 g
s
.683 .671 .832 r
.43066 .33133 m .44149 .32662 L .4445 .33144 L p F P
0 g
s
.683 .677 .838 r
.44149 .32662 m .43066 .33133 L .42762 .32657 L p F P
0 g
s
.653 .621 .804 r
.53068 .34319 m .53263 .3471 L .52131 .35019 L p F P
0 g
s
.653 .621 .804 r
.52131 .35019 m .51972 .34703 L .53068 .34319 L p F P
0 g
s
.554 .072 .065 r
.38549 .55321 m .3816 .55309 L .37386 .55046 L p F P
0 g
s
.554 .072 .066 r
.3816 .55309 m .37084 .55274 L .37386 .55046 L closepath p F P
0 g
s
.581 .375 .567 r
.57074 .50925 m .57051 .50392 L .58181 .50093 L p F P
0 g
s
.59 .4 .592 r
.58134 .49536 m .58181 .50093 L .57051 .50392 L p F P
0 g
s
.597 .469 .677 r
.59948 .46435 m .59799 .45773 L .60881 .45409 L p F P
0 g
s
.6 .48 .687 r
.60779 .44992 m .60881 .45409 L .59799 .45773 L p F P
0 g
s
.646 .607 .796 r
.54752 .35156 m .54886 .35439 L .53776 .35775 L p F P
0 g
s
.646 .607 .796 r
.53776 .35775 m .53653 .35518 L .54752 .35156 L p F P
0 g
s
.566 .285 .449 r
.53479 .53134 m .53547 .52687 L .54728 .52449 L p F P
0 g
s
.792 .659 .717 r
.20401 .43367 m .20778 .42851 L .2068 .42648 L p F P
0 g
s
.795 .598 .635 r
.22068 .48837 m .21379 .48644 L .21591 .48072 L p F P
0 g
s
.796 .6 .637 r
.20908 .47877 m .21591 .48072 L .21379 .48644 L p F P
0 g
s
.795 .61 .651 r
.21591 .48072 m .20908 .47877 L .21165 .47292 L p F P
0 g
s
.758 .445 .454 r
.27952 .53297 m .27137 .53148 L .26981 .52683 L p F P
0 g
s
.758 .445 .455 r
.26685 .52629 m .26981 .52683 L .27137 .53148 L p F P
0 g
s
.538 .1 .156 r
.4431 .55063 m .43996 .54988 L .44387 .54968 L closepath p F P
0 g
s
.479 0 .026 r
.43996 .54988 m .4431 .55063 L .44115 .55236 L p F P
0 g
s
.796 .585 .617 r
.22597 .49585 m .21903 .49395 L .22068 .48837 L p F P
0 g
s
.796 .587 .618 r
.21379 .48644 m .22068 .48837 L .21903 .49395 L p F P
0 g
s
.784 .671 .739 r
.20717 .40928 m .21344 .41148 L .20777 .41829 L p F P
0 g
s
.783 .673 .742 r
.21257 .40306 m .20717 .40928 L .21344 .41148 L p F P
0 g
s
.793 .649 .703 r
.19956 .44009 m .20597 .44222 L .20187 .44853 L p F P
0 g
s
.792 .653 .709 r
.20597 .44222 m .19956 .44009 L .20401 .43367 L p F P
0 g
s
.674 .655 .823 r
.47297 .33362 m .47221 .3323 L .46669 .33457 L closepath p F P
0 g
s
.676 .66 .827 r
.46922 .32733 m .47221 .3323 L .46669 .33457 L p F P
0 g
s
.676 .66 .827 r
.45835 .33176 m .46922 .32733 L p .46669 .33457 L F P
0 g
s
.665 .237 .22 r
.31209 .54506 m .3146 .54213 L p .3218 .54627 L F P
0 g
s
.701 .303 .29 r
.31209 .54506 m .30823 .54126 L .3146 .54213 L closepath p F P
0 g
s
.797 .612 .652 r
.20592 .47122 m .21165 .47292 L .20908 .47877 L p F P
0 g
s
.794 .621 .667 r
.20548 .4698 m .2079 .46495 L p .21165 .47292 L F P
0 g
s
.794 .621 .667 r
.21165 .47292 m .20592 .47122 L .20548 .4698 L p F P
0 g
s
.722 .69 .819 r
.31977 .33812 m .32843 .33293 L .33178 .33353 L p F P
0 g
s
.72 .693 .823 r
.32843 .33293 m .31977 .33812 L .31661 .3334 L p F P
0 g
s
.73 .368 .364 r
.283 .5336 m .28794 .53437 L .29062 .53871 L p F P
0 g
s
.737 .385 .384 r
.29806 .53991 m .29062 .53871 L .28794 .53437 L p F P
0 g
s
.577 .1 .086 r
.37084 .55274 m .36988 .55269 L .36241 .54971 L p F P
0 g
s
.521 .002 0 r
.35909 .54954 m .36241 .54971 L .36988 .55269 L p F P
0 g
s
.475 .001 .049 r
.44387 .54968 m .45642 .54887 L p .45444 .55153 L F P
0 g
s
.475 .001 .049 r
.4431 .55063 m .44387 .54968 L p .45444 .55153 L F P
0 g
s
.796 .571 .596 r
.23092 .50292 m .22481 .50128 L .22597 .49585 L p F P
0 g
s
.797 .572 .597 r
.21903 .49395 m .22597 .49585 L .22481 .50128 L p F P
0 g
s
.679 .666 .831 r
.4445 .33144 m .45535 .32687 L .45835 .33176 L p F P
0 g
s
.679 .672 .836 r
.45535 .32687 m .4445 .33144 L .44149 .32662 L p F P
0 g
s
.767 .681 .768 r
.23455 .38069 m .23479 .38047 L .23432 .38032 L closepath p F P
0 g
s
.763 .685 .776 r
.23686 .37056 m .24337 .37272 L .23479 .38047 L p F P
0 g
s
.763 .685 .776 r
.23133 .37555 m .23686 .37056 L p .23479 .38047 L F P
0 g
s
.763 .685 .776 r
.23479 .38047 m .23432 .38032 L .23133 .37555 L p F P
0 g
s
.771 .682 .765 r
.22709 .38793 m .23455 .38069 L .23432 .38032 L p F P
0 g
s
.713 .69 .826 r
.34128 .32579 m .34442 .33033 L .33732 .3343 L p F P
0 g
s
.713 .69 .826 r
.33053 .3317 m .34128 .32579 L p .33732 .3343 L F P
0 g
s
.713 .69 .826 r
.33732 .3343 m .33178 .33353 L .33053 .3317 L p F P
0 g
s
.665 .641 .816 r
.48904 .33849 m .49995 .33428 L .5029 .3397 L p F P
0 g
s
.665 .641 .816 r
.49995 .33428 m .48904 .33849 L .48607 .33314 L p F P
0 g
s
.746 .691 .798 r
.28068 .34934 m .28113 .35002 L p .26713 .35322 L F P
0 g
s
.74 .687 .8 r
.28113 .35002 m .28172 .34959 L .28068 .34934 L closepath p F P
0 g
s
.588 .429 .633 r
.5918 .48639 m .59088 .48037 L .60187 .47697 L p F P
0 g
s
.594 .445 .648 r
.60076 .47075 m .60187 .47697 L .59088 .48037 L p F P
0 g
s
.764 .688 .779 r
.24223 .36584 m .23686 .37056 L .24337 .37272 L p F P
0 g
s
.764 .688 .779 r
.24337 .37272 m .24544 .37089 L .24223 .36584 L p F P
0 g
s
.521 .002 0 r
.35674 .5514 m .35909 .54954 L p .36988 .55269 L F P
0 g
s
.604 .139 .122 r
.35674 .5514 m .35173 .54901 L .35909 .54954 L closepath p F P
0 g
s
.797 .623 .666 r
.20548 .4698 m .2079 .46495 L .20356 .46362 L closepath p F P
0 g
s
.794 .631 .68 r
.20252 .46067 m .20465 .45682 L p .2079 .46495 L F P
0 g
s
.794 .631 .68 r
.2079 .46495 m .20356 .46362 L .20252 .46067 L p F P
0 g
s
.759 .687 .783 r
.25273 .3647 m .24544 .37089 L .24223 .36584 L p F P
0 g
s
.737 .691 .806 r
.28942 .33875 m .29191 .34249 L .28172 .34959 L p F P
0 g
s
.737 .691 .806 r
.28783 .33832 m .28942 .33875 L p .28172 .34959 L F P
0 g
s
.737 .691 .806 r
.27793 .34522 m .28783 .33832 L p .28172 .34959 L F P
0 g
s
.737 .691 .806 r
.28172 .34959 m .28068 .34934 L .27793 .34522 L p F P
0 g
s
.733 .69 .809 r
.29191 .34249 m .29545 .34013 L .30314 .34191 L p F P
0 g
s
.734 .694 .812 r
.30268 .33543 m .29545 .34013 L .30314 .34191 L p F P
0 g
s
.734 .694 .812 r
.30314 .34191 m .30585 .34012 L .30268 .33543 L p F P
0 g
s
.79 .666 .726 r
.2068 .42648 m .20462 .42223 L .2025 .42497 L closepath p F P
0 g
s
.792 .659 .717 r
.2068 .42648 m .2025 .42497 L p .20401 .43367 L F P
0 g
s
.774 .49 .505 r
.26189 .52526 m .25413 .52365 L .25346 .51874 L p F P
0 g
s
.774 .49 .505 r
.24952 .51791 m .25346 .51874 L .25413 .52365 L p F P
0 g
s
.771 .682 .765 r
.23432 .38032 m .22842 .37827 L p .22709 .38793 L F P
0 g
s
.77 .687 .772 r
.23432 .38032 m .23133 .37555 L .22842 .37827 L closepath p F P
0 g
s
.541 .15 .25 r
.48283 .54636 m .47522 .54718 L .47086 .54635 L p F P
0 g
s
.538 .139 .233 r
.47522 .54718 m .47006 .5477 L .47086 .54635 L closepath p F P
0 g
s
.567 .186 .278 r
.47086 .54635 m .47006 .5477 L .4571 .54882 L p F P
0 g
s
.773 .679 .76 r
.22709 .38793 m .22359 .39142 L .22038 .386 L p F P
0 g
s
.773 .679 .76 r
.22038 .386 m .22061 .38577 L .22709 .38793 L p F P
0 g
s
.771 .682 .765 r
.22842 .37827 m .22061 .38577 L .22709 .38793 L p F P
0 g
s
.758 .445 .455 r
.27137 .53148 m .26532 .53038 L .26685 .52629 L p F P
0 g
s
.769 .457 .459 r
.26189 .52526 m .26685 .52629 L .26532 .53038 L p F P
0 g
s
.647 .609 .798 r
.54752 .35156 m .53653 .35518 L .5336 .34909 L p F P
0 g
s
.789 .548 .573 r
.23092 .50292 m .23185 .50315 L .23117 .50845 L p F P
0 g
s
.787 .546 .573 r
.23856 .5102 m .23117 .50845 L .23185 .50315 L p F P
0 g
s
.746 .691 .798 r
.26713 .35322 m .27464 .34762 L .28068 .34934 L p F P
0 g
s
.745 .693 .802 r
.28068 .34934 m .27793 .34522 L .27464 .34762 L closepath p F P
0 g
s
.759 .687 .783 r
.24223 .36584 m .24606 .3626 L .25273 .3647 L p F P
0 g
s
.758 .69 .786 r
.25309 .35679 m .24606 .3626 L .25273 .3647 L p F P
0 g
s
.758 .69 .786 r
.25273 .3647 m .2563 .36176 L .25309 .35679 L p F P
0 g
s
.777 .68 .757 r
.2199 .39522 m .22359 .39142 L .22038 .386 L p F P
0 g
s
.627 .568 .768 r
.58319 .376 m .58418 .37846 L .57312 .38146 L p F P
0 g
s
.627 .568 .768 r
.57312 .38146 m .57246 .37982 L .58319 .376 L p F P
0 g
s
.66 .634 .813 r
.51384 .33568 m .51548 .33877 L .50391 .34158 L p F P
0 g
s
.66 .634 .813 r
.50391 .34158 m .5029 .3397 L .51384 .33568 L p F P
0 g
s
.589 .415 .613 r
.59182 .4866 m .59249 .49218 L .58134 .49536 L p F P
0 g
s
.581 .393 .592 r
.58181 .50093 m .58134 .49536 L .59249 .49218 L p F P
0 g
s
.654 .623 .807 r
.53068 .34319 m .51972 .34703 L .51678 .34127 L p F P
0 g
s
.727 .695 .82 r
.31661 .3334 m .30585 .34012 L .30268 .33543 L p F P
0 g
s
.526 .035 .033 r
.39383 .55333 m .38549 .55321 L .38767 .55161 L closepath p F P
0 g
s
.527 .037 .037 r
.39982 .5534 m .39383 .55333 L .38767 .55161 L p F P
0 g
s
.797 .633 .679 r
.20252 .46067 m .20465 .45682 L .20071 .45558 L closepath p F P
0 g
s
.794 .64 .691 r
.19949 .45248 m .20187 .44853 L p .20465 .45682 L F P
0 g
s
.794 .64 .691 r
.20465 .45682 m .20071 .45558 L .19949 .45248 L p F P
0 g
s
.753 .689 .791 r
.26307 .35637 m .2563 .36176 L .25309 .35679 L p F P
0 g
s
.675 .667 .834 r
.46922 .32733 m .45835 .33176 L .45535 .32687 L p F P
0 g
s
.639 .594 .788 r
.56438 .36085 m .5644 .3609 L .55349 .36451 L p F P
0 g
s
.639 .594 .788 r
.55349 .36451 m .55336 .36421 L .56438 .36085 L p F P
0 g
s
.789 .548 .573 r
.23117 .50845 m .23088 .50838 L .23092 .50292 L p F P
0 g
s
.797 .555 .572 r
.22481 .50128 m .23092 .50292 L .23088 .50838 L p F P
0 g
s
.777 .68 .757 r
.22038 .386 m .2136 .39301 L .2199 .39522 L p F P
0 g
s
.777 .679 .755 r
.2136 .39301 m .2199 .39522 L .2132 .40236 L p F P
0 g
s
.787 .665 .729 r
.20462 .42223 m .20777 .41829 L .20147 .41614 L closepath p F P
0 g
s
.784 .671 .739 r
.20144 .41608 m .20717 .40928 L p .20777 .41829 L F P
0 g
s
.784 .671 .739 r
.20777 .41829 m .20147 .41614 L .20144 .41608 L p F P
0 g
s
.793 .657 .713 r
.19772 .43149 m .20401 .43367 L .19956 .44009 L p F P
0 g
s
.792 .659 .717 r
.2025 .42497 m .19772 .43149 L .20401 .43367 L p F P
0 g
s
.639 .597 .79 r
.56438 .36085 m .55336 .36421 L .55044 .35782 L p F P
0 g
s
.629 .575 .775 r
.58126 .37137 m .58319 .376 L .57246 .37982 L p F P
0 g
s
.629 .575 .775 r
.57246 .37982 m .57021 .37441 L .58126 .37137 L p F P
0 g
s
.565 .064 .023 r
.35173 .54901 m .35674 .5514 L .3558 .5519 L p F P
0 g
s
.565 .064 .023 r
.34381 .54846 m .35173 .54901 L p .3558 .5519 L F P
0 g
s
.662 .244 .241 r
.34131 .54823 m .33137 .54731 L .32925 .54578 L p F P
0 g
s
.662 .244 .241 r
.33137 .54731 m .32811 .54701 L .32925 .54578 L closepath p F P
0 g
s
.508 .115 .23 r
.49714 .5413 m .50933 .53959 L p .50781 .54306 L F P
0 g
s
.508 .115 .23 r
.49562 .54454 m .49714 .5413 L p .50781 .54306 L F P
0 g
s
.73 .368 .364 r
.28139 .53645 m .283 .5336 L p .29062 .53871 L F P
0 g
s
.748 .402 .397 r
.28139 .53645 m .27952 .53297 L .283 .5336 L closepath p F P
0 g
s
.67 .653 .825 r
.4831 .32801 m .48511 .33146 L .47297 .33362 L p F P
0 g
s
.67 .653 .825 r
.47297 .33362 m .47221 .3323 L .4831 .32801 L p F P
0 g
s
.696 .284 .261 r
.30823 .54126 m .31209 .54506 L .31197 .54517 L p F P
0 g
s
.696 .284 .261 r
.29917 .54006 m .30823 .54126 L p .31197 .54517 L F P
0 g
s
.719 .359 .367 r
.30823 .54126 m .29917 .54006 L .29851 .53917 L p F P
0 g
s
.591 .454 .663 r
.59974 .46565 m .59948 .46435 L .6103 .46072 L p F P
0 g
s
.597 .469 .677 r
.60881 .45409 m .6103 .46072 L .59948 .46435 L p F P
0 g
s
.548 .225 .372 r
.52167 .53756 m .52281 .53351 L .52901 .5324 L p F P
0 g
s
.562 .241 .382 r
.52281 .53351 m .52167 .53756 L .50952 .53956 L p F P
0 g
s
.72 .692 .823 r
.33178 .33353 m .33053 .3317 L .32843 .33293 L closepath p F P
0 g
s
.533 .105 .175 r
.45698 .54899 m .45642 .54887 L .4571 .54882 L closepath p F P
0 g
s
.475 .001 .049 r
.45642 .54887 m .45698 .54899 L .45444 .55153 L p F P
0 g
s
.517 .088 .165 r
.45698 .54899 m .4571 .54882 L .47006 .5477 L p F P
0 g
s
.607 .519 .728 r
.59883 .41865 m .59861 .41797 L .60922 .41403 L p F P
0 g
s
.611 .528 .737 r
.607 .40735 m .60922 .41403 L .59861 .41797 L p F P
0 g
s
.611 .528 .737 r
.59832 .40924 m .607 .40735 L p .59861 .41797 L F P
0 g
s
.611 .528 .737 r
.59861 .41797 m .59599 .4101 L .59832 .40924 L p F P
0 g
s
.607 .518 .728 r
.60103 .42561 m .59883 .41865 L .60995 .41632 L p F P
0 g
s
.607 .519 .728 r
.60922 .41403 m .60995 .41632 L .59883 .41865 L p F P
0 g
s
.591 .453 .662 r
.60076 .47075 m .59974 .46565 L .61087 .46351 L p F P
0 g
s
.591 .454 .663 r
.6103 .46072 m .61087 .46351 L .59974 .46565 L p F P
0 g
s
.607 .518 .728 r
.60995 .41632 m .61165 .42169 L .60103 .42561 L p F P
0 g
s
.604 .509 .719 r
.60179 .42816 m .60103 .42561 L .61165 .42169 L p F P
0 g
s
.774 .49 .505 r
.25413 .52365 m .24849 .52248 L .24952 .51791 L p F P
0 g
s
.784 .5 .507 r
.24587 .51706 m .24952 .51791 L .24849 .52248 L p F P
0 g
s
.753 .689 .791 r
.25309 .35679 m .25622 .35431 L .26307 .35637 L p F P
0 g
s
.752 .692 .795 r
.26392 .34836 m .25622 .35431 L .26307 .35637 L p F P
0 g
s
.752 .692 .795 r
.26307 .35637 m .26713 .35322 L .26392 .34836 L p F P
0 g
s
.787 .526 .543 r
.24587 .51706 m .2385 .51532 L .23856 .5102 L p F P
0 g
s
.786 .526 .543 r
.23117 .50845 m .23856 .5102 L .2385 .51532 L p F P
0 g
s
.575 .326 .502 r
.55911 .51942 m .55588 .51788 L .55926 .51713 L closepath p F P
0 g
s
.575 .323 .498 r
.55588 .51788 m .55911 .51942 L p .54728 .52449 L F P
0 g
s
.604 .509 .719 r
.60325 .43304 m .60179 .42816 L .61292 .42591 L p F P
0 g
s
.604 .509 .719 r
.61165 .42169 m .61292 .42591 L .60179 .42816 L p F P
0 g
s
.661 .639 .817 r
.51384 .33568 m .5029 .3397 L .49995 .33428 L p F P
0 g
s
.517 .088 .165 r
.47006 .5477 m .46781 .55022 L .45698 .54899 L p F P
0 g
s
.47 0 .055 r
.45444 .55153 m .45698 .54899 L .46781 .55022 L p F P
0 g
s
.614 .537 .745 r
.59599 .4101 m .59588 .40979 L .59832 .40924 L closepath p F P
0 g
s
.614 .538 .745 r
.59832 .40924 m .59588 .40979 L .59315 .40199 L p F P
0 g
s
.699 .689 .837 r
.37218 .32827 m .38295 .32302 L .38604 .32755 L p F P
0 g
s
.697 .698 .847 r
.38295 .32302 m .37218 .32827 L .36907 .32374 L p F P
0 g
s
.703 .691 .835 r
.3583 .32919 m .36907 .32374 L .37218 .32827 L p F P
0 g
s
.796 .642 .69 r
.19949 .45248 m .20187 .44853 L .19733 .44705 L closepath p F P
0 g
s
.793 .649 .703 r
.19641 .44493 m .19956 .44009 L p .20187 .44853 L F P
0 g
s
.793 .649 .703 r
.20187 .44853 m .19733 .44705 L .19641 .44493 L p F P
0 g
s
.504 .012 .02 r
.41387 .55332 m .40673 .55337 L .4015 .55217 L p F P
0 g
s
.502 .006 .011 r
.40673 .55337 m .39982 .5534 L .4015 .55217 L closepath p F P
0 g
s
.781 .674 .745 r
.21257 .40306 m .2132 .40236 L .21194 .40193 L closepath p F P
0 g
s
.777 .679 .755 r
.20935 .39753 m .2136 .39301 L p .2132 .40236 L F P
0 g
s
.777 .679 .755 r
.2132 .40236 m .21194 .40193 L .20935 .39753 L p F P
0 g
s
.695 .688 .839 r
.39717 .32299 m .39991 .32704 L p .38604 .32755 L F P
0 g
s
.695 .688 .839 r
.38604 .32755 m .39583 .32296 L .39717 .32299 L p F P
0 g
s
.692 .696 .849 r
.39583 .32296 m .38604 .32755 L .38295 .32302 L p F P
0 g
s
.791 .666 .726 r
.2025 .42497 m .20462 .42223 L .20147 .41614 L p F P
0 g
s
.72 .359 .365 r
.29917 .54006 m .29806 .53991 L .29851 .53917 L closepath p F P
0 g
s
.702 .699 .844 r
.36907 .32374 m .3583 .32919 L .35518 .32466 L p F P
0 g
s
.708 .693 .833 r
.34442 .33033 m .35518 .32466 L .3583 .32919 L p F P
0 g
s
.565 .064 .023 r
.34296 .54918 m .34381 .54846 L p .3558 .5519 L F P
0 g
s
.634 .184 .166 r
.34296 .54918 m .34131 .54823 L .34381 .54846 L closepath p F P
0 g
s
.785 .675 .743 r
.20717 .40928 m .21257 .40306 L .21194 .40193 L p F P
0 g
s
.671 .661 .832 r
.4831 .32801 m .47221 .3323 L .46922 .32733 L p F P
0 g
s
.601 .499 .71 r
.60477 .43842 m .60325 .43304 L .61389 .42914 L p F P
0 g
s
.604 .509 .719 r
.61292 .42591 m .61389 .42914 L .60325 .43304 L p F P
0 g
s
.69 .685 .84 r
.41123 .32292 m .41377 .32671 L p .39991 .32704 L F P
0 g
s
.69 .685 .84 r
.39991 .32704 m .40893 .32294 L .41123 .32292 L p F P
0 g
s
.691 .686 .841 r
.39991 .32704 m .40893 .32294 L .39717 .32299 L closepath p F P
0 g
s
.746 .692 .8 r
.27464 .34762 m .26713 .35322 L .26392 .34836 L p F P
0 g
s
.733 .689 .809 r
.29191 .34249 m .29545 .34013 L .28942 .33875 L closepath p F P
0 g
s
.749 .395 .382 r
.27952 .53297 m .28139 .53645 L .28091 .53718 L p F P
0 g
s
.749 .395 .382 r
.27137 .53148 m .27952 .53297 L p .28091 .53718 L F P
0 g
s
.722 .697 .826 r
.32737 .32717 m .32005 .33138 L .32843 .33293 L p F P
0 g
s
.722 .697 .826 r
.32843 .33293 m .33053 .3317 L .32737 .32717 L p F P
0 g
s
.72 .693 .823 r
.31661 .3334 m .32005 .33138 L .32843 .33293 L p F P
0 g
s
.769 .457 .459 r
.26532 .53038 m .26329 .52996 L .26189 .52526 L p F P
0 g
s
.771 .455 .453 r
.25413 .52365 m .26189 .52526 L .26329 .52996 L p F P
0 g
s
.707 .697 .838 r
.35518 .32466 m .34442 .33033 L .34128 .32579 L p F P
0 g
s
.801 .625 .664 r
.20356 .46362 m .20133 .46289 L p .20494 .47091 L F P
0 g
s
.801 .625 .664 r
.20494 .47091 m .20548 .4698 L .20356 .46362 L p F P
0 g
s
.8 .634 .676 r
.20356 .46362 m .20252 .46067 L .20133 .46289 L closepath p F P
0 g
s
.6 .115 .074 r
.34131 .54823 m .34296 .54918 L .34039 .55074 L p F P
0 g
s
.6 .115 .074 r
.33137 .54731 m .34131 .54823 L p .34039 .55074 L F P
0 g
s
.8 .625 .664 r
.20592 .47122 m .20548 .4698 L .20494 .47091 L closepath p F P
0 g
s
.614 .538 .745 r
.59315 .40199 m .59746 .40037 L p .59832 .40924 L F P
0 g
s
.616 .546 .753 r
.59315 .40199 m .59295 .40143 L .59746 .40037 L closepath p F P
0 g
s
.629 .576 .776 r
.57931 .36669 m .58126 .37137 L .57021 .37441 L p F P
0 g
s
.629 .576 .776 r
.57021 .37441 m .56859 .37054 L .57931 .36669 L p F P
0 g
s
.686 .681 .839 r
.4249 .32243 m .42762 .32657 L p .41377 .32671 L F P
0 g
s
.686 .681 .839 r
.41377 .32671 m .42333 .3225 L .4249 .32243 L p F P
0 g
s
.687 .684 .841 r
.41377 .32671 m .42333 .3225 L .41123 .32292 L closepath p F P
0 g
s
.797 .612 .652 r
.20908 .47877 m .2078 .47839 L .20592 .47122 L p F P
0 g
s
.803 .616 .649 r
.20494 .47091 m .20592 .47122 L .2078 .47839 L p F P
0 g
s
.475 .001 .049 r
.45444 .55153 m .45144 .55173 L .4431 .55063 L p F P
0 g
s
.468 0 .024 r
.45144 .55173 m .44115 .55236 L .4431 .55063 L closepath p F P
0 g
s
.488 0 .016 r
.42764 .55297 m .42048 .55316 L .41536 .55218 L p F P
0 g
s
.484 0 .002 r
.42048 .55316 m .41387 .55332 L .41536 .55218 L closepath p F P
0 g
s
.616 .546 .753 r
.59746 .40037 m .59295 .40143 L .59009 .39362 L p F P
0 g
s
.801 .635 .676 r
.20133 .46289 m .20252 .46067 L .20071 .45558 L p F P
0 g
s
.785 .675 .743 r
.21194 .40193 m .207 .40012 L p .20717 .40928 L F P
0 g
s
.783 .68 .75 r
.21194 .40193 m .20935 .39753 L .207 .40012 L closepath p F P
0 g
s
.601 .499 .71 r
.60529 .44026 m .60477 .43842 L .61591 .43626 L p F P
0 g
s
.601 .499 .71 r
.61389 .42914 m .61591 .43626 L .60477 .43842 L p F P
0 g
s
.793 .663 .72 r
.19631 .42274 m .2025 .42497 L .19772 .43149 L p F P
0 g
s
.791 .666 .726 r
.20141 .41612 m .19631 .42274 L .2025 .42497 L p F P
0 g
s
.791 .666 .726 r
.20147 .41614 m .20141 .41612 L p .2025 .42497 L F P
0 g
s
.479 0 .026 r
.44115 .55236 m .4353 .55264 L .42922 .55168 L p F P
0 g
s
.473 0 .006 r
.4353 .55264 m .42764 .55297 L .42922 .55168 L closepath p F P
0 g
s
.796 .6 .637 r
.20831 .48084 m .20908 .47877 L p .21379 .48644 L F P
0 g
s
.799 .602 .636 r
.20831 .48084 m .20908 .47877 L .2078 .47839 L closepath p F P
0 g
s
.796 .587 .618 r
.21903 .49395 m .2121 .49203 L .21379 .48644 L p F P
0 g
s
.798 .589 .619 r
.20921 .48514 m .21379 .48644 L .2121 .49203 L p F P
0 g
s
.796 .6 .637 r
.21379 .48644 m .20921 .48514 L .20831 .48084 L p F P
0 g
s
.713 .698 .835 r
.34128 .32579 m .33053 .3317 L .32737 .32717 L p F P
0 g
s
.597 .487 .699 r
.60714 .44728 m .60529 .44026 L .61595 .43639 L p F P
0 g
s
.601 .499 .71 r
.61591 .43626 m .61595 .43639 L .60529 .44026 L p F P
0 g
s
.581 .409 .613 r
.59182 .4866 m .5918 .48639 L .60279 .483 L p F P
0 g
s
.588 .429 .633 r
.60187 .47697 m .60279 .483 L .5918 .48639 L p F P
0 g
s
.801 .635 .676 r
.20071 .45558 m .19818 .45472 L p .20133 .46289 L F P
0 g
s
.8 .643 .688 r
.20071 .45558 m .19949 .45248 L .19818 .45472 L closepath p F P
0 g
s
.563 .315 .497 r
.55926 .51713 m .57072 .51434 L .57043 .51915 L p F P
0 g
s
.563 .315 .497 r
.55911 .51942 m .55926 .51713 L p .57043 .51915 L F P
0 g
s
.579 .353 .537 r
.57074 .50925 m .57072 .51434 L .55926 .51713 L p F P
0 g
s
.73 .693 .815 r
.29949 .33079 m .30268 .33543 L .29545 .34013 L p F P
0 g
s
.73 .693 .815 r
.28872 .33772 m .29949 .33079 L p .29545 .34013 L F P
0 g
s
.73 .693 .815 r
.29545 .34013 m .28942 .33875 L .28872 .33772 L p F P
0 g
s
.581 .408 .613 r
.59249 .49218 m .59182 .4866 L .60293 .48411 L p F P
0 g
s
.581 .409 .613 r
.60279 .483 m .60293 .48411 L .59182 .4866 L p F P
0 g
s
.804 .618 .65 r
.19851 .46882 m .20494 .47091 L .20251 .47672 L p F P
0 g
s
.801 .625 .664 r
.20133 .46289 m .19851 .46882 L .20494 .47091 L p F P
0 g
s
.803 .616 .649 r
.2078 .47839 m .20251 .47672 L .20494 .47091 L p F P
0 g
s
.683 .677 .838 r
.42762 .32657 m .43846 .32192 L .44149 .32662 L p F P
0 g
s
.683 .68 .841 r
.43817 .32149 m .43846 .32192 L .42762 .32657 L p F P
0 g
s
.683 .68 .841 r
.42762 .32657 m .4249 .32243 L .43817 .32149 L p F P
0 g
s
.784 .5 .507 r
.24849 .52248 m .24645 .522 L .24587 .51706 L p F P
0 g
s
.786 .501 .504 r
.2385 .51532 m .24587 .51706 L .24645 .522 L p F P
0 g
s
.796 .65 .701 r
.19641 .44493 m .19956 .44009 L .19338 .43799 L closepath p F P
0 g
s
.793 .657 .713 r
.19329 .43781 m .19772 .43149 L p .19956 .44009 L F P
0 g
s
.793 .657 .713 r
.19956 .44009 m .19338 .43799 L .19329 .43781 L p F P
0 g
s
.797 .572 .597 r
.22481 .50128 m .21785 .49939 L .21903 .49395 L p F P
0 g
s
.797 .573 .598 r
.2121 .49203 m .21903 .49395 L .21785 .49939 L p F P
0 g
s
.787 .673 .738 r
.20717 .40928 m .20144 .41608 L .19823 .41029 L p F P
0 g
s
.787 .673 .738 r
.19823 .41029 m .20094 .40705 L .20717 .40928 L p F P
0 g
s
.785 .675 .743 r
.207 .40012 m .20094 .40705 L .20717 .40928 L p F P
0 g
s
.548 .225 .372 r
.52901 .5324 m .53434 .5332 L p .52167 .53756 L F P
0 g
s
.552 .239 .39 r
.53434 .5332 m .52901 .5324 L .53479 .53134 L closepath p F P
0 g
s
.647 .609 .798 r
.5336 .34909 m .5446 .34545 L .54752 .35156 L p F P
0 g
s
.647 .612 .8 r
.54375 .34371 m .5446 .34545 L .5336 .34909 L p F P
0 g
s
.647 .612 .8 r
.5336 .34909 m .53263 .3471 L .54375 .34371 L p F P
0 g
s
.61 .528 .737 r
.607 .40735 m .59832 .40924 L .60659 .40614 L closepath p F P
0 g
s
.614 .538 .745 r
.60406 .39889 m .60659 .40614 L .59832 .40924 L p F P
0 g
s
.614 .538 .745 r
.59746 .40037 m .60406 .39889 L p .59832 .40924 L F P
0 g
s
.696 .284 .261 r
.31197 .54517 m .30342 .54394 L .29917 .54006 L p F P
0 g
s
.694 .286 .268 r
.29806 .53991 m .29917 .54006 L .30342 .54394 L p F P
0 g
s
.569 .345 .536 r
.57072 .51434 m .57074 .50925 L .58206 .50627 L p F P
0 g
s
.581 .375 .567 r
.58181 .50093 m .58206 .50627 L .57074 .50925 L p F P
0 g
s
.746 .692 .8 r
.26392 .34836 m .26763 .34561 L .27464 .34762 L p F P
0 g
s
.746 .695 .803 r
.27472 .34048 m .26763 .34561 L .27464 .34762 L p F P
0 g
s
.746 .695 .803 r
.27464 .34762 m .27793 .34522 L .27472 .34048 L p F P
0 g
s
.586 .439 .649 r
.60187 .47697 m .60076 .47075 L .6116 .46714 L p F P
0 g
s
.591 .453 .662 r
.61087 .46351 m .6116 .46714 L .60076 .47075 L p F P
0 g
s
.404 0 0 r
.47006 .5477 m .47522 .54718 L p .4803 .54913 L F P
0 g
s
.404 0 0 r
.46781 .55022 m .47006 .5477 L p .4803 .54913 L F P
0 g
s
.665 .641 .816 r
.49704 .32903 m .49995 .33428 L p .48607 .33314 L F P
0 g
s
.665 .641 .816 r
.48607 .33314 m .49636 .32917 L .49704 .32903 L p F P
0 g
s
.667 .649 .823 r
.48607 .33314 m .49636 .32917 L .48511 .33146 L closepath p F P
0 g
s
.803 .605 .634 r
.2078 .47839 m .20251 .47672 L p .20701 .48447 L F P
0 g
s
.803 .605 .634 r
.20701 .48447 m .20831 .48084 L .2078 .47839 L p F P
0 g
s
.8 .644 .688 r
.19818 .45472 m .19949 .45248 L .19733 .44705 L p F P
0 g
s
.639 .597 .79 r
.55044 .35782 m .56146 .35445 L .56438 .36085 L p F P
0 g
s
.639 .598 .791 r
.55977 .35075 m .56146 .35445 L .55044 .35782 L p F P
0 g
s
.639 .598 .791 r
.55044 .35782 m .54886 .35439 L .55977 .35075 L p F P
0 g
s
.766 .687 .776 r
.23686 .37056 m .23133 .37555 L .2281 .37045 L p F P
0 g
s
.771 .689 .773 r
.22842 .37827 m .23133 .37555 L .2281 .37045 L p F P
0 g
s
.694 .286 .268 r
.30342 .54394 m .29526 .54284 L .29806 .53991 L p F P
0 g
s
.712 .31 .283 r
.29062 .53871 m .29806 .53991 L .29526 .54284 L p F P
0 g
s
.77 .686 .77 r
.22212 .37604 m .22842 .37827 L .22061 .38577 L p F P
0 g
s
.771 .689 .773 r
.2281 .37045 m .22212 .37604 L .22842 .37827 L p F P
0 g
s
.764 .69 .78 r
.239 .36082 m .23039 .36838 L .23686 .37056 L p F P
0 g
s
.764 .69 .78 r
.23686 .37056 m .24223 .36584 L .239 .36082 L p F P
0 g
s
.766 .687 .776 r
.2281 .37045 m .23039 .36838 L .23686 .37056 L p F P
0 g
s
.554 .274 .445 r
.5466 .52895 m .54728 .52449 L .55894 .52192 L p F P
0 g
s
.575 .323 .498 r
.55911 .51942 m .55894 .52192 L .54728 .52449 L p F P
0 g
s
.566 .285 .449 r
.54728 .52449 m .5466 .52895 L .53479 .53134 L p F P
0 g
s
.631 .584 .782 r
.57835 .36446 m .57931 .36669 L .56859 .37054 L p F P
0 g
s
.631 .584 .782 r
.56859 .37054 m .56729 .36755 L .57835 .36446 L p F P
0 g
s
.804 .629 .665 r
.19497 .46076 m .20133 .46289 L .19851 .46882 L p F P
0 g
s
.801 .635 .676 r
.19818 .45472 m .19497 .46076 L .20133 .46289 L p F P
0 g
s
.616 .546 .753 r
.59009 .39362 m .59156 .39306 L p .59746 .40037 L F P
0 g
s
.619 .554 .76 r
.59009 .39362 m .59002 .39343 L .59156 .39306 L closepath p F P
0 g
s
.619 .555 .761 r
.59156 .39306 m .59002 .39343 L .5871 .3858 L p F P
0 g
s
.72 .691 .822 r
.31661 .3334 m .32005 .33138 L .31458 .33041 L closepath p F P
0 g
s
.727 .695 .82 r
.31458 .33041 m .31661 .3334 L p .30268 .33543 L F P
0 g
s
.759 .689 .784 r
.24606 .3626 m .24223 .36584 L .239 .36082 L p F P
0 g
s
.797 .555 .572 r
.23088 .50838 m .22416 .50657 L .22481 .50128 L p F P
0 g
s
.798 .556 .572 r
.21785 .49939 m .22481 .50128 L .22416 .50657 L p F P
0 g
s
.679 .672 .836 r
.44149 .32662 m .45234 .32209 L .45535 .32687 L p F P
0 g
s
.678 .68 .845 r
.45234 .32209 m .44149 .32662 L .43846 .32192 L p F P
0 g
s
.654 .623 .807 r
.51678 .34127 m .52774 .33741 L .53068 .34319 L p F P
0 g
s
.655 .627 .81 r
.52684 .33567 m .52774 .33741 L .51678 .34127 L p F P
0 g
s
.655 .627 .81 r
.51678 .34127 m .51548 .33877 L .52684 .33567 L p F P
0 g
s
.774 .682 .761 r
.22038 .386 m .22061 .38577 L .22015 .38561 L closepath p F P
0 g
s
.77 .686 .77 r
.21714 .38082 m .22212 .37604 L p .22061 .38577 L F P
0 g
s
.77 .686 .77 r
.22061 .38577 m .22015 .38561 L .21714 .38082 L p F P
0 g
s
.778 .683 .758 r
.2136 .39301 m .22038 .386 L .22015 .38561 L p F P
0 g
s
.74 .696 .81 r
.28783 .33832 m .27793 .34522 L .27472 .34048 L p F P
0 g
s
.593 .476 .689 r
.60779 .44992 m .60714 .44728 L .6178 .44341 L p F P
0 g
s
.597 .487 .699 r
.61595 .43639 m .6178 .44341 L .60714 .44728 L p F P
0 g
s
.759 .689 .784 r
.239 .36082 m .2394 .36048 L .24606 .3626 L p F P
0 g
s
.758 .692 .788 r
.24943 .35223 m .2394 .36048 L .24606 .3626 L p F P
0 g
s
.758 .692 .788 r
.25029 .35252 m .24943 .35223 L p .24606 .3626 L F P
0 g
s
.758 .692 .788 r
.24606 .3626 m .25309 .35679 L .25029 .35252 L p F P
0 g
s
.803 .605 .634 r
.20921 .48514 m .20831 .48084 L .20701 .48447 L closepath p F P
0 g
s
.6 .115 .074 r
.34039 .55074 m .33803 .55051 L .33137 .54731 L p F P
0 g
s
.55 .028 0 r
.32811 .54701 m .33137 .54731 L .33803 .55051 L p F P
0 g
s
.542 .185 .311 r
.5095 .53961 m .50933 .53959 L .50952 .53956 L closepath p F P
0 g
s
.508 .115 .23 r
.50933 .53959 m .5095 .53961 L .50781 .54306 L p F P
0 g
s
.778 .683 .758 r
.22015 .38561 m .21444 .38351 L p .2136 .39301 L F P
0 g
s
.777 .688 .765 r
.22015 .38561 m .21714 .38082 L .21444 .38351 L closepath p F P
0 g
s
.528 .171 .305 r
.5095 .53961 m .50952 .53956 L .52167 .53756 L p F P
0 g
s
.648 .619 .806 r
.54167 .33956 m .54375 .34371 L .53263 .3471 L p F P
0 g
s
.648 .619 .806 r
.53263 .3471 m .53068 .34319 L .54167 .33956 L p F P
0 g
s
.528 .171 .305 r
.52167 .53756 m .52048 .54031 L .5095 .53961 L p F P
0 g
s
.51 .128 .251 r
.50781 .54306 m .5095 .53961 L .52048 .54031 L p F P
0 g
s
.486 .047 .129 r
.48172 .54781 m .47522 .54718 L .48283 .54636 L closepath p F P
0 g
s
.404 0 0 r
.47522 .54718 m .48172 .54781 L .4803 .54913 L p F P
0 g
s
.8 .644 .688 r
.19733 .44705 m .19548 .4464 L p .19818 .45472 L F P
0 g
s
.799 .651 .699 r
.19733 .44705 m .19641 .44493 L .19548 .4464 L closepath p F P
0 g
s
.572 .368 .566 r
.58206 .50627 m .58181 .50093 L .59297 .49775 L p F P
0 g
s
.581 .393 .592 r
.59249 .49218 m .59297 .49775 L .58181 .50093 L p F P
0 g
s
.803 .638 .678 r
.19191 .45255 m .19818 .45472 L .19497 .46076 L p F P
0 g
s
.8 .644 .688 r
.19548 .4464 m .19191 .45255 L .19818 .45472 L p F P
0 g
s
.565 .064 .023 r
.3558 .5519 m .34837 .55132 L .34296 .54918 L p F P
0 g
s
.567 .07 .034 r
.34837 .55132 m .34039 .55074 L .34296 .54918 L closepath p F P
0 g
s
.619 .555 .761 r
.5982 .38316 m .60067 .3896 L .59156 .39306 L p F P
0 g
s
.619 .555 .761 r
.5871 .3858 m .5982 .38316 L p .59156 .39306 L F P
0 g
s
.616 .546 .753 r
.59156 .39306 m .60113 .39085 L p .59746 .40037 L F P
0 g
s
.616 .547 .754 r
.60113 .39085 m .59156 .39306 L .60067 .3896 L closepath p F P
0 g
s
.593 .475 .688 r
.60881 .45409 m .60779 .44992 L .61895 .44807 L p F P
0 g
s
.593 .476 .689 r
.6178 .44341 m .61895 .44807 L .60779 .44992 L p F P
0 g
s
.667 .654 .828 r
.49636 .32917 m .48511 .33146 L .4831 .32801 L p F P
0 g
s
.789 .672 .735 r
.20147 .41614 m .20144 .41608 L .20141 .41612 L closepath p F P
0 g
s
.631 .584 .783 r
.57544 .35776 m .57835 .36446 L .56729 .36755 L p F P
0 g
s
.631 .584 .783 r
.56516 .36063 m .57544 .35776 L p .56729 .36755 L F P
0 g
s
.631 .584 .783 r
.56729 .36755 m .5644 .3609 L .56516 .36063 L p F P
0 g
s
.55 .028 0 r
.3258 .54859 m .32811 .54701 L p .33803 .55051 L F P
0 g
s
.634 .166 .126 r
.3258 .54859 m .3218 .54627 L .32811 .54701 L closepath p F P
0 g
s
.753 .69 .791 r
.25309 .35679 m .25622 .35431 L .25029 .35252 L closepath p F P
0 g
s
.791 .675 .736 r
.20141 .41612 m .20144 .41608 L .19823 .41029 L p F P
0 g
s
.793 .67 .728 r
.19534 .41384 m .20141 .41612 L .19631 .42274 L p F P
0 g
s
.791 .675 .736 r
.19823 .41029 m .19534 .41384 L .20141 .41612 L p F P
0 g
s
.78 .68 .754 r
.2136 .39301 m .20935 .39753 L .20612 .39208 L p F P
0 g
s
.78 .68 .754 r
.20612 .39208 m .20735 .39078 L .2136 .39301 L p F P
0 g
s
.778 .683 .758 r
.21444 .38351 m .20735 .39078 L .2136 .39301 L p F P
0 g
s
.796 .658 .711 r
.19772 .43149 m .19329 .43781 L .19014 .43121 L p F P
0 g
s
.796 .658 .711 r
.19014 .43121 m .19147 .42929 L .19772 .43149 L p F P
0 g
s
.793 .663 .72 r
.19772 .43149 m .19147 .42929 L .19631 .42274 L p F P
0 g
s
.675 .667 .834 r
.45535 .32687 m .46623 .32247 L .46922 .32733 L p F P
0 g
s
.674 .673 .84 r
.46623 .32247 m .45535 .32687 L .45234 .32209 L p F P
0 g
s
.717 .695 .828 r
.3242 .32271 m .32737 .32717 L .32005 .33138 L p F P
0 g
s
.717 .695 .828 r
.31344 .32878 m .3242 .32271 L p .32005 .33138 L F P
0 g
s
.717 .695 .828 r
.32005 .33138 m .31458 .33041 L .31344 .32878 L p F P
0 g
s
.789 .528 .542 r
.23088 .50838 m .23117 .50845 L .2311 .51357 L p F P
0 g
s
.786 .526 .543 r
.2385 .51532 m .2311 .51357 L .23117 .50845 L p F P
0 g
s
.727 .695 .82 r
.30268 .33543 m .31179 .32978 L .31458 .33041 L p F P
0 g
s
.726 .698 .824 r
.31179 .32978 m .30268 .33543 L .29949 .33079 L p F P
0 g
s
.749 .395 .382 r
.28091 .53718 m .27389 .53586 L .27137 .53148 L p F P
0 g
s
.744 .382 .367 r
.26532 .53038 m .27137 .53148 L .27389 .53586 L p F P
0 g
s
.789 .528 .542 r
.2311 .51357 m .23033 .51338 L .23088 .50838 L p F P
0 g
s
.798 .536 .542 r
.22416 .50657 m .23088 .50838 L .23033 .51338 L p F P
0 g
s
.641 .605 .797 r
.55854 .34816 m .55977 .35075 L .54886 .35439 L p F P
0 g
s
.641 .605 .797 r
.54886 .35439 m .54752 .35156 L .55854 .34816 L p F P
0 g
s
.8 .652 .699 r
.19548 .4464 m .19641 .44493 L .19338 .43799 L p F P
0 g
s
.749 .694 .798 r
.26077 .34364 m .26392 .34836 L .25622 .35431 L p F P
0 g
s
.749 .694 .798 r
.26062 .34359 m .26077 .34364 L p .25622 .35431 L F P
0 g
s
.749 .694 .798 r
.24986 .35188 m .26062 .34359 L p .25622 .35431 L F P
0 g
s
.749 .694 .798 r
.25622 .35431 m .25029 .35252 L .24986 .35188 L p F P
0 g
s
.618 .556 .762 r
.59734 .38091 m .5982 .38316 L .5871 .3858 L p F P
0 g
s
.618 .556 .762 r
.5871 .3858 m .58678 .38496 L .59734 .38091 L p F P
0 g
s
.768 .448 .445 r
.24849 .52248 m .25413 .52365 L .25558 .52833 L p F P
0 g
s
.771 .455 .453 r
.26329 .52996 m .25558 .52833 L .25413 .52365 L p F P
0 g
s
.798 .589 .619 r
.2121 .49203 m .21016 .49148 L .20921 .48514 L p F P
0 g
s
.805 .594 .616 r
.20701 .48447 m .20921 .48514 L .21016 .49148 L p F P
0 g
s
.533 .212 .37 r
.53479 .53134 m .5466 .52895 L .54555 .53304 L p F P
0 g
s
.533 .212 .37 r
.53434 .5332 m .53479 .53134 L p .54555 .53304 L F P
0 g
s
.661 .639 .817 r
.49995 .33428 m .51089 .33026 L .51384 .33568 L p F P
0 g
s
.661 .642 .82 r
.50864 .3262 m .51089 .33026 L .49995 .33428 L p F P
0 g
s
.661 .642 .82 r
.49995 .33428 m .49704 .32903 L .50864 .3262 L p F P
0 g
s
.655 .633 .815 r
.52481 .33185 m .52684 .33567 L .51548 .33877 L p F P
0 g
s
.655 .633 .815 r
.51548 .33877 m .51384 .33568 L .52481 .33185 L p F P
0 g
s
.613 .538 .746 r
.60406 .39889 m .59746 .40037 L .60374 .398 L closepath p F P
0 g
s
.616 .546 .753 r
.60113 .39085 m .60374 .398 L .59746 .40037 L p F P
0 g
s
.621 .564 .769 r
.59528 .37576 m .59734 .38091 L .58678 .38496 L p F P
0 g
s
.621 .564 .769 r
.58678 .38496 m .58418 .37846 L .59528 .37576 L p F P
0 g
s
.784 .682 .751 r
.207 .40012 m .20935 .39753 L .20612 .39208 L p F P
0 g
s
.738 .695 .81 r
.28942 .33875 m .28872 .33772 L .28783 .33832 L closepath p F P
0 g
s
.563 .315 .497 r
.57043 .51915 m .56439 .52062 L .55911 .51942 L p F P
0 g
s
.563 .313 .494 r
.56439 .52062 m .55894 .52192 L .55911 .51942 L closepath p F P
0 g
s
.803 .647 .689 r
.1893 .44419 m .19548 .4464 L .19191 .45255 L p F P
0 g
s
.8 .652 .699 r
.19321 .43793 m .1893 .44419 L .19548 .4464 L p F P
0 g
s
.8 .652 .699 r
.19338 .43799 m .19321 .43793 L p .19548 .4464 L F P
0 g
s
.589 .463 .677 r
.6103 .46072 m .60881 .45409 L .61949 .45025 L p F P
0 g
s
.593 .475 .688 r
.61895 .44807 m .61949 .45025 L .60881 .45409 L p F P
0 g
s
.784 .679 .748 r
.20091 .39784 m .207 .40012 L .20094 .40705 L p F P
0 g
s
.784 .682 .751 r
.20612 .39208 m .20091 .39784 L .207 .40012 L p F P
0 g
s
.712 .31 .283 r
.29526 .54284 m .29445 .54271 L .29062 .53871 L p F P
0 g
s
.708 .292 .256 r
.28202 .53736 m .29062 .53871 L .29445 .54271 L p F P
0 g
s
.73 .368 .364 r
.29062 .53871 m .28202 .53736 L .28139 .53645 L p F P
0 g
s
.423 0 .028 r
.48283 .54636 m .49544 .54484 L .49296 .54764 L p F P
0 g
s
.423 0 .028 r
.48172 .54781 m .48283 .54636 L p .49296 .54764 L F P
0 g
s
.537 .153 .261 r
.49562 .54454 m .49544 .54484 L .48283 .54636 L p F P
0 g
s
.671 .667 .838 r
.48012 .32306 m .46922 .32733 L .46623 .32247 L p F P
0 g
s
.671 .661 .832 r
.46922 .32733 m .48012 .32306 L .4831 .32801 L p F P
0 g
s
.689 .69 .845 r
.40893 .32294 m .39717 .32299 L .39683 .3225 L p F P
0 g
s
.693 .691 .843 r
.39717 .32299 m .39683 .3225 L .39583 .32296 L closepath p F P
0 g
s
.692 .696 .849 r
.38295 .32302 m .38389 .3226 L .39583 .32296 L p F P
0 g
s
.696 .701 .851 r
.39374 .31823 m .38389 .3226 L .39583 .32296 L p F P
0 g
s
.696 .701 .851 r
.39583 .32296 m .39683 .3225 L .39374 .31823 L p F P
0 g
s
.689 .688 .844 r
.41123 .32292 m .41071 .32215 L .40893 .32294 L closepath p F P
0 g
s
.689 .69 .845 r
.40764 .31786 m .41071 .32215 L .40893 .32294 L p F P
0 g
s
.689 .69 .845 r
.39683 .3225 m .40764 .31786 L p .40893 .32294 L F P
0 g
s
.58 .423 .633 r
.60279 .483 m .60187 .47697 L .61271 .47337 L p F P
0 g
s
.586 .439 .649 r
.6116 .46714 m .61271 .47337 L .60187 .47697 L p F P
0 g
s
.74 .696 .81 r
.27472 .34048 m .28074 .33634 L .28783 .33832 L p F P
0 g
s
.74 .699 .813 r
.28551 .33311 m .28074 .33634 L .28783 .33832 L p F P
0 g
s
.74 .699 .813 r
.28783 .33832 m .28872 .33772 L .28551 .33311 L p F P
0 g
s
.604 .107 .045 r
.3218 .54627 m .3258 .54859 L .32453 .54918 L p F P
0 g
s
.604 .107 .045 r
.31229 .5452 m .3218 .54627 L p .32453 .54918 L F P
0 g
s
.665 .237 .22 r
.3218 .54627 m .31229 .5452 L .31209 .54506 L p F P
0 g
s
.686 .687 .846 r
.42333 .3225 m .41123 .32292 L .41071 .32215 L p F P
0 g
s
.746 .692 .8 r
.26392 .34836 m .26763 .34561 L .26077 .34364 L closepath p F P
0 g
s
.696 .696 .845 r
.36907 .32374 m .37308 .32185 L .36749 .32151 L closepath p F P
0 g
s
.702 .699 .844 r
.36749 .32151 m .36907 .32374 L p .35518 .32466 L F P
0 g
s
.697 .698 .847 r
.38263 .32256 m .38295 .32302 L p .36907 .32374 L F P
0 g
s
.697 .698 .847 r
.36907 .32374 m .37308 .32185 L .38263 .32256 L p F P
0 g
s
.692 .696 .849 r
.38295 .32302 m .38389 .3226 L .38263 .32256 L closepath p F P
0 g
s
.641 .607 .799 r
.55854 .34816 m .54752 .35156 L .5446 .34545 L p F P
0 g
s
.733 .7 .82 r
.29949 .33079 m .28872 .33772 L .28551 .33311 L p F P
0 g
s
.702 .699 .844 r
.35518 .32466 m .36265 .32098 L .36749 .32151 L p F P
0 g
s
.698 .702 .85 r
.36265 .32098 m .35518 .32466 L .35205 .32023 L p F P
0 g
s
.707 .697 .838 r
.34128 .32579 m .35205 .32023 L .35518 .32466 L p F P
0 g
s
.786 .501 .504 r
.24645 .522 m .23909 .52025 L .2385 .51532 L p F P
0 g
s
.785 .499 .503 r
.2311 .51357 m .2385 .51532 L .23909 .52025 L p F P
0 g
s
.649 .621 .808 r
.54167 .33956 m .53068 .34319 L .52774 .33741 L p F P
0 g
s
.581 .408 .613 r
.60293 .48411 m .6035 .4888 L .59249 .49218 L p F P
0 g
s
.572 .387 .591 r
.59297 .49775 m .59249 .49218 L .6035 .4888 L p F P
0 g
s
.805 .594 .616 r
.21016 .49148 m .20541 .49003 L .20701 .48447 L p F P
0 g
s
.807 .596 .617 r
.20047 .48242 m .20701 .48447 L .20541 .49003 L p F P
0 g
s
.803 .605 .634 r
.20251 .47672 m .20047 .48242 L .20701 .48447 L p F P
0 g
s
.725 .697 .823 r
.31458 .33041 m .31344 .32878 L .31179 .32978 L closepath p F P
0 g
s
.684 .706 .864 r
.40764 .31786 m .39683 .3225 L .39374 .31823 L p F P
0 g
s
.806 .609 .635 r
.19604 .47464 m .20251 .47672 L .20047 .48242 L p F P
0 g
s
.804 .618 .65 r
.20251 .47672 m .19604 .47464 L .19851 .46882 L p F P
0 g
s
.794 .667 .723 r
.19018 .42049 m .19631 .42274 L .19147 .42929 L p F P
0 g
s
.793 .67 .728 r
.19631 .42274 m .19018 .42049 L .19534 .41384 L p F P
0 g
s
.69 .699 .853 r
.39064 .31413 m .39374 .31823 L .38389 .3226 L p F P
0 g
s
.69 .699 .853 r
.37985 .31873 m .39064 .31413 L p .38389 .3226 L F P
0 g
s
.69 .699 .853 r
.38389 .3226 m .38263 .32256 L .37985 .31873 L p F P
0 g
s
.713 .698 .835 r
.32737 .32717 m .33813 .32135 L .34128 .32579 L p F P
0 g
s
.705 .706 .848 r
.35205 .32023 m .34128 .32579 L .33813 .32135 L p F P
0 g
s
.797 .573 .598 r
.21785 .49939 m .21088 .49748 L .2121 .49203 L p F P
0 g
s
.8 .576 .598 r
.21016 .49148 m .2121 .49203 L .21088 .49748 L p F P
0 g
s
.695 .701 .851 r
.38263 .32256 m .37985 .31873 L .37308 .32185 L closepath p F P
0 g
s
.743 .696 .807 r
.27151 .33578 m .27472 .34048 L .26763 .34561 L p F P
0 g
s
.743 .696 .807 r
.2607 .34354 m .27151 .33578 L p .26763 .34561 L F P
0 g
s
.743 .696 .807 r
.26763 .34561 m .26077 .34364 L .2607 .34354 L p F P
0 g
s
.685 .685 .844 r
.4249 .32243 m .42458 .32195 L .42333 .3225 L closepath p F P
0 g
s
.686 .687 .846 r
.42153 .31763 m .42458 .32195 L .42333 .3225 L p F P
0 g
s
.686 .687 .846 r
.41071 .32215 m .42153 .31763 L p .42333 .3225 L F P
0 g
s
.681 .704 .864 r
.42153 .31763 m .41071 .32215 L .40764 .31786 L p F P
0 g
s
.804 .629 .665 r
.19851 .46882 m .19211 .4667 L .19497 .46076 L p F P
0 g
s
.805 .621 .652 r
.19211 .4667 m .19851 .46882 L .19604 .47464 L p F P
0 g
s
.798 .659 .709 r
.19338 .43799 m .19329 .43781 L .19321 .43793 L closepath p F P
0 g
s
.679 .683 .847 r
.43543 .31752 m .43817 .32149 L .4249 .32243 L p F P
0 g
s
.679 .683 .847 r
.4249 .32243 m .42458 .32195 L .43543 .31752 L p F P
0 g
s
.621 .565 .77 r
.59375 .37192 m .59528 .37576 L .58418 .37846 L p F P
0 g
s
.621 .565 .77 r
.58418 .37846 m .58319 .376 L .59375 .37192 L p F P
0 g
s
.799 .661 .71 r
.19321 .43793 m .19329 .43781 L .19014 .43121 L p F P
0 g
s
.732 .368 .362 r
.28202 .53736 m .28091 .53718 L .28139 .53645 L closepath p F P
0 g
s
.761 .416 .401 r
.26432 .53207 m .26329 .52996 L .26532 .53038 L closepath p F P
0 g
s
.744 .382 .367 r
.26432 .53207 m .26532 .53038 L p .27389 .53586 L F P
0 g
s
.633 .591 .789 r
.5644 .3609 m .56438 .36085 L .56516 .36063 L closepath p F P
0 g
s
.803 .655 .7 r
.18713 .43568 m .19321 .43793 L .1893 .44419 L p F P
0 g
s
.799 .661 .71 r
.19014 .43121 m .18713 .43568 L .19321 .43793 L p F P
0 g
s
.634 .594 .792 r
.56516 .36063 m .56438 .36085 L .56146 .35445 L p F P
0 g
s
.788 .674 .738 r
.19823 .41029 m .20094 .40705 L .19528 .40499 L closepath p F P
0 g
s
.784 .679 .748 r
.19501 .40453 m .20091 .39784 L p .20094 .40705 L F P
0 g
s
.784 .679 .748 r
.20094 .40705 m .19528 .40499 L .19501 .40453 L p F P
0 g
s
.223 0 0 r
.39982 .5534 m .40673 .55337 L p .40962 .55464 L F P
0 g
s
.223 0 0 r
.39829 .5541 m .39982 .5534 L p .40962 .55464 L F P
0 g
s
.417 0 0 r
.39829 .5541 m .39383 .55333 L .39982 .5534 L closepath p F P
0 g
s
.712 .705 .841 r
.33813 .32135 m .32737 .32717 L .3242 .32271 L p F P
0 g
s
.393 0 0 r
.41217 .55411 m .40673 .55337 L .41387 .55332 L closepath p F P
0 g
s
.223 0 0 r
.40673 .55337 m .41217 .55411 L .40962 .55464 L p F P
0 g
s
.656 .637 .819 r
.52481 .33185 m .51384 .33568 L .51089 .33026 L p F P
0 g
s
.522 .005 0 r
.3589 .55207 m .3558 .5519 L .35674 .5514 L closepath p F P
0 g
s
.521 .002 0 r
.36988 .55269 m .3589 .55207 L .35674 .5514 L p F P
0 g
s
.667 .654 .828 r
.4831 .32801 m .49402 .32388 L p .49636 .32917 L F P
0 g
s
.667 .661 .835 r
.49402 .32388 m .4831 .32801 L .48012 .32306 L p F P
0 g
s
.262 0 0 r
.39383 .55333 m .39829 .5541 L .39546 .55466 L p F P
0 g
s
.262 0 0 r
.38549 .55321 m .39383 .55333 L p .39546 .55466 L F P
0 g
s
.798 .556 .572 r
.22416 .50657 m .21718 .50468 L .21785 .49939 L p F P
0 g
s
.798 .557 .573 r
.21088 .49748 m .21785 .49939 L .21718 .50468 L p F P
0 g
s
.201 0 0 r
.41387 .55332 m .42048 .55316 L p .42351 .55436 L F P
0 g
s
.201 0 0 r
.41217 .55411 m .41387 .55332 L p .42351 .55436 L F P
0 g
s
.767 .689 .777 r
.2281 .37045 m .23039 .36838 L .22575 .36679 L closepath p F P
0 g
s
.772 .69 .773 r
.22212 .37604 m .2281 .37045 L .22575 .36679 L p F P
0 g
s
.768 .448 .445 r
.24735 .52538 m .24849 .52248 L p .25558 .52833 L F P
0 g
s
.78 .469 .461 r
.24735 .52538 m .24645 .522 L .24849 .52248 L closepath p F P
0 g
s
.763 .693 .785 r
.23861 .36021 m .239 .36082 L .23039 .36838 L p F P
0 g
s
.763 .693 .785 r
.23311 .35822 m .23861 .36021 L p .23039 .36838 L F P
0 g
s
.763 .693 .785 r
.22485 .36543 m .23311 .35822 L p .23039 .36838 L F P
0 g
s
.763 .693 .785 r
.23039 .36838 m .22575 .36679 L .22485 .36543 L p F P
0 g
s
.679 .7 .863 r
.43543 .31752 m .42458 .32195 L .42153 .31763 L p F P
0 g
s
.773 .688 .769 r
.22212 .37604 m .21714 .38082 L .21389 .37568 L p F P
0 g
s
.773 .688 .769 r
.21389 .37568 m .21587 .37379 L .22212 .37604 L p F P
0 g
s
.772 .69 .773 r
.22405 .36615 m .21587 .37379 L .22212 .37604 L p F P
0 g
s
.772 .69 .773 r
.22575 .36679 m .22405 .36615 L p .22212 .37604 L F P
0 g
s
.632 .587 .785 r
.57544 .35776 m .56516 .36063 L .57511 .35701 L closepath p F P
0 g
s
.634 .594 .792 r
.57252 .35132 m .57511 .35701 L .56516 .36063 L p F P
0 g
s
.634 .594 .792 r
.56146 .35445 m .57252 .35132 L p .56516 .36063 L F P
0 g
s
.727 .702 .826 r
.31026 .32432 m .30408 .328 L .31179 .32978 L p F P
0 g
s
.727 .702 .826 r
.31179 .32978 m .31344 .32878 L .31026 .32432 L p F P
0 g
s
.726 .698 .824 r
.29949 .33079 m .30408 .328 L .31179 .32978 L p F P
0 g
s
.805 .631 .666 r
.18866 .45861 m .19497 .46076 L .19211 .4667 L p F P
0 g
s
.803 .638 .678 r
.19497 .46076 m .18866 .45861 L .19191 .45255 L p F P
0 g
s
.262 0 0 r
.38441 .5537 m .38549 .55321 L p .39546 .55466 L F P
0 g
s
.45 0 0 r
.38441 .5537 m .3816 .55309 L .38549 .55321 L closepath p F P
0 g
s
.623 .572 .776 r
.59237 .36859 m .59375 .37192 L .58319 .376 L p F P
0 g
s
.623 .572 .776 r
.58319 .376 m .58126 .37137 L .59237 .36859 L p F P
0 g
s
.583 .449 .664 r
.61087 .46351 m .6103 .46072 L .62098 .45688 L p F P
0 g
s
.589 .463 .677 r
.61949 .45025 m .62098 .45688 L .6103 .46072 L p F P
0 g
s
.379 0 0 r
.42608 .55375 m .42048 .55316 L .42764 .55297 L closepath p F P
0 g
s
.201 0 0 r
.42048 .55316 m .42608 .55375 L .42351 .55436 L p F P
0 g
s
.778 .689 .766 r
.21444 .38351 m .21714 .38082 L .21389 .37568 L p F P
0 g
s
.8 .576 .598 r
.21088 .49748 m .21064 .49742 L .21016 .49148 L p F P
0 g
s
.807 .582 .596 r
.20541 .49003 m .21016 .49148 L .21064 .49742 L p F P
0 g
s
.76 .691 .785 r
.239 .36082 m .2394 .36048 L .23861 .36021 L closepath p F P
0 g
s
.757 .695 .793 r
.24305 .35 m .24943 .35223 L .2394 .36048 L p F P
0 g
s
.757 .695 .793 r
.23575 .35598 m .24305 .35 L p .2394 .36048 L F P
0 g
s
.757 .695 .793 r
.2394 .36048 m .23861 .36021 L .23575 .35598 L p F P
0 g
s
.46 0 0 r
.3816 .55309 m .38441 .5537 L p .37056 .55287 L F P
0 g
s
.46 0 0 r
.37056 .55287 m .37084 .55274 L .3816 .55309 L p F P
0 g
s
.761 .406 .382 r
.26329 .52996 m .26432 .53207 L .26307 .53386 L p F P
0 g
s
.761 .406 .382 r
.25558 .52833 m .26329 .52996 L p .26307 .53386 L F P
0 g
s
.666 .235 .215 r
.31229 .5452 m .31197 .54517 L .31209 .54506 L closepath p F P
0 g
s
.792 .676 .736 r
.19534 .41384 m .19823 .41029 L .19528 .40499 L p F P
0 g
s
.778 .687 .764 r
.20834 .3812 m .21444 .38351 L .20735 .39078 L p F P
0 g
s
.778 .689 .766 r
.21389 .37568 m .20834 .3812 L .21444 .38351 L p F P
0 g
s
.695 .699 .85 r
.37673 .31461 m .37985 .31873 L .37308 .32185 L p F P
0 g
s
.695 .699 .85 r
.36595 .31939 m .37673 .31461 L p .37308 .32185 L F P
0 g
s
.695 .699 .85 r
.37308 .32185 m .36749 .32151 L .36595 .31939 L p F P
0 g
s
.484 .099 .234 r
.52167 .53756 m .53369 .5354 L .53208 .53895 L p F P
0 g
s
.484 .099 .234 r
.52048 .54031 m .52167 .53756 L p .53208 .53895 L F P
0 g
s
.548 .225 .372 r
.53434 .5332 m .53369 .5354 L .52167 .53756 L p F P
0 g
s
.197 0 0 r
.42764 .55297 m .4353 .55264 L p .43714 .55383 L F P
0 g
s
.197 0 0 r
.42608 .55375 m .42764 .55297 L p .43714 .55383 L F P
0 g
s
.508 .115 .23 r
.50781 .54306 m .49694 .54464 L .49562 .54454 L p F P
0 g
s
.501 .096 .205 r
.49694 .54464 m .49544 .54484 L .49562 .54454 L closepath p F P
0 g
s
.717 .703 .836 r
.3242 .32271 m .31344 .32878 L .31026 .32432 L p F P
0 g
s
.679 .686 .849 r
.43846 .32192 m .4399 .32134 L .43817 .32149 L closepath p F P
0 g
s
.678 .68 .845 r
.45103 .3201 m .45234 .32209 L p .43846 .32192 L F P
0 g
s
.678 .68 .845 r
.43846 .32192 m .4399 .32134 L .45103 .3201 L p F P
0 g
s
.604 .107 .045 r
.32453 .54918 m .31874 .54845 L .31229 .5452 L p F P
0 g
s
.544 .01 0 r
.31197 .54517 m .31229 .5452 L .31874 .54845 L p F P
0 g
s
.739 .697 .812 r
.28074 .33634 m .27472 .34048 L .27151 .33578 L p F P
0 g
s
.757 .696 .794 r
.25029 .35252 m .24986 .35188 L .24943 .35223 L closepath p F P
0 g
s
.544 .01 0 r
.30862 .54707 m .31197 .54517 L p .31874 .54845 L F P
0 g
s
.638 .158 .097 r
.30862 .54707 m .30342 .54394 L .31197 .54517 L closepath p F P
0 g
s
.569 .345 .536 r
.58206 .50627 m .58205 .51136 L .57072 .51434 L p F P
0 g
s
.553 .307 .497 r
.57043 .51915 m .57072 .51434 L .58205 .51136 L p F P
0 g
s
.764 .697 .788 r
.23861 .36021 m .23575 .35598 L .23311 .35822 L closepath p F P
0 g
s
.53 .202 .356 r
.54296 .53357 m .53369 .5354 L .53434 .5332 L closepath p F P
0 g
s
.533 .212 .37 r
.54555 .53304 m .54296 .53357 L .53434 .5332 L p F P
0 g
s
.783 .467 .453 r
.24645 .522 m .24735 .52538 L .24685 .52651 L p F P
0 g
s
.783 .467 .453 r
.23909 .52025 m .24645 .522 L p .24685 .52651 L F P
0 g
s
.798 .536 .542 r
.23033 .51338 m .22407 .5117 L .22416 .50657 L p F P
0 g
s
.798 .536 .542 r
.21718 .50468 m .22416 .50657 L .22407 .5117 L p F P
0 g
s
.708 .292 .256 r
.29445 .54271 m .28605 .5413 L .28202 .53736 L p F P
0 g
s
.706 .294 .264 r
.28091 .53718 m .28202 .53736 L .28605 .5413 L p F P
0 g
s
.542 .262 .44 r
.55827 .52638 m .55894 .52192 L .56439 .52062 L p F P
0 g
s
.554 .274 .445 r
.55894 .52192 m .55827 .52638 L .5466 .52895 L p F P
0 g
s
.601 .515 .73 r
.60995 .41632 m .60922 .41403 L .61968 .40985 L p F P
0 g
s
.604 .524 .738 r
.61816 .4053 m .61968 .40985 L .60922 .41403 L p F P
0 g
s
.604 .524 .738 r
.60922 .41403 m .607 .40735 L .61816 .4053 L p F P
0 g
s
.489 0 0 r
.37056 .55287 m .36988 .55269 L .37084 .55274 L closepath p F P
0 g
s
.804 .641 .679 r
.18569 .45036 m .19191 .45255 L .18866 .45861 L p F P
0 g
s
.803 .647 .689 r
.19191 .45255 m .18569 .45036 L .1893 .44419 L p F P
0 g
s
.601 .515 .729 r
.61165 .42169 m .60995 .41632 L .62112 .41438 L p F P
0 g
s
.601 .515 .73 r
.61968 .40985 m .62112 .41438 L .60995 .41632 L p F P
0 g
s
.701 .701 .847 r
.36749 .32151 m .36595 .31939 L .36265 .32098 L closepath p F P
0 g
s
.601 .515 .729 r
.62112 .41438 m .62213 .41755 L .61165 .42169 L p F P
0 g
s
.597 .505 .721 r
.61292 .42591 m .61165 .42169 L .62213 .41755 L p F P
0 g
s
.678 .69 .853 r
.4399 .32134 m .43817 .32149 L .43543 .31752 L p F P
0 g
s
.384 0 0 r
.36988 .55269 m .37056 .55287 L .36729 .55371 L p F P
0 g
s
.384 0 0 r
.36729 .55371 m .3589 .55207 L .36988 .55269 L p F P
0 g
s
.665 .649 .824 r
.49704 .32903 m .49699 .32893 L .49636 .32917 L closepath p F P
0 g
s
.667 .654 .828 r
.49402 .32388 m .49699 .32893 L .49636 .32917 L p F P
0 g
s
.583 .449 .664 r
.62098 .45688 m .62206 .46212 L .61087 .46351 L p F P
0 g
s
.584 .449 .663 r
.6116 .46714 m .61087 .46351 L .62206 .46212 L p F P
0 g
s
.197 0 0 r
.4353 .55264 m .43998 .55302 L .43714 .55383 L p F P
0 g
s
.374 0 0 r
.43998 .55302 m .4353 .55264 L .44115 .55236 L closepath p F P
0 g
s
.782 .682 .755 r
.20612 .39208 m .20735 .39078 L .20477 .38983 L closepath p F P
0 g
s
.778 .687 .764 r
.20288 .3868 m .20834 .3812 L p .20735 .39078 L F P
0 g
s
.778 .687 .764 r
.20735 .39078 m .20477 .38983 L .20288 .3868 L p F P
0 g
s
.758 .699 .795 r
.24662 .34715 m .24305 .35 L .24943 .35223 L p F P
0 g
s
.758 .699 .795 r
.24943 .35223 m .24986 .35188 L .24662 .34715 L p F P
0 g
s
.797 .661 .712 r
.19014 .43121 m .19147 .42929 L .18874 .4283 L closepath p F P
0 g
s
.794 .667 .723 r
.18696 .42485 m .19018 .42049 L p .19147 .42929 L F P
0 g
s
.794 .667 .723 r
.19147 .42929 m .18874 .4283 L .18696 .42485 L p F P
0 g
s
.604 .525 .738 r
.61704 .40193 m .61816 .4053 L .607 .40735 L p F P
0 g
s
.604 .525 .738 r
.607 .40735 m .60659 .40614 L .61704 .40193 L p F P
0 g
s
.706 .294 .264 r
.28605 .5413 m .27796 .54 L .28091 .53718 L p F P
0 g
s
.725 .32 .28 r
.27389 .53586 m .28091 .53718 L .27796 .54 L p F P
0 g
s
.753 .699 .801 r
.26062 .34359 m .24986 .35188 L .24662 .34715 L p F P
0 g
s
.794 .672 .73 r
.18932 .41154 m .19534 .41384 L .19018 .42049 L p F P
0 g
s
.792 .676 .736 r
.19478 .4048 m .18932 .41154 L .19534 .41384 L p F P
0 g
s
.792 .676 .736 r
.19528 .40499 m .19478 .4048 L p .19534 .41384 L F P
0 g
s
.607 .534 .746 r
.61522 .39674 m .61704 .40193 L .60659 .40614 L p F P
0 g
s
.607 .534 .746 r
.60659 .40614 m .60406 .39889 L .61522 .39674 L p F P
0 g
s
.598 .505 .72 r
.61389 .42914 m .61292 .42591 L .6241 .42408 L p F P
0 g
s
.597 .505 .721 r
.62213 .41755 m .6241 .42408 L .61292 .42591 L p F P
0 g
s
.677 .685 .85 r
.45103 .3201 m .44932 .31757 L .4399 .32134 L closepath p F P
0 g
s
.678 .69 .853 r
.4463 .31329 m .44932 .31757 L .4399 .32134 L p F P
0 g
s
.678 .69 .853 r
.43543 .31752 m .4463 .31329 L p .4399 .32134 L F P
0 g
s
.423 0 .047 r
.49296 .54764 m .49544 .54484 L .49694 .54464 L p F P
0 g
s
.661 .647 .825 r
.50794 .32496 m .50864 .3262 L .49704 .32903 L p F P
0 g
s
.661 .647 .825 r
.49704 .32903 m .49699 .32893 L .50794 .32496 L p F P
0 g
s
.786 .684 .752 r
.20091 .39784 m .20612 .39208 L .20477 .38983 L p F P
0 g
s
.559 .337 .535 r
.58205 .51136 m .58206 .50627 L .59323 .5031 L p F P
0 g
s
.572 .368 .566 r
.59297 .49775 m .59323 .5031 L .58206 .50627 L p F P
0 g
s
.662 .655 .832 r
.50794 .32496 m .49699 .32893 L .49402 .32388 L p F P
0 g
s
.624 .573 .777 r
.58987 .36259 m .59237 .36859 L .58126 .37137 L p F P
0 g
s
.624 .573 .777 r
.58126 .37137 m .57931 .36669 L .58987 .36259 L p F P
0 g
s
.595 .495 .711 r
.61389 .42914 m .62439 .42503 L p .61655 .43616 L F P
0 g
s
.595 .495 .711 r
.61655 .43616 m .61591 .43626 L .61389 .42914 L p F P
0 g
s
.598 .505 .72 r
.6241 .42408 m .62439 .42503 L .61389 .42914 L p F P
0 g
s
.674 .673 .84 r
.46366 .31845 m .46623 .32247 L p .45234 .32209 L F P
0 g
s
.674 .673 .84 r
.45234 .32209 m .46025 .31894 L .46366 .31845 L p F P
0 g
s
.676 .68 .846 r
.45234 .32209 m .46025 .31894 L .45103 .3201 L closepath p F P
0 g
s
.572 .402 .613 r
.60293 .48411 m .60279 .483 L .61365 .4794 L p F P
0 g
s
.58 .423 .633 r
.61271 .47337 m .61365 .4794 L .60279 .483 L p F P
0 g
s
.355 0 0 r
.43998 .55302 m .44115 .55236 L .45144 .55173 L p F P
0 g
s
.725 .696 .822 r
.29949 .33079 m .30408 .328 L .29639 .32633 L closepath p F P
0 g
s
.733 .7 .82 r
.29639 .32633 m .29949 .33079 L p .28551 .33311 L F P
0 g
s
.451 .011 .11 r
.50657 .54472 m .49694 .54464 L .50781 .54306 L closepath p F P
0 g
s
.423 0 .047 r
.49694 .54464 m .50657 .54472 L p .49296 .54764 L F P
0 g
s
.641 .607 .799 r
.5446 .34545 m .55562 .34205 L .55854 .34816 L p F P
0 g
s
.642 .61 .802 r
.55466 .34005 m .55562 .34205 L .5446 .34545 L p F P
0 g
s
.642 .61 .802 r
.5446 .34545 m .54375 .34371 L .55466 .34005 L p F P
0 g
s
.46 0 0 r
.38441 .5537 m .38118 .55438 L .37056 .55287 L p F P
0 g
s
.115 0 0 r
.37056 .55287 m .38118 .55438 L .38099 .55439 L p F P
0 g
s
.115 0 0 r
.36729 .55371 m .37056 .55287 L p .38099 .55439 L F P
0 g
s
.801 .662 .709 r
.18713 .43568 m .19014 .43121 L .18874 .4283 L p F P
0 g
s
.698 .702 .85 r
.35205 .32023 m .35248 .32002 L .36265 .32098 L p F P
0 g
s
.703 .709 .853 r
.36282 .31523 m .35248 .32002 L .36265 .32098 L p F P
0 g
s
.703 .709 .853 r
.36265 .32098 m .36595 .31939 L .36282 .31523 L p F P
0 g
s
.607 .534 .747 r
.61417 .39376 m .61522 .39674 L .60406 .39889 L p F P
0 g
s
.607 .534 .747 r
.60406 .39889 m .60374 .398 L .61417 .39376 L p F P
0 g
s
.739 .697 .812 r
.27151 .33578 m .2736 .33436 L .28074 .33634 L p F P
0 g
s
.739 .701 .815 r
.2823 .32855 m .2736 .33436 L .28074 .33634 L p F P
0 g
s
.739 .701 .815 r
.28074 .33634 m .28551 .33311 L .2823 .32855 L p F P
0 g
s
.609 .543 .755 r
.61228 .38861 m .61417 .39376 L .60374 .398 L p F P
0 g
s
.609 .543 .755 r
.60374 .398 m .60113 .39085 L .61228 .38861 L p F P
0 g
s
.649 .621 .808 r
.52774 .33741 m .53874 .33377 L .54167 .33956 L p F P
0 g
s
.65 .625 .812 r
.53797 .33228 m .53874 .33377 L .52774 .33741 L p F P
0 g
s
.65 .625 .812 r
.52774 .33741 m .52684 .33567 L .53797 .33228 L p F P
0 g
s
.804 .65 .691 r
.18317 .44195 m .1893 .44419 L .18569 .45036 L p F P
0 g
s
.803 .655 .7 r
.1893 .44419 m .18317 .44195 L .18713 .43568 L p F P
0 g
s
.787 .5 .503 r
.23033 .51338 m .2311 .51357 L .23171 .51849 L p F P
0 g
s
.785 .499 .503 r
.23909 .52025 m .23171 .51849 L .2311 .51357 L p F P
0 g
s
.634 .595 .793 r
.57048 .34684 m .57252 .35132 L .56146 .35445 L p F P
0 g
s
.634 .595 .793 r
.56146 .35445 m .55977 .35075 L .57048 .34684 L p F P
0 g
s
.523 .206 .372 r
.54555 .53304 m .5466 .52895 L .55827 .52638 L p F P
0 g
s
.204 0 0 r
.3589 .55207 m .36729 .55371 L .36612 .55375 L p F P
0 g
s
.204 0 0 r
.3558 .5519 m .3589 .55207 L p .36612 .55375 L F P
0 g
s
.595 .495 .711 r
.61595 .43639 m .61591 .43626 L .61655 .43616 L closepath p F P
0 g
s
.59 .483 .7 r
.6178 .44341 m .61595 .43639 L .61655 .43616 L p F P
0 g
s
.788 .682 .747 r
.20091 .39784 m .19501 .40453 L .19176 .39906 L p F P
0 g
s
.788 .682 .747 r
.19176 .39906 m .19487 .39552 L .20091 .39784 L p F P
0 g
s
.786 .684 .752 r
.20129 .38847 m .19487 .39552 L .20091 .39784 L p F P
0 g
s
.786 .684 .752 r
.20477 .38983 m .20129 .38847 L p .20091 .39784 L F P
0 g
s
.572 .402 .613 r
.6035 .4888 m .60293 .48411 L .61412 .48316 L p F P
0 g
s
.572 .402 .613 r
.61365 .4794 m .61412 .48316 L .60293 .48411 L p F P
0 g
s
.584 .449 .663 r
.62206 .46212 m .6223 .46333 L .6116 .46714 L p F P
0 g
s
.578 .433 .649 r
.61271 .47337 m .6116 .46714 L .6223 .46333 L p F P
0 g
s
.787 .5 .503 r
.23171 .51849 m .2292 .51788 L .23033 .51338 L p F P
0 g
s
.797 .511 .504 r
.22407 .5117 m .23033 .51338 L .2292 .51788 L p F P
0 g
s
.204 0 0 r
.35342 .55262 m .3558 .5519 L p .36612 .55375 L F P
0 g
s
.443 0 0 r
.35342 .55262 m .34837 .55132 L .3558 .5519 L closepath p F P
0 g
s
.671 .667 .838 r
.46623 .32247 m .47713 .31824 L .48012 .32306 L p F P
0 g
s
.671 .673 .843 r
.4759 .31633 m .47713 .31824 L .46623 .32247 L p F P
0 g
s
.671 .673 .843 r
.46623 .32247 m .46366 .31845 L .4759 .31633 L p F P
0 g
s
.644 .616 .808 r
.5527 .33613 m .55466 .34005 L .54375 .34371 L p F P
0 g
s
.644 .616 .808 r
.54375 .34371 m .54167 .33956 L .5527 .33613 L p F P
0 g
s
.77 .695 .78 r
.22575 .36679 m .22485 .36543 L .22405 .36615 L closepath p F P
0 g
s
.751 .698 .802 r
.26077 .34364 m .2607 .34354 L .26062 .34359 L closepath p F P
0 g
s
.59 .483 .7 r
.61655 .43616 m .62712 .4348 L p .6178 .44341 L F P
0 g
s
.59 .483 .701 r
.62712 .4348 m .61655 .43616 L .62645 .43228 L closepath p F P
0 g
s
.595 .495 .711 r
.62439 .42503 m .62645 .43228 L .61655 .43616 L p F P
0 g
s
.807 .596 .617 r
.20541 .49003 m .19885 .48799 L .20047 .48242 L p F P
0 g
s
.808 .598 .618 r
.19397 .48034 m .20047 .48242 L .19885 .48799 L p F P
0 g
s
.806 .609 .635 r
.20047 .48242 m .19397 .48034 L .19604 .47464 L p F P
0 g
s
.423 0 .028 r
.49296 .54764 m .49053 .54794 L .48172 .54781 L p F P
0 g
s
.405 0 0 r
.49053 .54794 m .4803 .54913 L .48172 .54781 L closepath p F P
0 g
s
.753 .699 .801 r
.24662 .34715 m .25413 .3414 L .26062 .34359 L p F P
0 g
s
.752 .701 .804 r
.25746 .3389 m .25413 .3414 L .26062 .34359 L p F P
0 g
s
.752 .701 .804 r
.26062 .34359 m .2607 .34354 L .25746 .3389 L p F P
0 g
s
.746 .702 .81 r
.27151 .33578 m .2607 .34354 L .25746 .3389 L p F P
0 g
s
.784 .689 .759 r
.20477 .38983 m .20288 .3868 L .20129 .38847 L closepath p F P
0 g
s
.626 .581 .784 r
.58945 .36163 m .58987 .36259 L .57931 .36669 L p F P
0 g
s
.626 .581 .784 r
.57931 .36669 m .57835 .36446 L .58945 .36163 L p F P
0 g
s
.807 .611 .637 r
.1896 .47253 m .19604 .47464 L .19397 .48034 L p F P
0 g
s
.805 .621 .652 r
.19604 .47464 m .1896 .47253 L .19211 .4667 L p F P
0 g
s
.379 0 0 r
.4539 .55188 m .45144 .55173 L .45444 .55153 L closepath p F P
0 g
s
.355 0 0 r
.45144 .55173 m .4539 .55188 L p .43998 .55302 L F P
0 g
s
.562 .361 .566 r
.59323 .5031 m .59297 .49775 L .60399 .49438 L p F P
0 g
s
.572 .387 .591 r
.6035 .4888 m .60399 .49438 L .59297 .49775 L p F P
0 g
s
.807 .582 .596 r
.21064 .49742 m .20426 .49547 L .20541 .49003 L p F P
0 g
s
.809 .583 .597 r
.19885 .48799 m .20541 .49003 L .20426 .49547 L p F P
0 g
s
.801 .662 .709 r
.18874 .4283 m .18539 .42702 L p .18713 .43568 L F P
0 g
s
.8 .669 .719 r
.18874 .4283 m .18696 .42485 L .18539 .42702 L closepath p F P
0 g
s
.609 .102 .019 r
.30342 .54394 m .30862 .54707 L .30821 .54721 L p F P
0 g
s
.609 .102 .019 r
.29526 .54284 m .30342 .54394 L p .30821 .54721 L F P
0 g
s
.609 .543 .755 r
.61108 .38533 m .61228 .38861 L .60113 .39085 L p F P
0 g
s
.609 .543 .755 r
.60113 .39085 m .60067 .3896 L .61108 .38533 L p F P
0 g
s
.722 .699 .828 r
.30706 .31993 m .31026 .32432 L .30408 .328 L p F P
0 g
s
.722 .699 .828 r
.2963 .3262 m .30706 .31993 L p .30408 .328 L F P
0 g
s
.722 .699 .828 r
.30408 .328 m .29639 .32633 L .2963 .3262 L p F P
0 g
s
.733 .7 .82 r
.28551 .33311 m .29618 .32627 L .29639 .32633 L p F P
0 g
s
.732 .704 .824 r
.29618 .32627 m .28551 .33311 L .2823 .32855 L p F P
0 g
s
.651 .631 .817 r
.53581 .3282 m .53797 .33228 L .52684 .33567 L p F P
0 g
s
.651 .631 .817 r
.52684 .33567 m .52481 .33185 L .53581 .3282 L p F P
0 g
s
.744 .382 .367 r
.27389 .53586 m .26576 .53436 L .26432 .53207 L p F P
0 g
s
.745 .382 .366 r
.26576 .53436 m .26307 .53386 L .26432 .53207 L closepath p F P
0 g
s
.797 .668 .721 r
.19018 .42049 m .18696 .42485 L .18376 .41868 L p F P
0 g
s
.797 .668 .721 r
.18376 .41868 m .1841 .41821 L .19018 .42049 L p F P
0 g
s
.794 .672 .73 r
.19018 .42049 m .1841 .41821 L .18932 .41154 L p F P
0 g
s
.262 0 0 r
.39546 .55466 m .39401 .55464 L .38441 .5537 L p F P
0 g
s
.264 0 0 r
.39401 .55464 m .38441 .5537 L .38118 .55438 L p F P
0 g
s
.359 0 0 r
.4539 .55188 m .45444 .55153 L .46749 .55046 L p F P
0 g
s
.47 0 .055 r
.46781 .55022 m .46749 .55046 L .45444 .55153 L p F P
0 g
s
.612 .552 .763 r
.60936 .38082 m .61108 .38533 L .60067 .3896 L p F P
0 g
s
.612 .552 .763 r
.60067 .3896 m .5982 .38316 L .60936 .38082 L p F P
0 g
s
.807 .623 .654 r
.18575 .46456 m .19211 .4667 L .1896 .47253 L p F P
0 g
s
.805 .631 .666 r
.19211 .4667 m .18575 .46456 L .18866 .45861 L p F P
0 g
s
.688 .716 .871 r
.37673 .31461 m .36595 .31939 L .36282 .31523 L p F P
0 g
s
.79 .681 .744 r
.19528 .40499 m .19501 .40453 L .19478 .4048 L closepath p F P
0 g
s
.698 .702 .85 r
.35205 .32023 m .35248 .32002 L .35185 .31996 L closepath p F P
0 g
s
.705 .706 .848 r
.35185 .31996 m .35205 .32023 L p .33813 .32135 L F P
0 g
s
.656 .637 .819 r
.51089 .33026 m .52186 .32642 L .52481 .33185 L p F P
0 g
s
.657 .641 .823 r
.52002 .32308 m .52186 .32642 L .51089 .33026 L p F P
0 g
s
.657 .641 .823 r
.51089 .33026 m .50864 .3262 L .52002 .32308 L p F P
0 g
s
.761 .406 .382 r
.26307 .53386 m .25794 .53276 L .25558 .52833 L p F P
0 g
s
.759 .399 .373 r
.2478 .52671 m .25558 .52833 L .25794 .53276 L p F P
0 g
s
.768 .448 .445 r
.25558 .52833 m .2478 .52671 L .24735 .52538 L p F P
0 g
s
.798 .557 .573 r
.21062 .49954 m .21088 .49748 L p .21718 .50468 L F P
0 g
s
.801 .559 .572 r
.21062 .49954 m .21088 .49748 L .21064 .49742 L closepath p F P
0 g
s
.545 .272 .452 r
.57023 .52069 m .56439 .52062 L .57043 .51915 L closepath p F P
0 g
s
.542 .262 .44 r
.56439 .52062 m .57023 .52069 L p .55827 .52638 L F P
0 g
s
.683 .717 .875 r
.39064 .31413 m .37985 .31873 L .37673 .31461 L p F P
0 g
s
.676 .684 .85 r
.46025 .31894 m .45103 .3201 L .44932 .31757 L p F P
0 g
s
.807 .564 .572 r
.21064 .49742 m .20426 .49547 L p .21021 .50278 L F P
0 g
s
.807 .564 .572 r
.21021 .50278 m .21062 .49954 L .21064 .49742 L p F P
0 g
s
.586 .472 .69 r
.6178 .44341 m .62832 .43933 L p .62784 .44704 L F P
0 g
s
.586 .472 .69 r
.62784 .44704 m .61895 .44807 L .6178 .44341 L p F P
0 g
s
.59 .483 .7 r
.62712 .4348 m .62832 .43933 L .6178 .44341 L p F P
0 g
s
.696 .705 .855 r
.35967 .31124 m .36282 .31523 L .35248 .32002 L p F P
0 g
s
.696 .705 .855 r
.3489 .31603 m .35967 .31124 L p .35248 .32002 L F P
0 g
s
.696 .705 .855 r
.35248 .32002 m .35185 .31996 L .3489 .31603 L p F P
0 g
s
.804 .658 .702 r
.1811 .4334 m .18713 .43568 L .18317 .44195 L p F P
0 g
s
.801 .662 .709 r
.18539 .42702 m .1811 .4334 L .18713 .43568 L p F P
0 g
s
.792 .683 .745 r
.19478 .4048 m .19501 .40453 L .19176 .39906 L p F P
0 g
s
.626 .582 .785 r
.58945 .36163 m .57835 .36446 L .57544 .35776 L p F P
0 g
s
.794 .679 .737 r
.18889 .40244 m .19478 .4048 L .18932 .41154 L p F P
0 g
s
.792 .683 .745 r
.19176 .39906 m .18889 .40244 L .19478 .4048 L p F P
0 g
s
.705 .706 .848 r
.33813 .32135 m .34356 .31864 L .35185 .31996 L p F P
0 g
s
.704 .708 .851 r
.35185 .31996 m .3489 .31603 L .34356 .31864 L closepath p F P
0 g
s
.304 0 0 r
.34837 .55132 m .35342 .55262 L .35093 .55282 L p F P
0 g
s
.304 0 0 r
.34039 .55074 m .34837 .55132 L p .35093 .55282 L F P
0 g
s
.684 .706 .864 r
.39374 .31823 m .40455 .31376 L .40764 .31786 L p F P
0 g
s
.68 .717 .877 r
.40455 .31376 m .39374 .31823 L .39064 .31413 L p F P
0 g
s
.704 .701 .844 r
.33813 .32135 m .34356 .31864 L .3354 .31759 L closepath p F P
0 g
s
.712 .705 .841 r
.3354 .31759 m .33813 .32135 L p .3242 .32271 L F P
0 g
s
.725 .32 .28 r
.27796 .54 m .27751 .53992 L .27389 .53586 L p F P
0 g
s
.722 .304 .254 r
.26576 .53436 m .27389 .53586 L .27751 .53992 L p F P
0 g
s
.636 .602 .799 r
.56961 .34499 m .57048 .34684 L .55977 .35075 L p F P
0 g
s
.636 .602 .799 r
.55977 .35075 m .55854 .34816 L .56961 .34499 L p F P
0 g
s
.771 .697 .781 r
.22159 .36057 m .21799 .36382 L .22405 .36615 L p F P
0 g
s
.771 .697 .781 r
.22405 .36615 m .22485 .36543 L .22159 .36057 L p F P
0 g
s
.77 .694 .779 r
.21799 .36382 m .22405 .36615 L .21587 .37379 L p F P
0 g
s
.767 .697 .785 r
.23311 .35822 m .22485 .36543 L .22159 .36057 L p F P
0 g
s
.667 .668 .841 r
.49105 .31895 m .48012 .32306 L .47713 .31824 L p F P
0 g
s
.667 .661 .835 r
.48012 .32306 m .49105 .31895 L .49402 .32388 L p F P
0 g
s
.774 .69 .77 r
.21389 .37568 m .21587 .37379 L .2117 .37225 L closepath p F P
0 g
s
.77 .694 .779 r
.21063 .37063 m .21799 .36382 L p .21587 .37379 L F P
0 g
s
.77 .694 .779 r
.21587 .37379 m .2117 .37225 L .21063 .37063 L p F P
0 g
s
.806 .634 .668 r
.18239 .45643 m .18866 .45861 L .18575 .46456 L p F P
0 g
s
.804 .641 .679 r
.18866 .45861 m .18239 .45643 L .18569 .45036 L p F P
0 g
s
.779 .691 .767 r
.20834 .3812 m .21389 .37568 L .2117 .37225 L p F P
0 g
s
.681 .704 .864 r
.40764 .31786 m .41846 .31349 L .42153 .31763 L p F P
0 g
s
.677 .715 .878 r
.41846 .31349 m .40764 .31786 L .40455 .31376 L p F P
0 g
s
.783 .467 .453 r
.24685 .52651 m .24043 .52496 L .23909 .52025 L p F P
0 g
s
.782 .464 .449 r
.23171 .51849 m .23909 .52025 L .24043 .52496 L p F P
0 g
s
.55 .028 0 r
.33803 .55051 m .32822 .54953 L .3258 .54859 L p F P
0 g
s
.551 .032 0 r
.32822 .54953 m .32453 .54918 L .3258 .54859 L closepath p F P
0 g
s
.767 .697 .785 r
.22159 .36057 m .22691 .35593 L .23311 .35822 L p F P
0 g
s
.765 .699 .789 r
.2325 .35119 m .22691 .35593 L .23311 .35822 L p F P
0 g
s
.765 .699 .789 r
.23311 .35822 m .23575 .35598 L .2325 .35119 L p F P
0 g
s
.404 0 0 r
.4803 .54913 m .46951 .55027 L .46781 .55022 L p F P
0 g
s
.386 0 0 r
.46951 .55027 m .46749 .55046 L .46781 .55022 L closepath p F P
0 g
s
.217 0 0 r
.40705 .55465 m .39546 .55466 L .39829 .5541 L closepath p F P
0 g
s
.223 0 0 r
.40962 .55464 m .40705 .55465 L .39829 .5541 L p F P
0 g
s
.712 .705 .841 r
.3242 .32271 m .33427 .31738 L .3354 .31759 L p F P
0 g
s
.709 .71 .849 r
.33427 .31738 m .3242 .32271 L .32102 .31833 L p F P
0 g
s
.717 .703 .836 r
.31026 .32432 m .32102 .31833 L .3242 .32271 L p F P
0 g
s
.798 .536 .542 r
.22407 .5117 m .21708 .50981 L .21718 .50468 L p F P
0 g
s
.799 .536 .541 r
.21059 .50289 m .21718 .50468 L .21708 .50981 L p F P
0 g
s
.798 .557 .573 r
.21718 .50468 m .21059 .50289 L .21062 .49954 L p F P
0 g
s
.76 .698 .793 r
.24305 .35 m .23575 .35598 L .2325 .35119 L p F P
0 g
s
.781 .689 .763 r
.20834 .3812 m .20288 .3868 L .19961 .38163 L p F P
0 g
s
.781 .689 .763 r
.19961 .38163 m .20231 .37887 L .20834 .3812 L p F P
0 g
s
.779 .691 .767 r
.20975 .37148 m .20231 .37887 L .20834 .3812 L p F P
0 g
s
.779 .691 .767 r
.2117 .37225 m .20975 .37148 L p .20834 .3812 L F P
0 g
s
.612 .552 .763 r
.60774 .37661 m .60936 .38082 L .5982 .38316 L p F P
0 g
s
.612 .552 .763 r
.5982 .38316 m .59734 .38091 L .60774 .37661 L p F P
0 g
s
.8 .67 .719 r
.18539 .42702 m .18696 .42485 L .18376 .41868 L p F P
0 g
s
.679 .7 .863 r
.42153 .31763 m .43238 .31333 L .43543 .31752 L p F P
0 g
s
.675 .712 .876 r
.43238 .31333 m .42153 .31763 L .41846 .31349 L p F P
0 g
s
.482 .106 .249 r
.53208 .53895 m .53369 .5354 L .54296 .53357 L p F P
0 g
s
.586 .472 .689 r
.61949 .45025 m .61895 .44807 L .62784 .44704 L closepath p F P
0 g
s
.387 0 .016 r
.50781 .54306 m .52004 .54112 L .51767 .54397 L p F P
0 g
s
.387 0 .016 r
.50657 .54472 m .50781 .54306 L p .51767 .54397 L F P
0 g
s
.51 .128 .251 r
.52048 .54031 m .52004 .54112 L .50781 .54306 L p F P
0 g
s
.304 0 0 r
.33959 .55102 m .34039 .55074 L p .35093 .55282 L F P
0 g
s
.505 0 0 r
.33959 .55102 m .33803 .55051 L .34039 .55074 L closepath p F P
0 g
s
.77 .449 .444 r
.2478 .52671 m .24685 .52651 L .24735 .52538 L closepath p F P
0 g
s
.644 .619 .81 r
.5527 .33613 m .54167 .33956 L .53874 .33377 L p F P
0 g
s
.739 .697 .812 r
.27151 .33578 m .2736 .33436 L .26977 .33328 L closepath p F P
0 g
s
.746 .702 .81 r
.26977 .33328 m .27151 .33578 L p .25746 .3389 L F P
0 g
s
.201 0 0 r
.42351 .55436 m .42091 .55442 L .41217 .55411 L p F P
0 g
s
.188 0 0 r
.42091 .55442 m .40962 .55464 L .41217 .55411 L closepath p F P
0 g
s
.806 .644 .681 r
.17951 .44814 m .18569 .45036 L .18239 .45643 L p F P
0 g
s
.804 .65 .691 r
.18569 .45036 m .17951 .44814 L .18317 .44195 L p F P
0 g
s
.615 .561 .77 r
.60643 .37333 m .60774 .37661 L .59734 .38091 L p F P
0 g
s
.615 .561 .77 r
.59734 .38091 m .59528 .37576 L .60643 .37333 L p F P
0 g
s
.636 .604 .801 r
.56961 .34499 m .55854 .34816 L .55562 .34205 L p F P
0 g
s
.359 0 0 r
.46749 .55046 m .46476 .55176 L .4539 .55188 L p F P
0 g
s
.022 0 0 r
.4539 .55188 m .46476 .55176 L .46361 .55197 L p F P
0 g
s
.022 0 0 r
.45082 .553 m .4539 .55188 L p .46361 .55197 L F P
0 g
s
.355 0 0 r
.4539 .55188 m .45082 .553 L .43998 .55302 L p F P
0 g
s
.785 .691 .76 r
.20129 .38847 m .20288 .3868 L .19961 .38163 L p F P
0 g
s
.717 .709 .842 r
.32102 .31833 m .31026 .32432 L .30706 .31993 L p F P
0 g
s
.76 .698 .793 r
.2325 .35119 m .23672 .34775 L .24305 .35 L p F P
0 g
s
.759 .7 .797 r
.24337 .34245 m .23672 .34775 L .24305 .35 L p F P
0 g
s
.759 .7 .797 r
.24305 .35 m .24662 .34715 L .24337 .34245 L p F P
0 g
s
.609 .102 .019 r
.29493 .54307 m .29526 .54284 L p .30821 .54721 L F P
0 g
s
.677 .226 .172 r
.29493 .54307 m .29445 .54271 L .29526 .54284 L closepath p F P
0 g
s
.806 .564 .572 r
.21059 .50289 m .21062 .49954 L .21021 .50278 L closepath p F P
0 g
s
.581 .458 .677 r
.62098 .45688 m .61949 .45025 L .62784 .44704 L p F P
0 g
s
.674 .706 .872 r
.4463 .31329 m .43543 .31752 L .43238 .31333 L p F P
0 g
s
.571 .417 .633 r
.61365 .4794 m .61271 .47337 L .62342 .46956 L p F P
0 g
s
.578 .433 .649 r
.6223 .46333 m .62342 .46956 L .61271 .47337 L p F P
0 g
s
.572 .402 .613 r
.61412 .48316 m .61437 .48522 L .6035 .4888 L p F P
0 g
s
.563 .38 .591 r
.60399 .49438 m .6035 .4888 L .61437 .48522 L p F P
0 g
s
.407 0 0 r
.33803 .55051 m .33959 .55102 L .33625 .55154 L p F P
0 g
s
.407 0 0 r
.33625 .55154 m .32822 .54953 L .33803 .55051 L p F P
0 g
s
.786 .687 .754 r
.1954 .38609 m .20129 .38847 L .19487 .39552 L p F P
0 g
s
.785 .691 .76 r
.19961 .38163 m .1954 .38609 L .20129 .38847 L p F P
0 g
s
.803 .666 .711 r
.17947 .4247 m .18539 .42702 L .1811 .4334 L p F P
0 g
s
.8 .67 .719 r
.18376 .41868 m .17947 .4247 L .18539 .42702 L p F P
0 g
s
.074 0 0 r
.46749 .55046 m .46951 .55027 L p .47653 .55071 L F P
0 g
s
.074 0 0 r
.46476 .55176 m .46749 .55046 L p .47653 .55071 L F P
0 g
s
.197 0 0 r
.43714 .55383 m .43582 .55389 L .42608 .55375 L p F P
0 g
s
.176 0 0 r
.43582 .55389 m .42351 .55436 L .42608 .55375 L closepath p F P
0 g
s
.184 0 0 r
.43714 .55383 m .43998 .55302 L .45082 .553 L p F P
0 g
s
.662 .655 .832 r
.49402 .32388 m .50498 .31991 L .50794 .32496 L p F P
0 g
s
.663 .661 .837 r
.50498 .31991 m .49402 .32388 L .49105 .31895 L p F P
0 g
s
.648 .162 .085 r
.29445 .54271 m .29493 .54307 L .29143 .54473 L p F P
0 g
s
.648 .162 .085 r
.29143 .54473 m .28605 .5413 L .29445 .54271 L p F P
0 g
s
.795 .676 .733 r
.18337 .40921 m .18932 .41154 L .1841 .41821 L p F P
0 g
s
.794 .679 .737 r
.18932 .41154 m .18337 .40921 L .18889 .40244 L p F P
0 g
s
.674 .678 .846 r
.46366 .31845 m .46323 .31778 L .46025 .31894 L closepath p F P
0 g
s
.676 .684 .85 r
.46022 .3134 m .46323 .31778 L .46025 .31894 L p F P
0 g
s
.676 .684 .85 r
.44932 .31757 m .46022 .3134 L p .46025 .31894 L F P
0 g
s
.735 .701 .818 r
.27907 .32404 m .2823 .32855 L .2736 .33436 L p F P
0 g
s
.735 .701 .818 r
.26828 .33119 m .27907 .32404 L p .2736 .33436 L F P
0 g
s
.735 .701 .818 r
.2736 .33436 m .26977 .33328 L .26828 .33119 L p F P
0 g
s
.753 .701 .802 r
.25413 .3414 m .24662 .34715 L .24337 .34245 L p F P
0 g
s
.652 .635 .82 r
.53581 .3282 m .52481 .33185 L .52186 .32642 L p F P
0 g
s
.797 .511 .504 r
.2292 .51788 m .2246 .51665 L .22407 .5117 L p F P
0 g
s
.798 .511 .502 r
.21708 .50981 m .22407 .5117 L .2246 .51665 L p F P
0 g
s
.295 0 0 r
.47871 .55008 m .46951 .55027 L .4803 .54913 L closepath p F P
0 g
s
.074 0 0 r
.46951 .55027 m .47871 .55008 L .47653 .55071 L p F P
0 g
s
.702 .704 .849 r
.34573 .31196 m .3489 .31603 L .34356 .31864 L p F P
0 g
s
.702 .704 .849 r
.33497 .31701 m .34573 .31196 L p .34356 .31864 L F P
0 g
s
.702 .704 .849 r
.34356 .31864 m .3354 .31759 L .33497 .31701 L p F P
0 g
s
.672 .7 .867 r
.46022 .3134 m .44932 .31757 L .4463 .31329 L p F P
0 g
s
.731 .702 .823 r
.29639 .32633 m .2963 .3262 L .29618 .32627 L closepath p F P
0 g
s
.626 .584 .787 r
.58563 .35285 m .58654 .35493 L .57544 .35776 L p F P
0 g
s
.626 .584 .787 r
.57544 .35776 m .57511 .35701 L .58563 .35285 L p F P
0 g
s
.626 .582 .785 r
.57544 .35776 m .58654 .35493 L .58945 .36163 L p F P
0 g
s
.732 .704 .824 r
.2823 .32855 m .2891 .32426 L .29618 .32627 L p F P
0 g
s
.733 .706 .826 r
.29308 .3218 m .2891 .32426 L .29618 .32627 L p F P
0 g
s
.733 .706 .826 r
.29618 .32627 m .2963 .3262 L .29308 .3218 L p F P
0 g
s
.722 .707 .836 r
.30706 .31993 m .2963 .3262 L .29308 .3218 L p F P
0 g
s
.612 .113 .042 r
.30054 .54605 m .29493 .54307 L .29143 .54473 L p F P
0 g
s
.609 .102 .019 r
.30821 .54721 m .30054 .54605 L .29493 .54307 L p F P
0 g
s
.533 .262 .449 r
.57023 .52069 m .57043 .51915 L .58177 .51618 L p F P
0 g
s
.553 .307 .497 r
.58205 .51136 m .58177 .51618 L .57043 .51915 L p F P
0 g
s
.657 .646 .827 r
.51892 .32114 m .52002 .32308 L .50864 .3262 L p F P
0 g
s
.657 .646 .827 r
.50864 .3262 m .50794 .32496 L .51892 .32114 L p F P
0 g
s
.805 .653 .694 r
.17709 .43969 m .18317 .44195 L .17951 .44814 L p F P
0 g
s
.804 .658 .702 r
.18317 .44195 m .17709 .43969 L .1811 .4334 L p F P
0 g
s
.67 .676 .847 r
.47414 .31367 m .4759 .31633 L .46366 .31845 L p F P
0 g
s
.67 .676 .847 r
.46366 .31845 m .46323 .31778 L .47414 .31367 L p F P
0 g
s
.615 .561 .771 r
.60414 .36759 m .60643 .37333 L .59528 .37576 L p F P
0 g
s
.615 .561 .771 r
.59528 .37576 m .59375 .37192 L .60414 .36759 L p F P
0 g
s
.542 .298 .494 r
.58177 .51618 m .58205 .51136 L .59324 .50819 L p F P
0 g
s
.559 .337 .535 r
.59323 .5031 m .59324 .50819 L .58205 .51136 L p F P
0 g
s
.628 .591 .793 r
.58363 .34843 m .58563 .35285 L .57511 .35701 L p F P
0 g
s
.628 .591 .793 r
.57511 .35701 m .57252 .35132 L .58363 .34843 L p F P
0 g
s
.484 .099 .234 r
.53208 .53895 m .52505 .54024 L .52048 .54031 L p F P
0 g
s
.474 .076 .204 r
.52505 .54024 m .52004 .54112 L .52048 .54031 L closepath p F P
0 g
s
.789 .683 .748 r
.19487 .39552 m .19176 .39906 L .18851 .39362 L p F P
0 g
s
.789 .683 .748 r
.18851 .39362 m .18889 .39318 L .19487 .39552 L p F P
0 g
s
.786 .687 .754 r
.19487 .39552 m .18889 .39318 L .1954 .38609 L p F P
0 g
s
.759 .399 .373 r
.25794 .53276 m .25025 .53111 L .2478 .52671 L p F P
0 g
s
.758 .399 .374 r
.24685 .52651 m .2478 .52671 L .25025 .53111 L p F P
0 g
s
.808 .598 .618 r
.19885 .48799 m .19231 .48593 L .19397 .48034 L p F P
0 g
s
.809 .6 .619 r
.18749 .47825 m .19397 .48034 L .19231 .48593 L p F P
0 g
s
.807 .611 .637 r
.19397 .48034 m .18749 .47825 L .1896 .47253 L p F P
0 g
s
.722 .304 .254 r
.27751 .53992 m .26956 .53836 L .26576 .53436 L p F P
0 g
s
.705 .268 .211 r
.26307 .53386 m .26576 .53436 L .26956 .53836 L p F P
0 g
s
.753 .701 .802 r
.24337 .34245 m .24766 .33918 L .25413 .3414 L p F P
0 g
s
.752 .703 .805 r
.25421 .3343 m .24766 .33918 L .25413 .3414 L p F P
0 g
s
.752 .703 .805 r
.25413 .3414 m .25746 .3389 L .25421 .3343 L p F P
0 g
s
.777 .696 .774 r
.2117 .37225 m .21063 .37063 L .20975 .37148 L closepath p F P
0 g
s
.809 .585 .598 r
.19231 .48593 m .19885 .48799 L .19767 .49343 L p F P
0 g
s
.809 .583 .597 r
.20426 .49547 m .19767 .49343 L .19885 .48799 L p F P
0 g
s
.809 .614 .638 r
.18566 .47122 m .1896 .47253 L .18749 .47825 L p F P
0 g
s
.807 .623 .654 r
.18455 .46736 m .18575 .46456 L p .1896 .47253 L F P
0 g
s
.807 .623 .654 r
.1896 .47253 m .18566 .47122 L .18455 .46736 L p F P
0 g
s
.758 .399 .374 r
.25025 .53111 m .24443 .52987 L .24685 .52651 L p F P
0 g
s
.773 .419 .384 r
.24043 .52496 m .24685 .52651 L .24443 .52987 L p F P
0 g
s
.67 .692 .862 r
.47414 .31367 m .46323 .31778 L .46022 .3134 L p F P
0 g
s
.304 0 0 r
.34844 .55261 m .33959 .55102 L p .35092 .55282 L F P
0 g
s
.326 0 0 r
.34844 .55261 m .33959 .55102 L .33625 .55154 L p F P
0 g
s
.326 0 0 r
.33625 .55154 m .33823 .55175 L .34844 .55261 L p F P
0 g
s
.078 .629 .825 r
.34685 .55209 m .33828 .55175 L p .34844 .55261 L F P
0 g
s
.078 .629 .825 r
.33828 .55175 m .33823 .55175 L .34844 .55261 L p F P
0 g
s
.304 0 0 r
.35093 .55282 m .34844 .55261 L p .35092 .55282 L F P
0 g
s
.509 .191 .364 r
.55722 .53046 m .55827 .52638 L .56979 .52362 L p F P
0 g
s
.542 .262 .44 r
.57023 .52069 m .56979 .52362 L .55827 .52638 L p F P
0 g
s
.523 .206 .372 r
.55827 .52638 m .55722 .53046 L .54555 .53304 L p F P
0 g
s
.238 0 0 r
.32822 .54953 m .33625 .55154 L .33531 .55151 L p F P
0 g
s
.238 0 0 r
.32453 .54918 m .32822 .54953 L p .33531 .55151 L F P
0 g
s
.658 .654 .834 r
.51892 .32114 m .50794 .32496 L .50498 .31991 L p F P
0 g
s
.793 .685 .745 r
.18889 .40244 m .19176 .39906 L .18851 .39362 L p F P
0 g
s
.576 .445 .665 r
.62098 .45688 m .63153 .45284 L p .62611 .46189 L F P
0 g
s
.576 .445 .665 r
.62611 .46189 m .62206 .46212 L .62098 .45688 L p F P
0 g
s
.581 .458 .677 r
.63017 .44685 m .63153 .45284 L .62098 .45688 L p F P
0 g
s
.581 .458 .677 r
.62784 .44704 m .63017 .44685 L p .62098 .45688 L F P
0 g
s
.807 .564 .572 r
.20426 .49547 m .20359 .50076 L .21021 .50278 L p F P
0 g
s
.81 .567 .572 r
.19767 .49343 m .20426 .49547 L .20359 .50076 L p F P
0 g
s
.746 .702 .81 r
.25746 .3389 m .26671 .33228 L .26977 .33328 L p F P
0 g
s
.746 .704 .812 r
.26671 .33228 m .25746 .3389 L .25421 .3343 L p F P
0 g
s
.81 .625 .653 r
.18455 .46736 m .18575 .46456 L .18351 .46379 L closepath p F P
0 g
s
.806 .634 .668 r
.18158 .4581 m .18239 .45643 L p .18575 .46456 L F P
0 g
s
.806 .634 .668 r
.18575 .46456 m .18351 .46379 L .18158 .4581 L p F P
0 g
s
.618 .569 .778 r
.60352 .36609 m .60414 .36759 L .59375 .37192 L p F P
0 g
s
.618 .569 .778 r
.59375 .37192 m .59237 .36859 L .60352 .36609 L p F P
0 g
s
.799 .671 .722 r
.18376 .41868 m .1841 .41821 L .18336 .41793 L closepath p F P
0 g
s
.795 .676 .733 r
.18052 .41285 m .18337 .40921 L p .1841 .41821 L F P
0 g
s
.795 .676 .733 r
.1841 .41821 m .18336 .41793 L .18052 .41285 L p F P
0 g
s
.744 .703 .813 r
.26977 .33328 m .26828 .33119 L .26671 .33228 L closepath p F P
0 g
s
.549 .329 .534 r
.59324 .50819 m .59323 .5031 L .60427 .49973 L p F P
0 g
s
.562 .361 .566 r
.60399 .49438 m .60427 .49973 L .59323 .5031 L p F P
0 g
s
.782 .464 .45 r
.2292 .51788 m .23171 .51849 L .23309 .52319 L p F P
0 g
s
.782 .464 .449 r
.24043 .52496 m .23309 .52319 L .23171 .51849 L p F P
0 g
s
.803 .672 .719 r
.17947 .4247 m .18376 .41868 L .18336 .41793 L p F P
0 g
s
.705 .268 .211 r
.26061 .53607 m .26307 .53386 L p .26956 .53836 L F P
0 g
s
.74 .337 .287 r
.26061 .53607 m .25794 .53276 L .26307 .53386 L closepath p F P
0 g
s
.73 .705 .827 r
.2891 .32426 m .2823 .32855 L .27907 .32404 L p F P
0 g
s
.799 .536 .541 r
.2101 .50706 m .21059 .50289 L p .21708 .50981 L F P
0 g
s
.807 .545 .542 r
.2101 .50706 m .21021 .50278 L .21059 .50289 L closepath p F P
0 g
s
.804 .662 .705 r
.17513 .43109 m .1811 .4334 L .17709 .43969 L p F P
0 g
s
.803 .666 .711 r
.1811 .4334 m .17513 .43109 L .17947 .4247 L p F P
0 g
s
.71 .706 .844 r
.3354 .31759 m .33497 .31701 L .33427 .31738 L closepath p F P
0 g
s
.238 0 0 r
.32241 .54969 m .32453 .54918 L p .33531 .55151 L F P
0 g
s
.485 0 0 r
.32241 .54969 m .31874 .54845 L .32453 .54918 L closepath p F P
0 g
s
.803 .672 .719 r
.18336 .41793 m .17826 .41585 L p .17947 .4247 L F P
0 g
s
.801 .678 .729 r
.18336 .41793 m .18052 .41285 L .17826 .41585 L closepath p F P
0 g
s
.278 0 0 r
.47871 .55008 m .4803 .54913 L .49053 .54794 L p F P
0 g
s
.795 .682 .74 r
.18306 .40005 m .18889 .40244 L .18337 .40921 L p F P
0 g
s
.793 .685 .745 r
.18851 .39362 m .18306 .40005 L .18889 .40244 L p F P
0 g
s
.772 .699 .782 r
.21831 .35574 m .21198 .36146 L .21799 .36382 L p F P
0 g
s
.772 .699 .782 r
.21799 .36382 m .22159 .36057 L .21831 .35574 L p F P
0 g
s
.774 .697 .778 r
.21799 .36382 m .21063 .37063 L .20735 .36575 L p F P
0 g
s
.774 .697 .778 r
.20735 .36575 m .21198 .36146 L .21799 .36382 L p F P
0 g
s
.81 .547 .541 r
.21021 .50278 m .2101 .50706 L .21 .50789 L p F P
0 g
s
.81 .547 .541 r
.20359 .50076 m .21021 .50278 L p .21 .50789 L F P
0 g
s
.767 .698 .786 r
.22691 .35593 m .22159 .36057 L .21831 .35574 L p F P
0 g
s
.636 .604 .801 r
.55562 .34205 m .56669 .33886 L .56961 .34499 L p F P
0 g
s
.637 .607 .803 r
.56536 .33609 m .56669 .33886 L .55562 .34205 L p F P
0 g
s
.637 .607 .803 r
.55562 .34205 m .55466 .34005 L .56536 .33609 L p F P
0 g
s
.809 .636 .667 r
.18158 .4581 m .18239 .45643 L .18082 .45587 L closepath p F P
0 g
s
.806 .644 .681 r
.17853 .44996 m .17951 .44814 L p .18239 .45643 L F P
0 g
s
.806 .644 .681 r
.18239 .45643 m .18082 .45587 L .17853 .44996 L p F P
0 g
s
.778 .698 .775 r
.20975 .37148 m .21063 .37063 L .20735 .36575 L p F P
0 g
s
.778 .695 .773 r
.20388 .36908 m .20975 .37148 L .20231 .37887 L p F P
0 g
s
.778 .698 .775 r
.20735 .36575 m .20388 .36908 L .20975 .37148 L p F P
0 g
s
.667 .668 .841 r
.47713 .31824 m .48807 .31416 L .49105 .31895 L p F P
0 g
s
.669 .676 .848 r
.48797 .314 m .48807 .31416 L .47713 .31824 L p F P
0 g
s
.669 .676 .848 r
.47713 .31824 m .4759 .31633 L .48797 .314 L p F P
0 g
s
.623 .111 .012 r
.28605 .5413 m .29143 .54473 L .29132 .54476 L p F P
0 g
s
.623 .111 .012 r
.27796 .54 m .28605 .5413 L p .29132 .54476 L F P
0 g
s
.5 .144 .295 r
.54538 .53349 m .54296 .53357 L .54555 .53304 L closepath p F P
0 g
s
.482 .106 .249 r
.54296 .53357 m .54538 .53349 L p .53208 .53895 L F P
0 g
s
.709 .71 .849 r
.32102 .31833 m .32614 .31572 L .33427 .31738 L p F P
0 g
s
.712 .714 .85 r
.33179 .31289 m .32614 .31572 L .33427 .31738 L p F P
0 g
s
.712 .714 .85 r
.33427 .31738 m .33497 .31701 L .33179 .31289 L p F P
0 g
s
.688 .716 .871 r
.36282 .31523 m .3736 .31068 L .37673 .31461 L p F P
0 g
s
.682 .727 .884 r
.3736 .31068 m .36282 .31523 L .35967 .31124 L p F P
0 g
s
.644 .619 .81 r
.53874 .33377 m .54978 .33032 L .5527 .33613 L p F P
0 g
s
.645 .623 .813 r
.54888 .32857 m .54978 .33032 L .53874 .33377 L p F P
0 g
s
.645 .623 .813 r
.53874 .33377 m .53797 .33228 L .54888 .32857 L p F P
0 g
s
.689 .724 .876 r
.35967 .31124 m .3489 .31603 L .34573 .31196 L p F P
0 g
s
.767 .698 .786 r
.21831 .35574 m .22077 .35361 L .22691 .35593 L p F P
0 g
s
.766 .7 .79 r
.22923 .34644 m .22077 .35361 L .22691 .35593 L p F P
0 g
s
.766 .7 .79 r
.22691 .35593 m .2325 .35119 L .22923 .34644 L p F P
0 g
s
.533 .262 .449 r
.58177 .51618 m .58136 .51939 L .57023 .52069 L p F P
0 g
s
.528 .248 .434 r
.56979 .52362 m .57023 .52069 L .58136 .51939 L p F P
0 g
s
.618 .57 .778 r
.6006 .35909 m .60352 .36609 L .59237 .36859 L p F P
0 g
s
.618 .57 .778 r
.59549 .36023 m .6006 .35909 L p .59237 .36859 L F P
0 g
s
.618 .57 .778 r
.59237 .36859 m .58987 .36259 L .59549 .36023 L p F P
0 g
s
.683 .717 .875 r
.37673 .31461 m .38753 .31023 L .39064 .31413 L p F P
0 g
s
.676 .73 .89 r
.38753 .31023 m .37673 .31461 L .3736 .31068 L p F P
0 g
s
.564 .397 .614 r
.61365 .4794 m .62436 .4756 L p .61953 .4834 L F P
0 g
s
.564 .397 .614 r
.61953 .4834 m .61412 .48316 L .61365 .4794 L p F P
0 g
s
.571 .417 .633 r
.62342 .46956 m .62436 .4756 L .61365 .4794 L p F P
0 g
s
.696 .72 .868 r
.34573 .31196 m .33497 .31701 L .33179 .31289 L p F P
0 g
s
.594 .511 .731 r
.62112 .41438 m .61968 .40985 L .63 .40545 L p F P
0 g
s
.597 .521 .739 r
.62939 .40361 m .63 .40545 L .61968 .40985 L p F P
0 g
s
.597 .521 .739 r
.61968 .40985 m .61816 .4053 L .62939 .40361 L p F P
0 g
s
.39 0 .038 r
.51767 .54397 m .52004 .54112 L .52505 .54024 L p F P
0 g
s
.594 .511 .731 r
.62213 .41755 m .62112 .41438 L .63236 .41282 L p F P
0 g
s
.594 .511 .731 r
.63 .40545 m .63236 .41282 L .62112 .41438 L p F P
0 g
s
.591 .502 .722 r
.62213 .41755 m .63247 .41318 L p .62776 .42362 L F P
0 g
s
.591 .502 .722 r
.62776 .42362 m .6241 .42408 L .62213 .41755 L p F P
0 g
s
.594 .511 .731 r
.63236 .41282 m .63247 .41318 L .62213 .41755 L p F P
0 g
s
.782 .464 .45 r
.23309 .52319 m .22742 .52183 L .2292 .51788 L p F P
0 g
s
.794 .478 .455 r
.2246 .51665 m .2292 .51788 L .22742 .52183 L p F P
0 g
s
.76 .7 .795 r
.23672 .34775 m .2325 .35119 L .22923 .34644 L p F P
0 g
s
.68 .717 .877 r
.39064 .31413 m .40146 .30988 L .40455 .31376 L p F P
0 g
s
.672 .731 .894 r
.40146 .30988 m .39064 .31413 L .38753 .31023 L p F P
0 g
s
.782 .691 .764 r
.19961 .38163 m .20231 .37887 L .19635 .37653 L closepath p F P
0 g
s
.778 .695 .773 r
.19634 .37651 m .20388 .36908 L p .20231 .37887 L F P
0 g
s
.778 .695 .773 r
.20231 .37887 m .19635 .37653 L .19634 .37651 L p F P
0 g
s
.597 .521 .74 r
.62733 .39749 m .62939 .40361 L .61816 .4053 L p F P
0 g
s
.597 .521 .74 r
.61816 .4053 m .61704 .40193 L .62733 .39749 L p F P
0 g
s
.814 .628 .651 r
.18351 .46379 m .17958 .46235 L p .1833 .47038 L F P
0 g
s
.814 .628 .651 r
.1833 .47038 m .18455 .46736 L .18351 .46379 L p F P
0 g
s
.813 .637 .664 r
.18351 .46379 m .18158 .4581 L .17958 .46235 L closepath p F P
0 g
s
.629 .592 .794 r
.58101 .34265 m .58363 .34843 L .57252 .35132 L p F P
0 g
s
.629 .592 .794 r
.57252 .35132 m .57048 .34684 L .58101 .34265 L p F P
0 g
s
.6 .53 .748 r
.62643 .39493 m .62733 .39749 L .61704 .40193 L p F P
0 g
s
.6 .53 .748 r
.61704 .40193 m .61522 .39674 L .62643 .39493 L p F P
0 g
s
.591 .502 .722 r
.62439 .42503 m .6241 .42408 L .62776 .42362 L closepath p F P
0 g
s
.786 .692 .761 r
.1954 .38609 m .19961 .38163 L .19635 .37653 L p F P
0 g
s
.813 .627 .65 r
.18566 .47122 m .18455 .46736 L .1833 .47038 L closepath p F P
0 g
s
.813 .638 .665 r
.17958 .46235 m .18158 .4581 L .18082 .45587 L p F P
0 g
s
.707 .705 .845 r
.32102 .31833 m .32614 .31572 L .31808 .31437 L closepath p F P
0 g
s
.717 .709 .842 r
.31808 .31437 m .32102 .31833 L p .30706 .31993 L F P
0 g
s
.587 .49 .712 r
.62645 .43228 m .62439 .42503 L .62776 .42362 L p F P
0 g
s
.677 .715 .878 r
.40455 .31376 m .41539 .3096 L .41846 .31349 L p F P
0 g
s
.67 .731 .895 r
.41539 .3096 m .40455 .31376 L .40146 .30988 L p F P
0 g
s
.639 .614 .809 r
.56378 .3329 m .56536 .33609 L .55466 .34005 L p F P
0 g
s
.639 .614 .809 r
.55466 .34005 m .5527 .33613 L .56378 .3329 L p F P
0 g
s
.813 .638 .665 r
.18082 .45587 m .17633 .45417 L p .17958 .46235 L F P
0 g
s
.812 .647 .677 r
.18082 .45587 m .17853 .44996 L .17633 .45417 L closepath p F P
0 g
s
.76 .7 .795 r
.22923 .34644 m .23041 .34548 L .23672 .34775 L p F P
0 g
s
.759 .702 .798 r
.24011 .33779 m .23041 .34548 L .23672 .34775 L p F P
0 g
s
.759 .702 .798 r
.23672 .34775 m .24337 .34245 L .24011 .33779 L p F P
0 g
s
.809 .646 .68 r
.17853 .44996 m .17951 .44814 L .17753 .44741 L closepath p F P
0 g
s
.805 .653 .694 r
.17541 .44254 m .17709 .43969 L p .17951 .44814 L F P
0 g
s
.805 .653 .694 r
.17951 .44814 m .17753 .44741 L .17541 .44254 L p F P
0 g
s
.746 .704 .812 r
.25421 .3343 m .26016 .33009 L .26671 .33228 L p F P
0 g
s
.746 .707 .815 r
.26503 .32671 m .26016 .33009 L .26671 .33228 L p F P
0 g
s
.746 .707 .815 r
.26671 .33228 m .26828 .33119 L .26503 .32671 L p F P
0 g
s
.576 .445 .665 r
.6223 .46333 m .62206 .46212 L .62611 .46189 L closepath p F P
0 g
s
.646 .629 .819 r
.54685 .32473 m .54888 .32857 L .53797 .33228 L p F P
0 g
s
.646 .629 .819 r
.53797 .33228 m .53581 .3282 L .54685 .32473 L p F P
0 g
s
.485 .13 .289 r
.54538 .53349 m .54555 .53304 L .55722 .53046 L p F P
0 g
s
.204 0 0 r
.36612 .55375 m .35921 .5533 L .35342 .55262 L p F P
0 g
s
.219 0 0 r
.35921 .5533 m .35093 .55282 L .35342 .55262 L closepath p F P
0 g
s
.369 0 0 r
.31874 .54845 m .32241 .54969 L .31926 .54983 L p F P
0 g
s
.369 0 0 r
.30934 .54735 m .31874 .54845 L p .31926 .54983 L F P
0 g
s
.544 .01 0 r
.31874 .54845 m .30934 .54735 L .30862 .54707 L p F P
0 g
s
.809 .614 .638 r
.18749 .47825 m .18728 .47819 L .18566 .47122 L p F P
0 g
s
.816 .618 .634 r
.1833 .47038 m .18566 .47122 L .18728 .47819 L p F P
0 g
s
.552 .353 .565 r
.60427 .49973 m .60399 .49438 L .61488 .4908 L p F P
0 g
s
.563 .38 .591 r
.61437 .48522 m .61488 .4908 L .60399 .49438 L p F P
0 g
s
.798 .511 .502 r
.2246 .51665 m .21763 .51475 L .21708 .50981 L p F P
0 g
s
.798 .51 .501 r
.21009 .50792 m .21708 .50981 L .21763 .51475 L p F P
0 g
s
.799 .536 .541 r
.21708 .50981 m .21009 .50792 L .2101 .50706 L p F P
0 g
s
.652 .635 .82 r
.52186 .32642 m .53288 .32275 L .53581 .3282 L p F P
0 g
s
.652 .64 .825 r
.53117 .31966 m .53288 .32275 L .52186 .32642 L p F P
0 g
s
.652 .64 .825 r
.52186 .32642 m .52002 .32308 L .53117 .31966 L p F P
0 g
s
.6 .531 .748 r
.62445 .38929 m .62643 .39493 L .61522 .39674 L p F P
0 g
s
.6 .531 .748 r
.61522 .39674 m .61417 .39376 L .62445 .38929 L p F P
0 g
s
.739 .708 .823 r
.27907 .32404 m .26828 .33119 L .26503 .32671 L p F P
0 g
s
.675 .712 .876 r
.41846 .31349 m .42932 .30938 L .43238 .31333 L p F P
0 g
s
.669 .728 .893 r
.42932 .30938 m .41846 .31349 L .41539 .3096 L p F P
0 g
s
.569 .427 .649 r
.62342 .46956 m .6223 .46333 L .62611 .46189 L p F P
0 g
s
.786 .691 .759 r
.18956 .38369 m .1954 .38609 L .18889 .39318 L p F P
0 g
s
.786 .692 .761 r
.19633 .37652 m .18956 .38369 L .1954 .38609 L p F P
0 g
s
.786 .692 .761 r
.19635 .37653 m .19633 .37652 L p .1954 .38609 L F P
0 g
s
.663 .666 .842 r
.50201 .31499 m .49105 .31895 L .48807 .31416 L p F P
0 g
s
.663 .661 .837 r
.49105 .31895 m .50201 .31499 L .50498 .31991 L p F P
0 g
s
.804 .668 .713 r
.1736 .42234 m .17947 .4247 L .17513 .43109 L p F P
0 g
s
.803 .672 .719 r
.17826 .41585 m .1736 .42234 L .17947 .4247 L p F P
0 g
s
.732 .709 .829 r
.28986 .31746 m .28192 .32228 L .2891 .32426 L p F P
0 g
s
.732 .709 .829 r
.2891 .32426 m .29308 .3218 L .28986 .31746 L p F P
0 g
s
.73 .705 .827 r
.27907 .32404 m .28192 .32228 L .2891 .32426 L p F P
0 g
s
.603 .54 .756 r
.62349 .38668 m .62445 .38929 L .61417 .39376 L p F P
0 g
s
.603 .54 .756 r
.61417 .39376 m .61228 .38861 L .62349 .38668 L p F P
0 g
s
.798 .677 .731 r
.18337 .40921 m .18052 .41285 L .17728 .40709 L p F P
0 g
s
.798 .677 .731 r
.17728 .40709 m .17747 .40685 L .18337 .40921 L p F P
0 g
s
.795 .682 .74 r
.18337 .40921 m .17747 .40685 L .18306 .40005 L p F P
0 g
s
.736 .319 .256 r
.25794 .53276 m .26061 .53607 L .25992 .53655 L p F P
0 g
s
.736 .319 .256 r
.25025 .53111 m .25794 .53276 L p .25992 .53655 L F P
0 g
s
.714 .715 .849 r
.31749 .31423 m .30706 .31993 L .30386 .3156 L p F P
0 g
s
.722 .707 .836 r
.29308 .3218 m .30386 .3156 L .30706 .31993 L p F P
0 g
s
.717 .709 .842 r
.30706 .31993 m .31749 .31423 L .31808 .31437 L p F P
0 g
s
.387 0 .016 r
.51767 .54397 m .51665 .54413 L .50657 .54472 L p F P
0 g
s
.361 0 0 r
.51665 .54413 m .50538 .54588 L .50657 .54472 L closepath p F P
0 g
s
.423 0 .047 r
.50657 .54472 m .50538 .54588 L .49296 .54764 L p F P
0 g
s
.582 .479 .702 r
.62712 .4348 m .62645 .43228 L .63681 .42795 L p F P
0 g
s
.587 .49 .712 r
.63535 .42285 m .63681 .42795 L .62645 .43228 L p F P
0 g
s
.587 .49 .712 r
.62776 .42362 m .63535 .42285 L p .62645 .43228 L F P
0 g
s
.773 .419 .384 r
.24443 .52987 m .24261 .52943 L .24043 .52496 L p F P
0 g
s
.774 .413 .373 r
.23309 .52319 m .24043 .52496 L .24261 .52943 L p F P
0 g
s
.752 .702 .804 r
.24766 .33918 m .24337 .34245 L .24011 .33779 L p F P
0 g
s
.667 .679 .853 r
.48509 .3097 m .48797 .314 L .4759 .31633 L p F P
0 g
s
.667 .679 .853 r
.4759 .31633 m .47414 .31367 L .48509 .3097 L p F P
0 g
s
.813 .647 .678 r
.17633 .45417 m .17853 .44996 L .17753 .44741 L p F P
0 g
s
.461 .08 .229 r
.54394 .53658 m .54538 .53349 L .55647 .53239 L p F P
0 g
s
.482 .106 .249 r
.54538 .53349 m .54394 .53658 L .53208 .53895 L p F P
0 g
s
.485 .13 .289 r
.55722 .53046 m .55647 .53239 L .54538 .53349 L p F P
0 g
s
.674 .706 .872 r
.43238 .31333 m .44326 .30925 L .4463 .31329 L p F P
0 g
s
.669 .722 .889 r
.44326 .30925 m .43238 .31333 L .42932 .30938 L p F P
0 g
s
.62 .578 .785 r
.58987 .36259 m .58945 .36163 L .59549 .36023 L closepath p F P
0 g
s
.43 .003 .124 r
.5315 .53982 m .52505 .54024 L .53208 .53895 L closepath p F P
0 g
s
.39 0 .038 r
.52505 .54024 m .5315 .53982 L p .51767 .54397 L F P
0 g
s
.329 0 0 r
.49265 .54787 m .49053 .54794 L .49296 .54764 L closepath p F P
0 g
s
.278 0 0 r
.49053 .54794 m .49265 .54787 L p .47871 .55008 L F P
0 g
s
.583 .479 .701 r
.62832 .43933 m .62712 .4348 L .63839 .43384 L p F P
0 g
s
.582 .479 .702 r
.63681 .42795 m .63839 .43384 L .62712 .4348 L p F P
0 g
s
.808 .655 .693 r
.17541 .44254 m .17709 .43969 L .17358 .43836 L closepath p F P
0 g
s
.804 .662 .705 r
.17226 .43558 m .17513 .43109 L p .17709 .43969 L F P
0 g
s
.804 .662 .705 r
.17709 .43969 m .17358 .43836 L .17226 .43558 L p F P
0 g
s
.603 .54 .757 r
.62134 .38082 m .62349 .38668 L .61228 .38861 L p F P
0 g
s
.603 .54 .757 r
.61228 .38861 m .61108 .38533 L .62134 .38082 L p F P
0 g
s
.813 .647 .678 r
.17753 .44741 m .17352 .44585 L p .17633 .45417 L F P
0 g
s
.811 .656 .689 r
.17753 .44741 m .17541 .44254 L .17352 .44585 L closepath p F P
0 g
s
.62 .579 .787 r
.59549 .36023 m .58945 .36163 L .58654 .35493 L p F P
0 g
s
.543 .007 0 r
.30934 .54735 m .30821 .54721 L .30862 .54707 L closepath p F P
0 g
s
.809 .6 .619 r
.18736 .47868 m .18749 .47825 L p .19231 .48593 L F P
0 g
s
.812 .602 .618 r
.18736 .47868 m .18749 .47825 L .18728 .47819 L closepath p F P
0 g
s
.752 .702 .804 r
.24011 .33779 m .24121 .33695 L .24766 .33918 L p F P
0 g
s
.752 .705 .807 r
.25095 .32975 m .24121 .33695 L .24766 .33918 L p F P
0 g
s
.752 .705 .807 r
.24766 .33918 m .25421 .3343 L .25095 .32975 L p F P
0 g
s
.809 .585 .598 r
.19767 .49343 m .19111 .49138 L .19231 .48593 L p F P
0 g
s
.811 .587 .598 r
.18834 .48465 m .19231 .48593 L .19111 .49138 L p F P
0 g
s
.809 .6 .619 r
.19231 .48593 m .18834 .48465 L .18736 .47868 L p F P
0 g
s
.623 .111 .012 r
.27776 .54012 m .27796 .54 L p .29132 .54476 L F P
0 g
s
.691 .238 .17 r
.27776 .54012 m .27751 .53992 L .27796 .54 L closepath p F P
0 g
s
.817 .605 .616 r
.18728 .47819 m .1813 .47606 L p .1859 .48382 L F P
0 g
s
.817 .605 .616 r
.1859 .48382 m .18736 .47868 L .18728 .47819 L p F P
0 g
s
.816 .618 .634 r
.18728 .47819 m .1813 .47606 L .1833 .47038 L p F P
0 g
s
.631 .599 .8 r
.58072 .34203 m .58101 .34265 L .57048 .34684 L p F P
0 g
s
.631 .599 .8 r
.57048 .34684 m .56961 .34499 L .58072 .34203 L p F P
0 g
s
.791 .686 .749 r
.18851 .39362 m .18889 .39318 L .18803 .39284 L closepath p F P
0 g
s
.786 .691 .759 r
.18523 .38842 m .18956 .38369 L p .18889 .39318 L F P
0 g
s
.786 .691 .759 r
.18889 .39318 m .18803 .39284 L .18523 .38842 L p F P
0 g
s
.801 .679 .729 r
.17826 .41585 m .18052 .41285 L .17728 .40709 L p F P
0 g
s
.564 .397 .614 r
.61437 .48522 m .61412 .48316 L .61953 .4834 L closepath p F P
0 g
s
.795 .687 .746 r
.18306 .40005 m .18851 .39362 L .18803 .39284 L p F P
0 g
s
.672 .7 .867 r
.4463 .31329 m .45719 .30924 L .46022 .3134 L p F P
0 g
s
.669 .714 .882 r
.45719 .30924 m .4463 .31329 L .44326 .30925 L p F P
0 g
s
.664 .178 .086 r
.27751 .53992 m .27776 .54012 L .27422 .54163 L p F P
0 g
s
.664 .178 .086 r
.27422 .54163 m .26956 .53836 L .27751 .53992 L p F P
0 g
s
.818 .62 .636 r
.17719 .46816 m .1833 .47038 L .1813 .47606 L p F P
0 g
s
.814 .628 .651 r
.17958 .46235 m .17719 .46816 L .1833 .47038 L p F P
0 g
s
.722 .711 .84 r
.30386 .3156 m .29308 .3218 L .28986 .31746 L p F P
0 g
s
.306 0 0 r
.49265 .54787 m .49296 .54764 L .50538 .54588 L p F P
0 g
s
.816 .605 .616 r
.18834 .48465 m .18736 .47868 L .1859 .48382 L closepath p F P
0 g
s
.126 0 0 r
.37025 .55391 m .36612 .55375 L .36729 .55371 L closepath p F P
0 g
s
.115 0 0 r
.38099 .55439 m .37025 .55391 L .36729 .55371 L p F P
0 g
s
.606 .549 .764 r
.62056 .37879 m .62134 .38082 L .61108 .38533 L p F P
0 g
s
.606 .549 .764 r
.61108 .38533 m .60936 .38082 L .62056 .37879 L p F P
0 g
s
.794 .478 .455 r
.22742 .52183 m .22582 .5214 L .2246 .51665 L p F P
0 g
s
.796 .477 .449 r
.21763 .51475 m .2246 .51665 L .22582 .5214 L p F P
0 g
s
.705 .708 .85 r
.32859 .30888 m .33179 .31289 L .32614 .31572 L p F P
0 g
s
.705 .708 .85 r
.31783 .31405 m .32859 .30888 L p .32614 .31572 L F P
0 g
s
.705 .708 .85 r
.32614 .31572 m .31808 .31437 L .31783 .31405 L p F P
0 g
s
.81 .567 .572 r
.20359 .50076 m .19699 .49873 L .19767 .49343 L p F P
0 g
s
.811 .569 .572 r
.19111 .49138 m .19767 .49343 L .19699 .49873 L p F P
0 g
s
.578 .467 .691 r
.63003 .4462 m .62832 .43933 L .63871 .43504 L p F P
0 g
s
.586 .472 .69 r
.62832 .43933 m .63003 .4462 L .62784 .44704 L p F P
0 g
s
.583 .479 .701 r
.63839 .43384 m .63871 .43504 L .62832 .43933 L p F P
0 g
s
.58 .458 .677 r
.63017 .44685 m .62784 .44704 L .63003 .4462 L closepath p F P
0 g
s
.639 .616 .811 r
.56378 .3329 m .5527 .33613 L .54978 .33032 L p F P
0 g
s
.623 .111 .012 r
.29132 .54476 m .28333 .54334 L .27776 .54012 L p F P
0 g
s
.626 .125 .041 r
.28333 .54334 m .27776 .54012 L .27422 .54163 L p F P
0 g
s
.658 .654 .834 r
.50498 .31991 m .51597 .3161 L .51892 .32114 L p F P
0 g
s
.659 .66 .839 r
.51597 .3161 m .50498 .31991 L .50201 .31499 L p F P
0 g
s
.795 .687 .746 r
.18803 .39284 m .18315 .39075 L p .18306 .40005 L F P
0 g
s
.793 .692 .754 r
.18803 .39284 m .18523 .38842 L .18315 .39075 L closepath p F P
0 g
s
.817 .632 .652 r
.17355 .46009 m .17958 .46235 L .17719 .46816 L p F P
0 g
s
.813 .638 .665 r
.17633 .45417 m .17355 .46009 L .17958 .46235 L p F P
0 g
s
.369 0 0 r
.31926 .54983 m .31867 .54975 L .30934 .54735 L p F P
0 g
s
.199 0 0 r
.30821 .54721 m .30934 .54735 L .31867 .54975 L p F P
0 g
s
.586 .49 .713 r
.63535 .42285 m .62776 .42362 L .63473 .42067 L closepath p F P
0 g
s
.591 .502 .722 r
.63247 .41318 m .63473 .42067 L .62776 .42362 L p F P
0 g
s
.631 .602 .803 r
.58072 .34203 m .56961 .34499 L .56669 .33886 L p F P
0 g
s
.801 .679 .729 r
.17728 .40709 m .1725 .41345 L .17826 .41585 L p F P
0 g
s
.804 .676 .722 r
.1725 .41345 m .17826 .41585 L .1736 .42234 L p F P
0 g
s
.668 .705 .874 r
.47114 .30937 m .46022 .3134 L .45719 .30924 L p F P
0 g
s
.67 .692 .862 r
.46022 .3134 m .47114 .30937 L .47414 .31367 L p F P
0 g
s
.199 0 0 r
.30521 .54769 m .30821 .54721 L p .31867 .54975 L F P
0 g
s
.477 0 0 r
.30521 .54769 m .30054 .54605 L .30821 .54721 L closepath p F P
0 g
s
.653 .645 .829 r
.52994 .31748 m .53117 .31966 L .52002 .32308 L p F P
0 g
s
.653 .645 .829 r
.52002 .32308 m .51892 .32114 L .52994 .31748 L p F P
0 g
s
.745 .705 .814 r
.26016 .33009 m .25421 .3343 L .25095 .32975 L p F P
0 g
s
.812 .656 .69 r
.17352 .44585 m .17541 .44254 L .17358 .43836 L p F P
0 g
s
.647 .633 .822 r
.54685 .32473 m .53581 .3282 L .53288 .32275 L p F P
0 g
s
.81 .547 .541 r
.21 .50789 m .20347 .5059 L .20359 .50076 L p F P
0 g
s
.811 .548 .54 r
.19699 .49873 m .20359 .50076 L .20347 .5059 L p F P
0 g
s
.606 .549 .765 r
.61798 .37207 m .62056 .37879 L .60936 .38082 L p F P
0 g
s
.606 .549 .765 r
.60936 .38082 m .60774 .37661 L .61798 .37207 L p F P
0 g
s
.52 .249 .443 r
.58136 .51939 m .58177 .51618 L .59298 .51301 L p F P
0 g
s
.542 .298 .494 r
.59324 .50819 m .59298 .51301 L .58177 .51618 L p F P
0 g
s
.306 0 0 r
.50538 .54588 m .50362 .54695 L .49265 .54787 L p F P
0 g
s
0 0 0 r
.49265 .54787 m .50362 .54695 L .50174 .5475 L p F P
0 g
s
0 0 0 r
.48966 .54918 m .49265 .54787 L p .50174 .5475 L F P
0 g
s
.278 0 0 r
.49265 .54787 m .48966 .54918 L .47871 .55008 L p F P
0 g
s
.554 .373 .591 r
.61488 .4908 m .61437 .48522 L .61953 .4834 L p F P
0 g
s
.808 .663 .703 r
.17513 .43109 m .17226 .43558 L .16908 .42896 L p F P
0 g
s
.808 .663 .703 r
.16908 .42896 m .16921 .42876 L .17513 .43109 L p F P
0 g
s
.804 .668 .713 r
.17513 .43109 m .16921 .42876 L .1736 .42234 L p F P
0 g
s
.801 .538 .541 r
.21009 .50792 m .21 .50789 L .2101 .50706 L closepath p F P
0 g
s
.773 .701 .783 r
.2147 .35126 m .20604 .35907 L .21198 .36146 L p F P
0 g
s
.773 .701 .783 r
.21545 .35157 m .2147 .35126 L p .21198 .36146 L F P
0 g
s
.773 .701 .783 r
.21198 .36146 m .21831 .35574 L .21545 .35157 L p F P
0 g
s
.775 .699 .78 r
.21198 .36146 m .20735 .36575 L .20406 .3609 L p F P
0 g
s
.775 .699 .78 r
.20406 .3609 m .20604 .35907 L .21198 .36146 L p F P
0 g
s
.779 .7 .776 r
.20388 .36908 m .20735 .36575 L .20406 .3609 L p F P
0 g
s
.045 0 0 r
.39508 .55468 m .39546 .55466 L .40705 .55465 L p F P
0 g
s
.081 0 0 r
.39508 .55468 m .39401 .55464 L .39546 .55466 L closepath p F P
0 g
s
.816 .642 .667 r
.17038 .45188 m .17633 .45417 L .17355 .46009 L p F P
0 g
s
.813 .647 .678 r
.17352 .44585 m .17038 .45188 L .17633 .45417 L p F P
0 g
s
.045 0 0 r
.40705 .55465 m .40901 .55467 L p .39508 .55468 L F P
0 g
s
.046 0 0 r
.40901 .55467 m .40705 .55465 L .40962 .55464 L closepath p F P
0 g
s
.73 .704 .826 r
.27907 .32404 m .28192 .32228 L .27678 .32089 L closepath p F P
0 g
s
.739 .708 .823 r
.27678 .32089 m .27907 .32404 L p .26503 .32671 L F P
0 g
s
.015 0 0 r
.40901 .55467 m .40962 .55464 L .42091 .55442 L p F P
0 g
s
.768 .7 .787 r
.21831 .35574 m .22077 .35361 L .21545 .35157 L closepath p F P
0 g
s
.264 0 0 r
.38118 .55438 m .38171 .5544 L .39401 .55464 L p F P
0 g
s
.05 0 0 r
.38171 .5544 m .38099 .55439 L .38118 .55438 L closepath p F P
0 g
s
.795 .685 .743 r
.17728 .39764 m .18306 .40005 L .17747 .40685 L p F P
0 g
s
.795 .687 .746 r
.18315 .39075 m .17728 .39764 L .18306 .40005 L p F P
0 g
s
.576 .445 .665 r
.63153 .45284 m .63286 .4593 L .62611 .46189 L p F P
0 g
s
.569 .428 .65 r
.63333 .46188 m .62611 .46189 L .63286 .4593 L closepath p F P
0 g
s
.569 .427 .649 r
.62611 .46189 m .63333 .46188 L p .62342 .46956 L F P
0 g
s
.119 .664 .826 r
.39401 .55464 m .39508 .55468 L .39189 .55423 L p F P
0 g
s
.119 .664 .826 r
.39189 .55423 m .38171 .5544 L .39401 .55464 L p F P
0 g
s
.782 .698 .772 r
.20388 .36908 m .19634 .37651 L .19304 .37161 L p F P
0 g
s
.782 .698 .772 r
.19304 .37161 m .19807 .36665 L .20388 .36908 L p F P
0 g
s
.779 .7 .776 r
.20406 .3609 m .19807 .36665 L .20388 .36908 L p F P
0 g
s
.562 .41 .633 r
.62436 .4756 m .62342 .46956 L .634 .46555 L p F P
0 g
s
.569 .427 .649 r
.63333 .46188 m .634 .46555 L .62342 .46956 L p F P
0 g
s
.764 .703 .795 r
.22792 .34456 m .22923 .34644 L .22077 .35361 L p F P
0 g
s
.764 .703 .795 r
.22436 .34311 m .22792 .34456 L p .22077 .35361 L F P
0 g
s
.764 .703 .795 r
.21503 .35097 m .22436 .34311 L p .22077 .35361 L F P
0 g
s
.764 .703 .795 r
.22077 .35361 m .21545 .35157 L .21503 .35097 L p F P
0 g
s
.549 .329 .534 r
.60427 .49973 m .60429 .50483 L .59324 .50819 L p F P
0 g
s
.531 .288 .492 r
.59298 .51301 m .59324 .50819 L .60429 .50483 L p F P
0 g
s
.493 .176 .357 r
.56876 .52768 m .56979 .52362 L .58117 .52066 L p F P
0 g
s
.528 .248 .434 r
.58136 .51939 m .58117 .52066 L .56979 .52362 L p F P
0 g
s
.509 .191 .364 r
.56979 .52362 m .56876 .52768 L .55722 .53046 L p F P
0 g
s
.667 .695 .867 r
.48509 .3097 m .47414 .31367 L .47114 .30937 L p F P
0 g
s
.03 0 0 r
.42294 .5544 m .42091 .55442 L .42351 .55436 L closepath p F P
0 g
s
.015 0 0 r
.42091 .55442 m .42294 .5544 L p .40901 .55467 L F P
0 g
s
.572 .452 .678 r
.63017 .44685 m .63003 .4462 L .64041 .4419 L p F P
0 g
s
.578 .467 .691 r
.63871 .43504 m .64041 .4419 L .63003 .4462 L p F P
0 g
s
.412 0 .114 r
.5315 .53982 m .53208 .53895 L .54394 .53658 L p F P
0 g
s
.609 .558 .772 r
.61764 .37119 m .61798 .37207 L .60774 .37661 L p F P
0 g
s
.609 .558 .772 r
.60774 .37661 m .60643 .37333 L .61764 .37119 L p F P
0 g
s
.113 .66 .822 r
.38171 .5544 m .39189 .55423 L p .37795 .55402 L F P
0 g
s
.113 .66 .822 r
.37795 .55402 m .38099 .55439 L .38171 .5544 L p F P
0 g
s
.071 .629 .799 r
.37795 .55402 m .37025 .55391 L .38099 .55439 L closepath p F P
0 g
s
.003 0 0 r
.42294 .5544 m .42351 .55436 L .43582 .55389 L p F P
0 g
s
.784 .697 .768 r
.19635 .37653 m .19634 .37651 L .19633 .37652 L closepath p F P
0 g
s
.573 .452 .677 r
.63153 .45284 m .63017 .44685 L .64148 .44657 L p F P
0 g
s
.572 .452 .678 r
.64041 .4419 m .64148 .44657 L .63017 .44685 L p F P
0 g
s
.786 .699 .769 r
.19633 .37652 m .19634 .37651 L .19304 .37161 L p F P
0 g
s
.787 .695 .763 r
.19064 .37405 m .19633 .37652 L .18956 .38369 L p F P
0 g
s
.786 .699 .769 r
.19304 .37161 m .19064 .37405 L .19633 .37652 L p F P
0 g
s
.812 .656 .69 r
.17358 .43836 m .17115 .43738 L p .17352 .44585 L F P
0 g
s
.81 .664 .701 r
.17358 .43836 m .17226 .43558 L .17115 .43738 L closepath p F P
0 g
s
.798 .51 .501 r
.21763 .51475 m .21064 .51286 L .21009 .50792 L p F P
0 g
s
.8 .512 .5 r
.21 .50789 m .21009 .50792 L .21064 .51286 L p F P
0 g
s
.736 .319 .256 r
.25992 .53655 m .2538 .53518 L .25025 .53111 L p F P
0 g
s
.727 .297 .228 r
.24443 .52987 m .25025 .53111 L .2538 .53518 L p F P
0 g
s
.62 .579 .787 r
.58654 .35493 m .59769 .35236 L p .59549 .36023 L F P
0 g
s
.62 .581 .788 r
.59597 .34841 m .59769 .35236 L .58654 .35493 L p F P
0 g
s
.62 .581 .788 r
.58654 .35493 m .58563 .35285 L .59597 .34841 L p F P
0 g
s
.745 .705 .814 r
.25095 .32975 m .2536 .32789 L .26016 .33009 L p F P
0 g
s
.745 .709 .817 r
.26177 .32227 m .2536 .32789 L .26016 .33009 L p F P
0 g
s
.745 .709 .817 r
.26016 .33009 m .26503 .32671 L .26177 .32227 L p F P
0 g
s
.761 .701 .796 r
.22923 .34644 m .23041 .34548 L .22792 .34456 L closepath p F P
0 g
s
.8 .512 .5 r
.21064 .51286 m .20876 .51234 L .21 .50789 L p F P
0 g
s
.81 .523 .502 r
.20347 .5059 m .21 .50789 L .20876 .51234 L p F P
0 g
s
.811 .587 .598 r
.19111 .49138 m .18888 .49067 L .18834 .48465 L p F P
0 g
s
.819 .592 .595 r
.1859 .48382 m .18834 .48465 L .18888 .49067 L p F P
0 g
s
.757 .705 .803 r
.23894 .33615 m .24011 .33779 L .23041 .34548 L p F P
0 g
s
.757 .705 .803 r
.23506 .33462 m .23894 .33615 L p .23041 .34548 L F P
0 g
s
.757 .705 .803 r
.22594 .34181 m .23506 .33462 L p .23041 .34548 L F P
0 g
s
.757 .705 .803 r
.23041 .34548 m .22792 .34456 L .22594 .34181 L p F P
0 g
s
.726 .707 .832 r
.28662 .31318 m .28986 .31746 L .28192 .32228 L p F P
0 g
s
.726 .707 .832 r
.27584 .31962 m .28662 .31318 L p .28192 .32228 L F P
0 g
s
.726 .707 .832 r
.28192 .32228 m .27678 .32089 L .27584 .31962 L p F P
0 g
s
.654 .652 .836 r
.52994 .31748 m .51892 .32114 L .51597 .3161 L p F P
0 g
s
.045 0 0 r
.40901 .55467 m .40584 .55421 L .39508 .55468 L p F P
0 g
s
.389 .798 .981 r
.40584 .55421 m .39508 .55468 L .39189 .55423 L p F P
0 g
s
.085 0 0 r
.47653 .55071 m .47871 .55008 L .48966 .54918 L p F P
0 g
s
.689 .724 .876 r
.34573 .31196 m .3565 .30742 L .35967 .31124 L p F P
0 g
s
.681 .734 .891 r
.3565 .30742 m .34573 .31196 L .34255 .30804 L p F P
0 g
s
.696 .72 .868 r
.33179 .31289 m .34255 .30804 L .34573 .31196 L p F P
0 g
s
.774 .413 .373 r
.24261 .52943 m .23536 .52764 L .23309 .52319 L p F P
0 g
s
.77 .403 .36 r
.22742 .52183 m .23309 .52319 L .23536 .52764 L p F P
0 g
s
.682 .727 .884 r
.35967 .31124 m .37045 .30696 L .3736 .31068 L p F P
0 g
s
.672 .74 .902 r
.37045 .30696 m .35967 .31124 L .3565 .30742 L p F P
0 g
s
.815 .652 .68 r
.16766 .44351 m .17352 .44585 L .17038 .45188 L p F P
0 g
s
.812 .656 .69 r
.17115 .43738 m .16766 .44351 L .17352 .44585 L p F P
0 g
s
.715 .711 .845 r
.31808 .31437 m .31783 .31405 L .31749 .31423 L closepath p F P
0 g
s
.69 .728 .879 r
.34255 .30804 m .33179 .31289 L .32859 .30888 L p F P
0 g
s
.676 .73 .89 r
.3736 .31068 m .3844 .30659 L .38753 .31023 L p F P
0 g
s
.664 .746 .911 r
.3844 .30659 m .3736 .31068 L .37045 .30696 L p F P
0 g
s
.609 .558 .772 r
.61472 .36389 m .61764 .37119 L .60643 .37333 L p F P
0 g
s
.609 .558 .772 r
.61069 .36465 m .61472 .36389 L p .60643 .37333 L F P
0 g
s
.609 .558 .772 r
.60643 .37333 m .60414 .36759 L .61069 .36465 L p F P
0 g
s
.264 0 0 r
.32847 .55074 m .31926 .54983 L .32241 .54969 L closepath p F P
0 g
s
.094 0 0 r
.32847 .55074 m .33293 .55116 L p .32262 .55016 L F P
0 g
s
.094 0 0 r
.31904 .54981 m .31926 .54983 L .32847 .55074 L p F P
0 g
s
.094 0 0 r
.31904 .54981 m .32847 .55074 L .32262 .55016 L F
.238 0 0 r
.32847 .55074 m .32241 .54969 L p .33321 .55122 L F P
0 g
s
.238 0 0 r
.33531 .55151 m .32847 .55074 L p .33321 .55122 L F P
0 g
s
.714 .715 .849 r
.30386 .3156 m .31008 .31232 L .31749 .31423 L p F P
0 g
s
.717 .717 .849 r
.31462 .30996 m .31008 .31232 L .31749 .31423 L p F P
0 g
s
.717 .717 .849 r
.31749 .31423 m .31783 .31405 L .31462 .30996 L p F P
0 g
s
.043 .61 .773 r
.37025 .55391 m .37795 .55402 L p .36403 .55356 L F P
0 g
s
.043 .61 .773 r
.36403 .55356 m .36612 .55375 L .37025 .55391 L p F P
0 g
s
.032 0 0 r
.43687 .55386 m .43582 .55389 L .43714 .55383 L closepath p F P
0 g
s
.003 0 0 r
.43582 .55389 m .43687 .55386 L p .42294 .5544 L F P
0 g
s
.623 .588 .794 r
.59478 .34577 m .59597 .34841 L .58563 .35285 L p F P
0 g
s
.623 .588 .794 r
.58563 .35285 m .58363 .34843 L .59478 .34577 L p F P
0 g
s
.699 .724 .869 r
.32859 .30888 m .31783 .31405 L .31462 .30996 L p F P
0 g
s
.538 .32 .532 r
.60429 .50483 m .60427 .49973 L .61517 .49616 L p F P
0 g
s
.552 .353 .565 r
.61488 .4908 m .61517 .49616 L .60427 .49973 L p F P
0 g
s
.672 .731 .894 r
.38753 .31023 m .39834 .30629 L .40146 .30988 L p F P
0 g
s
.659 .75 .917 r
.39834 .30629 m .38753 .31023 L .3844 .30659 L p F P
0 g
s
.004 0 0 r
.43687 .55386 m .43714 .55383 L .45051 .55303 L p F P
0 g
s
.184 0 0 r
.45082 .553 m .45051 .55303 L .43714 .55383 L p F P
0 g
s
.641 .13 .017 r
.26956 .53836 m .27422 .54163 L .27376 .54174 L p F P
0 g
s
.641 .13 .017 r
.26146 .53684 m .26956 .53836 L p .27376 .54174 L F P
0 g
s
.705 .268 .211 r
.26956 .53836 m .26146 .53684 L .26061 .53607 L p F P
0 g
s
.787 .695 .763 r
.18956 .38369 m .18379 .38126 L .19064 .37405 L p F P
0 g
s
.79 .693 .757 r
.18956 .38369 m .18523 .38842 L .18193 .38329 L p F P
0 g
s
.79 .693 .757 r
.18193 .38329 m .18379 .38126 L .18956 .38369 L p F P
0 g
s
.663 .666 .842 r
.49964 .31119 m .50201 .31499 L p .48807 .31416 L F P
0 g
s
.663 .666 .842 r
.48807 .31416 m .48946 .31367 L .49964 .31119 L p F P
0 g
s
.665 .679 .853 r
.48807 .31416 m .48946 .31367 L .48797 .314 L closepath p F P
0 g
s
.805 .672 .716 r
.16779 .41996 m .1736 .42234 L .16921 .42876 L p F P
0 g
s
.804 .676 .722 r
.1736 .42234 m .16779 .41996 L .1725 .41345 L p F P
0 g
s
.811 .665 .701 r
.17115 .43738 m .17226 .43558 L .16908 .42896 L p F P
0 g
s
.015 0 0 r
.42294 .5544 m .4198 .55398 L .40901 .55467 L p F P
0 g
s
.405 .807 .983 r
.4198 .55398 m .40901 .55467 L .40584 .55421 L p F P
0 g
s
.364 0 0 r
.30054 .54605 m .30521 .54769 L .30263 .54763 L p F P
0 g
s
.364 0 0 r
.29159 .5448 m .30054 .54605 L p .30263 .54763 L F P
0 g
s
.612 .113 .042 r
.29143 .54473 m .29159 .5448 L .30054 .54605 L p F P
0 g
s
.8 .68 .733 r
.17728 .40709 m .17747 .40685 L .17704 .40668 L closepath p F P
0 g
s
.795 .685 .743 r
.17401 .40164 m .17728 .39764 L p .17747 .40685 L F P
0 g
s
.795 .685 .743 r
.17747 .40685 m .17704 .40668 L .17401 .40164 L p F P
0 g
s
0 .57 .742 r
.36403 .55356 m .35921 .5533 L .36612 .55375 L closepath p F P
0 g
s
.804 .681 .729 r
.1725 .41345 m .17728 .40709 L .17704 .40668 L p F P
0 g
s
.665 .683 .857 r
.48946 .31367 m .48797 .314 L .48509 .3097 L p F P
0 g
s
.739 .708 .823 r
.26503 .32671 m .27485 .32025 L .27678 .32089 L p F P
0 g
s
.738 .711 .826 r
.27485 .32025 m .26503 .32671 L .26177 .32227 L p F P
0 g
s
.074 0 0 r
.47653 .55071 m .47087 .55129 L .46476 .55176 L p F P
0 g
s
.024 0 0 r
.47087 .55129 m .46361 .55197 L .46476 .55176 L closepath p F P
0 g
s
.462 .102 .268 r
.55647 .53239 m .55722 .53046 L .56876 .52768 L p F P
0 g
s
.657 .751 .919 r
.41229 .30601 m .40146 .30988 L .39834 .30629 L p F P
0 g
s
.67 .731 .895 r
.40146 .30988 m .41229 .30601 L .41539 .3096 L p F P
0 g
s
.224 0 0 r
.50362 .54695 m .50538 .54588 L .51665 .54413 L p F P
0 g
s
.804 .681 .729 r
.17704 .40668 m .1718 .4044 L p .1725 .41345 L F P
0 g
s
.802 .687 .738 r
.17704 .40668 m .17401 .40164 L .1718 .4044 L closepath p F P
0 g
s
.753 .703 .805 r
.24011 .33779 m .24121 .33695 L .23894 .33615 L closepath p F P
0 g
s
.617 .572 .78 r
.6006 .35909 m .59549 .36023 L .60023 .35821 L closepath p F P
0 g
s
.62 .579 .787 r
.59769 .35236 m .60023 .35821 L .59549 .36023 L p F P
0 g
s
.003 0 0 r
.43687 .55386 m .43377 .55355 L .42294 .5544 L p F P
0 g
s
.405 .813 .979 r
.43377 .55355 m .42294 .5544 L .4198 .55398 L p F P
0 g
s
.749 .707 .812 r
.24831 .32611 m .25095 .32975 L .24121 .33695 L p F P
0 g
s
.749 .707 .812 r
.24713 .32565 m .24831 .32611 L p .24121 .33695 L F P
0 g
s
.749 .707 .812 r
.23683 .33325 m .24713 .32565 L p .24121 .33695 L F P
0 g
s
.749 .707 .812 r
.24121 .33695 m .23894 .33615 L .23683 .33325 L p F P
0 g
s
0 0 0 r
.45227 .5529 m .45051 .55303 L .45082 .553 L closepath p F P
0 g
s
.022 0 0 r
.46361 .55197 m .45227 .5529 L .45082 .553 L p F P
0 g
s
.708 .714 .853 r
.31008 .31232 m .30386 .3156 L .30064 .31135 L p F P
0 g
s
.722 .711 .84 r
.28986 .31746 m .30064 .31135 L .30386 .3156 L p F P
0 g
s
.639 .616 .811 r
.54978 .33032 m .56086 .32709 L .56378 .3329 L p F P
0 g
s
.64 .62 .815 r
.55957 .32457 m .56086 .32709 L .54978 .33032 L p F P
0 g
s
.64 .62 .815 r
.54978 .33032 m .54888 .32857 L .55957 .32457 L p F P
0 g
s
.004 0 0 r
.45051 .55303 m .44774 .5529 L .43687 .55386 L p F P
0 g
s
.39 .814 .969 r
.44774 .5529 m .43687 .55386 L .43377 .55355 L p F P
0 g
s
.631 .602 .803 r
.56669 .33886 m .57781 .33591 L .58072 .34203 L p F P
0 g
s
.631 .604 .804 r
.57586 .33184 m .57781 .33591 L .56669 .33886 L p F P
0 g
s
.631 .604 .804 r
.56669 .33886 m .56536 .33609 L .57586 .33184 L p F P
0 g
s
.796 .477 .449 r
.22582 .5214 m .21889 .51949 L .21763 .51475 L p F P
0 g
s
.795 .474 .446 r
.21064 .51286 m .21763 .51475 L .21889 .51949 L p F P
0 g
s
.817 .605 .616 r
.1813 .47606 m .1797 .48163 L .1859 .48382 L p F P
0 g
s
.819 .592 .595 r
.18888 .49067 m .18475 .48925 L .1859 .48382 L p F P
0 g
s
.821 .595 .596 r
.1797 .48163 m .1859 .48382 L .18475 .48925 L p F P
0 g
s
.663 .673 .849 r
.49964 .31119 m .49904 .31026 L .48946 .31367 L closepath p F P
0 g
s
.665 .683 .857 r
.49607 .30584 m .49904 .31026 L .48946 .31367 L p F P
0 g
s
.665 .683 .857 r
.48509 .3097 m .49607 .30584 L p .48946 .31367 L F P
0 g
s
.794 .694 .754 r
.18315 .39075 m .18523 .38842 L .18193 .38329 L p F P
0 g
s
.82 .609 .618 r
.17516 .47385 m .1813 .47606 L .1797 .48163 L p F P
0 g
s
.818 .62 .636 r
.1813 .47606 m .17516 .47385 L .17719 .46816 L p F P
0 g
s
.815 .66 .691 r
.16538 .435 m .17115 .43738 L .16766 .44351 L p F P
0 g
s
.811 .665 .701 r
.16908 .42896 m .16538 .435 L .17115 .43738 L p F P
0 g
s
.567 .439 .665 r
.63286 .4593 m .63153 .45284 L .64194 .44858 L p F P
0 g
s
.573 .452 .677 r
.64148 .44657 m .64194 .44858 L .63153 .45284 L p F P
0 g
s
.669 .728 .893 r
.41539 .3096 m .42625 .30574 L .42932 .30938 L p F P
0 g
s
.658 .749 .917 r
.42625 .30574 m .41539 .3096 L .41229 .30601 L p F P
0 g
s
.765 .707 .797 r
.22792 .34456 m .22594 .34181 L .22436 .34311 L closepath p F P
0 g
s
.047 0 0 r
.35013 .55278 m .35093 .55282 L .35921 .5533 L p F P
0 g
s
.047 0 0 r
.35921 .5533 m .36403 .55356 L p .35013 .55278 L F P
0 g
s
.811 .569 .572 r
.19699 .49873 m .19041 .49668 L .19111 .49138 L p F P
0 g
s
.813 .571 .572 r
.18888 .49067 m .19111 .49138 L .19041 .49668 L p F P
0 g
s
.819 .622 .637 r
.17112 .46591 m .17719 .46816 L .17516 .47385 L p F P
0 g
s
.817 .632 .652 r
.17719 .46816 m .17112 .46591 L .17355 .46009 L p F P
0 g
s
.612 .566 .779 r
.60414 .36759 m .60352 .36609 L .61069 .36465 L closepath p F P
0 g
s
.796 .69 .749 r
.17751 .38828 m .18315 .39075 L .17728 .39764 L p F P
0 g
s
.794 .694 .754 r
.18193 .38329 m .17751 .38828 L .18315 .39075 L p F P
0 g
s
.412 0 .114 r
.54394 .53658 m .54257 .53851 L .5315 .53982 L p F P
0 g
s
.346 0 0 r
.52972 .54178 m .5315 .53982 L .54257 .53851 L p F P
0 g
s
.39 0 .038 r
.5315 .53982 m .52972 .54178 L .51767 .54397 L p F P
0 g
s
.669 .722 .889 r
.42932 .30938 m .4402 .30551 L .44326 .30925 L p F P
0 g
s
.66 .743 .911 r
.4402 .30551 m .42932 .30938 L .42625 .30574 L p F P
0 g
s
.705 .268 .208 r
.26146 .53684 m .25992 .53655 L .26061 .53607 L closepath p F P
0 g
s
.727 .297 .228 r
.24351 .53069 m .24443 .52987 L p .2538 .53518 L F P
0 g
s
.757 .361 .303 r
.24351 .53069 m .24261 .52943 L .24443 .52987 L closepath p F P
0 g
s
.181 .713 .827 r
.44774 .5529 m .45051 .55303 L .45227 .5529 L p F P
0 g
s
.564 .397 .614 r
.62436 .4756 m .62511 .48143 L .61953 .4834 L p F P
0 g
s
.554 .373 .591 r
.61953 .4834 m .62544 .48492 L p .61488 .4908 L F P
0 g
s
.553 .373 .592 r
.62544 .48492 m .61953 .4834 L .62511 .48143 L closepath p F P
0 g
s
.659 .66 .839 r
.50201 .31499 m .51301 .31118 L .51597 .3161 L p F P
0 g
s
.66 .667 .846 r
.51106 .30806 m .51301 .31118 L .50201 .31499 L p F P
0 g
s
.66 .667 .846 r
.50201 .31499 m .49964 .31119 L .51106 .30806 L p F P
0 g
s
.647 .633 .822 r
.53288 .32275 m .54392 .31927 L .54685 .32473 L p F P
0 g
s
.648 .638 .826 r
.54209 .31592 m .54392 .31927 L .53288 .32275 L p F P
0 g
s
.648 .638 .826 r
.53288 .32275 m .53117 .31966 L .54209 .31592 L p F P
0 g
s
.612 .567 .78 r
.61069 .36465 m .60352 .36609 L .6006 .35909 L p F P
0 g
s
.737 .71 .826 r
.27678 .32089 m .27584 .31962 L .27485 .32025 L closepath p F P
0 g
s
.554 .391 .614 r
.62511 .48143 m .62436 .4756 L .63495 .47159 L p F P
0 g
s
.562 .41 .633 r
.634 .46555 m .63495 .47159 L .62436 .4756 L p F P
0 g
s
.72 .718 .847 r
.30064 .31135 m .28986 .31746 L .28662 .31318 L p F P
0 g
s
.623 .589 .795 r
.59187 .33936 m .59478 .34577 L .58363 .34843 L p F P
0 g
s
.623 .589 .795 r
.58471 .34106 m .59187 .33936 L p .58363 .34843 L F P
0 g
s
.623 .589 .795 r
.58363 .34843 m .58101 .34265 L .58471 .34106 L p F P
0 g
s
.818 .634 .654 r
.16757 .45781 m .17355 .46009 L .17112 .46591 L p F P
0 g
s
.816 .642 .667 r
.17355 .46009 m .16757 .45781 L .17038 .45188 L p F P
0 g
s
.642 .627 .82 r
.55794 .32145 m .55957 .32457 L .54888 .32857 L p F P
0 g
s
.642 .627 .82 r
.54888 .32857 m .54685 .32473 L .55794 .32145 L p F P
0 g
s
.181 .713 .827 r
.45227 .5529 m .46171 .552 L p .44774 .5529 L F P
0 g
s
.127 .676 .773 r
.46171 .552 m .45227 .5529 L .46361 .55197 L closepath p F P
0 g
s
.811 .548 .54 r
.20347 .5059 m .19686 .50387 L .19699 .49873 L p F P
0 g
s
.812 .548 .54 r
.19041 .49668 m .19699 .49873 L .19686 .50387 L p F P
0 g
s
.104 0 0 r
.35013 .55278 m .34844 .55261 L .35093 .55282 L closepath p F P
0 g
s
.669 .714 .882 r
.44326 .30925 m .45416 .30535 L .45719 .30924 L p F P
0 g
s
.663 .734 .902 r
.45416 .30535 m .44326 .30925 L .4402 .30551 L p F P
0 g
s
.77 .403 .36 r
.22652 .52307 m .22742 .52183 L p .23536 .52764 L F P
0 g
s
.786 .437 .395 r
.22652 .52307 m .22582 .5214 L .22742 .52183 L closepath p F P
0 g
s
.758 .709 .806 r
.23894 .33615 m .23683 .33325 L .23506 .33462 L closepath p F P
0 g
s
.771 .705 .789 r
.21545 .35157 m .21503 .35097 L .2147 .35126 L closepath p F P
0 g
s
.127 0 0 r
.33823 .55175 m .33531 .55151 L .33625 .55154 L closepath p F P
0 g
s
.633 .611 .81 r
.57489 .32988 m .57586 .33184 L .56536 .33609 L p F P
0 g
s
.633 .611 .81 r
.56536 .33609 m .56378 .3329 L .57489 .32988 L p F P
0 g
s
.804 .68 .727 r
.1668 .41101 m .1725 .41345 L .16779 .41996 L p F P
0 g
s
.804 .681 .729 r
.1718 .4044 m .1668 .41101 L .1725 .41345 L p F P
0 g
s
.542 .346 .564 r
.61517 .49616 m .61488 .4908 L .62564 .48703 L p F P
0 g
s
.554 .373 .591 r
.62544 .48492 m .62564 .48703 L .61488 .4908 L p F P
0 g
s
.546 .002 0 r
.29159 .5448 m .29132 .54476 L .29143 .54473 L closepath p F P
0 g
s
.751 .336 .263 r
.24261 .52943 m .24351 .53069 L .24104 .53239 L p F P
0 g
s
.751 .336 .263 r
.23536 .52764 m .24261 .52943 L p .24104 .53239 L F P
0 g
s
.078 .629 .825 r
.34844 .55261 m .35013 .55278 L .34685 .55209 L p F P
0 g
s
.745 .705 .814 r
.25095 .32975 m .2536 .32789 L .24831 .32611 L closepath p F P
0 g
s
.813 .571 .572 r
.19041 .49668 m .18885 .49619 L .18888 .49067 L p F P
0 g
s
.821 .578 .571 r
.18475 .48925 m .18888 .49067 L .18885 .49619 L p F P
0 g
s
.52 .249 .443 r
.59298 .51301 m .5925 .51676 L .58136 .51939 L p F P
0 g
s
.513 .233 .427 r
.58117 .52066 m .58136 .51939 L .5925 .51676 L p F P
0 g
s
.81 .666 .704 r
.16908 .42896 m .16921 .42876 L .16892 .42864 L closepath p F P
0 g
s
.805 .672 .716 r
.16585 .42281 m .16779 .41996 L p .16921 .42876 L F P
0 g
s
.805 .672 .716 r
.16921 .42876 m .16892 .42864 L .16585 .42281 L p F P
0 g
s
.364 0 0 r
.30263 .54763 m .30056 .5473 L .29159 .5448 L p F P
0 g
s
.198 0 0 r
.29132 .54476 m .29159 .5448 L .30056 .5473 L p F P
0 g
s
.814 .667 .701 r
.16538 .435 m .16908 .42896 L .16892 .42864 L p F P
0 g
s
.771 .704 .789 r
.20895 .34879 m .2147 .35126 L .20604 .35907 L p F P
0 g
s
.771 .704 .789 r
.20076 .35612 m .20895 .34879 L p .20604 .35907 L F P
0 g
s
.771 .704 .789 r
.20604 .35907 m .20154 .35722 L .20076 .35612 L p F P
0 g
s
.776 .701 .781 r
.20406 .3609 m .20604 .35907 L .20154 .35722 L closepath p F P
0 g
s
.198 0 0 r
.28798 .54511 m .29132 .54476 L p .30056 .5473 L F P
0 g
s
.485 0 0 r
.28798 .54511 m .28333 .54334 L .29132 .54476 L closepath p F P
0 g
s
.781 .702 .777 r
.19807 .36665 m .20406 .3609 L .20154 .35722 L p F P
0 g
s
.588 .508 .733 r
.63 .40545 m .63567 .40287 L p .63356 .41269 L F P
0 g
s
.588 .508 .733 r
.63356 .41269 m .63236 .41282 L .63 .40545 L p F P
0 g
s
.591 .518 .741 r
.63 .40545 m .62939 .40361 L .63567 .40287 L closepath p F P
0 g
s
.817 .645 .668 r
.16448 .44955 m .17038 .45188 L .16757 .45781 L p F P
0 g
s
.815 .652 .68 r
.17038 .45188 m .16448 .44955 L .16766 .44351 L p F P
0 g
s
.588 .508 .732 r
.63247 .41318 m .63236 .41282 L .63356 .41269 L closepath p F P
0 g
s
.583 .497 .723 r
.63473 .42067 m .63247 .41318 L .63356 .41269 L p F P
0 g
s
.814 .667 .701 r
.16892 .42864 m .16352 .42634 L p .16538 .435 L F P
0 g
s
.812 .674 .712 r
.16892 .42864 m .16585 .42281 L .16352 .42634 L closepath p F P
0 g
s
.772 .708 .791 r
.21172 .34637 m .20895 .34879 L .2147 .35126 L p F P
0 g
s
.772 .708 .791 r
.2147 .35126 m .21503 .35097 L .21172 .34637 L p F P
0 g
s
.768 .707 .795 r
.22436 .34311 m .21503 .35097 L .21172 .34637 L p F P
0 g
s
.591 .518 .741 r
.63567 .40287 m .62939 .40361 L .62733 .39749 L p F P
0 g
s
.668 .705 .874 r
.45719 .30924 m .46812 .30532 L .47114 .30937 L p F P
0 g
s
.665 .722 .892 r
.46812 .30532 m .45719 .30924 L .45416 .30535 L p F P
0 g
s
.799 .687 .741 r
.17728 .39764 m .17401 .40164 L .17072 .39624 L p F P
0 g
s
.799 .687 .741 r
.17072 .39624 m .17157 .3952 L .17728 .39764 L p F P
0 g
s
.796 .69 .749 r
.17728 .39764 m .17157 .3952 L .17751 .38828 L p F P
0 g
s
.738 .711 .826 r
.26177 .32227 m .26833 .31803 L .27485 .32025 L p F P
0 g
s
.738 .714 .828 r
.27258 .31533 m .26833 .31803 L .27485 .32025 L p F P
0 g
s
.738 .714 .828 r
.27485 .32025 m .27584 .31962 L .27258 .31533 L p F P
0 g
s
.783 .7 .773 r
.19807 .36665 m .19304 .37161 L .18973 .36674 L p F P
0 g
s
.783 .7 .773 r
.18973 .36674 m .19232 .36419 L .19807 .36665 L p F P
0 g
s
.781 .702 .777 r
.2002 .35663 m .19232 .36419 L .19807 .36665 L p F P
0 g
s
.781 .702 .777 r
.20154 .35722 m .2002 .35663 L p .19807 .36665 L F P
0 g
s
.788 .428 .376 r
.22582 .5214 m .22652 .52307 L .2248 .52506 L p F P
0 g
s
.788 .428 .376 r
.21889 .51949 m .22582 .5214 L p .2248 .52506 L F P
0 g
s
.81 .523 .502 r
.20876 .51234 m .20393 .51086 L .20347 .5059 L p F P
0 g
s
.812 .523 .5 r
.19686 .50387 m .20347 .5059 L .20393 .51086 L p F P
0 g
s
.641 .13 .017 r
.27376 .54174 m .26697 .54034 L .26146 .53684 L p F P
0 g
s
.592 .053 0 r
.25992 .53655 m .26146 .53684 L .26697 .54034 L p F P
0 g
s
.741 .709 .821 r
.25851 .31788 m .26177 .32227 L .2536 .32789 L p F P
0 g
s
.741 .709 .821 r
.24768 .32525 m .25851 .31788 L p .2536 .32789 L F P
0 g
s
.741 .709 .821 r
.2536 .32789 m .24831 .32611 L .24768 .32525 L p F P
0 g
s
.591 .518 .741 r
.62733 .39749 m .63549 .39374 L p .63567 .40287 L F P
0 g
s
.594 .527 .749 r
.62733 .39749 m .62643 .39493 L .63549 .39374 L closepath p F P
0 g
s
.727 .715 .838 r
.28662 .31318 m .27584 .31962 L .27258 .31533 L p F P
0 g
s
.579 .486 .713 r
.63535 .42285 m .63473 .42067 L .64493 .41608 L p F P
0 g
s
.583 .497 .723 r
.64366 .41189 m .64493 .41608 L .63473 .42067 L p F P
0 g
s
.583 .497 .723 r
.63356 .41269 m .64366 .41189 L p .63473 .42067 L F P
0 g
s
.708 .714 .853 r
.30064 .31135 m .30223 .31055 L .31008 .31232 L p F P
0 g
s
.714 .722 .856 r
.3114 .30597 m .30223 .31055 L .31008 .31232 L p F P
0 g
s
.714 .722 .856 r
.31008 .31232 m .31462 .30996 L .3114 .30597 L p F P
0 g
s
.787 .701 .77 r
.19064 .37405 m .19304 .37161 L .18973 .36674 L p F P
0 g
s
.567 .439 .665 r
.64194 .44858 m .64328 .45504 L .63286 .4593 L p F P
0 g
s
.561 .423 .65 r
.63286 .4593 m .64328 .45504 L p .64165 .46246 L F P
0 g
s
.561 .423 .65 r
.64165 .46246 m .63333 .46188 L .63286 .4593 L p F P
0 g
s
.594 .528 .75 r
.63549 .39374 m .62643 .39493 L .62445 .38929 L p F P
0 g
s
.579 .486 .713 r
.63681 .42795 m .63535 .42285 L .64667 .42215 L p F P
0 g
s
.579 .486 .713 r
.64493 .41608 m .64667 .42215 L .63535 .42285 L p F P
0 g
s
.654 .652 .836 r
.51597 .3161 m .52699 .31243 L .52994 .31748 L p F P
0 g
s
.655 .658 .841 r
.52699 .31243 m .51597 .3161 L .51301 .31118 L p F P
0 g
s
.768 .707 .795 r
.21172 .34637 m .21851 .34067 L .22436 .34311 L p F P
0 g
s
.766 .709 .799 r
.22265 .33727 m .21851 .34067 L .22436 .34311 L p F P
0 g
s
.766 .709 .799 r
.22436 .34311 m .22594 .34181 L .22265 .33727 L p F P
0 g
s
.375 0 .068 r
.54257 .53851 m .54394 .53658 L .55567 .53402 L p F P
0 g
s
.461 .08 .229 r
.55647 .53239 m .55567 .53402 L .54394 .53658 L p F P
0 g
s
.787 .699 .768 r
.18501 .37156 m .19064 .37405 L .18379 .38126 L p F P
0 g
s
.787 .701 .77 r
.18973 .36674 m .18501 .37156 L .19064 .37405 L p F P
0 g
s
.686 .206 .104 r
.25702 .53772 m .2538 .53518 L .25992 .53655 L closepath p F P
0 g
s
.592 .053 0 r
.25702 .53772 m .25992 .53655 L p .26697 .54034 L F P
0 g
s
.583 .497 .724 r
.64366 .41189 m .63356 .41269 L .64264 .40855 L closepath p F P
0 g
s
.588 .508 .733 r
.64067 .40239 m .64264 .40855 L .63356 .41269 L p F P
0 g
s
.588 .508 .733 r
.63567 .40287 m .64067 .40239 L p .63356 .41269 L F P
0 g
s
.76 .709 .804 r
.23506 .33462 m .22594 .34181 L .22265 .33727 L p F P
0 g
s
.143 .688 .781 r
.46171 .552 m .46361 .55197 L .47087 .55129 L p F P
0 g
s
.665 .71 .881 r
.48209 .30547 m .47114 .30937 L .46812 .30532 L p F P
0 g
s
.667 .695 .867 r
.47114 .30937 m .48209 .30547 L .48509 .3097 L p F P
0 g
s
.802 .688 .739 r
.1718 .4044 m .17401 .40164 L .17072 .39624 L p F P
0 g
s
.297 0 0 r
.51757 .54405 m .51665 .54413 L .51767 .54397 L closepath p F P
0 g
s
.224 0 0 r
.51665 .54413 m .51757 .54405 L p .50362 .54695 L F P
0 g
s
.612 .567 .78 r
.6006 .35909 m .6118 .35688 L p .61069 .36465 L F P
0 g
s
.611 .569 .782 r
.61041 .35354 m .6118 .35688 L .6006 .35909 L p F P
0 g
s
.611 .569 .782 r
.6006 .35909 m .60023 .35821 L .61041 .35354 L p F P
0 g
s
.817 .654 .681 r
.16185 .44115 m .16766 .44351 L .16448 .44955 L p F P
0 g
s
.815 .66 .691 r
.16766 .44351 m .16185 .44115 L .16538 .435 L p F P
0 g
s
.649 .644 .831 r
.54099 .31397 m .54209 .31592 L .53117 .31966 L p F P
0 g
s
.649 .644 .831 r
.53117 .31966 m .52994 .31748 L .54099 .31397 L p F P
0 g
s
.594 .528 .75 r
.62445 .38929 m .63299 .38531 L p .63549 .39374 L F P
0 g
s
.597 .537 .757 r
.62445 .38929 m .62349 .38668 L .63299 .38531 L closepath p F P
0 g
s
.634 .614 .813 r
.57489 .32988 m .56378 .3329 L .56086 .32709 L p F P
0 g
s
.576 .475 .703 r
.63681 .42795 m .64703 .4234 L p .64176 .4337 L F P
0 g
s
.576 .475 .703 r
.64176 .4337 m .63839 .43384 L .63681 .42795 L p F P
0 g
s
.579 .486 .713 r
.64667 .42215 m .64703 .4234 L .63681 .42795 L p F P
0 g
s
.047 0 0 r
.36403 .55356 m .36078 .55269 L .35013 .55278 L p F P
0 g
s
.395 .783 .989 r
.35013 .55278 m .36078 .55269 L .35766 .55133 L p F P
0 g
s
.395 .783 .989 r
.34685 .55209 m .35013 .55278 L p .35766 .55133 L F P
0 g
s
.04 .604 .792 r
.33823 .55175 m .34685 .55209 L p .33293 .55116 L F P
0 g
s
.04 .604 .792 r
.33293 .55116 m .33531 .55151 L .33823 .55175 L p F P
0 g
s
.614 .577 .788 r
.60889 .35004 m .61041 .35354 L .60023 .35821 L p F P
0 g
s
.614 .577 .788 r
.60023 .35821 m .59769 .35236 L .60889 .35004 L p F P
0 g
s
.507 .237 .439 r
.5925 .51676 m .59298 .51301 L .60404 .50965 L p F P
0 g
s
.531 .288 .492 r
.60429 .50483 m .60404 .50965 L .59298 .51301 L p F P
0 g
s
.271 0 0 r
.51757 .54405 m .51767 .54397 L .52972 .54178 L p F P
0 g
s
.625 .596 .801 r
.58101 .34265 m .58072 .34203 L .58471 .34106 L closepath p F P
0 g
s
.642 .63 .823 r
.55794 .32145 m .54685 .32473 L .54392 .31927 L p F P
0 g
s
.597 .537 .758 r
.63299 .38531 m .62349 .38668 L .62134 .38082 L p F P
0 g
s
.477 .161 .351 r
.58014 .52472 m .58117 .52066 L .59239 .5175 L p F P
0 g
s
.513 .233 .427 r
.5925 .51676 m .59239 .5175 L .58117 .52066 L p F P
0 g
s
.493 .176 .357 r
.58117 .52066 m .58014 .52472 L .56876 .52768 L p F P
0 g
s
.727 .297 .228 r
.2538 .53518 m .24618 .5335 L .24351 .53069 L p F P
0 g
s
.726 .297 .231 r
.24618 .5335 m .24104 .53239 L .24351 .53069 L closepath p F P
0 g
s
.561 .422 .65 r
.634 .46555 m .63333 .46188 L .64165 .46246 L closepath p F P
0 g
s
.787 .699 .768 r
.17863 .37824 m .18501 .37156 L p .18379 .38126 L F P
0 g
s
.787 .699 .768 r
.18379 .38126 m .17938 .37935 L .17863 .37824 L p F P
0 g
s
.791 .695 .758 r
.18193 .38329 m .18379 .38126 L .17938 .37935 L closepath p F P
0 g
s
.795 .474 .446 r
.21889 .51949 m .21193 .51758 L .21064 .51286 L p F P
0 g
s
.796 .475 .446 r
.20876 .51234 m .21064 .51286 L .21193 .51758 L p F P
0 g
s
.809 .674 .715 r
.16585 .42281 m .16779 .41996 L .16335 .4181 L closepath p F P
0 g
s
.804 .68 .727 r
.16261 .41678 m .1668 .41101 L p .16779 .41996 L F P
0 g
s
.804 .68 .727 r
.16779 .41996 m .16335 .4181 L .16261 .41678 L p F P
0 g
s
.462 .102 .268 r
.56876 .52768 m .56758 .5306 L .55647 .53239 L p F P
0 g
s
.43 .042 .198 r
.55567 .53402 m .55647 .53239 L .56758 .5306 L p F P
0 g
s
.271 0 0 r
.52972 .54178 m .52862 .54257 L .51757 .54405 L p F P
0 g
s
0 0 0 r
.51757 .54405 m .52862 .54257 L .52621 .54347 L p F P
0 g
s
0 0 0 r
.51464 .5455 m .51757 .54405 L p .52621 .54347 L F P
0 g
s
.224 0 0 r
.51757 .54405 m .51464 .5455 L .50362 .54695 L p F P
0 g
s
0 .55 .75 r
.33293 .55116 m .32847 .55074 L .33531 .55151 L closepath p F P
0 g
s
.626 .6 .804 r
.58471 .34106 m .58072 .34203 L .57781 .33591 L p F P
0 g
s
.805 .685 .732 r
.16622 .40192 m .1718 .4044 L .1668 .41101 L p F P
0 g
s
.802 .688 .739 r
.17072 .39624 m .16622 .40192 L .1718 .4044 L p F P
0 g
s
.681 .734 .891 r
.34255 .30804 m .35332 .30382 L .3565 .30742 L p F P
0 g
s
.669 .746 .909 r
.35332 .30382 m .34255 .30804 L .33936 .3043 L p F P
0 g
s
.69 .728 .879 r
.32859 .30888 m .33936 .3043 L .34255 .30804 L p F P
0 g
s
.682 .738 .893 r
.33936 .3043 m .32859 .30888 L .32539 .305 L p F P
0 g
s
.699 .724 .869 r
.31462 .30996 m .32539 .305 L .32859 .30888 L p F P
0 g
s
.664 .697 .871 r
.49607 .30584 m .48509 .3097 L .48209 .30547 L p F P
0 g
s
.795 .696 .755 r
.17751 .38828 m .18193 .38329 L .17938 .37935 L p F P
0 g
s
.672 .74 .902 r
.3565 .30742 m .36728 .3035 L .37045 .30696 L p F P
0 g
s
.655 .756 .924 r
.36728 .3035 m .3565 .30742 L .35332 .30382 L p F P
0 g
s
.76 .709 .804 r
.22265 .33727 m .22911 .3322 L .23506 .33462 L p F P
0 g
s
.759 .711 .807 r
.23353 .3288 m .22911 .3322 L .23506 .33462 L p F P
0 g
s
.759 .711 .807 r
.23506 .33462 m .23683 .33325 L .23353 .3288 L p F P
0 g
s
.736 .712 .829 r
.26833 .31803 m .26177 .32227 L .25851 .31788 L p F P
0 g
s
.82 .609 .618 r
.1797 .48163 m .17354 .47942 L .17516 .47385 L p F P
0 g
s
.821 .595 .596 r
.18475 .48925 m .17854 .48707 L .1797 .48163 L p F P
0 g
s
.822 .597 .597 r
.17354 .47942 m .1797 .48163 L .17854 .48707 L p F P
0 g
s
.074 .635 .705 r
.47568 .5508 m .47087 .55129 L .47653 .55071 L closepath p F P
0 g
s
.143 .688 .781 r
.47087 .55129 m .47568 .5508 L p .46171 .552 L F P
0 g
s
.694 .731 .879 r
.32539 .305 m .31462 .30996 L .3114 .30597 L p F P
0 g
s
.576 .475 .703 r
.63871 .43504 m .63839 .43384 L .64176 .4337 L closepath p F P
0 g
s
.519 .279 .49 r
.60404 .50965 m .60429 .50483 L .61521 .50126 L p F P
0 g
s
.538 .32 .532 r
.61517 .49616 m .61521 .50126 L .60429 .50483 L p F P
0 g
s
.821 .612 .619 r
.16906 .47161 m .17516 .47385 L .17354 .47942 L p F P
0 g
s
.819 .622 .637 r
.17516 .47385 m .16906 .47161 L .17112 .46591 L p F P
0 g
s
.753 .713 .814 r
.24713 .32565 m .23683 .33325 L .23353 .3288 L p F P
0 g
s
.664 .746 .911 r
.37045 .30696 m .38125 .30326 L .3844 .30659 L p F P
0 g
s
.642 .765 .938 r
.38125 .30326 m .37045 .30696 L .36728 .3035 L p F P
0 g
s
.66 .671 .85 r
.51005 .30648 m .51106 .30806 L .49964 .31119 L p F P
0 g
s
.66 .671 .85 r
.49964 .31119 m .49904 .31026 L .51005 .30648 L p F P
0 g
s
.77 .403 .36 r
.23536 .52764 m .22805 .52585 L .22652 .52307 L p F P
0 g
s
.771 .403 .359 r
.22805 .52585 m .2248 .52506 L .22652 .52307 L closepath p F P
0 g
s
.821 .578 .571 r
.18885 .49619 m .18408 .49455 L .18475 .48925 L p F P
0 g
s
.823 .579 .571 r
.17854 .48707 m .18475 .48925 L .18408 .49455 L p F P
0 g
s
.57 .461 .691 r
.64041 .4419 m .63871 .43504 L .64176 .4337 L p F P
0 g
s
.597 .537 .758 r
.62134 .38082 m .62816 .37761 L p .63299 .38531 L F P
0 g
s
.6 .546 .765 r
.62134 .38082 m .62056 .37879 L .62816 .37761 L closepath p F P
0 g
s
.816 .663 .693 r
.15967 .43259 m .16538 .435 L .16185 .44115 L p F P
0 g
s
.814 .667 .701 r
.16352 .42634 m .15967 .43259 L .16538 .435 L p F P
0 g
s
.554 .391 .614 r
.63495 .47159 m .6357 .47742 L .62511 .48143 L p F P
0 g
s
.544 .367 .591 r
.62511 .48143 m .6357 .47742 L p .62811 .48611 L F P
0 g
s
.544 .367 .591 r
.62811 .48611 m .62544 .48492 L .62511 .48143 L p F P
0 g
s
.375 0 0 r
.28333 .54334 m .28798 .54511 L .28541 .54494 L p F P
0 g
s
.375 0 0 r
.27487 .54193 m .28333 .54334 L p .28541 .54494 L F P
0 g
s
.626 .125 .041 r
.27422 .54163 m .27487 .54193 L .28333 .54334 L p F P
0 g
s
.82 .626 .64 r
.1651 .46363 m .17112 .46591 L .16906 .47161 L p F P
0 g
s
.818 .634 .654 r
.17112 .46591 m .1651 .46363 L .16757 .45781 L p F P
0 g
s
.043 .61 .773 r
.37795 .55402 m .37474 .55302 L .36403 .55356 L p F P
0 g
s
.449 .799 .998 r
.36403 .55356 m .37474 .55302 L .3727 .55205 L p F P
0 g
s
.449 .799 .998 r
.36078 .55269 m .36403 .55356 L p .3727 .55205 L F P
0 g
s
.796 .475 .446 r
.21193 .51758 m .20681 .51617 L .20876 .51234 L p F P
0 g
s
.808 .489 .451 r
.20393 .51086 m .20876 .51234 L .20681 .51617 L p F P
0 g
s
.659 .75 .917 r
.3844 .30659 m .39521 .30304 L .39834 .30629 L p F P
0 g
s
.633 .773 .947 r
.39521 .30304 m .3844 .30659 L .38125 .30326 L p F P
0 g
s
.65 .65 .837 r
.54099 .31397 m .52994 .31748 L .52699 .31243 L p F P
0 g
s
.812 .675 .712 r
.16352 .42634 m .16585 .42281 L .16335 .4181 L p F P
0 g
s
.708 .713 .852 r
.30064 .31135 m .30223 .31055 L .29957 .30998 L closepath p F P
0 g
s
.72 .718 .847 r
.29957 .30998 m .30064 .31135 L p .28662 .31318 L F P
0 g
s
.6 .546 .766 r
.62816 .37761 m .62056 .37879 L .61798 .37207 L p F P
0 g
s
.44 .076 .249 r
.56758 .5306 m .56876 .52768 L .58014 .52472 L p F P
0 g
s
.199 0 0 r
.3097 .5485 m .30521 .54769 L p .31457 .54912 L F P
0 g
s
.23 0 0 r
.3097 .5485 m .30263 .54763 L .30521 .54769 L closepath p F P
0 g
s
0 .523 .726 r
.3097 .5485 m .3157 .54909 L p .3036 .54772 L F P
0 g
s
0 .523 .726 r
.30181 .54752 m .3097 .5485 L .3036 .54772 L F
.199 0 0 r
.31867 .54975 m .3097 .5485 L p .31457 .54912 L F P
0 g
s
.796 .694 .753 r
.17193 .38578 m .17751 .38828 L .17157 .3952 L p F P
0 g
s
.795 .696 .755 r
.17812 .37878 m .17193 .38578 L .17751 .38828 L p F P
0 g
s
.795 .696 .755 r
.17938 .37935 m .17812 .37878 L p .17751 .38828 L F P
0 g
s
.812 .548 .54 r
.19686 .50387 m .19027 .50182 L .19041 .49668 L p F P
0 g
s
.814 .55 .54 r
.18885 .49619 m .19041 .49668 L .19027 .50182 L p F P
0 g
s
.747 .322 .24 r
.22805 .52585 m .23536 .52764 L .23865 .53179 L p F P
0 g
s
.751 .336 .263 r
.24104 .53239 m .23865 .53179 L .23536 .52764 L p F P
0 g
s
.779 .706 .783 r
.20154 .35722 m .20076 .35612 L .2002 .35663 L closepath p F P
0 g
s
.657 .751 .919 r
.39834 .30629 m .40918 .30279 L .41229 .30601 L p F P
0 g
s
.63 .778 .952 r
.40918 .30279 m .39834 .30629 L .39521 .30304 L p F P
0 g
s
.661 .685 .862 r
.51005 .30648 m .49904 .31026 L .49607 .30584 L p F P
0 g
s
.819 .637 .656 r
.16163 .4555 m .16757 .45781 L .1651 .46363 L p F P
0 g
s
.817 .645 .668 r
.16757 .45781 m .16163 .4555 L .16448 .44955 L p F P
0 g
s
.553 .404 .632 r
.63495 .47159 m .634 .46555 L .64165 .46246 L p F P
0 g
s
.085 0 0 r
.48966 .54918 m .48925 .54924 L .47653 .55071 L p F P
0 g
s
.095 .651 .716 r
.47568 .5508 m .47653 .55071 L .48925 .54924 L p F P
0 g
s
.751 .711 .814 r
.24831 .32611 m .24768 .32525 L .24713 .32565 L closepath p F P
0 g
s
.662 .155 .029 r
.2538 .53518 m .25702 .53772 L .25543 .53808 L p F P
0 g
s
.662 .155 .029 r
.24618 .5335 m .2538 .53518 L p .25543 .53808 L F P
0 g
s
.705 .715 .857 r
.30817 .30209 m .3114 .30597 L .30223 .31055 L p F P
0 g
s
.705 .715 .857 r
.2974 .30726 m .30817 .30209 L p .30223 .31055 L F P
0 g
s
.705 .715 .857 r
.30223 .31055 m .29957 .30998 L .2974 .30726 L p F P
0 g
s
.614 .578 .789 r
.60615 .34372 m .60889 .35004 L .59769 .35236 L p F P
0 g
s
.614 .578 .789 r
.59769 .35236 m .59597 .34841 L .60615 .34372 L p F P
0 g
s
.634 .777 .95 r
.42316 .30249 m .41229 .30601 L .40918 .30279 L p F P
0 g
s
.658 .749 .917 r
.41229 .30601 m .42316 .30249 L .42625 .30574 L p F P
0 g
s
.609 .56 .774 r
.61472 .36389 m .61069 .36465 L .61435 .36299 L closepath p F P
0 g
s
.612 .567 .78 r
.6118 .35688 m .61435 .36299 L .61069 .36465 L p F P
0 g
s
.02 0 0 r
.50174 .5475 m .50362 .54695 L .51464 .5455 L p F P
0 g
s
.484 .808 1 r
.37795 .55402 m .38871 .55315 L .38744 .55251 L p F P
0 g
s
.484 .808 1 r
.37474 .55302 m .37795 .55402 L p .38744 .55251 L F P
0 g
s
.113 .66 .822 r
.39189 .55423 m .38871 .55315 L .37795 .55402 L p F P
0 g
s
.788 .428 .376 r
.2248 .52506 m .22096 .52399 L .21889 .51949 L p F P
0 g
s
.787 .423 .366 r
.21193 .51758 m .21889 .51949 L .22096 .52399 L p F P
0 g
s
.72 .718 .847 r
.28662 .31318 m .29499 .30857 L .29957 .30998 L p F P
0 g
s
.716 .72 .852 r
.29499 .30857 m .28662 .31318 L .28337 .30897 L p F P
0 g
s
.727 .715 .838 r
.27258 .31533 m .28337 .30897 L .28662 .31318 L p F P
0 g
s
.805 .685 .732 r
.1668 .41101 m .16116 .40855 L .16622 .40192 L p F P
0 g
s
.808 .682 .725 r
.1668 .41101 m .16261 .41678 L .15934 .41108 L p F P
0 g
s
.808 .682 .725 r
.15934 .41108 m .16116 .40855 L .1668 .41101 L p F P
0 g
s
.814 .55 .54 r
.19027 .50182 m .18819 .50117 L .18885 .49619 L p F P
0 g
s
.823 .559 .54 r
.18408 .49455 m .18885 .49619 L .18819 .50117 L p F P
0 g
s
.736 .712 .829 r
.25851 .31788 m .26176 .31582 L .26833 .31803 L p F P
0 g
s
.737 .716 .831 r
.26931 .31109 m .26176 .31582 L .26833 .31803 L p F P
0 g
s
.737 .716 .831 r
.26833 .31803 m .27258 .31533 L .26931 .31109 L p F P
0 g
s
.527 .312 .531 r
.61521 .50126 m .61517 .49616 L .62594 .49239 L p F P
0 g
s
.542 .346 .564 r
.62564 .48703 m .62594 .49239 L .61517 .49616 L p F P
0 g
s
.565 .449 .68 r
.64041 .4419 m .65066 .4374 L p .64628 .4467 L F P
0 g
s
.565 .449 .68 r
.64628 .4467 m .64148 .44657 L .64041 .4419 L p F P
0 g
s
.57 .461 .691 r
.64973 .43368 m .65066 .4374 L .64041 .4419 L p F P
0 g
s
.57 .461 .691 r
.64176 .4337 m .64973 .43368 L p .64041 .4419 L F P
0 g
s
.812 .523 .5 r
.20393 .51086 m .19734 .50883 L .19686 .50387 L p F P
0 g
s
.812 .522 .499 r
.19027 .50182 m .19686 .50387 L .19734 .50883 L p F P
0 g
s
.66 .743 .911 r
.42625 .30574 m .43714 .30215 L .4402 .30551 L p F P
0 g
s
.642 .772 .942 r
.43714 .30215 m .42625 .30574 L .42316 .30249 L p F P
0 g
s
.78 .709 .785 r
.2002 .35663 m .20076 .35612 L .19743 .3515 L p F P
0 g
s
.775 .708 .789 r
.20895 .34879 m .20076 .35612 L .19743 .3515 L p F P
0 g
s
.753 .713 .814 r
.23353 .3288 m .24112 .32325 L .24713 .32565 L p F P
0 g
s
.752 .714 .816 r
.24439 .3209 m .24112 .32325 L .24713 .32565 L p F P
0 g
s
.752 .714 .816 r
.24713 .32565 m .24768 .32525 L .24439 .3209 L p F P
0 g
s
.78 .709 .785 r
.19743 .3515 m .19463 .3541 L .2002 .35663 L p F P
0 g
s
.781 .704 .779 r
.19463 .3541 m .2002 .35663 L .19232 .36419 L p F P
0 g
s
.815 .671 .704 r
.15791 .42389 m .16352 .42634 L .15967 .43259 L p F P
0 g
s
.812 .675 .712 r
.16208 .41754 m .15791 .42389 L .16352 .42634 L p F P
0 g
s
.812 .675 .712 r
.16335 .4181 m .16208 .41754 L p .16352 .42634 L F P
0 g
s
.819 .648 .671 r
.15863 .4472 m .16448 .44955 L .16163 .4555 L p F P
0 g
s
.817 .654 .681 r
.16448 .44955 m .15863 .4472 L .16185 .44115 L p F P
0 g
s
.745 .716 .824 r
.25851 .31788 m .24768 .32525 L .24439 .3209 L p F P
0 g
s
.6 .546 .766 r
.61798 .37207 m .62099 .37064 L p .62816 .37761 L F P
0 g
s
.603 .555 .773 r
.61798 .37207 m .61764 .37119 L .62099 .37064 L closepath p F P
0 g
s
.623 .592 .798 r
.59187 .33936 m .58471 .34106 L .59132 .33816 L closepath p F P
0 g
s
.626 .6 .804 r
.58896 .33318 m .59132 .33816 L .58471 .34106 L p F P
0 g
s
.626 .6 .804 r
.57781 .33591 m .58896 .33318 L p .58471 .34106 L F P
0 g
s
.775 .708 .789 r
.19743 .3515 m .20327 .34628 L .20895 .34879 L p F P
0 g
s
.773 .71 .792 r
.20841 .3418 m .20327 .34628 L .20895 .34879 L p F P
0 g
s
.773 .71 .792 r
.20895 .34879 m .21172 .34637 L .20841 .3418 L p F P
0 g
s
.768 .709 .797 r
.21851 .34067 m .21172 .34637 L .20841 .3418 L p F P
0 g
s
.719 .719 .85 r
.29957 .30998 m .2974 .30726 L .29499 .30857 L closepath p F P
0 g
s
.8 .69 .743 r
.17072 .39624 m .17157 .3952 L .16952 .3943 L closepath p F P
0 g
s
.796 .694 .753 r
.16741 .39103 m .17193 .38578 L p .17157 .3952 L F P
0 g
s
.796 .694 .753 r
.17157 .3952 m .16952 .3943 L .16741 .39103 L p F P
0 g
s
.603 .556 .774 r
.62099 .37064 m .61764 .37119 L .61472 .36389 L p F P
0 g
s
.563 .019 0 r
.27487 .54193 m .27376 .54174 L .27422 .54163 L closepath p F P
0 g
s
.784 .702 .774 r
.19232 .36419 m .18973 .36674 L .18641 .36192 L p F P
0 g
s
.784 .702 .774 r
.18641 .36192 m .18663 .3617 L .19232 .36419 L p F P
0 g
s
.781 .704 .779 r
.19232 .36419 m .18663 .3617 L .19463 .3541 L p F P
0 g
s
.634 .614 .813 r
.56086 .32709 m .57198 .32406 L .57489 .32988 L p F P
0 g
s
.635 .618 .816 r
.57006 .32026 m .57198 .32406 L .56086 .32709 L p F P
0 g
s
.635 .618 .816 r
.56086 .32709 m .55957 .32457 L .57006 .32026 L p F P
0 g
s
.586 .508 .733 r
.64067 .40239 m .63567 .40287 L .64016 .4008 L closepath p F P
0 g
s
.591 .518 .741 r
.63771 .39349 m .64016 .4008 L .63567 .40287 L p F P
0 g
s
.591 .518 .741 r
.63549 .39374 m .63771 .39349 L p .63567 .40287 L F P
0 g
s
.663 .734 .902 r
.4402 .30551 m .45112 .30183 L .45416 .30535 L p F P
0 g
s
.651 .761 .93 r
.45112 .30183 m .4402 .30551 L .43714 .30215 L p F P
0 g
s
.389 .798 .981 r
.39189 .55423 m .40268 .5531 L .40584 .55421 L p F P
0 g
s
.506 .813 1 r
.39189 .55423 m .40268 .5531 L .40187 .55268 L p F P
0 g
s
.506 .813 1 r
.38871 .55315 m .39189 .55423 L p .40187 .55268 L F P
0 g
s
.788 .703 .77 r
.18501 .37156 m .18973 .36674 L .18641 .36192 L p F P
0 g
s
.804 .691 .739 r
.16622 .40192 m .17072 .39624 L .16952 .3943 L p F P
0 g
s
.626 .601 .805 r
.58618 .32732 m .58896 .33318 L .57781 .33591 L p F P
0 g
s
.626 .601 .805 r
.57781 .33591 m .57586 .33184 L .58618 .32732 L p F P
0 g
s
.655 .658 .841 r
.51301 .31118 m .52404 .30751 L .52699 .31243 L p F P
0 g
s
.657 .667 .848 r
.52223 .30461 m .52404 .30751 L .51301 .31118 L p F P
0 g
s
.657 .667 .848 r
.51301 .31118 m .51106 .30806 L .52223 .30461 L p F P
0 g
s
.569 .462 .692 r
.64973 .43368 m .64176 .4337 L .64894 .4305 L closepath p F P
0 g
s
.576 .475 .703 r
.64703 .4234 m .64894 .4305 L .64176 .4337 L p F P
0 g
s
.768 .709 .797 r
.20841 .3418 m .21272 .3382 L .21851 .34067 L p F P
0 g
s
.767 .711 .8 r
.21934 .33278 m .21272 .3382 L .21851 .34067 L p F P
0 g
s
.767 .711 .8 r
.21851 .34067 m .22265 .33727 L .21934 .33278 L p F P
0 g
s
.617 .585 .795 r
.60598 .34335 m .60615 .34372 L .59597 .34841 L p F P
0 g
s
.617 .585 .795 r
.59597 .34841 m .59478 .34577 L .60598 .34335 L p F P
0 g
s
0 0 0 r
.50174 .5475 m .49242 .54883 L .48966 .54918 L p F P
0 g
s
0 0 0 r
.49242 .54883 m .48925 .54924 L .48966 .54918 L closepath p F P
0 g
s
.168 0 0 r
.31904 .54981 m .31867 .54975 L .31926 .54983 L closepath p F P
0 g
s
.544 .367 .591 r
.62564 .48703 m .62544 .48492 L .62811 .48611 L closepath p F P
0 g
s
.81 .681 .722 r
.16335 .4181 m .16261 .41678 L .16208 .41754 L closepath p F P
0 g
s
.793 .7 .762 r
.17938 .37935 m .17863 .37824 L .17812 .37878 L closepath p F P
0 g
s
.726 .718 .842 r
.28337 .30897 m .27258 .31533 L .26931 .31109 L p F P
0 g
s
.79 .702 .767 r
.18501 .37156 m .17863 .37824 L .1753 .37338 L p F P
0 g
s
.79 .702 .767 r
.1753 .37338 m .17945 .36903 L .18501 .37156 L p F P
0 g
s
.788 .703 .77 r
.18641 .36192 m .17945 .36903 L .18501 .37156 L p F P
0 g
s
.016 .579 .799 r
.31867 .54975 m .31904 .54981 L .3157 .54909 L p F P
0 g
s
.016 .579 .799 r
.3157 .54909 m .3097 .5485 L .31867 .54975 L p F P
0 g
s
.642 .63 .823 r
.54392 .31927 m .55501 .31598 L .55794 .32145 L p F P
0 g
s
.643 .636 .827 r
.55278 .31188 m .55501 .31598 L .54392 .31927 L p F P
0 g
s
.643 .636 .827 r
.54392 .31927 m .54209 .31592 L .55278 .31188 L p F P
0 g
s
.665 .722 .892 r
.45416 .30535 m .4651 .30159 L .46812 .30532 L p F P
0 g
s
.658 .746 .915 r
.4651 .30159 m .45416 .30535 L .45112 .30183 L p F P
0 g
s
.375 0 0 r
.28541 .54494 m .28336 .54456 L .27487 .54193 L p F P
0 g
s
.222 0 0 r
.27376 .54174 m .27487 .54193 L .28336 .54456 L p F P
0 g
s
.405 .807 .983 r
.40584 .55421 m .41667 .5529 L .4198 .55398 L p F P
0 g
s
.518 .818 1 r
.40584 .55421 m .41667 .5529 L .41597 .55253 L p F P
0 g
s
.518 .818 1 r
.40268 .5531 m .40584 .55421 L p .41597 .55253 L F P
0 g
s
.76 .711 .806 r
.22911 .3322 m .22265 .33727 L .21934 .33278 L p F P
0 g
s
.565 .449 .679 r
.64194 .44858 m .64148 .44657 L .64628 .4467 L closepath p F P
0 g
s
.818 .658 .685 r
.1561 .43875 m .16185 .44115 L .15863 .4472 L p F P
0 g
s
.816 .663 .693 r
.16185 .44115 m .1561 .43875 L .15967 .43259 L p F P
0 g
s
.808 .489 .451 r
.20681 .51617 m .20507 .51564 L .20393 .51086 L p F P
0 g
s
.81 .489 .446 r
.19734 .50883 m .20393 .51086 L .20507 .51564 L p F P
0 g
s
.094 0 0 r
.33293 .55116 m .32962 .55016 L .31904 .54981 L p F P
0 g
s
.366 .761 .986 r
.32962 .55016 m .31904 .54981 L .3157 .54909 L p F P
0 g
s
.204 0 0 r
.52862 .54257 m .52972 .54178 L .54164 .53943 L p F P
0 g
s
.346 0 0 r
.54257 .53851 m .54164 .53943 L .52972 .54178 L p F P
0 g
s
.288 0 0 r
.55567 .53402 m .56724 .53127 L .56501 .53414 L p F P
0 g
s
.288 0 0 r
.55367 .53666 m .55567 .53402 L p .56501 .53414 L F P
0 g
s
.43 .042 .198 r
.56758 .5306 m .56724 .53127 L .55567 .53402 L p F P
0 g
s
.375 0 .068 r
.55567 .53402 m .55367 .53666 L .54257 .53851 L p F P
0 g
s
.222 0 0 r
.27073 .54196 m .27376 .54174 L p .28336 .54456 L F P
0 g
s
.51 0 0 r
.27073 .54196 m .26697 .54034 L .27376 .54174 L closepath p F P
0 g
s
.095 .651 .716 r
.48925 .54924 m .48665 .5492 L .47568 .5508 L p F P
0 g
s
.433 .839 .973 r
.48665 .5492 m .47568 .5508 L .47265 .55041 L p F P
0 g
s
.143 .688 .781 r
.47568 .5508 m .47265 .55041 L .46171 .552 L p F P
0 g
s
.811 .683 .723 r
.16208 .41754 m .16261 .41678 L .15934 .41108 L p F P
0 g
s
.405 .813 .979 r
.4198 .55398 m .43066 .55254 L .43377 .55355 L p F P
0 g
s
.522 .824 1 r
.4198 .55398 m .43066 .55254 L .42976 .55209 L p F P
0 g
s
.522 .824 1 r
.41667 .5529 m .4198 .55398 L p .42976 .55209 L F P
0 g
s
.665 .71 .881 r
.46812 .30532 m .47909 .30152 L .48209 .30547 L p F P
0 g
s
.662 .73 .9 r
.47909 .30152 m .46812 .30532 L .4651 .30159 L p F P
0 g
s
.559 .433 .665 r
.64328 .45504 m .64194 .44858 L .64628 .4467 L p F P
0 g
s
.794 .703 .764 r
.17812 .37878 m .17863 .37824 L .1753 .37338 L p F P
0 g
s
.637 .624 .821 r
.56906 .31835 m .57006 .32026 L .55957 .32457 L p F P
0 g
s
.637 .624 .821 r
.55957 .32457 m .55794 .32145 L .56906 .31835 L p F P
0 g
s
.804 .691 .739 r
.16952 .3943 m .16603 .39268 L p .16622 .40192 L F P
0 g
s
.802 .696 .748 r
.16952 .3943 m .16741 .39103 L .16603 .39268 L closepath p F P
0 g
s
.815 .679 .714 r
.15656 .41504 m .16208 .41754 L .15791 .42389 L p F P
0 g
s
.811 .683 .723 r
.15934 .41108 m .15656 .41504 L .16208 .41754 L p F P
0 g
s
.617 .587 .798 r
.60598 .34335 m .59478 .34577 L .59187 .33936 L p F P
0 g
s
.797 .699 .757 r
.17267 .37622 m .17812 .37878 L .17193 .38578 L p F P
0 g
s
.794 .703 .764 r
.1753 .37338 m .17267 .37622 L .17812 .37878 L p F P
0 g
s
.484 .841 .994 r
.46171 .552 m .47265 .55041 L .46971 .54933 L p F P
0 g
s
.484 .841 .994 r
.45865 .55133 m .46171 .552 L p .46971 .54933 L F P
0 g
s
.181 .713 .827 r
.46171 .552 m .45865 .55133 L .44774 .5529 L p F P
0 g
s
.39 .814 .969 r
.43377 .55355 m .44465 .55203 L .44774 .5529 L p F P
0 g
s
.518 .829 1 r
.43377 .55355 m .44465 .55203 L .44327 .55137 L p F P
0 g
s
.518 .829 1 r
.43066 .55254 m .43377 .55355 L p .44327 .55137 L F P
0 g
s
.23 .749 .836 r
.48665 .5492 m .48925 .54924 L .49242 .54883 L p F P
0 g
s
.76 .711 .806 r
.21934 .33278 m .2232 .32976 L .22911 .3322 L p F P
0 g
s
.76 .713 .809 r
.23023 .32438 m .2232 .32976 L .22911 .3322 L p F P
0 g
s
.76 .713 .809 r
.22911 .3322 m .23353 .3288 L .23023 .32438 L p F P
0 g
s
.506 .836 .999 r
.44774 .5529 m .45865 .55133 L .45657 .55044 L p F P
0 g
s
.506 .836 .999 r
.44465 .55203 m .44774 .5529 L p .45657 .55044 L F P
0 g
s
.805 .689 .737 r
.1607 .39941 m .16622 .40192 L .16116 .40855 L p F P
0 g
s
.804 .691 .739 r
.16603 .39268 m .1607 .39941 L .16622 .40192 L p F P
0 g
s
.822 .597 .597 r
.17854 .48707 m .17235 .48487 L .17354 .47942 L p F P
0 g
s
.823 .599 .598 r
.16741 .4772 m .17354 .47942 L .17235 .48487 L p F P
0 g
s
.821 .612 .619 r
.17354 .47942 m .16741 .4772 L .16906 .47161 L p F P
0 g
s
.603 .556 .774 r
.61472 .36389 m .62597 .36207 L p .62099 .37064 L F P
0 g
s
.602 .556 .775 r
.62438 .3581 m .62597 .36207 L .61472 .36389 L p F P
0 g
s
.602 .556 .775 r
.61472 .36389 m .61435 .36299 L .62438 .3581 L p F P
0 g
s
.823 .614 .62 r
.16323 .46944 m .16906 .47161 L .16741 .4772 L p F P
0 g
s
.82 .626 .64 r
.16313 .46904 m .1651 .46363 L p .16906 .47161 L F P
0 g
s
.82 .626 .64 r
.16906 .47161 m .16323 .46944 L .16313 .46904 L p F P
0 g
s
.747 .322 .24 r
.23865 .53179 m .23148 .52996 L .22805 .52585 L p F P
0 g
s
.734 .293 .203 r
.2248 .52506 m .22805 .52585 L .23148 .52996 L p F P
0 g
s
.544 .383 .614 r
.6357 .47742 m .63495 .47159 L .6454 .46737 L p F P
0 g
s
.553 .404 .632 r
.64471 .463 m .6454 .46737 L .63495 .47159 L p F P
0 g
s
.553 .404 .632 r
.64165 .46246 m .64471 .463 L p .63495 .47159 L F P
0 g
s
.823 .579 .571 r
.18408 .49455 m .17785 .49237 L .17854 .48707 L p F P
0 g
s
.824 .581 .571 r
.17235 .48487 m .17854 .48707 L .17785 .49237 L p F P
0 g
s
.507 .237 .439 r
.60404 .50965 m .60365 .51286 L .5925 .51676 L p F P
0 g
s
.498 .22 .422 r
.59239 .5175 m .5925 .51676 L .60365 .51286 L p F P
0 g
s
.532 .338 .563 r
.62811 .48611 m .62564 .48703 L .62594 .49239 L p F P
0 g
s
.287 0 0 r
.54164 .53943 m .54257 .53851 L .55367 .53666 L p F P
0 g
s
.605 .565 .782 r
.62306 .35492 m .62438 .3581 L .61435 .36299 L p F P
0 g
s
.605 .565 .782 r
.61435 .36299 m .6118 .35688 L .62306 .35492 L p F P
0 g
s
.662 .155 .029 r
.25543 .53808 m .2513 .53711 L .24618 .5335 L p F P
0 g
s
.63 .102 0 r
.24104 .53239 m .24618 .5335 L .2513 .53711 L p F P
0 g
s
.6 .546 .766 r
.62099 .37064 m .62889 .36945 L p .62816 .37761 L F P
0 g
s
.599 .547 .768 r
.62889 .36945 m .62099 .37064 L .62804 .36724 L closepath p F P
0 g
s
.603 .556 .774 r
.62597 .36207 m .62804 .36724 L .62099 .37064 L p F P
0 g
s
.65 .65 .837 r
.52699 .31243 m .53805 .30891 L .54099 .31397 L p F P
0 g
s
.651 .656 .842 r
.53805 .30891 m .52699 .31243 L .52404 .30751 L p F P
0 g
s
.664 .697 .871 r
.48209 .30547 m .49308 .30166 L .49607 .30584 L p F P
0 g
s
.663 .714 .886 r
.49308 .30166 m .48209 .30547 L .47909 .30152 L p F P
0 g
s
.823 .628 .639 r
.16313 .46904 m .1651 .46363 L .16131 .46217 L closepath p F P
0 g
s
.819 .637 .656 r
.16022 .45882 m .16163 .4555 L p .1651 .46363 L F P
0 g
s
.819 .637 .656 r
.1651 .46363 m .16131 .46217 L .16022 .45882 L p F P
0 g
s
.735 .711 .828 r
.25851 .31788 m .26176 .31582 L .25535 .3137 L closepath p F P
0 g
s
.745 .716 .824 r
.25535 .3137 m .25851 .31788 L p .24439 .3209 L F P
0 g
s
.628 .608 .811 r
.58605 .32706 m .58618 .32732 L .57586 .33184 L p F P
0 g
s
.628 .608 .811 r
.57586 .33184 m .57489 .32988 L .58605 .32706 L p F P
0 g
s
.716 .72 .852 r
.28337 .30897 m .28807 .30647 L .29499 .30857 L p F P
0 g
s
.72 .724 .853 r
.29415 .30327 m .28807 .30647 L .29499 .30857 L p F P
0 g
s
.72 .724 .853 r
.29499 .30857 m .2974 .30726 L .29415 .30327 L p F P
0 g
s
.753 .714 .816 r
.24112 .32325 m .23353 .3288 L .23023 .32438 L p F P
0 g
s
.817 .667 .697 r
.15401 .43015 m .15967 .43259 L .1561 .43875 L p F P
0 g
s
.815 .671 .704 r
.15967 .43259 m .15401 .43015 L .15791 .42389 L p F P
0 g
s
.137 .683 .739 r
.50065 .54761 m .49242 .54883 L .50174 .5475 L closepath p F P
0 g
s
.23 .749 .836 r
.49242 .54883 m .50065 .54761 L p .48665 .5492 L F P
0 g
s
.823 .559 .54 r
.18819 .50117 m .18391 .4997 L .18408 .49455 L p F P
0 g
s
.825 .56 .539 r
.17785 .49237 m .18408 .49455 L .18391 .4997 L p F P
0 g
s
.59 .518 .742 r
.63771 .39349 m .63549 .39374 L .63748 .39281 L closepath p F P
0 g
s
.594 .528 .75 r
.63476 .38509 m .63748 .39281 L .63549 .39374 L p F P
0 g
s
.594 .528 .75 r
.63299 .38531 m .63476 .38509 L p .63549 .39374 L F P
0 g
s
.682 .738 .893 r
.32539 .305 m .33615 .30074 L .33936 .3043 L p F P
0 g
s
.669 .748 .91 r
.33615 .30074 m .32539 .305 L .32216 .30126 L p F P
0 g
s
.694 .731 .879 r
.3114 .30597 m .32216 .30126 L .32539 .305 L p F P
0 g
s
.648 .761 .931 r
.35012 .30047 m .33936 .3043 L .33615 .30074 L p F P
0 g
s
.669 .746 .909 r
.33936 .3043 m .35012 .30047 L .35332 .30382 L p F P
0 g
s
.686 .738 .891 r
.32216 .30126 m .3114 .30597 L .30817 .30209 L p F P
0 g
s
.787 .423 .366 r
.22096 .52399 m .21409 .52206 L .21193 .51758 L p F P
0 g
s
.784 .412 .353 r
.20681 .51617 m .21193 .51758 L .21409 .52206 L p F P
0 g
s
.799 .697 .751 r
.17193 .38578 m .16741 .39103 L .16409 .38596 L p F P
0 g
s
.799 .697 .751 r
.16409 .38596 m .16641 .38325 L .17193 .38578 L p F P
0 g
s
.797 .699 .757 r
.17193 .38578 m .16641 .38325 L .17267 .37622 L p F P
0 g
s
.655 .756 .924 r
.35332 .30382 m .3641 .30036 L .36728 .3035 L p F P
0 g
s
.624 .775 .953 r
.3641 .30036 m .35332 .30382 L .35012 .30047 L p F P
0 g
s
.04 .604 .792 r
.34685 .55209 m .34357 .55086 L .33293 .55116 L p F P
0 g
s
.444 .786 .998 r
.33293 .55116 m .34357 .55086 L .34203 .55007 L p F P
0 g
s
.444 .786 .998 r
.32962 .55016 m .33293 .55116 L p .34203 .55007 L F P
0 g
s
.823 .64 .655 r
.16022 .45882 m .16163 .4555 L .15875 .45435 L closepath p F P
0 g
s
.819 .648 .671 r
.15718 .45024 m .15863 .4472 L p .16163 .4555 L F P
0 g
s
.819 .648 .671 r
.16163 .4555 m .15875 .45435 L .15718 .45024 L p F P
0 g
s
.645 .641 .832 r
.55209 .31063 m .55278 .31188 L .54209 .31592 L p F P
0 g
s
.645 .641 .832 r
.54209 .31592 m .54099 .31397 L .55209 .31063 L p F P
0 g
s
.461 .146 .345 r
.59139 .52156 m .59239 .5175 L .60347 .51413 L p F P
0 g
s
.498 .22 .422 r
.60365 .51286 m .60347 .51413 L .59239 .5175 L p F P
0 g
s
.477 .161 .351 r
.59239 .5175 m .59139 .52156 L .58014 .52472 L p F P
0 g
s
0 .523 .726 r
.30181 .54752 m .30263 .54763 L .3097 .5485 L p F P
0 g
s
.731 .714 .834 r
.26604 .30691 m .26931 .31109 L .26176 .31582 L p F P
0 g
s
.731 .714 .834 r
.25523 .31354 m .26604 .30691 L p .26176 .31582 L F P
0 g
s
.731 .714 .834 r
.26176 .31582 m .25535 .3137 L .25523 .31354 L p F P
0 g
s
.657 .672 .852 r
.52109 .30281 m .52223 .30461 L .51106 .30806 L p F P
0 g
s
.657 .672 .852 r
.51106 .30806 m .51005 .30648 L .52109 .30281 L p F P
0 g
s
.494 .227 .437 r
.60365 .51286 m .60404 .50965 L .61498 .50609 L p F P
0 g
s
.519 .279 .49 r
.61521 .50126 m .61498 .50609 L .60404 .50965 L p F P
0 g
s
.7 .731 .875 r
.30817 .30209 m .2974 .30726 L .29415 .30327 L p F P
0 g
s
.812 .522 .499 r
.19734 .50883 m .19076 .50678 L .19027 .50182 L p F P
0 g
s
.813 .523 .498 r
.18819 .50117 m .19027 .50182 L .19076 .50678 L p F P
0 g
s
.642 .765 .938 r
.36728 .3035 m .37808 .30032 L .38125 .30326 L p F P
0 g
s
.599 .788 .971 r
.37808 .30032 m .36728 .3035 L .3641 .30036 L p F P
0 g
s
.661 .685 .862 r
.49607 .30584 m .50708 .30208 L .51005 .30648 L p F P
0 g
s
.662 .698 .873 r
.50708 .30208 m .49607 .30584 L .49308 .30166 L p F P
0 g
s
.629 .612 .814 r
.58605 .32706 m .57489 .32988 L .57198 .32406 L p F P
0 g
s
.734 .293 .203 r
.22271 .52652 m .2248 .52506 L p .23148 .52996 L F P
0 g
s
.769 .363 .284 r
.22271 .52652 m .22096 .52399 L .2248 .52506 L closepath p F P
0 g
s
.637 .628 .824 r
.56906 .31835 m .55794 .32145 L .55501 .31598 L p F P
0 g
s
.597 .537 .758 r
.62816 .37761 m .63182 .3771 L p .63299 .38531 L F P
0 g
s
.596 .538 .759 r
.63182 .3771 m .62816 .37761 L .63143 .37605 L closepath p F P
0 g
s
.6 .546 .766 r
.62889 .36945 m .63143 .37605 L .62816 .37761 L p F P
0 g
s
.593 .528 .751 r
.63476 .38509 m .63299 .38531 L .63457 .38457 L closepath p F P
0 g
s
.597 .537 .758 r
.63182 .3771 m .63457 .38457 L .63299 .38531 L p F P
0 g
s
.532 .338 .563 r
.62594 .49239 m .63088 .49055 L .62811 .48611 L p F P
0 g
s
.53 .337 .564 r
.63624 .48304 m .62811 .48611 L .63088 .49055 L p F P
0 g
s
.544 .367 .591 r
.6357 .47742 m .63624 .48304 L .62811 .48611 L p F P
0 g
s
.58 .504 .734 r
.64264 .40855 m .64067 .40239 L .65203 .40167 L p F P
0 g
s
.579 .504 .734 r
.65017 .39589 m .65203 .40167 L .64067 .40239 L p F P
0 g
s
.579 .504 .734 r
.64067 .40239 m .64016 .4008 L .65017 .39589 L p F P
0 g
s
.583 .514 .743 r
.64905 .39259 m .65017 .39589 L .64016 .4008 L p F P
0 g
s
.583 .514 .743 r
.64016 .4008 m .63771 .39349 L .64905 .39259 L p F P
0 g
s
.576 .494 .725 r
.64264 .40855 m .65268 .40369 L p .65475 .41139 L F P
0 g
s
.576 .494 .725 r
.65475 .41139 m .64366 .41189 L .64264 .40855 L p F P
0 g
s
.58 .504 .734 r
.65203 .40167 m .65268 .40369 L .64264 .40855 L p F P
0 g
s
.805 .689 .737 r
.15605 .40547 m .1607 .39941 L p .16116 .40855 L F P
0 g
s
.805 .689 .737 r
.16116 .40855 m .15672 .40656 L .15605 .40547 L p F P
0 g
s
.809 .684 .726 r
.15934 .41108 m .16116 .40855 L .15672 .40656 L closepath p F P
0 g
s
.753 .714 .816 r
.23023 .32438 m .23514 .32082 L .24112 .32325 L p F P
0 g
s
.752 .716 .819 r
.24109 .31659 m .23514 .32082 L .24112 .32325 L p F P
0 g
s
.752 .716 .819 r
.24112 .32325 m .24439 .3209 L .24109 .31659 L p F P
0 g
s
.198 0 0 r
.29202 .54591 m .28798 .54511 L p .29678 .54664 L F P
0 g
s
.226 0 0 r
.29202 .54591 m .28541 .54494 L .28798 .54511 L closepath p F P
0 g
s
0 .523 .741 r
.29202 .54591 m .29843 .54662 L p .28585 .54497 L F P
0 g
s
0 .523 .741 r
.28454 .54479 m .29202 .54591 L .28585 .54497 L F
.198 0 0 r
.30056 .5473 m .29202 .54591 L p .29678 .54664 L F P
0 g
s
.552 .417 .651 r
.64444 .46132 m .64328 .45504 L .65357 .45058 L p F P
0 g
s
.561 .423 .65 r
.64328 .45504 m .64444 .46132 L .64165 .46246 L p F P
0 g
s
.559 .433 .665 r
.65288 .44728 m .65357 .45058 L .64328 .45504 L p F P
0 g
s
.559 .433 .665 r
.64628 .4467 m .65288 .44728 L p .64328 .45504 L F P
0 g
s
.402 0 0 r
.26697 .54034 m .27073 .54196 L .26751 .54168 L p F P
0 g
s
.402 0 0 r
.259 .53877 m .26697 .54034 L p .26751 .54168 L F P
0 g
s
.592 .053 0 r
.26697 .54034 m .259 .53877 L .25702 .53772 L p F P
0 g
s
.633 .773 .947 r
.38125 .30326 m .39206 .30024 L .39521 .30304 L p F P
0 g
s
.578 .8 .983 r
.39206 .30024 m .38125 .30326 L .37808 .30032 L p F P
0 g
s
.576 .493 .724 r
.64493 .41608 m .64366 .41189 L .65475 .41139 L closepath p F P
0 g
s
.606 .565 .783 r
.62043 .34862 m .62306 .35492 L .6118 .35688 L p F P
0 g
s
.606 .565 .783 r
.6118 .35688 m .61041 .35354 L .62043 .34862 L p F P
0 g
s
.822 .65 .67 r
.15718 .45024 m .15863 .4472 L .15551 .44592 L closepath p F P
0 g
s
.818 .658 .685 r
.15406 .44259 m .1561 .43875 L p .15863 .4472 L F P
0 g
s
.818 .658 .685 r
.15863 .4472 m .15551 .44592 L .15406 .44259 L p F P
0 g
s
.803 .698 .749 r
.16603 .39268 m .16741 .39103 L .16409 .38596 L p F P
0 g
s
.776 .71 .79 r
.20327 .34628 m .19743 .3515 L .1941 .34692 L p F P
0 g
s
.781 .711 .786 r
.19463 .3541 m .19743 .3515 L .1941 .34692 L p F P
0 g
s
.402 .023 .202 r
.58014 .52472 m .59139 .52156 L .58993 .52516 L p F P
0 g
s
.402 .023 .202 r
.57873 .52819 m .58014 .52472 L p .58993 .52516 L F P
0 g
s
.44 .076 .249 r
.58014 .52472 m .57873 .52819 L .56758 .5306 L p F P
0 g
s
.78 .708 .784 r
.18912 .35154 m .19463 .3541 L .18663 .3617 L p F P
0 g
s
.781 .711 .786 r
.1941 .34692 m .18912 .35154 L .19463 .3541 L p F P
0 g
s
.817 .674 .706 r
.15235 .4214 m .15791 .42389 L .15401 .43015 L p F P
0 g
s
.815 .679 .714 r
.15791 .42389 m .15235 .4214 L .15656 .41504 L p F P
0 g
s
.593 .056 0 r
.259 .53877 m .25543 .53808 L .25702 .53772 L closepath p F P
0 g
s
.582 .514 .743 r
.64745 .38786 m .64905 .39259 L .63771 .39349 L p F P
0 g
s
.582 .514 .743 r
.63771 .39349 m .63748 .39281 L .64745 .38786 L p F P
0 g
s
.711 .719 .856 r
.28807 .30647 m .28337 .30897 L .28011 .30482 L p F P
0 g
s
.726 .718 .842 r
.26931 .31109 m .28011 .30482 L .28337 .30897 L p F P
0 g
s
.776 .71 .79 r
.1941 .34692 m .19765 .34375 L .20327 .34628 L p F P
0 g
s
.774 .712 .793 r
.20508 .33728 m .19765 .34375 L .20327 .34628 L p F P
0 g
s
.774 .712 .793 r
.20327 .34628 m .20841 .3418 L .20508 .33728 L p F P
0 g
s
.572 .483 .715 r
.64493 .41608 m .65475 .41139 L p .64985 .42207 L F P
0 g
s
.572 .483 .715 r
.64985 .42207 m .64667 .42215 L .64493 .41608 L p F P
0 g
s
.586 .524 .751 r
.64609 .38401 m .64745 .38786 L .63748 .39281 L p F P
0 g
s
.586 .524 .751 r
.63748 .39281 m .63476 .38509 L .64609 .38401 L p F P
0 g
s
.63 .102 0 r
.23983 .53286 m .24104 .53239 L p .2513 .53711 L F P
0 g
s
.712 .243 .136 r
.23983 .53286 m .23865 .53179 L .24104 .53239 L closepath p F P
0 g
s
.617 .587 .798 r
.59187 .33936 m .60307 .33695 L .60598 .34335 L p F P
0 g
s
.617 .589 .799 r
.60144 .33337 m .60307 .33695 L .59187 .33936 L p F P
0 g
s
.617 .589 .799 r
.59187 .33936 m .59132 .33816 L .60144 .33337 L p F P
0 g
s
.785 .705 .776 r
.18641 .36192 m .18663 .3617 L .18607 .36145 L closepath p F P
0 g
s
.78 .708 .784 r
.18306 .35728 m .18912 .35154 L p .18663 .3617 L F P
0 g
s
.78 .708 .784 r
.18663 .3617 m .18607 .36145 L .18306 .35728 L p F P
0 g
s
.79 .706 .772 r
.17945 .36903 m .18641 .36192 L .18607 .36145 L p F P
0 g
s
.768 .711 .798 r
.21272 .3382 m .20841 .3418 L .20508 .33728 L p F P
0 g
s
.806 .694 .742 r
.16063 .39012 m .16603 .39268 L .1607 .39941 L p F P
0 g
s
.803 .698 .749 r
.16409 .38596 m .16063 .39012 L .16603 .39268 L p F P
0 g
s
.527 .312 .531 r
.62594 .49239 m .62599 .4975 L .61521 .50126 L p F P
0 g
s
.507 .268 .487 r
.62599 .4975 m .61521 .50126 L .61498 .50609 L p F P
0 g
s
.63 .778 .952 r
.39521 .30304 m .40605 .30006 L .40918 .30279 L p F P
0 g
s
.569 .808 .989 r
.40605 .30006 m .39521 .30304 L .39206 .30024 L p F P
0 g
s
.745 .716 .824 r
.24439 .3209 m .25512 .31361 L .25535 .3137 L p F P
0 g
s
.745 .719 .828 r
.25512 .31361 m .24439 .3209 L .24109 .31659 L p F P
0 g
s
.552 .403 .633 r
.64471 .463 m .64165 .46246 L .64444 .46132 L closepath p F P
0 g
s
.646 .648 .838 r
.55209 .31063 m .54099 .31397 L .53805 .30891 L p F P
0 g
s
.395 .783 .989 r
.35766 .55133 m .35728 .5513 L .34685 .55209 L p F P
0 g
s
.373 .782 .982 r
.35728 .5513 m .34685 .55209 L .34357 .55086 L p F P
0 g
s
.813 .523 .498 r
.19076 .50678 m .18684 .50555 L .18819 .50117 L p F P
0 g
s
.823 .535 .501 r
.18391 .4997 m .18819 .50117 L .18684 .50555 L p F P
0 g
s
.813 .685 .723 r
.15656 .41504 m .15934 .41108 L .15672 .40656 L p F P
0 g
s
.401 .007 .172 r
.56724 .53127 m .56758 .5306 L .57873 .52819 L p F P
0 g
s
.658 .684 .863 r
.52109 .30281 m .51005 .30648 L .50708 .30208 L p F P
0 g
s
.147 0 0 r
.30181 .54752 m .30056 .5473 L .30263 .54763 L closepath p F P
0 g
s
.768 .711 .798 r
.20508 .33728 m .20697 .3357 L .21272 .3382 L p F P
0 g
s
.767 .713 .802 r
.21601 .32832 m .20697 .3357 L .21272 .3382 L p F P
0 g
s
.767 .713 .802 r
.21272 .3382 m .21934 .33278 L .21601 .32832 L p F P
0 g
s
.81 .489 .446 r
.20507 .51564 m .19851 .51359 L .19734 .50883 L p F P
0 g
s
.81 .487 .442 r
.19076 .50678 m .19734 .50883 L .19851 .51359 L p F P
0 g
s
.79 .706 .772 r
.18607 .36145 m .1812 .35911 L p .17945 .36903 L F P
0 g
s
.787 .71 .778 r
.18607 .36145 m .18306 .35728 L .1812 .35911 L closepath p F P
0 g
s
.62 .597 .805 r
.60017 .33066 m .60144 .33337 L .59132 .33816 L p F P
0 g
s
.62 .597 .805 r
.59132 .33816 m .58896 .33318 L .60017 .33066 L p F P
0 g
s
.572 .483 .715 r
.64703 .4234 m .64667 .42215 L .64985 .42207 L closepath p F P
0 g
s
.634 .777 .95 r
.40918 .30279 m .42005 .29974 L .42316 .30249 L p F P
0 g
s
.576 .811 .988 r
.42005 .29974 m .40918 .30279 L .40605 .30006 L p F P
0 g
s
.558 .433 .666 r
.65288 .44728 m .64628 .4467 L .65221 .44409 L closepath p F P
0 g
s
.565 .449 .68 r
.65066 .4374 m .65221 .44409 L .64628 .4467 L p F P
0 g
s
.567 .47 .704 r
.64894 .4305 m .64703 .4234 L .64985 .42207 L p F P
0 g
s
.02 0 0 r
.51464 .5455 m .51407 .5456 L .50174 .5475 L p F P
0 g
s
.156 .697 .749 r
.50065 .54761 m .50174 .5475 L .51407 .5456 L p F P
0 g
s
.827 .63 .637 r
.16131 .46217 m .1592 .46132 L p .16301 .46935 L F P
0 g
s
.827 .63 .637 r
.16301 .46935 m .16313 .46904 L .16131 .46217 L p F P
0 g
s
.826 .641 .652 r
.16131 .46217 m .16022 .45882 L .1592 .46132 L closepath p F P
0 g
s
.586 .524 .752 r
.64452 .37957 m .64609 .38401 L .63476 .38509 L p F P
0 g
s
.586 .524 .752 r
.63476 .38509 m .63457 .38457 L .64452 .37957 L p F P
0 g
s
.204 0 0 r
.54164 .53943 m .5397 .54065 L .52862 .54257 L p F P
0 g
s
.017 0 0 r
.52621 .54347 m .52862 .54257 L .5397 .54065 L p F P
0 g
s
.827 .641 .652 r
.1592 .46132 m .16022 .45882 L .15875 .45435 L p F P
0 g
s
.609 .574 .789 r
.62014 .34796 m .62043 .34862 L .61041 .35354 L p F P
0 g
s
.609 .574 .789 r
.61041 .35354 m .60889 .35004 L .62014 .34796 L p F P
0 g
s
.59 .533 .76 r
.64315 .37585 m .64452 .37957 L .63457 .38457 L p F P
0 g
s
.59 .533 .76 r
.63457 .38457 m .63182 .3771 L .64315 .37585 L p F P
0 g
s
.792 .704 .768 r
.17945 .36903 m .1753 .37338 L .17195 .36857 L p F P
0 g
s
.792 .704 .768 r
.17195 .36857 m .17396 .36647 L .17945 .36903 L p F P
0 g
s
.79 .706 .772 r
.1812 .35911 m .17396 .36647 L .17945 .36903 L p F P
0 g
s
.827 .641 .652 r
.15875 .45435 m .15584 .45313 L p .1592 .46132 L F P
0 g
s
.825 .651 .666 r
.15875 .45435 m .15718 .45024 L .15584 .45313 L closepath p F P
0 g
s
.821 .66 .683 r
.15406 .44259 m .1561 .43875 L .15152 .43681 L closepath p F P
0 g
s
.817 .667 .697 r
.15089 .43551 m .15401 .43015 L p .1561 .43875 L F P
0 g
s
.817 .667 .697 r
.1561 .43875 m .15152 .43681 L .15089 .43551 L p F P
0 g
s
.597 .809 .981 r
.43405 .29929 m .42316 .30249 L .42005 .29974 L p F P
0 g
s
.642 .772 .942 r
.42316 .30249 m .43405 .29929 L .43714 .30215 L p F P
0 g
s
.685 .186 .051 r
.23865 .53179 m .23983 .53286 L .23624 .53369 L p F P
0 g
s
.685 .186 .051 r
.23148 .52996 m .23865 .53179 L p .23624 .53369 L F P
0 g
s
.022 .58 .813 r
.30056 .5473 m .30181 .54752 L .29843 .54662 L p F P
0 g
s
.022 .58 .813 r
.29843 .54662 m .29202 .54591 L .30056 .5473 L p F P
0 g
s
.76 .713 .808 r
.2232 .32976 m .21934 .33278 L .21601 .32832 L p F P
0 g
s
.725 .724 .85 r
.28011 .30482 m .26931 .31109 L .26604 .30691 L p F P
0 g
s
.765 .344 .25 r
.22096 .52399 m .22271 .52652 L .22111 .52736 L p F P
0 g
s
.765 .344 .25 r
.21409 .52206 m .22096 .52399 L p .22111 .52736 L F P
0 g
s
.533 .359 .591 r
.63624 .48304 m .6357 .47742 L .64616 .47321 L p F P
0 g
s
.544 .383 .614 r
.6454 .46737 m .64616 .47321 L .6357 .47742 L p F P
0 g
s
.784 .412 .353 r
.20577 .51741 m .20681 .51617 L p .21409 .52206 L F P
0 g
s
.801 .448 .39 r
.20577 .51741 m .20507 .51564 L .20681 .51617 L closepath p F P
0 g
s
.134 0 0 r
.5397 .54065 m .54164 .53943 L .55342 .5369 L p F P
0 g
s
.287 0 0 r
.55367 .53666 m .55342 .5369 L .54164 .53943 L p F P
0 g
s
.796 .705 .764 r
.17267 .37622 m .1753 .37338 L .17195 .36857 L p F P
0 g
s
.826 .652 .667 r
.15584 .45313 m .15718 .45024 L .15551 .44592 L p F P
0 g
s
.449 .799 .998 r
.3727 .55205 m .36869 .55182 L .36078 .55269 L p F P
0 g
s
.437 .8 .996 r
.36869 .55182 m .35766 .55133 L .36078 .55269 L closepath p F P
0 g
s
.651 .761 .93 r
.43714 .30215 m .44806 .29878 L .45112 .30183 L p F P
0 g
s
.621 .799 .967 r
.44806 .29878 m .43714 .30215 L .43405 .29929 L p F P
0 g
s
.826 .629 .636 r
.16323 .46944 m .16313 .46904 L .16301 .46935 L closepath p F P
0 g
s
.823 .599 .598 r
.17235 .48487 m .1662 .48265 L .16741 .4772 L p F P
0 g
s
.826 .601 .598 r
.16449 .47611 m .16741 .4772 L .1662 .48265 L p F P
0 g
s
.823 .614 .62 r
.16741 .4772 m .16449 .47611 L .16323 .46944 L p F P
0 g
s
.83 .618 .616 r
.16301 .46935 m .16323 .46944 L .16449 .47611 L p F P
0 g
s
.76 .713 .808 r
.21601 .32832 m .21734 .32729 L .2232 .32976 L p F P
0 g
s
.76 .716 .811 r
.22691 .32001 m .21734 .32729 L .2232 .32976 L p F P
0 g
s
.76 .716 .811 r
.2232 .32976 m .23023 .32438 L .22691 .32001 L p F P
0 g
s
.711 .719 .856 r
.28011 .30482 m .28076 .30449 L .28807 .30647 L p F P
0 g
s
.717 .728 .86 r
.29089 .29937 m .28076 .30449 L .28807 .30647 L p F P
0 g
s
.717 .728 .86 r
.28807 .30647 m .29415 .30327 L .29089 .29937 L p F P
0 g
s
.816 .682 .715 r
.15111 .41251 m .15656 .41504 L .15235 .4214 L p F P
0 g
s
.813 .685 .723 r
.15562 .40605 m .15111 .41251 L .15656 .41504 L p F P
0 g
s
.813 .685 .723 r
.15672 .40656 m .15562 .40605 L p .15656 .41504 L F P
0 g
s
.824 .581 .571 r
.17785 .49237 m .17165 .49018 L .17235 .48487 L p F P
0 g
s
.825 .583 .572 r
.1662 .48265 m .17235 .48487 L .17165 .49018 L p F P
0 g
s
.832 .621 .617 r
.15722 .467 m .16301 .46935 L .16145 .47491 L p F P
0 g
s
.827 .63 .637 r
.1592 .46132 m .15722 .467 L .16301 .46935 L p F P
0 g
s
.83 .618 .616 r
.16449 .47611 m .16145 .47491 L .16301 .46935 L p F P
0 g
s
.796 .705 .764 r
.17195 .36857 m .16729 .37363 L .17267 .37622 L p F P
0 g
s
.797 .702 .759 r
.16729 .37363 m .17267 .37622 L .16641 .38325 L p F P
0 g
s
.562 .458 .693 r
.64894 .4305 m .65903 .42573 L p .6579 .43402 L F P
0 g
s
.562 .458 .693 r
.6579 .43402 m .64973 .43368 L .64894 .4305 L p F P
0 g
s
.567 .47 .704 r
.65807 .42219 m .65903 .42573 L .64894 .4305 L p F P
0 g
s
.567 .47 .704 r
.64985 .42207 m .65807 .42219 L p .64894 .4305 L F P
0 g
s
.658 .746 .915 r
.45112 .30183 m .46207 .29829 L .4651 .30159 L p F P
0 g
s
.641 .781 .948 r
.46207 .29829 m .45112 .30183 L .44806 .29878 L p F P
0 g
s
.589 .534 .76 r
.64135 .371 m .64315 .37585 L .63182 .3771 L p F P
0 g
s
.589 .534 .76 r
.63182 .3771 m .63143 .37605 L .64135 .371 L p F P
0 g
s
.809 .691 .735 r
.1607 .39941 m .15605 .40547 L .15273 .40015 L p F P
0 g
s
.809 .691 .735 r
.15273 .40015 m .15524 .39686 L .1607 .39941 L p F P
0 g
s
.806 .694 .742 r
.1607 .39941 m .15524 .39686 L .16063 .39012 L p F P
0 g
s
.608 .574 .79 r
.61723 .34129 m .62014 .34796 L .60889 .35004 L p F P
0 g
s
.608 .574 .79 r
.60746 .34306 m .61723 .34129 L p .60889 .35004 L F P
0 g
s
.608 .574 .79 r
.60889 .35004 m .60615 .34372 L .60746 .34306 L p F P
0 g
s
.826 .652 .667 r
.15551 .44592 m .15292 .4448 L p .15584 .45313 L F P
0 g
s
.824 .66 .68 r
.15551 .44592 m .15406 .44259 L .15292 .4448 L closepath p F P
0 g
s
.302 0 0 r
.56501 .53414 m .56724 .53127 L .57866 .52832 L p F P
0 g
s
.401 .007 .172 r
.57873 .52819 m .57866 .52832 L .56724 .53127 L p F P
0 g
s
.593 .543 .768 r
.64021 .36804 m .64135 .371 L .63143 .37605 L p F P
0 g
s
.593 .543 .768 r
.63143 .37605 m .62889 .36945 L .64021 .36804 L p F P
0 g
s
.653 .666 .85 r
.53317 .30083 m .53511 .30397 L .52404 .30751 L p F P
0 g
s
.653 .666 .85 r
.52404 .30751 m .52223 .30461 L .53317 .30083 L p F P
0 g
s
.651 .656 .842 r
.52404 .30751 m .53511 .30397 L .53805 .30891 L p F P
0 g
s
.516 .303 .53 r
.63088 .49055 m .62594 .49239 L .62599 .4975 L p F P
0 g
s
.825 .56 .539 r
.18391 .4997 m .17768 .49752 L .17785 .49237 L p F P
0 g
s
.826 .561 .539 r
.17165 .49018 m .17785 .49237 L .17768 .49752 L p F P
0 g
s
.544 .398 .633 r
.64444 .46132 m .65473 .45686 L p .6515 .46477 L F P
0 g
s
.544 .398 .633 r
.6515 .46477 m .64471 .463 L .64444 .46132 L p F P
0 g
s
.552 .417 .651 r
.65357 .45058 m .65473 .45686 L .64444 .46132 L p F P
0 g
s
.831 .634 .636 r
.15348 .45893 m .1592 .46132 L .15722 .467 L p F P
0 g
s
.827 .641 .652 r
.15584 .45313 m .15348 .45893 L .1592 .46132 L p F P
0 g
s
.802 .44 .371 r
.20507 .51564 m .20577 .51741 L .20394 .51922 L p F P
0 g
s
.802 .44 .371 r
.19851 .51359 m .20507 .51564 L p .20394 .51922 L F P
0 g
s
0 .523 .726 r
.3157 .54909 m .31236 .54787 L .30181 .54752 L p F P
0 g
s
.378 .759 .99 r
.30181 .54752 m .31236 .54787 L .30955 .54648 L p F P
0 g
s
.378 .759 .99 r
.29843 .54662 m .30181 .54752 L p .30955 .54648 L F P
0 g
s
.629 .612 .814 r
.57198 .32406 m .58314 .32123 L .58605 .32706 L p F P
0 g
s
.63 .614 .816 r
.58035 .31567 m .58314 .32123 L .57198 .32406 L p F P
0 g
s
.63 .614 .816 r
.57198 .32406 m .57006 .32026 L .58035 .31567 L p F P
0 g
s
.484 .808 1 r
.38744 .55251 m .38038 .55226 L .37474 .55302 L p F P
0 g
s
.478 .81 1 r
.38038 .55226 m .3727 .55205 L .37474 .55302 L closepath p F P
0 g
s
.662 .73 .9 r
.4651 .30159 m .47608 .29793 L .47909 .30152 L p F P
0 g
s
.654 .759 .927 r
.47608 .29793 m .4651 .30159 L .46207 .29829 L p F P
0 g
s
.82 .669 .695 r
.15401 .43015 m .15089 .43551 L .14767 .42897 L p F P
0 g
s
.82 .669 .695 r
.14767 .42897 m .14841 .42769 L .15401 .43015 L p F P
0 g
s
.817 .674 .706 r
.15401 .43015 m .14841 .42769 L .15235 .4214 L p F P
0 g
s
.402 0 0 r
.26751 .54168 m .26694 .54155 L .259 .53877 L p F P
0 g
s
.273 0 0 r
.25543 .53808 m .259 .53877 L .26694 .54155 L p F P
0 g
s
.743 .717 .827 r
.25535 .3137 m .25523 .31354 L .25512 .31361 L closepath p F P
0 g
s
.562 .457 .692 r
.65066 .4374 m .64973 .43368 L .6579 .43402 L closepath p F P
0 g
s
0 0 0 r
.52621 .54347 m .52017 .54456 L .51464 .5455 L p F P
0 g
s
0 0 0 r
.52017 .54456 m .51407 .5456 L .51464 .5455 L closepath p F P
0 g
s
.745 .72 .829 r
.25193 .30935 m .24917 .31117 L .25512 .31361 L p F P
0 g
s
.745 .72 .829 r
.25512 .31361 m .25523 .31354 L .25193 .30935 L p F P
0 g
s
.745 .719 .828 r
.24109 .31659 m .24917 .31117 L .25512 .31361 L p F P
0 g
s
.752 .715 .818 r
.23514 .32082 m .23023 .32438 L .22691 .32001 L p F P
0 g
s
.733 .721 .84 r
.26604 .30691 m .25523 .31354 L .25193 .30935 L p F P
0 g
s
.637 .628 .824 r
.55501 .31598 m .56614 .31286 L .56906 .31835 L p F P
0 g
s
.639 .633 .828 r
.56327 .30753 m .56614 .31286 L .55501 .31598 L p F P
0 g
s
.639 .633 .828 r
.55501 .31598 m .55278 .31188 L .56327 .30753 L p F P
0 g
s
.825 .661 .68 r
.15292 .4448 m .15406 .44259 L .15152 .43681 L p F P
0 g
s
.62 .598 .806 r
.59726 .32455 m .60017 .33066 L .58896 .33318 L p F P
0 g
s
.62 .598 .806 r
.58734 .32677 m .59726 .32455 L p .58896 .33318 L F P
0 g
s
.62 .598 .806 r
.58896 .33318 m .58618 .32732 L .58734 .32677 L p F P
0 g
s
.811 .691 .732 r
.15672 .40656 m .15605 .40547 L .15562 .40605 L closepath p F P
0 g
s
.83 .646 .653 r
.1502 .45071 m .15584 .45313 L .15348 .45893 L p F P
0 g
s
.826 .652 .667 r
.15292 .4448 m .1502 .45071 L .15584 .45313 L p F P
0 g
s
.823 .535 .501 r
.18684 .50555 m .18431 .50468 L .18391 .4997 L p F P
0 g
s
.826 .536 .498 r
.17768 .49752 m .18391 .4997 L .18431 .50468 L p F P
0 g
s
.566 .47 .705 r
.65807 .42219 m .64985 .42207 L .6571 .4186 L closepath p F P
0 g
s
.572 .483 .715 r
.65503 .41138 m .6571 .4186 L .64985 .42207 L p F P
0 g
s
.572 .483 .715 r
.65475 .41139 m .65503 .41138 L p .64985 .42207 L F P
0 g
s
.801 .699 .752 r
.16641 .38325 m .16409 .38596 L .16075 .38093 L p F P
0 g
s
.801 .699 .752 r
.16075 .38093 m .16096 .38068 L .16641 .38325 L p F P
0 g
s
.797 .702 .759 r
.16641 .38325 m .16096 .38068 L .16729 .37363 L p F P
0 g
s
.663 .714 .886 r
.47909 .30152 m .49009 .29779 L .49308 .30166 L p F P
0 g
s
.66 .737 .907 r
.49009 .29779 m .47909 .30152 L .47608 .29793 L p F P
0 g
s
.544 .398 .633 r
.6454 .46737 m .64471 .463 L .6515 .46477 L closepath p F P
0 g
s
.633 .11 0 r
.24384 .53537 m .23624 .53369 L .23983 .53286 L closepath p F P
0 g
s
.63 .102 0 r
.2513 .53711 m .24384 .53537 L .23983 .53286 L p F P
0 g
s
.506 .813 1 r
.40187 .55268 m .39252 .55256 L .38871 .55315 L p F P
0 g
s
.504 .814 1 r
.39252 .55256 m .38744 .55251 L .38871 .55315 L closepath p F P
0 g
s
.494 .227 .437 r
.61498 .50609 m .6148 .50763 L .60365 .51286 L p F P
0 g
s
.484 .208 .419 r
.60347 .51413 m .60365 .51286 L .6148 .50763 L p F P
0 g
s
.556 .443 .68 r
.65221 .44409 m .65066 .4374 L .6579 .43402 L p F P
0 g
s
.593 .543 .769 r
.63794 .36214 m .64021 .36804 L .62889 .36945 L p F P
0 g
s
.593 .543 .769 r
.62889 .36945 m .62804 .36724 L .63794 .36214 L p F P
0 g
s
.669 .748 .91 r
.32216 .30126 m .33292 .29741 L .33615 .30074 L p F P
0 g
s
.649 .76 .93 r
.33292 .29741 m .32216 .30126 L .31892 .29769 L p F P
0 g
s
.686 .738 .891 r
.30817 .30209 m .31892 .29769 L .32216 .30126 L p F P
0 g
s
.826 .601 .598 r
.1662 .48265 m .16515 .48227 L .16449 .47611 L p F P
0 g
s
.833 .607 .595 r
.16145 .47491 m .16449 .47611 L .16515 .48227 L p F P
0 g
s
.675 .747 .905 r
.31892 .29769 m .30817 .30209 L .30491 .29834 L p F P
0 g
s
.7 .731 .875 r
.29415 .30327 m .30491 .29834 L .30817 .30209 L p F P
0 g
s
.752 .715 .818 r
.22691 .32001 m .22918 .31838 L .23514 .32082 L p F P
0 g
s
.752 .719 .821 r
.23778 .31232 m .22918 .31838 L .23514 .32082 L p F P
0 g
s
.752 .719 .821 r
.23514 .32082 m .24109 .31659 L .23778 .31232 L p F P
0 g
s
.805 .7 .749 r
.16063 .39012 m .16409 .38596 L .16075 .38093 L p F P
0 g
s
0 .523 .741 r
.28454 .54479 m .28541 .54494 L .29202 .54591 L p F P
0 g
s
.812 .693 .733 r
.15562 .40605 m .15605 .40547 L .15273 .40015 L p F P
0 g
s
.156 .697 .749 r
.51407 .5456 m .51169 .54562 L .50065 .54761 L p F P
0 g
s
.452 .852 .973 r
.51169 .54562 m .50065 .54761 L .49767 .54719 L p F P
0 g
s
.23 .749 .836 r
.50065 .54761 m .49767 .54719 L .48665 .5492 L p F P
0 g
s
.648 .761 .931 r
.33615 .30074 m .3469 .29742 L .35012 .30047 L p F P
0 g
s
.614 .777 .959 r
.3469 .29742 m .33615 .30074 L .33292 .29741 L p F P
0 g
s
.55 0 0 r
.25347 .53819 m .2513 .53711 L .25543 .53808 L closepath p F P
0 g
s
.273 0 0 r
.25347 .53819 m .25543 .53808 L p .26694 .54155 L F P
0 g
s
.518 .818 1 r
.41597 .55253 m .40537 .55265 L .40268 .5531 L p F P
0 g
s
.519 .818 .999 r
.40537 .55265 m .40187 .55268 L .40268 .5531 L closepath p F P
0 g
s
.596 .552 .776 r
.63728 .36051 m .63794 .36214 L .62804 .36724 L p F P
0 g
s
.596 .552 .776 r
.62804 .36724 m .62597 .36207 L .63728 .36051 L p F P
0 g
s
.816 .689 .724 r
.15027 .40347 m .15562 .40605 L .15111 .41251 L p F P
0 g
s
.812 .693 .733 r
.15273 .40015 m .15027 .40347 L .15562 .40605 L p F P
0 g
s
.662 .716 .889 r
.5041 .29793 m .49308 .30166 L .49009 .29779 L p F P
0 g
s
.662 .698 .873 r
.49308 .30166 m .5041 .29793 L .50708 .30208 L p F P
0 g
s
.693 .737 .885 r
.30491 .29834 m .29415 .30327 L .29089 .29937 L p F P
0 g
s
.829 .656 .668 r
.14736 .44234 m .15292 .4448 L .1502 .45071 L p F P
0 g
s
.825 .661 .68 r
.15043 .43632 m .14736 .44234 L .15292 .4448 L p F P
0 g
s
.825 .661 .68 r
.15152 .43681 m .15043 .43632 L p .15292 .4448 L F P
0 g
s
.777 .712 .791 r
.19765 .34375 m .1941 .34692 L .19075 .34238 L p F P
0 g
s
.782 .713 .787 r
.18912 .35154 m .1941 .34692 L .19075 .34238 L p F P
0 g
s
.646 .648 .838 r
.53805 .30891 m .54915 .30554 L .55209 .31063 L p F P
0 g
s
.647 .654 .843 r
.54915 .30554 m .53805 .30891 L .53511 .30397 L p F P
0 g
s
.784 .711 .783 r
.18912 .35154 m .18306 .35728 L .17971 .3527 L p F P
0 g
s
.784 .711 .783 r
.17971 .3527 m .18368 .34894 L .18912 .35154 L p F P
0 g
s
.782 .713 .787 r
.19075 .34238 m .18368 .34894 L .18912 .35154 L p F P
0 g
s
.818 .678 .709 r
.14686 .41889 m .15235 .4214 L .14841 .42769 L p F P
0 g
s
.816 .682 .715 r
.15235 .4214 m .14686 .41889 L .15111 .41251 L p F P
0 g
s
.777 .712 .791 r
.19075 .34238 m .1921 .34118 L .19765 .34375 L p F P
0 g
s
.775 .714 .795 r
.20134 .33315 m .1921 .34118 L .19765 .34375 L p F P
0 g
s
.775 .714 .795 r
.20237 .33365 m .20134 .33315 L p .19765 .34375 L F P
0 g
s
.775 .714 .795 r
.19765 .34375 m .20508 .33728 L .20237 .33365 L p F P
0 g
s
.564 .793 .985 r
.36089 .29761 m .35012 .30047 L .3469 .29742 L p F P
0 g
s
.624 .775 .953 r
.35012 .30047 m .36089 .29761 L .3641 .30036 L p F P
0 g
s
.81 .487 .442 r
.19851 .51359 m .19196 .51153 L .19076 .50678 L p F P
0 g
s
.809 .48 .432 r
.18684 .50555 m .19076 .50678 L .19196 .51153 L p F P
0 g
s
.222 0 0 r
.2753 .54301 m .27073 .54196 L p .28005 .54388 L F P
0 g
s
.254 0 0 r
.2753 .54301 m .26751 .54168 L .27073 .54196 L closepath p F P
0 g
s
0 .498 .727 r
.2753 .54301 m .28113 .5438 L p .27023 .5421 L F P
0 g
s
0 .498 .727 r
.26725 .54163 m .2753 .54301 L .27023 .5421 L F
.222 0 0 r
.28336 .54456 m .2753 .54301 L p .28005 .54388 L F P
0 g
s
.611 .582 .796 r
.60615 .34372 m .60598 .34335 L .60746 .34306 L closepath p F P
0 g
s
.261 .77 .838 r
.51169 .54562 m .51407 .5456 L .52017 .54456 L p F P
0 g
s
.522 .824 1 r
.42976 .55209 m .4192 .55245 L .41667 .5529 L p F P
0 g
s
.526 .821 .999 r
.4192 .55245 m .41597 .55253 L .41667 .5529 L closepath p F P
0 g
s
.789 .712 .779 r
.1812 .35911 m .18306 .35728 L .17971 .3527 L p F P
0 g
s
.47 .783 .998 r
.3157 .54909 m .32632 .54867 L .32611 .54855 L p F P
0 g
s
.47 .783 .998 r
.31236 .54787 m .3157 .54909 L p .32611 .54855 L F P
0 g
s
.366 .761 .986 r
.3157 .54909 m .32632 .54867 L .32962 .55016 L p F P
0 g
s
.612 .584 .799 r
.60746 .34306 m .60598 .34335 L .60307 .33695 L p F P
0 g
s
.823 .669 .692 r
.15152 .43681 m .15089 .43551 L .15043 .43632 L closepath p F P
0 g
s
.685 .186 .051 r
.23624 .53369 m .2362 .53368 L .23148 .52996 L p F P
0 g
s
.665 .147 0 r
.22423 .52814 m .23148 .52996 L .2362 .53368 L p F P
0 g
s
.734 .293 .203 r
.23148 .52996 m .22423 .52814 L .22271 .52652 L p F P
0 g
s
.517 .851 .996 r
.48665 .5492 m .49767 .54719 L .49512 .5462 L p F P
0 g
s
.517 .851 .996 r
.48364 .54838 m .48665 .5492 L p .49512 .5462 L F P
0 g
s
.433 .839 .973 r
.47265 .55041 m .48364 .54838 L .48665 .5492 L p F P
0 g
s
.788 .71 .778 r
.17586 .35649 m .1812 .35911 L .17396 .36647 L p F P
0 g
s
.789 .712 .779 r
.17971 .3527 m .17586 .35649 L .1812 .35911 L p F P
0 g
s
.784 .412 .353 r
.21409 .52206 m .20717 .52013 L .20577 .51741 L p F P
0 g
s
.785 .413 .352 r
.20717 .52013 m .20394 .51922 L .20577 .51741 L closepath p F P
0 g
s
.632 .621 .822 r
.58023 .31544 m .58035 .31567 L .57006 .32026 L p F P
0 g
s
.632 .621 .822 r
.57006 .32026 m .56906 .31835 L .58023 .31544 L p F P
0 g
s
.769 .713 .799 r
.20508 .33728 m .20697 .3357 L .20237 .33365 L closepath p F P
0 g
s
.807 .697 .744 r
.15529 .38752 m .16063 .39012 L .15524 .39686 L p F P
0 g
s
.805 .7 .749 r
.16075 .38093 m .15529 .38752 L .16063 .39012 L p F P
0 g
s
.711 .719 .856 r
.28011 .30482 m .28076 .30449 L .27959 .30418 L closepath p F P
0 g
s
.725 .724 .85 r
.27959 .30418 m .28011 .30482 L p .26604 .30691 L F P
0 g
s
.518 .829 1 r
.44327 .55137 m .43426 .55189 L .43066 .55254 L p F P
0 g
s
.526 .826 .999 r
.43426 .55189 m .42976 .55209 L .43066 .55254 L closepath p F P
0 g
s
.764 .716 .807 r
.21422 .32595 m .21601 .32832 L .20697 .3357 L p F P
0 g
s
.764 .716 .807 r
.21168 .32475 m .21422 .32595 L p .20697 .3357 L F P
0 g
s
.764 .716 .807 r
.20174 .33282 m .21168 .32475 L p .20697 .3357 L F P
0 g
s
.764 .716 .807 r
.20697 .3357 m .20237 .33365 L .20174 .33282 L p F P
0 g
s
.765 .344 .25 r
.22111 .52736 m .21723 .52624 L .21409 .52206 L p F P
0 g
s
.761 .33 .229 r
.20717 .52013 m .21409 .52206 L .21723 .52624 L p F P
0 g
s
.654 .671 .854 r
.53217 .29925 m .53317 .30083 L .52223 .30461 L p F P
0 g
s
.654 .671 .854 r
.52223 .30461 m .52109 .30281 L .53217 .29925 L p F P
0 g
s
.743 .72 .83 r
.24917 .31117 m .24109 .31659 L .23778 .31232 L p F P
0 g
s
.478 .84 .993 r
.46971 .54933 m .47265 .55041 L .48364 .54838 L p F P
0 g
s
.599 .788 .971 r
.3641 .30036 m .37488 .29786 L .37808 .30032 L p F P
0 g
s
.502 .802 .999 r
.37488 .29786 m .3641 .30036 L .36089 .29761 L p F P
0 g
s
.824 .671 .693 r
.15043 .43632 m .15089 .43551 L .14767 .42897 L p F P
0 g
s
.506 .836 .999 r
.45657 .55044 m .45079 .5509 L .44465 .55203 L p F P
0 g
s
.519 .831 1 r
.45079 .5509 m .44327 .55137 L .44465 .55203 L closepath p F P
0 g
s
.707 .721 .86 r
.28761 .29557 m .29089 .29937 L .28076 .30449 L p F P
0 g
s
.707 .721 .86 r
.27683 .30082 m .28761 .29557 L p .28076 .30449 L F P
0 g
s
.707 .721 .86 r
.28076 .30449 m .27959 .30418 L .27683 .30082 L p F P
0 g
s
.484 .841 .994 r
.46971 .54933 m .46908 .54939 L .45865 .55133 L p F P
0 g
s
.505 .837 .998 r
.46908 .54939 m .45657 .55044 L .45865 .55133 L closepath p F P
0 g
s
.445 .132 .34 r
.60249 .51819 m .60347 .51413 L .61441 .51056 L p F P
0 g
s
.484 .208 .419 r
.6148 .50763 m .61441 .51056 L .60347 .51413 L p F P
0 g
s
.461 .146 .345 r
.60347 .51413 m .60249 .51819 L .59139 .52156 L p F P
0 g
s
.734 .292 .202 r
.22423 .52814 m .22111 .52736 L .22271 .52652 L closepath p F P
0 g
s
.658 .684 .863 r
.50708 .30208 m .51813 .29841 L .52109 .30281 L p F P
0 g
s
.66 .698 .875 r
.51813 .29841 m .50708 .30208 L .5041 .29793 L p F P
0 g
s
.288 0 0 r
.56501 .53414 m .55958 .53545 L .55367 .53666 L p F P
0 g
s
.231 0 0 r
.55958 .53545 m .55342 .5369 L .55367 .53666 L closepath p F P
0 g
s
.519 .329 .563 r
.63656 .48841 m .63624 .48304 L .64672 .47883 L p F P
0 g
s
.533 .359 .591 r
.64616 .47321 m .64672 .47883 L .63624 .48304 L p F P
0 g
s
.53 .337 .564 r
.63088 .49055 m .63656 .48841 L .63624 .48304 L p F P
0 g
s
.596 .553 .776 r
.63436 .35323 m .63728 .36051 L .62597 .36207 L p F P
0 g
s
.596 .553 .776 r
.63351 .35335 m .63436 .35323 L p .62597 .36207 L F P
0 g
s
.596 .553 .776 r
.62597 .36207 m .62438 .3581 L .63351 .35335 L p F P
0 g
s
.793 .706 .769 r
.17195 .36857 m .17396 .36647 L .1687 .36396 L closepath p F P
0 g
s
.788 .71 .778 r
.1686 .36381 m .17586 .35649 L p .17396 .36647 L F P
0 g
s
.788 .71 .778 r
.17396 .36647 m .1687 .36396 L .1686 .36381 L p F P
0 g
s
.55 .428 .667 r
.65221 .44409 m .66233 .43937 L p .65885 .44815 L F P
0 g
s
.55 .428 .667 r
.65885 .44815 m .65288 .44728 L .65221 .44409 L p F P
0 g
s
.556 .443 .68 r
.66117 .43434 m .66233 .43937 L .65221 .44409 L p F P
0 g
s
.556 .443 .68 r
.6579 .43402 m .66117 .43434 L p .65221 .44409 L F P
0 g
s
.828 .665 .681 r
.14496 .43382 m .15043 .43632 L .14736 .44234 L p F P
0 g
s
.824 .671 .693 r
.14767 .42897 m .14496 .43382 L .15043 .43632 L p F P
0 g
s
.534 .376 .613 r
.64616 .47321 m .6454 .46737 L .6515 .46477 L p F P
0 g
s
.608 .576 .792 r
.61723 .34129 m .60746 .34306 L .6161 .33869 L closepath p F P
0 g
s
.612 .584 .799 r
.61433 .33478 m .6161 .33869 L .60746 .34306 L p F P
0 g
s
.612 .584 .799 r
.60307 .33695 m .61433 .33478 L p .60746 .34306 L F P
0 g
s
.725 .724 .85 r
.26604 .30691 m .27437 .30219 L .27959 .30418 L p F P
0 g
s
.723 .725 .851 r
.27959 .30418 m .27683 .30082 L .27437 .30219 L closepath p F P
0 g
s
.797 .707 .765 r
.16729 .37363 m .17195 .36857 L .1687 .36396 L p F P
0 g
s
.157 0 0 r
.28454 .54479 m .28336 .54456 L .28541 .54494 L closepath p F P
0 g
s
.482 .219 .437 r
.6148 .50763 m .62065 .50411 L .61498 .50609 L closepath p F P
0 g
s
.507 .268 .487 r
.62589 .49981 m .62599 .4975 L p .61498 .50609 L F P
0 g
s
.507 .268 .487 r
.61498 .50609 m .62065 .50411 L .62589 .49981 L p F P
0 g
s
.516 .303 .53 r
.62599 .4975 m .62908 .49636 L .63088 .49055 L p F P
0 g
s
.513 .301 .529 r
.63656 .48841 m .63088 .49055 L .62908 .49636 L p F P
0 g
s
.578 .8 .983 r
.37808 .30032 m .38888 .29802 L .39206 .30024 L p F P
0 g
s
.461 .804 .999 r
.37808 .30032 m .38888 .29802 L .38691 .29707 L p F P
0 g
s
.461 .804 .999 r
.37488 .29786 m .37808 .30032 L p .38691 .29707 L F P
0 g
s
.534 .812 .997 r
.39952 .55136 m .39252 .55256 L .40187 .55268 L closepath p F P
0 g
s
.543 .815 .996 r
.39952 .55136 m .40187 .55268 L .40537 .55265 L p F P
0 g
s
.64 .639 .833 r
.56322 .30744 m .56327 .30753 L .55278 .31188 L p F P
0 g
s
.64 .639 .833 r
.55278 .31188 m .55209 .31063 L .56322 .30744 L p F P
0 g
s
.761 .714 .809 r
.21601 .32832 m .21734 .32729 L .21422 .32595 L closepath p F P
0 g
s
.467 0 0 r
.2513 .53711 m .25347 .53819 L .24995 .53791 L p F P
0 g
s
.467 0 0 r
.24995 .53791 m .24384 .53537 L .2513 .53711 L p F P
0 g
s
.543 .816 .996 r
.41353 .55116 m .40537 .55265 L .41597 .55253 L closepath p F P
0 g
s
.543 .815 .996 r
.40537 .55265 m .41353 .55116 L p .39952 .55136 L F P
0 g
s
.383 .006 .193 r
.60249 .51819 m .59139 .52156 L .58993 .52516 L p F P
0 g
s
.632 .625 .825 r
.58023 .31544 m .56906 .31835 L .56614 .31286 L p F P
0 g
s
.832 .621 .617 r
.16145 .47491 m .15564 .47256 L .15722 .467 L p F P
0 g
s
.835 .609 .596 r
.15564 .47256 m .16145 .47491 L .16029 .48035 L p F P
0 g
s
.833 .607 .595 r
.16515 .48227 m .16029 .48035 L .16145 .47491 L p F P
0 g
s
.623 .605 .812 r
.58618 .32732 m .58605 .32706 L .58734 .32677 L closepath p F P
0 g
s
.825 .583 .572 r
.17165 .49018 m .16548 .48797 L .1662 .48265 L p F P
0 g
s
.828 .585 .572 r
.16515 .48227 m .1662 .48265 L .16548 .48797 L p F P
0 g
s
.756 .717 .816 r
.22401 .31624 m .22691 .32001 L .21734 .32729 L p F P
0 g
s
.756 .717 .816 r
.2233 .31591 m .22401 .31624 L p .21734 .32729 L F P
0 g
s
.756 .717 .816 r
.21268 .32396 m .2233 .31591 L p .21734 .32729 L F P
0 g
s
.756 .717 .816 r
.21734 .32729 m .21422 .32595 L .21268 .32396 L p F P
0 g
s
.53 .813 .998 r
.39252 .55256 m .39952 .55136 L p .38552 .55146 L F P
0 g
s
.53 .813 .998 r
.38552 .55146 m .38744 .55251 L .39252 .55256 L p F P
0 g
s
.549 .818 .996 r
.41353 .55116 m .41597 .55253 L .4192 .55245 L p F P
0 g
s
.517 .808 .998 r
.38552 .55146 m .38038 .55226 L .38744 .55251 L closepath p F P
0 g
s
.623 .609 .816 r
.58734 .32677 m .58605 .32706 L .58314 .32123 L p F P
0 g
s
.721 .726 .854 r
.27437 .30219 m .26604 .30691 L .26275 .30278 L p F P
0 g
s
.733 .721 .84 r
.25193 .30935 m .26275 .30278 L .26604 .30691 L p F P
0 g
s
.545 .82 .997 r
.42755 .55086 m .4192 .55245 L .42976 .55209 L closepath p F P
0 g
s
.549 .818 .996 r
.4192 .55245 m .42755 .55086 L p .41353 .55116 L F P
0 g
s
.834 .624 .618 r
.15148 .46462 m .15722 .467 L .15564 .47256 L p F P
0 g
s
.831 .634 .636 r
.15722 .467 m .15148 .46462 L .15348 .45893 L p F P
0 g
s
.444 .786 .998 r
.34203 .55007 m .33698 .5495 L .32962 .55016 L p F P
0 g
s
.424 .789 .995 r
.33698 .5495 m .32962 .55016 L .32632 .54867 L p F P
0 g
s
.067 0 0 r
.55083 .53836 m .55342 .5369 L .55958 .53545 L p F P
0 g
s
.134 0 0 r
.55342 .5369 m .55083 .53836 L .5397 .54065 L p F P
0 g
s
.802 .435 .361 r
.19196 .51153 m .19851 .51359 L .20047 .51812 L p F P
0 g
s
.802 .44 .371 r
.20394 .51922 m .20047 .51812 L .19851 .51359 L p F P
0 g
s
.817 .685 .717 r
.14572 .40995 m .15111 .41251 L .14686 .41889 L p F P
0 g
s
.816 .689 .724 r
.15111 .41251 m .14572 .40995 L .15027 .40347 L p F P
0 g
s
.141 .683 .712 r
.52571 .54355 m .52017 .54456 L .52621 .54347 L closepath p F P
0 g
s
.261 .77 .838 r
.52017 .54456 m .52571 .54355 L p .51169 .54562 L F P
0 g
s
.569 .808 .989 r
.39206 .30024 m .40289 .29797 L .40605 .30006 L p F P
0 g
s
.435 .808 .993 r
.39206 .30024 m .40289 .29797 L .4015 .29739 L p F P
0 g
s
.435 .808 .993 r
.38888 .29802 m .39206 .30024 L p .4015 .29739 L F P
0 g
s
.826 .561 .539 r
.17768 .49752 m .17148 .49533 L .17165 .49018 L p F P
0 g
s
.827 .562 .539 r
.16548 .48797 m .17165 .49018 L .17148 .49533 L p F P
0 g
s
.006 .564 .811 r
.28336 .54456 m .28454 .54479 L .28113 .5438 L p F P
0 g
s
.006 .564 .811 r
.28113 .5438 m .2753 .54301 L .28336 .54456 L p F P
0 g
s
.6 .562 .783 r
.62438 .3581 m .62306 .35492 L .63351 .35335 L closepath p F P
0 g
s
.797 .707 .765 r
.16854 .36387 m .16197 .371 L .16729 .37363 L p F P
0 g
s
.797 .707 .765 r
.1687 .36396 m .16854 .36387 L p .16729 .37363 L F P
0 g
s
.797 .706 .764 r
.16197 .371 m .16729 .37363 L .16096 .38068 L p F P
0 g
s
.51 .81 .999 r
.38038 .55226 m .38552 .55146 L p .37153 .55144 L F P
0 g
s
.51 .81 .999 r
.37153 .55144 m .3727 .55205 L .38038 .55226 L p F P
0 g
s
.81 .694 .736 r
.15524 .39686 m .15273 .40015 L .14939 .39488 L p F P
0 g
s
.81 .694 .736 r
.14939 .39488 m .14984 .39429 L .15524 .39686 L p F P
0 g
s
.807 .697 .744 r
.15524 .39686 m .14984 .39429 L .15529 .38752 L p F P
0 g
s
.55 .428 .666 r
.65357 .45058 m .65288 .44728 L .65885 .44815 L closepath p F P
0 g
s
.656 .683 .864 r
.53217 .29925 m .52109 .30281 L .51813 .29841 L p F P
0 g
s
.828 .585 .572 r
.16548 .48797 m .16515 .48785 L .16515 .48227 L p F P
0 g
s
.836 .592 .57 r
.16029 .48035 m .16515 .48227 L .16515 .48785 L p F P
0 g
s
.642 .645 .838 r
.56322 .30744 m .55209 .31063 L .54915 .30554 L p F P
0 g
s
.809 .48 .432 r
.18513 .50854 m .18684 .50555 L p .19196 .51153 L F P
0 g
s
.821 .503 .451 r
.18513 .50854 m .18431 .50468 L .18684 .50555 L closepath p F P
0 g
s
.833 .637 .638 r
.14781 .45651 m .15348 .45893 L .15148 .46462 L p F P
0 g
s
.83 .646 .653 r
.15348 .45893 m .14781 .45651 L .1502 .45071 L p F P
0 g
s
.55 .822 .996 r
.42755 .55086 m .42976 .55209 L .43426 .55189 L p F P
0 g
s
.62 .601 .809 r
.59726 .32455 m .58734 .32677 L .59624 .32244 L closepath p F P
0 g
s
.623 .609 .816 r
.59435 .31862 m .59624 .32244 L .58734 .32677 L p F P
0 g
s
.623 .609 .816 r
.58314 .32123 m .59435 .31862 L p .58734 .32677 L F P
0 g
s
.491 .803 1 r
.37153 .55144 m .36869 .55182 L .3727 .55205 L closepath p F P
0 g
s
.744 .723 .832 r
.24862 .30521 m .24323 .30872 L .24917 .31117 L p F P
0 g
s
.744 .723 .832 r
.24917 .31117 m .25193 .30935 L .24862 .30521 L p F P
0 g
s
.743 .72 .83 r
.23778 .31232 m .24323 .30872 L .24917 .31117 L p F P
0 g
s
.576 .811 .988 r
.40605 .30006 m .41692 .29767 L .42005 .29974 L p F P
0 g
s
.441 .817 .992 r
.40605 .30006 m .41692 .29767 L .41554 .29711 L p F P
0 g
s
.441 .817 .992 r
.40289 .29797 m .40605 .30006 L p .41554 .29711 L F P
0 g
s
.822 .671 .696 r
.14767 .42897 m .14841 .42769 L .14662 .42688 L closepath p F P
0 g
s
.818 .678 .709 r
.14441 .4228 m .14686 .41889 L p .14841 .42769 L F P
0 g
s
.818 .678 .709 r
.14841 .42769 m .14662 .42688 L .14441 .4228 L p F P
0 g
s
.826 .536 .498 r
.18431 .50468 m .1781 .5025 L .17768 .49752 L p F P
0 g
s
.827 .536 .496 r
.17148 .49533 m .17768 .49752 L .1781 .5025 L p F P
0 g
s
.496 .262 .489 r
.62589 .49981 m .62908 .49636 L .62599 .4975 L closepath p F P
0 g
s
.55 .822 .996 r
.43426 .55189 m .44157 .55047 L p .42755 .55086 L F P
0 g
s
.542 .826 .998 r
.44157 .55047 m .43426 .55189 L .44327 .55137 L closepath p F P
0 g
s
.612 .586 .8 r
.61142 .32837 m .61433 .33478 L .60307 .33695 L p F P
0 g
s
.612 .586 .8 r
.61118 .32842 m .61142 .32837 L p .60307 .33695 L F P
0 g
s
.612 .586 .8 r
.60307 .33695 m .60144 .33337 L .61118 .32842 L p F P
0 g
s
.479 .806 1 r
.36869 .55182 m .37153 .55144 L p .35754 .55127 L F P
0 g
s
.479 .806 1 r
.35754 .55127 m .35766 .55133 L .36869 .55182 L p F P
0 g
s
.402 .023 .202 r
.58993 .52516 m .58745 .52586 L .57873 .52819 L p F P
0 g
s
.374 0 .15 r
.58745 .52586 m .57866 .52832 L .57873 .52819 L closepath p F P
0 g
s
.597 .809 .981 r
.42005 .29974 m .43095 .2971 L .43405 .29929 L p F P
0 g
s
.477 .831 .996 r
.42005 .29974 m .43095 .2971 L .42908 .29629 L p F P
0 g
s
.477 .831 .996 r
.41692 .29767 m .42005 .29974 L p .42908 .29629 L F P
0 g
s
.6 .562 .784 r
.63351 .35335 m .62306 .35492 L .62043 .34862 L p F P
0 g
s
.752 .716 .818 r
.22691 .32001 m .22918 .31838 L .22401 .31624 L closepath p F P
0 g
s
.373 .782 .982 r
.34357 .55086 m .34715 .55039 L .35728 .5513 L p F P
0 g
s
.488 .802 1 r
.34715 .55039 m .34203 .55007 L .34357 .55086 L closepath p F P
0 g
s
.832 .648 .654 r
.14461 .44825 m .1502 .45071 L .14781 .45651 L p F P
0 g
s
.829 .656 .668 r
.1502 .45071 m .14461 .44825 L .14736 .44234 L p F P
0 g
s
.814 .695 .733 r
.15027 .40347 m .15273 .40015 L .14939 .39488 L p F P
0 g
s
.826 .673 .692 r
.14496 .43382 m .14767 .42897 L .14662 .42688 L p F P
0 g
s
0 .523 .741 r
.29843 .54662 m .29506 .54527 L .28454 .54479 L p F P
0 g
s
.373 .751 .99 r
.28454 .54479 m .29506 .54527 L .29241 .5439 L p F P
0 g
s
.373 .751 .99 r
.28113 .5438 m .28454 .54479 L p .29241 .5439 L F P
0 g
s
.732 .724 .843 r
.26275 .30278 m .25193 .30935 L .24862 .30521 L p F P
0 g
s
.803 .702 .754 r
.16075 .38093 m .16096 .38068 L .1604 .38041 L closepath p F P
0 g
s
.797 .706 .764 r
.15738 .37612 m .16197 .371 L p .16096 .38068 L F P
0 g
s
.797 .706 .764 r
.16096 .38068 m .1604 .38041 L .15738 .37612 L p F P
0 g
s
.532 .839 .999 r
.43405 .29929 m .44498 .29636 L .4421 .29489 L p F P
0 g
s
.532 .839 .999 r
.43095 .2971 m .43405 .29929 L p .4421 .29489 L F P
0 g
s
.621 .799 .967 r
.43405 .29929 m .44498 .29636 L .44806 .29878 L p F P
0 g
s
.272 0 0 r
.57644 .53117 m .57866 .52832 L .58745 .52586 L p F P
0 g
s
.302 0 0 r
.57866 .52832 m .57644 .53117 L .56501 .53414 L p F P
0 g
s
.807 .702 .75 r
.15529 .38752 m .16075 .38093 L .1604 .38041 L p F P
0 g
s
.469 .198 .419 r
.61441 .51056 m .6148 .50763 L .62065 .50411 L p F P
0 g
s
.542 .41 .651 r
.65473 .45686 m .65357 .45058 L .65885 .44815 L p F P
0 g
s
.747 .719 .825 r
.23445 .30809 m .23778 .31232 L .22918 .31838 L p F P
0 g
s
.747 .719 .825 r
.22358 .31569 m .23445 .30809 L p .22918 .31838 L F P
0 g
s
.747 .719 .825 r
.22918 .31838 m .22401 .31624 L .22358 .31569 L p F P
0 g
s
.641 .781 .948 r
.44806 .29878 m .45902 .29555 L .46207 .29829 L p F P
0 g
s
.594 .826 .988 r
.45902 .29555 m .44806 .29878 L .44498 .29636 L p F P
0 g
s
.665 .147 0 r
.2362 .53368 m .22921 .53179 L .22423 .52814 L p F P
0 g
s
.628 .088 0 r
.22111 .52736 m .22423 .52814 L .22921 .53179 L p F P
0 g
s
0 0 0 r
.53815 .5411 m .5397 .54065 L .55083 .53836 L p F P
0 g
s
.017 0 0 r
.5397 .54065 m .53815 .5411 L .52621 .54347 L p F P
0 g
s
.807 .702 .75 r
.1604 .38041 m .15572 .37804 L p .15529 .38752 L F P
0 g
s
.804 .707 .758 r
.1604 .38041 m .15738 .37612 L .15572 .37804 L closepath p F P
0 g
s
.545 .827 .998 r
.44157 .55047 m .44327 .55137 L .45079 .5509 L p F P
0 g
s
.573 .501 .735 r
.65268 .40369 m .65203 .40167 L .6569 .40152 L closepath p F P
0 g
s
.568 .49 .726 r
.65499 .41127 m .65268 .40369 L .6569 .40152 L p F P
0 g
s
.576 .494 .725 r
.65268 .40369 m .65499 .41127 L .65475 .41139 L p F P
0 g
s
.654 .759 .927 r
.46207 .29829 m .47305 .29483 L .47608 .29793 L p F P
0 g
s
.633 .801 .963 r
.47305 .29483 m .46207 .29829 L .45902 .29555 L p F P
0 g
s
.573 .501 .736 r
.6569 .40152 m .65203 .40167 L .65017 .39589 L p F P
0 g
s
.766 .719 .809 r
.21422 .32595 m .21268 .32396 L .21168 .32475 L closepath p F P
0 g
s
.573 .501 .736 r
.65017 .39589 m .65732 .39217 L p .6569 .40152 L F P
0 g
s
.577 .511 .744 r
.65017 .39589 m .64905 .39259 L .65732 .39217 L closepath p F P
0 g
s
.453 .794 .998 r
.35754 .55127 m .35728 .5513 L .35766 .55133 L closepath p F P
0 g
s
.825 .502 .443 r
.18431 .50468 m .18513 .50854 L .18468 .50924 L p F P
0 g
s
.825 .502 .443 r
.1781 .5025 m .18431 .50468 L p .18468 .50924 L F P
0 g
s
.529 .797 .995 r
.35728 .5513 m .35754 .55127 L .35431 .54931 L p F P
0 g
s
.529 .797 .995 r
.35431 .54931 m .34715 .55039 L .35728 .5513 L p F P
0 g
s
.57 .482 .715 r
.65503 .41138 m .65475 .41139 L .65499 .41127 L closepath p F P
0 g
s
.773 .717 .8 r
.20237 .33365 m .20174 .33282 L .20134 .33315 L closepath p F P
0 g
s
.647 .654 .843 r
.53511 .30397 m .54622 .30057 L .54915 .30554 L p F P
0 g
s
.649 .664 .851 r
.54387 .29673 m .54622 .30057 L .53511 .30397 L p F P
0 g
s
.649 .664 .851 r
.53511 .30397 m .53317 .30083 L .54387 .29673 L p F P
0 g
s
.826 .673 .692 r
.14662 .42688 m .14298 .42516 L p .14496 .43382 L F P
0 g
s
.824 .68 .704 r
.14662 .42688 m .14441 .4228 L .14298 .42516 L closepath p F P
0 g
s
.577 .511 .745 r
.65732 .39217 m .64905 .39259 L .64745 .38786 L p F P
0 g
s
.167 .702 .725 r
.52571 .54355 m .52621 .54347 L .53815 .5411 L p F P
0 g
s
.761 .33 .229 r
.21723 .52624 m .21045 .52427 L .20717 .52013 L p F P
0 g
s
.749 .303 .194 r
.20394 .51922 m .20717 .52013 L .21045 .52427 L p F P
0 g
s
.479 .806 1 r
.37153 .55144 m .36832 .54935 L .35754 .55127 L p F P
0 g
s
.605 .781 .965 r
.36832 .54935 m .35754 .55127 L .35431 .54931 L p F P
0 g
s
.562 .477 .716 r
.65503 .41138 m .65499 .41127 L .66488 .40617 L p F P
0 g
s
.568 .49 .726 r
.66346 .40152 m .66488 .40617 L .65499 .41127 L p F P
0 g
s
.568 .49 .726 r
.6569 .40152 m .66346 .40152 L p .65499 .41127 L F P
0 g
s
.563 .477 .715 r
.6571 .4186 m .65503 .41138 L .66648 .41168 L p F P
0 g
s
.562 .477 .716 r
.66488 .40617 m .66648 .41168 L .65503 .41138 L p F P
0 g
s
.814 .695 .733 r
.14939 .39488 m .14498 .40086 L .15027 .40347 L p F P
0 g
s
.817 .692 .726 r
.14498 .40086 m .15027 .40347 L .14572 .40995 L p F P
0 g
s
.66 .737 .907 r
.47608 .29793 m .48708 .29431 L .49009 .29779 L p F P
0 g
s
.652 .771 .936 r
.48708 .29431 m .47608 .29793 L .47305 .29483 L p F P
0 g
s
.831 .659 .669 r
.14186 .43984 m .14736 .44234 L .14461 .44825 L p F P
0 g
s
.828 .665 .681 r
.14736 .44234 m .14186 .43984 L .14496 .43382 L p F P
0 g
s
.273 0 0 r
.25937 .53985 m .25347 .53819 L p .26559 .54122 L F P
0 g
s
.318 0 0 r
.25937 .53985 m .25347 .53819 L .24995 .53791 L p F P
0 g
s
.086 .614 .872 r
.26036 .53922 m .25244 .53833 L p .25937 .53985 L F P
0 g
s
.086 .614 .872 r
.25244 .53833 m .25152 .53822 L .25937 .53985 L p F P
0 g
s
.273 0 0 r
.26694 .54155 m .25937 .53985 L p .26559 .54122 L F P
0 g
s
.577 .511 .745 r
.64745 .38786 m .65603 .38333 L p .65732 .39217 L F P
0 g
s
.58 .521 .753 r
.64745 .38786 m .64609 .38401 L .65603 .38333 L closepath p F P
0 g
s
.778 .714 .793 r
.19075 .34238 m .1921 .34118 L .18862 .33954 L closepath p F P
0 g
s
.783 .715 .788 r
.18368 .34894 m .19075 .34238 L .18862 .33954 L p F P
0 g
s
.772 .717 .801 r
.196 .3305 m .20134 .33315 L .1921 .34118 L p F P
0 g
s
.772 .717 .801 r
.18739 .33793 m .196 .3305 L p .1921 .34118 L F P
0 g
s
.772 .717 .801 r
.1921 .34118 m .18862 .33954 L .18739 .33793 L p F P
0 g
s
.785 .713 .785 r
.18368 .34894 m .17971 .3527 L .17634 .34817 L p F P
0 g
s
.785 .713 .785 r
.17634 .34817 m .17831 .3463 L .18368 .34894 L p F P
0 g
s
.783 .715 .788 r
.18669 .33856 m .17831 .3463 L .18368 .34894 L p F P
0 g
s
.783 .715 .788 r
.18862 .33954 m .18669 .33856 L p .18368 .34894 L F P
0 g
s
.821 .68 .707 r
.14686 .41889 m .14441 .4228 L .14113 .41681 L p F P
0 g
s
.821 .68 .707 r
.14113 .41681 m .14142 .41635 L .14686 .41889 L p F P
0 g
s
.817 .685 .717 r
.14686 .41889 m .14142 .41635 L .14572 .40995 L p F P
0 g
s
.614 .593 .806 r
.60144 .33337 m .60017 .33066 L .61118 .32842 L closepath p F P
0 g
s
.198 0 0 r
.56481 .53431 m .55958 .53545 L .56501 .53414 L closepath p F P
0 g
s
.067 0 0 r
.55958 .53545 m .56481 .53431 L p .55083 .53836 L F P
0 g
s
.79 .714 .781 r
.17586 .35649 m .17971 .3527 L .17634 .34817 L p F P
0 g
s
.721 .726 .854 r
.26275 .30278 m .26809 .29985 L .27437 .30219 L p F P
0 g
s
.725 .73 .854 r
.27354 .2969 m .26809 .29985 L .27437 .30219 L p F P
0 g
s
.725 .73 .854 r
.27437 .30219 m .27683 .30082 L .27354 .2969 L p F P
0 g
s
.675 .747 .905 r
.30491 .29834 m .31566 .29431 L .31892 .29769 L p F P
0 g
s
.658 .756 .922 r
.31566 .29431 m .30491 .29834 L .30165 .29471 L p F P
0 g
s
.693 .737 .885 r
.29089 .29937 m .30165 .29471 L .30491 .29834 L p F P
0 g
s
.523 .351 .59 r
.64672 .47883 m .64616 .47321 L .6565 .4688 L p F P
0 g
s
.534 .376 .613 r
.65626 .46695 m .6565 .4688 L .64616 .47321 L p F P
0 g
s
.534 .376 .613 r
.6515 .46477 m .65626 .46695 L p .64616 .47321 L F P
0 g
s
.358 0 0 r
.24384 .53537 m .24995 .53791 L .24872 .53766 L p F P
0 g
s
.358 0 0 r
.23624 .53369 m .24384 .53537 L p .24872 .53766 L F P
0 g
s
.533 .833 .999 r
.45559 .54995 m .45079 .5509 L .45657 .55044 L closepath p F P
0 g
s
.545 .827 .998 r
.45079 .5509 m .45559 .54995 L p .44157 .55047 L F P
0 g
s
.649 .76 .93 r
.31892 .29769 m .32966 .29434 L .33292 .29741 L p F P
0 g
s
.617 .773 .955 r
.32966 .29434 m .31892 .29769 L .31566 .29431 L p F P
0 g
s
.58 .521 .753 r
.65603 .38333 m .64609 .38401 L .64452 .37957 L p F P
0 g
s
.792 .713 .777 r
.17586 .35649 m .1686 .36381 L .16522 .35924 L p F P
0 g
s
.792 .713 .777 r
.16522 .35924 m .17059 .35382 L .17586 .35649 L p F P
0 g
s
.79 .714 .781 r
.17634 .34817 m .17059 .35382 L .17586 .35649 L p F P
0 g
s
.662 .716 .889 r
.49009 .29779 m .50112 .2941 L .5041 .29793 L p F P
0 g
s
.66 .742 .911 r
.50112 .2941 m .49009 .29779 L .48708 .29431 L p F P
0 g
s
.774 .72 .802 r
.19838 .32849 m .196 .3305 L .20134 .33315 L p F P
0 g
s
.774 .72 .802 r
.20134 .33315 m .20174 .33282 L .19838 .32849 L p F P
0 g
s
.684 .744 .896 r
.30165 .29471 m .29089 .29937 L .28761 .29557 L p F P
0 g
s
.769 .721 .808 r
.21168 .32475 m .20174 .33282 L .19838 .32849 L p F P
0 g
s
.807 .701 .748 r
.15002 .38489 m .15529 .38752 L .14984 .39429 L p F P
0 g
s
.807 .702 .75 r
.15572 .37804 m .15002 .38489 L .15529 .38752 L p F P
0 g
s
0 .498 .727 r
.26725 .54163 m .26751 .54168 L .2753 .54301 L p F P
0 g
s
.624 .611 .817 r
.59144 .3128 m .59435 .31862 L .58314 .32123 L p F P
0 g
s
.624 .611 .817 r
.5814 .31516 m .59144 .3128 L p .58314 .32123 L F P
0 g
s
.624 .611 .817 r
.58314 .32123 m .58035 .31567 L .5814 .31516 L p F P
0 g
s
.487 .25 .48 r
.62908 .49636 m .63663 .49352 L p .62577 .50232 L F P
0 g
s
.487 .25 .48 r
.62577 .50232 m .62589 .49981 L .62908 .49636 L p F P
0 g
s
.513 .301 .529 r
.62908 .49636 m .63663 .49352 L .63656 .48841 L p F P
0 g
s
.559 .466 .705 r
.6571 .4186 m .66703 .41356 L p .66534 .42257 L F P
0 g
s
.559 .466 .705 r
.66534 .42257 m .65807 .42219 L .6571 .4186 L p F P
0 g
s
.563 .477 .715 r
.66648 .41168 m .66703 .41356 L .6571 .4186 L p F P
0 g
s
.603 .57 .79 r
.62043 .34862 m .62014 .34796 L .62234 .34761 L closepath p F P
0 g
s
.6 .562 .784 r
.62043 .34862 m .62234 .34761 L p .63351 .35335 L F P
0 g
s
.469 .198 .419 r
.62065 .50411 m .62577 .50232 L p .61441 .51056 L F P
0 g
s
.503 .263 .483 r
.62065 .50411 m .62577 .50232 L .62589 .49981 L closepath p F P
0 g
s
.51 .81 .999 r
.38552 .55146 m .38234 .54928 L .37153 .55144 L p F P
0 g
s
.619 .778 .957 r
.38234 .54928 m .37153 .55144 L .36832 .54935 L p F P
0 g
s
.632 .625 .825 r
.56614 .31286 m .57731 .30993 L .58023 .31544 L p F P
0 g
s
.634 .629 .828 r
.5744 .30448 m .57731 .30993 L .56614 .31286 L p F P
0 g
s
.634 .629 .828 r
.56386 .30727 m .5744 .30448 L p .56614 .31286 L F P
0 g
s
.634 .629 .828 r
.56614 .31286 m .56327 .30753 L .56386 .30727 L p F P
0 g
s
.628 .088 0 r
.21902 .52793 m .22111 .52736 L p .22921 .53179 L F P
0 g
s
.721 .242 .109 r
.21902 .52793 m .21723 .52624 L .22111 .52736 L closepath p F P
0 g
s
.555 .443 .681 r
.66117 .43434 m .6579 .43402 L .66078 .43266 L closepath p F P
0 g
s
.562 .458 .693 r
.65903 .42573 m .66078 .43266 L .6579 .43402 L p F P
0 g
s
.614 .777 .959 r
.33292 .29741 m .34366 .29473 L .3469 .29742 L p F P
0 g
s
.549 .789 .988 r
.34366 .29473 m .33292 .29741 L .32966 .29434 L p F P
0 g
s
.603 .572 .792 r
.62234 .34761 m .62014 .34796 L .61723 .34129 L p F P
0 g
s
.58 .521 .753 r
.64452 .37957 m .65303 .37501 L p .65603 .38333 L F P
0 g
s
.584 .531 .761 r
.64452 .37957 m .64315 .37585 L .65303 .37501 L closepath p F P
0 g
s
.501 .292 .527 r
.63663 .49352 m .63656 .48841 L .64704 .48421 L p F P
0 g
s
.519 .329 .563 r
.64672 .47883 m .64704 .48421 L .63656 .48841 L p F P
0 g
s
.742 .721 .833 r
.24323 .30872 m .23778 .31232 L .23445 .30809 L p F P
0 g
s
.795 .711 .772 r
.1687 .36396 m .1686 .36381 L .16854 .36387 L closepath p F P
0 g
s
.703 .736 .877 r
.28761 .29557 m .27683 .30082 L .27354 .2969 L p F P
0 g
s
.796 .714 .773 r
.16854 .36387 m .1686 .36381 L .16522 .35924 L p F P
0 g
s
.799 .71 .767 r
.16335 .36119 m .16854 .36387 L .16197 .371 L p F P
0 g
s
.796 .714 .773 r
.16522 .35924 m .16335 .36119 L .16854 .36387 L p F P
0 g
s
.559 .466 .705 r
.65903 .42573 m .65807 .42219 L .66534 .42257 L closepath p F P
0 g
s
.378 .759 .99 r
.30955 .54648 m .30821 .54626 L .29843 .54662 L p F P
0 g
s
.34 .757 .978 r
.30821 .54626 m .29843 .54662 L .29506 .54527 L p F P
0 g
s
.83 .668 .683 r
.13955 .43128 m .14496 .43382 L .14186 .43984 L p F P
0 g
s
.826 .673 .692 r
.14298 .42516 m .13955 .43128 L .14496 .43382 L p F P
0 g
s
.167 .702 .725 r
.53815 .5411 m .53681 .54123 L .52571 .54355 L p F P
0 g
s
.426 .853 .947 r
.53681 .54123 m .52571 .54355 L .52277 .54331 L p F P
0 g
s
.261 .77 .838 r
.52571 .54355 m .52277 .54331 L .51169 .54562 L p F P
0 g
s
.535 .834 .999 r
.45559 .54995 m .45657 .55044 L .46908 .54939 L p F P
0 g
s
.802 .435 .361 r
.20047 .51812 m .19398 .51604 L .19196 .51153 L p F P
0 g
s
.801 .43 .353 r
.18539 .50947 m .19196 .51153 L .19398 .51604 L p F P
0 g
s
.809 .48 .432 r
.19196 .51153 m .18539 .50947 L .18513 .50854 L p F P
0 g
s
.516 .802 .998 r
.34715 .55039 m .35431 .54931 L p .3403 .5491 L F P
0 g
s
.516 .802 .998 r
.3403 .5491 m .34203 .55007 L .34715 .55039 L p F P
0 g
s
.66 .698 .875 r
.5041 .29793 m .51516 .29426 L .51813 .29841 L p F P
0 g
s
.661 .717 .89 r
.51516 .29426 m .5041 .29793 L .50112 .2941 L p F P
0 g
s
.53 .813 .998 r
.39952 .55136 m .39637 .54913 L .38552 .55146 L p F P
0 g
s
.627 .776 .952 r
.39637 .54913 m .38552 .55146 L .38234 .54928 L p F P
0 g
s
.615 .595 .808 r
.61118 .32842 m .60017 .33066 L .59726 .32455 L p F P
0 g
s
.836 .592 .57 r
.16515 .48785 m .15959 .48566 L .16029 .48035 L p F P
0 g
s
.838 .594 .57 r
.15447 .47801 m .16029 .48035 L .15959 .48566 L p F P
0 g
s
.835 .609 .596 r
.16029 .48035 m .15447 .47801 L .15564 .47256 L p F P
0 g
s
.834 .624 .618 r
.15564 .47256 m .14988 .47019 L .15148 .46462 L p F P
0 g
s
.837 .611 .597 r
.14988 .47019 m .15564 .47256 L .15447 .47801 L p F P
0 g
s
.749 .303 .194 r
.20192 .52038 m .20394 .51922 L p .21045 .52427 L F P
0 g
s
.784 .376 .278 r
.20192 .52038 m .20047 .51812 L .20394 .51922 L closepath p F P
0 g
s
.584 .531 .762 r
.65303 .37501 m .64315 .37585 L .64135 .371 L p F P
0 g
s
.533 .376 .614 r
.65626 .46695 m .6515 .46477 L .65572 .46294 L closepath p F P
0 g
s
.544 .398 .633 r
.65473 .45686 m .65572 .46294 L .6515 .46477 L p F P
0 g
s
.769 .721 .808 r
.19838 .32849 m .20627 .32211 L .21168 .32475 L p F P
0 g
s
.767 .722 .81 r
.20932 .31969 m .20627 .32211 L .21168 .32475 L p F P
0 g
s
.767 .722 .81 r
.21168 .32475 m .21268 .32396 L .20932 .31969 L p F P
0 g
s
.564 .793 .985 r
.3469 .29742 m .35765 .29535 L .36089 .29761 L p F P
0 g
s
.457 .787 .999 r
.3469 .29742 m .35765 .29535 L .3557 .29433 L p F P
0 g
s
.457 .787 .999 r
.34366 .29473 m .3469 .29742 L p .3557 .29433 L F P
0 g
s
.761 .723 .817 r
.2233 .31591 m .21268 .32396 L .20932 .31969 L p F P
0 g
s
.827 .562 .539 r
.17148 .49533 m .1653 .49312 L .16548 .48797 L p F P
0 g
s
.83 .565 .538 r
.16515 .48785 m .16548 .48797 L .1653 .49312 L p F P
0 g
s
.534 .392 .634 r
.65572 .46294 m .65473 .45686 L .6649 .45218 L p F P
0 g
s
.542 .41 .651 r
.66439 .44948 m .6649 .45218 L .65473 .45686 L p F P
0 g
s
.542 .41 .651 r
.65885 .44815 m .66439 .44948 L p .65473 .45686 L F P
0 g
s
.825 .681 .705 r
.14298 .42516 m .14441 .4228 L .14113 .41681 L p F P
0 g
s
.554 .453 .694 r
.66078 .43266 m .65903 .42573 L .66534 .42257 L p F P
0 g
s
.836 .626 .619 r
.14579 .46221 m .15148 .46462 L .14988 .47019 L p F P
0 g
s
.833 .637 .638 r
.15148 .46462 m .14579 .46221 L .14781 .45651 L p F P
0 g
s
.642 .645 .838 r
.54915 .30554 m .5603 .30232 L .56322 .30744 L p F P
0 g
s
.643 .651 .843 r
.5603 .30232 m .54915 .30554 L .54622 .30057 L p F P
0 g
s
.489 .791 .998 r
.3403 .5491 m .33698 .5495 L .34203 .55007 L closepath p F P
0 g
s
.83 .565 .538 r
.1653 .49312 m .16442 .4928 L .16515 .48785 L p F P
0 g
s
.839 .573 .538 r
.15959 .48566 m .16515 .48785 L .16442 .4928 L p F P
0 g
s
.543 .815 .996 r
.41353 .55116 m .4104 .54892 L .39952 .55136 L p F P
0 g
s
.631 .775 .95 r
.4104 .54892 m .39952 .55136 L .39637 .54913 L p F P
0 g
s
.818 .689 .721 r
.14039 .40736 m .14572 .40995 L .14142 .41635 L p F P
0 g
s
.817 .692 .726 r
.14572 .40995 m .14039 .40736 L .14498 .40086 L p F P
0 g
s
.716 .725 .857 r
.26809 .29985 m .26275 .30278 L .25944 .29871 L p F P
0 g
s
.732 .724 .843 r
.24862 .30521 m .25944 .29871 L .26275 .30278 L p F P
0 g
s
.799 .71 .767 r
.16197 .371 m .15673 .36834 L .16335 .36119 L p F P
0 g
s
.801 .708 .762 r
.16197 .371 m .15738 .37612 L .154 .37138 L p F P
0 g
s
.801 .708 .762 r
.154 .37138 m .15673 .36834 L .16197 .371 L p F P
0 g
s
.587 .54 .769 r
.64135 .371 m .64021 .36804 L .6483 .36723 L closepath p F P
0 g
s
.584 .531 .762 r
.64135 .371 m .6483 .36723 L p .65303 .37501 L F P
0 g
s
.812 .697 .737 r
.14939 .39488 m .14984 .39429 L .14863 .39369 L closepath p F P
0 g
s
.807 .701 .748 r
.14604 .38984 m .15002 .38489 L p .14984 .39429 L F P
0 g
s
.807 .701 .748 r
.14984 .39429 m .14863 .39369 L .14604 .38984 L p F P
0 g
s
.835 .64 .639 r
.1422 .45407 m .14781 .45651 L .14579 .46221 L p F P
0 g
s
.832 .648 .654 r
.14781 .45651 m .1422 .45407 L .14461 .44825 L p F P
0 g
s
.599 .563 .786 r
.63145 .34627 m .62234 .34761 L .63023 .34337 L closepath p F P
0 g
s
.603 .572 .792 r
.62854 .33948 m .63023 .34337 L .62234 .34761 L p F P
0 g
s
.603 .572 .792 r
.61723 .34129 m .62854 .33948 L p .62234 .34761 L F P
0 g
s
.6 .562 .784 r
.62234 .34761 m .63145 .34627 L p .63351 .35335 L F P
0 g
s
.743 .725 .835 r
.2453 .30111 m .23728 .30625 L .24323 .30872 L p F P
0 g
s
.743 .725 .835 r
.24323 .30872 m .24862 .30521 L .2453 .30111 L p F P
0 g
s
.742 .721 .833 r
.23445 .30809 m .23728 .30625 L .24323 .30872 L p F P
0 g
s
.522 .861 .994 r
.51169 .54562 m .52277 .54331 L .51982 .54227 L p F P
0 g
s
.522 .861 .994 r
.50873 .54486 m .51169 .54562 L p .51982 .54227 L F P
0 g
s
.452 .852 .973 r
.49767 .54719 m .50873 .54486 L .51169 .54562 L p F P
0 g
s
.549 .818 .996 r
.42755 .55086 m .42444 .54865 L .41353 .55116 L p F P
0 g
s
.633 .777 .95 r
.42444 .54865 m .41353 .55116 L .4104 .54892 L p F P
0 g
s
.827 .536 .496 r
.1781 .5025 m .1719 .50031 L .17148 .49533 L p F P
0 g
s
.828 .536 .495 r
.1653 .49312 m .17148 .49533 L .1719 .50031 L p F P
0 g
s
.349 .768 .977 r
.36089 .29761 m .37165 .29602 L .37159 .29599 L p F P
0 g
s
.349 .768 .977 r
.35765 .29535 m .36089 .29761 L p .37159 .29599 L F P
0 g
s
.502 .802 .999 r
.36089 .29761 m .37165 .29602 L .37488 .29786 L p F P
0 g
s
.656 .683 .864 r
.51813 .29841 m .52922 .29482 L .53217 .29925 L p F P
0 g
s
.658 .697 .875 r
.52922 .29482 m .51813 .29841 L .51516 .29426 L p F P
0 g
s
.816 .697 .734 r
.14498 .40086 m .14939 .39488 L .14863 .39369 L p F P
0 g
s
.65 .669 .854 r
.54328 .29579 m .54387 .29673 L .53317 .30083 L p F P
0 g
s
.65 .669 .854 r
.53317 .30083 m .53217 .29925 L .54328 .29579 L p F P
0 g
s
.171 0 0 r
.56481 .53431 m .56501 .53414 L .57644 .53117 L p F P
0 g
s
.829 .677 .694 r
.13766 .42258 m .14298 .42516 L .13955 .43128 L p F P
0 g
s
.825 .681 .705 r
.14113 .41681 m .13766 .42258 L .14298 .42516 L p F P
0 g
s
.759 .721 .818 r
.22401 .31624 m .22358 .31569 L .2233 .31591 L closepath p F P
0 g
s
.781 .719 .794 r
.18862 .33954 m .18739 .33793 L .18669 .33856 L closepath p F P
0 g
s
.696 .189 .03 r
.21723 .52624 m .21902 .52793 L .21586 .52831 L p F P
0 g
s
.696 .189 .03 r
.21045 .52427 m .21723 .52624 L p .21586 .52831 L F P
0 g
s
.587 .541 .77 r
.6483 .36723 m .64021 .36804 L .63794 .36214 L p F P
0 g
s
.55 .822 .996 r
.44157 .55047 m .43848 .54833 L .42755 .55086 L p F P
0 g
s
.632 .78 .953 r
.43848 .54833 m .42755 .55086 L .42444 .54865 L p F P
0 g
s
.47 .783 .998 r
.32611 .54855 m .31781 .54734 L .31236 .54787 L p F P
0 g
s
.45 .789 .998 r
.31781 .54734 m .30955 .54648 L .31236 .54787 L closepath p F P
0 g
s
.543 .796 .991 r
.33698 .5495 m .3403 .5491 L .33704 .54692 L p F P
0 g
s
.543 .796 .991 r
.33704 .54692 m .32676 .54861 L .33698 .5495 L p F P
0 g
s
.424 .789 .995 r
.32632 .54867 m .32676 .54861 L .33698 .5495 L p F P
0 g
s
.509 .851 .995 r
.49512 .5462 m .49767 .54719 L .50873 .54486 L p F P
0 g
s
.429 .119 .336 r
.61345 .51463 m .61441 .51056 L .6252 .50679 L p F P
0 g
s
.469 .198 .419 r
.62577 .50232 m .6252 .50679 L .61441 .51056 L p F P
0 g
s
.445 .132 .34 r
.61441 .51056 m .61345 .51463 L .60249 .51819 L p F P
0 g
s
.197 0 0 r
.26725 .54163 m .26694 .54155 L .26751 .54168 L closepath p F P
0 g
s
.805 .709 .759 r
.15572 .37804 m .15738 .37612 L .154 .37138 L p F P
0 g
s
.833 .651 .656 r
.13908 .44577 m .14461 .44825 L .1422 .45407 L p F P
0 g
s
.831 .659 .669 r
.14461 .44825 m .13908 .44577 L .14186 .43984 L p F P
0 g
s
.516 .84 .999 r
.46962 .54929 m .46908 .54939 L .46971 .54933 L closepath p F P
0 g
s
.535 .834 .999 r
.46908 .54939 m .46962 .54929 L p .45559 .54995 L F P
0 g
s
.628 .787 .958 r
.45252 .54794 m .44157 .55047 L .43848 .54833 L p F P
0 g
s
.545 .827 .998 r
.45559 .54995 m .45252 .54794 L .44157 .55047 L p F P
0 g
s
.547 .438 .681 r
.66078 .43266 m .67074 .42767 L p .66993 .43562 L F P
0 g
s
.547 .438 .681 r
.66993 .43562 m .66117 .43434 L .66078 .43266 L p F P
0 g
s
.554 .453 .694 r
.66956 .423 m .67074 .42767 L .66078 .43266 L p F P
0 g
s
.554 .453 .694 r
.66534 .42257 m .66956 .423 L p .66078 .43266 L F P
0 g
s
.567 .49 .727 r
.66346 .40152 m .6569 .40152 L .66255 .39857 L closepath p F P
0 g
s
.573 .501 .736 r
.66046 .39209 m .66255 .39857 L .6569 .40152 L p F P
0 g
s
.573 .501 .736 r
.65732 .39217 m .66046 .39209 L p .6569 .40152 L F P
0 g
s
.602 .573 .794 r
.62589 .3334 m .62854 .33948 L .61723 .34129 L p F P
0 g
s
.602 .573 .794 r
.61723 .34129 m .6161 .33869 L .62589 .3334 L p F P
0 g
s
0 .53 .792 r
.26694 .54155 m .26725 .54163 L .2638 .54062 L p F P
0 g
s
0 .53 .792 r
.2638 .54062 m .25937 .53985 L .26694 .54155 L p F P
0 g
s
.526 .844 .999 r
.46962 .54929 m .46971 .54933 L .48244 .54781 L p F P
0 g
s
.478 .84 .993 r
.48364 .54838 m .48244 .54781 L .46971 .54933 L p F P
0 g
s
.761 .723 .817 r
.20932 .31969 m .21784 .31327 L .2233 .31591 L p F P
0 g
s
.76 .724 .819 r
.22024 .3115 m .21784 .31327 L .2233 .31591 L p F P
0 g
s
.76 .724 .819 r
.2233 .31591 m .22358 .31569 L .22024 .3115 L p F P
0 g
s
.38 .017 .217 r
.60112 .52166 m .60249 .51819 L .61345 .51463 L p F P
0 g
s
.383 .006 .193 r
.60112 .52166 m .60249 .51819 L p .58993 .52516 L F P
0 g
s
.816 .697 .734 r
.14863 .39369 m .14463 .39164 L p .14498 .40086 L F P
0 g
s
.813 .702 .743 r
.14863 .39369 m .14604 .38984 L .14463 .39164 L closepath p F P
0 g
s
.171 0 0 r
.57644 .53117 m .57598 .53155 L .56481 .53431 L p F P
0 g
s
0 0 0 r
.57598 .53155 m .56481 .53431 L .56199 .53576 L p F P
0 g
s
.067 0 0 r
.56481 .53431 m .56199 .53576 L .55083 .53836 L p F P
0 g
s
.541 .411 .652 r
.66439 .44948 m .65885 .44815 L .66371 .44588 L closepath p F P
0 g
s
.55 .428 .667 r
.66233 .43937 m .66371 .44588 L .65885 .44815 L p F P
0 g
s
.751 .723 .826 r
.23445 .30809 m .22358 .31569 L .22024 .3115 L p F P
0 g
s
.517 .851 .996 r
.49512 .5462 m .49135 .54673 L .48364 .54838 L p F P
0 g
s
.543 .842 .999 r
.49135 .54673 m .48244 .54781 L .48364 .54838 L closepath p F P
0 g
s
.461 .804 .999 r
.38238 .29689 m .37488 .29786 L p .38566 .29715 L F P
0 g
s
.486 .795 .999 r
.38238 .29689 m .37488 .29786 L .37165 .29602 L p F P
0 g
s
.453 0 0 r
.38211 .29713 m .37193 .29648 L .36993 .29595 L p F P
0 g
s
.087 0 0 r
.38239 .29699 m .37286 .29611 L .38238 .29689 L F
.486 .795 .999 r
.37165 .29602 m .37178 .29601 L .38238 .29689 L p F P
0 g
s
.087 0 0 r
.37286 .29611 m .37178 .29601 L .38238 .29689 L p F P
0 g
s
.349 .768 .977 r
.36119 .29513 m .35765 .29535 L p .365 .29569 L F P
0 g
s
.349 .768 .977 r
.37159 .29599 m .36119 .29513 L p .365 .29569 L F P
0 g
s
0 .52 .745 r
.35168 .29389 m .35437 .29386 L .35104 .29362 L p F P
0 g
s
.238 0 0 r
.35437 .29386 m .35104 .29362 L p .35245 .29386 L F P
0 g
s
.457 .787 .999 r
.3557 .29433 m .35168 .29389 L .34366 .29473 L p F P
0 g
s
.402 .768 .994 r
.36119 .29513 m .3557 .29433 L .35765 .29535 L closepath p F P
0 g
s
.238 0 0 r
.36173 .29545 m .35836 .29472 L p .35245 .29386 L F P
0 g
s
.341 0 0 r
.3557 .29433 m .36119 .29513 L p .35686 .2945 L F P
0 g
s
.259 .726 .946 r
.35437 .29386 m .35168 .29389 L .3557 .29433 L closepath p F P
0 g
s
.238 0 0 r
.35836 .29472 m .35437 .29386 L p .35245 .29386 L F P
0 g
s
.341 0 0 r
.36359 .29549 m .35686 .2945 L .36119 .29513 L F
.36663 .29593 m .36136 .29516 L .36359 .29549 L F
.36136 .29516 m .35686 .2945 L .36359 .29549 L F
.303 .749 .962 r
.37178 .29601 m .37159 .29599 L .37165 .29602 L closepath p F P
0 g
s
.453 0 0 r
.37159 .29599 m .37178 .29601 L p .38211 .29713 L F P
0 g
s
.087 0 0 r
.38227 .29698 m .37286 .29611 L p .38239 .29699 L F P
0 g
s
.453 0 0 r
.37178 .29601 m .38239 .29699 L .38211 .29713 L p F P
0 g
s
.453 0 0 r
.36837 .29554 m .37159 .29599 L p .38211 .29713 L F P
0 g
s
.02 .589 .777 r
.36119 .29513 m .37159 .29599 L .36885 .2956 L p F P
0 g
s
.02 .589 .777 r
.36885 .2956 m .36837 .29554 L .36749 .29549 L p F P
0 g
s
.02 .589 .777 r
.36749 .29549 m .36119 .29513 L p .36885 .2956 L F P
0 g
s
.341 0 0 r
.36663 .29593 m .36173 .29545 L .35816 .29468 L p F P
0 g
s
.341 0 0 r
.36119 .29513 m .36837 .29554 L .36663 .29593 L p F P
0 g
s
.341 0 0 r
.35437 .29386 m .3557 .29433 L p .36663 .29593 L F P
0 g
s
.341 0 0 r
.35816 .29468 m .35437 .29386 L p .36034 .29487 L F P
0 g
s
.341 0 0 r
.36663 .29593 m .35816 .29468 L .36034 .29487 L F
.453 0 0 r
.36993 .29595 m .36837 .29554 L p .37716 .29655 L F P
0 g
s
.453 0 0 r
.38211 .29713 m .36993 .29595 L .37716 .29655 L F
.087 0 0 r
.38239 .29699 m .38227 .29698 L p .38239 .29699 L F P
0 g
s
.461 .804 .999 r
.38691 .29707 m .38238 .29689 L p .38566 .29715 L F P
0 g
s
.535 .834 .999 r
.46962 .54929 m .46657 .54745 L .45559 .54995 L p F P
0 g
s
.622 .797 .966 r
.46657 .54745 m .45559 .54995 L .45252 .54794 L p F P
0 g
s
.358 0 0 r
.23622 .53369 m .23624 .53369 L p .24872 .53766 L F P
0 g
s
.599 .046 0 r
.23622 .53369 m .2362 .53368 L .23624 .53369 L closepath p F P
0 g
s
.78 .356 .243 r
.20047 .51812 m .20192 .52038 L .19987 .52123 L p F P
0 g
s
.78 .356 .243 r
.19398 .51604 m .20047 .51812 L p .19987 .52123 L F P
0 g
s
.527 0 0 r
.2362 .53368 m .23622 .53369 L .23265 .53352 L p F P
0 g
s
.527 0 0 r
.23265 .53352 m .22921 .53179 L .2362 .53368 L p F P
0 g
s
.358 0 0 r
.24407 .53647 m .23622 .53369 L p .24855 .5376 L F P
0 g
s
.409 0 0 r
.24407 .53647 m .23622 .53369 L .23265 .53352 L p F P
0 g
s
.409 0 0 r
.2368 .53465 m .24407 .53647 L p .24256 .53608 L F P
0 g
s
.409 0 0 r
.23265 .53352 m .2368 .53465 L p .24256 .53608 L F P
0 g
s
.447 0 0 r
.22921 .53179 m .23265 .53352 L .2291 .53288 L p F P
0 g
s
.128 .634 .902 r
.2395 .534 m .23015 .533 L p .2368 .53465 L F P
0 g
s
.248 0 0 r
.2368 .53465 m .23265 .53352 L .2291 .53288 L p F P
0 g
s
.128 .634 .902 r
.23015 .533 m .22927 .53291 L .2368 .53465 L p F P
0 g
s
.019 .562 .839 r
.24297 .53567 m .23703 .53469 L p .24407 .53647 L F P
0 g
s
.019 .562 .839 r
.23703 .53469 m .2368 .53465 L .24407 .53647 L p F P
0 g
s
.358 0 0 r
.24872 .53766 m .24407 .53647 L p .24855 .5376 L F P
0 g
s
.808 .706 .753 r
.15056 .37535 m .15572 .37804 L .15002 .38489 L p F P
0 g
s
.805 .709 .759 r
.154 .37138 m .15056 .37535 L .15572 .37804 L p F P
0 g
s
.526 .844 .999 r
.48244 .54781 m .48062 .54682 L .46962 .54929 L p F P
0 g
s
.613 .809 .976 r
.48062 .54682 m .46962 .54929 L .46657 .54745 L p F P
0 g
s
.272 0 0 r
.58745 .52586 m .58991 .52519 L p .57644 .53117 L F P
0 g
s
.348 0 .104 r
.58991 .52519 m .58745 .52586 L .58993 .52516 L closepath p F P
0 g
s
.825 .502 .443 r
.18468 .50924 m .17917 .50729 L .1781 .5025 L p F P
0 g
s
.826 .501 .439 r
.1719 .50031 m .1781 .5025 L .17917 .50729 L p F P
0 g
s
0 .498 .727 r
.28113 .5438 m .27773 .5424 L .26725 .54163 L p F P
0 g
s
.346 .736 .985 r
.26725 .54163 m .27773 .5424 L .2746 .54077 L p F P
0 g
s
.346 .736 .985 r
.2638 .54062 m .26725 .54163 L p .2746 .54077 L F P
0 g
s
.548 .438 .68 r
.66233 .43937 m .66117 .43434 L .66993 .43562 L closepath p F P
0 g
s
.626 .617 .822 r
.58035 .31567 m .58023 .31544 L .5814 .31516 L closepath p F P
0 g
s
.732 .73 .849 r
.25944 .29871 m .24862 .30521 L .2453 .30111 L p F P
0 g
s
.627 .623 .827 r
.5814 .31516 m .58023 .31544 L .57731 .30993 L p F P
0 g
s
.459 .191 .42 r
.6252 .50679 m .62577 .50232 L .63641 .49833 L p F P
0 g
s
.487 .25 .48 r
.63663 .49352 m .63641 .49833 L .62577 .50232 L p F P
0 g
s
.812 .482 .43 r
.18539 .50947 m .18468 .50924 L .18513 .50854 L closepath p F P
0 g
s
.653 .68 .863 r
.54328 .29579 m .53217 .29925 L .52922 .29482 L p F P
0 g
s
.587 .541 .77 r
.63794 .36214 m .64184 .35999 L p .6483 .36723 L F P
0 g
s
.59 .549 .777 r
.63794 .36214 m .63728 .36051 L .64184 .35999 L closepath p F P
0 g
s
0 0 0 r
.55083 .53836 m .54996 .53856 L .53815 .5411 L p F P
0 g
s
.246 .76 .793 r
.53681 .54123 m .53815 .5411 L .54996 .53856 L p F P
0 g
s
.716 .725 .857 r
.25944 .29871 m .26161 .29756 L .26809 .29985 L p F P
0 g
s
.722 .733 .86 r
.27024 .29304 m .26161 .29756 L .26809 .29985 L p F P
0 g
s
.722 .733 .86 r
.26809 .29985 m .27354 .2969 L .27024 .29304 L p F P
0 g
s
.508 .321 .561 r
.64704 .48421 m .64672 .47883 L .65707 .47442 L p F P
0 g
s
.523 .351 .59 r
.6565 .4688 m .65707 .47442 L .64672 .47883 L p F P
0 g
s
.606 .581 .8 r
.62563 .33283 m .62589 .3334 L .6161 .33869 L p F P
0 g
s
.606 .581 .8 r
.6161 .33869 m .61433 .33478 L .62563 .33283 L p F P
0 g
s
.435 .808 .993 r
.39428 .29732 m .38888 .29802 L p .39954 .29749 L F P
0 g
s
.455 .805 .998 r
.39428 .29732 m .38691 .29707 L .38888 .29802 L closepath p F P
0 g
s
.242 0 0 r
.39658 .29761 m .38737 .2971 L .39428 .29732 L F
.39582 .29759 m .38737 .2971 L .39658 .29761 L F
.38691 .29707 m .39428 .29732 L p .38737 .2971 L F P
0 g
s
.242 0 0 r
.39695 .29766 m .39582 .29759 L .39658 .29761 L F
.38566 .29671 m .38691 .29707 L p .39695 .29766 L F P
0 g
s
.27 .746 .936 r
.38566 .29671 m .38238 .29689 L .38691 .29707 L closepath p F P
0 g
s
.182 0 0 r
.38566 .29671 m .38239 .29699 L p .39305 .29752 L F P
0 g
s
.182 0 0 r
.39499 .29762 m .39432 .29756 L p .39305 .29752 L F P
0 g
s
.182 0 0 r
.39432 .29756 m .38566 .29671 L p .39305 .29752 L F P
0 g
s
.435 .808 .993 r
.4015 .29739 m .39428 .29732 L p .39954 .29749 L F P
0 g
s
.832 .662 .671 r
.13642 .43732 m .14186 .43984 L .13908 .44577 L p F P
0 g
s
.83 .668 .683 r
.14186 .43984 m .13642 .43732 L .13955 .43128 L p F P
0 g
s
.635 .635 .833 r
.56327 .30753 m .56322 .30744 L .56386 .30727 L closepath p F P
0 g
s
.516 .798 .997 r
.32676 .54861 m .32611 .54855 L .32632 .54867 L closepath p F P
0 g
s
.615 .595 .808 r
.59726 .32455 m .60852 .32226 L p .61118 .32842 L F P
0 g
s
.615 .598 .81 r
.60613 .31727 m .60852 .32226 L .59726 .32455 L p F P
0 g
s
.615 .598 .81 r
.59726 .32455 m .59624 .32244 L .60613 .31727 L p F P
0 g
s
.636 .643 .84 r
.56386 .30727 m .56322 .30744 L .5603 .30232 L p F P
0 g
s
.818 .695 .728 r
.13976 .39822 m .14498 .40086 L .14039 .40736 L p F P
0 g
s
.816 .697 .734 r
.14463 .39164 m .13976 .39822 L .14498 .40086 L p F P
0 g
s
.783 .717 .791 r
.1815 .33585 m .18669 .33856 L .17831 .3463 L p F P
0 g
s
.782 .721 .796 r
.18401 .3336 m .1815 .33585 L .18669 .33856 L p F P
0 g
s
.782 .721 .796 r
.18669 .33856 m .18739 .33793 L .18401 .3336 L p F P
0 g
s
.777 .721 .8 r
.196 .3305 m .18739 .33793 L .18401 .3336 L p F P
0 g
s
.59 .55 .778 r
.64184 .35999 m .63728 .36051 L .63436 .35323 L p F P
0 g
s
.783 .717 .791 r
.17831 .3463 m .173 .34364 L .1815 .33585 L p F P
0 g
s
.786 .716 .786 r
.17831 .3463 m .17634 .34817 L .17296 .34368 L p F P
0 g
s
.786 .716 .786 r
.17296 .34368 m .173 .34364 L .17831 .3463 L p F P
0 g
s
.824 .683 .708 r
.14113 .41681 m .14142 .41635 L .14067 .41599 L closepath p F P
0 g
s
.818 .689 .721 r
.13781 .41121 m .14039 .40736 L p .14142 .41635 L F P
0 g
s
.818 .689 .721 r
.14142 .41635 m .14067 .41599 L .13781 .41121 L p F P
0 g
s
.624 .614 .821 r
.59144 .3128 m .5814 .31516 L .59036 .31069 L closepath p F P
0 g
s
.627 .623 .827 r
.58853 .30719 m .59036 .31069 L .5814 .31516 L p F P
0 g
s
.627 .623 .827 r
.57731 .30993 m .58853 .30719 L p .5814 .31516 L F P
0 g
s
.791 .716 .782 r
.17059 .35382 m .17634 .34817 L .17296 .34368 L p F P
0 g
s
.538 .797 .993 r
.32676 .54861 m .33704 .54692 L p .32303 .54669 L F P
0 g
s
.538 .797 .993 r
.32303 .54669 m .32611 .54855 L .32676 .54861 L p F P
0 g
s
.827 .684 .704 r
.13766 .42258 m .14113 .41681 L .14067 .41599 L p F P
0 g
s
.634 .635 .834 r
.5744 .30448 m .56386 .30727 L .57346 .30277 L closepath p F P
0 g
s
.636 .643 .84 r
.57148 .29926 m .57346 .30277 L .56386 .30727 L p F P
0 g
s
.636 .643 .84 r
.5603 .30232 m .57148 .29926 L p .56386 .30727 L F P
0 g
s
.524 .37 .614 r
.65572 .46294 m .66589 .45826 L p .65819 .46804 L F P
0 g
s
.524 .37 .614 r
.65819 .46804 m .65626 .46695 L .65572 .46294 L p F P
0 g
s
.534 .392 .634 r
.6649 .45218 m .66589 .45826 L .65572 .46294 L p F P
0 g
s
.507 .786 .995 r
.32303 .54669 m .31781 .54734 L .32611 .54855 L closepath p F P
0 g
s
.327 0 .093 r
.58991 .52519 m .59237 .52443 L .58993 .52516 L closepath p F P
0 g
s
.383 .006 .193 r
.58993 .52516 m .59237 .52443 L .60112 .52166 L p F P
0 g
s
.242 0 0 r
.58773 .528 m .58991 .52519 L .59237 .52443 L p F P
0 g
s
.272 0 0 r
.58991 .52519 m .58773 .528 L .57644 .53117 L p F P
0 g
s
.777 .721 .8 r
.18401 .3336 m .19074 .3278 L .196 .3305 L p F P
0 g
s
.775 .722 .803 r
.195 .3242 m .19074 .3278 L .196 .3305 L p F P
0 g
s
.775 .722 .803 r
.196 .3305 m .19838 .32849 L .195 .3242 L p F P
0 g
s
.441 .817 .992 r
.40754 .2973 m .40459 .29773 L p .4144 .29719 L F P
0 g
s
.441 .817 .992 r
.40459 .29773 m .40289 .29797 L p .40532 .29781 L F P
0 g
s
.441 .817 .992 r
.4144 .29719 m .40459 .29773 L .40532 .29781 L F
.449 .816 .994 r
.40754 .2973 m .4015 .29739 L .40289 .29797 L closepath p F P
0 g
s
.246 0 0 r
.41101 .29753 m .40163 .29739 L .40754 .2973 L F
.41119 .29755 m .41075 .29754 L .41101 .29753 L F
.41075 .29754 m .40163 .29739 L .41101 .29753 L F
.4015 .29739 m .40754 .2973 L p .40163 .29739 L F P
0 g
s
.246 0 0 r
.3997 .29703 m .40135 .29736 L p .41119 .29755 L F P
0 g
s
.246 0 0 r
.40135 .29736 m .4015 .29739 L p .40163 .29739 L F P
0 g
s
.246 0 0 r
.41119 .29755 m .40135 .29736 L .40163 .29739 L F
.214 .724 .892 r
.3997 .29703 m .39428 .29732 L .4015 .29739 L closepath p F P
0 g
s
.22 0 0 r
.39695 .29766 m .3997 .29703 L .40825 .29759 L p F P
0 g
s
.22 0 0 r
.40825 .29759 m .40831 .29759 L .40796 .2976 L p F P
0 g
s
.22 0 0 r
.40796 .2976 m .39695 .29766 L p .40825 .29759 L F P
0 g
s
.441 .817 .992 r
.41554 .29711 m .40754 .2973 L p .4144 .29719 L F P
0 g
s
.793 .715 .778 r
.17059 .35382 m .16522 .35924 L .16183 .35473 L p F P
0 g
s
.793 .715 .778 r
.16183 .35473 m .1654 .35113 L .17059 .35382 L p F P
0 g
s
.791 .716 .782 r
.17296 .34368 m .1654 .35113 L .17059 .35382 L p F P
0 g
s
.801 .43 .353 r
.19398 .51604 m .18747 .51396 L .18539 .50947 L p F P
0 g
s
.801 .43 .354 r
.18468 .50924 m .18539 .50947 L .18747 .51396 L p F P
0 g
s
.811 .704 .746 r
.15002 .38489 m .14604 .38984 L .14266 .38491 L p F P
0 g
s
.811 .704 .746 r
.14266 .38491 m .14481 .38222 L .15002 .38489 L p F P
0 g
s
.808 .706 .753 r
.15002 .38489 m .14481 .38222 L .15056 .37535 L p F P
0 g
s
.769 .723 .809 r
.20627 .32211 m .19838 .32849 L .195 .3242 L p F P
0 g
s
.541 .422 .667 r
.66371 .44588 m .66233 .43937 L .66993 .43562 L p F P
0 g
s
.827 .684 .704 r
.14067 .41599 m .13617 .41374 L p .13766 .42258 L F P
0 g
s
.824 .69 .715 r
.14067 .41599 m .13781 .41121 L .13617 .41374 L closepath p F P
0 g
s
.516 .802 .998 r
.35431 .54931 m .35107 .54695 L .3403 .5491 L p F P
0 g
s
.621 .77 .951 r
.35107 .54695 m .3403 .5491 L .33704 .54692 L p F P
0 g
s
.477 .831 .996 r
.42908 .29629 m .42263 .29667 L .41692 .29767 L p F P
0 g
s
.472 .831 .995 r
.42263 .29667 m .41554 .29711 L .41692 .29767 L closepath p F P
0 g
s
.618 .606 .816 r
.60561 .3162 m .60613 .31727 L .59624 .32244 L p F P
0 g
s
.618 .606 .816 r
.59624 .32244 m .59435 .31862 L .60561 .3162 L p F P
0 g
s
.801 .43 .354 r
.18747 .51396 m .18147 .51204 L .18468 .50924 L p F P
0 g
s
.817 .454 .369 r
.17917 .50729 m .18468 .50924 L .18147 .51204 L p F P
0 g
s
.798 .716 .774 r
.16335 .36119 m .16522 .35924 L .16183 .35473 L p F P
0 g
s
.658 .756 .922 r
.30165 .29471 m .31238 .29113 L .31566 .29431 L p F P
0 g
s
.634 .765 .942 r
.31238 .29113 m .30165 .29471 L .29836 .29122 L p F P
0 g
s
.684 .744 .896 r
.28761 .29557 m .29836 .29122 L .30165 .29471 L p F P
0 g
s
.532 .839 .999 r
.4421 .29489 m .4408 .29501 L .43095 .2971 L p F P
0 g
s
.516 .845 .998 r
.4408 .29501 m .42908 .29629 L .43095 .2971 L closepath p F P
0 g
s
.633 .801 .963 r
.45902 .29555 m .47001 .29237 L .47305 .29483 L p F P
0 g
s
.558 .854 .997 r
.45902 .29555 m .47001 .29237 L .46711 .29089 L p F P
0 g
s
.558 .854 .997 r
.45595 .29358 m .45902 .29555 L p .46711 .29089 L F P
0 g
s
.594 .826 .988 r
.44498 .29636 m .45595 .29358 L .45902 .29555 L p F P
0 g
s
.673 .75 .909 r
.29836 .29122 m .28761 .29557 L .28431 .29186 L p F P
0 g
s
.703 .736 .877 r
.27354 .2969 m .28431 .29186 L .28761 .29557 L p F P
0 g
s
.838 .594 .57 r
.15959 .48566 m .15376 .48332 L .15447 .47801 L p F P
0 g
s
.84 .596 .57 r
.14869 .47564 m .15447 .47801 L .15376 .48332 L p F P
0 g
s
.837 .611 .597 r
.15447 .47801 m .14869 .47564 L .14988 .47019 L p F P
0 g
s
.57 .849 .996 r
.4421 .29489 m .44498 .29636 L .45595 .29358 L p F P
0 g
s
.831 .671 .684 r
.1342 .42872 m .13955 .43128 L .13642 .43732 L p F P
0 g
s
.829 .677 .694 r
.13955 .43128 m .1342 .42872 L .13766 .42258 L p F P
0 g
s
.652 .771 .936 r
.47305 .29483 m .48407 .29137 L .48708 .29431 L p F P
0 g
s
.628 .819 .974 r
.48407 .29137 m .47305 .29483 L .47001 .29237 L p F P
0 g
s
.74 .722 .835 r
.23728 .30625 m .23445 .30809 L .23112 .30391 L p F P
0 g
s
.751 .723 .826 r
.22024 .3115 m .23112 .30391 L .23445 .30809 L p F P
0 g
s
.839 .614 .597 r
.14416 .4678 m .14988 .47019 L .14869 .47564 L p F P
0 g
s
.836 .626 .619 r
.14988 .47019 m .14416 .4678 L .14579 .46221 L p F P
0 g
s
.8 .713 .769 r
.15824 .35846 m .16335 .36119 L .15673 .36834 L p F P
0 g
s
.798 .716 .774 r
.16183 .35473 m .15824 .35846 L .16335 .36119 L p F P
0 g
s
.478 .244 .48 r
.63641 .49833 m .63663 .49352 L .64712 .48932 L p F P
0 g
s
.501 .292 .527 r
.64704 .48421 m .64712 .48932 L .63663 .49352 L p F P
0 g
s
.596 .554 .778 r
.63436 .35323 m .63351 .35335 L .63425 .35296 L closepath p F P
0 g
s
.6 .562 .784 r
.63145 .34627 m .63425 .35296 L .63351 .35335 L p F P
0 g
s
.841 .575 .537 r
.15376 .48332 m .15959 .48566 L .15938 .49082 L p F P
0 g
s
.839 .573 .538 r
.16442 .4928 m .15938 .49082 L .15959 .48566 L p F P
0 g
s
.605 .583 .802 r
.62563 .33283 m .61433 .33478 L .61142 .32837 L p F P
0 g
s
.617 .773 .955 r
.31566 .29431 m .32639 .29158 L .32966 .29434 L p F P
0 g
s
.562 .782 .981 r
.32639 .29158 m .31566 .29431 L .31238 .29113 L p F P
0 g
s
.66 .742 .911 r
.48708 .29431 m .49813 .29069 L .50112 .2941 L p F P
0 g
s
.653 .779 .94 r
.49813 .29069 m .48708 .29431 L .48407 .29137 L p F P
0 g
s
.646 .661 .851 r
.55444 .29245 m .55737 .29731 L .54622 .30057 L p F P
0 g
s
.646 .661 .851 r
.55303 .29287 m .55444 .29245 L p .54622 .30057 L F P
0 g
s
.646 .661 .851 r
.54622 .30057 m .54387 .29673 L .55303 .29287 L p F P
0 g
s
.643 .651 .843 r
.54622 .30057 m .55737 .29731 L .5603 .30232 L p F P
0 g
s
.628 .088 0 r
.22921 .53179 m .22211 .52991 L .21902 .52793 L p F P
0 g
s
.63 .094 0 r
.22211 .52991 m .21586 .52831 L .21902 .52793 L closepath p F P
0 g
s
.769 .723 .809 r
.195 .3242 m .20093 .31943 L .20627 .32211 L p F P
0 g
s
.768 .724 .812 r
.20596 .31547 m .20093 .31943 L .20627 .32211 L p F P
0 g
s
.768 .724 .812 r
.20627 .32211 m .20932 .31969 L .20596 .31547 L p F P
0 g
s
.571 .5 .737 r
.66046 .39209 m .65732 .39217 L .66002 .39074 L closepath p F P
0 g
s
.577 .511 .745 r
.65749 .38327 m .66002 .39074 L .65732 .39217 L p F P
0 g
s
.577 .511 .745 r
.65603 .38333 m .65749 .38327 L p .65732 .39217 L F P
0 g
s
.838 .629 .621 r
.14015 .45978 m .14579 .46221 L .14416 .4678 L p F P
0 g
s
.835 .64 .639 r
.14579 .46221 m .14015 .45978 L .1422 .45407 L p F P
0 g
s
.696 .741 .885 r
.28431 .29186 m .27354 .2969 L .27024 .29304 L p F P
0 g
s
.564 .836 .996 r
.48062 .54682 m .48244 .54781 L .49135 .54673 L p F P
0 g
s
.242 0 0 r
.59237 .52443 m .60105 .5218 L p .58773 .528 L F P
0 g
s
.352 0 .139 r
.59237 .52443 m .60105 .5218 L .60112 .52166 L closepath p F P
0 g
s
.373 .751 .99 r
.29241 .5439 m .29071 .54357 L .28113 .5438 L p F P
0 g
s
.331 .749 .977 r
.29071 .54357 m .28113 .5438 L .27773 .5424 L p F P
0 g
s
.164 .696 .693 r
.54996 .53856 m .55083 .53836 L .56199 .53576 L p F P
0 g
s
.605 .781 .965 r
.35431 .54931 m .36511 .54686 L .36832 .54935 L p F P
0 g
s
.636 .764 .941 r
.36511 .54686 m .35431 .54931 L .35107 .54695 L p F P
0 g
s
.761 .725 .819 r
.21784 .31327 m .20932 .31969 L .20596 .31547 L p F P
0 g
s
.59 .55 .778 r
.63436 .35323 m .64574 .35199 L p .64184 .35999 L F P
0 g
s
.589 .551 .779 r
.64391 .34748 m .64574 .35199 L .63436 .35323 L p F P
0 g
s
.589 .551 .779 r
.63436 .35323 m .63425 .35296 L .64391 .34748 L p F P
0 g
s
.815 .705 .744 r
.14463 .39164 m .14604 .38984 L .14266 .38491 L p F P
0 g
s
.74 .722 .835 r
.23112 .30391 m .2313 .30379 L .23728 .30625 L p F P
0 g
s
.742 .728 .839 r
.24196 .29706 m .2313 .30379 L .23728 .30625 L p F P
0 g
s
.742 .728 .839 r
.23728 .30625 m .2453 .30111 L .24196 .29706 L p F P
0 g
s
.661 .717 .89 r
.50112 .2941 m .51219 .29044 L .51516 .29426 L p F P
0 g
s
.66 .744 .912 r
.51219 .29044 m .50112 .2941 L .49813 .29069 L p F P
0 g
s
.086 .614 .872 r
.25937 .53985 m .2638 .54062 L .26036 .53922 L p F P
0 g
s
.318 0 0 r
.24995 .53791 m .25152 .53822 L .25937 .53985 L p F P
0 g
s
.593 .56 .786 r
.64282 .34486 m .64391 .34748 L .63425 .35296 L p F P
0 g
s
.593 .56 .786 r
.63425 .35296 m .63145 .34627 L .64282 .34486 L p F P
0 g
s
.828 .536 .495 r
.1719 .50031 m .16573 .4981 L .1653 .49312 L p F P
0 g
s
.83 .537 .494 r
.16442 .4928 m .1653 .49312 L .16573 .4981 L p F P
0 g
s
.696 .189 .03 r
.21586 .52831 m .21497 .52805 L .21045 .52427 L p F P
0 g
s
.676 .153 0 r
.2036 .52231 m .21045 .52427 L .21497 .52805 L p F P
0 g
s
.749 .303 .194 r
.21045 .52427 m .2036 .52231 L .20192 .52038 L p F P
0 g
s
.822 .69 .719 r
.14039 .40736 m .13781 .41121 L .13448 .4057 L p F P
0 g
s
.822 .69 .719 r
.13448 .4057 m .13512 .40474 L .14039 .40736 L p F P
0 g
s
.818 .695 .728 r
.14039 .40736 m .13512 .40474 L .13976 .39822 L p F P
0 g
s
.549 .789 .988 r
.32966 .29434 m .34038 .29248 L .34366 .29473 L p F P
0 g
s
.447 .776 .998 r
.32966 .29434 m .34038 .29248 L .3388 .29163 L p F P
0 g
s
.447 .776 .998 r
.32639 .29158 m .32966 .29434 L p .3388 .29163 L F P
0 g
s
.836 .643 .642 r
.13664 .4516 m .1422 .45407 L .14015 .45978 L p F P
0 g
s
.833 .651 .656 r
.1422 .45407 m .13664 .4516 L .13908 .44577 L p F P
0 g
s
.8 .713 .769 r
.15673 .36834 m .15155 .36565 L .15824 .35846 L p F P
0 g
s
.803 .711 .763 r
.15673 .36834 m .154 .37138 L .15061 .3667 L p F P
0 g
s
.803 .711 .763 r
.15061 .3667 m .15155 .36565 L .15673 .36834 L p F P
0 g
s
.749 .303 .193 r
.2036 .52231 m .19987 .52123 L .20192 .52038 L closepath p F P
0 g
s
.818 .701 .736 r
.13951 .38895 m .14463 .39164 L .13976 .39822 L p F P
0 g
s
.815 .705 .744 r
.14266 .38491 m .13951 .38895 L .14463 .39164 L p F P
0 g
s
.619 .778 .957 r
.36832 .54935 m .37916 .5467 L .38234 .54928 L p F P
0 g
s
.645 .76 .933 r
.37916 .5467 m .36832 .54935 L .36511 .54686 L p F P
0 g
s
.447 0 0 r
.2291 .53288 m .22211 .52991 L .22921 .53179 L p F P
0 g
s
.485 .793 .999 r
.31781 .54734 m .32303 .54669 L p .30903 .5462 L F P
0 g
s
.485 .793 .999 r
.30903 .5462 m .30955 .54648 L .31781 .54734 L p F P
0 g
s
.83 .537 .494 r
.16573 .4981 m .16287 .49706 L .16442 .4928 L p F P
0 g
s
.84 .549 .497 r
.15938 .49082 m .16442 .4928 L .16287 .49706 L p F P
0 g
s
.716 .724 .856 r
.25944 .29871 m .26161 .29756 L .2573 .29613 L closepath p F P
0 g
s
.732 .73 .849 r
.2573 .29613 m .25944 .29871 L p .2453 .30111 L F P
0 g
s
.525 .37 .613 r
.6565 .4688 m .65626 .46695 L .65819 .46804 L closepath p F P
0 g
s
.83 .68 .696 r
.1324 .41997 m .13766 .42258 L .1342 .42872 L p F P
0 g
s
.827 .684 .704 r
.13617 .41374 m .1324 .41997 L .13766 .42258 L p F P
0 g
s
.78 .356 .243 r
.19987 .52123 m .19694 .52028 L .19398 .51604 L p F P
0 g
s
.777 .344 .222 r
.18747 .51396 m .19398 .51604 L .19694 .52028 L p F P
0 g
s
.552 .452 .695 r
.66956 .423 m .66534 .42257 L .66898 .42072 L closepath p F P
0 g
s
.559 .466 .705 r
.66703 .41356 m .66898 .42072 L .66534 .42257 L p F P
0 g
s
.66 .716 .89 r
.52626 .29065 m .51516 .29426 L .51219 .29044 L p F P
0 g
s
.658 .697 .875 r
.51516 .29426 m .52626 .29065 L .52922 .29482 L p F P
0 g
s
.807 .711 .76 r
.15056 .37535 m .154 .37138 L .15061 .3667 L p F P
0 g
s
.533 .405 .652 r
.66371 .44588 m .67372 .44094 L p .66813 .45062 L F P
0 g
s
.533 .405 .652 r
.66813 .45062 m .66439 .44948 L .66371 .44588 L p F P
0 g
s
.541 .422 .667 r
.67272 .43625 m .67372 .44094 L .66371 .44588 L p F P
0 g
s
.541 .422 .667 r
.66993 .43562 m .67272 .43625 L p .66371 .44588 L F P
0 g
s
.628 .626 .829 r
.58853 .30719 m .57731 .30993 L .5744 .30448 L p F P
0 g
s
.618 .608 .819 r
.60561 .3162 m .59435 .31862 L .59144 .3128 L p F P
0 g
s
.826 .501 .439 r
.17917 .50729 m .173 .50509 L .1719 .50031 L p F P
0 g
s
.826 .499 .435 r
.16573 .4981 m .1719 .50031 L .173 .50509 L p F P
0 g
s
.835 .655 .659 r
.13361 .44326 m .13908 .44577 L .13664 .4516 L p F P
0 g
s
.832 .662 .671 r
.13908 .44577 m .13361 .44326 L .13642 .43732 L p F P
0 g
s
.627 .776 .952 r
.38234 .54928 m .39321 .54648 L .39637 .54913 L p F P
0 g
s
.65 .756 .927 r
.39321 .54648 m .38234 .54928 L .37916 .5467 L p F P
0 g
s
.761 .725 .819 r
.20596 .31547 m .21245 .31061 L .21784 .31327 L p F P
0 g
s
.76 .726 .821 r
.21688 .30735 m .21245 .31061 L .21784 .31327 L p F P
0 g
s
.76 .726 .821 r
.21784 .31327 m .22024 .3115 L .21688 .30735 L p F P
0 g
s
.587 .541 .77 r
.64184 .35999 m .64866 .35935 L p .6483 .36723 L F P
0 g
s
.586 .541 .772 r
.64866 .35935 m .64184 .35999 L .64765 .35675 L closepath p F P
0 g
s
.59 .55 .778 r
.64574 .35199 m .64765 .35675 L .64184 .35999 L p F P
0 g
s
.496 .768 .992 r
.35168 .29389 m .34366 .29473 L .34038 .29248 L p F P
0 g
s
.575 .511 .746 r
.65749 .38327 m .65603 .38333 L .65728 .38266 L closepath p F P
0 g
s
.58 .521 .753 r
.65453 .37492 m .65728 .38266 L .65603 .38333 L p F P
0 g
s
.58 .521 .753 r
.65303 .37501 m .65453 .37492 L p .65603 .38333 L F P
0 g
s
.141 0 0 r
.25152 .53822 m .24872 .53766 L .24995 .53791 L closepath p F P
0 g
s
.712 .726 .861 r
.26692 .28926 m .27024 .29304 L .26161 .29756 L p F P
0 g
s
.712 .726 .861 r
.25612 .29473 m .26692 .28926 L p .26161 .29756 L F P
0 g
s
.712 .726 .861 r
.26161 .29756 m .2573 .29613 L .25612 .29473 L p F P
0 g
s
.246 .76 .793 r
.54996 .53856 m .54795 .53864 L .53681 .54123 L p F P
0 g
s
.477 .869 .97 r
.54795 .53864 m .53681 .54123 L .53389 .54074 L p F P
0 g
s
.426 .853 .947 r
.52277 .54331 m .53389 .54074 L .53681 .54123 L p F P
0 g
s
.826 .692 .716 r
.13617 .41374 m .13781 .41121 L .13448 .4057 L p F P
0 g
s
.13 0 0 r
.57598 .53155 m .57644 .53117 L .58773 .528 L p F P
0 g
s
.809 .709 .755 r
.14548 .37263 m .15056 .37535 L .14481 .38222 L p F P
0 g
s
.807 .711 .76 r
.15061 .3667 m .14548 .37263 L .15056 .37535 L p F P
0 g
s
.752 .728 .831 r
.23112 .30391 m .22024 .3115 L .21688 .30735 L p F P
0 g
s
.631 .775 .95 r
.39637 .54913 m .40726 .54625 L .4104 .54892 L p F P
0 g
s
.652 .754 .925 r
.40726 .54625 m .39637 .54913 L .39321 .54648 L p F P
0 g
s
.564 .836 .996 r
.49135 .54673 m .49467 .546 L p .48062 .54682 L F P
0 g
s
.541 .848 .998 r
.49467 .546 m .49135 .54673 L .49512 .5462 L closepath p F P
0 g
s
.34 .757 .978 r
.29506 .54527 m .29977 .54483 L .30821 .54626 L p F P
0 g
s
.456 .785 .999 r
.29977 .54483 m .29241 .5439 L .29506 .54527 L closepath p F P
0 g
s
.512 .343 .589 r
.65819 .46804 m .6565 .4688 L .65707 .47442 L p F P
0 g
s
.638 .648 .843 r
.57148 .29926 m .5603 .30232 L .55737 .29731 L p F P
0 g
s
.242 0 0 r
.39428 .29732 m .3997 .29703 L .39695 .29766 L p F P
0 g
s
.23 .737 .889 r
.41375 .29681 m .40754 .2973 L .41554 .29711 L closepath p F P
0 g
s
.246 0 0 r
.40754 .2973 m .41375 .29681 L .41119 .29755 L p F P
0 g
s
.561 .486 .728 r
.66255 .39857 m .67228 .39319 L p .67287 .40182 L F P
0 g
s
.561 .486 .728 r
.67287 .40182 m .66346 .40152 L .66255 .39857 L p F P
0 g
s
.564 .496 .737 r
.67195 .39219 m .67228 .39319 L .66255 .39857 L p F P
0 g
s
.564 .496 .737 r
.66255 .39857 m .66046 .39209 L .67195 .39219 L p F P
0 g
s
.611 .588 .803 r
.61142 .32837 m .61118 .32842 L .61139 .32831 L closepath p F P
0 g
s
.615 .595 .808 r
.60852 .32226 m .61139 .32831 L .61118 .32842 L p F P
0 g
s
.563 .496 .738 r
.66971 .3853 m .67195 .39219 L .66046 .39209 L p F P
0 g
s
.563 .496 .738 r
.66046 .39209 m .66002 .39074 L .66971 .3853 L p F P
0 g
s
.568 .507 .746 r
.66896 .38311 m .66971 .3853 L .66002 .39074 L p F P
0 g
s
.568 .507 .746 r
.66002 .39074 m .65749 .38327 L .66896 .38311 L p F P
0 g
s
.49 .283 .525 r
.64712 .48932 m .64704 .48421 L .65741 .4798 L p F P
0 g
s
.508 .321 .561 r
.65707 .47442 m .65741 .4798 L .64704 .48421 L p F P
0 g
s
.561 .485 .727 r
.66488 .40617 m .66346 .40152 L .67287 .40182 L closepath p F P
0 g
s
.653 .68 .863 r
.52922 .29482 m .54034 .29132 L .54328 .29579 L p F P
0 g
s
.655 .694 .874 r
.54034 .29132 m .52922 .29482 L .52626 .29065 L p F P
0 g
s
.593 .56 .787 r
.6399 .33791 m .64282 .34486 L .63145 .34627 L p F P
0 g
s
.593 .56 .787 r
.63975 .33793 m .6399 .33791 L p .63145 .34627 L F P
0 g
s
.593 .56 .787 r
.63145 .34627 m .63023 .34337 L .63975 .33793 L p F P
0 g
s
.605 .583 .802 r
.61142 .32837 m .62273 .32645 L .62563 .33283 L p F P
0 g
s
.605 .585 .804 r
.62109 .32288 m .62273 .32645 L .61142 .32837 L p F P
0 g
s
.605 .585 .804 r
.61142 .32837 m .61139 .32831 L .62109 .32288 L p F P
0 g
s
.729 .732 .853 r
.25528 .29522 m .2453 .30111 L .24196 .29706 L p F P
0 g
s
.732 .73 .849 r
.2453 .30111 m .25528 .29522 L .2573 .29613 L p F P
0 g
s
.442 .774 .997 r
.30903 .5462 m .30821 .54626 L .30955 .54648 L closepath p F P
0 g
s
.609 .593 .81 r
.61982 .32019 m .62109 .32288 L .61139 .32831 L p F P
0 g
s
.609 .593 .81 r
.61139 .32831 m .60852 .32226 L .61982 .32019 L p F P
0 g
s
.653 .755 .924 r
.42132 .546 m .4104 .54892 L .40726 .54625 L p F P
0 g
s
.633 .777 .95 r
.4104 .54892 m .42132 .546 L .42444 .54865 L p F P
0 g
s
.185 0 0 r
.41554 .29711 m .42263 .29667 L p .42487 .29682 L F P
0 g
s
.185 0 0 r
.41375 .29681 m .41554 .29711 L p .42487 .29682 L F P
0 g
s
.582 .531 .763 r
.65159 .36697 m .6483 .36723 L .65111 .36569 L closepath p F P
0 g
s
.587 .541 .77 r
.64866 .35935 m .65111 .36569 L .6483 .36723 L p F P
0 g
s
.584 .531 .762 r
.6483 .36723 m .65159 .36697 L p .65303 .37501 L F P
0 g
s
.579 .521 .755 r
.65453 .37492 m .65303 .37501 L .65432 .37432 L closepath p F P
0 g
s
.584 .531 .762 r
.65159 .36697 m .65432 .37432 L .65303 .37501 L p F P
0 g
s
.556 .474 .718 r
.66488 .40617 m .67287 .40182 L p .67012 .4119 L F P
0 g
s
.556 .474 .718 r
.67012 .4119 m .66648 .41168 L .66488 .40617 L p F P
0 g
s
.834 .666 .675 r
.13104 .43477 m .13642 .43732 L .13361 .44326 L p F P
0 g
s
.831 .671 .684 r
.13642 .43732 m .13104 .43477 L .1342 .42872 L p F P
0 g
s
.164 .696 .693 r
.56199 .53576 m .56162 .53583 L .54996 .53856 L p F P
0 g
s
.31 .802 .842 r
.54795 .53864 m .54996 .53856 L .56162 .53583 L p F P
0 g
s
.533 .405 .651 r
.6649 .45218 m .66439 .44948 L .66813 .45062 L closepath p F P
0 g
s
.567 .507 .747 r
.66693 .37716 m .66896 .38311 L .65749 .38327 L p F P
0 g
s
.567 .507 .747 r
.65749 .38327 m .65728 .38266 L .66693 .37716 L p F P
0 g
s
.572 .517 .755 r
.66599 .37454 m .66693 .37716 L .65728 .38266 L p F P
0 g
s
.572 .517 .755 r
.65728 .38266 m .65453 .37492 L .66599 .37454 L p F P
0 g
s
.818 .701 .736 r
.13976 .39822 m .1346 .39555 L .13951 .38895 L p F P
0 g
s
.819 .699 .732 r
.1346 .39555 m .13976 .39822 L .13512 .40474 L p F P
0 g
s
.511 .782 .994 r
.30821 .54626 m .30903 .5462 L .3057 .54409 L p F P
0 g
s
.511 .782 .994 r
.3057 .54409 m .29977 .54483 L .30821 .54626 L p F P
0 g
s
.817 .454 .369 r
.18147 .51204 m .18098 .51187 L .17917 .50729 L p F P
0 g
s
.819 .45 .358 r
.173 .50509 m .17917 .50729 L .18098 .51187 L p F P
0 g
s
.087 0 0 r
.38238 .29689 m .38566 .29671 L .38239 .29699 L p F P
0 g
s
.782 .721 .796 r
.17638 .3331 m .1815 .33585 L .173 .34364 L p F P
0 g
s
.783 .724 .797 r
.18061 .32931 m .17638 .3331 L .1815 .33585 L p F P
0 g
s
.783 .724 .797 r
.1815 .33585 m .18401 .3336 L .18061 .32931 L p F P
0 g
s
.787 .718 .788 r
.17296 .34368 m .173 .34364 L .17287 .34357 L closepath p F P
0 g
s
.782 .721 .796 r
.16955 .33935 m .17638 .3331 L p .173 .34364 L F P
0 g
s
.782 .721 .796 r
.173 .34364 m .17287 .34357 L .16955 .33935 L p F P
0 g
s
.793 .719 .783 r
.1654 .35113 m .17296 .34368 L .17287 .34357 L p F P
0 g
s
.632 .78 .953 r
.42444 .54865 m .43538 .54573 L .43848 .54833 L p F P
0 g
s
.652 .757 .926 r
.43538 .54573 m .42444 .54865 L .42132 .546 L p F P
0 g
s
.778 .723 .802 r
.19074 .3278 m .18401 .3336 L .18061 .32931 L p F P
0 g
s
.829 .688 .707 r
.13101 .41108 m .13617 .41374 L .1324 .41997 L p F P
0 g
s
.826 .692 .716 r
.13448 .4057 m .13101 .41108 L .13617 .41374 L p F P
0 g
s
.548 .85 .998 r
.49467 .546 m .49512 .5462 L .50748 .54426 L p F P
0 g
s
.509 .851 .995 r
.50873 .54486 m .50748 .54426 L .49512 .5462 L p F P
0 g
s
.512 .862 .991 r
.51982 .54227 m .52277 .54331 L .53389 .54074 L p F P
0 g
s
.793 .719 .783 r
.17287 .34357 m .16795 .34087 L p .1654 .35113 L F P
0 g
s
.79 .723 .789 r
.17287 .34357 m .16955 .33935 L .16795 .34087 L closepath p F P
0 g
s
.556 .474 .718 r
.66703 .41356 m .66648 .41168 L .67012 .4119 L closepath p F P
0 g
s
.647 .666 .854 r
.54387 .29673 m .54328 .29579 L .55303 .29287 L closepath p F P
0 g
s
.312 .784 .929 r
.42781 .29603 m .42263 .29667 L .42908 .29629 L closepath p F P
0 g
s
.185 0 0 r
.42263 .29667 m .42781 .29603 L .42487 .29682 L p F P
0 g
s
.55 .461 .707 r
.66898 .42072 m .66703 .41356 L .67012 .4119 L p F P
0 g
s
.778 .723 .802 r
.18061 .32931 m .18554 .32508 L .19074 .3278 L p F P
0 g
s
.776 .725 .805 r
.19162 .31996 m .18554 .32508 L .19074 .3278 L p F P
0 g
s
.776 .725 .805 r
.19074 .3278 m .195 .3242 L .19162 .31996 L p F P
0 g
s
.018 .57 .824 r
.25152 .53822 m .26036 .53922 L p .24646 .53701 L F P
0 g
s
.018 .57 .824 r
.24646 .53701 m .24872 .53766 L .25152 .53822 L p F P
0 g
s
.628 .787 .958 r
.43848 .54833 m .44945 .54544 L .45252 .54794 L p F P
0 g
s
.649 .761 .931 r
.44945 .54544 m .43848 .54833 L .43538 .54573 L p F P
0 g
s
.596 .569 .794 r
.63023 .34337 m .62854 .33948 L .63975 .33793 L closepath p F P
0 g
s
.524 .37 .614 r
.66589 .45826 m .66669 .46414 L .65819 .46804 L p F P
0 g
s
.51 .343 .59 r
.66669 .46414 m .65819 .46804 L .66207 .47216 L p F P
0 g
s
.512 .343 .589 r
.65707 .47442 m .66207 .47216 L .65819 .46804 L p F P
0 g
s
.795 .718 .779 r
.1654 .35113 m .16183 .35473 L .15842 .35026 L p F P
0 g
s
.795 .718 .779 r
.15842 .35026 m .16027 .34839 L .1654 .35113 L p F P
0 g
s
.793 .719 .783 r
.16795 .34087 m .16027 .34839 L .1654 .35113 L p F P
0 g
s
.485 .793 .999 r
.32303 .54669 m .31974 .54435 L .30903 .5462 L p F P
0 g
s
.606 .77 .958 r
.31974 .54435 m .30903 .5462 L .3057 .54409 L p F P
0 g
s
.813 .706 .747 r
.14481 .38222 m .14266 .38491 L .13927 .38003 L p F P
0 g
s
.813 .706 .747 r
.13927 .38003 m .13967 .37952 L .14481 .38222 L p F P
0 g
s
.809 .709 .755 r
.14481 .38222 m .13967 .37952 L .14548 .37263 L p F P
0 g
s
.769 .725 .811 r
.20093 .31943 m .195 .3242 L .19162 .31996 L p F P
0 g
s
.13 0 0 r
.58773 .528 m .58719 .52845 L .57598 .53155 L p F P
0 g
s
0 0 0 r
.57598 .53155 m .58719 .52845 L .58444 .52972 L p F P
0 g
s
0 0 0 r
.57318 .53288 m .57598 .53155 L p .58444 .52972 L F P
0 g
s
0 0 0 r
.56199 .53576 m .57318 .53288 L .57598 .53155 L p F P
0 g
s
.622 .797 .966 r
.45252 .54794 m .46352 .5451 L .46657 .54745 L p F P
0 g
s
.645 .769 .938 r
.46352 .5451 m .45252 .54794 L .44945 .54544 L p F P
0 g
s
.571 .517 .756 r
.66393 .36876 m .66599 .37454 L .65453 .37492 L p F P
0 g
s
.571 .517 .756 r
.65453 .37492 m .65432 .37432 L .66393 .36876 L p F P
0 g
s
.522 .861 .994 r
.51982 .54227 m .51982 .54227 L .50873 .54486 L p F P
0 g
s
.555 .85 .998 r
.51982 .54227 m .50748 .54426 L .50873 .54486 L closepath p F P
0 g
s
.365 .007 .217 r
.61234 .51754 m .61345 .51463 L .62427 .51087 L p F P
0 g
s
.38 .017 .217 r
.61345 .51463 m .61234 .51754 L .60112 .52166 L p F P
0 g
s
.429 .119 .336 r
.6252 .50679 m .62427 .51087 L .61345 .51463 L p F P
0 g
s
.799 .718 .775 r
.15824 .35846 m .16183 .35473 L .15842 .35026 L p F P
0 g
s
.84 .596 .57 r
.15376 .48332 m .14797 .48096 L .14869 .47564 L p F P
0 g
s
.842 .598 .57 r
.14295 .47326 m .14869 .47564 L .14797 .48096 L p F P
0 g
s
.839 .614 .597 r
.14869 .47564 m .14295 .47326 L .14416 .4678 L p F P
0 g
s
.576 .527 .764 r
.66304 .36637 m .66393 .36876 L .65432 .37432 L p F P
0 g
s
.576 .527 .764 r
.65432 .37432 m .65159 .36697 L .66304 .36637 L p F P
0 g
s
.414 .107 .333 r
.62427 .51087 m .6252 .50679 L .63587 .50281 L p F P
0 g
s
.459 .191 .42 r
.63641 .49833 m .63587 .50281 L .6252 .50679 L p F P
0 g
s
.838 .629 .621 r
.14416 .4678 m .13849 .46538 L .14015 .45978 L p F P
0 g
s
.841 .617 .599 r
.13849 .46538 m .14416 .4678 L .14295 .47326 L p F P
0 g
s
.372 .818 .946 r
.42781 .29603 m .42908 .29629 L .4408 .29501 L p F P
0 g
s
.524 .384 .633 r
.66813 .45062 m .6649 .45218 L .66589 .45826 L p F P
0 g
s
.613 .809 .976 r
.46657 .54745 m .47759 .54467 L .48062 .54682 L p F P
0 g
s
.639 .779 .948 r
.47759 .54467 m .46657 .54745 L .46352 .5451 L p F P
0 g
s
.644 .102 0 r
.19987 .52123 m .2036 .52231 L .20835 .52601 L p F P
0 g
s
.676 .153 0 r
.21497 .52805 m .20835 .52601 L .2036 .52231 L p F P
0 g
s
.841 .575 .537 r
.15938 .49082 m .15355 .48848 L .15376 .48332 L p F P
0 g
s
.842 .576 .536 r
.14797 .48096 m .15376 .48332 L .15355 .48848 L p F P
0 g
s
.548 .85 .998 r
.50748 .54426 m .50575 .54333 L .49467 .546 L p F P
0 g
s
.619 .813 .975 r
.50575 .54333 m .49467 .546 L .49167 .5441 L p F P
0 g
s
.564 .836 .996 r
.49467 .546 m .49167 .5441 L .48062 .54682 L p F P
0 g
s
.648 .678 .865 r
.55303 .29287 m .54328 .29579 L .54034 .29132 L p F P
0 g
s
.832 .676 .689 r
.12891 .42613 m .1342 .42872 L .13104 .43477 L p F P
0 g
s
.83 .68 .696 r
.1342 .42872 m .12891 .42613 L .1324 .41997 L p F P
0 g
s
.631 .794 .96 r
.49167 .5441 m .48062 .54682 L .47759 .54467 L p F P
0 g
s
.73 .73 .85 r
.2573 .29613 m .25612 .29473 L .25528 .29522 L closepath p F P
0 g
s
.799 .717 .774 r
.15321 .35571 m .15824 .35846 L .15155 .36565 L p F P
0 g
s
.799 .718 .775 r
.15842 .35026 m .15321 .35571 L .15824 .35846 L p F P
0 g
s
.84 .632 .621 r
.13593 .45793 m .14015 .45978 L .13849 .46538 L p F P
0 g
s
.836 .643 .642 r
.1352 .45559 m .13664 .4516 L p .14015 .45978 L F P
0 g
s
.836 .643 .642 r
.14015 .45978 m .13593 .45793 L .1352 .45559 L p F P
0 g
s
.816 .707 .744 r
.13951 .38895 m .14266 .38491 L .13927 .38003 L p F P
0 g
s
.333 0 0 r
.22211 .52991 m .2291 .53288 L .22896 .53284 L p F P
0 g
s
.333 0 0 r
.21586 .52831 m .22211 .52991 L p .22896 .53284 L F P
0 g
s
.769 .725 .811 r
.19162 .31996 m .19566 .31673 L .20093 .31943 L p F P
0 g
s
.768 .726 .814 r
.20258 .31128 m .19566 .31673 L .20093 .31943 L p F P
0 g
s
.768 .726 .814 r
.20093 .31943 m .20596 .31547 L .20258 .31128 L p F P
0 g
s
.74 .724 .836 r
.23112 .30391 m .2313 .30379 L .23087 .30361 L closepath p F P
0 g
s
.752 .728 .831 r
.23087 .30361 m .23112 .30391 L p .21688 .30735 L F P
0 g
s
.735 .726 .842 r
.23862 .29306 m .24196 .29706 L .2313 .30379 L p F P
0 g
s
.735 .726 .842 r
.22776 .29985 m .23862 .29306 L p .2313 .30379 L F P
0 g
s
.735 .726 .842 r
.2313 .30379 m .23087 .30361 L .22776 .29985 L p F P
0 g
s
.545 .447 .695 r
.66898 .42072 m .67878 .41546 L p .67741 .42414 L F P
0 g
s
.545 .447 .695 r
.67741 .42414 m .66956 .423 L .66898 .42072 L p F P
0 g
s
.55 .461 .707 r
.67803 .41273 m .67878 .41546 L .66898 .42072 L p F P
0 g
s
.55 .461 .707 r
.67012 .4119 m .67803 .41273 L p .66898 .42072 L F P
0 g
s
0 .466 .74 r
.24646 .53701 m .24407 .53647 L .24872 .53766 L closepath p F P
0 g
s
.84 .549 .497 r
.16287 .49706 m .15973 .49582 L .15938 .49082 L p F P
0 g
s
.842 .55 .494 r
.15355 .48848 m .15938 .49082 L .15973 .49582 L p F P
0 g
s
.329 0 .128 r
.60105 .5218 m .60112 .52166 L .61234 .51754 L p F P
0 g
s
.538 .797 .993 r
.33704 .54692 m .33378 .54438 L .32303 .54669 L p F P
0 g
s
.631 .763 .942 r
.33378 .54438 m .32303 .54669 L .31974 .54435 L p F P
0 g
s
.618 .608 .819 r
.59144 .3128 m .6027 .31039 L .60561 .3162 L p F P
0 g
s
.619 .612 .822 r
.6002 .30542 m .6027 .31039 L .59144 .3128 L p F P
0 g
s
.619 .612 .822 r
.59144 .3128 m .59036 .31069 L .6002 .30542 L p F P
0 g
s
.75 .729 .833 r
.23087 .30361 m .22776 .29985 L .22589 .30112 L closepath p F P
0 g
s
.752 .728 .831 r
.21688 .30735 m .22589 .30112 L .23087 .30361 L p F P
0 g
s
.673 .75 .909 r
.28431 .29186 m .29506 .28788 L .29836 .29122 L p F P
0 g
s
.656 .757 .924 r
.29506 .28788 m .28431 .29186 L .281 .28825 L p F P
0 g
s
.696 .741 .885 r
.27024 .29304 m .281 .28825 L .28431 .29186 L p F P
0 g
s
.346 .736 .985 r
.2746 .54077 m .27399 .54063 L .2638 .54062 L p F P
0 g
s
.296 .731 .968 r
.27399 .54063 m .2638 .54062 L .26036 .53922 L p F P
0 g
s
.596 .57 .794 r
.63975 .33793 m .62854 .33948 L .62589 .3334 L p F P
0 g
s
.634 .765 .942 r
.29836 .29122 m .30908 .28818 L .31238 .29113 L p F P
0 g
s
.596 .773 .964 r
.30908 .28818 m .29836 .29122 L .29506 .28788 L p F P
0 g
s
.628 .626 .829 r
.5744 .30448 m .58562 .30171 L .58853 .30719 L p F P
0 g
s
.63 .633 .835 r
.58345 .29771 m .58562 .30171 L .5744 .30448 L p F P
0 g
s
.63 .633 .835 r
.5744 .30448 m .57346 .30277 L .58345 .29771 L p F P
0 g
s
.545 .447 .694 r
.67074 .42767 m .66956 .423 L .67741 .42414 L closepath p F P
0 g
s
.218 0 0 r
.59887 .52463 m .60105 .5218 L .61201 .51821 L p F P
0 g
s
.329 0 .128 r
.61234 .51754 m .61201 .51821 L .60105 .5218 L p F P
0 g
s
.242 0 0 r
.60105 .5218 m .59887 .52463 L .58773 .528 L p F P
0 g
s
.84 .646 .64 r
.1352 .45559 m .13664 .4516 L .13348 .45017 L closepath p F P
0 g
s
.835 .655 .659 r
.13216 .44672 m .13361 .44326 L p .13664 .4516 L F P
0 g
s
.835 .655 .659 r
.13664 .4516 m .13348 .45017 L .13216 .44672 L p F P
0 g
s
.76 .727 .821 r
.21245 .31061 m .20596 .31547 L .20258 .31128 L p F P
0 g
s
.777 .344 .222 r
.19694 .52028 m .19055 .51816 L .18747 .51396 L p F P
0 g
s
.771 .329 .202 r
.18147 .51204 m .18747 .51396 L .19055 .51816 L p F P
0 g
s
.575 .528 .764 r
.66069 .36007 m .66304 .36637 L .65159 .36697 L p F P
0 g
s
.575 .528 .764 r
.65159 .36697 m .65111 .36569 L .66069 .36007 L p F P
0 g
s
.445 .181 .418 r
.63587 .50281 m .63641 .49833 L .64692 .49414 L p F P
0 g
s
.478 .244 .48 r
.64712 .48932 m .64692 .49414 L .63641 .49833 L p F P
0 g
s
.824 .694 .72 r
.13448 .4057 m .13512 .40474 L .1333 .4038 L closepath p F P
0 g
s
.819 .699 .732 r
.13111 .40045 m .1346 .39555 L p .13512 .40474 L F P
0 g
s
.819 .699 .732 r
.13512 .40474 m .1333 .4038 L .13111 .40045 L p F P
0 g
s
.689 .745 .894 r
.281 .28825 m .27024 .29304 L .26692 .28926 L p F P
0 g
s
.58 .537 .772 r
.6601 .35855 m .66069 .36007 L .65111 .36569 L p F P
0 g
s
.58 .537 .772 r
.65111 .36569 m .64866 .35935 L .6601 .35855 L p F P
0 g
s
.799 .717 .774 r
.1472 .36214 m .15321 .35571 L p .15155 .36565 L F P
0 g
s
.799 .717 .774 r
.15155 .36565 m .14872 .36413 L .1472 .36214 L p F P
0 g
s
.804 .713 .765 r
.15061 .3667 m .15155 .36565 L .14872 .36413 L closepath p F P
0 g
s
.819 .704 .738 r
.13447 .38622 m .13951 .38895 L .1346 .39555 L p F P
0 g
s
.816 .707 .744 r
.13927 .38003 m .13447 .38622 L .13951 .38895 L p F P
0 g
s
.809 .714 .761 r
.14548 .37263 m .15061 .3667 L .14872 .36413 L p F P
0 g
s
.609 .594 .811 r
.61692 .31409 m .61982 .32019 L .60852 .32226 L p F P
0 g
s
.609 .594 .811 r
.6093 .31549 m .61692 .31409 L p .60852 .32226 L F P
0 g
s
.609 .594 .811 r
.60852 .32226 m .60613 .31727 L .6093 .31549 L p F P
0 g
s
.826 .499 .435 r
.173 .50509 m .16685 .50287 L .16573 .4981 L p F P
0 g
s
.826 .493 .424 r
.16287 .49706 m .16573 .4981 L .16685 .50287 L p F P
0 g
s
.828 .694 .716 r
.13101 .41108 m .13448 .4057 L .1333 .4038 L p F P
0 g
s
.562 .782 .981 r
.31238 .29113 m .32309 .28917 L .32639 .29158 L p F P
0 g
s
.479 .772 .995 r
.31238 .29113 m .32309 .28917 L .32068 .28771 L p F P
0 g
s
.479 .772 .995 r
.30908 .28818 m .31238 .29113 L p .32068 .28771 L F P
0 g
s
.646 .755 .929 r
.34784 .54425 m .33704 .54692 L .33378 .54438 L p F P
0 g
s
.621 .77 .951 r
.33704 .54692 m .34784 .54425 L .35107 .54695 L p F P
0 g
s
.489 .789 .998 r
.29977 .54483 m .3057 .54409 L p .2917 .54351 L F P
0 g
s
.489 .789 .998 r
.2917 .54351 m .29241 .5439 L .29977 .54483 L p F P
0 g
s
.539 .421 .668 r
.67272 .43625 m .66993 .43562 L .67233 .43442 L closepath p F P
0 g
s
.547 .438 .681 r
.67074 .42767 m .67233 .43442 L .66993 .43562 L p F P
0 g
s
.242 0 0 r
.39695 .29766 m .39499 .29762 L .38566 .29671 L p F P
0 g
s
.729 .732 .853 r
.24196 .29706 m .24968 .29261 L .25528 .29522 L p F P
0 g
s
.731 .734 .853 r
.25279 .29084 m .24968 .29261 L .25528 .29522 L p F P
0 g
s
.731 .734 .853 r
.25528 .29522 m .25612 .29473 L .25279 .29084 L p F P
0 g
s
.832 .683 .698 r
.12721 .41733 m .1324 .41997 L .12891 .42613 L p F P
0 g
s
.829 .688 .707 r
.1324 .41997 m .12721 .41733 L .13101 .41108 L p F P
0 g
s
.653 .779 .94 r
.48407 .29137 m .49513 .28785 L .49813 .29069 L p F P
0 g
s
.63 .832 .978 r
.49513 .28785 m .48407 .29137 L .48105 .28915 L p F P
0 g
s
.628 .819 .974 r
.47001 .29237 m .48105 .28915 L .48407 .29137 L p F P
0 g
s
.66 .744 .912 r
.49813 .29069 m .50921 .28705 L .51219 .29044 L p F P
0 g
s
.657 .783 .941 r
.50921 .28705 m .49813 .29069 L .49513 .28785 L p F P
0 g
s
.622 .619 .827 r
.5998 .30463 m .6002 .30542 L .59036 .31069 L p F P
0 g
s
.622 .619 .827 r
.59036 .31069 m .58853 .30719 L .5998 .30463 L p F P
0 g
s
.538 .433 .683 r
.67233 .43442 m .67074 .42767 L .67741 .42414 L p F P
0 g
s
.838 .657 .657 r
.13216 .44672 m .13361 .44326 L .13018 .44166 L closepath p F P
0 g
s
.834 .666 .675 r
.12901 .43904 m .13104 .43477 L p .13361 .44326 L F P
0 g
s
.834 .666 .675 r
.13361 .44326 m .13018 .44166 L .12901 .43904 L p F P
0 g
s
.644 .102 0 r
.19818 .52155 m .19987 .52123 L p .20835 .52601 L F P
0 g
s
.738 .258 .105 r
.19818 .52155 m .19694 .52028 L .19987 .52123 L closepath p F P
0 g
s
.598 .861 .993 r
.46711 .29089 m .47001 .29237 L .48105 .28915 L p F P
0 g
s
.709 .738 .874 r
.26692 .28926 m .25612 .29473 L .25279 .29084 L p F P
0 g
s
.497 .312 .56 r
.66207 .47216 m .65707 .47442 L .65741 .4798 L p F P
0 g
s
.43 .832 .978 r
.44188 .29482 m .4408 .29501 L .4421 .29489 L closepath p F P
0 g
s
.372 .818 .946 r
.4408 .29501 m .44188 .29482 L p .42781 .29603 L F P
0 g
s
.76 .727 .821 r
.20258 .31128 m .20711 .30792 L .21245 .31061 L p F P
0 g
s
.76 .729 .824 r
.21351 .30325 m .20711 .30792 L .21245 .31061 L p F P
0 g
s
.76 .729 .824 r
.21245 .31061 m .21688 .30735 L .21351 .30325 L p F P
0 g
s
.632 .639 .839 r
.5827 .29637 m .58345 .29771 L .57346 .30277 L p F P
0 g
s
.632 .639 .839 r
.57346 .30277 m .57148 .29926 L .5827 .29637 L p F P
0 g
s
.64 .655 .848 r
.56856 .29421 m .55737 .29731 L .55444 .29245 L p F P
0 g
s
.638 .648 .843 r
.55737 .29731 m .56856 .29421 L .57148 .29926 L p F P
0 g
s
.549 .461 .708 r
.67803 .41273 m .67012 .4119 L .6768 .40825 L closepath p F P
0 g
s
.556 .474 .718 r
.67497 .40197 m .6768 .40825 L .67012 .4119 L p F P
0 g
s
.556 .474 .718 r
.67287 .40182 m .67497 .40197 L p .67012 .4119 L F P
0 g
s
.462 .847 .983 r
.44188 .29482 m .4421 .29489 L .45488 .29321 L p F P
0 g
s
.57 .849 .996 r
.45595 .29358 m .45488 .29321 L .4421 .29489 L p F P
0 g
s
.636 .764 .941 r
.35107 .54695 m .3619 .54402 L .36511 .54686 L p F P
0 g
s
.656 .749 .918 r
.3619 .54402 m .35107 .54695 L .34784 .54425 L p F P
0 g
s
.66 .716 .89 r
.51219 .29044 m .5233 .28679 L .52626 .29065 L p F P
0 g
s
.661 .742 .91 r
.5233 .28679 m .51219 .29044 L .50921 .28705 L p F P
0 g
s
.52 .867 .991 r
.46574 .29112 m .45488 .29321 L .45595 .29358 L closepath p F P
0 g
s
.558 .854 .997 r
.46711 .29089 m .46574 .29112 L .45595 .29358 L p F P
0 g
s
.579 .538 .773 r
.6572 .35108 m .6601 .35855 L .64866 .35935 L p F P
0 g
s
.579 .538 .773 r
.64866 .35935 m .64765 .35675 L .6572 .35108 L p F P
0 g
s
.019 .562 .839 r
.24407 .53647 m .24646 .53701 L .24297 .53567 L p F P
0 g
s
.575 .842 .995 r
.50575 .54333 m .50748 .54426 L .51982 .54227 L p F P
0 g
s
.246 0 0 r
.41119 .29755 m .40831 .29759 L .3997 .29703 L p F P
0 g
s
.447 .776 .998 r
.3388 .29163 m .33405 .29091 L .32639 .29158 L p F P
0 g
s
.49 .754 .988 r
.33405 .29091 m .32639 .29158 L .32309 .28917 L p F P
0 g
s
.809 .713 .76 r
.14047 .36987 m .14548 .37263 L .13967 .37952 L p F P
0 g
s
.809 .714 .761 r
.14651 .3629 m .14047 .36987 L .14548 .37263 L p F P
0 g
s
.809 .714 .761 r
.14872 .36413 m .14651 .3629 L p .14548 .37263 L F P
0 g
s
.23 .746 .746 r
.56162 .53583 m .56199 .53576 L .57318 .53288 L p F P
0 g
s
.524 .384 .633 r
.66589 .45826 m .67511 .4538 L .66813 .45062 L p F P
0 g
s
.522 .385 .635 r
.67492 .44726 m .66813 .45062 L .67511 .4538 L p F P
0 g
s
.533 .405 .652 r
.67372 .44094 m .67492 .44726 L .66813 .45062 L p F P
0 g
s
.828 .694 .716 r
.1333 .4038 m .13001 .40205 L p .13101 .41108 L F P
0 g
s
.825 .7 .727 r
.1333 .4038 m .13111 .40045 L .13001 .40205 L closepath p F P
0 g
s
.462 .847 .983 r
.45488 .29321 m .45285 .29307 L .44188 .29482 L p F P
0 g
s
.24 0 0 r
.44188 .29482 m .45285 .29307 L .45096 .29397 L p F P
0 g
s
.24 0 0 r
.43874 .29523 m .44188 .29482 L p .45096 .29397 L F P
0 g
s
.372 .818 .946 r
.44188 .29482 m .43874 .29523 L .42781 .29603 L p F P
0 g
s
.751 .73 .833 r
.22589 .30112 m .21688 .30735 L .21351 .30325 L p F P
0 g
s
.645 .76 .933 r
.36511 .54686 m .37597 .54375 L .37916 .5467 L p F P
0 g
s
.662 .743 .91 r
.37597 .54375 m .36511 .54686 L .3619 .54402 L p F P
0 g
s
.819 .45 .358 r
.18098 .51187 m .17487 .50964 L .173 .50509 L p F P
0 g
s
.819 .446 .35 r
.16685 .50287 m .173 .50509 L .17487 .50964 L p F P
0 g
s
.513 .362 .613 r
.66669 .46414 m .66589 .45826 L .67511 .4538 L p F P
0 g
s
.331 .749 .977 r
.27773 .5424 m .28275 .54198 L .29071 .54357 L p F P
0 g
s
.446 .779 .998 r
.28275 .54198 m .2746 .54077 L .27773 .5424 L closepath p F P
0 g
s
.596 .57 .794 r
.62589 .3334 m .62729 .33258 L p .63975 .33793 L F P
0 g
s
.599 .578 .801 r
.62589 .3334 m .62563 .33283 L .62729 .33258 L closepath p F P
0 g
s
.837 .668 .673 r
.12901 .43904 m .13104 .43477 L .12593 .4323 L closepath p F P
0 g
s
.832 .676 .689 r
.12579 .43203 m .12891 .42613 L p .13104 .43477 L F P
0 g
s
.832 .676 .689 r
.13104 .43477 m .12593 .4323 L .12579 .43203 L p F P
0 g
s
.583 .547 .78 r
.65717 .351 m .6572 .35108 L .64765 .35675 L p F P
0 g
s
.583 .547 .78 r
.64765 .35675 m .64574 .35199 L .65717 .351 L p F P
0 g
s
.185 0 0 r
.42487 .29682 m .42368 .29689 L .41375 .29681 L p F P
0 g
s
.185 0 0 r
.42368 .29689 m .41119 .29755 L .41375 .29681 L closepath p F P
0 g
s
.075 0 0 r
.42487 .29682 m .42781 .29603 L .43874 .29523 L p F P
0 g
s
.465 .234 .479 r
.64692 .49414 m .64712 .48932 L .6575 .48492 L p F P
0 g
s
.49 .283 .525 r
.65741 .4798 m .6575 .48492 L .64712 .48932 L p F P
0 g
s
.655 .694 .874 r
.52626 .29065 m .53739 .28709 L .54034 .29132 L p F P
0 g
s
.658 .712 .888 r
.53739 .28709 m .52626 .29065 L .5233 .28679 L p F P
0 g
s
.333 0 0 r
.21538 .5283 m .21586 .52831 L p .22896 .53284 L F P
0 g
s
.601 .04 0 r
.21538 .5283 m .21497 .52805 L .21586 .52831 L closepath p F P
0 g
s
.599 .58 .803 r
.62729 .33258 m .62563 .33283 L .62273 .32645 L p F P
0 g
s
.439 .768 .997 r
.2917 .54351 m .29071 .54357 L .29241 .5439 L closepath p F P
0 g
s
.826 .493 .424 r
.16061 .50028 m .16287 .49706 L p .16685 .50287 L F P
0 g
s
.838 .516 .444 r
.16061 .50028 m .15973 .49582 L .16287 .49706 L closepath p F P
0 g
s
.65 .756 .927 r
.37916 .5467 m .39005 .54346 L .39321 .54648 L p F P
0 g
s
.665 .739 .905 r
.39005 .54346 m .37916 .5467 L .37597 .54375 L p F P
0 g
s
.726 .733 .856 r
.24968 .29261 m .24196 .29706 L .23862 .29306 L p F P
0 g
s
.843 .647 .637 r
.13348 .45017 m .1312 .44908 L p .1346 .45731 L F P
0 g
s
.843 .647 .637 r
.1346 .45731 m .1352 .45559 L .13348 .45017 L p F P
0 g
s
.841 .658 .654 r
.13348 .45017 m .13216 .44672 L .1312 .44908 L closepath p F P
0 g
s
.823 .701 .73 r
.1346 .39555 m .13111 .40045 L .12773 .39537 L p F P
0 g
s
.823 .701 .73 r
.12773 .39537 m .12952 .39284 L .1346 .39555 L p F P
0 g
s
.819 .704 .738 r
.1346 .39555 m .12952 .39284 L .13447 .38622 L p F P
0 g
s
.842 .646 .637 r
.13593 .45793 m .1352 .45559 L .1346 .45731 L closepath p F P
0 g
s
.786 .725 .795 r
.17638 .3331 m .16955 .33935 L .16613 .33508 L p F P
0 g
s
.791 .725 .791 r
.16795 .34087 m .16955 .33935 L .16613 .33508 L p F P
0 g
s
.786 .725 .795 r
.16613 .33508 m .17134 .33031 L .17638 .3331 L p F P
0 g
s
.784 .726 .798 r
.1772 .32507 m .17134 .33031 L .17638 .3331 L p F P
0 g
s
.784 .726 .798 r
.17638 .3331 m .18061 .32931 L .1772 .32507 L p F P
0 g
s
.84 .632 .621 r
.13849 .46538 m .13756 .46497 L .13593 .45793 L p F P
0 g
s
.847 .636 .617 r
.1346 .45731 m .13593 .45793 L .13756 .46497 L p F P
0 g
s
.791 .725 .791 r
.16613 .33508 m .16299 .33807 L .16795 .34087 L p F P
0 g
s
.792 .722 .786 r
.16299 .33807 m .16795 .34087 L .16027 .34839 L p F P
0 g
s
.831 .691 .709 r
.12591 .4084 m .13101 .41108 L .12721 .41733 L p F P
0 g
s
.828 .694 .716 r
.13001 .40205 m .12591 .4084 L .13101 .41108 L p F P
0 g
s
.778 .726 .804 r
.18554 .32508 m .18061 .32931 L .1772 .32507 L p F P
0 g
s
.714 .21 .037 r
.19694 .52028 m .19818 .52155 L .19449 .52176 L p F P
0 g
s
.714 .21 .037 r
.19449 .52176 m .19055 .51816 L .19694 .52028 L p F P
0 g
s
.531 .416 .668 r
.67233 .43442 m .68217 .42921 L p .67923 .43807 L F P
0 g
s
.531 .416 .668 r
.67923 .43807 m .67272 .43625 L .67233 .43442 L p F P
0 g
s
.538 .433 .683 r
.68116 .42493 m .68217 .42921 L .67233 .43442 L p F P
0 g
s
.538 .433 .683 r
.67741 .42414 m .68116 .42493 L p .67233 .43442 L F P
0 g
s
.531 0 0 r
.21497 .52805 m .21538 .5283 L .21177 .52785 L p F P
0 g
s
.531 0 0 r
.21177 .52785 m .20835 .52601 L .21497 .52805 L p F P
0 g
s
.361 .831 .874 r
.55913 .53583 m .56162 .53583 L .57311 .53289 L p F P
0 g
s
.31 .802 .842 r
.56162 .53583 m .55913 .53583 L .54795 .53864 L p F P
0 g
s
.23 .746 .746 r
.57318 .53288 m .57311 .53289 L .56162 .53583 L p F P
0 g
s
.097 0 0 r
.58719 .52845 m .58773 .528 L .59887 .52463 L p F P
0 g
s
.806 .718 .768 r
.14872 .36413 m .1472 .36214 L .14651 .3629 L closepath p F P
0 g
s
.652 .754 .925 r
.39321 .54648 m .40412 .54318 L .40726 .54625 L p F P
0 g
s
.667 .736 .902 r
.40412 .54318 m .39321 .54648 L .39005 .54346 L p F P
0 g
s
0 .52 .745 r
.34271 .29246 m .35168 .29389 L p .35108 .29363 L F P
0 g
s
0 .52 .745 r
.35047 .29354 m .34271 .29246 L p .35108 .29363 L F P
0 g
s
.496 .768 .992 r
.34271 .29246 m .35168 .29389 L p .34609 .29319 L F P
0 g
s
.496 .768 .992 r
.34038 .29248 m .34271 .29246 L p .34609 .29319 L F P
0 g
s
0 .52 .745 r
.35104 .29362 m .35047 .29354 L p .35108 .29363 L F P
0 g
s
.405 0 0 r
.34271 .29246 m .35104 .29362 L .35024 .2938 L p F P
0 g
s
.405 0 0 r
.3388 .29163 m .34271 .29246 L p .33959 .29178 L F P
0 g
s
.355 .739 .987 r
.34271 .29246 m .3388 .29163 L .34038 .29248 L closepath p F P
0 g
s
.405 0 0 r
.33707 .29097 m .3388 .29163 L p .35024 .2938 L F P
0 g
s
.233 .705 .941 r
.33707 .29097 m .33405 .29091 L .3388 .29163 L closepath p F P
0 g
s
0 .52 .775 r
.33405 .29091 m .33707 .29097 L .3337 .29051 L p F P
0 g
s
.296 0 0 r
.34314 .29278 m .33908 .29157 L p .3337 .29051 L F P
0 g
s
.296 0 0 r
.33908 .29157 m .33707 .29097 L .33508 .2907 L p F P
0 g
s
.296 0 0 r
.33508 .2907 m .3337 .29051 L p .33908 .29157 L F P
0 g
s
.405 0 0 r
.3453 .29292 m .33959 .29178 L .34271 .29246 L F
.35024 .2938 m .34324 .29247 L .3453 .29292 L F
.34324 .29247 m .33959 .29178 L .3453 .29292 L F
.35024 .2938 m .34314 .29278 L .34035 .29195 L p F P
0 g
s
.405 0 0 r
.34035 .29195 m .33707 .29097 L p .34501 .29268 L F P
0 g
s
.405 0 0 r
.35024 .2938 m .34035 .29195 L .34501 .29268 L F
.505 .776 .993 r
.29071 .54357 m .2917 .54351 L .28834 .54135 L p F P
0 g
s
.505 .776 .993 r
.28834 .54135 m .28275 .54198 L .29071 .54357 L p F P
0 g
s
.778 .726 .804 r
.1772 .32507 m .18042 .32231 L .18554 .32508 L p F P
0 g
s
.777 .727 .807 r
.18822 .31576 m .18042 .32231 L .18554 .32508 L p F P
0 g
s
.777 .727 .807 r
.18554 .32508 m .19162 .31996 L .18822 .31576 L p F P
0 g
s
.612 .602 .816 r
.60613 .31727 m .60561 .3162 L .6093 .31549 L closepath p F P
0 g
s
.842 .659 .654 r
.1312 .44908 m .13216 .44672 L .13018 .44166 L p F P
0 g
s
.842 .598 .57 r
.14797 .48096 m .14221 .47858 L .14295 .47326 L p F P
0 g
s
.844 .6 .571 r
.13841 .47133 m .14295 .47326 L .14221 .47858 L p F P
0 g
s
.841 .617 .599 r
.13795 .46781 m .13849 .46538 L p .14295 .47326 L F P
0 g
s
.841 .617 .599 r
.14295 .47326 m .13841 .47133 L .13795 .46781 L p F P
0 g
s
.796 .72 .781 r
.16027 .34839 m .15842 .35026 L .155 .34585 L p F P
0 g
s
.796 .72 .781 r
.155 .34585 m .15522 .34562 L .16027 .34839 L p F P
0 g
s
.792 .722 .786 r
.16027 .34839 m .15522 .34562 L .16299 .33807 L p F P
0 g
s
.622 .623 .83 r
.5998 .30463 m .58853 .30719 L .58562 .30171 L p F P
0 g
s
.844 .619 .598 r
.13795 .46781 m .13849 .46538 L .13756 .46497 L closepath p F P
0 g
s
.815 .709 .749 r
.13927 .38003 m .13967 .37952 L .13843 .37885 L closepath p F P
0 g
s
.809 .713 .76 r
.13585 .37535 m .14047 .36987 L p .13967 .37952 L F P
0 g
s
.809 .713 .76 r
.13967 .37952 m .13843 .37885 L .13585 .37535 L p F P
0 g
s
.842 .576 .536 r
.15355 .48848 m .14776 .48613 L .14797 .48096 L p F P
0 g
s
.844 .578 .536 r
.14221 .47858 m .14797 .48096 L .14776 .48613 L p F P
0 g
s
.801 .721 .776 r
.15321 .35571 m .15842 .35026 L .155 .34585 L p F P
0 g
s
.653 .755 .924 r
.40726 .54625 m .4182 .54293 L .42132 .546 L p F P
0 g
s
.666 .735 .902 r
.4182 .54293 m .40726 .54625 L .40412 .54318 L p F P
0 g
s
.333 0 0 r
.22249 .53093 m .21538 .5283 L p .22842 .53266 L F P
0 g
s
.388 0 0 r
.22249 .53093 m .21538 .5283 L .21177 .52785 L p F P
0 g
s
.034 .566 .856 r
.22205 .53011 m .21603 .52904 L p .22249 .53093 L F P
0 g
s
.388 0 0 r
.2156 .52897 m .22249 .53093 L p .22125 .53057 L F P
0 g
s
.388 0 0 r
.21177 .52785 m .2156 .52897 L p .22125 .53057 L F P
0 g
s
.454 0 0 r
.20835 .52601 m .21177 .52785 L .20818 .52699 L p F P
0 g
s
.136 .63 .911 r
.21854 .52828 m .2092 .52715 L p .2156 .52897 L F P
0 g
s
.233 0 0 r
.2156 .52897 m .21177 .52785 L .20818 .52699 L p F P
0 g
s
.136 .63 .911 r
.2092 .52715 m .20851 .52706 L .2156 .52897 L p F P
0 g
s
.034 .566 .856 r
.21603 .52904 m .2156 .52897 L .22249 .53093 L p F P
0 g
s
.333 0 0 r
.22896 .53284 m .22249 .53093 L p .22842 .53266 L F P
0 g
s
.819 .71 .745 r
.13447 .38622 m .13927 .38003 L .13843 .37885 L p F P
0 g
s
.77 .727 .813 r
.19566 .31673 m .19162 .31996 L .18822 .31576 L p F P
0 g
s
.531 .416 .667 r
.67372 .44094 m .67272 .43625 L .67923 .43807 L closepath p F P
0 g
s
.583 .547 .781 r
.65425 .34379 m .65717 .351 L .64574 .35199 L p F P
0 g
s
.583 .547 .781 r
.64935 .3442 m .65425 .34379 L p .64574 .35199 L F P
0 g
s
.583 .547 .781 r
.64574 .35199 m .64391 .34748 L .64935 .3442 L p F P
0 g
s
.596 .57 .794 r
.62729 .33258 m .637 .33127 L p .63975 .33793 L F P
0 g
s
.595 .571 .797 r
.637 .33127 m .62729 .33258 L .63545 .32775 L closepath p F P
0 g
s
.599 .58 .803 r
.63409 .32475 m .63545 .32775 L .62729 .33258 L p F P
0 g
s
.599 .58 .803 r
.62273 .32645 m .63409 .32475 L p .62729 .33258 L F P
0 g
s
.771 .329 .202 r
.18116 .51219 m .18147 .51204 L p .19055 .51816 L F P
0 g
s
.802 .398 .286 r
.18116 .51219 m .18098 .51187 L .18147 .51204 L closepath p F P
0 g
s
.612 .605 .82 r
.6093 .31549 m .60561 .3162 L .6027 .31039 L p F P
0 g
s
.511 .877 .98 r
.55913 .53583 m .54795 .53864 L .54505 .53797 L p F P
0 g
s
.477 .869 .97 r
.53389 .54074 m .54505 .53797 L .54795 .53864 L p F P
0 g
s
.648 .678 .865 r
.54034 .29132 m .5515 .28792 L p .55303 .29287 L F P
0 g
s
.652 .689 .872 r
.5515 .28792 m .54034 .29132 L .53739 .28709 L p F P
0 g
s
.836 .678 .686 r
.12891 .42613 m .12579 .43203 L .12251 .42573 L p F P
0 g
s
.836 .678 .686 r
.12251 .42573 m .12368 .4235 L .12891 .42613 L p F P
0 g
s
.832 .683 .698 r
.12891 .42613 m .12368 .4235 L .12721 .41733 L p F P
0 g
s
.849 .639 .618 r
.12924 .45477 m .1346 .45731 L .13303 .46288 L p F P
0 g
s
.843 .647 .637 r
.1312 .44908 m .12924 .45477 L .1346 .45731 L p F P
0 g
s
.847 .636 .617 r
.13756 .46497 m .13303 .46288 L .1346 .45731 L p F P
0 g
s
.489 .789 .998 r
.3057 .54409 m .30238 .54167 L .2917 .54351 L p F P
0 g
s
.606 .766 .956 r
.30238 .54167 m .2917 .54351 L .28834 .54135 L p F P
0 g
s
.633 .644 .843 r
.5827 .29637 m .57148 .29926 L .56856 .29421 L p F P
0 g
s
.842 .659 .654 r
.13018 .44166 m .12824 .44071 L p .1312 .44908 L F P
0 g
s
.84 .668 .669 r
.13018 .44166 m .12901 .43904 L .12824 .44071 L closepath p F P
0 g
s
.842 .55 .494 r
.15973 .49582 m .15391 .49348 L .15355 .48848 L p F P
0 g
s
.844 .551 .492 r
.14776 .48613 m .15355 .48848 L .15391 .49348 L p F P
0 g
s
.665 .736 .903 r
.43229 .5427 m .42132 .546 L .4182 .54293 L p F P
0 g
s
.652 .757 .926 r
.42132 .546 m .43229 .5427 L .43538 .54573 L p F P
0 g
s
.797 .375 .247 r
.18098 .51187 m .18116 .51219 L .17735 .51355 L p F P
0 g
s
.797 .375 .247 r
.17735 .51355 m .17487 .50964 L .18098 .51187 L p F P
0 g
s
.751 .732 .834 r
.2244 .29583 m .22057 .29841 L .22589 .30112 L p F P
0 g
s
.751 .732 .834 r
.22589 .30112 m .22776 .29985 L .2244 .29583 L p F P
0 g
s
.751 .73 .833 r
.21351 .30325 m .22057 .29841 L .22589 .30112 L p F P
0 g
s
.77 .727 .813 r
.18822 .31576 m .19045 .31398 L .19566 .31673 L p F P
0 g
s
.769 .729 .816 r
.19919 .30714 m .19045 .31398 L .19566 .31673 L p F P
0 g
s
.769 .729 .816 r
.19566 .31673 m .20258 .31128 L .19919 .30714 L p F P
0 g
s
.803 .72 .773 r
.15321 .35571 m .1472 .36214 L .14377 .35771 L p F P
0 g
s
.803 .72 .773 r
.14377 .35771 m .14824 .35291 L .15321 .35571 L p F P
0 g
s
.801 .721 .776 r
.155 .34585 m .14824 .35291 L .15321 .35571 L p F P
0 g
s
.848 .622 .596 r
.13756 .46497 m .13303 .46288 L p .1373 .47083 L F P
0 g
s
.848 .622 .596 r
.1373 .47083 m .13795 .46781 L .13756 .46497 L p F P
0 g
s
.35 .821 .898 r
.45285 .29307 m .45488 .29321 L .46574 .29112 L p F P
0 g
s
.018 .57 .824 r
.26036 .53922 m .25693 .53747 L .24646 .53701 L p F P
0 g
s
.399 .743 .993 r
.24646 .53701 m .25693 .53747 L .25587 .53684 L p F P
0 g
s
.399 .743 .993 r
.24297 .53567 m .24646 .53701 L p .25587 .53684 L F P
0 g
s
.826 .702 .727 r
.13001 .40205 m .13111 .40045 L .12773 .39537 L p F P
0 g
s
.649 .761 .931 r
.43538 .54573 m .44637 .54249 L .44945 .54544 L p F P
0 g
s
.662 .739 .907 r
.44637 .54249 m .43538 .54573 L .43229 .5427 L p F P
0 g
s
.739 .732 .846 r
.23862 .29306 m .22776 .29985 L .2244 .29583 L p F P
0 g
s
.771 .329 .202 r
.19055 .51816 m .18413 .51604 L .18116 .51219 L p F P
0 g
s
.77 .33 .207 r
.18413 .51604 m .18116 .51219 L .17735 .51355 L p F P
0 g
s
.819 .71 .745 r
.13843 .37885 m .1347 .37676 L p .13447 .38622 L F P
0 g
s
.815 .714 .753 r
.13843 .37885 m .13585 .37535 L .1347 .37676 L closepath p F P
0 g
s
.848 .652 .637 r
.12591 .44651 m .1312 .44908 L .12924 .45477 L p F P
0 g
s
.842 .659 .654 r
.12824 .44071 m .12591 .44651 L .1312 .44908 L p F P
0 g
s
.841 .669 .67 r
.12824 .44071 m .12901 .43904 L .12593 .4323 L p F P
0 g
s
.646 .671 .859 r
.55444 .29245 m .55303 .29287 L .55433 .29229 L closepath p F P
0 g
s
.648 .678 .865 r
.5515 .28792 m .55433 .29229 L .55303 .29287 L p F P
0 g
s
.842 .516 .437 r
.15973 .49582 m .16061 .50028 L .1604 .50053 L p F P
0 g
s
.842 .516 .437 r
.15391 .49348 m .15973 .49582 L p .1604 .50053 L F P
0 g
s
.587 .556 .787 r
.64391 .34748 m .64282 .34486 L .64935 .3442 L closepath p F P
0 g
s
.549 .863 .996 r
.53177 .53986 m .53389 .54074 L .54505 .53797 L p F P
0 g
s
.512 .862 .991 r
.53389 .54074 m .53177 .53986 L .51982 .54227 L p F P
0 g
s
.645 .769 .938 r
.44945 .54544 m .46046 .54227 L .46352 .5451 L p F P
0 g
s
.659 .744 .913 r
.46046 .54227 m .44945 .54544 L .44637 .54249 L p F P
0 g
s
.76 .728 .823 r
.20711 .30792 m .20258 .31128 L .19919 .30714 L p F P
0 g
s
.83 .698 .718 r
.12501 .39932 m .13001 .40205 L .12591 .4084 L p F P
0 g
s
.826 .702 .727 r
.12773 .39537 m .12501 .39932 L .13001 .40205 L p F P
0 g
s
.807 .721 .769 r
.14651 .3629 m .1472 .36214 L .14377 .35771 L p F P
0 g
s
.097 0 0 r
.59887 .52463 m .59843 .52501 L .58719 .52845 L p F P
0 g
s
0 0 0 r
.58444 .52972 m .58719 .52845 L .59843 .52501 L p F P
0 g
s
.311 0 .128 r
.61201 .51821 m .61234 .51754 L .62358 .5128 L p F P
0 g
s
.365 .007 .217 r
.62427 .51087 m .62358 .5128 L .61234 .51754 L p F P
0 g
s
.606 .77 .958 r
.3057 .54409 m .31645 .5417 L .31974 .54435 L p F P
0 g
s
.635 .759 .937 r
.31645 .5417 m .3057 .54409 L .30238 .54167 L p F P
0 g
s
.644 .102 0 r
.20835 .52601 m .20166 .52399 L .19818 .52155 L p F P
0 g
s
.647 .11 0 r
.20166 .52399 m .19818 .52155 L .19449 .52176 L p F P
0 g
s
.81 .718 .763 r
.14162 .36009 m .14651 .3629 L .14047 .36987 L p F P
0 g
s
.807 .721 .769 r
.14377 .35771 m .14162 .36009 L .14651 .3629 L p F P
0 g
s
.128 .634 .902 r
.2368 .53465 m .24297 .53567 L .2395 .534 L p F P
0 g
s
.248 0 0 r
.2291 .53288 m .22927 .53291 L .2368 .53465 L p F P
0 g
s
.726 .733 .856 r
.23862 .29306 m .24404 .29001 L .24968 .29261 L p F P
0 g
s
.729 .737 .857 r
.24944 .28701 m .24404 .29001 L .24968 .29261 L p F P
0 g
s
.729 .737 .857 r
.24968 .29261 m .25279 .29084 L .24944 .28701 L p F P
0 g
s
.523 .398 .652 r
.67492 .44726 m .67372 .44094 L .67923 .43807 L p F P
0 g
s
.494 .311 .56 r
.66727 .46978 m .66207 .47216 L .66369 .47697 L p F P
0 g
s
.51 .343 .59 r
.66207 .47216 m .66727 .46978 L .66669 .46414 L p F P
0 g
s
.497 .312 .56 r
.65741 .4798 m .66369 .47697 L .66207 .47216 L p F P
0 g
s
.599 .581 .804 r
.63119 .31839 m .63409 .32475 L .62273 .32645 L p F P
0 g
s
.599 .581 .804 r
.62775 .3189 m .63119 .31839 L p .62273 .32645 L F P
0 g
s
.599 .581 .804 r
.62273 .32645 m .62109 .32288 L .62775 .3189 L p F P
0 g
s
.639 .779 .948 r
.46352 .5451 m .47456 .54201 L .47759 .54467 L p F P
0 g
s
.655 .753 .922 r
.47456 .54201 m .46352 .5451 L .46046 .54227 L p F P
0 g
s
.847 .621 .595 r
.13841 .47133 m .13795 .46781 L .1373 .47083 L closepath p F P
0 g
s
.656 .757 .924 r
.281 .28825 m .29174 .2847 L .29506 .28788 L p F P
0 g
s
.634 .763 .94 r
.29174 .2847 m .281 .28825 L .27768 .28475 L p F P
0 g
s
.689 .745 .894 r
.26692 .28926 m .27768 .28475 L .281 .28825 L p F P
0 g
s
.821 .707 .74 r
.12949 .38346 m .13447 .38622 L .12952 .39284 L p F P
0 g
s
.819 .71 .745 r
.1347 .37676 m .12949 .38346 L .13447 .38622 L p F P
0 g
s
.554 .473 .719 r
.67497 .40197 m .67287 .40182 L .67464 .40084 L closepath p F P
0 g
s
.561 .486 .728 r
.67228 .39319 m .67464 .40084 L .67287 .40182 L p F P
0 g
s
.679 .75 .904 r
.27768 .28475 m .26692 .28926 L .26358 .28555 L p F P
0 g
s
.709 .738 .874 r
.25279 .29084 m .26358 .28555 L .26692 .28926 L p F P
0 g
s
.575 .842 .995 r
.51982 .54227 m .51982 .54227 L p .50575 .54333 L F P
0 g
s
.554 .861 .997 r
.51982 .54227 m .51982 .54227 L .53177 .53986 L p F P
0 g
s
.554 .861 .997 r
.53177 .53986 m .53096 .53946 L .51982 .54227 L p F P
0 g
s
.615 .826 .981 r
.53096 .53946 m .51982 .54227 L .51686 .54047 L p F P
0 g
s
.575 .842 .995 r
.51982 .54227 m .51686 .54047 L .50575 .54333 L p F P
0 g
s
.478 .274 .524 r
.66369 .47697 m .65741 .4798 L .6575 .48492 L p F P
0 g
s
.833 .687 .702 r
.12207 .41466 m .12721 .41733 L .12368 .4235 L p F P
0 g
s
.831 .691 .709 r
.12721 .41733 m .12207 .41466 L .12591 .4084 L p F P
0 g
s
.64 .655 .848 r
.55444 .29245 m .56563 .28929 L .56856 .29421 L p F P
0 g
s
.643 .67 .861 r
.56442 .28735 m .56563 .28929 L .55444 .29245 L p F P
0 g
s
.643 .67 .861 r
.55444 .29245 m .55433 .29229 L .56442 .28735 L p F P
0 g
s
.631 .794 .96 r
.47759 .54467 m .48865 .54166 L .49167 .5441 L p F P
0 g
s
.649 .764 .933 r
.48865 .54166 m .47759 .54467 L .47456 .54201 L p F P
0 g
s
.5 .335 .589 r
.66727 .46978 m .66669 .46414 L .67675 .45926 L p F P
0 g
s
.513 .362 .613 r
.6761 .45452 m .67675 .45926 L .66669 .46414 L p F P
0 g
s
.513 .362 .613 r
.67511 .4538 m .6761 .45452 L p .66669 .46414 L F P
0 g
s
.846 .663 .655 r
.12304 .43809 m .12824 .44071 L .12591 .44651 L p F P
0 g
s
.841 .669 .67 r
.12571 .43219 m .12304 .43809 L .12824 .44071 L p F P
0 g
s
.841 .669 .67 r
.12593 .4323 m .12571 .43219 L p .12824 .44071 L F P
0 g
s
.587 .557 .788 r
.64935 .3442 m .64282 .34486 L .6399 .33791 L p F P
0 g
s
.596 .773 .964 r
.29506 .28788 m .30576 .2855 L .30908 .28818 L p F P
0 g
s
.536 .774 .986 r
.30576 .2855 m .29506 .28788 L .29174 .2847 L p F P
0 g
s
.76 .728 .823 r
.19919 .30714 m .20184 .30519 L .20711 .30792 L p F P
0 g
s
.76 .731 .826 r
.21012 .29918 m .20184 .30519 L .20711 .30792 L p F P
0 g
s
.76 .731 .826 r
.20711 .30792 m .21351 .30325 L .21012 .29918 L p F P
0 g
s
.645 .675 .863 r
.5627 .28464 m .56442 .28735 L .55433 .29229 L p F P
0 g
s
.645 .675 .863 r
.55433 .29229 m .5515 .28792 L .5627 .28464 L p F P
0 g
s
.619 .813 .975 r
.49167 .5441 m .50275 .54117 L .50575 .54333 L p F P
0 g
s
.642 .78 .947 r
.50275 .54117 m .49167 .5441 L .48865 .54166 L p F P
0 g
s
.632 .801 .964 r
.51686 .54047 m .50575 .54333 L .50275 .54117 L p F P
0 g
s
.354 .002 .222 r
.62358 .5128 m .62427 .51087 L .63497 .5069 L p F P
0 g
s
.414 .107 .333 r
.63587 .50281 m .63497 .5069 L .62427 .51087 L p F P
0 g
s
.631 .763 .942 r
.31974 .54435 m .33052 .54152 L .33378 .54438 L p F P
0 g
s
.653 .75 .921 r
.33052 .54152 m .31974 .54435 L .31645 .5417 L p F P
0 g
s
.48 .783 .998 r
.28275 .54198 m .28834 .54135 L p .27433 .54061 L F P
0 g
s
.48 .783 .998 r
.27433 .54061 m .2746 .54077 L .28275 .54198 L p F P
0 g
s
.609 .597 .814 r
.61692 .31409 m .6093 .31549 L .61579 .31174 L closepath p F P
0 g
s
.612 .605 .82 r
.61402 .30817 m .61579 .31174 L .6093 .31549 L p F P
0 g
s
.612 .605 .82 r
.6027 .31039 m .61402 .30817 L p .6093 .31549 L F P
0 g
s
.819 .446 .35 r
.17487 .50964 m .16877 .50741 L .16685 .50287 L p F P
0 g
s
.818 .441 .342 r
.1607 .50064 m .16685 .50287 L .16877 .50741 L p F P
0 g
s
.826 .493 .424 r
.16685 .50287 m .1607 .50064 L .16061 .50028 L p F P
0 g
s
.704 .742 .881 r
.26358 .28555 m .25279 .29084 L .24944 .28701 L p F P
0 g
s
.396 .09 .325 r
.64641 .49863 m .63587 .50281 L .63497 .5069 L p F P
0 g
s
.445 .181 .418 r
.64692 .49414 m .64641 .49863 L .63587 .50281 L p F P
0 g
s
.813 .716 .758 r
.14047 .36987 m .13585 .37535 L .13242 .37078 L p F P
0 g
s
.813 .716 .758 r
.13242 .37078 m .13553 .36708 L .14047 .36987 L p F P
0 g
s
.81 .718 .763 r
.14047 .36987 m .13553 .36708 L .14162 .36009 L p F P
0 g
s
.479 .772 .995 r
.32068 .28771 m .31833 .28726 L .30908 .28818 L p F P
0 g
s
.515 .743 .978 r
.31833 .28726 m .30908 .28818 L .30576 .2855 L p F P
0 g
s
.646 .755 .929 r
.33378 .54438 m .34461 .54122 L .34784 .54425 L p F P
0 g
s
.664 .742 .908 r
.34461 .54122 m .33378 .54438 L .33052 .54152 L p F P
0 g
s
.838 .677 .683 r
.12593 .4323 m .12579 .43203 L .12571 .43219 L closepath p F P
0 g
s
.16 0 0 r
.62284 .51443 m .61201 .51821 L .60988 .52107 L p F P
0 g
s
.311 0 .128 r
.62358 .5128 m .62284 .51443 L .61201 .51821 L p F P
0 g
s
.218 0 0 r
.61201 .51821 m .60988 .52107 L .59887 .52463 L p F P
0 g
s
.454 0 0 r
.20818 .52699 m .20166 .52399 L .20835 .52601 L p F P
0 g
s
.844 .6 .571 r
.14221 .47858 m .13845 .47699 L .13841 .47133 L p F P
0 g
s
.851 .607 .568 r
.1373 .47083 m .13841 .47133 L .13845 .47699 L p F P
0 g
s
.552 .481 .729 r
.67464 .40084 m .67228 .39319 L .67387 .39226 L p F P
0 g
s
.558 .493 .739 r
.67228 .39319 m .67195 .39219 L .67387 .39226 L closepath p F P
0 g
s
.558 .494 .739 r
.67387 .39226 m .67195 .39219 L .66971 .3853 L p F P
0 g
s
.694 .171 0 r
.19055 .51816 m .19449 .52176 L .19402 .52173 L p F P
0 g
s
.694 .171 0 r
.18413 .51604 m .19055 .51816 L p .19402 .52173 L F P
0 g
s
.84 .68 .684 r
.12571 .43219 m .12579 .43203 L .12251 .42573 L p F P
0 g
s
.603 .589 .81 r
.62109 .32288 m .61982 .32019 L .62775 .3189 L closepath p F P
0 g
s
.845 .673 .67 r
.12059 .42953 m .12571 .43219 L .12304 .43809 L p F P
0 g
s
.84 .68 .684 r
.12251 .42573 m .12059 .42953 L .12571 .43219 L p F P
0 g
s
.75 .732 .835 r
.22057 .29841 m .21351 .30325 L .21012 .29918 L p F P
0 g
s
.558 .494 .739 r
.66971 .3853 m .67327 .38318 L p .67387 .39226 L F P
0 g
s
.562 .504 .748 r
.66971 .3853 m .66896 .38311 L .67327 .38318 L closepath p F P
0 g
s
.622 .623 .83 r
.58562 .30171 m .59689 .29914 L .5998 .30463 L p F P
0 g
s
.624 .628 .834 r
.59398 .2937 m .59689 .29914 L .58562 .30171 L p F P
0 g
s
.624 .628 .834 r
.58842 .295 m .59398 .2937 L p .58562 .30171 L F P
0 g
s
.624 .628 .834 r
.58562 .30171 m .58345 .29771 L .58842 .295 L p F P
0 g
s
.416 .767 .995 r
.26659 .53885 m .26036 .53922 L .25693 .53747 L p F P
0 g
s
.296 .731 .968 r
.26036 .53922 m .26659 .53885 L .27399 .54063 L p F P
0 g
s
.613 .608 .822 r
.61111 .30238 m .61402 .30817 L .6027 .31039 L p F P
0 g
s
.613 .608 .822 r
.60254 .30407 m .61111 .30238 L p .6027 .31039 L F P
0 g
s
.613 .608 .822 r
.6027 .31039 m .6002 .30542 L .60254 .30407 L p F P
0 g
s
.547 .469 .719 r
.67464 .40084 m .68423 .39523 L p .68574 .4031 L F P
0 g
s
.547 .469 .719 r
.68574 .4031 m .67497 .40197 L .67464 .40084 L p F P
0 g
s
.552 .481 .729 r
.68353 .39298 m .68423 .39523 L .67464 .40084 L p F P
0 g
s
.552 .481 .729 r
.67387 .39226 m .68353 .39298 L p .67464 .40084 L F P
0 g
s
.562 .504 .749 r
.67327 .38318 m .66896 .38311 L .66693 .37716 L p F P
0 g
s
.661 .742 .91 r
.50921 .28705 m .52033 .28336 L .5233 .28679 L p F P
0 g
s
.661 .781 .938 r
.52033 .28336 m .50921 .28705 L .50622 .28423 L p F P
0 g
s
.657 .783 .941 r
.49513 .28785 m .50622 .28423 L .50921 .28705 L p F P
0 g
s
.638 .839 .977 r
.50622 .28423 m .49513 .28785 L .49212 .28578 L p F P
0 g
s
.63 .832 .978 r
.48105 .28915 m .49212 .28578 L .49513 .28785 L p F P
0 g
s
.547 .469 .719 r
.6768 .40825 m .67497 .40197 L .68574 .4031 L closepath p F P
0 g
s
.656 .749 .918 r
.34784 .54425 m .3587 .54085 L .3619 .54402 L p F P
0 g
s
.671 .735 .898 r
.3587 .54085 m .34784 .54425 L .34461 .54122 L p F P
0 g
s
.536 .432 .683 r
.68116 .42493 m .67741 .42414 L .68057 .42244 L closepath p F P
0 g
s
.545 .447 .695 r
.67878 .41546 m .68057 .42244 L .67741 .42414 L p F P
0 g
s
.821 .707 .74 r
.12952 .39284 m .1245 .3901 L .12949 .38346 L p F P
0 g
s
.825 .704 .731 r
.12952 .39284 m .12773 .39537 L .12432 .39034 L p F P
0 g
s
.825 .704 .731 r
.12432 .39034 m .1245 .3901 L .12952 .39284 L p F P
0 g
s
.787 .727 .797 r
.17134 .33031 m .16613 .33508 L .1627 .33085 L p F P
0 g
s
.792 .728 .792 r
.16299 .33807 m .16613 .33508 L .1627 .33085 L p F P
0 g
s
.787 .727 .797 r
.1627 .33085 m .16638 .32749 L .17134 .33031 L p F P
0 g
s
.785 .728 .8 r
.17378 .32087 m .16638 .32749 L .17134 .33031 L p F P
0 g
s
.785 .728 .8 r
.17134 .33031 m .1772 .32507 L .17378 .32087 L p F P
0 g
s
.562 .504 .749 r
.66693 .37716 m .67133 .3745 L p .67327 .38318 L F P
0 g
s
.566 .514 .757 r
.66693 .37716 m .66599 .37454 L .67133 .3745 L closepath p F P
0 g
s
.833 .694 .71 r
.12088 .40568 m .12591 .4084 L .12207 .41466 L p F P
0 g
s
.83 .698 .718 r
.12591 .4084 m .12088 .40568 L .12501 .39932 L p F P
0 g
s
.791 .726 .791 r
.1581 .33523 m .16299 .33807 L .15522 .34562 L p F P
0 g
s
.792 .728 .792 r
.1627 .33085 m .1581 .33523 L .16299 .33807 L p F P
0 g
s
.779 .728 .805 r
.18042 .32231 m .1772 .32507 L .17378 .32087 L p F P
0 g
s
.658 .712 .888 r
.5233 .28679 m .53444 .28317 L .53739 .28709 L p F P
0 g
s
.662 .738 .906 r
.53444 .28317 m .5233 .28679 L .52033 .28336 L p F P
0 g
s
.587 .878 .993 r
.47917 .28836 m .48105 .28915 L .49212 .28578 L p F P
0 g
s
.598 .861 .993 r
.48105 .28915 m .47917 .28836 L .46711 .29089 L p F P
0 g
s
.722 .733 .86 r
.24404 .29001 m .23862 .29306 L .23526 .2891 L p F P
0 g
s
.739 .732 .846 r
.2244 .29583 m .23526 .2891 L .23862 .29306 L p F P
0 g
s
.851 .607 .568 r
.13845 .47699 m .13657 .47615 L .1373 .47083 L p F P
0 g
s
.854 .61 .568 r
.13186 .46833 m .1373 .47083 L .13657 .47615 L p F P
0 g
s
.848 .622 .596 r
.13303 .46288 m .13186 .46833 L .1373 .47083 L p F P
0 g
s
.35 .821 .898 r
.46574 .29112 m .46695 .29085 L p .45285 .29307 L F P
0 g
s
.481 .859 .983 r
.46695 .29085 m .46574 .29112 L .46711 .29089 L closepath p F P
0 g
s
.411 0 0 r
.37193 .29648 m .36663 .29593 L .36837 .29554 L closepath p F P
0 g
s
.662 .743 .91 r
.3619 .54402 m .37279 .54046 L .37597 .54375 L p F P
0 g
s
.675 .729 .891 r
.37279 .54046 m .3619 .54402 L .3587 .54085 L p F P
0 g
s
.844 .578 .536 r
.14776 .48613 m .14199 .48375 L .14221 .47858 L p F P
0 g
s
.846 .58 .536 r
.13845 .47699 m .14221 .47858 L .14199 .48375 L p F P
0 g
s
.779 .728 .805 r
.17378 .32087 m .17538 .31951 L .18042 .32231 L p F P
0 g
s
.777 .73 .808 r
.18481 .31161 m .17538 .31951 L .18042 .32231 L p F P
0 g
s
.777 .73 .808 r
.18042 .32231 m .18822 .31576 L .18481 .31161 L p F P
0 g
s
.542 .457 .709 r
.6768 .40825 m .68574 .4031 L p .68246 .41336 L F P
0 g
s
.542 .457 .709 r
.68246 .41336 m .67803 .41273 L .6768 .40825 L p F P
0 g
s
.592 .562 .789 r
.6399 .33791 m .63975 .33793 L .63988 .33785 L closepath p F P
0 g
s
.596 .57 .794 r
.637 .33127 m .63988 .33785 L .63975 .33793 L p F P
0 g
s
.566 .515 .757 r
.67133 .3745 m .66599 .37454 L .66393 .36876 L p F P
0 g
s
.817 .717 .754 r
.1347 .37676 m .13585 .37535 L .13242 .37078 L p F P
0 g
s
.513 .379 .635 r
.67595 .45338 m .67492 .44726 L .68481 .44212 L p F P
0 g
s
.523 .398 .652 r
.68442 .4401 m .68481 .44212 L .67492 .44726 L p F P
0 g
s
.523 .398 .652 r
.67923 .43807 m .68442 .4401 L p .67492 .44726 L F P
0 g
s
.522 .385 .635 r
.67511 .4538 m .67595 .45338 L .67492 .44726 L p F P
0 g
s
.431 .17 .415 r
.65732 .48976 m .64692 .49414 L .64641 .49863 L p F P
0 g
s
.465 .234 .479 r
.6575 .48492 m .65732 .48976 L .64692 .49414 L p F P
0 g
s
.849 .639 .618 r
.13303 .46288 m .12765 .46034 L .12924 .45477 L p F P
0 g
s
.853 .627 .595 r
.12765 .46034 m .13303 .46288 L .13186 .46833 L p F P
0 g
s
.587 .557 .788 r
.6399 .33791 m .65133 .3368 L p .64935 .3442 L F P
0 g
s
.585 .558 .79 r
.6493 .33197 m .65133 .3368 L .6399 .33791 L p F P
0 g
s
.585 .558 .79 r
.6399 .33791 m .63988 .33785 L .6493 .33197 L p F P
0 g
s
.589 .567 .797 r
.64842 .32997 m .6493 .33197 L .63988 .33785 L p F P
0 g
s
.589 .567 .797 r
.63988 .33785 m .637 .33127 L .64842 .32997 L p F P
0 g
s
.635 .65 .848 r
.57979 .29127 m .56856 .29421 L .56563 .28929 L p F P
0 g
s
.633 .644 .843 r
.56856 .29421 m .57979 .29127 L .5827 .29637 L p F P
0 g
s
.797 .723 .782 r
.155 .34585 m .15522 .34562 L .1545 .34522 L closepath p F P
0 g
s
.791 .726 .791 r
.15156 .34158 m .1581 .33523 L p .15522 .34562 L F P
0 g
s
.791 .726 .791 r
.15522 .34562 m .1545 .34522 L .15156 .34158 L p F P
0 g
s
.802 .724 .778 r
.14824 .35291 m .155 .34585 L .1545 .34522 L p F P
0 g
s
0 .52 .775 r
.32591 .28918 m .33405 .29091 L p .33373 .29055 L F P
0 g
s
0 .52 .775 r
.33293 .29038 m .32591 .28918 L p .33373 .29055 L F P
0 g
s
0 .52 .775 r
.3337 .29051 m .33293 .29038 L p .33373 .29055 L F P
0 g
s
.375 0 0 r
.32591 .28918 m .3337 .29051 L .33281 .29062 L p F P
0 g
s
.375 0 0 r
.32068 .28771 m .32591 .28918 L p .32594 .28919 L F P
0 g
s
.375 0 0 r
.33281 .29062 m .32279 .28822 L .32594 .28919 L F
.32279 .28822 m .32068 .28771 L .32594 .28919 L F
.49 .754 .988 r
.32309 .28917 m .32591 .28918 L .33405 .29091 L p F P
0 g
s
.365 .727 .988 r
.32591 .28918 m .32068 .28771 L .32309 .28917 L closepath p F P
0 g
s
.375 0 0 r
.31975 .28727 m .32068 .28771 L p .33281 .29062 L F P
0 g
s
.309 .728 .975 r
.31975 .28727 m .31833 .28726 L .32068 .28771 L closepath p F P
0 g
s
.058 .59 .862 r
.31833 .28726 m .31975 .28727 L .31636 .28623 L p F P
0 g
s
.22 0 0 r
.32653 .28941 m .32103 .28767 L p .31636 .28623 L F P
0 g
s
.22 0 0 r
.32103 .28767 m .31975 .28727 L .31692 .2864 L p F P
0 g
s
.22 0 0 r
.31692 .2864 m .31636 .28623 L p .32103 .28767 L F P
0 g
s
.375 0 0 r
.33281 .29062 m .32653 .28941 L .32337 .28841 L p F P
0 g
s
.375 0 0 r
.32337 .28841 m .31975 .28727 L p .32766 .2893 L F P
0 g
s
.375 0 0 r
.33281 .29062 m .32337 .28841 L .32766 .2893 L F
.511 .872 .985 r
.46695 .29085 m .46711 .29089 L .47917 .28836 L p F P
0 g
s
.795 .363 .221 r
.17487 .50964 m .17735 .51355 L .17686 .51365 L p F P
0 g
s
.795 .363 .221 r
.16877 .50741 m .17487 .50964 L p .17686 .51365 L F P
0 g
s
.603 .591 .812 r
.62775 .3189 m .61982 .32019 L .61692 .31409 L p F P
0 g
s
.82 .713 .747 r
.12983 .37395 m .1347 .37676 L .12949 .38346 L p F P
0 g
s
.817 .717 .754 r
.13242 .37078 m .12983 .37395 L .1347 .37676 L p F P
0 g
s
.665 .739 .905 r
.37597 .54375 m .38689 .54009 L .39005 .54346 L p F P
0 g
s
.676 .725 .886 r
.38689 .54009 m .37597 .54375 L .37279 .54046 L p F P
0 g
s
.844 .551 .492 r
.15391 .49348 m .14812 .49112 L .14776 .48613 L p F P
0 g
s
.846 .552 .491 r
.14199 .48375 m .14776 .48613 L .14812 .49112 L p F P
0 g
s
0 0 0 r
.58444 .52972 m .58083 .53073 L .57318 .53288 L p F P
0 g
s
.28 .781 .78 r
.58083 .53073 m .57311 .53289 L .57318 .53288 L closepath p F P
0 g
s
0 .496 .762 r
.22927 .53291 m .22896 .53284 L .2291 .53288 L closepath p F P
0 g
s
.828 .704 .728 r
.12501 .39932 m .12773 .39537 L .12432 .39034 L p F P
0 g
s
.42 .757 .995 r
.27433 .54061 m .27399 .54063 L .2746 .54077 L closepath p F P
0 g
s
.77 .729 .815 r
.19045 .31398 m .18822 .31576 L .18481 .31161 L p F P
0 g
s
.551 .482 .731 r
.68353 .39298 m .67387 .39226 L .68183 .38752 L closepath p F P
0 g
s
.558 .494 .739 r
.68052 .38352 m .68183 .38752 L .67387 .39226 L p F P
0 g
s
.558 .494 .739 r
.67327 .38318 m .68052 .38352 L p .67387 .39226 L F P
0 g
s
.851 .642 .619 r
.12393 .4522 m .12924 .45477 L .12765 .46034 L p F P
0 g
s
.848 .652 .637 r
.12924 .45477 m .12393 .4522 L .12591 .44651 L p F P
0 g
s
.323 .712 .981 r
.22927 .53291 m .2395 .534 L .23621 .53215 L p F P
0 g
s
.323 .712 .981 r
.22896 .53284 m .22927 .53291 L p .23621 .53215 L F P
0 g
s
.542 .457 .708 r
.67878 .41546 m .67803 .41273 L .68246 .41336 L closepath p F P
0 g
s
.838 .681 .687 r
.12251 .42573 m .12368 .4235 L .12046 .42184 L closepath p F P
0 g
s
.833 .687 .702 r
.1192 .41967 m .12207 .41466 L p .12368 .4235 L F P
0 g
s
.833 .687 .702 r
.12368 .4235 m .12046 .42184 L .1192 .41967 L p F P
0 g
s
.511 .872 .985 r
.478 .28815 m .46695 .29085 L p .47081 .29006 L F P
0 g
s
.511 .872 .985 r
.47917 .28836 m .478 .28815 L p .47081 .29006 L F P
0 g
s
.481 .88 .957 r
.48909 .28515 m .478 .28815 L p .48187 .28729 L F P
0 g
s
.481 .88 .957 r
.49081 .2853 m .48909 .28515 L p .48187 .28729 L F P
0 g
s
.47 .884 .931 r
.50022 .2817 m .48909 .28515 L p .49301 .28414 L F P
0 g
s
.47 .884 .931 r
.5021 .28182 m .50022 .2817 L p .49301 .28414 L F P
0 g
s
.49 .896 .925 r
.51139 .27776 m .50022 .2817 L p .50411 .28056 L F P
0 g
s
.49 .896 .925 r
.51308 .27792 m .51139 .27776 L p .50411 .28056 L F P
0 g
s
.539 .916 .94 r
.52373 .27359 m .52259 .27337 L .51139 .27776 L p F P
0 g
s
0 0 0 r
.51139 .27776 m .52259 .27337 L p .51903 .27482 L F P
0 g
s
.539 .916 .94 r
.51139 .27776 m .51308 .27792 L .52373 .27359 L p F P
0 g
s
0 0 0 r
.50941 .27874 m .51139 .27776 L p .51903 .27482 L F P
0 g
s
0 0 0 r
.50022 .2817 m .51139 .27776 L p .50737 .27928 L F P
0 g
s
.49 .896 .925 r
.50022 .2817 m .5021 .28182 L .51308 .27792 L p F P
0 g
s
0 0 0 r
.49842 .28266 m .50022 .2817 L p .50737 .27928 L F P
0 g
s
0 0 0 r
.48909 .28515 m .50022 .2817 L p .49667 .2829 L F P
0 g
s
.481 .88 .957 r
.478 .28815 m .47917 .28836 L .49081 .2853 L p F P
0 g
s
.47 .884 .931 r
.48909 .28515 m .49081 .2853 L .5021 .28182 L p F P
0 g
s
0 0 0 r
.48708 .28614 m .48909 .28515 L p .49667 .2829 L F P
0 g
s
0 0 0 r
.478 .28815 m .48909 .28515 L p .48674 .28583 L F P
0 g
s
0 0 0 r
.47536 .28915 m .478 .28815 L p .48674 .28583 L F P
0 g
s
.084 0 0 r
.46695 .29085 m .478 .28815 L .47536 .28915 L p F P
0 g
s
.35 .821 .898 r
.46695 .29085 m .46387 .29136 L .45285 .29307 L p F P
0 g
s
.084 0 0 r
.46387 .29136 m .46695 .29085 L p .47536 .28915 L F P
0 g
s
.398 .852 .893 r
.57034 .53282 m .57311 .53289 L .58083 .53073 L p F P
0 g
s
.361 .831 .874 r
.57311 .53289 m .57034 .53282 L .55913 .53583 L p F P
0 g
s
.566 .515 .757 r
.66393 .36876 m .66803 .36624 L p .67133 .3745 L F P
0 g
s
.569 .524 .765 r
.66393 .36876 m .66304 .36637 L .66803 .36624 L closepath p F P
0 g
s
.75 .732 .835 r
.21012 .29918 m .21529 .29568 L .22057 .29841 L p F P
0 g
s
.75 .734 .837 r
.22102 .29186 m .21529 .29568 L .22057 .29841 L p F P
0 g
s
.75 .734 .837 r
.22057 .29841 m .2244 .29583 L .22102 .29186 L p F P
0 g
s
.323 .712 .981 r
.22557 .53166 m .22896 .53284 L p .23621 .53215 L F P
0 g
s
0 .485 .78 r
.22557 .53166 m .22249 .53093 L .22896 .53284 L closepath p F P
0 g
s
.656 .706 .884 r
.54856 .28362 m .53739 .28709 L .53444 .28317 L p F P
0 g
s
.652 .689 .872 r
.53739 .28709 m .54856 .28362 L .5515 .28792 L p F P
0 g
s
.489 .768 .993 r
.27399 .54063 m .27433 .54061 L .27094 .53845 L p F P
0 g
s
.489 .768 .993 r
.27094 .53845 m .26659 .53885 L .27399 .54063 L p F P
0 g
s
.667 .736 .902 r
.39005 .54346 m .40098 .53977 L .40412 .54318 L p F P
0 g
s
.677 .721 .883 r
.40098 .53977 m .39005 .54346 L .38689 .54009 L p F P
0 g
s
.77 .729 .815 r
.18481 .31161 m .18532 .31121 L .19045 .31398 L p F P
0 g
s
.769 .731 .818 r
.19579 .30304 m .18532 .31121 L .19045 .31398 L p F P
0 g
s
.769 .731 .818 r
.19045 .31398 m .19919 .30714 L .19579 .30304 L p F P
0 g
s
.802 .724 .778 r
.1545 .34522 m .15037 .34277 L p .14824 .35291 L F P
0 g
s
.799 .727 .784 r
.1545 .34522 m .15156 .34158 L .15037 .34277 L closepath p F P
0 g
s
.535 .442 .696 r
.68057 .42244 m .67878 .41546 L .68246 .41336 L p F P
0 g
s
.48 .783 .998 r
.28834 .54135 m .28499 .53889 L .27433 .54061 L p F P
0 g
s
.6 .765 .958 r
.28499 .53889 m .27433 .54061 L .27094 .53845 L p F P
0 g
s
.805 .723 .774 r
.14824 .35291 m .14377 .35771 L .14032 .35333 L p F P
0 g
s
.805 .723 .774 r
.14032 .35333 m .14336 .35008 L .14824 .35291 L p F P
0 g
s
.802 .724 .778 r
.15037 .34277 m .14336 .35008 L .14824 .35291 L p F P
0 g
s
.569 .525 .766 r
.66803 .36624 m .66304 .36637 L .66069 .36007 L p F P
0 g
s
.842 .516 .437 r
.1604 .50053 m .15489 .4983 L .15391 .49348 L p F P
0 g
s
.843 .516 .433 r
.14812 .49112 m .15391 .49348 L .15489 .4983 L p F P
0 g
s
.666 .735 .902 r
.40412 .54318 m .41508 .5395 L .4182 .54293 L p F P
0 g
s
.676 .719 .882 r
.41508 .5395 m .40412 .54318 L .40098 .53977 L p F P
0 g
s
.85 .655 .639 r
.12069 .4439 m .12591 .44651 L .12393 .4522 L p F P
0 g
s
.846 .663 .655 r
.12591 .44651 m .12069 .4439 L .12304 .43809 L p F P
0 g
s
.072 0 0 r
.59843 .52501 m .59887 .52463 L .60988 .52107 L p F P
0 g
s
.738 .735 .848 r
.23526 .2891 m .2244 .29583 L .22102 .29186 L p F P
0 g
s
.722 .733 .86 r
.23526 .2891 m .23833 .28743 L .24404 .29001 L p F P
0 g
s
.726 .739 .862 r
.24608 .28323 m .23833 .28743 L .24404 .29001 L p F P
0 g
s
.726 .739 .862 r
.24404 .29001 m .24944 .28701 L .24608 .28323 L p F P
0 g
s
.483 .302 .559 r
.66763 .47517 m .66727 .46978 L .67734 .46491 L p F P
0 g
s
.5 .335 .589 r
.67675 .45926 m .67734 .46491 L .66727 .46978 L p F P
0 g
s
.494 .311 .56 r
.66369 .47697 m .66763 .47517 L .66727 .46978 L p F P
0 g
s
.665 .736 .903 r
.4182 .54293 m .42919 .53929 L .43229 .5427 L p F P
0 g
s
.674 .719 .883 r
.42919 .53929 m .4182 .54293 L .41508 .5395 L p F P
0 g
s
.809 .723 .77 r
.14162 .36009 m .14377 .35771 L .14032 .35333 L p F P
0 g
s
.842 .681 .683 r
.12059 .42953 m .12251 .42573 L .12046 .42184 L p F P
0 g
s
.627 .634 .838 r
.58345 .29771 m .5827 .29637 L .58842 .295 L closepath p F P
0 g
s
.832 .702 .72 r
.12007 .39655 m .12501 .39932 L .12088 .40568 L p F P
0 g
s
.828 .704 .728 r
.12432 .39034 m .12007 .39655 L .12501 .39932 L p F P
0 g
s
.602 .196 .246 r
.39695 .29766 m .40831 .29759 L p .40912 .30046 L F P
0 g
s
.602 .196 .246 r
.39643 .2981 m .39695 .29766 L p .40912 .30046 L F P
0 g
s
.539 .054 .053 r
.39643 .2981 m .39499 .29762 L .39695 .29766 L closepath p F P
0 g
s
.76 .73 .825 r
.20184 .30519 m .19919 .30714 L .19579 .30304 L p F P
0 g
s
.09 0 0 r
.45096 .29397 m .45285 .29307 L .46387 .29136 L p F P
0 g
s
.471 0 0 r
.38307 .29718 m .38211 .29713 L .38239 .29699 L closepath p F P
0 g
s
.182 0 0 r
.38239 .29699 m .38307 .29718 L .39499 .29762 L p F P
0 g
s
.829 .494 .421 r
.1607 .50064 m .1604 .50053 L .16061 .50028 L closepath p F P
0 g
s
.618 .2 .228 r
.39499 .29762 m .39643 .2981 L .39479 .30051 L p F P
0 g
s
.618 .2 .228 r
.38307 .29718 m .39499 .29762 L p .39479 .30051 L F P
0 g
s
.295 0 .135 r
.62284 .51443 m .62358 .5128 L .63482 .50735 L p F P
0 g
s
.354 .002 .222 r
.63497 .5069 m .63482 .50735 L .62358 .5128 L p F P
0 g
s
.616 .615 .827 r
.6002 .30542 m .5998 .30463 L .60254 .30407 L closepath p F P
0 g
s
.521 .045 .067 r
.41051 .2982 m .40831 .29759 L .41119 .29755 L closepath p F P
0 g
s
.602 .196 .246 r
.40831 .29759 m .41051 .2982 L .40912 .30046 L p F P
0 g
s
.577 .172 .239 r
.41119 .29755 m .42368 .29689 L p .42292 .29984 L F P
0 g
s
.577 .172 .239 r
.41051 .2982 m .41119 .29755 L p .42292 .29984 L F P
0 g
s
.811 .721 .765 r
.1368 .35724 m .14162 .36009 L .13553 .36708 L p F P
0 g
s
.809 .723 .77 r
.14032 .35333 m .1368 .35724 L .14162 .36009 L p F P
0 g
s
.573 .534 .773 r
.66069 .36007 m .6601 .35855 L .66337 .3584 L closepath p F P
0 g
s
.569 .525 .766 r
.66069 .36007 m .66337 .3584 L p .66803 .36624 L F P
0 g
s
.671 .72 .886 r
.44329 .53914 m .43229 .5427 L .42919 .53929 L p F P
0 g
s
.662 .739 .907 r
.43229 .5427 m .44329 .53914 L .44637 .54249 L p F P
0 g
s
.576 .857 .996 r
.53096 .53946 m .53177 .53986 L .54362 .5373 L p F P
0 g
s
.549 .863 .996 r
.54505 .53797 m .54362 .5373 L .53177 .53986 L p F P
0 g
s
.648 .683 .869 r
.5627 .28464 m .5515 .28792 L .54856 .28362 L p F P
0 g
s
.821 .712 .744 r
.12459 .38067 m .12949 .38346 L .1245 .3901 L p F P
0 g
s
.82 .713 .747 r
.12949 .38346 m .12459 .38067 L .12983 .37395 L p F P
0 g
s
.51 .36 .613 r
.6761 .45452 m .67511 .4538 L .67595 .45338 L closepath p F P
0 g
s
.533 .881 .985 r
.57034 .53282 m .55913 .53583 L .55624 .53503 L p F P
0 g
s
.511 .877 .98 r
.54505 .53797 m .55624 .53503 L .55913 .53583 L p F P
0 g
s
.606 .766 .956 r
.28834 .54135 m .29907 .53896 L .30238 .54167 L p F P
0 g
s
.634 .757 .936 r
.29907 .53896 m .28834 .54135 L .28499 .53889 L p F P
0 g
s
.837 .689 .699 r
.12207 .41466 m .1192 .41967 L .11585 .41398 L p F P
0 g
s
.837 .689 .699 r
.11585 .41398 m .11701 .41196 L .12207 .41466 L p F P
0 g
s
.833 .694 .71 r
.12207 .41466 m .11701 .41196 L .12088 .40568 L p F P
0 g
s
.76 .73 .825 r
.19579 .30304 m .19662 .30243 L .20184 .30519 L p F P
0 g
s
.76 .733 .828 r
.20672 .29515 m .19662 .30243 L .20184 .30519 L p F P
0 g
s
.76 .733 .828 r
.20184 .30519 m .21012 .29918 L .20672 .29515 L p F P
0 g
s
.818 .441 .341 r
.1604 .50053 m .1607 .50064 L .16268 .50516 L p F P
0 g
s
.818 .441 .342 r
.16877 .50741 m .16268 .50516 L .1607 .50064 L p F P
0 g
s
.848 .666 .656 r
.11789 .43544 m .12304 .43809 L .12069 .4439 L p F P
0 g
s
.845 .673 .67 r
.12304 .43809 m .11789 .43544 L .12059 .42953 L p F P
0 g
s
.529 .427 .683 r
.68057 .42244 m .69024 .41695 L p .68708 .42646 L F P
0 g
s
.529 .427 .683 r
.68708 .42646 m .68116 .42493 L .68057 .42244 L p F P
0 g
s
.535 .442 .696 r
.68969 .41481 m .69024 .41695 L .68057 .42244 L p F P
0 g
s
.535 .442 .696 r
.68246 .41336 m .68969 .41481 L p .68057 .42244 L F P
0 g
s
.521 .398 .653 r
.68442 .4401 m .67923 .43807 L .68358 .43577 L closepath p F P
0 g
s
.531 .416 .668 r
.68217 .42921 m .68358 .43577 L .67923 .43807 L p F P
0 g
s
.573 .535 .774 r
.66337 .3584 m .6601 .35855 L .6572 .35108 L p F P
0 g
s
.616 .62 .831 r
.60254 .30407 m .5998 .30463 L .59689 .29914 L p F P
0 g
s
.582 .549 .783 r
.65425 .34379 m .64935 .3442 L .6534 .34171 L closepath p F P
0 g
s
.587 .557 .788 r
.65133 .3368 m .6534 .34171 L .64935 .3442 L p F P
0 g
s
.589 .568 .798 r
.64551 .32334 m .64842 .32997 L .637 .33127 L p F P
0 g
s
.589 .568 .798 r
.64175 .32377 m .64551 .32334 L p .637 .33127 L F P
0 g
s
.589 .568 .798 r
.637 .33127 m .63545 .32775 L .64175 .32377 L p F P
0 g
s
.478 .274 .524 r
.6575 .48492 m .66283 .48253 L .66369 .47697 L p F P
0 g
s
.453 .225 .478 r
.66283 .48253 m .6575 .48492 L .65732 .48976 L p F P
0 g
s
.353 0 0 r
.20166 .52399 m .20818 .52699 L .20785 .52688 L p F P
0 g
s
.353 0 0 r
.19488 .52199 m .20166 .52399 L p .20785 .52688 L F P
0 g
s
.647 .11 0 r
.19449 .52176 m .19488 .52199 L .20166 .52399 L p F P
0 g
s
.818 .441 .341 r
.16268 .50516 m .15669 .50295 L .1604 .50053 L p F P
0 g
s
.834 .467 .36 r
.15489 .4983 m .1604 .50053 L .15669 .50295 L p F P
0 g
s
.659 .744 .913 r
.44637 .54249 m .4574 .53901 L .46046 .54227 L p F P
0 g
s
.668 .724 .891 r
.4574 .53901 m .44637 .54249 L .44329 .53914 L p F P
0 g
s
.618 .2 .228 r
.39479 .30051 m .38853 .30032 L .38307 .29718 L p F P
0 g
s
.62 .187 .197 r
.38211 .29713 m .38307 .29718 L .38853 .30032 L p F P
0 g
s
.555 .493 .741 r
.68052 .38352 m .67327 .38318 L .67923 .37958 L closepath p F P
0 g
s
.562 .504 .749 r
.67753 .37463 m .67923 .37958 L .67327 .38318 L p F P
0 g
s
.562 .504 .749 r
.67133 .3745 m .67753 .37463 L p .67327 .38318 L F P
0 g
s
.846 .58 .536 r
.14199 .48375 m .13763 .48191 L .13845 .47699 L p F P
0 g
s
.854 .588 .536 r
.13657 .47615 m .13845 .47699 L .13763 .48191 L p F P
0 g
s
.474 .27 .523 r
.66763 .47517 m .66369 .47697 L .66283 .48253 L p F P
0 g
s
.62 .187 .197 r
.38853 .30032 m .37981 .29987 L .38211 .29713 L p F P
0 g
s
.63 .197 .202 r
.37193 .29648 m .38211 .29713 L .37981 .29987 L p F P
0 g
s
.627 .641 .845 r
.58842 .295 m .5827 .29637 L .57979 .29127 L p F P
0 g
s
.694 .171 0 r
.19402 .52173 m .18858 .51983 L .18413 .51604 L p F P
0 g
s
.675 .14 0 r
.17768 .51392 m .18413 .51604 L .18858 .51983 L p F P
0 g
s
.77 .33 .207 r
.17735 .51355 m .17768 .51392 L .18413 .51604 L p F P
0 g
s
.634 .763 .94 r
.27768 .28475 m .28839 .2817 L .29174 .2847 L p F P
0 g
s
.603 .766 .958 r
.28839 .2817 m .27768 .28475 L .27434 .28135 L p F P
0 g
s
.679 .75 .904 r
.26358 .28555 m .27434 .28135 L .27768 .28475 L p F P
0 g
s
.667 .754 .915 r
.27434 .28135 m .26358 .28555 L .26023 .28191 L p F P
0 g
s
.704 .742 .881 r
.24944 .28701 m .26023 .28191 L .26358 .28555 L p F P
0 g
s
.501 .354 .613 r
.67595 .45338 m .68583 .44823 L p .67989 .45765 L F P
0 g
s
.501 .354 .613 r
.67989 .45765 m .6761 .45452 L .67595 .45338 L p F P
0 g
s
.513 .379 .635 r
.68481 .44212 m .68583 .44823 L .67595 .45338 L p F P
0 g
s
.072 0 0 r
.60988 .52107 m .60969 .52124 L .59843 .52501 L p F P
0 g
s
0 0 0 r
.60969 .52124 m .59843 .52501 L .59567 .52633 L p F P
0 g
s
0 0 0 r
.59843 .52501 m .59567 .52633 L p .58444 .52972 L F P
0 g
s
.529 .427 .683 r
.68217 .42921 m .68116 .42493 L .68708 .42646 L closepath p F P
0 g
s
.655 .753 .922 r
.46046 .54227 m .47151 .5389 L .47456 .54201 L p F P
0 g
s
.664 .73 .899 r
.47151 .5389 m .46046 .54227 L .4574 .53901 L p F P
0 g
s
.473 0 .02 r
.42462 .29705 m .42368 .29689 L .42487 .29682 L closepath p F P
0 g
s
.577 .172 .239 r
.42368 .29689 m .42462 .29705 L .42292 .29984 L p F P
0 g
s
.24 0 0 r
.45096 .29397 m .44249 .29504 L .43874 .29523 L p F P
0 g
s
.28 0 0 r
.44249 .29504 m .43813 .29564 L .43874 .29523 L closepath p F P
0 g
s
.075 0 0 r
.43874 .29523 m .43813 .29564 L .42487 .29682 L p F P
0 g
s
.603 .591 .812 r
.61692 .31409 m .62828 .31225 L p .62775 .3189 L F P
0 g
s
.603 .594 .815 r
.62538 .30617 m .62828 .31225 L .61692 .31409 L p F P
0 g
s
.603 .594 .815 r
.62464 .30629 m .62538 .30617 L p .61692 .31409 L F P
0 g
s
.603 .594 .815 r
.61692 .31409 m .61579 .31174 L .62464 .30629 L p F P
0 g
s
.656 .748 .918 r
.31316 .53876 m .30238 .54167 L .29907 .53896 L p F P
0 g
s
.635 .759 .937 r
.30238 .54167 m .31316 .53876 L .31645 .5417 L p F P
0 g
s
.535 .12 .2 r
.42487 .29682 m .43813 .29564 L .4362 .29865 L p F P
0 g
s
.535 .12 .2 r
.42462 .29705 m .42487 .29682 L p .4362 .29865 L F P
0 g
s
.842 .681 .683 r
.12046 .42184 m .11856 .42083 L p .12059 .42953 L F P
0 g
s
.839 .689 .696 r
.12046 .42184 m .1192 .41967 L .11856 .42083 L closepath p F P
0 g
s
.574 .862 .996 r
.54362 .5373 m .54505 .53797 L .55624 .53503 L p F P
0 g
s
.815 .718 .759 r
.13553 .36708 m .13242 .37078 L .12897 .36627 L p F P
0 g
s
.815 .718 .759 r
.12897 .36627 m .13066 .36425 L .13553 .36708 L p F P
0 g
s
.811 .721 .765 r
.13553 .36708 m .13066 .36425 L .1368 .35724 L p F P
0 g
s
.399 .743 .993 r
.25587 .53684 m .25103 .53552 L .24297 .53567 L p F P
0 g
s
.359 .747 .987 r
.25103 .53552 m .24297 .53567 L .2395 .534 L p F P
0 g
s
.699 .745 .887 r
.26023 .28191 m .24944 .28701 L .24608 .28323 L p F P
0 g
s
.536 .774 .986 r
.29174 .2847 m .30241 .2831 L .30576 .2855 L p F P
0 g
s
.463 .757 .993 r
.29174 .2847 m .30241 .2831 L .30093 .28217 L p F P
0 g
s
.463 .757 .993 r
.28839 .2817 m .29174 .2847 L p .30093 .28217 L F P
0 g
s
.649 .764 .933 r
.47456 .54201 m .48563 .53874 L .48865 .54166 L p F P
0 g
s
.66 .739 .908 r
.48563 .53874 m .47456 .54201 L .47151 .5389 L p F P
0 g
s
.502 .354 .612 r
.67675 .45926 m .6761 .45452 L .67989 .45765 L closepath p F P
0 g
s
.602 .196 .246 r
.40912 .30046 m .40118 .30053 L .39643 .2981 L p F P
0 g
s
.603 .189 .228 r
.40118 .30053 m .39479 .30051 L .39643 .2981 L closepath p F P
0 g
s
.847 .677 .671 r
.11553 .42684 m .12059 .42953 L .11789 .43544 L p F P
0 g
s
.842 .681 .683 r
.11856 .42083 m .11553 .42684 L .12059 .42953 L p F P
0 g
s
.63 .197 .202 r
.37981 .29987 m .37714 .2997 L .37193 .29648 L p F P
0 g
s
.672 .277 .29 r
.36663 .29593 m .37193 .29648 L .37714 .2997 L p F P
0 g
s
.593 .577 .804 r
.63545 .32775 m .63409 .32475 L .64175 .32377 L closepath p F P
0 g
s
.749 .733 .838 r
.21529 .29568 m .21012 .29918 L .20672 .29515 L p F P
0 g
s
.642 .78 .947 r
.48865 .54166 m .49975 .5385 L .50275 .54117 L p F P
0 g
s
.655 .752 .921 r
.49975 .5385 m .48865 .54166 L .48563 .53874 L p F P
0 g
s
.653 .75 .921 r
.31645 .5417 m .32727 .53838 L .33052 .54152 L p F P
0 g
s
.669 .739 .903 r
.32727 .53838 m .31645 .5417 L .31316 .53876 L p F P
0 g
s
.532 .779 .988 r
.26659 .53885 m .27094 .53845 L .26755 .53601 L p F P
0 g
s
.532 .779 .988 r
.26755 .53601 m .25848 .53729 L .26659 .53885 L p F P
0 g
s
.416 .767 .995 r
.25693 .53747 m .25848 .53729 L .26659 .53885 L p F P
0 g
s
.576 .857 .996 r
.54362 .5373 m .54213 .5365 L .53096 .53946 L p F P
0 g
s
.625 .818 .974 r
.54213 .5365 m .53096 .53946 L .528 .53747 L p F P
0 g
s
.615 .826 .981 r
.51686 .54047 m .528 .53747 L .53096 .53946 L p F P
0 g
s
.573 .535 .774 r
.6572 .35108 m .65735 .35099 L p .66337 .3584 L F P
0 g
s
.577 .544 .781 r
.6572 .35108 m .65717 .351 L .65735 .35099 L closepath p F P
0 g
s
.577 .545 .783 r
.65735 .35099 m .65717 .351 L .65425 .34379 L p F P
0 g
s
.535 .12 .2 r
.4362 .29865 m .4324 .29898 L .42462 .29705 L p F P
0 g
s
.536 .125 .209 r
.4324 .29898 m .42292 .29984 L .42462 .29705 L closepath p F P
0 g
s
.56 .504 .75 r
.67753 .37463 m .67133 .3745 L .67641 .37138 L closepath p F P
0 g
s
.566 .515 .757 r
.67456 .36623 m .67641 .37138 L .67133 .3745 L p F P
0 g
s
.566 .515 .757 r
.66803 .36624 m .67456 .36623 L p .67133 .3745 L F P
0 g
s
.635 .65 .848 r
.56563 .28929 m .57687 .28629 L .57979 .29127 L p F P
0 g
s
.639 .664 .858 r
.57437 .28217 m .57687 .28629 L .56563 .28929 L p F P
0 g
s
.639 .664 .858 r
.56563 .28929 m .56442 .28735 L .57437 .28217 L p F P
0 g
s
.034 .566 .856 r
.22249 .53093 m .22557 .53166 L .22205 .53011 L p F P
0 g
s
.632 .801 .964 r
.50275 .54117 m .51388 .53811 L .51686 .54047 L p F P
0 g
s
.648 .768 .936 r
.51388 .53811 m .50275 .54117 L .49975 .5385 L p F P
0 g
s
.613 .611 .825 r
.61111 .30238 m .60254 .30407 L .60978 .29976 L closepath p F P
0 g
s
.616 .62 .831 r
.60821 .29675 m .60978 .29976 L .60254 .30407 L p F P
0 g
s
.616 .62 .831 r
.59689 .29914 m .60821 .29675 L p .60254 .30407 L F P
0 g
s
.854 .61 .568 r
.13657 .47615 m .13113 .47365 L .13186 .46833 L p F P
0 g
s
.856 .612 .568 r
.12647 .4658 m .13186 .46833 L .13113 .47365 L p F P
0 g
s
.853 .627 .595 r
.13186 .46833 m .12647 .4658 L .12765 .46034 L p F P
0 g
s
.854 .588 .536 r
.13763 .48191 m .13632 .48133 L .13657 .47615 L p F P
0 g
s
.857 .591 .534 r
.13113 .47365 m .13657 .47615 L .13632 .48133 L p F P
0 g
s
.821 .712 .744 r
.12089 .38559 m .12459 .38067 L p .1245 .3901 L F P
0 g
s
.821 .712 .744 r
.1245 .3901 m .12394 .38979 L .12089 .38559 L p F P
0 g
s
.827 .707 .732 r
.12432 .39034 m .1245 .3901 L .12394 .38979 L closepath p F P
0 g
s
.573 .535 .774 r
.65735 .35099 m .66868 .35053 L p .66337 .3584 L F P
0 g
s
.571 .535 .776 r
.66868 .35053 m .65735 .35099 L .66654 .34506 L closepath p F P
0 g
s
.577 .545 .783 r
.66575 .34311 m .66654 .34506 L .65735 .35099 L p F P
0 g
s
.577 .545 .783 r
.65425 .34379 m .66575 .34311 L p .65735 .35099 L F P
0 g
s
.521 .411 .669 r
.68358 .43577 m .68217 .42921 L .68708 .42646 L p F P
0 g
s
.639 .79 .955 r
.528 .53747 m .51686 .54047 L .51388 .53811 L p F P
0 g
s
.788 .73 .798 r
.16638 .32749 m .1627 .33085 L .15926 .32667 L p F P
0 g
s
.794 .73 .793 r
.1581 .33523 m .1627 .33085 L .15926 .32667 L p F P
0 g
s
.795 .363 .221 r
.17686 .51365 m .17161 .51167 L .16877 .50741 L p F P
0 g
s
.791 .351 .202 r
.16268 .50516 m .16877 .50741 L .17161 .51167 L p F P
0 g
s
.788 .73 .798 r
.15926 .32667 m .1615 .32463 L .16638 .32749 L p F P
0 g
s
.786 .731 .801 r
.17035 .31672 m .1615 .32463 L .16638 .32749 L p F P
0 g
s
.786 .731 .801 r
.16638 .32749 m .17378 .32087 L .17035 .31672 L p F P
0 g
s
.819 .719 .755 r
.12983 .37395 m .13242 .37078 L .12897 .36627 L p F P
0 g
s
.831 .707 .728 r
.12007 .39655 m .12432 .39034 L .12394 .38979 L p F P
0 g
s
.587 .878 .993 r
.49212 .28578 m .49081 .2853 L .47917 .28836 L p F P
0 g
s
.833 .699 .715 r
.11591 .40293 m .12088 .40568 L .11701 .41196 L p F P
0 g
s
.832 .702 .72 r
.12088 .40568 m .11591 .40293 L .12007 .39655 L p F P
0 g
s
.794 .73 .793 r
.15926 .32667 m .15328 .33235 L .1581 .33523 L p F P
0 g
s
.796 .729 .79 r
.1581 .33523 m .15156 .34158 L .1481 .33738 L p F P
0 g
s
.796 .729 .79 r
.1481 .33738 m .15328 .33235 L .1581 .33523 L p F P
0 g
s
.779 .73 .807 r
.17538 .31951 m .17378 .32087 L .17035 .31672 L p F P
0 g
s
.607 .602 .82 r
.61579 .31174 m .61402 .30817 L .62464 .30629 L closepath p F P
0 g
s
.577 .172 .239 r
.42292 .29984 m .41549 .30019 L .41051 .2982 L p F P
0 g
s
.577 .17 .234 r
.41549 .30019 m .40912 .30046 L .41051 .2982 L closepath p F P
0 g
s
.664 .742 .908 r
.33052 .54152 m .34138 .5379 L .34461 .54122 L p F P
0 g
s
.677 .731 .891 r
.34138 .5379 m .33052 .54152 L .32727 .53838 L p F P
0 g
s
.851 .642 .619 r
.12765 .46034 m .12233 .45778 L .12393 .4522 L p F P
0 g
s
.855 .63 .596 r
.12233 .45778 m .12765 .46034 L .12647 .4658 L p F P
0 g
s
.231 .745 .726 r
.58441 .52973 m .58083 .53073 L .58444 .52972 L closepath p F P
0 g
s
.398 .852 .893 r
.58083 .53073 m .58441 .52973 L p .57034 .53282 L F P
0 g
s
.779 .73 .807 r
.17035 .31672 m .17041 .31667 L .17538 .31951 L p F P
0 g
s
.778 .732 .81 r
.18042 .30834 m .17041 .31667 L .17538 .31951 L p F P
0 g
s
.778 .732 .81 r
.18373 .31032 m .18042 .30834 L p .17538 .31951 L F P
0 g
s
.778 .732 .81 r
.17538 .31951 m .18481 .31161 L .18373 .31032 L p F P
0 g
s
.534 .443 .698 r
.68969 .41481 m .68246 .41336 L .68842 .40993 L closepath p F P
0 g
s
.542 .457 .709 r
.68658 .40323 m .68842 .40993 L .68246 .41336 L p F P
0 g
s
.542 .457 .709 r
.68574 .4031 m .68658 .40323 L p .68246 .41336 L F P
0 g
s
.846 .552 .491 r
.14812 .49112 m .14236 .48874 L .14199 .48375 L p F P
0 g
s
.848 .551 .487 r
.13763 .48191 m .14199 .48375 L .14236 .48874 L p F P
0 g
s
.84 .691 .697 r
.11856 .42083 m .1192 .41967 L .11585 .41398 L p F P
0 g
s
.672 .277 .29 r
.365 .2973 m .36663 .29593 L p .37714 .2997 L F P
0 g
s
.618 .151 .121 r
.365 .2973 m .36173 .29545 L .36663 .29593 L closepath p F P
0 g
s
.718 .733 .863 r
.23833 .28743 m .23526 .2891 L .23189 .28519 L p F P
0 g
s
.738 .735 .848 r
.22102 .29186 m .23189 .28519 L .23526 .2891 L p F P
0 g
s
.827 .712 .738 r
.12394 .38979 m .12089 .38559 L .11965 .38729 L closepath p F P
0 g
s
.831 .707 .728 r
.12394 .38979 m .11965 .38729 L p .12007 .39655 L F P
0 g
s
.801 .73 .786 r
.15037 .34277 m .15156 .34158 L .1481 .33738 L p F P
0 g
s
.803 .727 .78 r
.14562 .33988 m .15037 .34277 L .14336 .35008 L p F P
0 g
s
.801 .73 .786 r
.1481 .33738 m .14562 .33988 L .15037 .34277 L p F P
0 g
s
.564 .515 .759 r
.67456 .36623 m .66803 .36624 L .67337 .36291 L closepath p F P
0 g
s
.569 .525 .766 r
.67161 .35822 m .67337 .36291 L .66803 .36624 L p F P
0 g
s
.569 .525 .766 r
.66337 .3584 m .67161 .35822 L p .66803 .36624 L F P
0 g
s
.671 .735 .898 r
.34461 .54122 m .35549 .53738 L .3587 .54085 L p F P
0 g
s
.682 .723 .881 r
.35549 .53738 m .34461 .54122 L .34138 .5379 L p F P
0 g
s
.568 .525 .768 r
.67161 .35822 m .66337 .3584 L .67008 .35415 L closepath p F P
0 g
s
.573 .535 .774 r
.66868 .35053 m .67008 .35415 L .66337 .3584 L p F P
0 g
s
.515 .743 .978 r
.30576 .2855 m .31049 .28542 L .31833 .28726 L p F P
0 g
s
.425 .727 .989 r
.31049 .28542 m .30576 .2855 L .30241 .2831 L p F P
0 g
s
.854 .645 .62 r
.11869 .4496 m .12393 .4522 L .12233 .45778 L p F P
0 g
s
.85 .655 .639 r
.12393 .4522 m .11869 .4496 L .12069 .4439 L p F P
0 g
s
.822 .717 .749 r
.12504 .3711 m .12983 .37395 L .12459 .38067 L p F P
0 g
s
.819 .719 .755 r
.12897 .36627 m .12504 .3711 L .12983 .37395 L p F P
0 g
s
.593 .578 .805 r
.64175 .32377 m .63409 .32475 L .63119 .31839 L p F P
0 g
s
.749 .733 .838 r
.20672 .29515 m .21007 .29291 L .21529 .29568 L p F P
0 g
s
.75 .736 .84 r
.21763 .28792 m .21007 .29291 L .21529 .29568 L p F P
0 g
s
.75 .736 .84 r
.21529 .29568 m .22102 .29186 L .21763 .28792 L p F P
0 g
s
.344 .001 .232 r
.63482 .50735 m .63728 .50599 L .63497 .5069 L closepath p F P
0 g
s
.396 .09 .325 r
.64604 .5005 m .64641 .49863 L p .63497 .5069 L F P
0 g
s
.396 .09 .325 r
.63497 .5069 m .63728 .50599 L .64604 .5005 L p F P
0 g
s
.486 .064 .165 r
.4362 .29865 m .43813 .29564 L .44249 .29504 L p F P
0 g
s
.845 .686 .684 r
.11358 .4181 m .11856 .42083 L .11553 .42684 L p F P
0 g
s
.84 .691 .697 r
.11585 .41398 m .11358 .4181 L .11856 .42083 L p F P
0 g
s
.662 .738 .906 r
.52033 .28336 m .53148 .27965 L .53444 .28317 L p F P
0 g
s
.665 .775 .931 r
.53148 .27965 m .52033 .28336 L .51736 .2805 L p F P
0 g
s
.661 .781 .938 r
.50622 .28423 m .51736 .2805 L .52033 .28336 L p F P
0 g
s
.675 .729 .891 r
.3587 .54085 m .36961 .53688 L .37279 .54046 L p F P
0 g
s
.684 .717 .874 r
.36961 .53688 m .3587 .54085 L .35549 .53738 L p F P
0 g
s
.771 .731 .816 r
.18481 .31161 m .18532 .31121 L .18373 .31032 L closepath p F P
0 g
s
.651 .838 .972 r
.51736 .2805 m .50622 .28423 L .50323 .28221 L p F P
0 g
s
.638 .839 .977 r
.49212 .28578 m .50323 .28221 L .50622 .28423 L p F P
0 g
s
.765 .733 .823 r
.19412 .30106 m .19579 .30304 L .18532 .31121 L p F P
0 g
s
.765 .733 .823 r
.19163 .29958 m .19412 .30106 L p .18532 .31121 L F P
0 g
s
.765 .733 .823 r
.18138 .30755 m .19163 .29958 L p .18532 .31121 L F P
0 g
s
.765 .733 .823 r
.18532 .31121 m .18373 .31032 L .18138 .30755 L p F P
0 g
s
.843 .516 .433 r
.15489 .4983 m .14913 .49593 L .14812 .49112 L p F P
0 g
s
.845 .515 .429 r
.14236 .48874 m .14812 .49112 L .14913 .49593 L p F P
0 g
s
.238 0 0 r
.35104 .29362 m .35234 .29415 L .36173 .29545 L p F P
0 g
s
.668 .245 .233 r
.36173 .29545 m .365 .2973 L .36412 .29849 L p F P
0 g
s
.668 .245 .233 r
.35234 .29415 m .36173 .29545 L p .36412 .29849 L F P
0 g
s
.599 .583 .807 r
.63119 .31839 m .62775 .3189 L .63062 .31715 L closepath p F P
0 g
s
.603 .591 .812 r
.62828 .31225 m .63062 .31715 L .62775 .3189 L p F P
0 g
s
.676 .725 .886 r
.37279 .54046 m .38373 .53642 L .38689 .54009 L p F P
0 g
s
.685 .712 .869 r
.38373 .53642 m .37279 .54046 L .36961 .53688 L p F P
0 g
s
.584 .017 0 r
.19488 .52199 m .19402 .52173 L .19449 .52176 L closepath p F P
0 g
s
.497 .781 .996 r
.25848 .53729 m .25587 .53684 L .25693 .53747 L closepath p F P
0 g
s
.182 0 0 r
.62097 .51705 m .62284 .51443 L .63353 .51043 L p F P
0 g
s
.295 0 .135 r
.63482 .50735 m .63353 .51043 L .62284 .51443 L p F P
0 g
s
.16 0 0 r
.62097 .51705 m .62284 .51443 L p .60988 .52107 L F P
0 g
s
.656 .706 .884 r
.53444 .28317 m .54562 .2796 L .54856 .28362 L p F P
0 g
s
.661 .73 .9 r
.54562 .2796 m .53444 .28317 L .53148 .27965 L p F P
0 g
s
.806 .725 .775 r
.14336 .35008 m .14032 .35333 L .13686 .34902 L p F P
0 g
s
.806 .725 .775 r
.13686 .34902 m .13855 .34721 L .14336 .35008 L p F P
0 g
s
.803 .727 .78 r
.14336 .35008 m .13855 .34721 L .14562 .33988 L p F P
0 g
s
.718 .733 .863 r
.23189 .28519 m .23248 .28487 L .23833 .28743 L p F P
0 g
s
.723 .742 .866 r
.24271 .27949 m .23248 .28487 L .23833 .28743 L p F P
0 g
s
.723 .742 .866 r
.23833 .28743 m .24608 .28323 L .24271 .27949 L p F P
0 g
s
.852 .658 .64 r
.11552 .44126 m .12069 .4439 L .11869 .4496 L p F P
0 g
s
.848 .666 .656 r
.12069 .4439 m .11552 .44126 L .11789 .43544 L p F P
0 g
s
.461 .261 .521 r
.66774 .4803 m .66763 .47517 L .67771 .4703 L p F P
0 g
s
.483 .302 .559 r
.67734 .46491 m .67771 .4703 L .66763 .47517 L p F P
0 g
s
.474 .27 .523 r
.66283 .48253 m .66774 .4803 L .66763 .47517 L p F P
0 g
s
.641 .669 .861 r
.57395 .28148 m .57437 .28217 L .56442 .28735 L p F P
0 g
s
.641 .669 .861 r
.56442 .28735 m .5627 .28464 L .57395 .28148 L p F P
0 g
s
.677 .721 .883 r
.38689 .54009 m .39784 .53603 L .40098 .53977 L p F P
0 g
s
.684 .708 .866 r
.39784 .53603 m .38689 .54009 L .38373 .53642 L p F P
0 g
s
.585 .89 .99 r
.49081 .2853 m .49212 .28578 L .50323 .28221 L p F P
0 g
s
.389 .094 .339 r
.64604 .5005 m .65144 .49652 L .64641 .49863 L closepath p F P
0 g
s
.431 .17 .415 r
.65718 .49115 m .65732 .48976 L p .64641 .49863 L F P
0 g
s
.431 .17 .415 r
.64641 .49863 m .65144 .49652 L .65718 .49115 L p F P
0 g
s
.514 0 0 r
.35234 .29415 m .35024 .2938 L .35104 .29362 L closepath p F P
0 g
s
.755 .29 .144 r
.17768 .51392 m .17686 .51365 L .17735 .51355 L closepath p F P
0 g
s
.618 .622 .833 r
.60821 .29675 m .59689 .29914 L .59398 .2937 L p F P
0 g
s
.284 0 .149 r
.63353 .51043 m .63482 .50735 L .63728 .50599 L p F P
0 g
s
.575 .545 .784 r
.66282 .33592 m .66575 .34311 L .65425 .34379 L p F P
0 g
s
.575 .545 .784 r
.66223 .33595 m .66282 .33592 L p .65425 .34379 L F P
0 g
s
.575 .545 .784 r
.65425 .34379 m .6534 .34171 L .66223 .33595 L p F P
0 g
s
.058 .59 .862 r
.31482 .28602 m .31049 .28542 L p .31691 .28652 L F P
0 g
s
.254 0 0 r
.31049 .28542 m .31636 .28623 L .31396 .28601 L p F P
0 g
s
.254 0 0 r
.30372 .2832 m .31049 .28542 L p .31374 .28598 L F P
0 g
s
.254 0 0 r
.31396 .28601 m .31309 .28578 L .31374 .28598 L F
.31309 .28578 m .30372 .2832 L .31374 .28598 L F
.31396 .28601 m .31161 .28545 L .30726 .28421 L p F P
0 g
s
.254 0 0 r
.30726 .28421 m .30372 .2832 L p .30827 .28445 L F P
0 g
s
.254 0 0 r
.31396 .28601 m .30726 .28421 L .30827 .28445 L F
.433 0 0 r
.30093 .28217 m .30372 .2832 L .30495 .28355 L p F P
0 g
s
.433 0 0 r
.30495 .28355 m .31161 .28545 L p .30322 .28287 L F P
0 g
s
.433 0 0 r
.30322 .28287 m .30093 .28217 L .30495 .28355 L F
.29902 .2812 m .30093 .28217 L p .31161 .28545 L F P
0 g
s
.271 .699 .967 r
.29902 .2812 m .29664 .28109 L .30093 .28217 L closepath p F P
0 g
s
.077 .584 .888 r
.29664 .28109 m .29902 .2812 L .29559 .27991 L p F P
0 g
s
.305 0 0 r
.30425 .28342 m .29991 .28158 L p .29559 .27991 L F P
0 g
s
.305 0 0 r
.29991 .28158 m .29902 .2812 L .29714 .28049 L p F P
0 g
s
.305 0 0 r
.29714 .28049 m .29559 .27991 L p .29991 .28158 L F P
0 g
s
.433 0 0 r
.31161 .28545 m .30425 .28342 L .30103 .28205 L p F P
0 g
s
.433 0 0 r
.30103 .28205 m .29902 .2812 L p .30711 .28393 L F P
0 g
s
.433 0 0 r
.31161 .28545 m .30103 .28205 L .30711 .28393 L F
.058 .59 .862 r
.31049 .28542 m .31833 .28726 L p .31691 .28652 L F P
0 g
s
.058 .59 .862 r
.31636 .28623 m .31482 .28602 L p .31691 .28652 L F P
0 g
s
.462 .014 .1 r
.4497 .29561 m .44249 .29504 L .45096 .29397 L closepath p F P
0 g
s
.486 .064 .165 r
.44249 .29504 m .4497 .29561 L p .4362 .29865 L F P
0 g
s
.81 .726 .771 r
.1368 .35724 m .14032 .35333 L .13686 .34902 L p F P
0 g
s
.353 0 0 r
.20208 .52495 m .19488 .52199 L p .20759 .52679 L F P
0 g
s
.241 0 0 r
.19402 .52173 m .19488 .52199 L .20208 .52495 L p F P
0 g
s
.241 0 0 r
.19084 .5212 m .19402 .52173 L p .20208 .52495 L F P
0 g
s
.01 .541 .85 r
.20105 .52398 m .19585 .52288 L p .20208 .52495 L F P
0 g
s
.241 0 0 r
.19564 .52283 m .19084 .5212 L p .20141 .52473 L F P
0 g
s
.241 0 0 r
.20208 .52495 m .19564 .52283 L p .20141 .52473 L F P
0 g
s
.562 0 0 r
.19084 .5212 m .18858 .51983 L .19402 .52173 L closepath p F P
0 g
s
.492 0 0 r
.18858 .51983 m .19084 .5212 L .1872 .52024 L p F P
0 g
s
.106 .603 .903 r
.19749 .52208 m .18948 .52081 L p .19564 .52283 L F P
0 g
s
.278 0 0 r
.19564 .52283 m .19084 .5212 L .1872 .52024 L p F P
0 g
s
.106 .603 .903 r
.18948 .52081 m .18906 .52074 L .19564 .52283 L p F P
0 g
s
.01 .541 .85 r
.19585 .52288 m .19564 .52283 L .20208 .52495 L p F P
0 g
s
.353 0 0 r
.20785 .52688 m .20208 .52495 L p .20759 .52679 L F P
0 g
s
.624 .632 .838 r
.59398 .2937 m .58842 .295 L .5932 .29228 L closepath p F P
0 g
s
.627 .641 .845 r
.59107 .2885 m .5932 .29228 L .58842 .295 L p F P
0 g
s
.627 .641 .845 r
.57979 .29127 m .59107 .2885 L p .58842 .295 L F P
0 g
s
.676 .719 .882 r
.40098 .53977 m .41196 .53573 L .41508 .5395 L p F P
0 g
s
.683 .705 .864 r
.41196 .53573 m .40098 .53977 L .39784 .53603 L p F P
0 g
s
0 0 0 r
.59567 .52633 m .58799 .52865 L .58444 .52972 L p F P
0 g
s
.258 .763 .738 r
.58441 .52973 m .58799 .52865 L .58444 .52972 L closepath p F P
0 g
s
.488 .326 .587 r
.67989 .45765 m .67675 .45926 L .67734 .46491 L p F P
0 g
s
.607 .604 .823 r
.62464 .30629 m .61402 .30817 L .61111 .30238 L p F P
0 g
s
.513 .393 .653 r
.68358 .43577 m .69331 .43034 L p .68664 .44111 L F P
0 g
s
.513 .393 .653 r
.68664 .44111 m .68442 .4401 L .68358 .43577 L p F P
0 g
s
.521 .411 .669 r
.6929 .42849 m .69331 .43034 L .68358 .43577 L p F P
0 g
s
.521 .411 .669 r
.68708 .42646 m .6929 .42849 L p .68358 .43577 L F P
0 g
s
.398 .852 .893 r
.58441 .52973 m .58159 .52963 L .57034 .53282 L p F P
0 g
s
.419 .863 .898 r
.58799 .52865 m .58441 .52973 L .58159 .52963 L p F P
0 g
s
.737 .74 .853 r
.23189 .28519 m .22102 .29186 L .21763 .28792 L p F P
0 g
s
.834 .705 .722 r
.11521 .39375 m .12007 .39655 L .11591 .40293 L p F P
0 g
s
.831 .707 .728 r
.11965 .38729 m .11521 .39375 L .12007 .39655 L p F P
0 g
s
.834 .467 .36 r
.15669 .50295 m .15659 .5029 L .15489 .4983 L p F P
0 g
s
.836 .465 .349 r
.14913 .49593 m .15489 .4983 L .15659 .5029 L p F P
0 g
s
.675 .14 0 r
.18858 .51983 m .18232 .51765 L .17768 .51392 L p F P
0 g
s
.631 .075 0 r
.17686 .51365 m .17768 .51392 L .18232 .51765 L p F P
0 g
s
.58 .555 .791 r
.6534 .34171 m .65133 .3368 L .66223 .33595 L closepath p F P
0 g
s
.63 .646 .847 r
.59107 .2885 m .57979 .29127 L .57687 .28629 L p F P
0 g
s
.761 .732 .826 r
.19579 .30304 m .19662 .30243 L .19412 .30106 L closepath p F P
0 g
s
.453 .225 .478 r
.65732 .48976 m .65919 .48892 L .66283 .48253 L p F P
0 g
s
.447 .219 .473 r
.66774 .4803 m .66283 .48253 L .65919 .48892 L p F P
0 g
s
.776 .735 .815 r
.18373 .31032 m .18138 .30755 L .18042 .30834 L closepath p F P
0 g
s
.674 .719 .883 r
.41508 .5395 m .42608 .53553 L .42919 .53929 L p F P
0 g
s
.68 .704 .865 r
.42608 .53553 m .41508 .5395 L .41196 .53573 L p F P
0 g
s
.284 0 .149 r
.63728 .50599 m .6455 .5027 L p .63353 .51043 L F P
0 g
s
.38 .067 .304 r
.63728 .50599 m .6455 .5027 L .64604 .5005 L closepath p F P
0 g
s
.593 .853 .993 r
.54213 .5365 m .54362 .5373 L .55533 .53456 L p F P
0 g
s
.574 .862 .996 r
.55624 .53503 m .55533 .53456 L .54362 .5373 L p F P
0 g
s
.52 .782 .992 r
.25848 .53729 m .26755 .53601 L p .2535 .53537 L F P
0 g
s
.52 .782 .992 r
.2535 .53537 m .25587 .53684 L .25848 .53729 L p F P
0 g
s
.81 .726 .771 r
.13686 .34902 m .13205 .35435 L .1368 .35724 L p F P
0 g
s
.812 .724 .767 r
.13205 .35435 m .1368 .35724 L .13066 .36425 L p F P
0 g
s
.653 .699 .88 r
.55977 .28024 m .54856 .28362 L .54562 .2796 L p F P
0 g
s
.648 .683 .869 r
.54856 .28362 m .55977 .28024 L .5627 .28464 L p F P
0 g
s
.755 .734 .833 r
.20331 .29116 m .20672 .29515 L .19662 .30243 L p F P
0 g
s
.755 .734 .833 r
.19237 .29902 m .20331 .29116 L p .19662 .30243 L F P
0 g
s
.755 .734 .833 r
.19662 .30243 m .19412 .30106 L .19237 .29902 L p F P
0 g
s
.825 .714 .742 r
.12459 .38067 m .12089 .38559 L .11744 .38092 L p F P
0 g
s
.825 .714 .742 r
.11744 .38092 m .11975 .37784 L .12459 .38067 L p F P
0 g
s
.822 .717 .749 r
.12459 .38067 m .11975 .37784 L .12504 .3711 L p F P
0 g
s
.85 .67 .657 r
.1128 .43277 m .11789 .43544 L .11552 .44126 L p F P
0 g
s
.847 .677 .671 r
.11789 .43544 m .1128 .43277 L .11553 .42684 L p F P
0 g
s
.839 .693 .7 r
.11585 .41398 m .11701 .41196 L .11348 .41003 L closepath p F P
0 g
s
.833 .699 .715 r
.11248 .40847 m .11591 .40293 L p .11701 .41196 L F P
0 g
s
.833 .699 .715 r
.11701 .41196 m .11348 .41003 L .11248 .40847 L p F P
0 g
s
.631 .075 0 r
.1736 .51376 m .17686 .51365 L p .18232 .51765 L F P
0 g
s
.743 .25 .062 r
.1736 .51376 m .17161 .51167 L .17686 .51365 L closepath p F P
0 g
s
.628 .757 .94 r
.28164 .53618 m .27094 .53845 L .26755 .53601 L p F P
0 g
s
.6 .765 .958 r
.27094 .53845 m .28164 .53618 L .28499 .53889 L p F P
0 g
s
.671 .72 .886 r
.42919 .53929 m .44021 .53541 L .44329 .53914 L p F P
0 g
s
.677 .705 .868 r
.44021 .53541 m .42919 .53929 L .42608 .53553 L p F P
0 g
s
.323 .712 .981 r
.23621 .53215 m .23585 .53204 L .22557 .53166 L p F P
0 g
s
.268 .707 .963 r
.23585 .53204 m .22557 .53166 L .22205 .53011 L p F P
0 g
s
.668 .245 .233 r
.36412 .29849 m .35667 .29765 L .35234 .29415 L p F P
0 g
s
.714 .321 .302 r
.35024 .2938 m .35234 .29415 L .35667 .29765 L p F P
0 g
s
.457 .757 .994 r
.2535 .53537 m .25103 .53552 L .25587 .53684 L closepath p F P
0 g
s
.136 .63 .911 r
.2156 .52897 m .22205 .53011 L .21854 .52828 L p F P
0 g
s
.233 0 0 r
.20818 .52699 m .20851 .52706 L .2156 .52897 L p F P
0 g
s
.674 .707 .872 r
.45433 .53537 m .44329 .53914 L .44021 .53541 L p F P
0 g
s
.668 .724 .891 r
.44329 .53914 m .45433 .53537 L .4574 .53901 L p F P
0 g
s
.421 .167 .421 r
.65718 .49115 m .65919 .48892 L .65732 .48976 L closepath p F P
0 g
s
.057 0 0 r
.60969 .52124 m .61498 .51931 L .60988 .52107 L closepath p F P
0 g
s
.16 0 0 r
.60988 .52107 m .61498 .51931 L .62097 .51705 L p F P
0 g
s
.593 .578 .805 r
.63119 .31839 m .64261 .31694 L p .64175 .32377 L F P
0 g
s
.593 .58 .808 r
.63992 .31107 m .64261 .31694 L .63119 .31839 L p F P
0 g
s
.593 .58 .808 r
.63119 .31839 m .63062 .31715 L .63992 .31107 L p F P
0 g
s
.848 .551 .487 r
.13649 .48457 m .13763 .48191 L p .14236 .48874 L F P
0 g
s
.856 .565 .495 r
.13649 .48457 m .13632 .48133 L .13763 .48191 L closepath p F P
0 g
s
.491 .093 .214 r
.45096 .29397 m .46334 .29177 L .46153 .29485 L p F P
0 g
s
.491 .093 .214 r
.4497 .29561 m .45096 .29397 L p .46153 .29485 L F P
0 g
s
.09 0 0 r
.46387 .29136 m .46334 .29177 L .45096 .29397 L p F P
0 g
s
.843 .693 .697 r
.11358 .4181 m .11585 .41398 L .11348 .41003 L p F P
0 g
s
.667 .754 .915 r
.26023 .28191 m .27098 .27806 L .27434 .28135 L p F P
0 g
s
.652 .757 .927 r
.27098 .27806 m .26023 .28191 L .25687 .27834 L p F P
0 g
s
.699 .745 .887 r
.24608 .28323 m .25687 .27834 L .26023 .28191 L p F P
0 g
s
.513 .393 .653 r
.68481 .44212 m .68442 .4401 L .68664 .44111 L closepath p F P
0 g
s
.714 .321 .302 r
.34758 .29606 m .35024 .2938 L p .35667 .29765 L F P
0 g
s
.661 .207 .163 r
.34758 .29606 m .34314 .29278 L .35024 .2938 L closepath p F P
0 g
s
.817 .721 .76 r
.13066 .36425 m .12897 .36627 L .1255 .36182 L p F P
0 g
s
.817 .721 .76 r
.1255 .36182 m .12587 .36139 L .13066 .36425 L p F P
0 g
s
.812 .724 .767 r
.13066 .36425 m .12587 .36139 L .13205 .35435 L p F P
0 g
s
.58 .555 .791 r
.66223 .33595 m .65133 .3368 L .6493 .33197 L p F P
0 g
s
.634 .757 .936 r
.28499 .53889 m .29575 .53599 L .29907 .53896 L p F P
0 g
s
.655 .748 .918 r
.29575 .53599 m .28499 .53889 L .28164 .53618 L p F P
0 g
s
.787 .339 .184 r
.15669 .50295 m .16268 .50516 L .16562 .5094 L p F P
0 g
s
.791 .351 .202 r
.17161 .51167 m .16562 .5094 L .16268 .50516 L p F P
0 g
s
.419 .863 .898 r
.5956 .52634 m .58799 .52865 L p .58159 .52963 L F P
0 g
s
.308 .8 .791 r
.58799 .52865 m .5956 .52634 L .59567 .52633 L closepath p F P
0 g
s
.849 .68 .672 r
.11053 .42412 m .11553 .42684 L .1128 .43277 L p F P
0 g
s
.845 .686 .684 r
.11553 .42684 m .11053 .42412 L .11358 .4181 L p F P
0 g
s
.603 .766 .958 r
.27434 .28135 m .28503 .27888 L .28839 .2817 L p F P
0 g
s
.559 .766 .975 r
.28503 .27888 m .27434 .28135 L .27098 .27806 L p F P
0 g
s
.664 .73 .899 r
.4574 .53901 m .46846 .53537 L .47151 .5389 L p F P
0 g
s
.67 .711 .879 r
.46846 .53537 m .4574 .53901 L .45433 .53537 L p F P
0 g
s
.597 .589 .814 r
.6397 .31061 m .63992 .31107 L .63062 .31715 L p F P
0 g
s
.597 .589 .814 r
.63062 .31715 m .62828 .31225 L .6397 .31061 L p F P
0 g
s
.829 .715 .739 r
.11965 .38729 m .12089 .38559 L .11744 .38092 L p F P
0 g
s
.546 .885 .986 r
.58159 .52963 m .57034 .53282 L .56747 .53193 L p F P
0 g
s
.533 .881 .985 r
.55624 .53503 m .56747 .53193 L .57034 .53282 L p F P
0 g
s
.644 .677 .867 r
.57395 .28148 m .5627 .28464 L .55977 .28024 L p F P
0 g
s
0 0 0 r
.61498 .51931 m .60969 .52124 L .60696 .52266 L p F P
0 g
s
0 0 0 r
.59567 .52633 m .60696 .52266 L .60969 .52124 L p F P
0 g
s
.544 .478 .732 r
.68183 .38752 m .68737 .38403 L p .68721 .39337 L F P
0 g
s
.544 .478 .732 r
.68721 .39337 m .68353 .39298 L .68183 .38752 L p F P
0 g
s
.549 .489 .741 r
.68183 .38752 m .68052 .38352 L .68737 .38403 L closepath p F P
0 g
s
.857 .591 .534 r
.13632 .48133 m .13088 .47883 L .13113 .47365 L p F P
0 g
s
.86 .593 .533 r
.12573 .47112 m .13113 .47365 L .13088 .47883 L p F P
0 g
s
.856 .612 .568 r
.13113 .47365 m .12573 .47112 L .12647 .4658 L p F P
0 g
s
.693 .748 .894 r
.25687 .27834 m .24608 .28323 L .24271 .27949 L p F P
0 g
s
.859 .615 .568 r
.12113 .46324 m .12647 .4658 L .12573 .47112 L p F P
0 g
s
.855 .63 .596 r
.12647 .4658 m .12113 .46324 L .12233 .45778 L p F P
0 g
s
.82 .722 .756 r
.12504 .3711 m .12897 .36627 L .1255 .36182 L p F P
0 g
s
.549 .489 .741 r
.68737 .38403 m .68052 .38352 L .67923 .37958 L p F P
0 g
s
.539 .456 .709 r
.68658 .40323 m .68574 .4031 L .68643 .4027 L closepath p F P
0 g
s
.547 .469 .719 r
.68423 .39523 m .68643 .4027 L .68574 .4031 L p F P
0 g
s
.544 .478 .731 r
.68423 .39523 m .68353 .39298 L .68721 .39337 L closepath p F P
0 g
s
.549 .489 .741 r
.67923 .37958 m .6863 .37506 L p .68737 .38403 L F P
0 g
s
.553 .5 .75 r
.67923 .37958 m .67753 .37463 L .6863 .37506 L closepath p F P
0 g
s
.748 .735 .84 r
.21007 .29291 m .20672 .29515 L .20331 .29116 L p F P
0 g
s
.538 .465 .721 r
.68643 .4027 m .68423 .39523 L .68721 .39337 L p F P
0 g
s
.86 .566 .491 r
.13632 .48133 m .13649 .48457 L .13582 .48599 L p F P
0 g
s
.86 .566 .491 r
.13088 .47883 m .13632 .48133 L p .13582 .48599 L F P
0 g
s
.352 .043 .294 r
.6455 .5027 m .64604 .5005 L .65144 .49652 L p F P
0 g
s
.66 .739 .908 r
.47151 .5389 m .4826 .53539 L .48563 .53874 L p F P
0 g
s
.666 .718 .887 r
.4826 .53539 m .47151 .5389 L .46846 .53537 L p F P
0 g
s
.519 .411 .67 r
.6929 .42849 m .68708 .42646 L .69186 .42375 L closepath p F P
0 g
s
.529 .427 .683 r
.69024 .41695 m .69186 .42375 L .68708 .42646 L p F P
0 g
s
.789 .732 .8 r
.1615 .32463 m .15926 .32667 L .1558 .32254 L p F P
0 g
s
.795 .733 .795 r
.15328 .33235 m .15926 .32667 L .1558 .32254 L p F P
0 g
s
.829 .715 .739 r
.11744 .38092 m .11488 .38444 L .11965 .38729 L p F P
0 g
s
.833 .711 .731 r
.11488 .38444 m .11965 .38729 L .11521 .39375 L p F P
0 g
s
.502 .37 .633 r
.68664 .44111 m .68481 .44212 L .68583 .44823 L p F P
0 g
s
.789 .732 .8 r
.1558 .32254 m .15669 .32173 L .1615 .32463 L p F P
0 g
s
.787 .734 .803 r
.1657 .31373 m .15669 .32173 L .1615 .32463 L p F P
0 g
s
.787 .734 .803 r
.17021 .31656 m .1657 .31373 L p .1615 .32463 L F P
0 g
s
.787 .734 .803 r
.1615 .32463 m .17035 .31672 L .17021 .31656 L p F P
0 g
s
.854 .645 .62 r
.12233 .45778 m .11706 .45519 L .11869 .4496 L p F P
0 g
s
.857 .633 .597 r
.11706 .45519 m .12233 .45778 L .12113 .46324 L p F P
0 g
s
.656 .748 .918 r
.29907 .53896 m .30987 .53556 L .31316 .53876 L p F P
0 g
s
.671 .738 .901 r
.30987 .53556 m .29907 .53896 L .29575 .53599 L p F P
0 g
s
.838 .701 .712 r
.11591 .40293 m .11248 .40847 L .10907 .4033 L p F P
0 g
s
.838 .701 .712 r
.10907 .4033 m .11101 .40014 L .11591 .40293 L p F P
0 g
s
.834 .705 .722 r
.11591 .40293 m .11101 .40014 L .11521 .39375 L p F P
0 g
s
.425 .727 .989 r
.30241 .2831 m .30372 .2832 L .31049 .28542 L p F P
0 g
s
.768 .736 .824 r
.19412 .30106 m .19237 .29902 L .19163 .29958 L closepath p F P
0 g
s
.553 .501 .751 r
.6863 .37506 m .67753 .37463 L .67641 .37138 L p F P
0 g
s
.797 .732 .791 r
.15328 .33235 m .1481 .33738 L .14463 .33324 L p F P
0 g
s
.797 .732 .791 r
.14463 .33324 m .14855 .32943 L .15328 .33235 L p F P
0 g
s
.795 .733 .795 r
.1558 .32254 m .14855 .32943 L .15328 .33235 L p F P
0 g
s
.781 .733 .809 r
.17035 .31672 m .17041 .31667 L .17021 .31656 L closepath p F P
0 g
s
.775 .735 .816 r
.17568 .3054 m .18042 .30834 L .17041 .31667 L p F P
0 g
s
.775 .735 .816 r
.1669 .31269 m .17568 .3054 L p .17041 .31667 L F P
0 g
s
.775 .735 .816 r
.17041 .31667 m .17021 .31656 L .1669 .31269 L p F P
0 g
s
.501 .354 .613 r
.68583 .44823 m .68666 .45413 L .67989 .45765 L p F P
0 g
s
.488 .326 .587 r
.67734 .46491 m .68296 .46204 L .67989 .45765 L p F P
0 g
s
.485 .325 .589 r
.68666 .45413 m .67989 .45765 L .68296 .46204 L p F P
0 g
s
.585 .89 .99 r
.50323 .28221 m .5021 .28182 L .49081 .2853 L p F P
0 g
s
.396 .136 .398 r
.65919 .48892 m .66756 .48511 L p .65681 .49423 L F P
0 g
s
.396 .136 .398 r
.65681 .49423 m .65718 .49115 L .65919 .48892 L p F P
0 g
s
.447 .219 .473 r
.65919 .48892 m .66756 .48511 L .66774 .4803 L p F P
0 g
s
.785 .736 .808 r
.17021 .31656 m .1669 .31269 L .1657 .31373 L closepath p F P
0 g
s
.553 .501 .751 r
.67641 .37138 m .68399 .36646 L p .6863 .37506 L F P
0 g
s
.558 .511 .759 r
.67641 .37138 m .67456 .36623 L .68399 .36646 L closepath p F P
0 g
s
.501 .729 .975 r
.29664 .28109 m .28839 .2817 L .28503 .27888 L p F P
0 g
s
.463 .757 .993 r
.30093 .28217 m .29664 .28109 L .28839 .2817 L p F P
0 g
s
.532 .451 .71 r
.68643 .4027 m .69588 .39685 L p .69634 .40511 L F P
0 g
s
.532 .451 .71 r
.69634 .40511 m .68658 .40323 L .68643 .4027 L p F P
0 g
s
.538 .465 .721 r
.69521 .39457 m .69588 .39685 L .68643 .4027 L p F P
0 g
s
.538 .465 .721 r
.68721 .39337 m .69521 .39457 L p .68643 .4027 L F P
0 g
s
.802 .732 .787 r
.14562 .33988 m .1481 .33738 L .14463 .33324 L p F P
0 g
s
.655 .752 .921 r
.48563 .53874 m .49674 .53536 L .49975 .5385 L p F P
0 g
s
.662 .727 .898 r
.49674 .53536 m .48563 .53874 L .4826 .53539 L p F P
0 g
s
.532 .451 .709 r
.68842 .40993 m .68658 .40323 L .69634 .40511 L closepath p F P
0 g
s
.669 .739 .903 r
.31316 .53876 m .32401 .53498 L .32727 .53838 L p F P
0 g
s
.681 .729 .886 r
.32401 .53498 m .31316 .53876 L .30987 .53556 L p F P
0 g
s
.856 .648 .621 r
.11349 .44697 m .11869 .4496 L .11706 .45519 L p F P
0 g
s
.852 .658 .64 r
.11869 .4496 m .11349 .44697 L .11552 .44126 L p F P
0 g
s
.749 .739 .842 r
.21422 .28403 m .20489 .29012 L .21007 .29291 L p F P
0 g
s
.749 .739 .842 r
.21007 .29291 m .21763 .28792 L .21422 .28403 L p F P
0 g
s
.748 .735 .84 r
.20331 .29116 m .20489 .29012 L .21007 .29291 L p F P
0 g
s
.618 .622 .833 r
.59398 .2937 m .6053 .29129 L .60821 .29675 L p F P
0 g
s
.62 .63 .839 r
.60271 .2865 m .6053 .29129 L .59398 .2937 L p F P
0 g
s
.62 .63 .839 r
.59398 .2937 m .5932 .29228 L .60271 .2865 L p F P
0 g
s
.084 0 0 r
.47536 .28915 m .47034 .2902 L .46387 .29136 L p F P
0 g
s
.192 0 0 r
.47034 .2902 m .46334 .29177 L .46387 .29136 L closepath p F P
0 g
s
.845 .515 .429 r
.14913 .49593 m .14339 .49354 L .14236 .48874 L p F P
0 g
s
.846 .514 .425 r
.13663 .48634 m .14236 .48874 L .14339 .49354 L p F P
0 g
s
.848 .551 .487 r
.14236 .48874 m .13663 .48634 L .13649 .48457 L p F P
0 g
s
.422 .157 .405 r
.65144 .49652 m .65681 .49423 L .65718 .49115 L closepath p F P
0 g
s
.591 .86 .994 r
.55533 .53456 m .55624 .53503 L .56747 .53193 L p F P
0 g
s
.804 .73 .782 r
.14094 .33695 m .14562 .33988 L .13855 .34721 L p F P
0 g
s
.802 .732 .787 r
.14463 .33324 m .14094 .33695 L .14562 .33988 L p F P
0 g
s
.607 .604 .823 r
.61111 .30238 m .62248 .30036 L p .62464 .30629 L F P
0 g
s
.608 .608 .826 r
.61958 .2946 m .62248 .30036 L .61111 .30238 L p F P
0 g
s
.608 .608 .826 r
.61722 .29503 m .61958 .2946 L p .61111 .30238 L F P
0 g
s
.608 .608 .826 r
.61111 .30238 m .60978 .29976 L .61722 .29503 L p F P
0 g
s
.737 .74 .853 r
.23105 .28424 m .23189 .28519 L p .21763 .28792 L F P
0 g
s
.718 .734 .863 r
.23189 .28519 m .23248 .28487 L .23105 .28424 L closepath p F P
0 g
s
.352 .043 .294 r
.65144 .49652 m .65681 .49423 L p .6455 .5027 L F P
0 g
s
.583 .564 .798 r
.6493 .33197 m .64842 .32997 L .65294 .32955 L closepath p F P
0 g
s
.58 .555 .791 r
.6493 .33197 m .65294 .32955 L p .66223 .33595 L F P
0 g
s
.296 0 0 r
.3337 .29051 m .33485 .29109 L .34314 .29278 L p F P
0 g
s
.694 .27 .235 r
.34314 .29278 m .34758 .29606 L .3475 .29616 L p F P
0 g
s
.694 .27 .235 r
.33485 .29109 m .34314 .29278 L p .3475 .29616 L F P
0 g
s
.677 .731 .891 r
.32727 .53838 m .33815 .53432 L .34138 .5379 L p F P
0 g
s
.687 .721 .875 r
.33815 .53432 m .32727 .53838 L .32401 .53498 L p F P
0 g
s
.823 .72 .751 r
.12031 .36822 m .12504 .3711 L .11975 .37784 L p F P
0 g
s
.82 .722 .756 r
.1255 .36182 m .12031 .36822 L .12504 .3711 L p F P
0 g
s
.847 .689 .686 r
.10867 .41533 m .11358 .4181 L .11053 .42412 L p F P
0 g
s
.843 .693 .697 r
.11204 .40921 m .10867 .41533 L .11358 .4181 L p F P
0 g
s
.843 .693 .697 r
.11348 .41003 m .11204 .40921 L p .11358 .4181 L F P
0 g
s
.714 .735 .868 r
.23932 .27581 m .24271 .27949 L .23248 .28487 L p F P
0 g
s
.714 .735 .868 r
.2285 .28136 m .23932 .27581 L p .23248 .28487 L F P
0 g
s
.714 .735 .868 r
.23248 .28487 m .23105 .28424 L .2285 .28136 L p F P
0 g
s
.648 .768 .936 r
.49975 .5385 m .51089 .53524 L .51388 .53811 L p F P
0 g
s
.657 .741 .911 r
.51089 .53524 m .49975 .5385 L .49674 .53536 L p F P
0 g
s
.657 .331 .41 r
.40118 .30053 m .40912 .30046 L .408 .30441 L p F P
0 g
s
.657 .331 .41 r
.408 .30441 m .40442 .30444 L .40118 .30053 L p F P
0 g
s
.661 .331 .404 r
.39479 .30051 m .40118 .30053 L .40442 .30444 L p F P
0 g
s
.661 .331 .404 r
.40442 .30444 m .39359 .3044 L .39479 .30051 L p F P
0 g
s
.675 .345 .408 r
.38853 .30032 m .39479 .30051 L .39359 .3044 L p F P
0 g
s
.777 .737 .816 r
.17794 .30356 m .17568 .3054 L .18042 .30834 L p F P
0 g
s
.777 .737 .816 r
.18042 .30834 m .18138 .30755 L .17794 .30356 L p F P
0 g
s
.557 .511 .76 r
.68399 .36646 m .67456 .36623 L .67337 .36291 L p F P
0 g
s
.672 .277 .29 r
.37714 .2997 m .36662 .29877 L .365 .2973 L p F P
0 g
s
.679 .272 .267 r
.36662 .29877 m .36412 .29849 L .365 .2973 L closepath p F P
0 g
s
.507 .768 .99 r
.25103 .53552 m .2535 .53537 L .25007 .53299 L p F P
0 g
s
.507 .768 .99 r
.25007 .53299 m .24377 .53368 L .25103 .53552 L p F P
0 g
s
.359 .747 .987 r
.2395 .534 m .24377 .53368 L .25103 .53552 L p F P
0 g
s
.637 .311 .403 r
.40912 .30046 m .41549 .30019 L .41928 .30392 L p F P
0 g
s
.637 .311 .403 r
.41928 .30392 m .408 .30441 L .40912 .30046 L p F P
0 g
s
.492 0 0 r
.1872 .52024 m .18232 .51765 L .18858 .51983 L p F P
0 g
s
.77 .738 .823 r
.19163 .29958 m .18138 .30755 L .17794 .30356 L p F P
0 g
s
.682 .723 .881 r
.34138 .5379 m .35229 .53365 L .35549 .53738 L p F P
0 g
s
.691 .712 .865 r
.35229 .53365 m .34138 .5379 L .33815 .53432 L p F P
0 g
s
.453 .769 .997 r
.24377 .53368 m .23621 .53215 L .2395 .534 L closepath p F P
0 g
s
.471 .293 .557 r
.68296 .46204 m .67734 .46491 L .67771 .4703 L p F P
0 g
s
.593 .853 .993 r
.55533 .53456 m .55333 .53342 L .54213 .5365 L p F P
0 g
s
.632 .813 .969 r
.55333 .53342 m .54213 .5365 L .53919 .53437 L p F P
0 g
s
.625 .818 .974 r
.528 .53747 m .53919 .53437 L .54213 .5365 L p F P
0 g
s
.639 .79 .955 r
.51388 .53811 m .52504 .53494 L .528 .53747 L p F P
0 g
s
.652 .759 .928 r
.52504 .53494 m .51388 .53811 L .51089 .53524 L p F P
0 g
s
.839 .7 .709 r
.11348 .41003 m .11248 .40847 L .11204 .40921 L closepath p F P
0 g
s
.675 .345 .408 r
.39359 .3044 m .39144 .30434 L .38853 .30032 L p F P
0 g
s
.69 .375 .436 r
.37981 .29987 m .38853 .30032 L .39144 .30434 L p F P
0 g
s
.684 .717 .874 r
.35549 .53738 m .36643 .53301 L .36961 .53688 L p F P
0 g
s
.692 .705 .857 r
.36643 .53301 m .35549 .53738 L .35229 .53365 L p F P
0 g
s
.589 .57 .8 r
.64551 .32334 m .64175 .32377 L .64482 .32179 L closepath p F P
0 g
s
.593 .578 .805 r
.64261 .31694 m .64482 .32179 L .64175 .32377 L p F P
0 g
s
.644 .782 .948 r
.53919 .53437 m .528 .53747 L .52504 .53494 L p F P
0 g
s
.527 .438 .698 r
.68842 .40993 m .69634 .40511 L p .69263 .41552 L F P
0 g
s
.527 .438 .698 r
.69263 .41552 m .68969 .41481 L .68842 .40993 L p F P
0 g
s
.557 .511 .76 r
.67337 .36291 m .68044 .35824 L p .68399 .36646 L F P
0 g
s
.562 .521 .768 r
.67337 .36291 m .67161 .35822 L .68044 .35824 L closepath p F P
0 g
s
.854 .661 .641 r
.11041 .43859 m .11552 .44126 L .11349 .44697 L p F P
0 g
s
.85 .67 .657 r
.11552 .44126 m .11041 .43859 L .1128 .43277 L p F P
0 g
s
.808 .728 .777 r
.13855 .34721 m .13686 .34902 L .13338 .34477 L p F P
0 g
s
.808 .728 .777 r
.13338 .34477 m .13381 .34431 L .13855 .34721 L p F P
0 g
s
.804 .73 .782 r
.13855 .34721 m .13381 .34431 L .14094 .33695 L p F P
0 g
s
.636 .312 .406 r
.41549 .30019 m .42292 .29984 L .42184 .3038 L p F P
0 g
s
.636 .312 .406 r
.42184 .3038 m .41928 .30392 L .41549 .30019 L p F P
0 g
s
.583 .565 .799 r
.65294 .32955 m .64842 .32997 L .64551 .32334 L p F P
0 g
s
.685 .712 .869 r
.3807 .53262 m .38373 .53642 L p .36961 .53688 L F P
0 g
s
.685 .712 .869 r
.36961 .53688 m .38018 .5326 L .3807 .53262 L p F P
0 g
s
.692 .7 .853 r
.38018 .5326 m .36961 .53688 L .36643 .53301 L p F P
0 g
s
.623 .637 .844 r
.60239 .28592 m .60271 .2865 L .5932 .29228 L p F P
0 g
s
.623 .637 .844 r
.5932 .29228 m .59107 .2885 L .60239 .28592 L p F P
0 g
s
.719 .203 0 r
.17161 .51167 m .1736 .51376 L .17017 .51347 L p F P
0 g
s
.719 .203 0 r
.16562 .5094 m .17161 .51167 L p .17017 .51347 L F P
0 g
s
.63 .646 .847 r
.57687 .28629 m .58815 .28346 L .59107 .2885 L p F P
0 g
s
.633 .657 .855 r
.58524 .27855 m .58815 .28346 L .57687 .28629 L p F P
0 g
s
.633 .657 .855 r
.57703 .28067 m .58524 .27855 L p .57687 .28629 L F P
0 g
s
.633 .657 .855 r
.57687 .28629 m .57437 .28217 L .57703 .28067 L p F P
0 g
s
.433 .208 .471 r
.66756 .48511 m .66774 .4803 L .67783 .47543 L p F P
0 g
s
.461 .261 .521 r
.67771 .4703 m .67783 .47543 L .66774 .4803 L p F P
0 g
s
.502 .37 .633 r
.68583 .44823 m .69225 .44472 L .68664 .44111 L p F P
0 g
s
.5 .37 .635 r
.69454 .4367 m .68664 .44111 L .69225 .44472 L p F P
0 g
s
.513 .393 .653 r
.69331 .43034 m .69454 .4367 L .68664 .44111 L p F P
0 g
s
.812 .729 .772 r
.13205 .35435 m .13686 .34902 L .13338 .34477 L p F P
0 g
s
.836 .465 .349 r
.15659 .5029 m .15087 .50052 L .14913 .49593 L p F P
0 g
s
.837 .461 .34 r
.14339 .49354 m .14913 .49593 L .15087 .50052 L p F P
0 g
s
.596 .59 .816 r
.6397 .31061 m .62828 .31225 L .62538 .30617 L p F P
0 g
s
0 .494 .777 r
.20851 .52706 m .20785 .52688 L .20818 .52699 L closepath p F P
0 g
s
.684 .708 .866 r
.39549 .53299 m .39784 .53603 L p .38373 .53642 L F P
0 g
s
.684 .708 .866 r
.38373 .53642 m .39227 .53296 L .39549 .53299 L p F P
0 g
s
.685 .712 .869 r
.38373 .53642 m .39227 .53296 L .3807 .53262 L closepath p F P
0 g
s
.737 .74 .853 r
.21763 .28792 m .22728 .28209 L .23105 .28424 L p F P
0 g
s
.736 .74 .855 r
.23105 .28424 m .2285 .28136 L .22728 .28209 L closepath p F P
0 g
s
.546 0 0 r
.33485 .29109 m .33281 .29062 L .3337 .29051 L closepath p F P
0 g
s
0 0 0 r
.62073 .51728 m .61498 .51931 L p .60696 .52266 L F P
0 g
s
.078 0 0 r
.61498 .51931 m .62073 .51728 L .62097 .51705 L closepath p F P
0 g
s
.689 .349 .394 r
.37895 .30226 m .37714 .2997 L .37981 .29987 L closepath p F P
0 g
s
.69 .375 .436 r
.37895 .30226 m .37981 .29987 L p .39144 .30434 L F P
0 g
s
.61 .287 .397 r
.42184 .3038 m .42292 .29984 L .4324 .29898 L p F P
0 g
s
.661 .73 .9 r
.53148 .27965 m .54267 .27595 L .54562 .2796 L p F P
0 g
s
.667 .763 .922 r
.54267 .27595 m .53148 .27965 L .52852 .27667 L p F P
0 g
s
.665 .775 .931 r
.51736 .2805 m .52852 .27667 L .53148 .27965 L p F P
0 g
s
.664 .829 .963 r
.52852 .27667 m .51736 .2805 L .51438 .27841 L p F P
0 g
s
.651 .838 .972 r
.50323 .28221 m .51438 .27841 L .51736 .2805 L p F P
0 g
s
.314 .7 .979 r
.20851 .52706 m .21854 .52828 L .21518 .5263 L p F P
0 g
s
.314 .7 .979 r
.20785 .52688 m .20851 .52706 L p .21518 .5263 L F P
0 g
s
.683 .705 .864 r
.40985 .53297 m .41196 .53573 L p .39784 .53603 L F P
0 g
s
.683 .705 .864 r
.39784 .53603 m .40541 .53301 L .40985 .53297 L p F P
0 g
s
.683 .707 .866 r
.39784 .53603 m .40541 .53301 L .39549 .53299 L closepath p F P
0 g
s
.611 .616 .831 r
.60978 .29976 m .60821 .29675 L .61722 .29503 L closepath p F P
0 g
s
.562 .522 .768 r
.68044 .35824 m .67161 .35822 L .67008 .35415 L p F P
0 g
s
.835 .708 .724 r
.11041 .39092 m .11521 .39375 L .11101 .40014 L p F P
0 g
s
.833 .711 .731 r
.11521 .39375 m .11041 .39092 L .11488 .38444 L p F P
0 g
s
.702 .376 .423 r
.37714 .2997 m .37895 .30226 L .37855 .30372 L p F P
0 g
s
.702 .376 .423 r
.36662 .29877 m .37714 .2997 L p .37855 .30372 L F P
0 g
s
.841 .702 .71 r
.11204 .40921 m .11248 .40847 L .10907 .4033 L p F P
0 g
s
.29 .68 .974 r
.30372 .2832 m .30093 .28217 L .30241 .2831 L closepath p F P
0 g
s
.527 .438 .698 r
.69024 .41695 m .68969 .41481 L .69263 .41552 L closepath p F P
0 g
s
.417 .004 .146 r
.46153 .29485 m .46334 .29177 L .47034 .2902 L p F P
0 g
s
.735 .741 .856 r
.22728 .28209 m .21763 .28792 L .21422 .28403 L p F P
0 g
s
.314 .7 .979 r
.20461 .52563 m .20785 .52688 L p .21518 .5263 L F P
0 g
s
0 .464 .776 r
.20461 .52563 m .20208 .52495 L .20785 .52688 L closepath p F P
0 g
s
.77 .738 .823 r
.17794 .30356 m .18687 .29665 L .19163 .29958 L p F P
0 g
s
.769 .739 .825 r
.18893 .29508 m .18687 .29665 L .19163 .29958 L p F P
0 g
s
.769 .739 .825 r
.19163 .29958 m .19237 .29902 L .18893 .29508 L p F P
0 g
s
.68 .704 .865 r
.42387 .5326 m .42608 .53553 L p .41196 .53573 L F P
0 g
s
.68 .704 .865 r
.41196 .53573 m .41968 .53271 L .42387 .5326 L p F P
0 g
s
.68 .704 .865 r
.41196 .53573 m .41968 .53271 L .40985 .53297 L closepath p F P
0 g
s
.852 .673 .659 r
.10778 .43006 m .1128 .43277 L .11041 .43859 L p F P
0 g
s
.849 .68 .672 r
.1128 .43277 m .10778 .43006 L .11053 .42412 L p F P
0 g
s
.761 .74 .834 r
.20331 .29116 m .19237 .29902 L .18893 .29508 L p F P
0 g
s
.812 .729 .772 r
.13338 .34477 m .12739 .35143 L .13205 .35435 L p F P
0 g
s
.812 .728 .772 r
.12739 .35143 m .13205 .35435 L .12587 .36139 L p F P
0 g
s
.846 .697 .698 r
.10721 .4064 m .11204 .40921 L .10867 .41533 L p F P
0 g
s
.841 .702 .71 r
.10907 .4033 m .10721 .4064 L .11204 .40921 L p F P
0 g
s
.827 .717 .743 r
.11975 .37784 m .11744 .38092 L .11397 .37633 L p F P
0 g
s
.827 .717 .743 r
.11397 .37633 m .11499 .37497 L .11975 .37784 L p F P
0 g
s
.823 .72 .751 r
.11975 .37784 m .11499 .37497 L .12031 .36822 L p F P
0 g
s
.653 .699 .88 r
.54562 .2796 m .55684 .2761 L .55977 .28024 L p F P
0 g
s
.659 .72 .894 r
.55684 .2761 m .54562 .2796 L .54267 .27595 L p F P
0 g
s
.605 .85 .99 r
.55333 .53342 m .55533 .53456 L .56688 .53162 L p F P
0 g
s
.591 .86 .994 r
.56747 .53193 m .56688 .53162 L .55533 .53456 L p F P
0 g
s
.518 .421 .684 r
.69263 .41552 m .69024 .41695 L .69186 .42375 L p F P
0 g
s
.537 .465 .723 r
.69521 .39457 m .68721 .39337 L .69365 .38932 L closepath p F P
0 g
s
.544 .478 .732 r
.69216 .38458 m .69365 .38932 L .68721 .39337 L p F P
0 g
s
.544 .478 .732 r
.68737 .38403 m .69216 .38458 L p .68721 .39337 L F P
0 g
s
.52 .782 .992 r
.26755 .53601 m .26416 .53334 L .2535 .53537 L p F P
0 g
s
.616 .758 .947 r
.26416 .53334 m .2535 .53537 L .25007 .53299 L p F P
0 g
s
.489 .346 .613 r
.68666 .45413 m .68583 .44823 L .69225 .44472 L p F P
0 g
s
.562 .522 .768 r
.67008 .35415 m .67564 .35041 L p .68044 .35824 L F P
0 g
s
.566 .532 .776 r
.67008 .35415 m .66868 .35053 L .67564 .35041 L closepath p F P
0 g
s
.595 .897 .987 r
.5021 .28182 m .50323 .28221 L .51438 .27841 L p F P
0 g
s
.677 .705 .868 r
.43753 .53189 m .44021 .53541 L p .42608 .53553 L F P
0 g
s
.677 .705 .868 r
.42608 .53553 m .43542 .53198 L .43753 .53189 L p F P
0 g
s
.677 .703 .867 r
.42608 .53553 m .43542 .53198 L .42387 .5326 L closepath p F P
0 g
s
.851 .554 .485 r
.13663 .48634 m .13582 .48599 L .13649 .48457 L closepath p F P
0 g
s
.787 .339 .184 r
.15662 .50297 m .15669 .50295 L p .16562 .5094 L F P
0 g
s
.819 .411 .274 r
.15662 .50297 m .15659 .5029 L .15669 .50295 L closepath p F P
0 g
s
.337 .818 .802 r
.5956 .52634 m .59567 .52633 L .60696 .52266 L p F P
0 g
s
.815 .391 .238 r
.15659 .5029 m .15662 .50297 L .15277 .50377 L p F P
0 g
s
.815 .391 .238 r
.15277 .50377 m .15087 .50052 L .15659 .5029 L p F P
0 g
s
.787 .339 .184 r
.16562 .5094 m .15962 .50711 L .15662 .50297 L p F P
0 g
s
.785 .34 .19 r
.15962 .50711 m .15662 .50297 L .15277 .50377 L p F P
0 g
s
.337 .818 .802 r
.60696 .52266 m .6066 .52273 L .5956 .52634 L p F P
0 g
s
.442 .875 .904 r
.59287 .52626 m .5956 .52634 L .6066 .52273 L p F P
0 g
s
.419 .863 .898 r
.58159 .52963 m .59287 .52626 L .5956 .52634 L p F P
0 g
s
.609 .281 .388 r
.43549 .30114 m .4324 .29898 L .4362 .29865 L closepath p F P
0 g
s
.61 .287 .397 r
.4324 .29898 m .43549 .30114 L p .42184 .3038 L F P
0 g
s
.74 .338 .288 r
.33281 .29062 m .33485 .29109 L .33871 .29475 L p F P
0 g
s
.694 .27 .235 r
.3475 .29616 m .33871 .29475 L .33485 .29109 L p F P
0 g
s
.831 .717 .74 r
.11488 .38444 m .11744 .38092 L .11397 .37633 L p F P
0 g
s
.674 .707 .872 r
.44021 .53541 m .45126 .53136 L .45433 .53537 L p F P
0 g
s
.674 .703 .869 r
.45095 .53092 m .45126 .53136 L .44021 .53541 L p F P
0 g
s
.674 .703 .869 r
.44021 .53541 m .43753 .53189 L .45095 .53092 L p F P
0 g
s
.269 0 .135 r
.6559 .49828 m .6455 .5027 L .6441 .50624 L p F P
0 g
s
.284 0 .149 r
.6455 .5027 m .6441 .50624 L .63353 .51043 L p F P
0 g
s
.352 .043 .294 r
.65681 .49423 m .6559 .49828 L .6455 .5027 L p F P
0 g
s
.491 .093 .214 r
.46153 .29485 m .45473 .29598 L .4497 .29561 L p F P
0 g
s
.499 .118 .248 r
.45473 .29598 m .44907 .29698 L .4497 .29561 L closepath p F P
0 g
s
.486 .064 .165 r
.4497 .29561 m .44907 .29698 L .4362 .29865 L p F P
0 g
s
.702 .376 .423 r
.37855 .30372 m .3689 .30298 L .36662 .29877 L p F P
0 g
s
.716 .381 .41 r
.36412 .29849 m .36662 .29877 L .3689 .30298 L p F P
0 g
s
.565 .532 .777 r
.67564 .35041 m .66868 .35053 L .66654 .34506 L p F P
0 g
s
.179 0 0 r
.63227 .51235 m .63353 .51043 L .6441 .50624 L p F P
0 g
s
.182 0 0 r
.63353 .51043 m .63227 .51235 L .62097 .51705 L p F P
0 g
s
.851 .683 .674 r
.10559 .42137 m .11053 .42412 L .10778 .43006 L p F P
0 g
s
.847 .689 .686 r
.11053 .42412 m .10559 .42137 L .10867 .41533 L p F P
0 g
s
.818 .724 .761 r
.1255 .36182 m .12587 .36139 L .12447 .36052 L closepath p F P
0 g
s
.812 .728 .772 r
.12201 .35753 m .12739 .35143 L p .12587 .36139 L F P
0 g
s
.812 .728 .772 r
.12587 .36139 m .12447 .36052 L .12201 .35753 L p F P
0 g
s
.6 .292 .419 r
.4362 .29865 m .44907 .29698 L .44812 .30105 L p F P
0 g
s
.6 .292 .419 r
.43549 .30114 m .4362 .29865 L p .44812 .30105 L F P
0 g
s
.583 .565 .799 r
.64551 .32334 m .657 .32231 L p .65294 .32955 L F P
0 g
s
.583 .566 .801 r
.65409 .3157 m .657 .32231 L .64551 .32334 L p F P
0 g
s
.583 .566 .801 r
.65361 .31575 m .65409 .3157 L p .64551 .32334 L F P
0 g
s
.583 .566 .801 r
.64551 .32334 m .64482 .32179 L .65361 .31575 L p F P
0 g
s
.649 .691 .876 r
.57102 .27698 m .55977 .28024 L .55684 .2761 L p F P
0 g
s
.644 .677 .867 r
.55977 .28024 m .57102 .27698 L .57395 .28148 L p F P
0 g
s
.86 .593 .533 r
.13088 .47883 m .12548 .47631 L .12573 .47112 L p F P
0 g
s
.862 .595 .533 r
.12038 .46857 m .12573 .47112 L .12548 .47631 L p F P
0 g
s
.859 .615 .568 r
.12573 .47112 m .12038 .46857 L .12113 .46324 L p F P
0 g
s
.822 .725 .757 r
.12031 .36822 m .1255 .36182 L .12447 .36052 L p F P
0 g
s
.611 .619 .835 r
.61722 .29503 m .60821 .29675 L .6053 .29129 L p F P
0 g
s
.861 .617 .568 r
.11585 .46066 m .12113 .46324 L .12038 .46857 L p F P
0 g
s
.857 .633 .597 r
.12113 .46324 m .11585 .46066 L .11706 .45519 L p F P
0 g
s
.628 .757 .94 r
.26755 .53601 m .27829 .53323 L .28164 .53618 L p F P
0 g
s
.65 .75 .922 r
.27829 .53323 m .26755 .53601 L .26416 .53334 L p F P
0 g
s
.716 .381 .41 r
.3689 .30298 m .36278 .3023 L .36412 .29849 L p F P
0 g
s
.716 .381 .409 r
.35667 .29765 m .36412 .29849 L .36278 .3023 L p F P
0 g
s
.675 .695 .861 r
.46541 .53147 m .45433 .53537 L .45126 .53136 L p F P
0 g
s
.67 .711 .879 r
.45433 .53537 m .46541 .53147 L .46846 .53537 L p F P
0 g
s
.86 .566 .491 r
.13582 .48599 m .13116 .48385 L .13088 .47883 L p F P
0 g
s
.862 .568 .489 r
.12548 .47631 m .13088 .47883 L .13116 .48385 L p F P
0 g
s
.74 .338 .288 r
.33021 .29231 m .33281 .29062 L p .33871 .29475 L F P
0 g
s
.675 .205 .129 r
.33021 .29231 m .32653 .28941 L .33281 .29062 L closepath p F P
0 g
s
.603 .597 .818 r
.62538 .30617 m .62464 .30629 L .62525 .30591 L closepath p F P
0 g
s
.607 .604 .823 r
.62248 .30036 m .62525 .30591 L .62464 .30629 L p F P
0 g
s
.484 .774 .995 r
.24377 .53368 m .25007 .53299 L p .23602 .53204 L F P
0 g
s
.484 .774 .995 r
.23602 .53204 m .23621 .53215 L .24377 .53368 L p F P
0 g
s
.624 .641 .847 r
.60239 .28592 m .59107 .2885 L .58815 .28346 L p F P
0 g
s
.652 .757 .927 r
.25687 .27834 m .2676 .27488 L .27098 .27806 L p F P
0 g
s
.633 .759 .939 r
.2676 .27488 m .25687 .27834 L .25349 .27483 L p F P
0 g
s
.693 .748 .894 r
.24271 .27949 m .25349 .27483 L .25687 .27834 L p F P
0 g
s
.86 .636 .597 r
.11185 .45257 m .11706 .45519 L .11585 .46066 L p F P
0 g
s
.856 .648 .621 r
.11706 .45519 m .11185 .45257 L .11349 .44697 L p F P
0 g
s
.511 .405 .67 r
.69186 .42375 m .70115 .4182 L p .69502 .42934 L F P
0 g
s
.511 .405 .67 r
.69502 .42934 m .6929 .42849 L .69186 .42375 L p F P
0 g
s
.518 .421 .684 r
.69186 .42375 m .70115 .4182 L .69263 .41552 L p F P
0 g
s
.587 .575 .807 r
.64482 .32179 m .64261 .31694 L .65361 .31575 L closepath p F P
0 g
s
.748 .736 .841 r
.20331 .29116 m .20489 .29012 L .20013 .2875 L closepath p F P
0 g
s
.761 .74 .834 r
.20013 .2875 m .20331 .29116 L p .18893 .29508 L F P
0 g
s
.79 .735 .801 r
.1558 .32254 m .15669 .32173 L .15329 .3196 L closepath p F P
0 g
s
.796 .736 .796 r
.14855 .32943 m .1558 .32254 L .15329 .3196 L p F P
0 g
s
.04 0 0 r
.62073 .51728 m .62097 .51705 L .63227 .51235 L p F P
0 g
s
.784 .737 .809 r
.16108 .31075 m .1657 .31373 L .15669 .32173 L p F P
0 g
s
.784 .737 .809 r
.15232 .31849 m .16108 .31075 L p .15669 .32173 L F P
0 g
s
.784 .737 .809 r
.15669 .32173 m .15329 .3196 L .15232 .31849 L p F P
0 g
s
.84 .704 .713 r
.11101 .40014 m .10907 .4033 L .10564 .39821 L p F P
0 g
s
.84 .704 .713 r
.10564 .39821 m .10618 .39732 L .11101 .40014 L p F P
0 g
s
.835 .708 .724 r
.11101 .40014 m .10618 .39732 L .11041 .39092 L p F P
0 g
s
.58 .555 .791 r
.65294 .32955 m .65991 .32904 L p .66223 .33595 L F P
0 g
s
.578 .556 .794 r
.65991 .32904 m .65294 .32955 L .65852 .32577 L closepath p F P
0 g
s
.583 .565 .799 r
.657 .32231 m .65852 .32577 L .65294 .32955 L p F P
0 g
s
.831 .717 .74 r
.11397 .37633 m .11018 .38156 L .11488 .38444 L p F P
0 g
s
.834 .715 .732 r
.11018 .38156 m .11488 .38444 L .11041 .39092 L p F P
0 g
s
.685 .75 .901 r
.25349 .27483 m .24271 .27949 L .23932 .27581 L p F P
0 g
s
.352 .05 .306 r
.6559 .49828 m .65681 .49423 L .66706 .48959 L p F P
0 g
s
.396 .136 .398 r
.66756 .48511 m .66706 .48959 L .65681 .49423 L p F P
0 g
s
.596 .59 .816 r
.62538 .30617 m .6368 .30455 L .6397 .31061 L p F P
0 g
s
.597 .594 .819 r
.63445 .29966 m .6368 .30455 L .62538 .30617 L p F P
0 g
s
.597 .594 .819 r
.62538 .30617 m .62525 .30591 L .63445 .29966 L p F P
0 g
s
.846 .514 .425 r
.14339 .49354 m .13768 .49114 L .13663 .48634 L p F P
0 g
s
.848 .516 .424 r
.13582 .48599 m .13663 .48634 L .13768 .49114 L p F P
0 g
s
.505 .752 .984 r
.27098 .27806 m .28165 .27624 L .27858 .27405 L p F P
0 g
s
.505 .752 .984 r
.2676 .27488 m .27098 .27806 L p .27858 .27405 L F P
0 g
s
.559 .766 .975 r
.27098 .27806 m .28165 .27624 L .28503 .27888 L p F P
0 g
s
.601 .602 .824 r
.6339 .29855 m .63445 .29966 L .62525 .30591 L p F P
0 g
s
.601 .602 .824 r
.62525 .30591 m .62248 .30036 L .6339 .29855 L p F P
0 g
s
0 0 0 r
.48909 .28515 m .48708 .28614 L .47536 .28915 L p F P
0 g
s
.798 .735 .793 r
.14855 .32943 m .14463 .33324 L .14114 .32915 L p F P
0 g
s
.798 .735 .793 r
.14114 .32915 m .1439 .32647 L .14855 .32943 L p F P
0 g
s
.796 .736 .796 r
.15201 .31877 m .1439 .32647 L .14855 .32943 L p F P
0 g
s
.796 .736 .796 r
.15329 .3196 m .15201 .31877 L p .14855 .32943 L F P
0 g
s
.666 .718 .887 r
.46846 .53537 m .47956 .53163 L .4826 .53539 L p F P
0 g
s
.671 .701 .869 r
.47956 .53163 m .46846 .53537 L .46541 .53147 L p F P
0 g
s
.786 .739 .809 r
.16343 .30871 m .16108 .31075 L .1657 .31373 L p F P
0 g
s
.786 .739 .809 r
.1657 .31373 m .1669 .31269 L .16343 .30871 L p F P
0 g
s
.336 0 0 r
.47493 .28964 m .47034 .2902 L .47536 .28915 L closepath p F P
0 g
s
.417 .004 .146 r
.47034 .2902 m .47493 .28964 L p .46153 .29485 L F P
0 g
s
.655 .748 .918 r
.28164 .53618 m .29243 .53279 L .29575 .53599 L p F P
0 g
s
.671 .74 .902 r
.29243 .53279 m .28164 .53618 L .27829 .53323 L p F P
0 g
s
.395 0 0 r
.18232 .51765 m .1872 .52024 L .18496 .51946 L p F P
0 g
s
.395 0 0 r
.17602 .51547 m .18232 .51765 L p .18496 .51946 L F P
0 g
s
.631 .075 0 r
.18232 .51765 m .17602 .51547 L .1736 .51376 L p F P
0 g
s
.78 .739 .815 r
.17568 .3054 m .1669 .31269 L .16343 .30871 L p F P
0 g
s
.565 .532 .777 r
.66654 .34506 m .66959 .34297 L p .67564 .35041 L F P
0 g
s
.569 .541 .784 r
.66654 .34506 m .66575 .34311 L .66959 .34297 L closepath p F P
0 g
s
.743 .737 .847 r
.2108 .28017 m .21422 .28403 L .20489 .29012 L p F P
0 g
s
.743 .737 .847 r
.19989 .28722 m .2108 .28017 L p .20489 .29012 L F P
0 g
s
.743 .737 .847 r
.20489 .29012 m .20013 .2875 L .19989 .28722 L p F P
0 g
s
.858 .651 .622 r
.10836 .44431 m .11349 .44697 L .11185 .45257 L p F P
0 g
s
.854 .661 .641 r
.11349 .44697 m .10836 .44431 L .11041 .43859 L p F P
0 g
s
.378 .746 .991 r
.2293 .52997 m .22205 .53011 L .21854 .52828 L p F P
0 g
s
.268 .707 .963 r
.22205 .53011 m .2293 .52997 L .23585 .53204 L p F P
0 g
s
.803 .735 .788 r
.14094 .33695 m .14463 .33324 L .14114 .32915 L p F P
0 g
s
.632 .077 0 r
.17602 .51547 m .17017 .51347 L .1736 .51376 L closepath p F P
0 g
s
.635 .662 .859 r
.57437 .28217 m .57395 .28148 L .57703 .28067 L closepath p F P
0 g
s
.517 .423 .687 r
.69975 .41118 m .69263 .41552 L .70115 .4182 L p F P
0 g
s
.527 .438 .698 r
.6983 .40561 m .69975 .41118 L .69263 .41552 L p F P
0 g
s
.527 .438 .698 r
.69634 .40511 m .6983 .40561 L p .69263 .41552 L F P
0 g
s
.735 .741 .856 r
.21422 .28403 m .22235 .2792 L .22728 .28209 L p F P
0 g
s
.737 .743 .856 r
.2251 .27758 m .22235 .2792 L .22728 .28209 L p F P
0 g
s
.737 .743 .856 r
.22728 .28209 m .2285 .28136 L .2251 .27758 L p F P
0 g
s
.822 .725 .757 r
.12447 .36052 m .12122 .35846 L p .12031 .36822 L F P
0 g
s
.819 .728 .765 r
.12447 .36052 m .12201 .35753 L .12122 .35846 L closepath p F P
0 g
s
.552 .889 .985 r
.59287 .52626 m .58159 .52963 L .57874 .52871 L p F P
0 g
s
.546 .885 .986 r
.56747 .53193 m .57874 .52871 L .58159 .52963 L p F P
0 g
s
.542 .477 .733 r
.69216 .38458 m .68737 .38403 L .69122 .38157 L closepath p F P
0 g
s
.549 .489 .741 r
.68915 .3753 m .69122 .38157 L .68737 .38403 L p F P
0 g
s
.549 .489 .741 r
.6863 .37506 m .68915 .3753 L p .68737 .38403 L F P
0 g
s
.449 .252 .519 r
.68429 .46696 m .67771 .4703 L .67783 .47543 L p F P
0 g
s
.471 .293 .557 r
.67771 .4703 m .68429 .46696 L .68296 .46204 L p F P
0 g
s
.803 .734 .788 r
.13635 .33398 m .14094 .33695 L .13381 .34431 L p F P
0 g
s
.803 .735 .788 r
.14114 .32915 m .13635 .33398 L .14094 .33695 L p F P
0 g
s
.848 .516 .424 r
.13768 .49114 m .13281 .48905 L .13582 .48599 L p F P
0 g
s
.859 .532 .434 r
.13116 .48385 m .13582 .48599 L .13281 .48905 L p F P
0 g
s
.671 .738 .901 r
.29575 .53599 m .30659 .53213 L .30987 .53556 L p F P
0 g
s
.684 .73 .886 r
.30659 .53213 m .29575 .53599 L .29243 .53279 L p F P
0 g
s
.569 .542 .785 r
.66959 .34297 m .66575 .34311 L .66282 .33592 L p F P
0 g
s
.683 .704 .864 r
.40985 .53297 m .40884 .53163 L .40541 .53301 L closepath p F P
0 g
s
.683 .707 .866 r
.40571 .5272 m .40884 .53163 L .40541 .53301 L p F P
0 g
s
.683 .707 .866 r
.3947 .53198 m .40571 .5272 L p .40541 .53301 L F P
0 g
s
.683 .707 .866 r
.40541 .53301 m .39549 .53299 L .3947 .53198 L p F P
0 g
s
.849 .692 .687 r
.10382 .41254 m .10867 .41533 L .10559 .42137 L p F P
0 g
s
.846 .697 .698 r
.10867 .41533 m .10382 .41254 L .10721 .4064 L p F P
0 g
s
.716 .381 .409 r
.36278 .3023 m .35894 .30186 L .35667 .29765 L p F P
0 g
s
.733 .404 .424 r
.3477 .2962 m .35667 .29765 L .35894 .30186 L p F P
0 g
s
.714 .321 .302 r
.35667 .29765 m .3477 .2962 L .34758 .29606 L p F P
0 g
s
.684 .707 .865 r
.39549 .53299 m .3947 .53198 L .39227 .53296 L closepath p F P
0 g
s
.662 .727 .898 r
.4826 .53539 m .49372 .5318 L .49674 .53536 L p F P
0 g
s
.667 .707 .878 r
.49372 .5318 m .4826 .53539 L .47956 .53163 L p F P
0 g
s
0 0 0 r
.61828 .51871 m .62073 .51728 L .63142 .51326 L p F P
0 g
s
.04 0 0 r
.63227 .51235 m .63142 .51326 L .62073 .51728 L p F P
0 g
s
0 0 0 r
.60696 .52266 m .61828 .51871 L .62073 .51728 L p F P
0 g
s
.681 .704 .865 r
.41968 .53271 m .40985 .53297 L .40884 .53163 L p F P
0 g
s
.685 .712 .868 r
.39156 .5276 m .3947 .53198 L .39227 .53296 L p F P
0 g
s
.685 .712 .868 r
.38056 .53245 m .39156 .5276 L p .39227 .53296 L F P
0 g
s
.685 .712 .868 r
.39227 .53296 m .3807 .53262 L .38056 .53245 L p F P
0 g
s
.822 .724 .756 r
.11566 .3653 m .12031 .36822 L .11499 .37497 L p F P
0 g
s
.822 .725 .757 r
.12122 .35846 m .11566 .3653 L .12031 .36822 L p F P
0 g
s
.719 .203 0 r
.17017 .51347 m .1697 .51329 L .16562 .5094 L p F P
0 g
s
.702 .173 0 r
.15962 .50711 m .16562 .5094 L .1697 .51329 L p F P
0 g
s
.78 .739 .815 r
.16343 .30871 m .17102 .30242 L .17568 .3054 L p F P
0 g
s
.778 .74 .818 r
.17448 .29961 m .17102 .30242 L .17568 .3054 L p F P
0 g
s
.778 .74 .818 r
.17568 .3054 m .17794 .30356 L .17448 .29961 L p F P
0 g
s
.713 .745 .877 r
.23932 .27581 m .2285 .28136 L .2251 .27758 L p F P
0 g
s
.681 .729 .886 r
.30987 .53556 m .32075 .53134 L .32401 .53498 L p F P
0 g
s
.691 .721 .872 r
.32075 .53134 m .30987 .53556 L .30659 .53213 L p F P
0 g
s
.595 .897 .987 r
.51438 .27841 m .51308 .27792 L .5021 .28182 L p F P
0 g
s
.636 .674 .869 r
.57703 .28067 m .57395 .28148 L .57102 .27698 L p F P
0 g
s
.22 0 0 r
.31636 .28623 m .31888 .2875 L .32653 .28941 L p F P
0 g
s
.501 0 0 r
.31888 .2875 m .31396 .28601 L .31636 .28623 L closepath p F P
0 g
s
.01 .541 .85 r
.20208 .52495 m .20461 .52563 L .20105 .52398 L p F P
0 g
s
.687 .721 .875 r
.32401 .53498 m .33492 .5305 L .33815 .53432 L p F P
0 g
s
.696 .71 .859 r
.33492 .5305 m .32401 .53498 L .32075 .53134 L p F P
0 g
s
.771 .74 .825 r
.18687 .29665 m .17794 .30356 L .17448 .29961 L p F P
0 g
s
.837 .461 .34 r
.15087 .50052 m .14518 .49812 L .14339 .49354 L p F P
0 g
s
.837 .457 .332 r
.13768 .49114 m .14339 .49354 L .14518 .49812 L p F P
0 g
s
.856 .665 .642 r
.10536 .43589 m .11041 .43859 L .10836 .44431 L p F P
0 g
s
.852 .673 .659 r
.11041 .43859 m .10536 .43589 L .10778 .43006 L p F P
0 g
s
.691 .712 .865 r
.3501 .53093 m .35229 .53365 L p .33815 .53432 L F P
0 g
s
.691 .712 .865 r
.33815 .53432 m .34661 .5307 L .3501 .53093 L p F P
0 g
s
.7 .708 .854 r
.34661 .5307 m .33815 .53432 L .33492 .5305 L p F P
0 g
s
.843 .705 .71 r
.10721 .4064 m .10907 .4033 L .10564 .39821 L p F P
0 g
s
.681 .703 .864 r
.42387 .5326 m .42298 .53142 L .41968 .53271 L closepath p F P
0 g
s
.681 .704 .865 r
.41987 .52697 m .42298 .53142 L .41968 .53271 L p F P
0 g
s
.681 .704 .865 r
.40884 .53163 m .41987 .52697 L p .41968 .53271 L F P
0 g
s
.511 .405 .67 r
.69331 .43034 m .6929 .42849 L .69502 .42934 L closepath p F P
0 g
s
.692 .705 .857 r
.36565 .53201 m .36643 .53301 L p .35229 .53365 L F P
0 g
s
.692 .705 .857 r
.35229 .53365 m .35703 .53157 L .36565 .53201 L p F P
0 g
s
.694 .714 .864 r
.35229 .53365 m .35703 .53157 L .3501 .53093 L closepath p F P
0 g
s
.467 .291 .558 r
.68728 .4598 m .68296 .46204 L .68429 .46696 L p F P
0 g
s
.485 .325 .589 r
.68296 .46204 m .68728 .4598 L .68666 .45413 L p F P
0 g
s
.69 .375 .436 r
.39144 .30434 m .37977 .3038 L .37895 .30226 L p F P
0 g
s
.697 .377 .431 r
.37977 .3038 m .37855 .30372 L .37895 .30226 L closepath p F P
0 g
s
.711 .273 .207 r
.32653 .28941 m .33021 .29231 L .32979 .29274 L p F P
0 g
s
.711 .273 .207 r
.31888 .2875 m .32653 .28941 L p .32979 .29274 L F P
0 g
s
.685 .711 .869 r
.3807 .53262 m .38056 .53245 L .38018 .5326 L closepath p F P
0 g
s
.809 .731 .778 r
.13338 .34477 m .13381 .34431 L .13208 .34321 L closepath p F P
0 g
s
.803 .734 .788 r
.12989 .34063 m .13635 .33398 L p .13381 .34431 L F P
0 g
s
.803 .734 .788 r
.13381 .34431 m .13208 .34321 L .12989 .34063 L p F P
0 g
s
.657 .741 .911 r
.49674 .53536 m .50789 .53191 L .51089 .53524 L p F P
0 g
s
.663 .718 .89 r
.50789 .53191 m .49674 .53536 L .49372 .5318 L p F P
0 g
s
.692 .7 .853 r
.36643 .53301 m .36833 .53217 L .38018 .5326 L p F P
0 g
s
.694 .706 .857 r
.36643 .53301 m .36833 .53217 L .36565 .53201 L closepath p F P
0 g
s
.682 .696 .857 r
.3774 .52816 m .36833 .53217 L .38018 .5326 L p F P
0 g
s
.682 .696 .857 r
.38018 .5326 m .38056 .53245 L .3774 .52816 L p F P
0 g
s
.677 .702 .866 r
.43542 .53198 m .42387 .5326 L .42298 .53142 L p F P
0 g
s
.475 .318 .588 r
.68728 .4598 m .68666 .45413 L .69645 .44878 L p F P
0 g
s
.489 .346 .613 r
.69643 .44865 m .69645 .44878 L .68666 .45413 L p F P
0 g
s
.489 .346 .613 r
.69225 .44472 m .69643 .44865 L p .68666 .45413 L F P
0 g
s
.814 .731 .774 r
.12739 .35143 m .13338 .34477 L .13208 .34321 L p F P
0 g
s
.501 .729 .975 r
.28503 .27888 m .28977 .27889 L .29664 .28109 L p F P
0 g
s
.424 .71 .983 r
.28977 .27889 m .28503 .27888 L .28165 .27624 L p F P
0 g
s
.696 .685 .836 r
.39156 .5276 m .38056 .53245 L .3774 .52816 L p F P
0 g
s
.28 0 0 r
.47493 .28964 m .47536 .28915 L .48708 .28614 L p F P
0 g
s
.564 .253 .399 r
.44812 .30105 m .44907 .29698 L .45473 .29598 L p F P
0 g
s
.603 .859 .992 r
.56688 .53162 m .56747 .53193 L .57874 .52871 L p F P
0 g
s
.587 .576 .808 r
.65361 .31575 m .64261 .31694 L .63992 .31107 L p F P
0 g
s
.693 .682 .835 r
.40571 .5272 m .3947 .53198 L .39156 .5276 L p F P
0 g
s
.501 .384 .653 r
.69502 .42934 m .69331 .43034 L .69454 .4367 L p F P
0 g
s
.652 .759 .928 r
.51089 .53524 m .52206 .53191 L .52504 .53494 L p F P
0 g
s
.658 .732 .904 r
.52206 .53191 m .51089 .53524 L .50789 .53191 L p F P
0 g
s
.077 .584 .888 r
.29559 .27991 m .28977 .27889 L .29664 .28109 L p F P
0 g
s
.392 .133 .397 r
.67767 .48027 m .66756 .48511 L .66706 .48959 L p F P
0 g
s
.433 .208 .471 r
.67783 .47543 m .67767 .48027 L .66756 .48511 L p F P
0 g
s
.836 .713 .728 r
.10568 .38805 m .11041 .39092 L .10618 .39732 L p F P
0 g
s
.834 .715 .732 r
.11041 .39092 m .10568 .38805 L .11018 .38156 L p F P
0 g
s
.694 .706 .857 r
.37424 .52362 m .3774 .52816 L .36833 .53217 L p F P
0 g
s
.694 .706 .857 r
.36324 .52885 m .37424 .52362 L p .36833 .53217 L F P
0 g
s
.694 .706 .857 r
.36833 .53217 m .36565 .53201 L .36324 .52885 L p F P
0 g
s
.575 .547 .786 r
.66282 .33592 m .66223 .33595 L .66271 .33563 L closepath p F P
0 g
s
.58 .555 .791 r
.65991 .32904 m .66271 .33563 L .66223 .33595 L p F P
0 g
s
.69 .679 .835 r
.41987 .52697 m .40884 .53163 L .40571 .5272 L p F P
0 g
s
.405 .739 .992 r
.23602 .53204 m .23585 .53204 L .23621 .53215 L closepath p F P
0 g
s
.771 .74 .825 r
.17448 .29961 m .18218 .29367 L .18687 .29665 L p F P
0 g
s
.769 .741 .827 r
.18548 .29117 m .18218 .29367 L .18687 .29665 L p F P
0 g
s
.769 .741 .827 r
.18687 .29665 m .18893 .29508 L .18548 .29117 L p F P
0 g
s
.855 .676 .66 r
.10282 .42731 m .10778 .43006 L .10536 .43589 L p F P
0 g
s
.851 .683 .674 r
.10778 .43006 m .10282 .42731 L .10559 .42137 L p F P
0 g
s
.644 .782 .948 r
.52504 .53494 m .53623 .5317 L .53919 .53437 L p F P
0 g
s
.653 .751 .922 r
.53623 .5317 m .52504 .53494 L .52206 .53191 L p F P
0 g
s
.678 .401 .495 r
.40442 .30444 m .408 .30441 L .40747 .30901 L p F P
0 g
s
.678 .401 .495 r
.40747 .30901 m .40569 .30903 L .40442 .30444 L p F P
0 g
s
.683 .405 .494 r
.39359 .3044 m .40442 .30444 L .40569 .30903 L p F P
0 g
s
.605 .85 .99 r
.56688 .53162 m .56458 .53025 L .55333 .53342 L p F P
0 g
s
.636 .809 .966 r
.56458 .53025 m .55333 .53342 L .55041 .53119 L p F P
0 g
s
.632 .813 .969 r
.53919 .53437 m .55041 .53119 L .55333 .53342 L p F P
0 g
s
.468 .752 .991 r
.23585 .53204 m .23602 .53204 L .23256 .52976 L p F P
0 g
s
.468 .752 .991 r
.23256 .52976 m .2293 .52997 L .23585 .53204 L p F P
0 g
s
.546 .489 .743 r
.68915 .3753 m .6863 .37506 L .68858 .37358 L closepath p F P
0 g
s
.553 .501 .751 r
.68617 .36658 m .68858 .37358 L .6863 .37506 L p F P
0 g
s
.553 .501 .751 r
.68399 .36646 m .68617 .36658 L p .6863 .37506 L F P
0 g
s
.662 .387 .493 r
.408 .30441 m .41928 .30392 L .42078 .30844 L p F P
0 g
s
.662 .387 .493 r
.42078 .30844 m .40747 .30901 L .408 .30441 L p F P
0 g
s
.683 .405 .494 r
.40569 .30903 m .39302 .30898 L .39359 .3044 L p F P
0 g
s
.695 .415 .495 r
.39144 .30434 m .39359 .3044 L .39302 .30898 L p F P
0 g
s
.692 .705 .857 r
.36565 .53201 m .36324 .52885 L .35703 .53157 L closepath p F P
0 g
s
.678 .704 .867 r
.43753 .53189 m .43712 .53134 L .43542 .53198 L closepath p F P
0 g
s
.677 .702 .866 r
.43402 .52689 m .43712 .53134 L .43542 .53198 L p F P
0 g
s
.677 .702 .866 r
.42298 .53142 m .43402 .52689 L p .43542 .53198 L F P
0 g
s
.848 .701 .699 r
.10245 .40356 m .10721 .4064 L .10382 .41254 L p F P
0 g
s
.843 .705 .71 r
.10564 .39821 m .10245 .40356 L .10721 .4064 L p F P
0 g
s
.647 .777 .943 r
.55041 .53119 m .53919 .53437 L .53623 .5317 L p F P
0 g
s
.484 .774 .995 r
.25007 .53299 m .24665 .5304 L .23602 .53204 L p F P
0 g
s
.594 .759 .957 r
.24665 .5304 m .23602 .53204 L .23256 .52976 L p F P
0 g
s
.695 .415 .495 r
.39302 .30898 m .39256 .30897 L .39144 .30434 L p F P
0 g
s
.701 .424 .502 r
.37977 .3038 m .39144 .30434 L .39256 .30897 L p F P
0 g
s
.733 .742 .859 r
.22235 .2792 m .21422 .28403 L .2108 .28017 L p F P
0 g
s
.816 .731 .77 r
.12739 .35143 m .12201 .35753 L .11851 .35334 L p F P
0 g
s
.816 .731 .77 r
.11851 .35334 m .12279 .34846 L .12739 .35143 L p F P
0 g
s
.814 .731 .774 r
.12922 .34134 m .12279 .34846 L .12739 .35143 L p F P
0 g
s
.814 .731 .774 r
.13208 .34321 m .12922 .34134 L p .12739 .35143 L F P
0 g
s
.829 .72 .744 r
.11397 .37633 m .11499 .37497 L .11103 .37252 L closepath p F P
0 g
s
.822 .724 .756 r
.11048 .37184 m .11566 .3653 L p .11499 .37497 L F P
0 g
s
.822 .724 .756 r
.11499 .37497 m .11103 .37252 L .11048 .37184 L p F P
0 g
s
.761 .74 .834 r
.18893 .29508 m .1998 .28729 L .20013 .2875 L p F P
0 g
s
.761 .742 .836 r
.1998 .28729 m .18893 .29508 L .18548 .29117 L p F P
0 g
s
.812 .377 .209 r
.15087 .50052 m .15277 .50377 L .15126 .5039 L p F P
0 g
s
.812 .377 .209 r
.14518 .49812 m .15087 .50052 L p .15126 .5039 L F P
0 g
s
.569 .542 .785 r
.66282 .33592 m .67439 .33555 L p .66959 .34297 L F P
0 g
s
.567 .543 .787 r
.67179 .32919 m .67439 .33555 L .66282 .33592 L p F P
0 g
s
.567 .543 .787 r
.66282 .33592 m .66271 .33563 L .67179 .32919 L p F P
0 g
s
.682 .705 .865 r
.44818 .52697 m .45095 .53092 L .43753 .53189 L p F P
0 g
s
.682 .705 .865 r
.43753 .53189 m .43712 .53134 L .44818 .52697 L p F P
0 g
s
.686 .677 .836 r
.43402 .52689 m .42298 .53142 L .41987 .52697 L p F P
0 g
s
.572 .552 .794 r
.67147 .32843 m .67179 .32919 L .66271 .33563 L p F P
0 g
s
.572 .552 .794 r
.66271 .33563 m .65991 .32904 L .67147 .32843 L p F P
0 g
s
.611 .619 .835 r
.6053 .29129 m .61667 .28908 L p .61722 .29503 L F P
0 g
s
.613 .624 .838 r
.61377 .28364 m .61667 .28908 L .6053 .29129 L p F P
0 g
s
.613 .624 .838 r
.60416 .28555 m .61377 .28364 L p .6053 .29129 L F P
0 g
s
.613 .624 .838 r
.6053 .29129 m .60271 .2865 L .60416 .28555 L p F P
0 g
s
.633 .663 .861 r
.58524 .27855 m .57703 .28067 L .58397 .27649 L closepath p F P
0 g
s
.636 .674 .869 r
.58232 .27388 m .58397 .27649 L .57703 .28067 L p F P
0 g
s
.636 .674 .869 r
.57102 .27698 m .58232 .27388 L p .57703 .28067 L F P
0 g
s
.719 .32 .291 r
.3477 .2962 m .3475 .29616 L .34758 .29606 L closepath p F P
0 g
s
.833 .72 .74 r
.11018 .38156 m .11397 .37633 L .11103 .37252 L p F P
0 g
s
.667 .763 .922 r
.52852 .27667 m .53972 .27278 L .54267 .27595 L p F P
0 g
s
.673 .813 .95 r
.53972 .27278 m .52852 .27667 L .52556 .27441 L p F P
0 g
s
.664 .829 .963 r
.51438 .27841 m .52556 .27441 L .52852 .27667 L p F P
0 g
s
.733 .404 .424 r
.35894 .30186 m .34961 .30053 L .3477 .2962 L p F P
0 g
s
.745 .409 .414 r
.3475 .29616 m .3477 .2962 L .34961 .30053 L p F P
0 g
s
.659 .72 .894 r
.54267 .27595 m .5539 .27228 L .55684 .2761 L p F P
0 g
s
.667 .749 .912 r
.5539 .27228 m .54267 .27595 L .53972 .27278 L p F P
0 g
s
.745 .409 .414 r
.34961 .30053 m .34607 .29991 L .3475 .29616 L p F P
0 g
s
.738 .4 .409 r
.33871 .29475 m .3475 .29616 L .34607 .29991 L p F P
0 g
s
.6 .292 .419 r
.44812 .30105 m .43722 .30239 L .43549 .30114 L p F P
0 g
s
.598 .294 .424 r
.43722 .30239 m .43518 .30265 L .43549 .30114 L closepath p F P
0 g
s
.61 .287 .397 r
.43549 .30114 m .43518 .30265 L .42184 .3038 L p F P
0 g
s
.601 .603 .826 r
.6339 .29855 m .62248 .30036 L .61958 .2946 L p F P
0 g
s
.614 .848 .988 r
.56458 .53025 m .56688 .53162 L .57826 .52845 L p F P
0 g
s
.603 .859 .992 r
.57874 .52871 m .57826 .52845 L .56688 .53162 L p F P
0 g
s
.81 .734 .781 r
.13208 .34321 m .12989 .34063 L .12922 .34134 L closepath p F P
0 g
s
.66 .386 .494 r
.41928 .30392 m .42184 .3038 L .42133 .30841 L p F P
0 g
s
.66 .386 .494 r
.42133 .30841 m .42078 .30844 L .41928 .30392 L p F P
0 g
s
.694 .713 .863 r
.36006 .52444 m .36324 .52885 L .35703 .53157 L p F P
0 g
s
.694 .713 .863 r
.34908 .52965 m .36006 .52444 L p .35703 .53157 L F P
0 g
s
.694 .713 .863 r
.35703 .53157 m .3501 .53093 L .34908 .52965 L p F P
0 g
s
.793 .738 .802 r
.15329 .3196 m .15232 .31849 L .15201 .31877 L closepath p F P
0 g
s
.682 .677 .839 r
.44818 .52697 m .43712 .53134 L .43402 .52689 L p F P
0 g
s
.28 0 0 r
.48708 .28614 m .48604 .28755 L .47493 .28964 L p F P
0 g
s
.406 .015 .181 r
.47363 .29227 m .47493 .28964 L .48604 .28755 L p F P
0 g
s
.417 .004 .146 r
.47493 .28964 m .47363 .29227 L .46153 .29485 L p F P
0 g
s
.564 .243 .383 r
.46071 .29809 m .45473 .29598 L .46153 .29485 L closepath p F P
0 g
s
.564 .253 .399 r
.45473 .29598 m .46071 .29809 L p .44812 .30105 L F P
0 g
s
.641 .369 .491 r
.42133 .30841 m .42184 .3038 L .43518 .30265 L p F P
0 g
s
.701 .424 .502 r
.39256 .30897 m .38069 .30849 L .37977 .3038 L p F P
0 g
s
.71 .43 .499 r
.37855 .30372 m .37977 .3038 L .38069 .30849 L p F P
0 g
s
.624 .641 .847 r
.58815 .28346 m .59948 .28081 L .60239 .28592 L p F P
0 g
s
.627 .647 .851 r
.59948 .28081 m .58815 .28346 L .58524 .27855 L p F P
0 g
s
.717 .436 .499 r
.3689 .30298 m .37855 .30372 L .37797 .30832 L p F P
0 g
s
.71 .43 .499 r
.38069 .30849 m .37797 .30832 L .37855 .30372 L p F P
0 g
s
.511 .405 .67 r
.70149 .41835 m .70287 .42464 L .69502 .42934 L p F P
0 g
s
.511 .405 .67 r
.70115 .4182 m .70149 .41835 L p .69502 .42934 L F P
0 g
s
.501 .384 .653 r
.69454 .4367 m .70131 .43273 L .69502 .42934 L p F P
0 g
s
.499 .385 .655 r
.70287 .42464 m .69502 .42934 L .70131 .43273 L p F P
0 g
s
.564 .533 .779 r
.67732 .34287 m .66959 .34297 L .67569 .33873 L closepath p F P
0 g
s
.569 .542 .785 r
.67439 .33555 m .67569 .33873 L .66959 .34297 L p F P
0 g
s
.565 .532 .777 r
.66959 .34297 m .67732 .34287 L p .67564 .35041 L F P
0 g
s
.862 .595 .533 r
.12548 .47631 m .12013 .47375 L .12038 .46857 L p F P
0 g
s
.865 .597 .532 r
.11509 .46599 m .12038 .46857 L .12013 .47375 L p F P
0 g
s
.861 .617 .568 r
.12038 .46857 m .11509 .46599 L .11585 .46066 L p F P
0 g
s
.551 .501 .753 r
.68617 .36658 m .68399 .36646 L .68573 .36531 L closepath p F P
0 g
s
.557 .511 .76 r
.6832 .35832 m .68573 .36531 L .68399 .36646 L p F P
0 g
s
.557 .511 .76 r
.68044 .35824 m .6832 .35832 L p .68399 .36646 L F P
0 g
s
.864 .62 .569 r
.11062 .45804 m .11585 .46066 L .11509 .46599 L p F P
0 g
s
.86 .636 .597 r
.11585 .46066 m .11062 .45804 L .11185 .45257 L p F P
0 g
s
.82 .731 .766 r
.12122 .35846 m .12201 .35753 L .11851 .35334 L p F P
0 g
s
.853 .687 .675 r
.10072 .41858 m .10559 .42137 L .10282 .42731 L p F P
0 g
s
.849 .692 .687 r
.10559 .42137 m .10072 .41858 L .10382 .41254 L p F P
0 g
s
.314 .7 .979 r
.21518 .5263 m .2149 .5262 L .20461 .52563 L p F P
0 g
s
.258 .695 .962 r
.2149 .5262 m .20461 .52563 L .20105 .52398 L p F P
0 g
s
.862 .568 .489 r
.13116 .48385 m .12577 .48133 L .12548 .47631 L p F P
0 g
s
.865 .569 .486 r
.12013 .47375 m .12548 .47631 L .12577 .48133 L p F P
0 g
s
.614 .899 .987 r
.51308 .27792 m .51438 .27841 L .52556 .27441 L p F P
0 g
s
.824 .728 .759 r
.11668 .35549 m .12122 .35846 L .11566 .3653 L p F P
0 g
s
.82 .731 .766 r
.11851 .35334 m .11668 .35549 L .12122 .35846 L p F P
0 g
s
.649 .691 .876 r
.55684 .2761 m .5681 .27271 L .57102 .27698 L p F P
0 g
s
.655 .709 .887 r
.5681 .27271 m .55684 .2761 L .5539 .27228 L p F P
0 g
s
.349 .824 .794 r
.6066 .52273 m .60696 .52266 L .61828 .51871 L p F P
0 g
s
.395 0 0 r
.18496 .51946 m .18265 .5186 L .17602 .51547 L p F P
0 g
s
.322 0 0 r
.17017 .51347 m .17602 .51547 L .18265 .5186 L p F P
0 g
s
.675 .695 .861 r
.46419 .52977 m .46541 .53147 L p .45126 .53136 L F P
0 g
s
.675 .695 .861 r
.45126 .53136 m .45298 .53072 L .46419 .52977 L p F P
0 g
s
.674 .689 .856 r
.45126 .53136 m .45298 .53072 L .45095 .53092 L closepath p F P
0 g
s
.616 .758 .947 r
.25007 .53299 m .26078 .53045 L .26416 .53334 L p F P
0 g
s
.64 .752 .93 r
.26078 .53045 m .25007 .53299 L .24665 .5304 L p F P
0 g
s
.487 .346 .614 r
.69643 .44865 m .69225 .44472 L .6956 .44285 L closepath p F P
0 g
s
.5 .37 .635 r
.69225 .44472 m .6956 .44285 L .69454 .4367 L p F P
0 g
s
.862 .639 .599 r
.10669 .44992 m .11185 .45257 L .11062 .45804 L p F P
0 g
s
.858 .651 .622 r
.11185 .45257 m .10669 .44992 L .10836 .44431 L p F P
0 g
s
.562 .522 .768 r
.67564 .35041 m .68026 .35044 L p .68044 .35824 L F P
0 g
s
.56 .522 .771 r
.68026 .35044 m .67564 .35041 L .6793 .34791 L closepath p F P
0 g
s
.565 .532 .777 r
.67732 .34287 m .6793 .34791 L .67564 .35041 L p F P
0 g
s
.555 .512 .762 r
.6832 .35832 m .68044 .35824 L .68264 .35676 L closepath p F P
0 g
s
.562 .522 .768 r
.68026 .35044 m .68264 .35676 L .68044 .35824 L p F P
0 g
s
.862 .533 .428 r
.12577 .48133 m .13116 .48385 L .13204 .4887 L p F P
0 g
s
.859 .532 .434 r
.13281 .48905 m .13204 .4887 L .13116 .48385 L p F P
0 g
s
.587 .576 .808 r
.63992 .31107 m .64076 .31048 L p .65361 .31575 L F P
0 g
s
.59 .584 .814 r
.63992 .31107 m .6397 .31061 L .64076 .31048 L closepath p F P
0 g
s
.711 .273 .207 r
.32979 .29274 m .32256 .29121 L .31888 .2875 L p F P
0 g
s
.75 .326 .244 r
.31396 .28601 m .31888 .2875 L .32256 .29121 L p F P
0 g
s
.49 .363 .635 r
.6956 .44285 m .69454 .4367 L .70131 .43273 L p F P
0 g
s
.759 .74 .836 r
.20013 .2875 m .19989 .28722 L .1998 .28729 L closepath p F P
0 g
s
.691 .712 .865 r
.3501 .53093 m .34908 .52965 L .34661 .5307 L closepath p F P
0 g
s
.674 .688 .855 r
.45298 .53072 m .45095 .53092 L .44818 .52697 L p F P
0 g
s
.179 0 0 r
.6441 .50624 m .64359 .5071 L .63227 .51235 L p F P
0 g
s
.037 0 0 r
.63142 .51326 m .63227 .51235 L .64359 .5071 L p F P
0 g
s
.842 .707 .714 r
.10564 .39821 m .10618 .39732 L .1042 .39613 L closepath p F P
0 g
s
.836 .713 .728 r
.10217 .39335 m .10568 .38805 L p .10618 .39732 L F P
0 g
s
.836 .713 .728 r
.10618 .39732 m .1042 .39613 L .10217 .39335 L p F P
0 g
s
.59 .587 .817 r
.64076 .31048 m .6397 .31061 L .6368 .30455 L p F P
0 g
s
.789 .741 .808 r
.16108 .31075 m .15232 .31849 L .14883 .31454 L p F P
0 g
s
.794 .741 .803 r
.15201 .31877 m .15232 .31849 L .14883 .31454 L p F P
0 g
s
.797 .738 .798 r
.14751 .31574 m .15201 .31877 L .1439 .32647 L p F P
0 g
s
.794 .741 .803 r
.14883 .31454 m .14751 .31574 L .15201 .31877 L p F P
0 g
s
.54 .485 .743 r
.69122 .38157 m .68915 .3753 L .6989 .37638 L closepath p F P
0 g
s
.535 .473 .734 r
.69122 .38157 m .6989 .37638 L p .69924 .3856 L F P
0 g
s
.535 .473 .734 r
.69924 .3856 m .69216 .38458 L .69122 .38157 L p F P
0 g
s
.833 .72 .74 r
.11031 .37207 m .10555 .37864 L .11018 .38156 L p F P
0 g
s
.833 .72 .74 r
.11103 .37252 m .11031 .37207 L p .11018 .38156 L F P
0 g
s
.836 .718 .734 r
.10555 .37864 m .11018 .38156 L .10568 .38805 L p F P
0 g
s
.523 .436 .699 r
.6983 .40561 m .69634 .40511 L .69792 .40413 L closepath p F P
0 g
s
.532 .451 .71 r
.69588 .39685 m .69792 .40413 L .69634 .40511 L p F P
0 g
s
.535 .473 .733 r
.69365 .38932 m .69216 .38458 L .69924 .3856 L closepath p F P
0 g
s
.761 .742 .836 r
.18548 .29117 m .19513 .2843 L .1998 .28729 L p F P
0 g
s
.76 .743 .837 r
.19645 .28337 m .19513 .2843 L .1998 .28729 L p F P
0 g
s
.76 .743 .837 r
.1998 .28729 m .19989 .28722 L .19645 .28337 L p F P
0 g
s
.747 .743 .848 r
.2108 .28017 m .19989 .28722 L .19645 .28337 L p F P
0 g
s
.671 .701 .869 r
.47705 .52822 m .47956 .53163 L p .46541 .53147 L F P
0 g
s
.671 .701 .869 r
.46541 .53147 m .47344 .5286 L .47705 .52822 L p F P
0 g
s
.67 .692 .862 r
.46541 .53147 m .47344 .5286 L .46419 .52977 L closepath p F P
0 g
s
.717 .436 .499 r
.37797 .30832 m .36977 .30769 L .3689 .30298 L p F P
0 g
s
.73 .445 .496 r
.36278 .3023 m .3689 .30298 L .36977 .30769 L p F P
0 g
s
.675 .693 .859 r
.46419 .52977 m .46235 .52718 L .45298 .53072 L closepath p F P
0 g
s
.674 .688 .855 r
.45928 .52254 m .46235 .52718 L .45298 .53072 L p F P
0 g
s
.674 .688 .855 r
.44818 .52697 m .45928 .52254 L p .45298 .53072 L F P
0 g
s
.7 .708 .854 r
.33492 .5305 m .33661 .52971 L .34661 .5307 L p F P
0 g
s
.688 .699 .855 r
.34588 .52539 m .33661 .52971 L .34661 .5307 L p F P
0 g
s
.688 .699 .855 r
.34661 .5307 m .34908 .52965 L .34588 .52539 L p F P
0 g
s
.861 .655 .623 r
.10329 .44162 m .10836 .44431 L .10669 .44992 L p F P
0 g
s
.856 .665 .642 r
.10836 .44431 m .10329 .44162 L .10536 .43589 L p F P
0 g
s
.53 .461 .723 r
.69365 .38932 m .69924 .3856 L p .69846 .39516 L F P
0 g
s
.53 .461 .723 r
.69846 .39516 m .69521 .39457 L .69365 .38932 L p F P
0 g
s
.54 .485 .744 r
.6989 .37638 m .68915 .3753 L .68858 .37358 L p F P
0 g
s
.278 0 0 r
.1872 .52024 m .18906 .52074 L .19564 .52283 L p F P
0 g
s
.106 .603 .903 r
.19564 .52283 m .20105 .52398 L .19749 .52208 L p F P
0 g
s
.797 .738 .798 r
.1439 .32647 m .13934 .32347 L .14751 .31574 L p F P
0 g
s
.8 .737 .794 r
.1439 .32647 m .14114 .32915 L .13764 .32511 L p F P
0 g
s
.8 .737 .794 r
.13764 .32511 m .13934 .32347 L .1439 .32647 L p F P
0 g
s
.702 .173 0 r
.1697 .51329 m .16386 .51095 L .15962 .50711 L p F P
0 g
s
.684 .145 0 r
.15361 .50482 m .15962 .50711 L .16386 .51095 L p F P
0 g
s
.785 .34 .19 r
.15277 .50377 m .15361 .50482 L .15962 .50711 L p F P
0 g
s
.789 .741 .808 r
.14883 .31454 m .15654 .30773 L .16108 .31075 L p F P
0 g
s
.787 .741 .811 r
.15994 .30478 m .15654 .30773 L .16108 .31075 L p F P
0 g
s
.787 .741 .811 r
.16108 .31075 m .16343 .30871 L .15994 .30478 L p F P
0 g
s
.54 .485 .744 r
.68858 .37358 m .69742 .3675 L p .6989 .37638 L F P
0 g
s
.544 .496 .753 r
.68858 .37358 m .68617 .36658 L .69742 .3675 L closepath p F P
0 g
s
.609 .759 .95 r
.26421 .2718 m .25349 .27483 L .2501 .27138 L p F P
0 g
s
.685 .75 .901 r
.23932 .27581 m .2501 .27138 L .25349 .27483 L p F P
0 g
s
.633 .759 .939 r
.25349 .27483 m .26421 .2718 L .2676 .27488 L p F P
0 g
s
.572 .553 .794 r
.66855 .32159 m .67147 .32843 L .65991 .32904 L p F P
0 g
s
.572 .553 .794 r
.66399 .32182 m .66855 .32159 L p .65991 .32904 L F P
0 g
s
.572 .553 .794 r
.65991 .32904 m .65852 .32577 L .66399 .32182 L p F P
0 g
s
.608 .611 .829 r
.61958 .2946 m .61722 .29503 L .61915 .29376 L closepath p F P
0 g
s
.611 .619 .835 r
.61667 .28908 m .61915 .29376 L .61722 .29503 L p F P
0 g
s
.846 .708 .71 r
.10245 .40356 m .10564 .39821 L .1042 .39613 L p F P
0 g
s
.65 .75 .922 r
.26416 .53334 m .27494 .53006 L .27829 .53323 L p F P
0 g
s
.667 .743 .907 r
.27494 .53006 m .26416 .53334 L .26078 .53045 L p F P
0 g
s
.78 .742 .817 r
.17102 .30242 m .16343 .30871 L .15994 .30478 L p F P
0 g
s
.805 .738 .789 r
.13635 .33398 m .14114 .32915 L .13764 .32511 L p F P
0 g
s
.45 .881 .898 r
.60418 .52271 m .6066 .52273 L .61745 .5189 L p F P
0 g
s
.442 .875 .904 r
.6066 .52273 m .60418 .52271 L .59287 .52626 L p F P
0 g
s
.349 .824 .794 r
.61828 .51871 m .61745 .5189 L .6066 .52273 L p F P
0 g
s
.677 .752 .907 r
.2501 .27138 m .23932 .27581 L .23592 .27216 L p F P
0 g
s
.713 .745 .877 r
.2251 .27758 m .23592 .27216 L .23932 .27581 L p F P
0 g
s
.733 .742 .859 r
.2108 .28017 m .21746 .27628 L .22235 .2792 L p F P
0 g
s
.735 .745 .86 r
.22168 .27384 m .21746 .27628 L .22235 .2792 L p F P
0 g
s
.735 .745 .86 r
.22235 .2792 m .2251 .27758 L .22168 .27384 L p F P
0 g
s
.455 .282 .556 r
.68766 .46521 m .68728 .4598 L .69707 .45445 L p F P
0 g
s
.475 .318 .588 r
.69645 .44878 m .69707 .45445 L .68728 .4598 L p F P
0 g
s
.467 .291 .558 r
.68429 .46696 m .68766 .46521 L .68728 .4598 L p F P
0 g
s
.55 .246 .406 r
.46153 .29485 m .47363 .29227 L .47271 .29633 L p F P
0 g
s
.55 .246 .406 r
.46071 .29809 m .46153 .29485 L p .47271 .29633 L F P
0 g
s
.53 .461 .723 r
.69588 .39685 m .69521 .39457 L .69846 .39516 L closepath p F P
0 g
s
.622 .357 .495 r
.43518 .30265 m .43722 .30239 L .43927 .30673 L p F P
0 g
s
.622 .357 .495 r
.43927 .30673 m .43474 .30731 L .43518 .30265 L p F P
0 g
s
.641 .369 .491 r
.43518 .30265 m .43474 .30731 L .42133 .30841 L p F P
0 g
s
.587 .576 .808 r
.64076 .31048 m .65119 .30939 L p .65361 .31575 L F P
0 g
s
.586 .578 .811 r
.65119 .30939 m .64076 .31048 L .64898 .3046 L closepath p F P
0 g
s
.59 .587 .817 r
.64829 .30314 m .64898 .3046 L .64076 .31048 L p F P
0 g
s
.59 .587 .817 r
.6368 .30455 m .64829 .30314 L p .64076 .31048 L F P
0 g
s
.42 .199 .47 r
.68369 .47246 m .67783 .47543 L .67767 .48027 L p F P
0 g
s
.449 .252 .519 r
.67783 .47543 m .68369 .47246 L .68429 .46696 L p F P
0 g
s
.837 .457 .332 r
.14518 .49812 m .13951 .4957 L .13768 .49114 L p F P
0 g
s
.837 .452 .321 r
.13281 .48905 m .13768 .49114 L .13951 .4957 L p F P
0 g
s
.758 .424 .419 r
.3307 .29296 m .33871 .29475 L .34072 .29904 L p F P
0 g
s
.74 .338 .288 r
.33871 .29475 m .3307 .29296 L .33021 .29231 L p F P
0 g
s
.738 .4 .409 r
.34607 .29991 m .34072 .29904 L .33871 .29475 L p F P
0 g
s
.522 .447 .712 r
.69792 .40413 m .69588 .39685 L .69846 .39516 L p F P
0 g
s
.851 .696 .689 r
.09904 .40971 m .10382 .41254 L .10072 .41858 L p F P
0 g
s
.848 .701 .699 r
.10382 .41254 m .09904 .40971 L .10245 .40356 L p F P
0 g
s
.643 .682 .872 r
.58232 .27388 m .57102 .27698 L .5681 .27271 L p F P
0 g
s
.807 .737 .786 r
.13635 .33398 m .12989 .34063 L .12637 .33659 L p F P
0 g
s
.807 .737 .786 r
.12637 .33659 m .13183 .33096 L .13635 .33398 L p F P
0 g
s
.805 .738 .789 r
.13764 .32511 m .13183 .33096 L .13635 .33398 L p F P
0 g
s
.544 .497 .753 r
.69742 .3675 m .68617 .36658 L .68573 .36531 L p F P
0 g
s
.667 .707 .878 r
.47956 .53163 m .49069 .52784 L .49372 .5318 L p F P
0 g
s
.667 .698 .87 r
.48976 .5265 m .49069 .52784 L .47956 .53163 L p F P
0 g
s
.667 .698 .87 r
.47956 .53163 m .47705 .52822 L .48976 .5265 L p F P
0 g
s
.671 .74 .902 r
.27829 .53323 m .28912 .52937 L .29243 .53279 L p F P
0 g
s
.683 .733 .888 r
.28912 .52937 m .27829 .53323 L .27494 .53006 L p F P
0 g
s
.544 .497 .753 r
.68573 .36531 m .6948 .35896 L p .69742 .3675 L F P
0 g
s
.549 .508 .762 r
.68573 .36531 m .6832 .35832 L .6948 .35896 L closepath p F P
0 g
s
0 .382 .678 r
.28977 .27889 m .29559 .27991 L .29301 .27932 L p F P
0 g
s
0 .382 .678 r
.28366 .27642 m .28977 .27889 L p .29301 .27932 L F P
0 g
s
.424 .71 .983 r
.28165 .27624 m .28366 .27642 L .28977 .27889 L p F P
0 g
s
.827 .727 .754 r
.11566 .3653 m .11048 .37184 L .10697 .36755 L p F P
0 g
s
.827 .727 .754 r
.10697 .36755 m .11108 .36234 L .11566 .3653 L p F P
0 g
s
.824 .728 .759 r
.11566 .3653 m .11108 .36234 L .11668 .35549 L p F P
0 g
s
.78 .742 .817 r
.15994 .30478 m .16645 .2994 L .17102 .30242 L p F P
0 g
s
.779 .742 .82 r
.17101 .2957 m .16645 .2994 L .17102 .30242 L p F P
0 g
s
.779 .742 .82 r
.17102 .30242 m .17448 .29961 L .17101 .2957 L p F P
0 g
s
.505 .752 .984 r
.27858 .27405 m .27789 .27383 L .2676 .27488 L p F P
0 g
s
.53 .723 .962 r
.27789 .27383 m .2676 .27488 L .26421 .2718 L p F P
0 g
s
.625 .358 .493 r
.43722 .30239 m .44812 .30105 L .44769 .30569 L p F P
0 g
s
.625 .358 .493 r
.44769 .30569 m .43927 .30673 L .43722 .30239 L p F P
0 g
s
.859 .669 .644 r
.10037 .43316 m .10536 .43589 L .10329 .44162 L p F P
0 g
s
.855 .676 .66 r
.10536 .43589 m .10037 .43316 L .10282 .42731 L p F P
0 g
s
.73 .445 .496 r
.36977 .30769 m .36213 .30684 L .36278 .3023 L p F P
0 g
s
.732 .446 .496 r
.35894 .30186 m .36278 .3023 L .36213 .30684 L p F P
0 g
s
.702 .683 .828 r
.37424 .52362 m .36324 .52885 L .36006 .52444 L p F P
0 g
s
.684 .73 .886 r
.29243 .53279 m .3033 .52849 L .30659 .53213 L p F P
0 g
s
.693 .723 .872 r
.3033 .52849 m .29243 .53279 L .28912 .52937 L p F P
0 g
s
.704 .689 .833 r
.36006 .52444 m .34908 .52965 L .34588 .52539 L p F P
0 g
s
.701 .713 .858 r
.33492 .5305 m .33661 .52971 L .33403 .52938 L closepath p F P
0 g
s
.696 .71 .859 r
.33403 .52938 m .33492 .5305 L p .32075 .53134 L F P
0 g
s
.696 .685 .836 r
.3774 .52816 m .38842 .52297 L .39156 .5276 L p F P
0 g
s
.7 .677 .825 r
.38842 .52297 m .3774 .52816 L .37424 .52362 L p F P
0 g
s
.696 .71 .859 r
.32075 .53134 m .32659 .52871 L .33403 .52938 L p F P
0 g
s
.707 .713 .854 r
.32659 .52871 m .32075 .53134 L .31749 .52749 L p F P
0 g
s
.691 .721 .872 r
.30659 .53213 m .31749 .52749 L .32075 .53134 L p F P
0 g
s
.709 .747 .881 r
.23592 .27216 m .2251 .27758 L .22168 .27384 L p F P
0 g
s
.7 .711 .857 r
.31749 .52749 m .30659 .53213 L .3033 .52849 L p F P
0 g
s
.616 .631 .842 r
.60271 .2865 m .60239 .28592 L .60416 .28555 L closepath p F P
0 g
s
.771 .743 .827 r
.18218 .29367 m .17448 .29961 L .17101 .2957 L p F P
0 g
s
.576 .562 .801 r
.65852 .32577 m .657 .32231 L .66399 .32182 L closepath p F P
0 g
s
.51 .764 .988 r
.2293 .52997 m .23256 .52976 L .2291 .52727 L p F P
0 g
s
.51 .764 .988 r
.2291 .52727 m .2224 .528 L .2293 .52997 L p F P
0 g
s
.378 .746 .991 r
.21854 .52828 m .2224 .528 L .2293 .52997 L p F P
0 g
s
.697 .673 .823 r
.40259 .5225 m .39156 .5276 L .38842 .52297 L p F P
0 g
s
.693 .682 .835 r
.39156 .5276 m .40259 .5225 L .40571 .5272 L p F P
0 g
s
0 0 0 r
.50022 .2817 m .49842 .28266 L .48708 .28614 L p F P
0 g
s
.812 .737 .782 r
.12922 .34134 m .12989 .34063 L .12637 .33659 L p F P
0 g
s
.815 .735 .776 r
.12475 .33832 m .12922 .34134 L .12279 .34846 L p F P
0 g
s
.812 .737 .782 r
.12637 .33659 m .12475 .33832 L .12922 .34134 L p F P
0 g
s
.553 .894 .982 r
.60418 .52271 m .59287 .52626 L .59004 .52536 L p F P
0 g
s
.552 .889 .985 r
.57874 .52871 m .59004 .52536 L .59287 .52626 L p F P
0 g
s
.516 .432 .699 r
.69792 .40413 m .70725 .39805 L p .70525 .40765 L F P
0 g
s
.516 .432 .699 r
.70525 .40765 m .6983 .40561 L .69792 .40413 L p F P
0 g
s
.522 .447 .712 r
.70701 .39718 m .70725 .39805 L .69792 .40413 L p F P
0 g
s
.522 .447 .712 r
.69846 .39516 m .70701 .39718 L p .69792 .40413 L F P
0 g
s
.663 .718 .89 r
.49372 .5318 m .50488 .52817 L .50789 .53191 L p F P
0 g
s
.666 .7 .872 r
.50488 .52817 m .49372 .5318 L .49069 .52784 L p F P
0 g
s
.444 .248 .518 r
.68766 .46521 m .68429 .46696 L .68369 .47246 L p F P
0 g
s
.181 0 0 r
.64359 .5071 m .6502 .50368 L .6441 .50624 L closepath p F P
0 g
s
.269 0 .135 r
.6549 .50102 m .6559 .49828 L p .6441 .50624 L F P
0 g
s
.269 0 .135 r
.6441 .50624 m .6502 .50368 L .6549 .50102 L p F P
0 g
s
.616 .637 .849 r
.60416 .28555 m .60239 .28592 L .59948 .28081 L p F P
0 g
s
.601 .603 .826 r
.61958 .2946 m .631 .29278 L .6339 .29855 L p F P
0 g
s
.602 .608 .83 r
.62826 .28737 m .631 .29278 L .61958 .2946 L p F P
0 g
s
.602 .608 .83 r
.61958 .2946 m .61915 .29376 L .62826 .28737 L p F P
0 g
s
.69 .679 .835 r
.40571 .5272 m .41676 .52223 L .41987 .52697 L p F P
0 g
s
.693 .67 .823 r
.41676 .52223 m .40571 .5272 L .40259 .5225 L p F P
0 g
s
.67 .692 .862 r
.47344 .5286 m .46419 .52977 L .46235 .52718 L p F P
0 g
s
.549 .508 .762 r
.6948 .35896 m .6832 .35832 L .68264 .35676 L p F P
0 g
s
.732 .446 .496 r
.36213 .30684 m .35978 .30657 L .35894 .30186 L p F P
0 g
s
.741 .458 .5 r
.34961 .30053 m .35894 .30186 L .35978 .30657 L p F P
0 g
s
0 .445 .746 r
.18906 .52074 m .18496 .51946 L .1872 .52024 L closepath p F P
0 g
s
.271 0 0 r
.48604 .28755 m .48708 .28614 L .49842 .28266 L p F P
0 g
s
.846 .708 .71 r
.1042 .39613 m .10147 .39445 L p .10245 .40356 L F P
0 g
s
.842 .713 .722 r
.1042 .39613 m .10217 .39335 L .10147 .39445 L closepath p F P
0 g
s
.275 0 .174 r
.6549 .50102 m .6559 .49828 L .6662 .49367 L p F P
0 g
s
.352 .05 .306 r
.66706 .48959 m .6662 .49367 L .6559 .49828 L p F P
0 g
s
.702 .712 .857 r
.34267 .52091 m .34588 .52539 L .33661 .52971 L p F P
0 g
s
.702 .712 .857 r
.33169 .52642 m .34267 .52091 L p .33661 .52971 L F P
0 g
s
.702 .712 .857 r
.33661 .52971 m .33403 .52938 L .33169 .52642 L p F P
0 g
s
.516 .431 .699 r
.69975 .41118 m .6983 .40561 L .70525 .40765 L closepath p F P
0 g
s
.829 .724 .749 r
.11103 .37252 m .11048 .37184 L .11031 .37207 L closepath p F P
0 g
s
.46 .764 .996 r
.2224 .528 m .21518 .5263 L .21854 .52828 L closepath p F P
0 g
s
.549 .508 .762 r
.68264 .35676 m .69104 .35078 L p .6948 .35896 L F P
0 g
s
.553 .518 .771 r
.68264 .35676 m .68026 .35044 L .69104 .35078 L closepath p F P
0 g
s
.75 .326 .244 r
.3129 .28634 m .31396 .28601 L p .32256 .29121 L F P
0 g
s
.646 .128 0 r
.3129 .28634 m .31161 .28545 L .31396 .28601 L closepath p F P
0 g
s
.812 .377 .209 r
.15126 .5039 m .14784 .50244 L .14518 .49812 L p F P
0 g
s
.81 .367 .19 r
.13951 .4957 m .14518 .49812 L .14784 .50244 L p F P
0 g
s
.686 .677 .836 r
.41987 .52697 m .43093 .52215 L .43402 .52689 L p F P
0 g
s
.689 .668 .824 r
.43093 .52215 m .41987 .52697 L .41676 .52223 L p F P
0 g
s
.606 .616 .835 r
.6281 .28706 m .62826 .28737 L .61915 .29376 L p F P
0 g
s
.606 .616 .835 r
.61915 .29376 m .61667 .28908 L .6281 .28706 L p F P
0 g
s
.84 .715 .726 r
.10568 .38805 m .10217 .39335 L .09869 .38869 L p F P
0 g
s
.84 .715 .726 r
.09869 .38869 m .10102 .38514 L .10568 .38805 L p F P
0 g
s
.836 .718 .734 r
.10568 .38805 m .10102 .38514 L .10555 .37864 L p F P
0 g
s
.857 .681 .663 r
.09792 .42454 m .10282 .42731 L .10037 .43316 L p F P
0 g
s
.853 .687 .675 r
.10282 .42731 m .09792 .42454 L .10072 .41858 L p F P
0 g
s
.771 .743 .827 r
.17101 .2957 m .17759 .29065 L .18218 .29367 L p F P
0 g
s
.77 .744 .829 r
.18202 .2873 m .17759 .29065 L .18218 .29367 L p F P
0 g
s
.77 .744 .829 r
.18218 .29367 m .18548 .29117 L .18202 .2873 L p F P
0 g
s
.658 .732 .904 r
.50789 .53191 m .51907 .52843 L .52206 .53191 L p F P
0 g
s
.662 .71 .884 r
.51907 .52843 m .50789 .53191 L .50488 .52817 L p F P
0 g
s
.614 .899 .987 r
.52556 .27441 m .52373 .27359 L .51308 .27792 L p F P
0 g
s
.696 .711 .86 r
.33403 .52938 m .33169 .52642 L .32659 .52871 L closepath p F P
0 g
s
.747 .337 .274 r
.3307 .29296 m .32979 .29274 L .33021 .29231 L closepath p F P
0 g
s
.772 .304 .13 r
.15361 .50482 m .15126 .5039 L .15277 .50377 L closepath p F P
0 g
s
.85 .704 .701 r
.09776 .40069 m .10245 .40356 L .09904 .40971 L p F P
0 g
s
.846 .708 .71 r
.10147 .39445 m .09776 .40069 L .10245 .40356 L p F P
0 g
s
.478 .34 .614 r
.6956 .44285 m .70521 .43721 L p .69652 .44874 L F P
0 g
s
.478 .34 .614 r
.69652 .44874 m .69643 .44865 L .6956 .44285 L p F P
0 g
s
.49 .363 .635 r
.70489 .43535 m .70521 .43721 L .6956 .44285 L p F P
0 g
s
.49 .363 .635 r
.70131 .43273 m .70489 .43535 L p .6956 .44285 L F P
0 g
s
.576 .563 .802 r
.66399 .32182 m .657 .32231 L .65409 .3157 L p F P
0 g
s
.831 .727 .751 r
.11031 .37207 m .11048 .37184 L .10697 .36755 L p F P
0 g
s
.835 .724 .742 r
.10578 .3691 m .11031 .37207 L .10555 .37864 L p F P
0 g
s
.831 .727 .751 r
.10697 .36755 m .10578 .3691 L .11031 .37207 L p F P
0 g
s
.818 .734 .771 r
.12279 .34846 m .11851 .35334 L .11498 .34922 L p F P
0 g
s
.818 .734 .771 r
.11498 .34922 m .11828 .34546 L .12279 .34846 L p F P
0 g
s
.815 .735 .776 r
.12279 .34846 m .11828 .34546 L .12475 .33832 L p F P
0 g
s
.613 .627 .841 r
.61377 .28364 m .60416 .28555 L .61193 .28026 L closepath p F P
0 g
s
.616 .637 .849 r
.61086 .27836 m .61193 .28026 L .60416 .28555 L p F P
0 g
s
.616 .637 .849 r
.59948 .28081 m .61086 .27836 L p .60416 .28555 L F P
0 g
s
.322 0 0 r
.16987 .51342 m .17017 .51347 L p .18265 .5186 L F P
0 g
s
.617 .051 0 r
.16987 .51342 m .1697 .51329 L .17017 .51347 L closepath p F P
0 g
s
.682 .677 .839 r
.43402 .52689 m .4451 .52226 L .44818 .52697 L p F P
0 g
s
.685 .667 .827 r
.4451 .52226 m .43402 .52689 L .43093 .52215 L p F P
0 g
s
.627 .647 .851 r
.58524 .27855 m .59657 .27582 L .59948 .28081 L p F P
0 g
s
.631 .662 .861 r
.59366 .27096 m .59657 .27582 L .58524 .27855 L p F P
0 g
s
.631 .662 .861 r
.59215 .27134 m .59366 .27096 L p .58524 .27855 L F P
0 g
s
.631 .662 .861 r
.58524 .27855 m .58397 .27649 L .59215 .27134 L p F P
0 g
s
.76 .744 .838 r
.19513 .2843 m .18548 .29117 L .18202 .2873 L p F P
0 g
s
.731 .743 .862 r
.21746 .27628 m .2108 .28017 L .20737 .27635 L p F P
0 g
s
.747 .743 .848 r
.19645 .28337 m .20737 .27635 L .2108 .28017 L p F P
0 g
s
.319 .672 .976 r
.28366 .27642 m .27858 .27405 L .28165 .27624 L closepath p F P
0 g
s
.59 .588 .819 r
.64539 .29711 m .64829 .30314 L .6368 .30455 L p F P
0 g
s
.59 .588 .819 r
.63645 .2982 m .64539 .29711 L p .6368 .30455 L F P
0 g
s
.59 .588 .819 r
.6368 .30455 m .63445 .29966 L .63645 .2982 L p F P
0 g
s
.716 .249 .141 r
.31161 .28545 m .3129 .28634 L .31053 .28775 L p F P
0 g
s
.716 .249 .141 r
.30425 .28342 m .31161 .28545 L p .31053 .28775 L F P
0 g
s
.688 .442 .544 r
.40569 .30903 m .40747 .30901 L .40737 .31409 L p F P
0 g
s
.688 .442 .544 r
.40737 .31409 m .40553 .3141 L .40569 .30903 L p F P
0 g
s
.693 .446 .544 r
.39302 .30898 m .40569 .30903 L .40553 .3141 L p F P
0 g
s
.673 .429 .544 r
.40747 .30901 m .42078 .30844 L .42063 .31352 L p F P
0 g
s
.673 .429 .544 r
.42063 .31352 m .40737 .31409 L .40747 .30901 L p F P
0 g
s
.508 .416 .687 r
.70142 .41804 m .69975 .41118 L .70525 .40765 L p F P
0 g
s
.517 .423 .687 r
.70115 .4182 m .70142 .41804 L .69975 .41118 L p F P
0 g
s
.612 .86 .99 r
.57826 .52845 m .57874 .52871 L .59004 .52536 L p F P
0 g
s
.693 .446 .544 r
.40553 .3141 m .3929 .31406 L .39302 .30898 L p F P
0 g
s
.704 .455 .545 r
.39256 .30897 m .39302 .30898 L .3929 .31406 L p F P
0 g
s
.708 .458 .544 r
.38069 .30849 m .39256 .30897 L .39238 .31404 L p F P
0 g
s
.704 .455 .545 r
.3929 .31406 m .39238 .31404 L .39256 .30897 L p F P
0 g
s
.653 .751 .922 r
.52206 .53191 m .53327 .52855 L .53623 .5317 L p F P
0 g
s
.658 .725 .899 r
.53327 .52855 m .52206 .53191 L .51907 .52843 L p F P
0 g
s
.557 0 0 r
.1697 .51329 m .16987 .51342 L .16619 .51244 L p F P
0 g
s
.557 0 0 r
.16619 .51244 m .16386 .51095 L .1697 .51329 L p F P
0 g
s
.598 .335 .489 r
.44769 .30569 m .44812 .30105 L .46056 .29887 L p F P
0 g
s
.564 .253 .399 r
.46071 .29809 m .46056 .29887 L .44812 .30105 L p F P
0 g
s
.553 .519 .771 r
.69104 .35078 m .68026 .35044 L .6793 .34791 L p F P
0 g
s
0 0 0 r
.62962 .51444 m .63142 .51326 L .64199 .50904 L p F P
0 g
s
.037 0 0 r
.64359 .5071 m .64199 .50904 L .63142 .51326 L p F P
0 g
s
0 0 0 r
.63142 .51326 m .62962 .51444 L .61828 .51871 L p F P
0 g
s
.34 .044 .309 r
.67556 .48554 m .66706 .48959 L .6662 .49367 L p F P
0 g
s
.392 .133 .397 r
.67735 .48348 m .67767 .48027 L p .66706 .48959 L F P
0 g
s
.392 .133 .397 r
.66706 .48959 m .67556 .48554 L .67735 .48348 L p F P
0 g
s
.865 .597 .532 r
.12013 .47375 m .11483 .47118 L .11509 .46599 L p F P
0 g
s
.867 .6 .531 r
.10984 .46338 m .11509 .46599 L .11483 .47118 L p F P
0 g
s
.864 .62 .569 r
.11509 .46599 m .10984 .46338 L .11062 .45804 L p F P
0 g
s
.322 0 0 r
.17667 .51631 m .16987 .51342 L p .18244 .51851 L F P
0 g
s
.375 0 0 r
.17667 .51631 m .16987 .51342 L .16619 .51244 L p F P
0 g
s
.035 .547 .872 r
.17636 .51531 m .17078 .51406 L p .17667 .51631 L F P
0 g
s
.035 .547 .872 r
.17078 .51406 m .17062 .51403 L .17667 .51631 L p F P
0 g
s
.322 0 0 r
.18265 .5186 m .17667 .51631 L p .18244 .51851 L F P
0 g
s
.521 .448 .714 r
.70701 .39718 m .69846 .39516 L .70517 .3907 L closepath p F P
0 g
s
.53 .461 .723 r
.70392 .3865 m .70517 .3907 L .69846 .39516 L p F P
0 g
s
.53 .461 .723 r
.69924 .3856 m .70392 .3865 L p .69846 .39516 L F P
0 g
s
.867 .623 .569 r
.10626 .45582 m .11062 .45804 L .10984 .46338 L p F P
0 g
s
.862 .639 .599 r
.10585 .45365 m .10669 .44992 L p .11062 .45804 L F P
0 g
s
.862 .639 .599 r
.11062 .45804 m .10626 .45582 L .10585 .45365 L p F P
0 g
s
.758 .424 .419 r
.34072 .29904 m .3324 .29735 L .3307 .29296 L p F P
0 g
s
.773 .431 .407 r
.32979 .29274 m .3307 .29296 L .3324 .29735 L p F P
0 g
s
.865 .569 .486 r
.12577 .48133 m .12042 .47877 L .12013 .47375 L p F P
0 g
s
.867 .571 .484 r
.11483 .47118 m .12013 .47375 L .12042 .47877 L p F P
0 g
s
.68 .667 .831 r
.45928 .52254 m .44818 .52697 L .4451 .52226 L p F P
0 g
s
.647 .777 .943 r
.53623 .5317 m .54747 .52842 L .55041 .53119 L p F P
0 g
s
.653 .746 .918 r
.54747 .52842 m .53623 .5317 L .53327 .52855 L p F P
0 g
s
.558 .529 .779 r
.6793 .34791 m .67732 .34287 L .68612 .34295 L closepath p F P
0 g
s
.553 .519 .771 r
.6793 .34791 m .68612 .34295 L p .69104 .35078 L F P
0 g
s
.822 .734 .767 r
.11668 .35549 m .11851 .35334 L .11498 .34922 L p F P
0 g
s
.707 .713 .854 r
.31749 .52749 m .31779 .52735 L .32659 .52871 L p F P
0 g
s
.694 .7 .852 r
.32846 .52213 m .31779 .52735 L .32659 .52871 L p F P
0 g
s
.694 .7 .852 r
.32659 .52871 m .33169 .52642 L .32846 .52213 L p F P
0 g
s
.614 .848 .988 r
.57826 .52845 m .57586 .52699 L .56458 .53025 L p F P
0 g
s
.638 .808 .965 r
.57586 .52699 m .56458 .53025 L .56167 .52795 L p F P
0 g
s
.636 .809 .966 r
.55041 .53119 m .56167 .52795 L .56458 .53025 L p F P
0 g
s
.854 .692 .68 r
.09591 .41576 m .10072 .41858 L .09792 .42454 L p F P
0 g
s
.851 .696 .689 r
.10072 .41858 m .09591 .41576 L .09904 .40971 L p F P
0 g
s
.648 .773 .94 r
.56167 .52795 m .55041 .53119 L .54747 .52842 L p F P
0 g
s
.708 .458 .544 r
.39238 .31404 m .38051 .31356 L .38069 .30849 L p F P
0 g
s
.717 .466 .545 r
.37797 .30832 m .38069 .30849 L .38051 .31356 L p F P
0 g
s
.019 .55 .852 r
.18906 .52074 m .19749 .52208 L p .18358 .5189 L F P
0 g
s
.019 .55 .852 r
.18358 .5189 m .18496 .51946 L .18906 .52074 L p F P
0 g
s
.671 .699 .868 r
.47705 .52822 m .47652 .52749 L .47344 .5286 L closepath p F P
0 g
s
.67 .692 .862 r
.47347 .52296 m .47652 .52749 L .47344 .5286 L p F P
0 g
s
.67 .692 .862 r
.46235 .52718 m .47347 .52296 L p .47344 .5286 L F P
0 g
s
.773 .431 .407 r
.3324 .29735 m .32818 .29632 L .32979 .29274 L p F P
0 g
s
.759 .413 .399 r
.32256 .29121 m .32979 .29274 L .32818 .29632 L p F P
0 g
s
.672 .428 .544 r
.42078 .30844 m .42133 .30841 L .42125 .31349 L p F P
0 g
s
.672 .428 .544 r
.42125 .31349 m .42063 .31352 L .42078 .30844 L p F P
0 g
s
.594 .759 .957 r
.23256 .52976 m .24323 .5276 L .24665 .5304 L p F P
0 g
s
.621 .755 .942 r
.24323 .5276 m .23256 .52976 L .2291 .52727 L p F P
0 g
s
.657 .416 .543 r
.42125 .31349 m .42133 .30841 L .43474 .30731 L p F P
0 g
s
.861 .655 .623 r
.10297 .4427 m .10329 .44162 L p .10669 .44992 L F P
0 g
s
.861 .655 .623 r
.10669 .44992 m .10494 .44899 L .10297 .4427 L p F P
0 g
s
.866 .642 .598 r
.10585 .45365 m .10669 .44992 L .10494 .44899 L closepath p F P
0 g
s
.741 .458 .5 r
.35978 .30657 m .35031 .30528 L .34961 .30053 L p F P
0 g
s
.756 .468 .496 r
.34607 .29991 m .34961 .30053 L .35031 .30528 L p F P
0 g
s
.667 .749 .912 r
.53972 .27278 m .55096 .26889 L .5539 .27228 L p F P
0 g
s
.677 .792 .936 r
.55096 .26889 m .53972 .27278 L .53677 .27026 L p F P
0 g
s
.673 .813 .95 r
.52556 .27441 m .53677 .27026 L .53972 .27278 L p F P
0 g
s
.041 0 0 r
.64199 .50904 m .64359 .5071 L .6502 .50368 L p F P
0 g
s
.862 .533 .428 r
.13204 .4887 m .12667 .48617 L .12577 .48133 L p F P
0 g
s
.864 .533 .424 r
.12042 .47877 m .12577 .48133 L .12667 .48617 L p F P
0 g
s
.717 .466 .545 r
.38051 .31356 m .37783 .31339 L .37797 .30832 L p F P
0 g
s
.723 .47 .544 r
.36977 .30769 m .37797 .30832 L .37783 .31339 L p F P
0 g
s
.826 .732 .761 r
.11221 .35248 m .11668 .35549 L .11108 .36234 L p F P
0 g
s
.822 .734 .767 r
.11498 .34922 m .11221 .35248 L .11668 .35549 L p F P
0 g
s
.62 .849 .986 r
.57586 .52699 m .57826 .52845 L .58946 .52504 L p F P
0 g
s
.612 .86 .99 r
.59004 .52536 m .58946 .52504 L .57826 .52845 L p F P
0 g
s
.684 .145 0 r
.16386 .51095 m .15802 .5086 L .15361 .50482 L p F P
0 g
s
.649 .094 0 r
.15126 .5039 m .15361 .50482 L .15802 .5086 L p F P
0 g
s
.844 .716 .723 r
.10147 .39445 m .10217 .39335 L .09869 .38869 L p F P
0 g
s
.655 .709 .887 r
.5539 .27228 m .56517 .26871 L .5681 .27271 L p F P
0 g
s
.664 .734 .902 r
.56517 .26871 m .5539 .27228 L .55096 .26889 L p F P
0 g
s
.837 .452 .321 r
.13224 .48934 m .13281 .48905 L p .13951 .4957 L F P
0 g
s
.853 .491 .367 r
.13224 .48934 m .13204 .4887 L .13281 .48905 L closepath p F P
0 g
s
.676 .669 .836 r
.47347 .52296 m .46235 .52718 L .45928 .52254 L p F P
0 g
s
.507 .403 .67 r
.70149 .41835 m .70115 .4182 L .70142 .41804 L closepath p F P
0 g
s
.672 .699 .867 r
.48766 .52347 m .48976 .5265 L .47705 .52822 L p F P
0 g
s
.672 .699 .867 r
.47705 .52822 m .47652 .52749 L .48766 .52347 L p F P
0 g
s
.351 .823 .773 r
.61745 .5189 m .61828 .51871 L .62962 .51444 L p F P
0 g
s
.51 .202 .38 r
.47271 .29633 m .47363 .29227 L .48532 .28921 L p F P
0 g
s
.406 .015 .181 r
.48604 .28755 m .48532 .28921 L .47363 .29227 L p F P
0 g
s
.633 .667 .865 r
.58397 .27649 m .58232 .27388 L .59215 .27134 L closepath p F P
0 g
s
.848 .712 .712 r
.09687 .39153 m .10147 .39445 L .09776 .40069 L p F P
0 g
s
.844 .716 .723 r
.09869 .38869 m .09687 .39153 L .10147 .39445 L p F P
0 g
s
.499 .397 .67 r
.70142 .41804 m .7108 .41202 L p .70798 .42142 L F P
0 g
s
.499 .397 .67 r
.70798 .42142 m .70149 .41835 L .70142 .41804 L p F P
0 g
s
.508 .416 .687 r
.71018 .40949 m .7108 .41202 L .70142 .41804 L p F P
0 g
s
.508 .416 .687 r
.70525 .40765 m .71018 .40949 L p .70142 .41804 L F P
0 g
s
.864 .658 .621 r
.10297 .4427 m .10329 .44162 L .10249 .44118 L closepath p F P
0 g
s
.859 .669 .644 r
.09981 .43474 m .10037 .43316 L p .10329 .44162 L F P
0 g
s
.859 .669 .644 r
.10329 .44162 m .10249 .44118 L .09981 .43474 L p F P
0 g
s
.431 .237 .516 r
.68779 .47034 m .68766 .46521 L .69747 .45987 L p F P
0 g
s
.455 .282 .556 r
.69707 .45445 m .69747 .45987 L .68766 .46521 L p F P
0 g
s
.444 .248 .518 r
.68369 .47246 m .68779 .47034 L .68766 .46521 L p F P
0 g
s
.635 .893 .986 r
.52373 .27359 m .52556 .27441 L .53677 .27026 L p F P
0 g
s
.76 .744 .838 r
.18202 .2873 m .19054 .28126 L .19513 .2843 L p F P
0 g
s
.76 .745 .839 r
.193 .27955 m .19054 .28126 L .19513 .2843 L p F P
0 g
s
.76 .745 .839 r
.19513 .2843 m .19645 .28337 L .193 .27955 L p F P
0 g
s
.582 .568 .804 r
.65409 .3157 m .65361 .31575 L .65399 .31548 L closepath p F P
0 g
s
.587 .576 .808 r
.65119 .30939 m .65399 .31548 L .65361 .31575 L p F P
0 g
s
.79 .743 .81 r
.15654 .30773 m .14883 .31454 L .14532 .31063 L p F P
0 g
s
.796 .743 .804 r
.14751 .31574 m .14883 .31454 L .14532 .31063 L p F P
0 g
s
.499 .397 .67 r
.70287 .42464 m .70149 .41835 L .70798 .42142 L closepath p F P
0 g
s
.798 .741 .8 r
.1431 .31267 m .14751 .31574 L .13934 .32347 L p F P
0 g
s
.796 .743 .804 r
.14532 .31063 m .1431 .31267 L .14751 .31574 L p F P
0 g
s
0 .37 .753 r
.27824 .27383 m .27479 .27187 L p .27508 .27201 L F P
0 g
s
.346 0 0 r
.28366 .27642 m .29121 .27876 L p .27886 .27415 L F P
0 g
s
.346 0 0 r
.27824 .27383 m .27858 .27405 L p .29121 .27876 L F P
0 g
s
.346 0 0 r
.29121 .27876 m .28457 .27646 L .27824 .27383 L p F P
0 g
s
0 .37 .753 r
.28457 .27646 m .27844 .27391 L p .27508 .27201 L F P
0 g
s
0 .37 .753 r
.27844 .27391 m .27824 .27383 L p .27508 .27201 L F P
0 g
s
.346 0 0 r
.27858 .27405 m .27912 .2743 L p .27886 .27415 L F P
0 g
s
.346 0 0 r
.27912 .2743 m .28366 .27642 L p .27886 .27415 L F P
0 g
s
0 .382 .678 r
.29121 .27876 m .28366 .27642 L p .2928 .27926 L F P
0 g
s
.729 .24 .079 r
.28887 .28038 m .28495 .27681 L .29121 .27876 L F
.28457 .27646 m .29121 .27876 L p .28495 .27681 L F P
0 g
s
0 .382 .678 r
.29301 .27932 m .29121 .27876 L p .2928 .27926 L F P
0 g
s
.558 .529 .78 r
.68612 .34295 m .67732 .34287 L .67569 .33873 L p F P
0 g
s
.838 .722 .736 r
.101 .37568 m .10555 .37864 L .10102 .38514 L p F P
0 g
s
.835 .724 .742 r
.10555 .37864 m .101 .37568 L .10578 .3691 L p F P
0 g
s
.854 .482 .346 r
.13204 .4887 m .13224 .48934 L .12825 .4908 L p F P
0 g
s
.854 .482 .346 r
.12825 .4908 m .12667 .48617 L .13204 .4887 L p F P
0 g
s
.75 .326 .244 r
.32256 .29121 m .31513 .2892 L .3129 .28634 L p F P
0 g
s
.761 .322 .209 r
.31513 .2892 m .31053 .28775 L .3129 .28634 L closepath p F P
0 g
s
.488 .769 .993 r
.2224 .528 m .2291 .52727 L p .21502 .5262 L F P
0 g
s
.488 .769 .993 r
.21502 .5262 m .21518 .5263 L .2224 .528 L p F P
0 g
s
.756 .468 .496 r
.35031 .30528 m .34536 .30442 L .34607 .29991 L p F P
0 g
s
.752 .464 .495 r
.34072 .29904 m .34607 .29991 L .34536 .30442 L p F P
0 g
s
.731 .743 .862 r
.20737 .27635 m .21261 .27334 L .21746 .27628 L p F P
0 g
s
.733 .747 .863 r
.21825 .27013 m .21261 .27334 L .21746 .27628 L p F P
0 g
s
.733 .747 .863 r
.21746 .27628 m .22168 .27384 L .21825 .27013 L p F P
0 g
s
.801 .74 .796 r
.13934 .32347 m .13764 .32511 L .13412 .32114 L p F P
0 g
s
.801 .74 .796 r
.13412 .32114 m .13486 .32043 L .13934 .32347 L p F P
0 g
s
.798 .741 .8 r
.13934 .32347 m .13486 .32043 L .1431 .31267 L p F P
0 g
s
.79 .743 .81 r
.14532 .31063 m .15209 .30466 L .15654 .30773 L p F P
0 g
s
.788 .744 .813 r
.15645 .30089 m .15209 .30466 L .15654 .30773 L p F P
0 g
s
.788 .744 .813 r
.15654 .30773 m .15994 .30478 L .15645 .30089 L p F P
0 g
s
.746 .745 .851 r
.20737 .27635 m .19645 .28337 L .193 .27955 L p F P
0 g
s
.723 .47 .544 r
.37783 .31339 m .36959 .31275 L .36977 .30769 L p F P
0 g
s
.736 .482 .545 r
.36213 .30684 m .36977 .30769 L .36959 .31275 L p F P
0 g
s
.806 .741 .791 r
.13183 .33096 m .13764 .32511 L .13412 .32114 L p F P
0 g
s
.64 .752 .93 r
.24665 .5304 m .25739 .52736 L .26078 .53045 L p F P
0 g
s
.658 .747 .915 r
.25739 .52736 m .24665 .5304 L .24323 .5276 L p F P
0 g
s
.576 .563 .802 r
.65409 .3157 m .66565 .31493 L p .66399 .32182 L F P
0 g
s
.575 .565 .805 r
.66292 .30878 m .66565 .31493 L .65409 .3157 L p F P
0 g
s
.575 .565 .805 r
.65409 .3157 m .65399 .31548 L .66292 .30878 L p F P
0 g
s
.781 .744 .819 r
.16645 .2994 m .15994 .30478 L .15645 .30089 L p F P
0 g
s
.58 .574 .811 r
.66274 .30839 m .66292 .30878 L .65399 .31548 L p F P
0 g
s
.58 .574 .811 r
.65399 .31548 m .65119 .30939 L .66274 .30839 L p F P
0 g
s
.607 .619 .837 r
.6281 .28706 m .61667 .28908 L .61377 .28364 L p F P
0 g
s
.672 .673 .843 r
.48766 .52347 m .47652 .52749 L .47347 .52296 L p F P
0 g
s
.643 .682 .872 r
.5681 .27271 m .5794 .26946 L .58232 .27388 L p F P
0 g
s
.65 .698 .881 r
.5794 .26946 m .5681 .27271 L .56517 .26871 L p F P
0 g
s
.594 .597 .824 r
.63445 .29966 m .6339 .29855 L .63645 .2982 L closepath p F P
0 g
s
.702 .683 .828 r
.36006 .52444 m .37108 .51886 L .37424 .52362 L p F P
0 g
s
.7 .677 .825 r
.37424 .52362 m .38527 .51809 L .38842 .52297 L p F P
0 g
s
.704 .668 .812 r
.38527 .51809 m .37424 .52362 L .37108 .51886 L p F P
0 g
s
.706 .674 .816 r
.37108 .51886 m .36006 .52444 L .35688 .51981 L p F P
0 g
s
.704 .689 .833 r
.34588 .52539 m .35688 .51981 L .36006 .52444 L p F P
0 g
s
.868 .659 .618 r
.10169 .44721 m .10297 .4427 L .10249 .44118 L p F P
0 g
s
.867 .658 .618 r
.10494 .44899 m .10297 .4427 L .10169 .44721 L closepath p F P
0 g
s
.868 .659 .618 r
.10249 .44118 m .09838 .43887 L p .10169 .44721 L F P
0 g
s
.865 .67 .638 r
.10249 .44118 m .09981 .43474 L .09838 .43887 L closepath p F P
0 g
s
.854 .7 .69 r
.09433 .40684 m .09904 .40971 L .09591 .41576 L p F P
0 g
s
.85 .704 .701 r
.09904 .40971 m .09433 .40684 L .09776 .40069 L p F P
0 g
s
.697 .673 .823 r
.38842 .52297 m .39946 .51754 L .40259 .5225 L p F P
0 g
s
.7 .663 .81 r
.39946 .51754 m .38842 .52297 L .38527 .51809 L p F P
0 g
s
.708 .681 .821 r
.35688 .51981 m .34588 .52539 L .34267 .52091 L p F P
0 g
s
.869 .645 .595 r
.10494 .44899 m .10169 .44721 L p .10547 .45539 L F P
0 g
s
.869 .645 .595 r
.10547 .45539 m .10585 .45365 L .10494 .44899 L p F P
0 g
s
.55 .246 .406 r
.47271 .29633 m .46231 .29849 L .46071 .29809 L p F P
0 g
s
.55 .255 .419 r
.46231 .29849 m .46056 .29887 L .46071 .29809 L closepath p F P
0 g
s
.677 .752 .907 r
.23592 .27216 m .2467 .26799 L .2501 .27138 L p F P
0 g
s
.668 .753 .914 r
.2467 .26799 m .23592 .27216 L .23251 .26855 L p F P
0 g
s
.709 .747 .881 r
.22168 .27384 m .23251 .26855 L .23592 .27216 L p F P
0 g
s
.62 .642 .85 r
.61086 .27836 m .59948 .28081 L .59657 .27582 L p F P
0 g
s
.609 .759 .95 r
.2501 .27138 m .2608 .26881 L .26421 .2718 L p F P
0 g
s
.58 .756 .962 r
.2608 .26881 m .2501 .27138 L .2467 .26799 L p F P
0 g
s
.809 .74 .788 r
.13183 .33096 m .12637 .33659 L .12284 .33261 L p F P
0 g
s
.809 .74 .788 r
.12284 .33261 m .1274 .32791 L .13183 .33096 L p F P
0 g
s
.806 .741 .791 r
.13412 .32114 m .1274 .32791 L .13183 .33096 L p F P
0 g
s
.839 .453 .319 r
.13387 .49326 m .13224 .48934 L .12825 .4908 L p F P
0 g
s
.837 .452 .321 r
.13951 .4957 m .13387 .49326 L .13224 .48934 L p F P
0 g
s
.258 .695 .962 r
.20105 .52398 m .20875 .52399 L .2149 .5262 L p F P
0 g
s
.361 .733 .988 r
.20875 .52399 m .20105 .52398 L .19749 .52208 L p F P
0 g
s
.636 .398 .541 r
.43474 .30731 m .43927 .30673 L .43912 .31181 L p F P
0 g
s
.636 .398 .541 r
.43912 .31181 m .43467 .31238 L .43474 .30731 L p F P
0 g
s
.657 .416 .543 r
.43474 .30731 m .43467 .31238 L .42125 .31349 L p F P
0 g
s
.863 .671 .642 r
.09981 .43474 m .10037 .43316 L .09874 .43224 L closepath p F P
0 g
s
.857 .681 .663 r
.09653 .42787 m .09792 .42454 L p .10037 .43316 L F P
0 g
s
.857 .681 .663 r
.10037 .43316 m .09874 .43224 L .09653 .42787 L p F P
0 g
s
.71 .689 .829 r
.34267 .52091 m .33169 .52642 L .32846 .52213 L p F P
0 g
s
.696 .66 .81 r
.41333 .51737 m .40259 .5225 L .39946 .51754 L p F P
0 g
s
.693 .67 .823 r
.41374 .51736 m .41676 .52223 L p .40259 .5225 L F P
0 g
s
.693 .67 .823 r
.40259 .5225 m .41333 .51737 L .41374 .51736 L p F P
0 g
s
.829 .73 .755 r
.11108 .36234 m .10697 .36755 L .10344 .36333 L p F P
0 g
s
.829 .73 .755 r
.10344 .36333 m .10658 .35934 L .11108 .36234 L p F P
0 g
s
.826 .732 .761 r
.11108 .36234 m .10658 .35934 L .11221 .35248 L p F P
0 g
s
.42 .199 .47 r
.67767 .48027 m .68096 .47861 L .68369 .47246 L p F P
0 g
s
.413 .191 .465 r
.68779 .47034 m .68369 .47246 L .68096 .47861 L p F P
0 g
s
.781 .744 .819 r
.15645 .30089 m .16197 .29634 L .16645 .2994 L p F P
0 g
s
.78 .745 .821 r
.16752 .29184 m .16197 .29634 L .16645 .2994 L p F P
0 g
s
.78 .745 .821 r
.16645 .2994 m .17101 .2957 L .16752 .29184 L p F P
0 g
s
.558 .529 .78 r
.67569 .33873 m .68006 .33548 L p .68612 .34295 L F P
0 g
s
.562 .539 .787 r
.67569 .33873 m .67439 .33555 L .68006 .33548 L closepath p F P
0 g
s
.649 .094 0 r
.14896 .50374 m .15126 .5039 L p .15802 .5086 L F P
0 g
s
.763 .271 .058 r
.14896 .50374 m .14784 .50244 L .15126 .5039 L closepath p F P
0 g
s
.667 .743 .907 r
.26078 .53045 m .27159 .52671 L .27494 .53006 L p F P
0 g
s
.68 .737 .893 r
.27159 .52671 m .26078 .53045 L .25739 .52736 L p F P
0 g
s
.479 .34 .613 r
.69645 .44878 m .69643 .44865 L .69652 .44874 L closepath p F P
0 g
s
.381 .131 .405 r
.67735 .48348 m .68096 .47861 L .67767 .48027 L closepath p F P
0 g
s
.461 .307 .585 r
.69652 .44874 m .69645 .44878 L .69707 .45445 L p F P
0 g
s
.594 .6 .828 r
.63645 .2982 m .6339 .29855 L .631 .29278 L p F P
0 g
s
.461 .307 .585 r
.69707 .45445 m .69907 .4533 L .69652 .44874 L p F P
0 g
s
.458 .306 .586 r
.70607 .44314 m .69652 .44874 L .69907 .4533 L p F P
0 g
s
.478 .34 .614 r
.70521 .43721 m .70607 .44314 L .69652 .44874 L p F P
0 g
s
.271 0 0 r
.49842 .28266 m .4972 .28443 L .48604 .28755 L p F P
0 g
s
.392 .018 .204 r
.48532 .28921 m .48604 .28755 L .4972 .28443 L p F P
0 g
s
.707 .715 .855 r
.31749 .52749 m .31779 .52735 L .31732 .52727 L closepath p F P
0 g
s
.7 .711 .857 r
.31732 .52727 m .31749 .52749 L p .3033 .52849 L F P
0 g
s
.708 .714 .854 r
.32523 .51764 m .32846 .52213 L .31779 .52735 L p F P
0 g
s
.708 .714 .854 r
.31424 .5234 m .32523 .51764 L p .31779 .52735 L F P
0 g
s
.708 .714 .854 r
.31779 .52735 m .31732 .52727 L .31424 .5234 L p F P
0 g
s
0 .405 .733 r
.18358 .5189 m .18265 .5186 L .18496 .51946 L closepath p F P
0 g
s
.711 .718 .854 r
.30816 .52622 m .3033 .52849 L .30002 .52465 L p F P
0 g
s
.693 .723 .872 r
.28912 .52937 m .30002 .52465 L .3033 .52849 L p F P
0 g
s
.7 .711 .857 r
.3033 .52849 m .30816 .52622 L .31732 .52727 L p F P
0 g
s
.683 .733 .888 r
.27494 .53006 m .2858 .52577 L .28912 .52937 L p F P
0 g
s
.694 .726 .875 r
.2858 .52577 m .27494 .53006 L .27159 .52671 L p F P
0 g
s
.305 0 0 r
.29559 .27991 m .29761 .28114 L .30425 .28342 L p F P
0 g
s
.746 .297 .185 r
.29761 .28114 m .30425 .28342 L .30801 .28709 L p F P
0 g
s
.716 .249 .141 r
.31053 .28775 m .30801 .28709 L .30425 .28342 L p F P
0 g
s
.689 .668 .824 r
.41676 .52223 m .42783 .51713 L .43093 .52215 L p F P
0 g
s
.689 .669 .825 r
.42769 .51688 m .42783 .51713 L .41676 .52223 L p F P
0 g
s
.689 .669 .825 r
.41676 .52223 m .41374 .51736 L .42769 .51688 L p F P
0 g
s
.041 0 0 r
.6502 .50368 m .65452 .50182 L p .64199 .50904 L F P
0 g
s
.233 0 .087 r
.6502 .50368 m .65452 .50182 L .6549 .50102 L closepath p F P
0 g
s
.813 .74 .783 r
.12475 .33832 m .12637 .33659 L .12284 .33261 L p F P
0 g
s
.7 .712 .858 r
.31732 .52727 m .31424 .5234 L .30816 .52622 L closepath p F P
0 g
s
.771 .745 .829 r
.17759 .29065 m .17101 .2957 L .16752 .29184 L p F P
0 g
s
.702 .714 .858 r
.30002 .52465 m .28912 .52937 L .2858 .52577 L p F P
0 g
s
.666 .7 .872 r
.50215 .52442 m .50488 .52817 L p .49069 .52784 L F P
0 g
s
.666 .7 .872 r
.49069 .52784 m .49961 .5248 L .50215 .52442 L p F P
0 g
s
.664 .687 .861 r
.49069 .52784 m .49961 .5248 L .48976 .5265 L closepath p F P
0 g
s
.759 .413 .399 r
.32818 .29632 m .32445 .29553 L .32256 .29121 L p F P
0 g
s
.776 .435 .41 r
.31513 .2892 m .32256 .29121 L .32445 .29553 L p F P
0 g
s
.527 .46 .725 r
.70392 .3865 m .69924 .3856 L .70291 .38313 L closepath p F P
0 g
s
.535 .473 .734 r
.70087 .37668 m .70291 .38313 L .69924 .3856 L p F P
0 g
s
.535 .473 .734 r
.6989 .37638 m .70087 .37668 L p .69924 .3856 L F P
0 g
s
.752 .464 .495 r
.34536 .30442 m .34144 .30378 L .34072 .29904 L p F P
0 g
s
.765 .477 .498 r
.3324 .29735 m .34072 .29904 L .34144 .30378 L p F P
0 g
s
.706 .749 .885 r
.23251 .26855 m .22168 .27384 L .21825 .27013 L p F P
0 g
s
.81 .367 .19 r
.14784 .50244 m .14225 .49999 L .13951 .4957 L p F P
0 g
s
.807 .357 .172 r
.13387 .49326 m .13951 .4957 L .14225 .49999 L p F P
0 g
s
.816 .738 .778 r
.12035 .33526 m .12475 .33832 L .11828 .34546 L p F P
0 g
s
.813 .74 .783 r
.12284 .33261 m .12035 .33526 L .12475 .33832 L p F P
0 g
s
.488 .363 .636 r
.70489 .43535 m .70131 .43273 L .70414 .43104 L closepath p F P
0 g
s
.499 .385 .655 r
.70131 .43273 m .70414 .43104 L .70287 .42464 L p F P
0 g
s
.736 .482 .545 r
.36959 .31275 m .36197 .31192 L .36213 .30684 L p F P
0 g
s
.738 .483 .544 r
.35978 .30657 m .36213 .30684 L .36197 .31192 L p F P
0 g
s
.578 .321 .49 r
.46056 .29887 m .46231 .29849 L .46617 .30225 L p F P
0 g
s
.578 .321 .49 r
.46617 .30225 m .46018 .30355 L .46056 .29887 L p F P
0 g
s
.598 .335 .489 r
.46056 .29887 m .46018 .30355 L .44769 .30569 L p F P
0 g
s
.639 .401 .542 r
.43927 .30673 m .44769 .30569 L .44764 .31077 L p F P
0 g
s
.639 .401 .542 r
.44764 .31077 m .43912 .31181 L .43927 .30673 L p F P
0 g
s
.53 .723 .962 r
.26421 .2718 m .27131 .2715 L .27789 .27383 L p F P
0 g
s
.481 .71 .971 r
.27131 .2715 m .26421 .2718 L .2608 .26881 L p F P
0 g
s
.562 .539 .788 r
.68006 .33548 m .67439 .33555 L .67179 .32919 L p F P
0 g
s
.866 .672 .639 r
.09838 .43887 m .09981 .43474 L .09874 .43224 L p F P
0 g
s
.868 .643 .595 r
.10626 .45582 m .10585 .45365 L .10547 .45539 L closepath p F P
0 g
s
.685 .667 .827 r
.43093 .52215 m .44202 .51725 L .4451 .52226 L p F P
0 g
s
.687 .656 .814 r
.44202 .51725 m .43093 .52215 L .42783 .51713 L p F P
0 g
s
.489 .378 .654 r
.70414 .43104 m .70287 .42464 L .70798 .42142 L p F P
0 g
s
.534 0 0 r
.29761 .28114 m .29301 .27932 L .29559 .27991 L closepath p F P
0 g
s
.738 .483 .544 r
.36197 .31192 m .35958 .31164 L .35978 .30657 L p F P
0 g
s
.746 .49 .544 r
.35031 .30528 m .35978 .30657 L .35958 .31164 L p F P
0 g
s
.86 .683 .661 r
.09653 .42787 m .09792 .42454 L .09347 .42195 L closepath p F P
0 g
s
.854 .692 .68 r
.0932 .4215 m .09591 .41576 L p .09792 .42454 L F P
0 g
s
.854 .692 .68 r
.09792 .42454 m .09347 .42195 L .0932 .4215 L p F P
0 g
s
0 0 0 r
.51139 .27776 m .50941 .27874 L .49842 .28266 L p F P
0 g
s
.843 .718 .727 r
.10102 .38514 m .09869 .38869 L .09518 .38411 L p F P
0 g
s
.843 .718 .727 r
.09518 .38411 m .09644 .3822 L .10102 .38514 L p F P
0 g
s
.838 .722 .736 r
.10102 .38514 m .09644 .3822 L .101 .37568 L p F P
0 g
s
.45 .882 .883 r
.61553 .51895 m .61745 .5189 L .62817 .51487 L p F P
0 g
s
.45 .881 .898 r
.61745 .5189 m .61553 .51895 L .60418 .52271 L p F P
0 g
s
.351 .823 .773 r
.62962 .51444 m .62817 .51487 L .61745 .5189 L p F P
0 g
s
.634 .678 .875 r
.59215 .27134 m .58232 .27388 L .5794 .26946 L p F P
0 g
s
.833 .73 .752 r
.10578 .3691 m .10697 .36755 L .10344 .36333 L p F P
0 g
s
.771 .745 .829 r
.16752 .29184 m .17308 .28759 L .17759 .29065 L p F P
0 g
s
.77 .746 .831 r
.17855 .28347 m .17308 .28759 L .17759 .29065 L p F P
0 g
s
.77 .746 .831 r
.17759 .29065 m .18202 .2873 L .17855 .28347 L p F P
0 g
s
.662 .71 .884 r
.50488 .52817 m .51607 .52454 L .51907 .52843 L p F P
0 g
s
.663 .697 .872 r
.51447 .52226 m .51607 .52454 L .50488 .52817 L p F P
0 g
s
.663 .697 .872 r
.50488 .52817 m .50215 .52442 L .51447 .52226 L p F P
0 g
s
.582 .321 .486 r
.46231 .29849 m .47271 .29633 L .47231 .30097 L p F P
0 g
s
.582 .321 .486 r
.47231 .30097 m .46617 .30225 L .46231 .29849 L p F P
0 g
s
.493 0 0 r
.16386 .51095 m .16619 .51244 L .1625 .51118 L p F P
0 g
s
.493 0 0 r
.1625 .51118 m .15802 .5086 L .16386 .51095 L p F P
0 g
s
.548 .9 .975 r
.61553 .51895 m .60418 .52271 L .60137 .52187 L p F P
0 g
s
.553 .894 .982 r
.59004 .52536 m .60137 .52187 L .60418 .52271 L p F P
0 g
s
.866 .672 .639 r
.09874 .43224 m .09553 .43037 L p .09838 .43887 L F P
0 g
s
.862 .682 .657 r
.09874 .43224 m .09653 .42787 L .09553 .43037 L closepath p F P
0 g
s
.867 .623 .569 r
.10984 .46338 m .10644 .46165 L .10626 .45582 L p F P
0 g
s
.873 .628 .566 r
.10547 .45539 m .10626 .45582 L .10644 .46165 L p F P
0 g
s
.231 0 0 r
.4972 .28443 m .49842 .28266 L .50941 .27874 L p F P
0 g
s
.852 .708 .702 r
.09314 .39778 m .09776 .40069 L .09433 .40684 L p F P
0 g
s
.848 .712 .712 r
.09776 .40069 m .09314 .39778 L .09687 .39153 L p F P
0 g
s
.693 .467 .575 r
.40553 .3141 m .40737 .31409 L .40759 .31951 L p F P
0 g
s
.693 .467 .575 r
.40759 .31951 m .4043 .31954 L .40553 .3141 L p F P
0 g
s
.698 .471 .576 r
.3929 .31406 m .40553 .3141 L .4043 .31954 L p F P
0 g
s
.68 .456 .575 r
.40737 .31409 m .42063 .31352 L .41923 .31902 L p F P
0 g
s
.68 .456 .575 r
.41923 .31902 m .40759 .31951 L .40737 .31409 L p F P
0 g
s
.698 .471 .576 r
.4043 .31954 m .39312 .3195 L .3929 .31406 L p F P
0 g
s
.708 .479 .575 r
.39238 .31404 m .3929 .31406 L .39312 .3195 L p F P
0 g
s
.714 .482 .572 r
.38051 .31356 m .39238 .31404 L .39124 .31945 L p F P
0 g
s
.708 .479 .575 r
.39312 .3195 m .39124 .31945 L .39238 .31404 L p F P
0 g
s
.68 .667 .831 r
.4451 .52226 m .45621 .51758 L .45928 .52254 L p F P
0 g
s
.682 .657 .818 r
.45621 .51758 m .4451 .52226 L .44202 .51725 L p F P
0 g
s
.275 0 .174 r
.6662 .49367 m .66618 .49372 L .6549 .50102 L p F P
0 g
s
.189 0 .067 r
.65452 .50182 m .6549 .50102 L .66618 .49372 L p F P
0 g
s
.837 .728 .744 r
.10132 .36609 m .10578 .3691 L .101 .37568 L p F P
0 g
s
.833 .73 .752 r
.10344 .36333 m .10132 .36609 L .10578 .3691 L p F P
0 g
s
.664 .686 .861 r
.49961 .5248 m .48976 .5265 L .48766 .52347 L p F P
0 g
s
.82 .737 .773 r
.11828 .34546 m .11498 .34922 L .11144 .34516 L p F P
0 g
s
.82 .737 .773 r
.11144 .34516 m .11385 .34242 L .11828 .34546 L p F P
0 g
s
.816 .738 .778 r
.11828 .34546 m .11385 .34242 L .12035 .33526 L p F P
0 g
s
0 .485 .815 r
.18265 .5186 m .18358 .5189 L .17996 .51721 L p F P
0 g
s
0 .485 .815 r
.17996 .51721 m .17667 .51631 L .18265 .5186 L p F P
0 g
s
.571 .554 .797 r
.66855 .32159 m .66399 .32182 L .66754 .31921 L closepath p F P
0 g
s
.576 .563 .802 r
.66565 .31493 m .66754 .31921 L .66399 .32182 L p F P
0 g
s
.59 .591 .821 r
.64539 .29711 m .63645 .2982 L .64341 .29302 L closepath p F P
0 g
s
.594 .6 .828 r
.64249 .29117 m .64341 .29302 L .63645 .2982 L p F P
0 g
s
.594 .6 .828 r
.631 .29278 m .64249 .29117 L p .63645 .2982 L F P
0 g
s
.867 .6 .531 r
.11483 .47118 m .10957 .46857 L .10984 .46338 L p F P
0 g
s
.87 .603 .531 r
.10644 .46165 m .10984 .46338 L .10957 .46857 L p F P
0 g
s
.76 .746 .84 r
.19054 .28126 m .18202 .2873 L .17855 .28347 L p F P
0 g
s
.579 .574 .812 r
.65984 .30211 m .66274 .30839 L .65119 .30939 L p F P
0 g
s
.579 .574 .812 r
.65127 .30284 m .65984 .30211 L p .65119 .30939 L F P
0 g
s
.579 .574 .812 r
.65119 .30939 m .64898 .3046 L .65127 .30284 L p F P
0 g
s
.729 .744 .864 r
.21261 .27334 m .20737 .27635 L .20393 .27256 L p F P
0 g
s
.746 .745 .851 r
.193 .27955 m .20393 .27256 L .20737 .27635 L p F P
0 g
s
.398 .73 .991 r
.21502 .5262 m .2149 .5262 L .21518 .5263 L closepath p F P
0 g
s
.867 .571 .484 r
.12042 .47877 m .11512 .4762 L .11483 .47118 L p F P
0 g
s
.87 .572 .482 r
.10957 .46857 m .11483 .47118 L .11512 .4762 L p F P
0 g
s
.873 .628 .566 r
.10644 .46165 m .10471 .46073 L .10547 .45539 L p F P
0 g
s
.876 .631 .566 r
.1005 .45267 m .10547 .45539 L .10471 .46073 L p F P
0 g
s
.869 .645 .595 r
.10169 .44721 m .1005 .45267 L .10547 .45539 L p F P
0 g
s
.711 .718 .854 r
.30002 .52465 m .30006 .52463 L .30816 .52622 L p F P
0 g
s
.698 .703 .851 r
.31098 .51912 m .30006 .52463 L .30816 .52622 L p F P
0 g
s
.698 .703 .851 r
.30816 .52622 m .31424 .5234 L .31098 .51912 L p F P
0 g
s
.658 .725 .899 r
.51907 .52843 m .53029 .52495 L .53327 .52855 L p F P
0 g
s
.66 .704 .879 r
.53029 .52495 m .51907 .52843 L .51607 .52454 L p F P
0 g
s
.457 .743 .99 r
.2149 .5262 m .21502 .5262 L .21152 .52386 L p F P
0 g
s
.457 .743 .99 r
.21152 .52386 m .20875 .52399 L .2149 .5262 L p F P
0 g
s
.488 .769 .993 r
.2291 .52727 m .22563 .5246 L .21502 .5262 L p F P
0 g
s
.591 .756 .957 r
.22563 .5246 m .21502 .5262 L .21152 .52386 L p F P
0 g
s
.617 .383 .54 r
.44764 .31077 m .44769 .30569 L .46018 .30355 L p F P
0 g
s
.714 .482 .572 r
.39124 .31945 m .37949 .31892 L .38051 .31356 L p F P
0 g
s
.72 .488 .574 r
.37783 .31339 m .38051 .31356 L .37949 .31892 L p F P
0 g
s
.824 .737 .768 r
.11221 .35248 m .11498 .34922 L .11144 .34516 L p F P
0 g
s
.678 .454 .575 r
.42063 .31352 m .42125 .31349 L .42148 .31891 L p F P
0 g
s
.678 .454 .575 r
.42148 .31891 m .41923 .31902 L .42063 .31352 L p F P
0 g
s
.743 .233 0 r
.14784 .50244 m .14896 .50374 L .14519 .50312 L p F P
0 g
s
.743 .233 0 r
.14519 .50312 m .14225 .49999 L .14784 .50244 L p F P
0 g
s
.664 .443 .575 r
.42148 .31891 m .42125 .31349 L .43467 .31238 L p F P
0 g
s
.846 .719 .723 r
.09687 .39153 m .09869 .38869 L .09518 .38411 L p F P
0 g
s
.676 .669 .836 r
.45928 .52254 m .47041 .51809 L .47347 .52296 L p F P
0 g
s
.678 .659 .824 r
.47041 .51809 m .45928 .52254 L .45621 .51758 L p F P
0 g
s
.864 .533 .424 r
.12667 .48617 m .12134 .48361 L .12042 .47877 L p F P
0 g
s
.866 .533 .419 r
.11512 .4762 m .12042 .47877 L .12134 .48361 L p F P
0 g
s
.562 .539 .788 r
.67179 .32919 m .67285 .32839 L p .68006 .33548 L F P
0 g
s
.566 .549 .795 r
.67179 .32919 m .67147 .32843 L .67285 .32839 L closepath p F P
0 g
s
.859 .694 .677 r
.09591 .41576 m .0932 .4215 L .0898 .41584 L p F P
0 g
s
.859 .694 .677 r
.0898 .41584 m .09118 .41291 L .09591 .41576 L p F P
0 g
s
.854 .7 .69 r
.09591 .41576 m .09118 .41291 L .09433 .40684 L p F P
0 g
s
.373 .722 .988 r
.27824 .27383 m .27789 .27383 L .27858 .27405 L closepath p F P
0 g
s
.54 .485 .744 r
.69786 .36755 m .70044 .37532 L .6989 .37638 L p F P
0 g
s
.54 .485 .744 r
.69742 .3675 m .69786 .36755 L p .6989 .37638 L F P
0 g
s
.532 .473 .735 r
.70087 .37668 m .6989 .37638 L .70044 .37532 L closepath p F P
0 g
s
.72 .488 .574 r
.37949 .31892 m .37802 .31883 L .37783 .31339 L p F P
0 g
s
.726 .493 .573 r
.36959 .31275 m .37783 .31339 L .37802 .31883 L p F P
0 g
s
.868 .659 .618 r
.09838 .43887 m .09679 .44445 L .10169 .44721 L p F P
0 g
s
.874 .649 .594 r
.09679 .44445 m .10169 .44721 L .1005 .45267 L p F P
0 g
s
.019 .55 .852 r
.19749 .52208 m .19393 .51997 L .18358 .5189 L p F P
0 g
s
.349 .702 .984 r
.18358 .5189 m .19393 .51997 L .19231 .51892 L p F P
0 g
s
.349 .702 .984 r
.17996 .51721 m .18358 .5189 L p .19231 .51892 L F P
0 g
s
.565 .55 .796 r
.67285 .32839 m .67147 .32843 L .66855 .32159 L p F P
0 g
s
.349 .093 .378 r
.68096 .47861 m .68764 .47516 L p .67719 .48475 L F P
0 g
s
.349 .093 .378 r
.67719 .48475 m .67735 .48348 L .68096 .47861 L p F P
0 g
s
.413 .191 .465 r
.68096 .47861 m .68764 .47516 L .68779 .47034 L p F P
0 g
s
.608 .625 .842 r
.6223 .27619 m .6252 .2816 L .61377 .28364 L p F P
0 g
s
.608 .625 .842 r
.61588 .27738 m .6223 .27619 L p .61377 .28364 L F P
0 g
s
.608 .625 .842 r
.61377 .28364 m .61193 .28026 L .61588 .27738 L p F P
0 g
s
.607 .619 .837 r
.61377 .28364 m .6252 .2816 L .6281 .28706 L p F P
0 g
s
.618 .864 .989 r
.58946 .52504 m .59004 .52536 L .60137 .52187 L p F P
0 g
s
.653 .746 .918 r
.53327 .52855 m .54451 .52518 L .54747 .52842 L p F P
0 g
s
.657 .72 .896 r
.54451 .52518 m .53327 .52855 L .53029 .52495 L p F P
0 g
s
.234 .659 .959 r
.27789 .27383 m .27824 .27383 L .27479 .27187 L p F P
0 g
s
.234 .659 .959 r
.27479 .27187 m .27131 .2715 L .27789 .27383 L p F P
0 g
s
.506 .416 .688 r
.71018 .40949 m .70525 .40765 L .70912 .40514 L closepath p F P
0 g
s
.516 .432 .699 r
.70725 .39805 m .70912 .40514 L .70525 .40765 L p F P
0 g
s
.746 .49 .544 r
.35958 .31164 m .3501 .31035 L .35031 .30528 L p F P
0 g
s
.76 .502 .544 r
.34536 .30442 m .35031 .30528 L .3501 .31035 L p F P
0 g
s
.864 .684 .657 r
.09553 .43037 m .09653 .42787 L .09347 .42195 L p F P
0 g
s
.827 .735 .763 r
.10781 .34943 m .11221 .35248 L .10658 .35934 L p F P
0 g
s
.824 .737 .768 r
.11144 .34516 m .10781 .34943 L .11221 .35248 L p F P
0 g
s
.765 .477 .498 r
.34144 .30378 m .333 .30213 L .3324 .29735 L p F P
0 g
s
.781 .49 .494 r
.32818 .29632 m .3324 .29735 L .333 .30213 L p F P
0 g
s
.595 .602 .829 r
.63959 .28543 m .64249 .29117 L .631 .29278 L p F P
0 g
s
.595 .602 .829 r
.62881 .28695 m .63959 .28543 L p .631 .29278 L F P
0 g
s
.595 .602 .829 r
.631 .29278 m .62826 .28737 L .62881 .28695 L p F P
0 g
s
.605 .93 .963 r
.52259 .27337 m .52373 .27359 L .53397 .26872 L p F P
0 g
s
.635 .893 .986 r
.53677 .27026 m .53397 .26872 L .52373 .27359 L p F P
0 g
s
.857 .481 .335 r
.12667 .48617 m .12825 .4908 L .12825 .4908 L p F P
0 g
s
.857 .481 .335 r
.12134 .48361 m .12667 .48617 L p .12825 .4908 L F P
0 g
s
.478 .356 .635 r
.70414 .43104 m .71359 .42511 L p .70634 .43652 L F P
0 g
s
.478 .356 .635 r
.70634 .43652 m .70489 .43535 L .70414 .43104 L p F P
0 g
s
.489 .378 .654 r
.71352 .42477 m .71359 .42511 L .70414 .43104 L p F P
0 g
s
.489 .378 .654 r
.70798 .42142 m .71352 .42477 L p .70414 .43104 L F P
0 g
s
.704 .668 .812 r
.38481 .51733 m .38527 .51809 L p .37108 .51886 L F P
0 g
s
.704 .668 .812 r
.37108 .51886 m .37453 .517 L .38481 .51733 L p F P
0 g
s
.706 .675 .817 r
.37108 .51886 m .37453 .517 L .36976 .51676 L closepath p F P
0 g
s
.706 .674 .816 r
.36976 .51676 m .37108 .51886 L p .35688 .51981 L F P
0 g
s
.7 .663 .81 r
.39944 .51751 m .39946 .51754 L p .38527 .51809 L F P
0 g
s
.7 .663 .81 r
.38527 .51809 m .38664 .51738 L .39944 .51751 L p F P
0 g
s
.702 .668 .814 r
.38527 .51809 m .38664 .51738 L .38481 .51733 L closepath p F P
0 g
s
.872 .664 .619 r
.09356 .43607 m .09838 .43887 L .09679 .44445 L p F P
0 g
s
.866 .672 .639 r
.09553 .43037 m .09356 .43607 L .09838 .43887 L p F P
0 g
s
.648 .773 .94 r
.54747 .52842 m .55874 .52512 L .56167 .52795 L p F P
0 g
s
.653 .743 .916 r
.55874 .52512 m .54747 .52842 L .54451 .52518 L p F P
0 g
s
.398 .18 .462 r
.68764 .47516 m .68779 .47034 L .69761 .46501 L p F P
0 g
s
.431 .237 .516 r
.69747 .45987 m .69761 .46501 L .68779 .47034 L p F P
0 g
s
.049 0 0 r
.66478 .49716 m .65452 .50182 L .65245 .50463 L p F P
0 g
s
.189 0 .067 r
.66618 .49372 m .66478 .49716 L .65452 .50182 L p F P
0 g
s
.041 0 0 r
.65452 .50182 m .65245 .50463 L .64199 .50904 L p F P
0 g
s
.483 .182 .379 r
.48445 .29331 m .48532 .28921 L .49667 .28572 L p F P
0 g
s
.392 .018 .204 r
.4972 .28443 m .49667 .28572 L .48532 .28921 L p F P
0 g
s
.51 .202 .38 r
.48532 .28921 m .48445 .29331 L .47271 .29633 L p F P
0 g
s
.672 .673 .843 r
.47347 .52296 m .48462 .51874 L .48766 .52347 L p F P
0 g
s
.673 .661 .83 r
.48462 .51874 m .47347 .52296 L .47041 .51809 L p F P
0 g
s
.709 .682 .822 r
.35688 .51981 m .36314 .51641 L .35418 .5157 L closepath p F P
0 g
s
.708 .681 .821 r
.35418 .5157 m .35688 .51981 L p .34267 .52091 L F P
0 g
s
.706 .674 .816 r
.35688 .51981 m .36314 .51641 L .36976 .51676 L p F P
0 g
s
.776 .435 .41 r
.32445 .29553 m .31676 .29361 L .31513 .2892 L p F P
0 g
s
.8 .465 .423 r
.31053 .28775 m .31513 .2892 L .31676 .29361 L p F P
0 g
s
.62 .849 .986 r
.58946 .52504 m .58718 .52365 L .57586 .52699 L p F P
0 g
s
.639 .81 .965 r
.58718 .52365 m .57586 .52699 L .57296 .52466 L p F P
0 g
s
.638 .808 .965 r
.56167 .52795 m .57296 .52466 L .57586 .52699 L p F P
0 g
s
.696 .66 .81 r
.39946 .51754 m .39953 .51751 L .41333 .51737 L p F P
0 g
s
.697 .662 .812 r
.39946 .51754 m .39953 .51751 L .39944 .51751 L closepath p F P
0 g
s
.851 .715 .713 r
.09234 .38857 m .09687 .39153 L .09314 .39778 L p F P
0 g
s
.846 .719 .723 r
.09518 .38411 m .09234 .38857 L .09687 .39153 L p F P
0 g
s
.697 .662 .811 r
.39953 .51751 m .39944 .51751 L .39634 .51226 L p F P
0 g
s
.7 .663 .81 r
.39944 .51751 m .39634 .51226 L .38664 .51738 L closepath p F P
0 g
s
.62 .642 .85 r
.59657 .27582 m .60796 .27329 L .61086 .27836 L p F P
0 g
s
.623 .648 .854 r
.60796 .27329 m .59657 .27582 L .59366 .27096 L p F P
0 g
s
.689 .656 .812 r
.41054 .51187 m .39953 .51751 L .41333 .51737 L p F P
0 g
s
.697 .662 .811 r
.40743 .50629 m .41054 .51187 L .39953 .51751 L p F P
0 g
s
.697 .662 .811 r
.39634 .51226 m .40743 .50629 L p .39953 .51751 L F P
0 g
s
.76 .746 .84 r
.17855 .28347 m .18605 .27819 L .19054 .28126 L p F P
0 g
s
.76 .747 .841 r
.18953 .27577 m .18605 .27819 L .19054 .28126 L p F P
0 g
s
.76 .747 .841 r
.19054 .28126 m .193 .27955 L .18953 .27577 L p F P
0 g
s
0 0 0 r
.64199 .50904 m .64098 .5098 L .62962 .51444 L p F P
0 g
s
.345 .814 .739 r
.62817 .51487 m .62962 .51444 L .64098 .5098 L p F P
0 g
s
.726 .493 .573 r
.37802 .31883 m .36861 .3181 L .36959 .31275 L p F P
0 g
s
.738 .505 .575 r
.36197 .31192 m .36959 .31275 L .36861 .3181 L p F P
0 g
s
.729 .744 .864 r
.20393 .27256 m .2078 .27037 L .21261 .27334 L p F P
0 g
s
.731 .748 .866 r
.21481 .26645 m .2078 .27037 L .21261 .27334 L p F P
0 g
s
.731 .748 .866 r
.21261 .27334 m .21825 .27013 L .21481 .26645 L p F P
0 g
s
.442 .272 .554 r
.69907 .4533 m .69707 .45445 L .69747 .45987 L p F P
0 g
s
.648 .772 .939 r
.57296 .52466 m .56167 .52795 L .55874 .52512 L p F P
0 g
s
.837 .728 .744 r
.101 .37568 m .09651 .37269 L .10132 .36609 L p F P
0 g
s
.84 .725 .738 r
.09651 .37269 m .101 .37568 L .09644 .3822 L p F P
0 g
s
.664 .734 .902 r
.55096 .26889 m .56224 .26508 L .56517 .26871 L p F P
0 g
s
.675 .769 .921 r
.56224 .26508 m .55096 .26889 L .54802 .26606 L p F P
0 g
s
.677 .792 .936 r
.53677 .27026 m .54802 .26606 L .55096 .26889 L p F P
0 g
s
.791 .746 .812 r
.15209 .30466 m .14532 .31063 L .14179 .30678 L p F P
0 g
s
.797 .746 .806 r
.1431 .31267 m .14532 .31063 L .14179 .30678 L p F P
0 g
s
.795 .745 .806 r
.13876 .30956 m .1431 .31267 L .13486 .32043 L p F P
0 g
s
.797 .746 .806 r
.14179 .30678 m .13876 .30956 L .1431 .31267 L p F P
0 g
s
.708 .681 .821 r
.34267 .52091 m .35254 .51558 L .35418 .5157 L p F P
0 g
s
.714 .676 .811 r
.35254 .51558 m .34267 .52091 L .33947 .51624 L p F P
0 g
s
.71 .689 .829 r
.32846 .52213 m .33947 .51624 L .34267 .52091 L p F P
0 g
s
.746 .297 .185 r
.30801 .28709 m .30088 .28497 L .29761 .28114 L p F P
0 g
s
.78 .344 .215 r
.29301 .27932 m .29761 .28114 L .30088 .28497 L p F P
0 g
s
.621 .755 .942 r
.2291 .52727 m .2398 .52461 L .24323 .5276 L p F P
0 g
s
.643 .751 .927 r
.2398 .52461 m .2291 .52727 L .22563 .5246 L p F P
0 g
s
.562 .539 .788 r
.67285 .32839 m .6831 .32831 L p .68006 .33548 L F P
0 g
s
.56 .54 .79 r
.6831 .32831 m .67285 .32839 L .68066 .32238 L closepath p F P
0 g
s
.565 .55 .796 r
.68018 .32126 m .68066 .32238 L .67285 .32839 L p F P
0 g
s
.565 .55 .796 r
.66855 .32159 m .68018 .32126 L p .67285 .32839 L F P
0 g
s
.702 .667 .813 r
.39321 .50676 m .39634 .51226 L .38664 .51738 L p F P
0 g
s
.702 .667 .813 r
.38213 .51292 m .39321 .50676 L p .38664 .51738 L F P
0 g
s
.702 .667 .813 r
.38664 .51738 m .38481 .51733 L .38213 .51292 L p F P
0 g
s
.689 .656 .812 r
.41333 .51737 m .41365 .51722 L .41054 .51187 L p F P
0 g
s
.693 .669 .822 r
.41374 .51736 m .41365 .51722 L .41333 .51737 L closepath p F P
0 g
s
.696 .67 .821 r
.42474 .51175 m .42769 .51688 L .41374 .51736 L p F P
0 g
s
.696 .67 .821 r
.41374 .51736 m .41365 .51722 L .42474 .51175 L p F P
0 g
s
.704 .668 .812 r
.38481 .51733 m .38213 .51292 L .37453 .517 L closepath p F P
0 g
s
.802 .743 .798 r
.13412 .32114 m .13486 .32043 L .13111 .31779 L closepath p F P
0 g
s
.795 .745 .806 r
.13059 .31723 m .13876 .30956 L p .13486 .32043 L F P
0 g
s
.795 .745 .806 r
.13486 .32043 m .13111 .31779 L .13059 .31723 L p F P
0 g
s
.694 .649 .801 r
.42474 .51175 m .41365 .51722 L .41054 .51187 L p F P
0 g
s
.791 .746 .812 r
.14179 .30678 m .14773 .30155 L .15209 .30466 L p F P
0 g
s
.789 .747 .814 r
.15294 .29705 m .14773 .30155 L .15209 .30466 L p F P
0 g
s
.789 .747 .814 r
.15209 .30466 m .15645 .30089 L .15294 .29705 L p F P
0 g
s
.275 0 .202 r
.66618 .49372 m .66635 .4936 L .6662 .49367 L closepath p F P
0 g
s
.34 .044 .309 r
.6662 .49367 m .66635 .4936 L .67556 .48554 L p F P
0 g
s
.808 .744 .792 r
.1274 .32791 m .13412 .32114 L .13111 .31779 L p F P
0 g
s
.381 .119 .387 r
.67556 .48554 m .67719 .48475 L .67735 .48348 L closepath p F P
0 g
s
.584 .583 .818 r
.64898 .3046 m .64829 .30314 L .65127 .30284 L closepath p F P
0 g
s
.195 0 .109 r
.66478 .49716 m .66618 .49372 L .66635 .4936 L p F P
0 g
s
.195 0 .109 r
.66635 .4936 m .6763 .48877 L p .66478 .49716 L F P
0 g
s
.323 .022 .291 r
.67719 .48475 m .67556 .48554 L .66635 .4936 L p F P
0 g
s
.323 .022 .291 r
.66635 .4936 m .6763 .48877 L .67719 .48475 L p F P
0 g
s
.714 .681 .817 r
.33947 .51624 m .32846 .52213 L .32523 .51764 L p F P
0 g
s
.746 .747 .853 r
.20393 .27256 m .193 .27955 L .18953 .27577 L p F P
0 g
s
.782 .747 .821 r
.16197 .29634 m .15645 .30089 L .15294 .29705 L p F P
0 g
s
.644 .425 .571 r
.43467 .31238 m .43912 .31181 L .43731 .31746 L p F P
0 g
s
.644 .425 .571 r
.43731 .31746 m .43488 .31777 L .43467 .31238 L p F P
0 g
s
.664 .443 .575 r
.43467 .31238 m .43488 .31777 L .42148 .31891 L p F P
0 g
s
.625 .852 .985 r
.58718 .52365 m .58946 .52504 L .60048 .52139 L p F P
0 g
s
.618 .864 .989 r
.60137 .52187 m .60048 .52139 L .58946 .52504 L p F P
0 g
s
.537 .485 .745 r
.69786 .36755 m .69742 .3675 L .69777 .36726 L closepath p F P
0 g
s
.544 .497 .753 r
.69488 .35897 m .69777 .36726 L .69742 .3675 L p F P
0 g
s
.544 .497 .753 r
.6948 .35896 m .69488 .35897 L p .69742 .3675 L F P
0 g
s
.652 .877 .982 r
.53397 .26872 m .53677 .27026 L .54802 .26606 L p F P
0 g
s
.65 .698 .881 r
.56517 .26871 m .57648 .26528 L .5794 .26946 L p F P
0 g
s
.658 .718 .893 r
.57648 .26528 m .56517 .26871 L .56224 .26508 L p F P
0 g
s
.856 .703 .692 r
.08968 .40394 m .09433 .40684 L .09118 .41291 L p F P
0 g
s
.852 .708 .702 r
.09433 .40684 m .08968 .40394 L .09314 .39778 L p F P
0 g
s
.525 .469 .736 r
.70044 .37532 m .70891 .36917 L p .70969 .37829 L F P
0 g
s
.525 .469 .736 r
.70969 .37829 m .70087 .37668 L .70044 .37532 L p F P
0 g
s
.53 .481 .745 r
.70044 .37532 m .69786 .36755 L .70891 .36917 L closepath p F P
0 g
s
.525 .468 .735 r
.70291 .38313 m .70087 .37668 L .70969 .37829 L closepath p F P
0 g
s
.76 .502 .544 r
.3501 .31035 m .34519 .3095 L .34536 .30442 L p F P
0 g
s
.756 .499 .544 r
.34144 .30378 m .34536 .30442 L .34519 .3095 L p F P
0 g
s
.519 .456 .725 r
.70291 .38313 m .70969 .37829 L p .70941 .38773 L F P
0 g
s
.519 .456 .725 r
.70941 .38773 m .70392 .3865 L .70291 .38313 L p F P
0 g
s
.87 .677 .639 r
.09078 .42754 m .09553 .43037 L .09356 .43607 L p F P
0 g
s
.864 .684 .657 r
.0931 .42173 m .09078 .42754 L .09553 .43037 L p F P
0 g
s
.864 .684 .657 r
.09347 .42195 m .0931 .42173 L p .09553 .43037 L F P
0 g
s
.706 .674 .816 r
.37899 .50752 m .38213 .51292 L .37453 .517 L p F P
0 g
s
.706 .674 .816 r
.36792 .51383 m .37899 .50752 L p .37453 .517 L F P
0 g
s
.706 .674 .816 r
.37453 .517 m .36976 .51676 L .36792 .51383 L p F P
0 g
s
.715 .692 .827 r
.32523 .51764 m .31424 .5234 L .31098 .51912 L p F P
0 g
s
.687 .656 .814 r
.44136 .51611 m .44202 .51725 L p .42783 .51713 L F P
0 g
s
.687 .656 .814 r
.42783 .51713 m .42846 .51683 L .44136 .51611 L p F P
0 g
s
.687 .655 .813 r
.42783 .51713 m .42846 .51683 L .42769 .51688 L closepath p F P
0 g
s
.649 .094 0 r
.15802 .5086 m .15217 .50625 L .14896 .50374 L p F P
0 g
s
.653 .101 0 r
.15217 .50625 m .14896 .50374 L .14519 .50312 L p F P
0 g
s
.81 .743 .789 r
.1274 .32791 m .12284 .33261 L .11929 .32869 L p F P
0 g
s
.81 .743 .789 r
.11929 .32869 m .12305 .32482 L .1274 .32791 L p F P
0 g
s
.808 .744 .792 r
.13048 .31734 m .12305 .32482 L .1274 .32791 L p F P
0 g
s
.808 .744 .792 r
.13111 .31779 m .13048 .31734 L p .1274 .32791 L F P
0 g
s
.375 0 0 r
.16619 .51244 m .17062 .51403 L .17667 .51631 L p F P
0 g
s
.247 0 0 r
.17062 .51403 m .16619 .51244 L .1625 .51118 L p F P
0 g
s
.664 .686 .861 r
.48766 .52347 m .49883 .51947 L p .49961 .5248 L F P
0 g
s
.669 .665 .838 r
.49883 .51947 m .48766 .52347 L .48462 .51874 L p F P
0 g
s
.53 .481 .746 r
.70891 .36917 m .69786 .36755 L .69777 .36726 L p F P
0 g
s
.53 .481 .746 r
.69777 .36726 m .70675 .3606 L p .70891 .36917 L F P
0 g
s
.535 .493 .755 r
.70665 .36032 m .70675 .3606 L .69777 .36726 L p F P
0 g
s
.535 .493 .755 r
.69777 .36726 m .69488 .35897 L .70665 .36032 L p F P
0 g
s
.666 .698 .87 r
.50215 .52442 m .50186 .52403 L .49961 .5248 L closepath p F P
0 g
s
.664 .686 .861 r
.49883 .51947 m .50186 .52403 L .49961 .5248 L p F P
0 g
s
0 0 0 r
.64098 .5098 m .64199 .50904 L .65245 .50463 L p F P
0 g
s
.52 .456 .725 r
.70517 .3907 m .70392 .3865 L .70941 .38773 L closepath p F P
0 g
s
.782 .747 .821 r
.15294 .29705 m .15757 .29323 L .16197 .29634 L p F P
0 g
s
.78 .747 .823 r
.16402 .28802 m .15757 .29323 L .16197 .29634 L p F P
0 g
s
.78 .747 .823 r
.16197 .29634 m .16752 .29184 L .16402 .28802 L p F P
0 g
s
.803 .346 .154 r
.12825 .49081 m .13387 .49326 L .13669 .49753 L p F P
0 g
s
.839 .453 .319 r
.12825 .4908 m .12825 .49081 L .13387 .49326 L p F P
0 g
s
.807 .357 .172 r
.14225 .49999 m .13669 .49753 L .13387 .49326 L p F P
0 g
s
.556 .299 .481 r
.47231 .30097 m .47271 .29633 L .48445 .29331 L p F P
0 g
s
.831 .733 .757 r
.10658 .35934 m .10344 .36333 L .09989 .35919 L p F P
0 g
s
.831 .733 .757 r
.09989 .35919 m .10216 .35631 L .10658 .35934 L p F P
0 g
s
.827 .735 .763 r
.10658 .35934 m .10216 .35631 L .10781 .34943 L p F P
0 g
s
.781 .49 .494 r
.333 .30213 m .32738 .30078 L .32818 .29632 L p F P
0 g
s
.772 .479 .491 r
.32445 .29553 m .32818 .29632 L .32738 .30078 L p F P
0 g
s
.687 .654 .812 r
.42846 .51683 m .42769 .51688 L .42474 .51175 L p F P
0 g
s
.673 .742 .902 r
.25401 .52409 m .24323 .5276 L .2398 .52461 L p F P
0 g
s
.658 .747 .915 r
.24323 .5276 m .25401 .52409 L .25739 .52736 L p F P
0 g
s
.584 .586 .82 r
.65127 .30284 m .64829 .30314 L .64539 .29711 L p F P
0 g
s
.687 .655 .813 r
.44136 .51611 m .43894 .5119 L .42846 .51683 L closepath p F P
0 g
s
.687 .654 .812 r
.43585 .50626 m .43894 .5119 L .42846 .51683 L p F P
0 g
s
.687 .654 .812 r
.42474 .51175 m .43585 .50626 L p .42846 .51683 L F P
0 g
s
.668 .753 .914 r
.23251 .26855 m .24327 .26465 L .2467 .26799 L p F P
0 g
s
.657 .753 .921 r
.24327 .26465 m .23251 .26855 L .22908 .26498 L p F P
0 g
s
.706 .749 .885 r
.21825 .27013 m .22908 .26498 L .23251 .26855 L p F P
0 g
s
.87 .603 .531 r
.10957 .46857 m .10543 .46648 L .10644 .46165 L p F P
0 g
s
.877 .61 .531 r
.10471 .46073 m .10644 .46165 L .10543 .46648 L p F P
0 g
s
.712 .718 .854 r
.30002 .52465 m .30006 .52463 L .29999 .52462 L closepath p F P
0 g
s
.702 .714 .858 r
.29999 .52462 m .30002 .52465 L p .2858 .52577 L F P
0 g
s
.706 .674 .816 r
.36976 .51676 m .36792 .51383 L .36314 .51641 L closepath p F P
0 g
s
.712 .717 .853 r
.30773 .51467 m .31098 .51912 L .30006 .52463 L p F P
0 g
s
.712 .717 .853 r
.29673 .5206 m .30773 .51467 L p .30006 .52463 L F P
0 g
s
.712 .717 .853 r
.30006 .52463 m .29999 .52462 L .29673 .5206 L p F P
0 g
s
.514 .443 .714 r
.70517 .3907 m .70941 .38773 L p .70808 .39747 L F P
0 g
s
.514 .443 .714 r
.70808 .39747 m .70701 .39718 L .70517 .3907 L p F P
0 g
s
.702 .714 .858 r
.2858 .52577 m .29088 .52336 L .29999 .52462 L p F P
0 g
s
.702 .715 .859 r
.29999 .52462 m .29673 .5206 L .29088 .52336 L closepath p F P
0 g
s
.738 .505 .575 r
.36861 .3181 m .36219 .31739 L .36197 .31192 L p F P
0 g
s
.74 .506 .575 r
.35958 .31164 m .36197 .31192 L .36219 .31739 L p F P
0 g
s
.58 .756 .962 r
.2467 .26799 m .25737 .26591 L .2608 .26881 L p F P
0 g
s
.546 .75 .971 r
.25737 .26591 m .2467 .26799 L .24327 .26465 L p F P
0 g
s
.558 .529 .78 r
.68006 .33548 m .68603 .33556 L p .68612 .34295 L F P
0 g
s
.556 .53 .782 r
.68603 .33556 m .68006 .33548 L .68463 .33204 L closepath p F P
0 g
s
.562 .539 .788 r
.6831 .32831 m .68463 .33204 L .68006 .33548 L p F P
0 g
s
.815 .743 .784 r
.12035 .33526 m .12284 .33261 L .11929 .32869 L p F P
0 g
s
.564 .55 .798 r
.67727 .31446 m .68018 .32126 L .66855 .32159 L p F P
0 g
s
.564 .55 .798 r
.67345 .31456 m .67727 .31446 L p .66855 .32159 L F P
0 g
s
.564 .55 .798 r
.66855 .32159 m .66754 .31921 L .67345 .31456 L p F P
0 g
s
.646 .428 .572 r
.43912 .31181 m .44764 .31077 L .44787 .31616 L p F P
0 g
s
.646 .428 .572 r
.44787 .31616 m .43731 .31746 L .43912 .31181 L p F P
0 g
s
.612 .632 .846 r
.61193 .28026 m .61086 .27836 L .61588 .27738 L closepath p F P
0 g
s
.714 .721 .855 r
.29088 .52336 m .2858 .52577 L .28248 .52199 L p F P
0 g
s
.694 .726 .875 r
.27159 .52671 m .28248 .52199 L .2858 .52577 L p F P
0 g
s
.68 .737 .893 r
.25739 .52736 m .26824 .52318 L .27159 .52671 L p F P
0 g
s
.691 .731 .881 r
.26824 .52318 m .25739 .52736 L .25401 .52409 L p F P
0 g
s
.772 .747 .831 r
.17308 .28759 m .16752 .29184 L .16402 .28802 L p F P
0 g
s
.665 .698 .871 r
.51306 .52024 m .51447 .52226 L .50215 .52442 L p F P
0 g
s
.665 .698 .871 r
.50215 .52442 m .50186 .52403 L .51306 .52024 L p F P
0 g
s
.542 .497 .755 r
.69488 .35897 m .6948 .35896 L .69486 .35892 L closepath p F P
0 g
s
.549 .508 .762 r
.69192 .35083 m .69486 .35892 L .6948 .35896 L p F P
0 g
s
.549 .508 .762 r
.69104 .35078 m .69192 .35083 L p .6948 .35896 L F P
0 g
s
.682 .657 .818 r
.45472 .51502 m .45621 .51758 L p .44202 .51725 L F P
0 g
s
.682 .657 .818 r
.44202 .51725 m .44537 .51576 L .45472 .51502 L p F P
0 g
s
.682 .653 .816 r
.44202 .51725 m .44537 .51576 L .44136 .51611 L closepath p F P
0 g
s
.703 .719 .862 r
.28248 .52199 m .27159 .52671 L .26824 .52318 L p F P
0 g
s
.479 .356 .635 r
.70521 .43721 m .70489 .43535 L .70634 .43652 L closepath p F P
0 g
s
.696 .483 .595 r
.4043 .31954 m .40759 .31951 L .40806 .32521 L p F P
0 g
s
.696 .483 .595 r
.40806 .32521 m .40225 .32526 L .4043 .31954 L p F P
0 g
s
.701 .488 .597 r
.39312 .3195 m .4043 .31954 L .40225 .32526 L p F P
0 g
s
.756 .499 .544 r
.34519 .3095 m .34123 .30885 L .34144 .30378 L p F P
0 g
s
.768 .509 .543 r
.333 .30213 m .34144 .30378 L .34123 .30885 L p F P
0 g
s
.533 .492 .756 r
.70379 .35218 m .70665 .36032 L .69488 .35897 L p F P
0 g
s
.533 .492 .756 r
.69488 .35897 m .69486 .35892 L .70379 .35218 L p F P
0 g
s
.86 .692 .673 r
.09347 .42195 m .0932 .4215 L .0931 .42173 L closepath p F P
0 g
s
.54 .504 .765 r
.70367 .35184 m .70379 .35218 L .69486 .35892 L p F P
0 g
s
.54 .504 .765 r
.69486 .35892 m .69192 .35083 L .70367 .35184 L p F P
0 g
s
.74 .506 .575 r
.36219 .31739 m .3586 .31698 L .35958 .31164 L p F P
0 g
s
.75 .513 .573 r
.3501 .31035 m .35958 .31164 L .3586 .31698 L p F P
0 g
s
.683 .474 .596 r
.40759 .31951 m .41923 .31902 L .41689 .32484 L p F P
0 g
s
.683 .474 .596 r
.41689 .32484 m .40806 .32521 L .40759 .31951 L p F P
0 g
s
.401 0 0 r
.15802 .5086 m .1625 .51118 L .15958 .50997 L p F P
0 g
s
.401 0 0 r
.15217 .50625 m .15802 .5086 L p .15958 .50997 L F P
0 g
s
.701 .488 .597 r
.40225 .32526 m .3936 .32523 L .39312 .3195 L p F P
0 g
s
.711 .496 .596 r
.39124 .31945 m .39312 .3195 L .3936 .32523 L p F P
0 g
s
.818 .741 .78 r
.11604 .33216 m .12035 .33526 L .11385 .34242 L p F P
0 g
s
.815 .743 .784 r
.11929 .32869 m .11604 .33216 L .12035 .33526 L p F P
0 g
s
.718 .502 .597 r
.37949 .31892 m .39124 .31945 L .38937 .3251 L p F P
0 g
s
.711 .496 .596 r
.3936 .32523 m .38937 .3251 L .39124 .31945 L p F P
0 g
s
.709 .681 .821 r
.36476 .50856 m .36792 .51383 L .36314 .51641 L p F P
0 g
s
.709 .681 .821 r
.35369 .51496 m .36476 .50856 L p .36314 .51641 L F P
0 g
s
.709 .681 .821 r
.36314 .51641 m .35418 .5157 L .35369 .51496 L p F P
0 g
s
.702 .75 .889 r
.22908 .26498 m .21825 .27013 L .21481 .26645 L p F P
0 g
s
.862 .695 .674 r
.0931 .42173 m .0932 .4215 L .0898 .41584 L p F P
0 g
s
.634 .678 .875 r
.5794 .26946 m .59075 .26639 L p .59215 .27134 L F P
0 g
s
.643 .686 .876 r
.59075 .26639 m .5794 .26946 L .57648 .26528 L p F P
0 g
s
.442 .272 .554 r
.69747 .45987 m .70021 .45829 L .69907 .4533 L p F P
0 g
s
.438 .269 .554 r
.70671 .44883 m .69907 .4533 L .70021 .45829 L p F P
0 g
s
.458 .306 .586 r
.69907 .4533 m .70671 .44883 L .70607 .44314 L p F P
0 g
s
.035 .547 .872 r
.17667 .51631 m .17996 .51721 L .17636 .51531 L p F P
0 g
s
.665 .672 .848 r
.51306 .52024 m .50186 .52403 L .49883 .51947 L p F P
0 g
s
.514 .443 .714 r
.70725 .39805 m .70701 .39718 L .70808 .39747 L closepath p F P
0 g
s
.551 .52 .773 r
.68897 .34305 m .68612 .34295 L .68831 .34133 L closepath p F P
0 g
s
.558 .529 .78 r
.68603 .33556 m .68831 .34133 L .68612 .34295 L p F P
0 g
s
.553 .519 .771 r
.68612 .34295 m .68897 .34305 L p .69104 .35078 L F P
0 g
s
.596 .366 .538 r
.46018 .30355 m .46617 .30225 L .46599 .30736 L p F P
0 g
s
.596 .366 .538 r
.46599 .30736 m .46014 .30863 L .46018 .30355 L p F P
0 g
s
.617 .383 .54 r
.46018 .30355 m .46014 .30863 L .44764 .31077 L p F P
0 g
s
.835 .733 .753 r
.10132 .36609 m .10344 .36333 L .09989 .35919 L p F P
0 g
s
.862 .695 .674 r
.0898 .41584 m .08843 .41885 L .0931 .42173 L p F P
0 g
s
.868 .688 .657 r
.08843 .41885 m .0931 .42173 L .09078 .42754 L p F P
0 g
s
.295 0 .266 r
.68716 .47963 m .67719 .48475 L .6763 .48877 L p F P
0 g
s
.349 .093 .378 r
.68764 .47516 m .68716 .47963 L .67719 .48475 L p F P
0 g
s
.8 .465 .423 r
.30927 .28982 m .31053 .28775 L p .31676 .29361 L F P
0 g
s
.775 .414 .372 r
.30927 .28982 m .30801 .28709 L .31053 .28775 L closepath p F P
0 g
s
.547 .508 .765 r
.69192 .35083 m .69104 .35078 L .69172 .35028 L closepath p F P
0 g
s
.553 .519 .771 r
.68897 .34305 m .69172 .35028 L .69104 .35078 L p F P
0 g
s
.505 .426 .7 r
.70808 .39747 m .70725 .39805 L .70912 .40514 L p F P
0 g
s
.569 .56 .804 r
.66754 .31921 m .66565 .31493 L .67345 .31456 L closepath p F P
0 g
s
.772 .479 .491 r
.32738 .30078 m .32511 .30029 L .32445 .29553 L p F P
0 g
s
.782 .491 .494 r
.31676 .29361 m .32445 .29553 L .32511 .30029 L p F P
0 g
s
.845 .722 .727 r
.09644 .3822 m .09518 .38411 L .09165 .37964 L p F P
0 g
s
.845 .722 .727 r
.09165 .37964 m .09193 .37922 L .09644 .3822 L p F P
0 g
s
.84 .725 .738 r
.09644 .3822 m .09193 .37922 L .09651 .37269 L p F P
0 g
s
.772 .747 .831 r
.16402 .28802 m .16866 .28448 L .17308 .28759 L p F P
0 g
s
.771 .748 .833 r
.17506 .27968 m .16866 .28448 L .17308 .28759 L p F P
0 g
s
.771 .748 .833 r
.17308 .28759 m .17855 .28347 L .17506 .27968 L p F P
0 g
s
.682 .653 .815 r
.44537 .51576 m .44136 .51611 L .43894 .5119 L p F P
0 g
s
.498 .755 .987 r
.20875 .52399 m .21152 .52386 L .20801 .52133 L p F P
0 g
s
.498 .755 .987 r
.20801 .52133 m .20236 .52184 L .20875 .52399 L p F P
0 g
s
.361 .733 .988 r
.19749 .52208 m .20236 .52184 L .20875 .52399 L p F P
0 g
s
.438 .753 .994 r
.20236 .52184 m .19749 .52208 L .19393 .51997 L p F P
0 g
s
.681 .472 .595 r
.41923 .31902 m .42148 .31891 L .42195 .3246 L p F P
0 g
s
.681 .472 .595 r
.42195 .3246 m .41689 .32484 L .41923 .31902 L p F P
0 g
s
.463 .328 .611 r
.70634 .43652 m .70521 .43721 L .70607 .44314 L p F P
0 g
s
.678 .659 .824 r
.46775 .51359 m .47041 .51809 L p .45621 .51758 L F P
0 g
s
.678 .659 .824 r
.45621 .51758 m .46511 .51385 L .46775 .51359 L p F P
0 g
s
.676 .653 .82 r
.45621 .51758 m .46511 .51385 L .45472 .51502 L closepath p F P
0 g
s
.499 .397 .67 r
.7108 .41202 m .71228 .41867 L .70798 .42142 L p F P
0 g
s
.487 .379 .656 r
.71352 .42477 m .70798 .42142 L .71228 .41867 L closepath p F P
0 g
s
.854 .711 .704 r
.08859 .39483 m .09314 .39778 L .08968 .40394 L p F P
0 g
s
.851 .715 .713 r
.09314 .39778 m .08859 .39483 L .09234 .38857 L p F P
0 g
s
.605 .93 .963 r
.53397 .26872 m .53382 .26867 L .52259 .27337 L p F P
0 g
s
.299 .777 .682 r
.52003 .27434 m .52259 .27337 L .53382 .26867 L p F P
0 g
s
0 0 0 r
.52259 .27337 m .52003 .27434 L p .5136 .27703 L F P
0 g
s
.019 0 0 r
.52003 .27434 m .51962 .27483 L .52223 .27342 L p F P
0 g
s
.299 .777 .682 r
.52003 .27434 m .52115 .27388 L .53087 .26914 L F
.53382 .26867 m .53087 .26914 L p .52115 .27388 L F P
0 g
s
.641 .954 .938 r
.53087 .26914 m .54214 .26343 L .54406 .26361 L p F P
0 g
s
0 0 0 r
.53087 .26914 m .54214 .26343 L p .53541 .26692 L F P
0 g
s
.641 .954 .938 r
.53506 .26814 m .53382 .26867 L .53087 .26914 L p F P
0 g
s
.641 .954 .938 r
.54406 .26361 m .53506 .26814 L p .53087 .26914 L F P
0 g
s
0 0 0 r
.53037 .26954 m .53087 .26914 L p .53541 .26692 L F P
0 g
s
.019 0 0 r
.52223 .27342 m .52428 .27232 L .52003 .27434 L p F P
0 g
s
0 0 0 r
.52003 .27434 m .50941 .27874 L p .5136 .27703 L F P
0 g
s
.231 0 0 r
.50941 .27874 m .5084 .28015 L .4972 .28443 L p F P
0 g
s
.362 0 .201 r
.49667 .28572 m .4972 .28443 L .5084 .28015 L p F P
0 g
s
.718 .502 .597 r
.37834 .32271 m .37949 .31892 L p .38937 .3251 L F P
0 g
s
.722 .504 .595 r
.37834 .32271 m .37949 .31892 L .37802 .31883 L closepath p F P
0 g
s
.666 .46 .596 r
.42148 .31891 m .43488 .31777 L p .4343 .32351 L F P
0 g
s
.666 .46 .596 r
.4343 .32351 m .42195 .3246 L .42148 .31891 L p F P
0 g
s
.599 .61 .834 r
.62826 .28737 m .6281 .28706 L .62881 .28695 L closepath p F P
0 g
s
.877 .61 .531 r
.10543 .46648 m .10441 .46593 L .10471 .46073 L p F P
0 g
s
.88 .613 .53 r
.09973 .45801 m .10471 .46073 L .10441 .46593 L p F P
0 g
s
.876 .631 .566 r
.10471 .46073 m .09973 .45801 L .1005 .45267 L p F P
0 g
s
.481 .71 .971 r
.2608 .26881 m .26545 .26892 L .27131 .2715 L p F P
0 g
s
.422 .691 .975 r
.26545 .26892 m .2608 .26881 L .25737 .26591 L p F P
0 g
s
.87 .572 .482 r
.11512 .4762 m .10987 .47359 L .10957 .46857 L p F P
0 g
s
.872 .573 .479 r
.10543 .46648 m .10957 .46857 L .10987 .47359 L p F P
0 g
s
.721 .503 .595 r
.37802 .31883 m .36861 .3181 L p .37779 .32452 L F P
0 g
s
.721 .503 .595 r
.37779 .32452 m .37834 .32271 L .37802 .31883 L p F P
0 g
s
.538 .504 .765 r
.7007 .34376 m .70367 .35184 L .69192 .35083 L p F P
0 g
s
.538 .504 .765 r
.70025 .34372 m .7007 .34376 L p .69192 .35083 L F P
0 g
s
.538 .504 .765 r
.69192 .35083 m .69172 .35028 L .70025 .34372 L p F P
0 g
s
.839 .731 .745 r
.09694 .36305 m .10132 .36609 L .09651 .37269 L p F P
0 g
s
.835 .733 .753 r
.09989 .35919 m .09694 .36305 L .10132 .36609 L p F P
0 g
s
.612 .638 .852 r
.61588 .27738 m .61086 .27836 L .60796 .27329 L p F P
0 g
s
.104 .572 .912 r
.27131 .2715 m .27479 .27187 L .27131 .27018 L p F P
0 g
s
.104 .572 .912 r
.27131 .27018 m .26545 .26892 L .27131 .2715 L p F P
0 g
s
.818 .741 .78 r
.11385 .34242 m .1095 .33934 L .11604 .33216 L p F P
0 g
s
.822 .74 .774 r
.11385 .34242 m .11144 .34516 L .10788 .34118 L p F P
0 g
s
.822 .74 .774 r
.10788 .34118 m .1095 .33934 L .11385 .34242 L p F P
0 g
s
.599 .615 .839 r
.62881 .28695 m .6281 .28706 L .6252 .2816 L p F P
0 g
s
.545 .515 .774 r
.69172 .35028 m .68897 .34305 L .70025 .34372 L closepath p F P
0 g
s
.78 .344 .215 r
.2921 .27941 m .29301 .27932 L p .30088 .28497 L F P
0 g
s
.648 .109 0 r
.2921 .27941 m .29121 .27876 L .29301 .27932 L closepath p F P
0 g
s
.683 .656 .817 r
.45472 .51502 m .45314 .51229 L .44537 .51576 L closepath p F P
0 g
s
.682 .653 .815 r
.45007 .50668 m .45314 .51229 L .44537 .51576 L p F P
0 g
s
.682 .653 .815 r
.43894 .5119 m .45007 .50668 L p .44537 .51576 L F P
0 g
s
.722 .195 0 r
.14225 .49999 m .14519 .50312 L .14321 .50263 L p F P
0 g
s
.722 .195 0 r
.13669 .49753 m .14225 .49999 L p .14321 .50263 L F P
0 g
s
.848 .722 .724 r
.09234 .38857 m .09518 .38411 L .09165 .37964 L p F P
0 g
s
.879 .635 .565 r
.09559 .44992 m .1005 .45267 L .09973 .45801 L p F P
0 g
s
.874 .649 .594 r
.1005 .45267 m .09559 .44992 L .09679 .44445 L p F P
0 g
s
.45 .882 .883 r
.62817 .51487 m .6269 .51497 L .61553 .51895 L p F P
0 g
s
.536 .904 .962 r
.6269 .51497 m .61553 .51895 L .61274 .51823 L p F P
0 g
s
.548 .9 .975 r
.60137 .52187 m .61274 .51823 L .61553 .51895 L p F P
0 g
s
.708 .681 .822 r
.35418 .5157 m .35369 .51496 L .35254 .51558 L closepath p F P
0 g
s
.504 .427 .702 r
.71641 .39165 m .70808 .39747 L .7162 .40027 L p F P
0 g
s
.514 .443 .714 r
.7158 .38952 m .71641 .39165 L .70808 .39747 L p F P
0 g
s
.514 .443 .714 r
.70941 .38773 m .7158 .38952 L p .70808 .39747 L F P
0 g
s
.505 .426 .7 r
.70912 .40514 m .7162 .40027 L .70808 .39747 L p F P
0 g
s
.627 .412 .572 r
.44787 .31616 m .44764 .31077 L .46014 .30863 L p F P
0 g
s
.66 .704 .879 r
.51607 .52454 m .5273 .52094 L .53029 .52495 L p F P
0 g
s
.659 .689 .866 r
.52648 .51973 m .5273 .52094 L .51607 .52454 L p F P
0 g
s
.659 .689 .866 r
.51607 .52454 m .51447 .52226 L .52648 .51973 L p F P
0 g
s
.631 .667 .866 r
.59366 .27096 m .59215 .27134 L .59338 .27051 L closepath p F P
0 g
s
.634 .678 .875 r
.59075 .26639 m .59338 .27051 L .59215 .27134 L p F P
0 g
s
.788 .437 .393 r
.30801 .28709 m .30927 .28982 L .30864 .2911 L p F P
0 g
s
.788 .437 .393 r
.30088 .28497 m .30801 .28709 L p .30864 .2911 L F P
0 g
s
.579 .576 .814 r
.65984 .30211 m .65127 .30284 L .6578 .29773 L closepath p F P
0 g
s
.584 .586 .82 r
.65693 .29591 m .6578 .29773 L .65127 .30284 L p F P
0 g
s
.584 .586 .82 r
.64539 .29711 m .65693 .29591 L p .65127 .30284 L F P
0 g
s
.76 .748 .842 r
.18605 .27819 m .17855 .28347 L .17506 .27968 L p F P
0 g
s
.866 .533 .419 r
.12134 .48361 m .11606 .48103 L .11512 .4762 L p F P
0 g
s
.869 .534 .415 r
.10987 .47359 m .11512 .4762 L .11606 .48103 L p F P
0 g
s
.706 .649 .791 r
.39321 .50676 m .38213 .51292 L .37899 .50752 L p F P
0 g
s
.714 .676 .811 r
.33947 .51624 m .34216 .51468 L .35254 .51558 L p F P
0 g
s
.705 .671 .814 r
.35051 .50985 m .34216 .51468 L .35254 .51558 L p F P
0 g
s
.705 .671 .814 r
.35254 .51558 m .35369 .51496 L .35051 .50985 L p F P
0 g
s
.726 .745 .867 r
.2078 .27037 m .20393 .27256 L .20047 .26881 L p F P
0 g
s
.746 .747 .853 r
.18953 .27577 m .20047 .26881 L .20393 .27256 L p F P
0 g
s
.595 .604 .831 r
.63959 .28543 m .62881 .28695 L .63709 .28052 L closepath p F P
0 g
s
.599 .615 .839 r
.63669 .27975 m .63709 .28052 L .62881 .28695 L p F P
0 g
s
.599 .615 .839 r
.6252 .2816 m .63669 .27975 L p .62881 .28695 L F P
0 g
s
.71 .655 .793 r
.37899 .50752 m .36792 .51383 L .36476 .50856 L p F P
0 g
s
.701 .645 .79 r
.40743 .50629 m .39634 .51226 L .39321 .50676 L p F P
0 g
s
.826 .74 .77 r
.10781 .34943 m .11144 .34516 L .10788 .34118 L p F P
0 g
s
.498 .411 .688 r
.70912 .40514 m .7162 .40027 L p .71287 .41062 L F P
0 g
s
.498 .411 .688 r
.71287 .41062 m .71018 .40949 L .70912 .40514 L p F P
0 g
s
.714 .721 .855 r
.28248 .52199 m .28318 .52163 L .29088 .52336 L p F P
0 g
s
.7 .707 .853 r
.29345 .51638 m .28318 .52163 L .29088 .52336 L p F P
0 g
s
.7 .707 .853 r
.29088 .52336 m .29673 .5206 L .29345 .51638 L p F P
0 g
s
.877 .652 .595 r
.09196 .44166 m .09679 .44445 L .09559 .44992 L p F P
0 g
s
.872 .664 .619 r
.09679 .44445 m .09196 .44166 L .09356 .43607 L p F P
0 g
s
.862 .697 .676 r
.09118 .41291 m .0898 .41584 L .08637 .4103 L p F P
0 g
s
.862 .697 .676 r
.08637 .4103 m .0865 .41002 L .09118 .41291 L p F P
0 g
s
.856 .703 .692 r
.09118 .41291 m .0865 .41002 L .08968 .40394 L p F P
0 g
s
.673 .661 .83 r
.47041 .51809 m .48157 .51368 L .48462 .51874 L p F P
0 g
s
.673 .656 .825 r
.48059 .51194 m .48157 .51368 L .47041 .51809 L p F P
0 g
s
.673 .656 .825 r
.47041 .51809 m .46775 .51359 L .48059 .51194 L p F P
0 g
s
.714 .661 .797 r
.36476 .50856 m .35369 .51496 L .35051 .50985 L p F P
0 g
s
.463 .328 .611 r
.70607 .44314 m .70992 .44076 L .70634 .43652 L p F P
0 g
s
.461 .328 .613 r
.71466 .43129 m .70634 .43652 L .70992 .44076 L p F P
0 g
s
.478 .356 .635 r
.71359 .42511 m .71466 .43129 L .70634 .43652 L p F P
0 g
s
.694 .649 .801 r
.41054 .51187 m .42164 .50612 L .42474 .51175 L p F P
0 g
s
.696 .641 .79 r
.42164 .50612 m .41054 .51187 L .40743 .50629 L p F P
0 g
s
.75 .513 .573 r
.3586 .31698 m .34921 .31566 L .3501 .31035 L p F P
0 g
s
.761 .524 .574 r
.34519 .3095 m .3501 .31035 L .34921 .31566 L p F P
0 g
s
.729 .24 .079 r
.29121 .27876 m .2921 .27941 L .28887 .28038 L p F P
0 g
s
.569 .561 .805 r
.67345 .31456 m .66565 .31493 L .66292 .30878 L p F P
0 g
s
.151 0 0 r
.5084 .28015 m .50941 .27874 L .52003 .27434 L p F P
0 g
s
.721 .503 .595 r
.36861 .3181 m .36703 .32365 L .37779 .32452 L p F P
0 g
s
.739 .52 .596 r
.36219 .31739 m .36861 .3181 L .36703 .32365 L p F P
0 g
s
.628 .665 .867 r
.60244 .26402 m .60505 .26833 L .59366 .27096 L p F P
0 g
s
.628 .665 .867 r
.59366 .27096 m .59338 .27051 L .60244 .26402 L p F P
0 g
s
.623 .648 .854 r
.59366 .27096 m .60505 .26833 L .60796 .27329 L p F P
0 g
s
.857 .481 .335 r
.12825 .4908 m .12296 .48824 L .12134 .48361 L p F P
0 g
s
.858 .478 .326 r
.11606 .48103 m .12134 .48361 L .12296 .48824 L p F P
0 g
s
.717 .684 .817 r
.33947 .51624 m .34216 .51468 L .33814 .51422 L closepath p F P
0 g
s
.714 .681 .817 r
.33814 .51422 m .33947 .51624 L p .32523 .51764 L F P
0 g
s
.6 .37 .539 r
.46617 .30225 m .47231 .30097 L .47229 .30605 L p F P
0 g
s
.6 .37 .539 r
.47229 .30605 m .46599 .30736 L .46617 .30225 L p F P
0 g
s
.658 .699 .877 r
.54154 .52149 m .53029 .52495 L .5273 .52094 L p F P
0 g
s
.657 .72 .896 r
.53029 .52495 m .54154 .52149 L .54451 .52518 L p F P
0 g
s
.584 .587 .822 r
.65404 .28992 m .65693 .29591 L .64539 .29711 L p F P
0 g
s
.584 .587 .822 r
.64629 .29072 m .65404 .28992 L p .64539 .29711 L F P
0 g
s
.584 .587 .822 r
.64539 .29711 m .64341 .29302 L .64629 .29072 L p F P
0 g
s
.417 .227 .514 r
.70021 .45829 m .69747 .45987 L .69761 .46501 L p F P
0 g
s
.676 .653 .819 r
.46511 .51385 m .45472 .51502 L .45314 .51229 L p F P
0 g
s
.691 .639 .793 r
.43585 .50626 m .42474 .51175 L .42164 .50612 L p F P
0 g
s
.768 .509 .543 r
.34123 .30885 m .33278 .3072 L .333 .30213 L p F P
0 g
s
.783 .523 .543 r
.32738 .30078 m .333 .30213 L .33278 .3072 L p F P
0 g
s
.829 .738 .765 r
.1035 .34634 m .10781 .34943 L .10216 .35631 L p F P
0 g
s
.826 .74 .77 r
.10788 .34118 m .1035 .34634 L .10781 .34943 L p F P
0 g
s
.545 .516 .774 r
.70025 .34372 m .68897 .34305 L .68831 .34133 L p F P
0 g
s
.631 .671 .87 r
.60214 .26352 m .60244 .26402 L .59338 .27051 L p F P
0 g
s
.631 .671 .87 r
.59338 .27051 m .59075 .26639 L .60214 .26352 L p F P
0 g
s
.875 .668 .619 r
.0888 .43325 m .09356 .43607 L .09196 .44166 L p F P
0 g
s
.87 .677 .639 r
.09356 .43607 m .0888 .43325 L .09078 .42754 L p F P
0 g
s
.804 .746 .798 r
.13111 .31779 m .13059 .31723 L .13048 .31734 L closepath p F P
0 g
s
.498 .41 .687 r
.7108 .41202 m .71018 .40949 L .71287 .41062 L closepath p F P
0 g
s
.649 .445 .593 r
.43518 .32159 m .43731 .31746 L .43488 .31777 L closepath p F P
0 g
s
.666 .46 .596 r
.43488 .31777 m .43518 .32159 L .4343 .32351 L p F P
0 g
s
.591 .756 .957 r
.21152 .52386 m .22217 .52175 L .22563 .5246 L p F P
0 g
s
.617 .753 .943 r
.22217 .52175 m .21152 .52386 L .20801 .52133 L p F P
0 g
s
.439 .877 .86 r
.6269 .51497 m .62817 .51487 L .63877 .51065 L p F P
0 g
s
.345 .814 .739 r
.64098 .5098 m .63877 .51065 L .62817 .51487 L p F P
0 g
s
.714 .681 .817 r
.32523 .51764 m .33225 .51363 L .33814 .51422 L p F P
0 g
s
.722 .683 .812 r
.33225 .51363 m .32523 .51764 L .322 .51298 L p F P
0 g
s
.715 .692 .827 r
.31098 .51912 m .322 .51298 L .32523 .51764 L p F P
0 g
s
.726 .745 .867 r
.20047 .26881 m .20305 .26737 L .2078 .27037 L p F P
0 g
s
.729 .75 .869 r
.21136 .26279 m .20305 .26737 L .2078 .27037 L p F P
0 g
s
.729 .75 .869 r
.2078 .27037 m .21481 .26645 L .21136 .26279 L p F P
0 g
s
0 0 0 r
.65245 .50463 m .65236 .50471 L .64098 .5098 L p F P
0 g
s
.331 .797 .692 r
.63877 .51065 m .64098 .5098 L .65236 .50471 L p F P
0 g
s
.549 .526 .782 r
.68831 .34133 m .68603 .33556 L .69524 .33589 L closepath p F P
0 g
s
.545 .516 .774 r
.68831 .34133 m .69524 .33589 L p .70025 .34372 L F P
0 g
s
.76 .749 .843 r
.18605 .27202 m .18164 .27507 L .18605 .27819 L p F P
0 g
s
.76 .749 .843 r
.18605 .27819 m .18953 .27577 L .18605 .27202 L p F P
0 g
s
.76 .748 .842 r
.17506 .27968 m .18164 .27507 L .18605 .27819 L p F P
0 g
s
.853 .719 .715 r
.08788 .38558 m .09234 .38857 L .08859 .39483 L p F P
0 g
s
.848 .722 .724 r
.09165 .37964 m .08788 .38558 L .09234 .38857 L p F P
0 g
s
.623 .87 .989 r
.60048 .52139 m .60137 .52187 L .61274 .51823 L p F P
0 g
s
.669 .665 .838 r
.48462 .51874 m .4958 .51458 L .49883 .51947 L p F P
0 g
s
.67 .655 .827 r
.4958 .51458 m .48462 .51874 L .48157 .51368 L p F P
0 g
s
.717 .683 .816 r
.34733 .50457 m .35051 .50985 L .34216 .51468 L p F P
0 g
s
.717 .683 .816 r
.33626 .51134 m .34733 .50457 L p .34216 .51468 L F P
0 g
s
.717 .683 .816 r
.34216 .51468 m .33814 .51422 L .33626 .51134 L p F P
0 g
s
.839 .731 .745 r
.09651 .37269 m .0921 .36966 L .09694 .36305 L p F P
0 g
s
.84 .73 .743 r
.0921 .36966 m .09651 .37269 L .09193 .37922 L p F P
0 g
s
.653 .743 .916 r
.54451 .52518 m .55579 .52182 L .55874 .52512 L p F P
0 g
s
.655 .717 .894 r
.55579 .52182 m .54451 .52518 L .54154 .52149 L p F P
0 g
s
.654 .45 .595 r
.43731 .31746 m .44787 .31616 L p .43533 .32342 L F P
0 g
s
.654 .45 .595 r
.43533 .32342 m .43518 .32159 L .43731 .31746 L p F P
0 g
s
.792 .749 .813 r
.14773 .30155 m .14179 .30678 L .13825 .30297 L p F P
0 g
s
.798 .749 .807 r
.13876 .30956 m .14179 .30678 L .13825 .30297 L p F P
0 g
s
.801 .748 .804 r
.13876 .30956 m .13059 .31723 L .12703 .31342 L p F P
0 g
s
.801 .748 .804 r
.12703 .31342 m .13452 .30641 L .13876 .30956 L p F P
0 g
s
.798 .749 .807 r
.13825 .30297 m .13452 .30641 L .13876 .30956 L p F P
0 g
s
.355 .105 .39 r
.69748 .46985 m .68764 .47516 L .68716 .47963 L p F P
0 g
s
.398 .18 .462 r
.69761 .46501 m .69748 .46985 L .68764 .47516 L p F P
0 g
s
.686 .638 .796 r
.45007 .50668 m .43894 .5119 L .43585 .50626 L p F P
0 g
s
.739 .52 .596 r
.36703 .32365 m .36269 .32318 L .36219 .31739 L p F P
0 g
s
.742 .522 .596 r
.3586 .31698 m .36219 .31739 L .36269 .32318 L p F P
0 g
s
.761 .524 .574 r
.34921 .31566 m .34541 .31501 L .34519 .3095 L p F P
0 g
s
.758 .521 .574 r
.34123 .30885 m .34519 .3095 L .34541 .31501 L p F P
0 g
s
.487 .391 .671 r
.71287 .41062 m .7108 .41202 L .71228 .41867 L p F P
0 g
s
.698 .495 .61 r
.40225 .32526 m .40806 .32521 L .40871 .33112 L p F P
0 g
s
.698 .495 .61 r
.40871 .33112 m .39957 .3312 L .40225 .32526 L p F P
0 g
s
.703 .501 .612 r
.3936 .32523 m .40225 .32526 L .39957 .3312 L p F P
0 g
s
.718 .502 .597 r
.38937 .3251 m .3785 .32456 L .37834 .32271 L p F P
0 g
s
.724 .507 .596 r
.3785 .32456 m .37834 .32271 L .37779 .32452 L closepath p F P
0 g
s
.72 .684 .815 r
.322 .51298 m .31098 .51912 L .30773 .51467 L p F P
0 g
s
.703 .501 .612 r
.39957 .3312 m .39428 .33118 L .3936 .32523 L p F P
0 g
s
.712 .507 .61 r
.38937 .3251 m .3936 .32523 L .39428 .33118 L p F P
0 g
s
.806 .748 .8 r
.13048 .31734 m .13059 .31723 L .12703 .31342 L p F P
0 g
s
.806 .748 .8 r
.12703 .31342 m .12625 .31418 L .13048 .31734 L p F P
0 g
s
.809 .747 .794 r
.12625 .31418 m .13048 .31734 L .12305 .32482 L p F P
0 g
s
.686 .486 .611 r
.40806 .32521 m .41689 .32484 L .41382 .33091 L p F P
0 g
s
.686 .486 .611 r
.41382 .33091 m .40871 .33112 L .40806 .32521 L p F P
0 g
s
.864 .698 .674 r
.08843 .41885 m .0898 .41584 L .08637 .4103 L p F P
0 g
s
.792 .749 .813 r
.13825 .30297 m .14346 .2984 L .14773 .30155 L p F P
0 g
s
.79 .749 .816 r
.14941 .29326 m .14346 .2984 L .14773 .30155 L p F P
0 g
s
.79 .749 .816 r
.14773 .30155 m .15294 .29705 L .14941 .29326 L p F P
0 g
s
.78 .344 .215 r
.30088 .28497 m .29435 .28263 L .2921 .27941 L p F P
0 g
s
.791 .341 .177 r
.29435 .28263 m .28887 .28038 L .2921 .27941 L closepath p F P
0 g
s
.837 .437 .288 r
.12825 .49081 m .12825 .4908 L .12825 .4908 L closepath p F P
0 g
s
.803 .346 .154 r
.13669 .49753 m .13115 .49505 L .12825 .49081 L p F P
0 g
s
.79 .317 .108 r
.12825 .4908 m .12825 .49081 L .13115 .49505 L p F P
0 g
s
.79 .317 .108 r
.12437 .49086 m .12825 .4908 L p .13115 .49505 L F P
0 g
s
.834 .407 .222 r
.12437 .49086 m .12296 .48824 L .12825 .4908 L closepath p F P
0 g
s
.782 .491 .494 r
.32511 .30029 m .31732 .2984 L .31676 .29361 L p F P
0 g
s
.802 .51 .495 r
.30974 .29146 m .31676 .29361 L .31732 .2984 L p F P
0 g
s
.8 .465 .423 r
.31676 .29361 m .30974 .29146 L .30927 .28982 L p F P
0 g
s
.454 .158 .372 r
.49583 .28983 m .49667 .28572 L .50769 .28181 L p F P
0 g
s
.362 0 .201 r
.5084 .28015 m .50769 .28181 L .49667 .28572 L p F P
0 g
s
.483 .182 .379 r
.49667 .28572 m .49583 .28983 L .48445 .29331 L p F P
0 g
s
.712 .507 .61 r
.39428 .33118 m .38693 .33096 L .38937 .3251 L p F P
0 g
s
.719 .516 .614 r
.3785 .32456 m .38937 .3251 L .38693 .33096 L p F P
0 g
s
.662 .689 .865 r
.5243 .51651 m .52648 .51973 L .51447 .52226 L p F P
0 g
s
.662 .689 .865 r
.51447 .52226 m .51306 .52024 L .5243 .51651 L p F P
0 g
s
.857 .708 .696 r
.0851 .40101 m .08968 .40394 L .0865 .41002 L p F P
0 g
s
.854 .711 .704 r
.08968 .40394 m .0851 .40101 L .08859 .39483 L p F P
0 g
s
.783 .749 .822 r
.15757 .29323 m .15294 .29705 L .14941 .29326 L p F P
0 g
s
.746 .749 .855 r
.20047 .26881 m .18953 .27577 L .18605 .27202 L p F P
0 g
s
.873 .681 .64 r
.08609 .42467 m .09078 .42754 L .0888 .43325 L p F P
0 g
s
.868 .688 .657 r
.09078 .42754 m .08609 .42467 L .08843 .41885 L p F P
0 g
s
.349 .702 .984 r
.19231 .51892 m .18913 .51764 L .17996 .51721 L p F P
0 g
s
.304 .704 .977 r
.18913 .51764 m .17996 .51721 L .17636 .51531 L p F P
0 g
s
.648 .772 .939 r
.55874 .52512 m .57005 .52181 L .57296 .52466 L p F P
0 g
s
.652 .741 .915 r
.57005 .52181 m .55874 .52512 L .55579 .52182 L p F P
0 g
s
.625 .852 .985 r
.60048 .52139 m .59853 .52023 L .58718 .52365 L p F P
0 g
s
.639 .815 .967 r
.59853 .52023 m .58718 .52365 L .58429 .52133 L p F P
0 g
s
.639 .81 .965 r
.57296 .52466 m .58429 .52133 L .58718 .52365 L p F P
0 g
s
.714 .682 .818 r
.33814 .51422 m .33626 .51134 L .33225 .51363 L closepath p F P
0 g
s
.742 .522 .596 r
.36269 .32318 m .35704 .32253 L .3586 .31698 L p F P
0 g
s
.753 .53 .593 r
.34921 .31566 m .3586 .31698 L .35704 .32253 L p F P
0 g
s
.719 .696 .828 r
.30773 .51467 m .29673 .5206 L .29345 .51638 L p F P
0 g
s
.531 .279 .478 r
.48408 .29797 m .48445 .29331 L .49583 .28983 L p F P
0 g
s
.556 .299 .481 r
.48445 .29331 m .48408 .29797 L .47231 .30097 L p F P
0 g
s
.658 .718 .893 r
.56224 .26508 m .57355 .2614 L .57648 .26528 L p F P
0 g
s
.67 .746 .908 r
.57355 .2614 m .56224 .26508 L .55931 .26192 L p F P
0 g
s
.675 .769 .921 r
.54802 .26606 m .55931 .26192 L .56224 .26508 L p F P
0 g
s
.643 .751 .927 r
.22563 .5246 m .23638 .52147 L .2398 .52461 L p F P
0 g
s
.66 .747 .914 r
.23638 .52147 m .22563 .5246 L .22217 .52175 L p F P
0 g
s
.684 .484 .61 r
.41689 .32484 m .42195 .3246 L .4226 .33049 L p F P
0 g
s
.684 .484 .61 r
.4226 .33049 m .41382 .33091 L .41689 .32484 L p F P
0 g
s
.401 0 0 r
.15958 .50997 m .15843 .50947 L .15217 .50625 L p F P
0 g
s
.338 0 0 r
.1463 .50389 m .15217 .50625 L .15843 .50947 L p F P
0 g
s
.653 .101 0 r
.14519 .50312 m .1463 .50389 L .15217 .50625 L p F P
0 g
s
.447 .298 .585 r
.70992 .44076 m .70607 .44314 L .70671 .44883 L p F P
0 g
s
.812 .746 .791 r
.12305 .32482 m .11929 .32869 L .11572 .32484 L p F P
0 g
s
.812 .746 .791 r
.11572 .32484 m .11879 .32168 L .12305 .32482 L p F P
0 g
s
.809 .747 .794 r
.12305 .32482 m .11879 .32168 L .12625 .31418 L p F P
0 g
s
.648 .773 .94 r
.58429 .52133 m .57296 .52466 L .57005 .52181 L p F P
0 g
s
.783 .749 .822 r
.14941 .29326 m .15328 .29008 L .15757 .29323 L p F P
0 g
s
.781 .75 .825 r
.16051 .28424 m .15328 .29008 L .15757 .29323 L p F P
0 g
s
.781 .75 .825 r
.15757 .29323 m .16402 .28802 L .16051 .28424 L p F P
0 g
s
.833 .736 .758 r
.10216 .35631 m .09989 .35919 L .09632 .35514 L p F P
0 g
s
.833 .736 .758 r
.09632 .35514 m .09781 .35324 L .10216 .35631 L p F P
0 g
s
.829 .738 .765 r
.10216 .35631 m .09781 .35324 L .1035 .34634 L p F P
0 g
s
.69 .819 .944 r
.55931 .26192 m .54802 .26606 L .54508 .26401 L p F P
0 g
s
.652 .877 .982 r
.54802 .26606 m .54508 .26401 L p .53397 .26872 L F P
0 g
s
.612 .638 .852 r
.61939 .27097 m .62089 .27362 L .61588 .27738 L p F P
0 g
s
.612 .638 .852 r
.60796 .27329 m .61939 .27097 L p .61588 .27738 L F P
0 g
s
.608 .627 .844 r
.6223 .27619 m .61588 .27738 L .62089 .27362 L closepath p F P
0 g
s
.119 .599 .914 r
.17062 .51403 m .17636 .51531 L .17275 .51321 L p F P
0 g
s
.119 .599 .914 r
.17275 .51321 m .1645 .51176 L .17062 .51403 L p F P
0 g
s
.247 0 0 r
.1625 .51118 m .1645 .51176 L .17062 .51403 L p F P
0 g
s
.549 .527 .783 r
.69524 .33589 m .68603 .33556 L .68463 .33204 L p F P
0 g
s
.676 .653 .819 r
.45314 .51229 m .46429 .50736 L p .46511 .51385 L F P
0 g
s
.68 .638 .801 r
.46429 .50736 m .45314 .51229 L .45007 .50668 L p F P
0 g
s
.579 .352 .537 r
.47229 .30605 m .47231 .30097 L .48408 .29797 L p F P
0 g
s
.665 .672 .848 r
.49883 .51947 m .51004 .51554 L .51306 .52024 L p F P
0 g
s
.665 .659 .834 r
.51004 .51554 m .49883 .51947 L .4958 .51458 L p F P
0 g
s
.77 .531 .572 r
.33278 .3072 m .34123 .30885 L .34031 .31417 L p F P
0 g
s
.758 .521 .574 r
.34541 .31501 m .34031 .31417 L .34123 .30885 L p F P
0 g
s
.511 .442 .716 r
.7158 .38952 m .70941 .38773 L .7143 .38425 L closepath p F P
0 g
s
.519 .456 .725 r
.71271 .379 m .7143 .38425 L .70941 .38773 L p F P
0 g
s
.519 .456 .725 r
.70969 .37829 m .71271 .379 L p .70941 .38773 L F P
0 g
s
.532 .764 .983 r
.20236 .52184 m .20801 .52133 L .2045 .51863 L p F P
0 g
s
.532 .764 .983 r
.2045 .51863 m .19554 .5198 L .20236 .52184 L p F P
0 g
s
.438 .753 .994 r
.19393 .51997 m .19554 .5198 L .20236 .52184 L p F P
0 g
s
.669 .473 .612 r
.42195 .3246 m .4343 .32351 L .4306 .32979 L p F P
0 g
s
.669 .473 .612 r
.4306 .32979 m .4226 .33049 L .42195 .3246 L p F P
0 g
s
.391 0 0 r
.27849 .27396 m .27479 .27187 L .27131 .27018 L p F P
0 g
s
0 .37 .753 r
.27479 .27187 m .27849 .27396 L .28457 .27646 L p F P
0 g
s
.588 .596 .828 r
.64341 .29302 m .64249 .29117 L .64629 .29072 L closepath p F P
0 g
s
.719 .516 .614 r
.38693 .33096 m .37923 .33058 L .3785 .32456 L p F P
0 g
s
.726 .52 .613 r
.37779 .32452 m .3785 .32456 L .37923 .33058 L p F P
0 g
s
.816 .746 .786 r
.11604 .33216 m .11929 .32869 L .11572 .32484 L p F P
0 g
s
.569 .561 .805 r
.66292 .30878 m .66346 .30834 L p .67345 .31456 L F P
0 g
s
.573 .57 .811 r
.66292 .30878 m .66274 .30839 L .66346 .30834 L closepath p F P
0 g
s
.715 .723 .857 r
.28248 .52199 m .28318 .52163 L .28193 .52133 L closepath p F P
0 g
s
.703 .719 .862 r
.28193 .52133 m .28248 .52199 L p .26824 .52318 L F P
0 g
s
.678 .658 .823 r
.46775 .51359 m .46735 .51291 L .46511 .51385 L closepath p F P
0 g
s
.676 .653 .819 r
.46429 .50736 m .46735 .51291 L .46511 .51385 L p F P
0 g
s
.726 .52 .613 r
.37923 .33058 m .37547 .33033 L .37779 .32452 L p F P
0 g
s
.733 .524 .608 r
.36703 .32365 m .37779 .32452 L .37547 .33033 L p F P
0 g
s
.872 .573 .479 r
.10449 .46805 m .10543 .46648 L p .10987 .47359 L F P
0 g
s
.879 .586 .488 r
.10449 .46805 m .10441 .46593 L .10543 .46648 L closepath p F P
0 g
s
.657 .753 .921 r
.22908 .26498 m .23984 .26134 L .24327 .26465 L p F P
0 g
s
.646 .753 .927 r
.23984 .26134 m .22908 .26498 L .22564 .26144 L p F P
0 g
s
.702 .75 .889 r
.21481 .26645 m .22564 .26144 L .22908 .26498 L p F P
0 g
s
.573 .572 .814 r
.66346 .30834 m .66274 .30839 L .65984 .30211 L p F P
0 g
s
.783 .523 .543 r
.33278 .3072 m .32718 .30586 L .32738 .30078 L p F P
0 g
s
.775 .516 .543 r
.32511 .30029 m .32738 .30078 L .32718 .30586 L p F P
0 g
s
.601 .618 .84 r
.63669 .27975 m .6252 .2816 L .6223 .27619 L p F P
0 g
s
.673 .742 .902 r
.2398 .52461 m .25062 .52067 L .25401 .52409 L p F P
0 g
s
.685 .737 .89 r
.25062 .52067 m .2398 .52461 L .23638 .52147 L p F P
0 g
s
.788 .437 .393 r
.30864 .2911 m .30255 .28936 L .30088 .28497 L p F P
0 g
s
.808 .46 .397 r
.29435 .28263 m .30088 .28497 L .30255 .28936 L p F P
0 g
s
.607 .396 .569 r
.46014 .30863 m .46599 .30736 L .46276 .31349 L p F P
0 g
s
.607 .396 .569 r
.46276 .31349 m .46037 .314 L .46014 .30863 L p F P
0 g
s
.627 .412 .572 r
.46014 .30863 m .46037 .314 L .44787 .31616 L p F P
0 g
s
.715 .723 .856 r
.29016 .51201 m .29345 .51638 L .28318 .52163 L p F P
0 g
s
.715 .723 .856 r
.27916 .51802 m .29016 .51201 L p .28318 .52163 L F P
0 g
s
.715 .723 .856 r
.28318 .52163 m .28193 .52133 L .27916 .51802 L p F P
0 g
s
.772 .75 .833 r
.16866 .28448 m .16402 .28802 L .16051 .28424 L p F P
0 g
s
.703 .719 .862 r
.26824 .52318 m .27462 .52016 L .28193 .52133 L p F P
0 g
s
.714 .724 .858 r
.27462 .52016 m .26824 .52318 L .26489 .51949 L p F P
0 g
s
.691 .731 .881 r
.25401 .52409 m .26489 .51949 L .26824 .52318 L p F P
0 g
s
.643 .686 .876 r
.57648 .26528 m .58783 .26204 L .59075 .26639 L p F P
0 g
s
.651 .703 .885 r
.58783 .26204 m .57648 .26528 L .57355 .2614 L p F P
0 g
s
.837 .736 .754 r
.09694 .36305 m .09989 .35919 L .09632 .35514 L p F P
0 g
s
.708 .655 .795 r
.37899 .50752 m .38314 .50507 L .37751 .50487 L closepath p F P
0 g
s
.71 .655 .793 r
.37751 .50487 m .37899 .50752 L p .36476 .50856 L F P
0 g
s
.706 .649 .791 r
.3924 .50527 m .39321 .50676 L p .37899 .50752 L F P
0 g
s
.706 .649 .791 r
.37899 .50752 m .38314 .50507 L .3924 .50527 L p F P
0 g
s
.7 .725 .869 r
.26489 .51949 m .25401 .52409 L .25062 .52067 L p F P
0 g
s
.722 .683 .812 r
.322 .51298 m .323 .51237 L .33225 .51363 L p F P
0 g
s
.711 .674 .812 r
.33306 .50625 m .323 .51237 L .33225 .51363 L p F P
0 g
s
.711 .674 .812 r
.33225 .51363 m .33626 .51134 L .33306 .50625 L p F P
0 g
s
.819 .744 .781 r
.1118 .32902 m .11604 .33216 L .1095 .33934 L p F P
0 g
s
.816 .746 .786 r
.11572 .32484 m .1118 .32902 L .11604 .33216 L p F P
0 g
s
.701 .645 .79 r
.40689 .50528 m .40743 .50629 L p .39321 .50676 L F P
0 g
s
.701 .645 .79 r
.39321 .50676 m .39577 .5053 L .40689 .50528 L p F P
0 g
s
.703 .648 .793 r
.39321 .50676 m .39577 .5053 L .3924 .50527 L closepath p F P
0 g
s
.808 .47 .416 r
.30974 .29146 m .30864 .2911 L .30927 .28982 L closepath p F P
0 g
s
.616 .642 .853 r
.61939 .27097 m .60796 .27329 L .60505 .26833 L p F P
0 g
s
.677 .657 .823 r
.47852 .50826 m .48059 .51194 L .46775 .51359 L p F P
0 g
s
.677 .657 .823 r
.46775 .51359 m .46735 .51291 L .47852 .50826 L p F P
0 g
s
.546 .75 .971 r
.24327 .26465 m .25393 .26309 L .25737 .26591 L p F P
0 g
s
.513 .735 .974 r
.24327 .26465 m .25393 .26309 L .25114 .26086 L p F P
0 g
s
.513 .735 .974 r
.23984 .26134 m .24327 .26465 L p .25114 .26086 L F P
0 g
s
.87 .692 .658 r
.08383 .41595 m .08843 .41885 L .08609 .42467 L p F P
0 g
s
.864 .698 .674 r
.08637 .4103 m .08383 .41595 L .08843 .41885 L p F P
0 g
s
.417 .227 .514 r
.69761 .46501 m .6998 .46376 L .70021 .45829 L p F P
0 g
s
.412 .223 .512 r
.70712 .45426 m .70021 .45829 L .6998 .46376 L p F P
0 g
s
.438 .269 .554 r
.70021 .45829 m .70712 .45426 L .70671 .44883 L p F P
0 g
s
.549 .527 .783 r
.68463 .33204 m .68916 .3284 L p .69524 .33589 L F P
0 g
s
.554 .537 .79 r
.68463 .33204 m .6831 .32831 L .68916 .3284 L closepath p F P
0 g
s
0 .43 .777 r
.26545 .26892 m .27131 .27018 L .26841 .26899 L p F P
0 g
s
0 .43 .777 r
.26006 .26616 m .26545 .26892 L p .26841 .26899 L F P
0 g
s
.422 .691 .975 r
.25737 .26591 m .26006 .26616 L .26545 .26892 L p F P
0 g
s
.71 .655 .793 r
.36476 .50856 m .37132 .5046 L .37751 .50487 L p F P
0 g
s
.713 .662 .798 r
.36476 .50856 m .37132 .5046 L .36212 .50401 L closepath p F P
0 g
s
.714 .661 .797 r
.36212 .50401 m .36476 .50856 L p .35051 .50985 L F P
0 g
s
.628 .857 .986 r
.59853 .52023 m .60048 .52139 L .61136 .51753 L p F P
0 g
s
.623 .87 .989 r
.61274 .51823 m .61136 .51753 L .60048 .52139 L p F P
0 g
s
.666 .459 .595 r
.43533 .32342 m .43518 .32159 L .4343 .32351 L closepath p F P
0 g
s
.569 .561 .805 r
.66346 .30834 m .67436 .30785 L p .67345 .31456 L F P
0 g
s
.568 .562 .807 r
.67436 .30785 m .66346 .30834 L .6716 .30168 L closepath p F P
0 g
s
.573 .572 .814 r
.67145 .30135 m .6716 .30168 L .66346 .30834 L p F P
0 g
s
.573 .572 .814 r
.65984 .30211 m .67145 .30135 L p .66346 .30834 L F P
0 g
s
.696 .641 .79 r
.42101 .50493 m .42164 .50612 L p .40743 .50629 L F P
0 g
s
.696 .641 .79 r
.40743 .50629 m .40937 .50522 L .42101 .50493 L p F P
0 g
s
.697 .643 .792 r
.40743 .50629 m .40937 .50522 L .40689 .50528 L closepath p F P
0 g
s
.698 .751 .893 r
.22564 .26144 m .21481 .26645 L .21136 .26279 L p F P
0 g
s
.702 .719 .863 r
.28193 .52133 m .27916 .51802 L .27462 .52016 L closepath p F P
0 g
s
.631 .431 .593 r
.44787 .31616 m .46037 .314 L p .45798 .32013 L F P
0 g
s
.631 .431 .593 r
.45798 .32013 m .44832 .3218 L .44787 .31616 L p F P
0 g
s
.654 .45 .595 r
.44787 .31616 m .44832 .3218 L .43533 .32342 L p F P
0 g
s
.847 .725 .729 r
.09165 .37964 m .09193 .37922 L .09056 .37829 L closepath p F P
0 g
s
.84 .73 .743 r
.0881 .37536 m .0921 .36966 L p .09193 .37922 L F P
0 g
s
.84 .73 .743 r
.09193 .37922 m .09056 .37829 L .0881 .37536 L p F P
0 g
s
.478 .373 .656 r
.71228 .41867 m .71922 .41399 L p .7138 .42496 L F P
0 g
s
.478 .373 .656 r
.7138 .42496 m .71352 .42477 L .71228 .41867 L p F P
0 g
s
.487 .391 .671 r
.71228 .41867 m .71922 .41399 L .71287 .41062 L p F P
0 g
s
.655 .922 .976 r
.53382 .26867 m .53506 .26814 L .53397 .26872 L closepath p F P
0 g
s
.652 .877 .982 r
.54508 .26401 m .53506 .26814 L .53397 .26872 L p F P
0 g
s
.775 .516 .543 r
.32718 .30586 m .32487 .30536 L .32511 .30029 L p F P
0 g
s
.785 .523 .542 r
.31732 .2984 m .32511 .30029 L .32487 .30536 L p F P
0 g
s
.772 .75 .833 r
.16051 .28424 m .16434 .28133 L .16866 .28448 L p F P
0 g
s
.771 .751 .835 r
.17155 .27593 m .16434 .28133 L .16866 .28448 L p F P
0 g
s
.771 .751 .835 r
.16866 .28448 m .17506 .27968 L .17155 .27593 L p F P
0 g
s
.588 .599 .831 r
.64629 .29072 m .64249 .29117 L .63959 .28543 L p F P
0 g
s
.675 .638 .805 r
.47852 .50826 m .46735 .51291 L .46429 .50736 L p F P
0 g
s
.705 .169 0 r
.13115 .49505 m .13669 .49753 L .14063 .50146 L p F P
0 g
s
.722 .195 0 r
.14321 .50263 m .14063 .50146 L .13669 .49753 L p F P
0 g
s
.883 .588 .483 r
.10441 .46593 m .10449 .46805 L .10304 .47012 L p F P
0 g
s
.883 .588 .483 r
.09943 .46321 m .10441 .46593 L p .10304 .47012 L F P
0 g
s
.88 .613 .53 r
.10441 .46593 m .09943 .46321 L .09973 .45801 L p F P
0 g
s
.851 .725 .724 r
.08788 .38558 m .09165 .37964 L .09056 .37829 L p F P
0 g
s
.714 .661 .797 r
.35051 .50985 m .36029 .50389 L .36212 .50401 L p F P
0 g
s
.718 .658 .789 r
.36029 .50389 m .35051 .50985 L .34733 .50457 L p F P
0 g
s
.883 .616 .528 r
.09482 .45527 m .09973 .45801 L .09943 .46321 L p F P
0 g
s
.879 .635 .565 r
.09973 .45801 m .09482 .45527 L .09559 .44992 L p F P
0 g
s
.661 .667 .845 r
.5243 .51651 m .51306 .52024 L .51004 .51554 L p F P
0 g
s
.486 .391 .673 r
.72002 .40571 m .71287 .41062 L .71922 .41399 L p F P
0 g
s
.498 .411 .688 r
.71897 .40146 m .72002 .40571 L .71287 .41062 L p F P
0 g
s
.498 .411 .688 r
.7162 .40027 m .71897 .40146 L p .71287 .41062 L F P
0 g
s
.729 .24 .079 r
.28887 .28038 m .28821 .28016 L .28457 .27646 L p F P
0 g
s
.757 .286 .126 r
.27849 .27396 m .28457 .27646 L .28821 .28016 L p F P
0 g
s
.856 .715 .706 r
.0841 .39185 m .08859 .39483 L .0851 .40101 L p F P
0 g
s
.853 .719 .715 r
.08859 .39483 m .0841 .39185 L .08788 .38558 L p F P
0 g
s
.701 .644 .789 r
.40689 .50528 m .40431 .5004 L .39577 .5053 L closepath p F P
0 g
s
.703 .648 .792 r
.40122 .49432 m .40431 .5004 L .39577 .5053 L p F P
0 g
s
.703 .648 .792 r
.40113 .49432 m .40122 .49432 L p .39577 .5053 L F P
0 g
s
.703 .648 .792 r
.39008 .50097 m .40113 .49432 L p .39577 .5053 L F P
0 g
s
.703 .648 .792 r
.39577 .5053 m .3924 .50527 L .39008 .50097 L p F P
0 g
s
.697 .642 .791 r
.40937 .50522 m .40689 .50528 L .40431 .5004 L p F P
0 g
s
.691 .639 .793 r
.43481 .50426 m .43585 .50626 L p .42164 .50612 L F P
0 g
s
.691 .639 .793 r
.42164 .50612 m .42423 .50477 L .43481 .50426 L p F P
0 g
s
.691 .639 .792 r
.42164 .50612 m .42423 .50477 L .42101 .50493 L closepath p F P
0 g
s
.706 .649 .791 r
.3924 .50527 m .39008 .50097 L .38314 .50507 L closepath p F P
0 g
s
.696 .64 .79 r
.42101 .50493 m .41854 .50018 L .40937 .50522 L closepath p F P
0 g
s
.697 .642 .791 r
.4155 .4941 m .41854 .50018 L .40937 .50522 L p F P
0 g
s
.697 .642 .791 r
.41522 .49411 m .4155 .4941 L p .40937 .50522 L F P
0 g
s
.697 .642 .791 r
.40431 .5004 m .41522 .49411 L p .40937 .50522 L F P
0 g
s
.733 .524 .608 r
.37547 .33033 m .36496 .32938 L .36703 .32365 L p F P
0 g
s
.74 .531 .611 r
.36269 .32318 m .36703 .32365 L .36496 .32938 L p F P
0 g
s
.882 .638 .565 r
.09075 .44714 m .09559 .44992 L .09482 .45527 L p F P
0 g
s
.877 .652 .595 r
.09559 .44992 m .09075 .44714 L .09196 .44166 L p F P
0 g
s
.869 .534 .415 r
.11606 .48103 m .11082 .47842 L .10987 .47359 L p F P
0 g
s
.871 .534 .41 r
.10467 .47096 m .10987 .47359 L .11082 .47842 L p F P
0 g
s
.872 .573 .479 r
.10987 .47359 m .10467 .47096 L .10449 .46805 L p F P
0 g
s
0 .447 .772 r
.1645 .51176 m .15958 .50997 L .1625 .51118 L closepath p F P
0 g
s
.841 .734 .747 r
.09263 .35997 m .09694 .36305 L .0921 .36966 L p F P
0 g
s
.837 .736 .754 r
.09632 .35514 m .09263 .35997 L .09694 .36305 L p F P
0 g
s
.819 .744 .781 r
.1095 .33934 m .10523 .33622 L .1118 .32902 L p F P
0 g
s
.823 .743 .775 r
.1095 .33934 m .10788 .34118 L .1043 .33727 L p F P
0 g
s
.823 .743 .775 r
.1043 .33727 m .10523 .33622 L .1095 .33934 L p F P
0 g
s
.753 .53 .593 r
.35704 .32253 m .34779 .32116 L .34921 .31566 L p F P
0 g
s
.761 .538 .595 r
.34541 .31501 m .34921 .31566 L .34779 .32116 L p F P
0 g
s
.708 .654 .794 r
.38696 .49496 m .39008 .50097 L .38314 .50507 L p F P
0 g
s
.708 .654 .794 r
.37584 .50187 m .38696 .49496 L p .38314 .50507 L F P
0 g
s
.708 .654 .794 r
.38314 .50507 m .37751 .50487 L .37584 .50187 L p F P
0 g
s
.09 0 0 r
.66373 .49879 m .67372 .4929 L .66478 .49716 L closepath p F P
0 g
s
.195 0 .109 r
.67509 .492 m .67372 .4929 L .66478 .49716 L p F P
0 g
s
.195 0 .109 r
.6763 .48877 m .67509 .492 L p .66478 .49716 L F P
0 g
s
.049 0 0 r
.66373 .49879 m .66478 .49716 L p .65245 .50463 L F P
0 g
s
.72 .663 .793 r
.34733 .50457 m .33626 .51134 L .33306 .50625 L p F P
0 g
s
.669 .474 .612 r
.4343 .32351 m .43533 .32342 L .436 .32932 L p F P
0 g
s
.669 .474 .612 r
.436 .32932 m .4306 .32979 L .4343 .32351 L p F P
0 g
s
.151 0 0 r
.52003 .27434 m .51962 .27483 L .5084 .28015 L p F P
0 g
s
.318 0 .171 r
.50769 .28181 m .5084 .28015 L .51962 .27483 L p F P
0 g
s
.554 .537 .791 r
.68916 .3284 m .6831 .32831 L .68066 .32238 L p F P
0 g
s
.655 .464 .613 r
.436 .32932 m .43533 .32342 L .44832 .3218 L p F P
0 g
s
.691 .638 .792 r
.42423 .50477 m .42101 .50493 L .41854 .50018 L p F P
0 g
s
.649 .912 .98 r
.53506 .26814 m .54406 .26361 L .54508 .26401 L closepath p F P
0 g
s
.828 .743 .771 r
.1035 .34634 m .10788 .34118 L .1043 .33727 L p F P
0 g
s
.71 .655 .793 r
.37751 .50487 m .37584 .50187 L .37132 .5046 L closepath p F P
0 g
s
.699 .504 .62 r
.39957 .3312 m .40871 .33112 L .40952 .33721 L p F P
0 g
s
.699 .504 .62 r
.40952 .33721 m .39638 .33731 L .39957 .3312 L p F P
0 g
s
.704 .509 .623 r
.39428 .33118 m .39957 .3312 L .39638 .33731 L p F P
0 g
s
.76 .751 .844 r
.18164 .27507 m .17506 .27968 L .17155 .27593 L p F P
0 g
s
.704 .509 .623 r
.39638 .33731 m .39512 .33731 L .39428 .33118 L p F P
0 g
s
.713 .516 .621 r
.38693 .33096 m .39428 .33118 L .39512 .33731 L p F P
0 g
s
.685 .636 .794 r
.43585 .50626 m .44086 .50379 L .43481 .50426 L closepath p F P
0 g
s
.686 .638 .796 r
.44828 .50325 m .45007 .50668 L p .43585 .50626 L F P
0 g
s
.686 .638 .796 r
.43585 .50626 m .44086 .50379 L .44828 .50325 L p F P
0 g
s
.596 .023 0 r
.1463 .50389 m .14321 .50263 L .14519 .50312 L closepath p F P
0 g
s
.439 .877 .86 r
.63877 .51065 m .6383 .51072 L .6269 .51497 L p F P
0 g
s
.516 .905 .939 r
.6383 .51072 m .6269 .51497 L .62414 .51442 L p F P
0 g
s
.536 .904 .962 r
.61274 .51823 m .62414 .51442 L .6269 .51497 L p F P
0 g
s
.875 .668 .619 r
.09196 .44166 m .08718 .43884 L .0888 .43325 L p F P
0 g
s
.88 .656 .595 r
.08718 .43884 m .09196 .44166 L .09075 .44714 L p F P
0 g
s
.687 .496 .622 r
.40871 .33112 m .41382 .33091 L .41016 .33718 L p F P
0 g
s
.687 .496 .622 r
.41016 .33718 m .40952 .33721 L .40871 .33112 L p F P
0 g
s
.636 .676 .871 r
.60214 .26352 m .59075 .26639 L .58783 .26204 L p F P
0 g
s
.691 .638 .791 r
.43481 .50426 m .43276 .5003 L .42423 .50477 L closepath p F P
0 g
s
.691 .638 .792 r
.42968 .49407 m .43276 .5003 L .42423 .50477 L p F P
0 g
s
.691 .638 .792 r
.41854 .50018 m .42968 .49407 L p .42423 .50477 L F P
0 g
s
.724 .746 .869 r
.20305 .26737 m .20047 .26881 L .197 .26508 L p F P
0 g
s
.746 .749 .855 r
.18605 .27202 m .197 .26508 L .20047 .26881 L p F P
0 g
s
.864 .701 .677 r
.08637 .4103 m .0865 .41002 L .08598 .40969 L closepath p F P
0 g
s
.857 .708 .696 r
.08289 .40525 m .0851 .40101 L p .0865 .41002 L F P
0 g
s
.857 .708 .696 r
.0865 .41002 m .08598 .40969 L .08289 .40525 L p F P
0 g
s
.74 .531 .611 r
.36496 .32938 m .36342 .32921 L .36269 .32318 L p F P
0 g
s
.742 .533 .61 r
.35704 .32253 m .36269 .32318 L .36342 .32921 L p F P
0 g
s
.858 .478 .326 r
.12296 .48824 m .11771 .48564 L .11606 .48103 L p F P
0 g
s
.859 .476 .317 r
.11082 .47842 m .11606 .48103 L .11771 .48564 L p F P
0 g
s
.611 .401 .572 r
.46599 .30736 m .47229 .30605 L .47255 .31146 L p F P
0 g
s
.611 .401 .572 r
.47255 .31146 m .46276 .31349 L .46599 .30736 L p F P
0 g
s
.497 .764 .991 r
.19554 .5198 m .19231 .51892 L .19393 .51997 L closepath p F P
0 g
s
.67 .655 .827 r
.49312 .50996 m .4958 .51458 L p .48157 .51368 L F P
0 g
s
.67 .655 .827 r
.48157 .51368 m .49001 .51042 L .49312 .50996 L p F P
0 g
s
.668 .646 .819 r
.48157 .51368 m .49001 .51042 L .48059 .51194 L closepath p F P
0 g
s
.867 .701 .673 r
.08383 .41595 m .08637 .4103 L .08598 .40969 L p F P
0 g
s
.724 .687 .815 r
.322 .51298 m .323 .51237 L .32143 .51214 L closepath p F P
0 g
s
.72 .684 .815 r
.32143 .51214 m .322 .51298 L p .30773 .51467 L F P
0 g
s
.713 .516 .621 r
.39512 .33731 m .38404 .33697 L .38693 .33096 L p F P
0 g
s
.72 .524 .625 r
.37923 .33058 m .38693 .33096 L .38404 .33697 L p F P
0 g
s
0 0 0 r
.65236 .50471 m .65331 .50425 L .65245 .50463 L closepath p F P
0 g
s
.049 0 0 r
.65245 .50463 m .65331 .50425 L .66373 .49879 L p F P
0 g
s
.351 .663 .972 r
.26006 .26616 m .25737 .26591 L .25393 .26309 L p F P
0 g
s
.802 .51 .495 r
.31732 .2984 m .31019 .29629 L .30974 .29146 L p F P
0 g
s
.813 .518 .491 r
.30864 .2911 m .30974 .29146 L .31019 .29629 L p F P
0 g
s
.517 .456 .727 r
.71271 .379 m .70969 .37829 L .71199 .37662 L closepath p F P
0 g
s
.525 .469 .736 r
.70966 .36931 m .71199 .37662 L .70969 .37829 L p F P
0 g
s
.525 .469 .736 r
.70891 .36917 m .70966 .36931 L p .70969 .37829 L F P
0 g
s
.658 .699 .877 r
.5273 .52094 m .53856 .5174 L .54154 .52149 L p F P
0 g
s
.656 .682 .862 r
.53825 .51693 m .53856 .5174 L .5273 .52094 L p F P
0 g
s
.656 .682 .862 r
.5273 .52094 m .52648 .51973 L .53825 .51693 L p F P
0 g
s
.713 .662 .797 r
.3727 .49599 m .37584 .50187 L .37132 .5046 L p F P
0 g
s
.713 .662 .797 r
.36159 .5031 m .3727 .49599 L p .37132 .5046 L F P
0 g
s
.713 .662 .797 r
.37132 .5046 m .36212 .50401 L .36159 .5031 L p F P
0 g
s
.851 .725 .724 r
.09056 .37829 m .08753 .37619 L p .08788 .38558 L F P
0 g
s
.846 .729 .735 r
.09056 .37829 m .0881 .37536 L .08753 .37619 L closepath p F P
0 g
s
.685 .493 .621 r
.41382 .33091 m .4226 .33049 L .42341 .33656 L p F P
0 g
s
.685 .493 .621 r
.42341 .33656 m .41016 .33718 L .41382 .33091 L p F P
0 g
s
.212 0 .135 r
.67509 .492 m .6857 .484 L .6763 .48877 L closepath p F P
0 g
s
.295 0 .266 r
.68638 .48339 m .68716 .47963 L p .6763 .48877 L F P
0 g
s
.295 0 .266 r
.6763 .48877 m .6857 .484 L .68638 .48339 L p F P
0 g
s
.77 .531 .572 r
.34031 .31417 m .33193 .31249 L .33278 .3072 L p F P
0 g
s
.783 .543 .574 r
.32718 .30586 m .33278 .3072 L .33193 .31249 L p F P
0 g
s
.384 .17 .461 r
.6998 .46376 m .69761 .46501 L .69748 .46985 L p F P
0 g
s
.761 .538 .595 r
.34779 .32116 m .34594 .32084 L .34541 .31501 L p F P
0 g
s
.759 .536 .595 r
.34031 .31417 m .34541 .31501 L .34594 .32084 L p F P
0 g
s
.724 .687 .814 r
.32985 .501 m .33306 .50625 L .323 .51237 L p F P
0 g
s
.724 .687 .814 r
.31877 .50811 m .32985 .501 L p .323 .51237 L F P
0 g
s
.724 .687 .814 r
.323 .51237 m .32143 .51214 L .31877 .50811 L p F P
0 g
s
0 0 0 r
.65331 .50425 m .65236 .50471 L .64972 .50608 L p F P
0 g
s
.331 .797 .692 r
.65236 .50471 m .64972 .50608 L p .63877 .51065 L F P
0 g
s
.867 .701 .673 r
.08598 .40969 m .08197 .40708 L p .08383 .41595 L F P
0 g
s
.863 .708 .689 r
.08598 .40969 m .08289 .40525 L .08197 .40708 L closepath p F P
0 g
s
.714 .724 .858 r
.26489 .51949 m .26707 .51838 L .27462 .52016 L p F P
0 g
s
.701 .712 .857 r
.27585 .5139 m .26707 .51838 L .27462 .52016 L p F P
0 g
s
.701 .712 .857 r
.27462 .52016 m .27916 .51802 L .27585 .5139 L p F P
0 g
s
.878 .671 .62 r
.0841 .43039 m .0888 .43325 L .08718 .43884 L p F P
0 g
s
.873 .681 .64 r
.0888 .43325 m .0841 .43039 L .08609 .42467 L p F P
0 g
s
.726 .528 .623 r
.37547 .33033 m .37923 .33058 L .38012 .33678 L p F P
0 g
s
.72 .524 .625 r
.38404 .33697 m .38012 .33678 L .37923 .33058 L p F P
0 g
s
.572 .573 .815 r
.66855 .29511 m .67145 .30135 L .65984 .30211 L p F P
0 g
s
.572 .573 .815 r
.66029 .29564 m .66855 .29511 L p .65984 .30211 L F P
0 g
s
.572 .573 .815 r
.65984 .30211 m .6578 .29773 L .66029 .29564 L p F P
0 g
s
.813 .518 .491 r
.31019 .29629 m .30774 .29548 L .30864 .2911 L p F P
0 g
s
.798 .502 .488 r
.30255 .28936 m .30864 .2911 L .30774 .29548 L p F P
0 g
s
.685 .635 .794 r
.44086 .50379 m .43481 .50426 L .43276 .5003 L p F P
0 g
s
.83 .742 .766 r
.09926 .34321 m .1035 .34634 L .09781 .35324 L p F P
0 g
s
.828 .743 .771 r
.1043 .33727 m .09926 .34321 L .1035 .34634 L p F P
0 g
s
.68 .638 .801 r
.46141 .50188 m .46429 .50736 L p .45007 .50668 L F P
0 g
s
.68 .638 .801 r
.45007 .50668 m .46018 .502 L .46141 .50188 L p F P
0 g
s
.679 .634 .798 r
.45007 .50668 m .46018 .502 L .44828 .50325 L closepath p F P
0 g
s
0 0 0 r
.6627 .49992 m .65331 .50425 L p .64972 .50608 L F P
0 g
s
0 0 0 r
.65331 .50425 m .6627 .49992 L .66373 .49879 L closepath p F P
0 g
s
.724 .746 .869 r
.197 .26508 m .19836 .26434 L .20305 .26737 L p F P
0 g
s
.727 .751 .872 r
.20789 .25916 m .19836 .26434 L .20305 .26737 L p F P
0 g
s
.727 .751 .872 r
.20305 .26737 m .21136 .26279 L .20789 .25916 L p F P
0 g
s
.719 .685 .816 r
.32143 .51214 m .31877 .50811 L .31364 .51114 L closepath p F P
0 g
s
.72 .684 .815 r
.30773 .51467 m .31364 .51114 L .32143 .51214 L p F P
0 g
s
.876 .576 .477 r
.10467 .47096 m .10304 .47012 L .10449 .46805 L closepath p F P
0 g
s
.671 .483 .623 r
.4226 .33049 m .4306 .32979 L .42619 .33631 L p F P
0 g
s
.671 .483 .623 r
.42619 .33631 m .42341 .33656 L .4226 .33049 L p F P
0 g
s
.729 .69 .813 r
.31364 .51114 m .30773 .51467 L .30447 .51007 L p F P
0 g
s
.719 .696 .828 r
.29345 .51638 m .30447 .51007 L .30773 .51467 L p F P
0 g
s
.479 .372 .655 r
.71359 .42511 m .71352 .42477 L .7138 .42496 L closepath p F P
0 g
s
.742 .533 .61 r
.36342 .32921 m .35501 .32824 L .35704 .32253 L p F P
0 g
s
.755 .546 .613 r
.34779 .32116 m .35704 .32253 L .35501 .32824 L p F P
0 g
s
.425 .26 .552 r
.71231 .44538 m .70671 .44883 L .70712 .45426 L p F P
0 g
s
.447 .298 .585 r
.70671 .44883 m .71231 .44538 L .70992 .44076 L p F P
0 g
s
.564 .552 .8 r
.67727 .31446 m .67345 .31456 L .67632 .31227 L closepath p F P
0 g
s
.569 .561 .805 r
.67436 .30785 m .67632 .31227 L .67345 .31456 L p F P
0 g
s
.464 .346 .634 r
.7138 .42496 m .71359 .42511 L .71466 .43129 L p F P
0 g
s
.76 .751 .844 r
.17155 .27593 m .17732 .2719 L .18164 .27507 L p F P
0 g
s
.76 .752 .845 r
.18255 .2683 m .17732 .2719 L .18164 .27507 L p F P
0 g
s
.76 .752 .845 r
.18164 .27507 m .18605 .27202 L .18255 .2683 L p F P
0 g
s
.726 .528 .623 r
.38012 .33678 m .37275 .33628 L .37547 .33033 L p F P
0 g
s
.736 .539 .626 r
.36496 .32938 m .37547 .33033 L .37275 .33628 L p F P
0 g
s
.668 .645 .818 r
.49001 .51042 m .48059 .51194 L .47852 .50826 L p F P
0 g
s
.831 .392 .19 r
.12296 .48824 m .12437 .49086 L .12138 .4906 L p F P
0 g
s
.831 .392 .19 r
.11771 .48564 m .12296 .48824 L p .12138 .4906 L F P
0 g
s
.855 .722 .716 r
.08348 .38255 m .08788 .38558 L .0841 .39185 L p F P
0 g
s
.851 .725 .724 r
.08753 .37619 m .08348 .38255 L .08788 .38558 L p F P
0 g
s
.517 .766 .987 r
.19554 .5198 m .2045 .51863 L p .19037 .51763 L F P
0 g
s
.517 .766 .987 r
.19037 .51763 m .19231 .51892 L .19554 .5198 L p F P
0 g
s
.714 .662 .797 r
.36212 .50401 m .36159 .5031 L .36029 .50389 L closepath p F P
0 g
s
.554 .537 .791 r
.68066 .32238 m .68204 .32125 L p .68916 .3284 L F P
0 g
s
.558 .547 .798 r
.68066 .32238 m .68018 .32126 L .68204 .32125 L closepath p F P
0 g
s
.655 .717 .894 r
.54154 .52149 m .55283 .51807 L .55579 .52182 L p F P
0 g
s
.655 .696 .876 r
.55283 .51807 m .54154 .52149 L .53856 .5174 L p F P
0 g
s
.706 .632 .772 r
.40113 .49432 m .39008 .50097 L .38696 .49496 L p F P
0 g
s
.658 .682 .861 r
.53557 .51287 m .53825 .51693 L .52648 .51973 L p F P
0 g
s
.658 .682 .861 r
.52648 .51973 m .5243 .51651 L .53557 .51287 L p F P
0 g
s
.461 .328 .613 r
.70992 .44076 m .71554 .43724 L .71466 .43129 L p F P
0 g
s
.443 .296 .586 r
.71554 .43724 m .70992 .44076 L .71231 .44538 L p F P
0 g
s
.583 .589 .824 r
.65404 .28992 m .64629 .29072 L .65211 .28597 L closepath p F P
0 g
s
.588 .599 .831 r
.65114 .28402 m .65211 .28597 L .64629 .29072 L p F P
0 g
s
.588 .599 .831 r
.63959 .28543 m .65114 .28402 L p .64629 .29072 L F P
0 g
s
.464 .346 .634 r
.71466 .43129 m .71818 .42896 L .7138 .42496 L p F P
0 g
s
.462 .346 .635 r
.72286 .41887 m .7138 .42496 L .71818 .42896 L p F P
0 g
s
.478 .373 .656 r
.72229 .41609 m .72286 .41887 L .7138 .42496 L p F P
0 g
s
.478 .373 .656 r
.71922 .41399 m .72229 .41609 L p .7138 .42496 L F P
0 g
s
.841 .734 .747 r
.0921 .36966 m .08777 .36659 L .09263 .35997 L p F P
0 g
s
.844 .732 .74 r
.0921 .36966 m .0881 .37536 L .08452 .37123 L p F P
0 g
s
.844 .732 .74 r
.08452 .37123 m .08777 .36659 L .0921 .36966 L p F P
0 g
s
.711 .638 .773 r
.38696 .49496 m .37584 .50187 L .3727 .49599 L p F P
0 g
s
.338 0 0 r
.15843 .50947 m .15286 .50702 L .1463 .50389 L p F P
0 g
s
0 .313 .666 r
.14321 .50263 m .1463 .50389 L .15286 .50702 L p F P
0 g
s
.718 .658 .789 r
.34733 .50457 m .34967 .50305 L .36029 .50389 L p F P
0 g
s
.71 .653 .791 r
.35843 .49737 m .34967 .50305 L .36029 .50389 L p F P
0 g
s
.71 .653 .791 r
.36029 .50389 m .36159 .5031 L .35843 .49737 L p F P
0 g
s
.027 .545 .866 r
.1645 .51176 m .17275 .51321 L p .15883 .50962 L F P
0 g
s
.027 .545 .866 r
.15883 .50962 m .15958 .50997 L .1645 .51176 L p F P
0 g
s
.665 .659 .834 r
.4958 .51458 m .50702 .5105 L .51004 .51554 L p F P
0 g
s
.665 .651 .827 r
.50549 .50779 m .50702 .5105 L .4958 .51458 L p F P
0 g
s
.665 .651 .827 r
.4958 .51458 m .49312 .50996 L .50549 .50779 L p F P
0 g
s
.699 .637 .784 r
.40431 .5004 m .41522 .49411 L .40122 .49432 L closepath p F P
0 g
s
.793 .752 .815 r
.14346 .2984 m .13825 .30297 L .1347 .29922 L p F P
0 g
s
.799 .752 .809 r
.13452 .30641 m .13825 .30297 L .1347 .29922 L p F P
0 g
s
.802 .751 .806 r
.13452 .30641 m .12703 .31342 L .12346 .30967 L p F P
0 g
s
.802 .751 .806 r
.12346 .30967 m .13036 .30321 L .13452 .30641 L p F P
0 g
s
.799 .752 .809 r
.1347 .29922 m .13036 .30321 L .13452 .30641 L p F P
0 g
s
.601 .618 .84 r
.6223 .27619 m .63379 .27432 L .63669 .27975 L p F P
0 g
s
.603 .625 .846 r
.63089 .26894 m .63379 .27432 L .6223 .27619 L p F P
0 g
s
.603 .625 .846 r
.62554 .26985 m .63089 .26894 L p .6223 .27619 L F P
0 g
s
.603 .625 .846 r
.6223 .27619 m .62089 .27362 L .62554 .26985 L p F P
0 g
s
.685 .635 .794 r
.44391 .49452 m .44699 .50075 L .44086 .50379 L p F P
0 g
s
.685 .635 .794 r
.43276 .5003 m .44391 .49452 L p .44086 .50379 L F P
0 g
s
.686 .637 .795 r
.44828 .50325 m .44699 .50075 L .44086 .50379 L closepath p F P
0 g
s
.558 .548 .799 r
.68204 .32125 m .68018 .32126 L .67727 .31446 L p F P
0 g
s
.808 .46 .397 r
.30255 .28936 m .29582 .28709 L .29435 .28263 L p F P
0 g
s
.828 .483 .404 r
.28887 .28038 m .29435 .28263 L .29582 .28709 L p F P
0 g
s
.724 .689 .816 r
.30447 .51007 m .29345 .51638 L .29016 .51201 L p F P
0 g
s
.807 .751 .801 r
.12625 .31418 m .12703 .31342 L .12346 .30967 L p F P
0 g
s
.785 .523 .542 r
.32487 .30536 m .31708 .30347 L .31732 .2984 L p F P
0 g
s
.802 .54 .541 r
.31019 .29629 m .31732 .2984 L .31708 .30347 L p F P
0 g
s
.793 .752 .815 r
.1347 .29922 m .13928 .2952 L .14346 .2984 L p F P
0 g
s
.791 .752 .817 r
.14587 .28951 m .13928 .2952 L .14346 .2984 L p F P
0 g
s
.791 .752 .817 r
.14346 .2984 m .14941 .29326 L .14587 .28951 L p F P
0 g
s
.807 .751 .801 r
.12346 .30967 m .12211 .31098 L .12625 .31418 L p F P
0 g
s
.81 .75 .796 r
.12211 .31098 m .12625 .31418 L .11879 .32168 L p F P
0 g
s
.773 .548 .593 r
.33193 .31249 m .34031 .31417 L .33886 .31967 L p F P
0 g
s
.759 .536 .595 r
.34594 .32084 m .33886 .31967 L .34031 .31417 L p F P
0 g
s
.716 .644 .776 r
.3727 .49599 m .36159 .5031 L .35843 .49737 L p F P
0 g
s
.862 .71 .693 r
.0851 .40101 m .08289 .40525 L .07938 .40038 L p F P
0 g
s
.862 .71 .693 r
.07938 .40038 m .0806 .39804 L .0851 .40101 L p F P
0 g
s
.856 .715 .706 r
.0851 .40101 m .0806 .39804 L .0841 .39185 L p F P
0 g
s
.617 .753 .943 r
.20801 .52133 m .2187 .51875 L .22217 .52175 L p F P
0 g
s
.637 .751 .931 r
.2187 .51875 m .20801 .52133 L .2045 .51863 L p F P
0 g
s
.875 .684 .641 r
.08148 .42177 m .08609 .42467 L .0841 .43039 L p F P
0 g
s
.87 .692 .658 r
.08609 .42467 m .08148 .42177 L .08383 .41595 L p F P
0 g
s
.626 .879 .988 r
.61136 .51753 m .61274 .51823 L .62414 .51442 L p F P
0 g
s
.693 .633 .784 r
.42942 .49353 m .42968 .49407 L .41854 .50018 L p F P
0 g
s
.693 .633 .784 r
.41854 .50018 m .4155 .4941 L .42942 .49353 L p F P
0 g
s
.784 .752 .824 r
.15328 .29008 m .14941 .29326 L .14587 .28951 L p F P
0 g
s
.614 .418 .592 r
.46054 .31616 m .46276 .31349 L .46037 .314 L closepath p F P
0 g
s
.631 .431 .593 r
.46037 .314 m .46054 .31616 L .45798 .32013 L p F P
0 g
s
.671 .483 .623 r
.4306 .32979 m .436 .32932 L .43681 .33539 L p F P
0 g
s
.671 .483 .623 r
.43681 .33539 m .42619 .33631 L .4306 .32979 L p F P
0 g
s
.675 .638 .805 r
.46429 .50736 m .47546 .50252 L .47852 .50826 L p F P
0 g
s
.676 .635 .802 r
.47435 .50031 m .47546 .50252 L .46429 .50736 L p F P
0 g
s
.676 .635 .802 r
.46429 .50736 m .46141 .50188 L .47435 .50031 L p F P
0 g
s
.589 .601 .833 r
.64824 .2783 m .65114 .28402 L .63959 .28543 L p F P
0 g
s
.589 .601 .833 r
.63826 .27954 m .64824 .2783 L p .63959 .28543 L F P
0 g
s
.589 .601 .833 r
.63959 .28543 m .63709 .28052 L .63826 .27954 L p F P
0 g
s
.746 .751 .856 r
.197 .26508 m .18605 .27202 L .18255 .2683 L p F P
0 g
s
.591 .386 .571 r
.47255 .31146 m .47229 .30605 L .48407 .30305 L p F P
0 g
s
.579 .352 .537 r
.48408 .29797 m .48407 .30305 L .47229 .30605 L p F P
0 g
s
.636 .446 .609 r
.44832 .3218 m .45798 .32013 L .45235 .32705 L p F P
0 g
s
.636 .446 .609 r
.45235 .32705 m .44894 .32764 L .44832 .3218 L p F P
0 g
s
.655 .464 .613 r
.44832 .3218 m .44894 .32764 L .436 .32932 L p F P
0 g
s
.522 .469 .738 r
.70966 .36931 m .70891 .36917 L .70948 .36875 L closepath p F P
0 g
s
.53 .481 .746 r
.70675 .3606 m .70948 .36875 L .70891 .36917 L p F P
0 g
s
.652 .741 .915 r
.55579 .52182 m .56711 .51848 L .57005 .52181 L p F P
0 g
s
.653 .715 .894 r
.56711 .51848 m .55579 .52182 L .55283 .51807 L p F P
0 g
s
.299 .777 .682 r
.53087 .26914 m .52428 .27232 L .52003 .27434 L p F P
0 g
s
.62 .654 .862 r
.61358 .26099 m .61649 .26592 L .60505 .26833 L p F P
0 g
s
.62 .654 .862 r
.60347 .26322 m .61358 .26099 L p .60505 .26833 L F P
0 g
s
.62 .654 .862 r
.60505 .26833 m .60244 .26402 L .60347 .26322 L p F P
0 g
s
.616 .642 .853 r
.60505 .26833 m .61649 .26592 L .61939 .27097 L p F P
0 g
s
.813 .749 .792 r
.11879 .32168 m .11572 .32484 L .11214 .32105 L p F P
0 g
s
.813 .749 .792 r
.11214 .32105 m .11461 .3185 L .11879 .32168 L p F P
0 g
s
.81 .75 .796 r
.11879 .32168 m .11461 .3185 L .12211 .31098 L p F P
0 g
s
.721 .665 .794 r
.34733 .50457 m .34967 .50305 L .34625 .5027 L closepath p F P
0 g
s
.72 .663 .793 r
.34625 .5027 m .34733 .50457 L p .33306 .50625 L F P
0 g
s
.784 .752 .824 r
.14587 .28951 m .14907 .28688 L .15328 .29008 L p F P
0 g
s
.782 .753 .827 r
.15698 .28051 m .14907 .28688 L .15328 .29008 L p F P
0 g
s
.782 .753 .827 r
.15328 .29008 m .16051 .28424 L .15698 .28051 L p F P
0 g
s
.556 .334 .534 r
.48407 .30305 m .48408 .29797 L .49548 .2945 L p F P
0 g
s
.531 .279 .478 r
.49583 .28983 m .49548 .2945 L .48408 .29797 L p F P
0 g
s
.722 .702 .83 r
.29016 .51201 m .27916 .51802 L .27585 .5139 L p F P
0 g
s
.783 .543 .574 r
.33193 .31249 m .32744 .31143 L .32718 .30586 L p F P
0 g
s
.776 .538 .575 r
.32487 .30536 m .32718 .30586 L .32744 .31143 L p F P
0 g
s
.292 .003 .29 r
.68638 .48339 m .693 .47648 L .68716 .47963 L closepath p F P
0 g
s
.355 .105 .39 r
.69746 .47007 m .69748 .46985 L p .68716 .47963 L F P
0 g
s
.355 .105 .39 r
.68716 .47963 m .693 .47648 L .69746 .47007 L p F P
0 g
s
.835 .74 .759 r
.09781 .35324 m .09632 .35514 L .09273 .35116 L p F P
0 g
s
.835 .74 .759 r
.09273 .35116 m .09355 .35012 L .09781 .35324 L p F P
0 g
s
.83 .742 .766 r
.09781 .35324 m .09355 .35012 L .09926 .34321 L p F P
0 g
s
.412 .223 .512 r
.6998 .46376 m .70728 .4594 L .70712 .45426 L p F P
0 g
s
.384 .17 .461 r
.69748 .46985 m .69766 .46975 L .6998 .46376 L p F P
0 g
s
.377 .163 .457 r
.70728 .4594 m .6998 .46376 L .69766 .46975 L p F P
0 g
s
.679 .634 .797 r
.46018 .502 m .44828 .50325 L .44699 .50075 L p F P
0 g
s
.717 .679 .812 r
.31554 .50307 m .30512 .50966 L .31364 .51114 L p F P
0 g
s
.717 .679 .812 r
.31364 .51114 m .31877 .50811 L .31554 .50307 L p F P
0 g
s
.729 .69 .813 r
.30447 .51007 m .30512 .50966 L .31364 .51114 L p F P
0 g
s
.702 .518 .637 r
.39638 .33731 m .40952 .33721 L p .4061 .34359 L F P
0 g
s
.702 .518 .637 r
.39539 .33899 m .39638 .33731 L p .4061 .34359 L F P
0 g
s
.705 .518 .633 r
.39539 .33899 m .39638 .33731 L .39512 .33731 L closepath p F P
0 g
s
.717 .53 .636 r
.39512 .33731 m .39539 .33899 L .39275 .34358 L p F P
0 g
s
.717 .53 .636 r
.38404 .33697 m .39512 .33731 L p .39275 .34358 L F P
0 g
s
.736 .539 .626 r
.36384 .332 m .36496 .32938 L p .37275 .33628 L F P
0 g
s
.74 .54 .623 r
.36384 .332 m .36496 .32938 L .36342 .32921 L closepath p F P
0 g
s
.818 .749 .787 r
.1118 .32902 m .11572 .32484 L .11214 .32105 L p F P
0 g
s
0 .43 .777 r
.26737 .26856 m .26006 .26616 L p .2683 .26895 L F P
0 g
s
0 .347 .707 r
.25502 .26327 m .26006 .26616 L .26737 .26856 L p F P
0 g
s
.713 .185 0 r
.26422 .26853 m .26184 .2662 L p .26737 .26856 L F P
0 g
s
0 .347 .707 r
.26156 .26593 m .25502 .26327 L p .26593 .26794 L F P
0 g
s
0 .347 .707 r
.26737 .26856 m .26156 .26593 L p .26593 .26794 L F P
0 g
s
.351 .663 .972 r
.25393 .26309 m .25502 .26327 L .26006 .26616 L p F P
0 g
s
0 .278 .659 r
.25114 .26086 m .25502 .26327 L .26156 .26593 L p F P
0 g
s
.755 .248 .002 r
.26268 .26851 m .25695 .26381 L .26156 .26593 L F
0 .278 .659 r
.25047 .26036 m .25114 .26086 L p .26156 .26593 L F P
0 g
s
0 .278 .659 r
.25615 .26315 m .25047 .26036 L p .26026 .26528 L F P
0 g
s
0 .278 .659 r
.26156 .26593 m .25615 .26315 L p .26026 .26528 L F P
0 g
s
.271 .624 .96 r
.25502 .26327 m .25114 .26086 L .25393 .26309 L closepath p F P
0 g
s
0 .345 .771 r
.25615 .26315 m .25047 .26036 L .24698 .25782 L p F P
0 g
s
.776 .278 .018 r
.25615 .26315 m .25945 .26695 L p .25201 .26101 L F P
0 g
s
.776 .278 .018 r
.25106 .26025 m .25615 .26315 L p .25201 .26101 L F P
0 g
s
.755 .248 .002 r
.25615 .26315 m .26156 .26593 L p .25695 .26381 L F P
0 g
s
.713 .185 0 r
.26184 .2662 m .26156 .26593 L .26737 .26856 L p F P
0 g
s
0 .43 .777 r
.26841 .26899 m .26737 .26856 L p .2683 .26895 L F P
0 g
s
.577 .582 .821 r
.6578 .29773 m .65693 .29591 L .66029 .29564 L closepath p F P
0 g
s
.688 .622 .776 r
.44391 .49452 m .43276 .5003 L .42968 .49407 L p F P
0 g
s
.505 .258 .474 r
.49548 .2945 m .49583 .28983 L .50686 .2859 L p F P
0 g
s
.454 .158 .372 r
.50769 .28181 m .50686 .2859 L .49583 .28983 L p F P
0 g
s
.655 .472 .624 r
.436 .32932 m .44894 .32764 L p .44623 .33414 L F P
0 g
s
.655 .472 .624 r
.44623 .33414 m .43681 .33539 L .436 .32932 L p F P
0 g
s
.422 .727 .989 r
.19037 .51763 m .18913 .51764 L .19231 .51892 L closepath p F P
0 g
s
.689 .505 .633 r
.40964 .33797 m .41016 .33718 L .40952 .33721 L closepath p F P
0 g
s
.702 .518 .637 r
.40952 .33721 m .40964 .33797 L .4061 .34359 L p F P
0 g
s
.618 .423 .595 r
.46276 .31349 m .47255 .31146 L p .46084 .31965 L F P
0 g
s
.618 .423 .595 r
.46084 .31965 m .46054 .31616 L .46276 .31349 L p F P
0 g
s
.686 .506 .637 r
.41016 .33718 m .42341 .33656 L p .42138 .34297 L F P
0 g
s
.686 .506 .637 r
.40964 .33797 m .41016 .33718 L p .42138 .34297 L F P
0 g
s
.66 .747 .914 r
.22217 .52175 m .23295 .51818 L .23638 .52147 L p F P
0 g
s
.674 .743 .903 r
.23295 .51818 m .22217 .52175 L .2187 .51875 L p F P
0 g
s
.757 .286 .126 r
.28821 .28016 m .28174 .27779 L .27849 .27396 L p F P
0 g
s
.785 .321 .14 r
.27284 .27129 m .27849 .27396 L .28174 .27779 L p F P
0 g
s
.391 0 0 r
.27131 .27018 m .27284 .27129 L .27849 .27396 L p F P
0 g
s
.521 .477 .748 r
.70704 .36037 m .70675 .3606 L .70948 .36875 L p F P
0 g
s
.521 .477 .748 r
.70948 .36875 m .71773 .3623 L .70704 .36037 L p F P
0 g
s
.515 .464 .738 r
.70948 .36875 m .71773 .3623 L p .71888 .37134 L F P
0 g
s
.515 .464 .738 r
.71888 .37134 m .70966 .36931 L .70948 .36875 L p F P
0 g
s
.515 .464 .738 r
.71199 .37662 m .70966 .36931 L .71888 .37134 L closepath p F P
0 g
s
.722 .664 .793 r
.35583 .49252 m .35843 .49737 L .34967 .50305 L p F P
0 g
s
.722 .664 .793 r
.35395 .49237 m .35583 .49252 L p .34967 .50305 L F P
0 g
s
.722 .664 .793 r
.34415 .49906 m .35395 .49237 L p .34967 .50305 L F P
0 g
s
.722 .664 .793 r
.34967 .50305 m .34625 .5027 L .34415 .49906 L p F P
0 g
s
.628 .857 .986 r
.61136 .51753 m .60992 .51671 L .59853 .52023 L p F P
0 g
s
.639 .822 .971 r
.60992 .51671 m .59853 .52023 L .59566 .51796 L p F P
0 g
s
.639 .815 .967 r
.58429 .52133 m .59566 .51796 L .59853 .52023 L p F P
0 g
s
.648 .773 .94 r
.57005 .52181 m .58139 .51849 L .58429 .52133 L p F P
0 g
s
.65 .742 .916 r
.58139 .51849 m .57005 .52181 L .56711 .51848 L p F P
0 g
s
.839 .74 .755 r
.09263 .35997 m .09632 .35514 L .09273 .35116 L p F P
0 g
s
.509 .451 .727 r
.71199 .37662 m .71888 .37134 L p .71905 .38067 L F P
0 g
s
.509 .451 .727 r
.71905 .38067 m .71271 .379 L .71199 .37662 L p F P
0 g
s
.67 .746 .908 r
.55931 .26192 m .57063 .25791 L .57355 .2614 L p F P
0 g
s
.685 .785 .926 r
.57063 .25791 m .55931 .26192 L .55637 .25939 L p F P
0 g
s
.69 .819 .944 r
.54508 .26401 m .55637 .25939 L .55931 .26192 L p F P
0 g
s
.736 .538 .624 r
.36342 .32921 m .35501 .32824 L p .36239 .33528 L F P
0 g
s
.736 .538 .624 r
.36239 .33528 m .36384 .332 L .36342 .32921 L p F P
0 g
s
.418 .125 .358 r
.50686 .2859 m .50769 .28181 L .51838 .27746 L p F P
0 g
s
.318 0 .171 r
.51962 .27483 m .51838 .27746 L .50769 .28181 L p F P
0 g
s
.661 .653 .832 r
.52129 .5117 m .51004 .51554 L .50702 .5105 L p F P
0 g
s
.661 .667 .845 r
.51004 .51554 m .52129 .5117 L .5243 .51651 L p F P
0 g
s
.715 .73 .862 r
.26489 .51949 m .26707 .51838 L .26288 .5172 L closepath p F P
0 g
s
.7 .725 .869 r
.26288 .5172 m .26489 .51949 L p .25062 .52067 L F P
0 g
s
.494 .409 .689 r
.71897 .40146 m .7162 .40027 L .71831 .3988 L closepath p F P
0 g
s
.504 .427 .702 r
.7162 .40027 m .71831 .3988 L .71641 .39165 L p F P
0 g
s
.554 .537 .791 r
.68204 .32125 m .69189 .32142 L p .68916 .3284 L F P
0 g
s
.552 .538 .793 r
.69189 .32142 m .68204 .32125 L .6893 .31518 L closepath p F P
0 g
s
.558 .548 .799 r
.68897 .3144 m .6893 .31518 L .68204 .32125 L p F P
0 g
s
.558 .548 .799 r
.67727 .31446 m .68897 .3144 L p .68204 .32125 L F P
0 g
s
.509 .451 .727 r
.7143 .38425 m .71271 .379 L .71905 .38067 L closepath p F P
0 g
s
.705 .169 0 r
.14063 .50146 m .13521 .49893 L .13115 .49505 L p F P
0 g
s
.688 .143 0 r
.12563 .49255 m .13115 .49505 L .13521 .49893 L p F P
0 g
s
.79 .317 .108 r
.13115 .49505 m .12563 .49255 L .12437 .49086 L p F P
0 g
s
.72 .663 .793 r
.33306 .50625 m .3395 .50206 L .34625 .5027 L p F P
0 g
s
.728 .667 .79 r
.3395 .50206 m .33306 .50625 L .32985 .501 L p F P
0 g
s
.686 .506 .637 r
.42138 .34297 m .41055 .34352 L .40964 .33797 L p F P
0 g
s
.698 .514 .635 r
.41055 .34352 m .40964 .33797 L .4061 .34359 L closepath p F P
0 g
s
.773 .752 .834 r
.16434 .28133 m .16051 .28424 L .15698 .28051 L p F P
0 g
s
.717 .53 .636 r
.38107 .34255 m .38404 .33697 L p .39275 .34358 L F P
0 g
s
.72 .531 .633 r
.38107 .34255 m .38404 .33697 L .38012 .33678 L closepath p F P
0 g
s
.647 .777 .943 r
.59566 .51796 m .58429 .52133 L .58139 .51849 L p F P
0 g
s
.776 .538 .575 r
.32744 .31143 m .32396 .31067 L .32487 .30536 L p F P
0 g
s
.786 .546 .572 r
.31708 .30347 m .32487 .30536 L .32396 .31067 L p F P
0 g
s
.651 .703 .885 r
.57355 .2614 m .58491 .25793 L .58783 .26204 L p F P
0 g
s
.661 .725 .896 r
.58491 .25793 m .57355 .2614 L .57063 .25791 L p F P
0 g
s
.755 .546 .613 r
.34649 .32508 m .34779 .32116 L p .35501 .32824 L F P
0 g
s
.76 .549 .611 r
.34649 .32508 m .34779 .32116 L .34594 .32084 L closepath p F P
0 g
s
.646 .753 .927 r
.22564 .26144 m .23639 .25806 L .23984 .26134 L p F P
0 g
s
.634 .751 .932 r
.23639 .25806 m .22564 .26144 L .22219 .25791 L p F P
0 g
s
.698 .751 .893 r
.21136 .26279 m .22219 .25791 L .22564 .26144 L p F P
0 g
s
.867 .701 .673 r
.08197 .40708 m .07929 .41301 L .08383 .41595 L p F P
0 g
s
.873 .696 .659 r
.07929 .41301 m .08383 .41595 L .08148 .42177 L p F P
0 g
s
.821 .748 .783 r
.10765 .32584 m .1118 .32902 L .10523 .33622 L p F P
0 g
s
.818 .749 .787 r
.11214 .32105 m .10765 .32584 L .1118 .32902 L p F P
0 g
s
.7 .725 .869 r
.25062 .52067 m .25948 .51659 L .26288 .5172 L p F P
0 g
s
.711 .725 .861 r
.25948 .51659 m .25062 .52067 L .24723 .51711 L p F P
0 g
s
.685 .737 .89 r
.23638 .52147 m .24723 .51711 L .25062 .52067 L p F P
0 g
s
.695 .733 .88 r
.24723 .51711 m .23638 .52147 L .23295 .51818 L p F P
0 g
s
.528 .49 .757 r
.70675 .3606 m .70665 .36032 L .70704 .36037 L closepath p F P
0 g
s
.528 .49 .758 r
.70704 .36037 m .70665 .36032 L .70379 .35218 L p F P
0 g
s
.702 .518 .637 r
.4061 .34359 m .39617 .34365 L .39539 .33899 L p F P
0 g
s
.711 .525 .635 r
.39617 .34365 m .39539 .33899 L .39275 .34358 L closepath p F P
0 g
s
.848 .733 .736 r
.08753 .37619 m .0881 .37536 L .08452 .37123 L p F P
0 g
s
.503 .437 .716 r
.7143 .38425 m .71905 .38067 L p .71824 .39029 L F P
0 g
s
.503 .437 .716 r
.71824 .39029 m .7158 .38952 L .7143 .38425 L p F P
0 g
s
.607 .632 .85 r
.62089 .27362 m .61939 .27097 L .62554 .26985 L closepath p F P
0 g
s
.635 .435 .595 r
.46084 .31965 m .46054 .31616 L .45798 .32013 L closepath p F P
0 g
s
.304 .704 .977 r
.17636 .51531 m .1833 .51529 L .18913 .51764 L p F P
0 g
s
.384 .731 .99 r
.1833 .51529 m .17636 .51531 L .17275 .51321 L p F P
0 g
s
.331 .797 .692 r
.64972 .50608 m .64401 .50844 L .63877 .51065 L p F P
0 g
s
.422 .867 .826 r
.6383 .51072 m .64401 .50844 L .63877 .51065 L closepath p F P
0 g
s
.886 .59 .481 r
.09452 .46047 m .09943 .46321 L .09965 .46826 L p F P
0 g
s
.883 .588 .483 r
.10304 .47012 m .09965 .46826 L .09943 .46321 L p F P
0 g
s
.883 .616 .528 r
.09943 .46321 m .09452 .46047 L .09482 .45527 L p F P
0 g
s
.668 .645 .818 r
.47852 .50826 m .48972 .50372 L p .49001 .51042 L F P
0 g
s
.671 .633 .803 r
.48972 .50372 m .47852 .50826 L .47546 .50252 L p F P
0 g
s
.72 .53 .633 r
.38012 .33678 m .37275 .33628 L p .38077 .34312 L F P
0 g
s
.72 .53 .633 r
.38077 .34312 m .38107 .34255 L .38012 .33678 L p F P
0 g
s
.798 .502 .488 r
.30774 .29548 m .30311 .29415 L .30255 .28936 L p F P
0 g
s
.813 .516 .488 r
.29582 .28709 m .30255 .28936 L .30311 .29415 L p F P
0 g
s
.72 .664 .793 r
.34625 .5027 m .34415 .49906 L .3395 .50206 L closepath p F P
0 g
s
.886 .618 .527 r
.08996 .45249 m .09482 .45527 L .09452 .46047 L p F P
0 g
s
.882 .638 .565 r
.09482 .45527 m .08996 .45249 L .09075 .44714 L p F P
0 g
s
0 .313 .666 r
.14144 .50206 m .14321 .50263 L p .15286 .50702 L F P
0 g
s
.595 .022 0 r
.14144 .50206 m .14063 .50146 L .14321 .50263 L closepath p F P
0 g
s
.853 .729 .726 r
.08323 .37311 m .08753 .37619 L .08348 .38255 L p F P
0 g
s
.848 .733 .736 r
.08452 .37123 m .08323 .37311 L .08753 .37619 L p F P
0 g
s
.577 .584 .824 r
.66029 .29564 m .65693 .29591 L .65404 .28992 L p F P
0 g
s
.52 .478 .75 r
.71554 .3536 m .70704 .36037 L .71773 .3623 L p F P
0 g
s
.528 .49 .758 r
.71553 .35355 m .71554 .3536 L .70704 .36037 L p F P
0 g
s
.528 .49 .758 r
.70415 .35189 m .71553 .35355 L p .70704 .36037 L F P
0 g
s
.528 .49 .758 r
.70379 .35218 m .70415 .35189 L p .70704 .36037 L F P
0 g
s
.753 .544 .612 r
.34594 .32084 m .33886 .31967 L p .34588 .32683 L F P
0 g
s
.753 .544 .612 r
.34588 .32683 m .34649 .32508 L .34594 .32084 L p F P
0 g
s
.773 .752 .834 r
.15698 .28051 m .16012 .27813 L .16434 .28133 L p F P
0 g
s
.772 .753 .836 r
.16803 .27221 m .16012 .27813 L .16434 .28133 L p F P
0 g
s
.772 .753 .836 r
.16434 .28133 m .17155 .27593 L .16803 .27221 L p F P
0 g
s
.694 .752 .896 r
.22219 .25791 m .21136 .26279 L .20789 .25916 L p F P
0 g
s
.871 .534 .41 r
.11082 .47842 m .10563 .47579 L .10467 .47096 L p F P
0 g
s
.873 .53 .398 r
.10304 .47012 m .10467 .47096 L .10563 .47579 L p F P
0 g
s
.716 .73 .861 r
.27253 .50965 m .27585 .5139 L .26707 .51838 L p F P
0 g
s
.716 .73 .861 r
.26153 .51565 m .27253 .50965 L p .26707 .51838 L F P
0 g
s
.716 .73 .861 r
.26707 .51838 m .26288 .5172 L .26153 .51565 L p F P
0 g
s
.682 .621 .78 r
.45815 .49531 m .44699 .50075 L .44391 .49452 L p F P
0 g
s
.679 .634 .797 r
.44699 .50075 m .45815 .49531 L p .46018 .502 L F P
0 g
s
.67 .653 .824 r
.49312 .50996 m .49276 .50935 L .49001 .51042 L closepath p F P
0 g
s
.668 .645 .818 r
.48972 .50372 m .49276 .50935 L .49001 .51042 L p F P
0 g
s
.513 .735 .974 r
.25114 .26086 m .25001 .26035 L .23984 .26134 L p F P
0 g
s
.53 .712 .955 r
.25001 .26035 m .23984 .26134 L .23639 .25806 L p F P
0 g
s
.673 .492 .633 r
.42384 .33943 m .42619 .33631 L .42341 .33656 L closepath p F P
0 g
s
.686 .506 .637 r
.42341 .33656 m .42384 .33943 L .42138 .34297 L p F P
0 g
s
.859 .719 .707 r
.07969 .38883 m .0841 .39185 L .0806 .39804 L p F P
0 g
s
.855 .722 .716 r
.0841 .39185 m .07969 .38883 L .08348 .38255 L p F P
0 g
s
.254 0 .109 r
.51838 .27746 m .51962 .27483 L .52428 .27232 L p F P
0 g
s
.865 .711 .689 r
.08197 .40708 m .08289 .40525 L .07938 .40038 L p F P
0 g
s
.885 .641 .565 r
.08596 .44433 m .09075 .44714 L .08996 .45249 L p F P
0 g
s
.88 .656 .595 r
.09075 .44714 m .08596 .44433 L .08718 .43884 L p F P
0 g
s
.503 .437 .715 r
.71641 .39165 m .7158 .38952 L .71824 .39029 L closepath p F P
0 g
s
.556 .548 .801 r
.68605 .30765 m .68897 .3144 L .67727 .31446 L p F P
0 g
s
.556 .548 .801 r
.68169 .30767 m .68605 .30765 L p .67727 .31446 L F P
0 g
s
.556 .548 .801 r
.67727 .31446 m .67632 .31227 L .68169 .30767 L p F P
0 g
s
.449 .319 .612 r
.71818 .42896 m .71466 .43129 L .71554 .43724 L p F P
0 g
s
.727 .667 .791 r
.32985 .501 m .31877 .50811 L .31554 .50307 L p F P
0 g
s
.647 .911 .98 r
.54406 .26361 m .54508 .26401 L .55637 .25939 L p F P
0 g
s
.736 .539 .626 r
.37275 .33628 m .36438 .33549 L .36384 .332 L p F P
0 g
s
.739 .541 .625 r
.36438 .33549 m .36384 .332 L .36239 .33528 L closepath p F P
0 g
s
.533 .501 .767 r
.70379 .35218 m .70367 .35184 L .70415 .35189 L closepath p F P
0 g
s
0 0 0 r
.6627 .49992 m .66373 .49879 L .67372 .4929 L p F P
0 g
s
.533 .502 .767 r
.70415 .35189 m .70367 .35184 L .7007 .34376 L p F P
0 g
s
.494 .42 .702 r
.71824 .39029 m .71641 .39165 L .71831 .3988 L p F P
0 g
s
.677 .498 .636 r
.42619 .33631 m .43681 .33539 L p .42438 .34281 L F P
0 g
s
.677 .498 .636 r
.42438 .34281 m .42384 .33943 L .42619 .33631 L p F P
0 g
s
.549 .527 .783 r
.68916 .3284 m .69482 .32862 L p .69524 .33589 L F P
0 g
s
.547 .528 .785 r
.69482 .32862 m .68916 .3284 L .69336 .32497 L closepath p F P
0 g
s
.554 .537 .791 r
.69189 .32142 m .69336 .32497 L .68916 .3284 L p F P
0 g
s
.706 .632 .772 r
.38696 .49496 m .38813 .49421 L .40113 .49432 L p F P
0 g
s
.708 .637 .776 r
.38696 .49496 m .38813 .49421 L .38657 .49418 L closepath p F P
0 g
s
.711 .638 .773 r
.38657 .49418 m .38696 .49496 L p .3727 .49599 L F P
0 g
s
.72 .53 .633 r
.37275 .33628 m .3697 .34235 L .38077 .34312 L p F P
0 g
s
.736 .546 .636 r
.36438 .33549 m .37275 .33628 L .3697 .34235 L p F P
0 g
s
.842 .738 .748 r
.08839 .35685 m .09263 .35997 L .08777 .36659 L p F P
0 g
s
.839 .74 .755 r
.09273 .35116 m .08839 .35685 L .09263 .35997 L p F P
0 g
s
.699 .636 .783 r
.41522 .49411 m .40122 .49432 L .4012 .49428 L p F P
0 g
s
.704 .638 .781 r
.40122 .49432 m .4012 .49428 L .40113 .49432 L closepath p F P
0 g
s
.7 .629 .774 r
.39809 .48784 m .38813 .49421 L .40113 .49432 L p F P
0 g
s
.7 .629 .774 r
.40113 .49432 m .4012 .49428 L .39809 .48784 L p F P
0 g
s
.702 .622 .764 r
.41234 .48746 m .4012 .49428 L .39809 .48784 L p F P
0 g
s
.699 .636 .783 r
.4012 .49428 m .41234 .48746 L p .41522 .49411 L F P
0 g
s
.825 .746 .777 r
.10523 .33622 m .1043 .33727 L .10071 .33343 L p F P
0 g
s
.825 .746 .777 r
.10071 .33343 m .10104 .33305 L .10523 .33622 L p F P
0 g
s
.821 .748 .783 r
.10523 .33622 m .10104 .33305 L .10765 .32584 L p F P
0 g
s
.773 .548 .593 r
.33886 .31967 m .3306 .31796 L .33193 .31249 L p F P
0 g
s
.782 .557 .595 r
.32744 .31143 m .33193 .31249 L .3306 .31796 L p F P
0 g
s
.657 .662 .843 r
.53557 .51287 m .5243 .51651 L .52129 .5117 L p F P
0 g
s
.636 .676 .871 r
.58783 .26204 m .59923 .25901 L .60214 .26352 L p F P
0 g
s
.642 .689 .879 r
.59923 .25901 m .58783 .26204 L .58491 .25793 L p F P
0 g
s
.711 .638 .773 r
.3727 .49599 m .37599 .49383 L .38657 .49418 L p F P
0 g
s
.714 .644 .778 r
.3727 .49599 m .37599 .49383 L .37147 .4936 L closepath p F P
0 g
s
.716 .644 .776 r
.37147 .4936 m .3727 .49599 L p .35843 .49737 L F P
0 g
s
.859 .476 .317 r
.11771 .48564 m .11251 .48302 L .11082 .47842 L p F P
0 g
s
.861 .473 .308 r
.10563 .47579 m .11082 .47842 L .11251 .48302 L p F P
0 g
s
.736 .538 .624 r
.35501 .32824 m .35262 .33408 L .36239 .33528 L p F P
0 g
s
.755 .555 .626 r
.34673 .32696 m .35501 .32824 L .35262 .33408 L p F P
0 g
s
.755 .546 .613 r
.35501 .32824 m .34673 .32696 L .34649 .32508 L p F P
0 g
s
.708 .636 .775 r
.39637 .48415 m .39809 .48784 L .38813 .49421 L p F P
0 g
s
.708 .636 .775 r
.39067 .48406 m .39637 .48415 L p .38813 .49421 L F P
0 g
s
.708 .636 .775 r
.38383 .48866 m .39067 .48406 L p .38813 .49421 L F P
0 g
s
.708 .636 .775 r
.38813 .49421 m .38657 .49418 L .38383 .48866 L p F P
0 g
s
.829 .746 .772 r
.09926 .34321 m .1043 .33727 L .10071 .33343 L p F P
0 g
s
.711 .638 .773 r
.38657 .49418 m .38383 .48866 L .37599 .49383 L closepath p F P
0 g
s
.883 .659 .595 r
.08247 .43599 m .08718 .43884 L .08596 .44433 L p F P
0 g
s
.878 .671 .62 r
.08718 .43884 m .08247 .43599 L .0841 .43039 L p F P
0 g
s
.524 .488 .759 r
.70415 .35189 m .71553 .35355 L .71254 .34512 L p F P
0 g
s
.524 .488 .759 r
.71254 .34512 m .71247 .34511 L .70415 .35189 L p F P
0 g
s
.533 .502 .767 r
.7007 .34376 m .71247 .34511 L .70415 .35189 L p F P
0 g
s
0 .385 .735 r
.15883 .50962 m .15843 .50947 L .15958 .50997 L closepath p F P
0 g
s
.728 .667 .79 r
.32985 .501 m .33007 .50085 L .3395 .50206 L p F P
0 g
s
.718 .658 .789 r
.34097 .49337 m .33007 .50085 L .3395 .50206 L p F P
0 g
s
.718 .658 .789 r
.3395 .50206 m .34415 .49906 L .34097 .49337 L p F P
0 g
s
.667 .652 .825 r
.50398 .5051 m .50549 .50779 L .49312 .50996 L p F P
0 g
s
.667 .652 .825 r
.49312 .50996 m .49276 .50935 L .50398 .5051 L p F P
0 g
s
.557 0 0 r
.27284 .27129 m .26841 .26899 L .27131 .27018 L closepath p F P
0 g
s
.698 .634 .781 r
.4155 .4941 m .41544 .49398 L .41522 .49411 L closepath p F P
0 g
s
.699 .636 .783 r
.41234 .48746 m .41544 .49398 L .41522 .49411 L p F P
0 g
s
.699 .634 .781 r
.42659 .4875 m .42942 .49353 L .4155 .4941 L p F P
0 g
s
.699 .634 .781 r
.4155 .4941 m .41544 .49398 L .42659 .4875 L p F P
0 g
s
.68 .637 .799 r
.46141 .50188 m .46122 .50152 L .46018 .502 L closepath p F P
0 g
s
.679 .634 .797 r
.45815 .49531 m .46122 .50152 L .46018 .502 L p F P
0 g
s
.696 .618 .765 r
.42659 .4875 m .41544 .49398 L .41234 .48746 L p F P
0 g
s
.562 .558 .808 r
.67632 .31227 m .67436 .30785 L .68169 .30767 L closepath p F P
0 g
s
.79 .316 .103 r
.12563 .49255 m .12138 .4906 L .12437 .49086 L closepath p F P
0 g
s
.639 .45 .612 r
.45798 .32013 m .46084 .31965 L .46151 .32554 L p F P
0 g
s
.639 .45 .612 r
.46151 .32554 m .45235 .32705 L .45798 .32013 L p F P
0 g
s
.871 .706 .675 r
.07752 .40409 m .08197 .40708 L .07929 .41301 L p F P
0 g
s
.865 .711 .689 r
.07938 .40038 m .07752 .40409 L .08197 .40708 L p F P
0 g
s
.76 .753 .846 r
.17732 .2719 m .17155 .27593 L .16803 .27221 L p F P
0 g
s
.491 .901 .906 r
.64401 .50844 m .6383 .51072 L .63556 .5104 L p F P
0 g
s
.516 .905 .939 r
.62414 .51442 m .63556 .5104 L .6383 .51072 L p F P
0 g
s
.545 .516 .774 r
.69524 .33589 m .69776 .33605 L p .70025 .34372 L F P
0 g
s
.543 .517 .776 r
.69776 .33605 m .69524 .33589 L .69712 .33439 L closepath p F P
0 g
s
.549 .527 .783 r
.69482 .32862 m .69712 .33439 L .69524 .33589 L p F P
0 g
s
.678 .636 .8 r
.4724 .49642 m .47435 .50031 L .46141 .50188 L p F P
0 g
s
.678 .636 .8 r
.46141 .50188 m .46122 .50152 L .4724 .49642 L p F P
0 g
s
.716 .644 .776 r
.35843 .49737 m .3646 .49321 L .37147 .4936 L p F P
0 g
s
.72 .652 .782 r
.35843 .49737 m .3646 .49321 L .35583 .49252 L closepath p F P
0 g
s
.593 .609 .838 r
.63709 .28052 m .63669 .27975 L .63826 .27954 L closepath p F P
0 g
s
.73 .693 .815 r
.30447 .51007 m .30512 .50966 L .30404 .50945 L closepath p F P
0 g
s
.724 .689 .816 r
.30404 .50945 m .30447 .51007 L p .29016 .51201 L F P
0 g
s
.467 .739 .987 r
.18913 .51764 m .19037 .51763 L .18682 .51511 L p F P
0 g
s
.467 .739 .987 r
.18682 .51511 m .1833 .51529 L .18913 .51764 L p F P
0 g
s
.538 .505 .767 r
.7007 .34376 m .70025 .34372 L .70059 .34345 L closepath p F P
0 g
s
.545 .516 .774 r
.69776 .33605 m .70059 .34345 L .70025 .34372 L p F P
0 g
s
.812 .549 .54 r
.30774 .29548 m .31019 .29629 L .30994 .30136 L p F P
0 g
s
.802 .54 .541 r
.31708 .30347 m .30994 .30136 L .31019 .29629 L p F P
0 g
s
.665 .634 .808 r
.50398 .5051 m .49276 .50935 L .48972 .50372 L p F P
0 g
s
.722 .747 .872 r
.19836 .26434 m .197 .26508 L .19351 .26139 L p F P
0 g
s
.746 .751 .856 r
.18255 .2683 m .19351 .26139 L .197 .26508 L p F P
0 g
s
.685 .503 .635 r
.42438 .34281 m .42384 .33943 L .42138 .34297 L closepath p F P
0 g
s
.676 .62 .785 r
.4724 .49642 m .46122 .50152 L .45815 .49531 L p F P
0 g
s
.702 .524 .644 r
.39617 .34365 m .4061 .34359 L .4017 .35012 L p F P
0 g
s
.702 .524 .644 r
.4017 .35012 m .39734 .35014 L .39617 .34365 L p F P
0 g
s
.712 .53 .642 r
.39275 .34358 m .39617 .34365 L .39734 .35014 L p F P
0 g
s
.73 .692 .814 r
.31257 .49833 m .31554 .50307 L .30512 .50966 L p F P
0 g
s
.73 .692 .814 r
.31183 .49822 m .31257 .49833 L p .30512 .50966 L F P
0 g
s
.73 .692 .814 r
.30121 .50528 m .31183 .49822 L p .30512 .50966 L F P
0 g
s
.73 .692 .814 r
.30512 .50966 m .30404 .50945 L .30121 .50528 L p F P
0 g
s
.873 .53 .398 r
.10019 .47175 m .10304 .47012 L p .10563 .47579 L F P
0 g
s
.882 .554 .424 r
.10019 .47175 m .09965 .46826 L .10304 .47012 L closepath p F P
0 g
s
.828 .483 .404 r
.2885 .28078 m .28887 .28038 L p .29582 .28709 L F P
0 g
s
.8 .419 .336 r
.2885 .28078 m .28821 .28016 L .28887 .28038 L closepath p F P
0 g
s
.714 .643 .777 r
.38151 .48382 m .38383 .48866 L .37599 .49383 L p F P
0 g
s
.714 .643 .777 r
.37846 .4837 m .38151 .48382 L p .37599 .49383 L F P
0 g
s
.714 .643 .777 r
.36956 .48987 m .37846 .4837 L p .37599 .49383 L F P
0 g
s
.714 .643 .777 r
.37599 .49383 m .37147 .4936 L .36956 .48987 L p F P
0 g
s
.629 .864 .987 r
.60992 .51671 m .61136 .51753 L .62212 .51349 L p F P
0 g
s
.626 .879 .988 r
.62414 .51442 m .62212 .51349 L .61136 .51753 L p F P
0 g
s
.699 .52 .642 r
.4061 .34359 m .41055 .34352 L .41168 .34996 L p F P
0 g
s
.699 .52 .642 r
.41168 .34996 m .4017 .35012 L .4061 .34359 L p F P
0 g
s
.712 .53 .642 r
.39734 .35014 m .38879 .34996 L .39275 .34358 L p F P
0 g
s
.717 .538 .646 r
.38117 .34314 m .39275 .34358 L .38879 .34996 L p F P
0 g
s
.717 .53 .636 r
.39275 .34358 m .38117 .34314 L .38107 .34255 L p F P
0 g
s
.398 .213 .51 r
.71341 .4504 m .70712 .45426 L .70728 .4594 L p F P
0 g
s
.425 .26 .552 r
.70712 .45426 m .71341 .4504 L .71231 .44538 L p F P
0 g
s
.687 .512 .644 r
.41055 .34352 m .42138 .34297 L .41629 .34973 L p F P
0 g
s
.687 .512 .644 r
.41629 .34973 m .41168 .34996 L .41055 .34352 L p F P
0 g
s
.607 .638 .855 r
.62554 .26985 m .61939 .27097 L .61649 .26592 L p F P
0 g
s
.531 .501 .768 r
.71247 .34511 m .7007 .34376 L .70059 .34345 L p F P
0 g
s
0 0 0 r
.52428 .27232 m .53037 .26954 L .53087 .26914 L closepath p F P
0 g
s
.254 0 .109 r
.52428 .27232 m .53037 .26954 L p .51838 .27746 L F P
0 g
s
.593 .614 .842 r
.63826 .27954 m .63669 .27975 L .63379 .27432 L p F P
0 g
s
.485 .403 .689 r
.71831 .3988 m .72584 .39326 L p .72316 .40344 L F P
0 g
s
.485 .403 .689 r
.72316 .40344 m .71897 .40146 L .71831 .3988 L p F P
0 g
s
.494 .42 .702 r
.71831 .3988 m .72584 .39326 L .71824 .39029 L p F P
0 g
s
.639 .458 .622 r
.44928 .33032 m .45235 .32705 L .44894 .32764 L closepath p F P
0 g
s
.655 .472 .624 r
.44894 .32764 m .44928 .33032 L .44623 .33414 L p F P
0 g
s
.531 .501 .768 r
.70059 .34345 m .70837 .33697 L p .71247 .34511 L F P
0 g
s
.536 .512 .777 r
.70059 .34345 m .69776 .33605 L .70837 .33697 L closepath p F P
0 g
s
0 .455 .807 r
.15843 .50947 m .15883 .50962 L .15517 .50776 L p F P
0 g
s
0 .455 .807 r
.15517 .50776 m .15286 .50702 L .15843 .50947 L p F P
0 g
s
.688 .622 .776 r
.44303 .49263 m .44391 .49452 L p .42968 .49407 L F P
0 g
s
.688 .622 .776 r
.42968 .49407 m .43083 .49344 L .44303 .49263 L p F P
0 g
s
.688 .621 .776 r
.42968 .49407 m .43083 .49344 L .42942 .49353 L closepath p F P
0 g
s
.724 .689 .816 r
.29016 .51201 m .29632 .50825 L .30404 .50945 L p F P
0 g
s
.723 .69 .818 r
.30404 .50945 m .30121 .50528 L .29632 .50825 L closepath p F P
0 g
s
.88 .675 .62 r
.07947 .42749 m .0841 .43039 L .08247 .43599 L p F P
0 g
s
.875 .684 .641 r
.0841 .43039 m .07947 .42749 L .08148 .42177 L p F P
0 g
s
.815 .452 .369 r
.28821 .28016 m .2885 .28078 L .28657 .28336 L p F P
0 g
s
.815 .452 .369 r
.28174 .27779 m .28821 .28016 L p .28657 .28336 L F P
0 g
s
.722 .747 .872 r
.19351 .26139 m .19374 .26127 L .19836 .26434 L p F P
0 g
s
.725 .752 .874 r
.20441 .25555 m .19374 .26127 L .19836 .26434 L p F P
0 g
s
.725 .752 .874 r
.19836 .26434 m .20789 .25916 L .20441 .25555 L p F P
0 g
s
.736 .546 .636 r
.3697 .34235 m .36551 .34196 L .36438 .33549 L p F P
0 g
s
.739 .548 .635 r
.36239 .33528 m .36438 .33549 L .36551 .34196 L p F P
0 g
s
.776 .563 .612 r
.3306 .31796 m .33886 .31967 L .33699 .32533 L p F P
0 g
s
.753 .544 .612 r
.33886 .31967 m .33699 .32533 L .34588 .32683 L p F P
0 g
s
.716 .644 .776 r
.37147 .4936 m .36956 .48987 L .3646 .49321 L closepath p F P
0 g
s
.623 .439 .612 r
.46151 .32554 m .46084 .31965 L .47302 .31711 L p F P
0 g
s
.618 .423 .595 r
.47255 .31146 m .47302 .31711 L .46084 .31965 L p F P
0 g
s
.344 .104 .399 r
.69746 .47007 m .69766 .46975 L .69748 .46985 L closepath p F P
0 g
s
.54 0 0 r
.14063 .50146 m .14144 .50206 L .13771 .50062 L p F P
0 g
s
.54 0 0 r
.13771 .50062 m .13521 .49893 L .14063 .50146 L p F P
0 g
s
.831 .392 .19 r
.12138 .4906 m .1202 .49001 L .11771 .48564 L p F P
0 g
s
.829 .384 .17 r
.11251 .48302 m .11771 .48564 L .1202 .49001 L p F P
0 g
s
.755 .545 .613 r
.34673 .32696 m .34649 .32508 L .34588 .32683 L closepath p F P
0 g
s
.688 .62 .775 r
.43083 .49344 m .42942 .49353 L .42659 .4875 L p F P
0 g
s
.725 .649 .773 r
.35395 .49237 m .34415 .49906 L .34097 .49337 L p F P
0 g
s
.657 .479 .633 r
.43681 .33539 m .44623 .33414 L .43989 .34131 L p F P
0 g
s
.657 .479 .633 r
.43989 .34131 m .43775 .34159 L .43681 .33539 L p F P
0 g
s
.677 .498 .636 r
.43681 .33539 m .43775 .34159 L .42438 .34281 L p F P
0 g
s
.724 .535 .635 r
.38117 .34314 m .38107 .34255 L .38077 .34312 L closepath p F P
0 g
s
.7 .725 .87 r
.26288 .5172 m .26153 .51565 L .25948 .51659 L closepath p F P
0 g
s
.305 .061 .37 r
.69766 .46975 m .70715 .46423 L p .697 .47429 L F P
0 g
s
.305 .061 .37 r
.697 .47429 m .69746 .47007 L .69766 .46975 L p F P
0 g
s
.377 .163 .457 r
.69766 .46975 m .70715 .46423 L .70728 .4594 L p F P
0 g
s
.655 .696 .876 r
.53856 .5174 m .54986 .51392 L .55283 .51807 L p F P
0 g
s
.653 .677 .86 r
.54984 .5139 m .54986 .51392 L .53856 .5174 L p F P
0 g
s
.653 .677 .86 r
.53856 .5174 m .53825 .51693 L .54984 .5139 L p F P
0 g
s
.832 .745 .768 r
.0951 .34004 m .09926 .34321 L .09355 .35012 L p F P
0 g
s
.829 .746 .772 r
.10071 .33343 m .0951 .34004 L .09926 .34321 L p F P
0 g
s
.688 .621 .775 r
.44303 .49263 m .44083 .48795 L .43083 .49344 L closepath p F P
0 g
s
.688 .62 .775 r
.43848 .48271 m .44083 .48795 L .43083 .49344 L p F P
0 g
s
.688 .62 .775 r
.43453 .48295 m .43848 .48271 L p .43083 .49344 L F P
0 g
s
.688 .62 .775 r
.42659 .4875 m .43453 .48295 L p .43083 .49344 L F P
0 g
s
.739 .548 .635 r
.36551 .34196 m .35943 .34132 L .36239 .33528 L p F P
0 g
s
.749 .554 .632 r
.35262 .33408 m .36239 .33528 L .35943 .34132 L p F P
0 g
s
.344 .092 .381 r
.693 .47648 m .697 .47429 L .69746 .47007 L closepath p F P
0 g
s
.027 .545 .866 r
.17275 .51321 m .16914 .51093 L .15883 .50962 L p F P
0 g
s
.327 .683 .979 r
.15883 .50962 m .16914 .51093 L .16694 .50946 L p F P
0 g
s
.327 .683 .979 r
.15517 .50776 m .15883 .50962 L p .16694 .50946 L F P
0 g
s
.733 .695 .814 r
.29632 .50825 m .29016 .51201 L .28687 .50751 L p F P
0 g
s
.722 .702 .83 r
.27585 .5139 m .28687 .50751 L .29016 .51201 L p F P
0 g
s
.717 .538 .646 r
.38879 .34996 m .38242 .34972 L .38117 .34314 L p F P
0 g
s
.724 .542 .644 r
.38077 .34312 m .38117 .34314 L .38242 .34972 L p F P
0 g
s
.732 .55 .646 r
.3697 .34235 m .38077 .34312 L .37707 .34941 L p F P
0 g
s
.724 .542 .644 r
.38242 .34972 m .37707 .34941 L .38077 .34312 L p F P
0 g
s
.601 .752 .95 r
.20099 .51579 m .19037 .51763 L .18682 .51511 L p F P
0 g
s
.517 .766 .987 r
.2045 .51863 m .20099 .51579 L .19037 .51763 L p F P
0 g
s
.622 .659 .865 r
.60244 .26402 m .60214 .26352 L .60347 .26322 L closepath p F P
0 g
s
.572 .574 .817 r
.66855 .29511 m .66029 .29564 L .66637 .29045 L closepath p F P
0 g
s
.577 .584 .824 r
.66565 .28894 m .66637 .29045 L .66029 .29564 L p F P
0 g
s
.577 .584 .824 r
.65404 .28992 m .66565 .28894 L p .66029 .29564 L F P
0 g
s
.599 .407 .593 r
.47302 .31711 m .47255 .31146 L .48434 .30844 L p F P
0 g
s
.591 .386 .571 r
.48407 .30305 m .48434 .30844 L .47255 .31146 L p F P
0 g
s
.76 .753 .846 r
.16803 .27221 m .17311 .26869 L .17732 .2719 L p F P
0 g
s
.76 .754 .847 r
.17905 .26462 m .17311 .26869 L .17732 .2719 L p F P
0 g
s
.76 .754 .847 r
.17732 .2719 m .18255 .2683 L .17905 .26462 L p F P
0 g
s
.486 .403 .688 r
.72002 .40571 m .71897 .40146 L .72316 .40344 L closepath p F P
0 g
s
.782 .557 .595 r
.3306 .31796 m .32804 .31735 L .32744 .31143 L p F P
0 g
s
.776 .553 .596 r
.32396 .31067 m .32744 .31143 L .32804 .31735 L p F P
0 g
s
.786 .546 .572 r
.32396 .31067 m .31625 .30876 L .31708 .30347 L p F P
0 g
s
.803 .56 .571 r
.30994 .30136 m .31708 .30347 L .31625 .30876 L p F P
0 g
s
.857 .726 .718 r
.07916 .37949 m .08348 .38255 L .07969 .38883 L p F P
0 g
s
.853 .729 .726 r
.08348 .38255 m .07916 .37949 L .08323 .37311 L p F P
0 g
s
.686 .51 .643 r
.42138 .34297 m .42438 .34281 L .42551 .34923 L p F P
0 g
s
.686 .51 .643 r
.42551 .34923 m .41629 .34973 L .42138 .34297 L p F P
0 g
s
.72 .651 .781 r
.36642 .48355 m .36956 .48987 L .3646 .49321 L p F P
0 g
s
.72 .651 .781 r
.35527 .49147 m .36642 .48355 L p .3646 .49321 L F P
0 g
s
.72 .651 .781 r
.3646 .49321 m .35583 .49252 L .35527 .49147 L p F P
0 g
s
.655 .677 .859 r
.54688 .50933 m .54984 .5139 L .53825 .51693 L p F P
0 g
s
.655 .677 .859 r
.53825 .51693 m .53557 .51287 L .54688 .50933 L p F P
0 g
s
.812 .549 .54 r
.30994 .30136 m .30752 .30057 L .30774 .29548 L p F P
0 g
s
.8 .537 .541 r
.30311 .29415 m .30774 .29548 L .30752 .30057 L p F P
0 g
s
.828 .483 .404 r
.29582 .28709 m .28958 .28465 L .2885 .28078 L p F P
0 g
s
.839 .49 .393 r
.28958 .28465 m .28657 .28336 L .2885 .28078 L closepath p F P
0 g
s
.644 .464 .626 r
.45235 .32705 m .46151 .32554 L p .44975 .33369 L F P
0 g
s
.644 .464 .626 r
.44975 .33369 m .44928 .33032 L .45235 .32705 L p F P
0 g
s
.847 .736 .741 r
.08777 .36659 m .08452 .37123 L .08092 .36718 L p F P
0 g
s
.847 .736 .741 r
.08092 .36718 m .08351 .36348 L .08777 .36659 L p F P
0 g
s
.842 .738 .748 r
.08777 .36659 m .08351 .36348 L .08839 .35685 L p F P
0 g
s
.492 .421 .705 r
.72539 .38493 m .71824 .39029 L .72584 .39326 L p F P
0 g
s
.503 .437 .716 r
.72469 .3825 m .72539 .38493 L .71824 .39029 L p F P
0 g
s
.503 .437 .716 r
.71905 .38067 m .72469 .3825 L p .71824 .39029 L F P
0 g
s
.623 .67 .875 r
.60347 .26322 m .60214 .26352 L .59923 .25901 L p F P
0 g
s
.474 .37 .656 r
.72229 .41609 m .71922 .41399 L .72154 .41241 L closepath p F P
0 g
s
.486 .391 .673 r
.71922 .41399 m .72154 .41241 L .72002 .40571 L p F P
0 g
s
.672 .501 .645 r
.42438 .34281 m .43775 .34159 L p .43354 .34848 L F P
0 g
s
.672 .501 .645 r
.43354 .34848 m .42551 .34923 L .42438 .34281 L p F P
0 g
s
.588 .603 .835 r
.64824 .2783 m .63826 .27954 L .64564 .27323 L closepath p F P
0 g
s
.593 .614 .842 r
.64534 .27265 m .64564 .27323 L .63826 .27954 L p F P
0 g
s
.593 .614 .842 r
.63379 .27432 m .64534 .27265 L p .63826 .27954 L F P
0 g
s
.561 .559 .808 r
.68169 .30767 m .67436 .30785 L .6716 .30168 L p F P
0 g
s
.682 .621 .78 r
.4563 .49139 m .45815 .49531 L p .44391 .49452 L F P
0 g
s
.682 .621 .78 r
.44391 .49452 m .44869 .49209 L .4563 .49139 L p F P
0 g
s
.681 .618 .778 r
.44391 .49452 m .44869 .49209 L .44303 .49263 L closepath p F P
0 g
s
.755 .555 .626 r
.35262 .33408 m .34778 .33334 L .34673 .32696 L p F P
0 g
s
.755 .555 .626 r
.34588 .32683 m .34673 .32696 L .34778 .33334 L p F P
0 g
s
.794 .755 .816 r
.13928 .2952 m .1347 .29922 L .13113 .29552 L p F P
0 g
s
.801 .755 .81 r
.13036 .30321 m .1347 .29922 L .13113 .29552 L p F P
0 g
s
.803 .754 .808 r
.13036 .30321 m .12346 .30967 L .11988 .30597 L p F P
0 g
s
.803 .754 .808 r
.11988 .30597 m .12629 .29996 L .13036 .30321 L p F P
0 g
s
.801 .755 .81 r
.13113 .29552 m .12629 .29996 L .13036 .30321 L p F P
0 g
s
.671 .633 .803 r
.48696 .49837 m .48972 .50372 L p .47546 .50252 L F P
0 g
s
.671 .633 .803 r
.47546 .50252 m .48448 .49873 L .48696 .49837 L p F P
0 g
s
.668 .625 .796 r
.47546 .50252 m .48448 .49873 L .47435 .50031 L closepath p F P
0 g
s
.634 .952 .939 r
.54214 .26343 m .54406 .26361 L .55365 .25783 L p F P
0 g
s
.647 .911 .98 r
.55637 .25939 m .55365 .25783 L .54406 .26361 L p F P
0 g
s
.729 .669 .791 r
.32985 .501 m .33007 .50085 L .32974 .50081 L closepath p F P
0 g
s
.727 .667 .791 r
.32974 .50081 m .32985 .501 L p .31554 .50307 L F P
0 g
s
.661 .653 .832 r
.50702 .5105 m .51827 .50655 L .52129 .5117 L p F P
0 g
s
.66 .643 .823 r
.51758 .50529 m .51827 .50655 L .50702 .5105 L p F P
0 g
s
.66 .643 .823 r
.50702 .5105 m .50549 .50779 L .51758 .50529 L p F P
0 g
s
.878 .688 .642 r
.07692 .41884 m .08148 .42177 L .07947 .42749 L p F P
0 g
s
.873 .696 .659 r
.08148 .42177 m .07692 .41884 L .07929 .41301 L p F P
0 g
s
.865 .714 .693 r
.0806 .39804 m .07938 .40038 L .07585 .39563 L p F P
0 g
s
.865 .714 .693 r
.07585 .39563 m .07616 .39503 L .0806 .39804 L p F P
0 g
s
.859 .719 .707 r
.0806 .39804 m .07616 .39503 L .07969 .38883 L p F P
0 g
s
.73 .669 .79 r
.33966 .49094 m .34097 .49337 L .33007 .50085 L p F P
0 g
s
.73 .669 .79 r
.33387 .4903 m .33966 .49094 L p .33007 .50085 L F P
0 g
s
.73 .669 .79 r
.32665 .49552 m .33387 .4903 L p .33007 .50085 L F P
0 g
s
.73 .669 .79 r
.33007 .50085 m .32974 .50081 L .32665 .49552 L p F P
0 g
s
.808 .754 .802 r
.12211 .31098 m .12346 .30967 L .11988 .30597 L p F P
0 g
s
.576 .586 .825 r
.66275 .28298 m .66565 .28894 L .65404 .28992 L p F P
0 g
s
.576 .586 .825 r
.65474 .28366 m .66275 .28298 L p .65404 .28992 L F P
0 g
s
.576 .586 .825 r
.65404 .28992 m .65211 .28597 L .65474 .28366 L p F P
0 g
s
.794 .755 .816 r
.13113 .29552 m .13519 .29195 L .13928 .2952 L p F P
0 g
s
.792 .755 .819 r
.14231 .28582 m .13519 .29195 L .13928 .2952 L p F P
0 g
s
.792 .755 .819 r
.13928 .2952 m .14587 .28951 L .14231 .28582 L p F P
0 g
s
.755 .555 .626 r
.34778 .33334 m .34346 .33268 L .34588 .32683 L p F P
0 g
s
.764 .561 .622 r
.33699 .32533 m .34588 .32683 L .34346 .33268 L p F P
0 g
s
.727 .667 .791 r
.31554 .50307 m .32054 .49966 L .32974 .50081 L p F P
0 g
s
.727 .668 .792 r
.32974 .50081 m .32665 .49552 L .32054 .49966 L closepath p F P
0 g
s
0 0 0 r
.67372 .4929 m .67494 .4923 L p .6627 .49992 L F P
0 g
s
.16 0 .037 r
.67372 .4929 m .67494 .4923 L .67509 .492 L closepath p F P
0 g
s
.812 .753 .798 r
.11805 .30774 m .12211 .31098 L .11461 .3185 L p F P
0 g
s
.808 .754 .802 r
.11988 .30597 m .11805 .30774 L .12211 .31098 L p F P
0 g
s
.656 .473 .625 r
.44975 .33369 m .44928 .33032 L .44623 .33414 L closepath p F P
0 g
s
.57 .368 .568 r
.48434 .30844 m .48407 .30305 L .49549 .29958 L p F P
0 g
s
.556 .334 .534 r
.49548 .2945 m .49549 .29958 L .48407 .30305 L p F P
0 g
s
.711 .725 .861 r
.24723 .51711 m .25177 .51484 L .25948 .51659 L p F P
0 g
s
.698 .718 .865 r
.25818 .51166 m .25177 .51484 L .25948 .51659 L p F P
0 g
s
.698 .718 .865 r
.25948 .51659 m .26153 .51565 L .25818 .51166 L p F P
0 g
s
.727 .695 .82 r
.28687 .50751 m .27585 .5139 L .27253 .50965 L p F P
0 g
s
.305 0 0 r
.14728 .50455 m .14144 .50206 L .13771 .50062 L p F P
0 g
s
0 .313 .666 r
.15286 .50702 m .14728 .50455 L .14144 .50206 L p F P
0 g
s
.421 .258 .552 r
.71621 .44295 m .71231 .44538 L .71341 .4504 L p F P
0 g
s
.443 .296 .586 r
.71231 .44538 m .71621 .44295 L .71554 .43724 L p F P
0 g
s
.702 .622 .764 r
.41079 .48405 m .41234 .48746 L p .39809 .48784 L F P
0 g
s
.702 .622 .764 r
.39809 .48784 m .40389 .48412 L .41079 .48405 L p F P
0 g
s
.704 .625 .767 r
.39809 .48784 m .40389 .48412 L .39637 .48415 L closepath p F P
0 g
s
.71 .632 .768 r
.38383 .48866 m .39067 .48406 L .38151 .48382 L closepath p F P
0 g
s
.536 .513 .777 r
.70837 .33697 m .69776 .33605 L .69712 .33439 L p F P
0 g
s
.785 .321 .14 r
.28174 .27779 m .27574 .27524 L .27284 .27129 L p F P
0 g
s
.811 .359 .163 r
.26841 .26899 m .27284 .27129 L .27574 .27524 L p F P
0 g
s
.83 .533 .488 r
.28958 .28465 m .29582 .28709 L .29629 .29191 L p F P
0 g
s
.813 .516 .488 r
.30311 .29415 m .29629 .29191 L .29582 .28709 L p F P
0 g
s
.653 .715 .894 r
.55283 .51807 m .56416 .51471 L .56711 .51848 L p F P
0 g
s
.652 .696 .878 r
.56416 .51471 m .55283 .51807 L .54986 .51392 L p F P
0 g
s
.104 0 .012 r
.67494 .4923 m .67509 .492 L .6857 .484 L p F P
0 g
s
.785 .755 .826 r
.14907 .28688 m .14587 .28951 L .14231 .28582 L p F P
0 g
s
.475 .384 .673 r
.72316 .40344 m .72002 .40571 L .72154 .41241 L p F P
0 g
s
.746 .754 .859 r
.19351 .26139 m .18255 .2683 L .17905 .26462 L p F P
0 g
s
.732 .55 .646 r
.36666 .34798 m .3697 .34235 L p .37707 .34941 L F P
0 g
s
.736 .551 .642 r
.36666 .34798 m .3697 .34235 L .36551 .34196 L closepath p F P
0 g
s
.681 .617 .778 r
.44869 .49209 m .44303 .49263 L .44083 .48795 L p F P
0 g
s
.697 .619 .766 r
.41234 .48746 m .41835 .4838 L .41079 .48405 L closepath p F P
0 g
s
.696 .618 .765 r
.42481 .48356 m .42659 .4875 L p .41234 .48746 L F P
0 g
s
.696 .618 .765 r
.41234 .48746 m .41835 .4838 L .42481 .48356 L p F P
0 g
s
.427 .869 .819 r
.64401 .50844 m .6492 .50617 L .64972 .50608 L closepath p F P
0 g
s
.491 .901 .906 r
.6492 .50617 m .64401 .50844 L p .63556 .5104 L F P
0 g
s
.62 .656 .864 r
.61358 .26099 m .60347 .26322 L .61117 .25702 L closepath p F P
0 g
s
.623 .67 .875 r
.61068 .25622 m .61117 .25702 L .60347 .26322 L p F P
0 g
s
.623 .67 .875 r
.59923 .25901 m .61068 .25622 L p .60347 .26322 L F P
0 g
s
.449 .319 .612 r
.71554 .43724 m .72154 .43328 L .71818 .42896 L p F P
0 g
s
.431 .287 .584 r
.72154 .43328 m .71554 .43724 L .71621 .44295 L p F P
0 g
s
.718 .631 .76 r
.37846 .4837 m .36956 .48987 L .36642 .48355 L p F P
0 g
s
.776 .553 .596 r
.32804 .31735 m .32255 .31616 L .32396 .31067 L p F P
0 g
s
.788 .562 .594 r
.31625 .30876 m .32396 .31067 L .32255 .31616 L p F P
0 g
s
.628 .891 .987 r
.62212 .51349 m .62414 .51442 L .63556 .5104 L p F P
0 g
s
.541 .523 .785 r
.69712 .33439 m .69482 .32862 L .70328 .32914 L closepath p F P
0 g
s
.536 .513 .777 r
.69712 .33439 m .70328 .32914 L p .70837 .33697 L F P
0 g
s
.785 .755 .826 r
.14231 .28582 m .14497 .28363 L .14907 .28688 L p F P
0 g
s
.783 .755 .828 r
.15343 .27682 m .14497 .28363 L .14907 .28688 L p F P
0 g
s
.783 .755 .828 r
.14907 .28688 m .15698 .28051 L .15343 .27682 L p F P
0 g
s
.688 .143 0 r
.13521 .49893 m .12982 .49639 L .12563 .49255 L p F P
0 g
s
.664 .111 0 r
.12138 .4906 m .12563 .49255 L .12982 .49639 L p F P
0 g
s
.815 .752 .794 r
.11461 .3185 m .11214 .32105 L .10854 .31732 L p F P
0 g
s
.815 .752 .794 r
.10854 .31732 m .11052 .31528 L .11461 .3185 L p F P
0 g
s
.812 .753 .798 r
.11461 .3185 m .11052 .31528 L .11805 .30774 L p F P
0 g
s
.703 .529 .65 r
.39827 .35494 m .4017 .35012 L .39734 .35014 L closepath p F P
0 g
s
.705 .531 .649 r
.39734 .35014 m .38879 .34996 L p .39702 .35674 L F P
0 g
s
.705 .531 .649 r
.39702 .35674 m .39827 .35494 L .39734 .35014 L p F P
0 g
s
.72 .652 .78 r
.35583 .49252 m .35527 .49147 L .35395 .49237 L closepath p F P
0 g
s
.837 .743 .76 r
.09355 .35012 m .09273 .35116 L .08912 .34727 L p F P
0 g
s
.837 .743 .76 r
.08912 .34727 m .08936 .34697 L .09355 .35012 L p F P
0 g
s
.832 .745 .768 r
.09355 .35012 m .08936 .34697 L .0951 .34004 L p F P
0 g
s
.7 .53 .654 r
.4017 .35012 m .41168 .34996 L p .41093 .35658 L F P
0 g
s
.7 .53 .654 r
.39827 .35494 m .4017 .35012 L p .41093 .35658 L F P
0 g
s
.637 .751 .931 r
.2045 .51863 m .21523 .51561 L .2187 .51875 L p F P
0 g
s
.654 .748 .919 r
.21523 .51561 m .2045 .51863 L .20099 .51579 L p F P
0 g
s
.722 .685 .814 r
.29795 .50035 m .28827 .5066 L .29632 .50825 L p F P
0 g
s
.722 .685 .814 r
.29632 .50825 m .30121 .50528 L .29795 .50035 L p F P
0 g
s
.733 .695 .814 r
.28687 .50751 m .28827 .5066 L .29632 .50825 L p F P
0 g
s
.668 .624 .796 r
.48448 .49873 m .47435 .50031 L .4724 .49642 L p F P
0 g
s
.724 .708 .835 r
.27253 .50965 m .26153 .51565 L .25818 .51166 L p F P
0 g
s
.82 .752 .789 r
.10765 .32584 m .11214 .32105 L .10854 .31732 L p F P
0 g
s
.725 .649 .773 r
.34097 .49337 m .34368 .49141 L .35395 .49237 L p F P
0 g
s
.717 .645 .776 r
.35212 .48533 m .34368 .49141 L .35395 .49237 L p F P
0 g
s
.717 .645 .776 r
.35395 .49237 m .35527 .49147 L .35212 .48533 L p F P
0 g
s
.658 .482 .635 r
.44623 .33414 m .44975 .33369 L .45072 .33993 L p F P
0 g
s
.658 .482 .635 r
.45072 .33993 m .43989 .34131 L .44623 .33414 L p F P
0 g
s
.688 .517 .65 r
.41253 .35447 m .41629 .34973 L .41168 .34996 L closepath p F P
0 g
s
.7 .53 .654 r
.41168 .34996 m .41253 .35447 L .41093 .35658 L p F P
0 g
s
.705 .531 .649 r
.38879 .34996 m .38458 .35643 L .39702 .35674 L p F P
0 g
s
.717 .541 .651 r
.38242 .34972 m .38879 .34996 L .38458 .35643 L p F P
0 g
s
.841 .743 .756 r
.08839 .35685 m .09273 .35116 L .08912 .34727 L p F P
0 g
s
.732 .68 .799 r
.31554 .50307 m .32054 .49966 L .31257 .49833 L closepath p F P
0 g
s
.749 .554 .632 r
.35943 .34132 m .34994 .34003 L .35262 .33408 L p F P
0 g
s
.755 .561 .634 r
.34778 .33334 m .35262 .33408 L .34994 .34003 L p F P
0 g
s
.228 0 .228 r
.693 .47648 m .697 .47429 L p .68631 .48369 L F P
0 g
s
.228 0 .228 r
.68631 .48369 m .68638 .48339 L .693 .47648 L p F P
0 g
s
0 0 0 r
.68491 .48715 m .67494 .4923 L .67286 .49503 L p F P
0 g
s
.104 0 .012 r
.68631 .48369 m .68491 .48715 L .67494 .4923 L p F P
0 g
s
.104 0 .012 r
.6857 .484 m .68631 .48369 L p .67494 .4923 L F P
0 g
s
0 0 0 r
.67494 .4923 m .67286 .49503 L .6627 .49992 L p F P
0 g
s
.532 .315 .531 r
.49549 .29958 m .49548 .2945 L .50652 .29057 L p F P
0 g
s
.505 .258 .474 r
.50686 .2859 m .50652 .29057 L .49548 .2945 L p F P
0 g
s
.733 .549 .643 r
.36551 .34196 m .35943 .34132 L p .36636 .34853 L F P
0 g
s
.733 .549 .643 r
.36636 .34853 m .36666 .34798 L .36551 .34196 L p F P
0 g
s
.675 .616 .782 r
.46923 .48978 m .46934 .49003 L .45815 .49531 L p F P
0 g
s
.675 .616 .782 r
.45815 .49531 m .4563 .49139 L .46923 .48978 L p F P
0 g
s
.676 .62 .785 r
.45815 .49531 m .46934 .49003 L .4724 .49642 L p F P
0 g
s
.867 .714 .689 r
.07752 .40409 m .07938 .40038 L .07585 .39563 L p F P
0 g
s
.447 .319 .613 r
.72396 .42508 m .71818 .42896 L .72154 .43328 L p F P
0 g
s
.462 .346 .635 r
.71818 .42896 m .72396 .42508 L .72286 .41887 L p F P
0 g
s
.689 .615 .767 r
.42659 .4875 m .43453 .48295 L .42481 .48356 L closepath p F P
0 g
s
.722 .635 .761 r
.36642 .48355 m .35527 .49147 L .35212 .48533 L p F P
0 g
s
.85 .736 .737 r
.08323 .37311 m .08452 .37123 L .08092 .36718 L p F P
0 g
s
.65 .742 .916 r
.56711 .51848 m .57847 .51516 L .58139 .51849 L p F P
0 g
s
.651 .716 .896 r
.57847 .51516 m .56711 .51848 L .56416 .51471 L p F P
0 g
s
.692 .523 .653 r
.41629 .34973 m .42551 .34923 L p .41293 .35653 L F P
0 g
s
.692 .523 .653 r
.41293 .35653 m .41253 .35447 L .41629 .34973 L p F P
0 g
s
.717 .541 .651 r
.38458 .35643 m .38376 .3564 L .38242 .34972 L p F P
0 g
s
.724 .546 .649 r
.37707 .34941 m .38242 .34972 L .38376 .3564 L p F P
0 g
s
.876 .699 .66 r
.07482 .41003 m .07929 .41301 L .07692 .41884 L p F P
0 g
s
.871 .706 .675 r
.07929 .41301 m .07482 .41003 L .07752 .40409 L p F P
0 g
s
.886 .59 .481 r
.09965 .46826 m .09473 .46552 L .09452 .46047 L p F P
0 g
s
.889 .592 .478 r
.08966 .45769 m .09452 .46047 L .09473 .46552 L p F P
0 g
s
.886 .618 .527 r
.09452 .46047 m .08966 .45769 L .08996 .45249 L p F P
0 g
s
.682 .619 .779 r
.4563 .49139 m .45508 .48881 L .44869 .49209 L closepath p F P
0 g
s
.681 .617 .778 r
.45201 .48199 m .45508 .48881 L .44869 .49209 L p F P
0 g
s
.681 .617 .778 r
.44083 .48795 m .45201 .48199 L p .44869 .49209 L F P
0 g
s
.773 .755 .836 r
.16012 .27813 m .15698 .28051 L .15343 .27682 L p F P
0 g
s
.721 .73 .858 r
.25177 .51484 m .24723 .51711 L .24384 .51342 L p F P
0 g
s
.695 .733 .88 r
.23295 .51818 m .24384 .51342 L .24723 .51711 L p F P
0 g
s
.704 .625 .766 r
.40389 .48412 m .39637 .48415 L .39498 .48117 L p F P
0 g
s
.708 .627 .764 r
.39637 .48415 m .39498 .48117 L .39067 .48406 L closepath p F P
0 g
s
.889 .621 .526 r
.08517 .44968 m .08996 .45249 L .08966 .45769 L p F P
0 g
s
.885 .641 .565 r
.08996 .45249 m .08517 .44968 L .08596 .44433 L p F P
0 g
s
.702 .621 .764 r
.41079 .48405 m .40925 .48067 L .40389 .48412 L closepath p F P
0 g
s
.704 .625 .766 r
.4065 .47441 m .40925 .48067 L .40389 .48412 L p F P
0 g
s
.704 .625 .766 r
.40496 .47441 m .4065 .47441 L p .40389 .48412 L F P
0 g
s
.704 .625 .766 r
.39498 .48117 m .40496 .47441 L p .40389 .48412 L F P
0 g
s
.674 .743 .903 r
.2187 .51875 m .22952 .51476 L .23295 .51818 L p F P
0 g
s
.685 .74 .892 r
.22952 .51476 m .2187 .51875 L .21523 .51561 L p F P
0 g
s
.776 .563 .612 r
.3289 .32349 m .3306 .31796 L p .33699 .32533 L F P
0 g
s
.781 .567 .61 r
.3289 .32349 m .3306 .31796 L .32804 .31735 L closepath p F P
0 g
s
.665 .634 .808 r
.48972 .50372 m .50095 .49934 L .50398 .5051 L p F P
0 g
s
.665 .628 .803 r
.49939 .49623 m .50095 .49934 L .48972 .50372 L p F P
0 g
s
.665 .628 .803 r
.48972 .50372 m .48696 .49837 L .49939 .49623 L p F P
0 g
s
0 0 0 r
.66115 .50095 m .6627 .49992 L .67286 .49503 L p F P
0 g
s
0 0 0 r
.64972 .50608 m .66115 .50095 L .6627 .49992 L p F P
0 g
s
.819 .752 .789 r
.10358 .32261 m .10765 .32584 L .10104 .33305 L p F P
0 g
s
.82 .752 .789 r
.10854 .31732 m .10358 .32261 L .10765 .32584 L p F P
0 g
s
.886 .554 .416 r
.09965 .46826 m .10019 .47175 L .09891 .47228 L p F P
0 g
s
.886 .554 .416 r
.09473 .46552 m .09965 .46826 L p .09891 .47228 L F P
0 g
s
.657 .662 .843 r
.52129 .5117 m .53256 .50797 L .53557 .51287 L p F P
0 g
s
.657 .649 .83 r
.53256 .50797 m .52129 .5117 L .51827 .50655 L p F P
0 g
s
.711 .631 .767 r
.39194 .47437 m .39498 .48117 L .39067 .48406 L p F P
0 g
s
.711 .631 .767 r
.3917 .47437 m .39194 .47437 L p .39067 .48406 L F P
0 g
s
.711 .631 .767 r
.38071 .48214 m .3917 .47437 L p .39067 .48406 L F P
0 g
s
.711 .631 .767 r
.39067 .48406 m .38151 .48382 L .38071 .48214 L p F P
0 g
s
.8 .537 .541 r
.30752 .30057 m .30285 .29923 L .30311 .29415 L p F P
0 g
s
.813 .549 .539 r
.29629 .29191 m .30311 .29415 L .30285 .29923 L p F P
0 g
s
.697 .619 .766 r
.41835 .4838 m .41079 .48405 L .40925 .48067 L p F P
0 g
s
.662 .644 .822 r
.51524 .50101 m .51758 .50529 L .50549 .50779 L p F P
0 g
s
.662 .644 .822 r
.50549 .50779 m .50398 .5051 L .51524 .50101 L p F P
0 g
s
.644 .472 .636 r
.45072 .33993 m .44975 .33369 L .46231 .33158 L p F P
0 g
s
.644 .464 .626 r
.46151 .32554 m .46231 .33158 L .44975 .33369 L p F P
0 g
s
.658 .487 .642 r
.43803 .34326 m .43989 .34131 L .43775 .34159 L closepath p F P
0 g
s
.672 .501 .645 r
.43775 .34159 m .43803 .34326 L .43354 .34848 L p F P
0 g
s
.704 .728 .869 r
.24384 .51342 m .23295 .51818 L .22952 .51476 L p F P
0 g
s
.275 0 .245 r
.6857 .484 m .68631 .48369 L .68638 .48339 L closepath p F P
0 g
s
.634 .751 .932 r
.22219 .25791 m .23293 .2548 L .23639 .25806 L p F P
0 g
s
.623 .748 .937 r
.23293 .2548 m .22219 .25791 L .21873 .2544 L p F P
0 g
s
.694 .752 .896 r
.20789 .25916 m .21873 .2544 L .22219 .25791 L p F P
0 g
s
.661 .725 .896 r
.57063 .25791 m .58199 .25413 L .58491 .25793 L p F P
0 g
s
.676 .755 .911 r
.58199 .25413 m .57063 .25791 L .5677 .25492 L p F P
0 g
s
.685 .785 .926 r
.55637 .25939 m .5677 .25492 L .57063 .25791 L p F P
0 g
s
.629 .864 .987 r
.62212 .51349 m .62134 .51307 L .60992 .51671 L p F P
0 g
s
.638 .833 .975 r
.62134 .51307 m .60992 .51671 L .60707 .51452 L p F P
0 g
s
.639 .822 .971 r
.59566 .51796 m .60707 .51452 L .60992 .51671 L p F P
0 g
s
.732 .556 .654 r
.36678 .34857 m .37707 .34941 L .37316 .35578 L p F P
0 g
s
.732 .55 .646 r
.37707 .34941 m .36678 .34857 L .36666 .34798 L p F P
0 g
s
.724 .546 .649 r
.38376 .3564 m .37316 .35578 L .37707 .34941 L p F P
0 g
s
.855 .733 .727 r
.079 .37 m .08323 .37311 L .07916 .37949 L p F P
0 g
s
.85 .736 .737 r
.08092 .36718 m .079 .37 L .08323 .37311 L p F P
0 g
s
.888 .644 .564 r
.08124 .44148 m .08596 .44433 L .08517 .44968 L p F P
0 g
s
.883 .659 .595 r
.08596 .44433 m .08124 .44148 L .08247 .43599 L p F P
0 g
s
.773 .755 .836 r
.15343 .27682 m .156 .27488 L .16012 .27813 L p F P
0 g
s
.772 .756 .838 r
.1645 .26854 m .156 .27488 L .16012 .27813 L p F P
0 g
s
.772 .756 .838 r
.16012 .27813 m .16803 .27221 L .1645 .26854 L p F P
0 g
s
.647 .777 .943 r
.58139 .51849 m .59277 .51515 L .59566 .51796 L p F P
0 g
s
.649 .745 .919 r
.59277 .51515 m .58139 .51849 L .57847 .51516 L p F P
0 g
s
.733 .679 .798 r
.32344 .48992 m .32665 .49552 L .32054 .49966 L p F P
0 g
s
.733 .679 .798 r
.31231 .4979 m .32344 .48992 L p .32054 .49966 L F P
0 g
s
.733 .679 .798 r
.32054 .49966 m .31257 .49833 L .31231 .4979 L p F P
0 g
s
.541 .524 .786 r
.70328 .32914 m .69482 .32862 L .69336 .32497 L p F P
0 g
s
.714 .633 .766 r
.38151 .48382 m .38071 .48214 L .37846 .4837 L closepath p F P
0 g
s
.581 .594 .831 r
.65211 .28597 m .65114 .28402 L .65474 .28366 L closepath p F P
0 g
s
.625 .449 .624 r
.46231 .33158 m .46151 .32554 L .47367 .32296 L p F P
0 g
s
.623 .439 .612 r
.47302 .31711 m .47367 .32296 L .46151 .32554 L p F P
0 g
s
.697 .619 .766 r
.42063 .47401 m .4235 .48064 L .41835 .4838 L p F P
0 g
s
.697 .619 .766 r
.41958 .47405 m .42063 .47401 L p .41835 .4838 L F P
0 g
s
.697 .619 .766 r
.40925 .48067 m .41958 .47405 L p .41835 .4838 L F P
0 g
s
.696 .617 .764 r
.42481 .48356 m .4235 .48064 L .41835 .4838 L closepath p F P
0 g
s
.859 .724 .712 r
.07535 .38578 m .07969 .38883 L .07616 .39503 L p F P
0 g
s
.857 .726 .718 r
.07969 .38883 m .07535 .38578 L .07916 .37949 L p F P
0 g
s
.733 .549 .643 r
.35943 .34132 m .35622 .34745 L .36636 .34853 L p F P
0 g
s
.75 .566 .646 r
.34994 .34003 m .35943 .34132 L .35622 .34745 L p F P
0 g
s
.673 .505 .65 r
.42551 .34923 m .43354 .34848 L .427 .35572 L p F P
0 g
s
.673 .505 .65 r
.427 .35572 m .42671 .35574 L .42551 .34923 L p F P
0 g
s
.692 .523 .653 r
.42551 .34923 m .42671 .35574 L .41293 .35653 L p F P
0 g
s
.728 .657 .779 r
.34097 .49337 m .34368 .49141 L .33966 .49094 L closepath p F P
0 g
s
.663 .494 .646 r
.43989 .34131 m .45072 .33993 L p .43886 .34799 L F P
0 g
s
.663 .494 .646 r
.43886 .34799 m .43803 .34326 L .43989 .34131 L p F P
0 g
s
.474 .232 .467 r
.50652 .29057 m .50686 .2859 L .51753 .28151 L p F P
0 g
s
.418 .125 .358 r
.51838 .27746 m .51753 .28151 L .50686 .2859 L p F P
0 g
s
.733 .673 .792 r
.31183 .49822 m .30121 .50528 L .29795 .50035 L p F P
0 g
s
.69 .752 .899 r
.21873 .2544 m .20789 .25916 L .20441 .25555 L p F P
0 g
s
.646 .783 .947 r
.60707 .51452 m .59566 .51796 L .59277 .51515 L p F P
0 g
s
.7 .53 .654 r
.41093 .35658 m .39863 .35676 L .39827 .35494 L p F P
0 g
s
.71 .536 .652 r
.39863 .35676 m .39827 .35494 L .39702 .35674 L closepath p F P
0 g
s
.755 .561 .634 r
.34994 .34003 m .34897 .33988 L .34778 .33334 L p F P
0 g
s
.755 .561 .634 r
.34346 .33268 m .34778 .33334 L .34897 .33988 L p F P
0 g
s
.683 .611 .769 r
.4518 .4815 m .45201 .48199 L .44083 .48795 L p F P
0 g
s
.683 .611 .769 r
.44083 .48795 m .43848 .48271 L .4518 .4815 L p F P
0 g
s
.561 .559 .808 r
.6716 .30168 m .67201 .30132 L p .68169 .30767 L F P
0 g
s
.566 .568 .815 r
.6716 .30168 m .67145 .30135 L .67201 .30132 L closepath p F P
0 g
s
.718 .631 .76 r
.36642 .48355 m .36706 .48308 L .37846 .4837 L p F P
0 g
s
.711 .626 .761 r
.37759 .47536 m .36706 .48308 L .37846 .4837 L p F P
0 g
s
.711 .626 .761 r
.37846 .4837 m .38071 .48214 L .37759 .47536 L p F P
0 g
s
.861 .473 .308 r
.11251 .48302 m .10735 .48038 L .10563 .47579 L p F P
0 g
s
.862 .471 .299 r
.10049 .47312 m .10563 .47579 L .10735 .48038 L p F P
0 g
s
.873 .53 .398 r
.10563 .47579 m .10049 .47312 L .10019 .47175 L p F P
0 g
s
.143 0 .063 r
.69613 .47831 m .68631 .48369 L .68491 .48715 L p F P
0 g
s
.228 0 .228 r
.697 .47429 m .69613 .47831 L .68631 .48369 L p F P
0 g
s
.595 .617 .844 r
.64534 .27265 m .63379 .27432 L .63089 .26894 L p F P
0 g
s
.475 .384 .673 r
.72154 .41241 m .72911 .40695 L .72316 .40344 L p F P
0 g
s
.464 .364 .656 r
.72154 .41241 m .72911 .40695 L p .72448 .41772 L F P
0 g
s
.464 .364 .656 r
.72448 .41772 m .72229 .41609 L .72154 .41241 L p F P
0 g
s
.673 .501 .645 r
.43886 .34799 m .43803 .34326 L .43354 .34848 L closepath p F P
0 g
s
.501 .749 .984 r
.1833 .51529 m .18682 .51511 L .18326 .51244 L p F P
0 g
s
.501 .749 .984 r
.18326 .51244 m .17728 .51298 L .1833 .51529 L p F P
0 g
s
.384 .731 .99 r
.17275 .51321 m .17728 .51298 L .1833 .51529 L p F P
0 g
s
.665 .878 .978 r
.55365 .25783 m .55637 .25939 L .5677 .25492 L p F P
0 g
s
.764 .561 .622 r
.34346 .33268 m .33479 .3311 L .33699 .32533 L p F P
0 g
s
.774 .573 .626 r
.32891 .32357 m .33699 .32533 L .33479 .3311 L p F P
0 g
s
.776 .563 .612 r
.33699 .32533 m .32891 .32357 L .3289 .32349 L p F P
0 g
s
.565 .57 .817 r
.67201 .30132 m .67145 .30135 L .66855 .29511 L p F P
0 g
s
.697 .526 .652 r
.41293 .35653 m .41253 .35447 L .41093 .35658 L closepath p F P
0 g
s
.83 .469 .374 r
.27574 .27524 m .28174 .27779 L .28336 .28219 L p F P
0 g
s
.815 .452 .369 r
.28657 .28336 m .28336 .28219 L .28174 .27779 L p F P
0 g
s
.5 .437 .718 r
.72469 .3825 m .71905 .38067 L .72324 .37747 L closepath p F P
0 g
s
.509 .451 .727 r
.72159 .37208 m .72324 .37747 L .71905 .38067 L p F P
0 g
s
.509 .451 .727 r
.71888 .37134 m .72159 .37208 L p .71905 .38067 L F P
0 g
s
.689 .614 .767 r
.43453 .48295 m .42481 .48356 L .4235 .48064 L p F P
0 g
s
.771 .56 .613 r
.32804 .31735 m .32255 .31616 L p .32887 .32356 L F P
0 g
s
.771 .56 .613 r
.32887 .32356 m .3289 .32349 L .32804 .31735 L p F P
0 g
s
.642 .689 .879 r
.58491 .25793 m .59632 .25469 L .59923 .25901 L p F P
0 g
s
.651 .706 .887 r
.59632 .25469 m .58491 .25793 L .58199 .25413 L p F P
0 g
s
.603 .627 .848 r
.63089 .26894 m .62554 .26985 L .62956 .26652 L closepath p F P
0 g
s
.607 .638 .855 r
.62799 .26374 m .62956 .26652 L .62554 .26985 L p F P
0 g
s
.607 .638 .855 r
.61649 .26592 m .62799 .26374 L p .62554 .26985 L F P
0 g
s
.706 .62 .759 r
.39498 .48117 m .40496 .47441 L .39194 .47437 L closepath p F P
0 g
s
.612 .642 .856 r
.62799 .26374 m .61649 .26592 L .61358 .26099 L p F P
0 g
s
.729 .656 .777 r
.35034 .48177 m .35212 .48533 L .34368 .49141 L p F P
0 g
s
.729 .656 .777 r
.34587 .48135 m .35034 .48177 L p .34368 .49141 L F P
0 g
s
.729 .656 .777 r
.33779 .48748 m .34587 .48135 L p .34368 .49141 L F P
0 g
s
.729 .656 .777 r
.34368 .49141 m .33966 .49094 L .33779 .48748 L p F P
0 g
s
.53 .712 .955 r
.23639 .25806 m .2445 .2576 L .25001 .26035 L p F P
0 g
s
.501 .702 .96 r
.2445 .2576 m .23639 .25806 L .23293 .2548 L p F P
0 g
s
.844 .741 .75 r
.08423 .35369 m .08839 .35685 L .08351 .36348 L p F P
0 g
s
.841 .743 .756 r
.08912 .34727 m .08423 .35369 L .08839 .35685 L p F P
0 g
s
.88 .675 .62 r
.08247 .43599 m .07782 .43311 L .07947 .42749 L p F P
0 g
s
.886 .663 .595 r
.07782 .43311 m .08247 .43599 L .08124 .44148 L p F P
0 g
s
.679 .618 .78 r
.46628 .48325 m .46923 .48978 L .4563 .49139 L p F P
0 g
s
.679 .618 .78 r
.4563 .49139 m .45508 .48881 L .46628 .48325 L p F P
0 g
s
.713 .617 .749 r
.3917 .47437 m .38071 .48214 L .37759 .47536 L p F P
0 g
s
.819 .752 .789 r
.09709 .32969 m .10358 .32261 L p .10104 .33305 L F P
0 g
s
.819 .752 .789 r
.10104 .33305 m .09822 .33084 L .09709 .32969 L p F P
0 g
s
.827 .75 .778 r
.10071 .33343 m .10104 .33305 L .09822 .33084 L closepath p F P
0 g
s
.668 .624 .796 r
.4724 .49642 m .48361 .4915 L p .48448 .49873 L F P
0 g
s
.671 .613 .782 r
.48361 .4915 m .4724 .49642 L .46934 .49003 L p F P
0 g
s
.803 .56 .571 r
.31625 .30876 m .30914 .30664 L .30994 .30136 L p F P
0 g
s
.81 .568 .572 r
.30752 .30057 m .30994 .30136 L .30914 .30664 L p F P
0 g
s
.701 .535 .66 r
.39863 .35676 m .41093 .35658 L .40543 .36348 L p F P
0 g
s
.701 .535 .66 r
.40543 .36348 m .40009 .36356 L .39863 .35676 L p F P
0 g
s
.71 .541 .658 r
.39702 .35674 m .39863 .35676 L .40009 .36356 L p F P
0 g
s
.831 .75 .773 r
.0951 .34004 m .10071 .33343 L .09822 .33084 L p F P
0 g
s
.698 .614 .759 r
.40925 .48067 m .41958 .47405 L .4065 .47441 L closepath p F P
0 g
s
.71 .541 .658 r
.40009 .36356 m .3921 .36345 L .39702 .35674 L p F P
0 g
s
.715 .547 .661 r
.38458 .35643 m .39702 .35674 L .3921 .36345 L p F P
0 g
s
.56 .561 .811 r
.67201 .30132 m .68314 .30107 L .68023 .2946 L p F P
0 g
s
.56 .561 .811 r
.68023 .2946 m .6795 .29462 L .67201 .30132 L p F P
0 g
s
.565 .57 .817 r
.66855 .29511 m .6795 .29462 L .67201 .30132 L p F P
0 g
s
.561 .559 .808 r
.67201 .30132 m .68314 .30107 L p .68169 .30767 L F P
0 g
s
.467 .891 .83 r
.6492 .50617 m .64972 .50608 L .66115 .50095 L p F P
0 g
s
.447 .747 .992 r
.17728 .51298 m .17275 .51321 L .16914 .51093 L p F P
0 g
s
.604 .423 .609 r
.47367 .32296 m .47302 .31711 L .48481 .31408 L p F P
0 g
s
.599 .407 .593 r
.48434 .30844 m .48481 .31408 L .47302 .31711 L p F P
0 g
s
.541 .524 .786 r
.69336 .32497 m .6972 .32162 L p .70328 .32914 L F P
0 g
s
.545 .534 .793 r
.69336 .32497 m .69189 .32142 L .6972 .32162 L closepath p F P
0 g
s
0 .51 .858 r
.15286 .50702 m .15517 .50776 L .15151 .50571 L p F P
0 g
s
0 .51 .858 r
.15151 .50571 m .14728 .50455 L .15286 .50702 L p F P
0 g
s
.376 .095 .353 r
.52869 .2726 m .51838 .27746 L .51753 .28151 L p F P
0 g
s
.254 0 .109 r
.53037 .26954 m .52869 .2726 L .51838 .27746 L p F P
0 g
s
0 0 0 r
.54038 .26429 m .53037 .26954 L p .53557 .26684 L F P
0 g
s
0 0 0 r
.54214 .26343 m .54038 .26429 L p .53557 .26684 L F P
0 g
s
.634 .952 .939 r
.55365 .25783 m .55345 .25776 L .54214 .26343 L p F P
0 g
s
.327 .783 .643 r
.54038 .26429 m .54214 .26343 L .55345 .25776 L p F P
0 g
s
.327 .783 .643 r
.55345 .25776 m .55053 .25807 L p .54038 .26429 L F P
0 g
s
0 0 0 r
.54038 .26429 m .53923 .26592 L .54413 .26229 L p F P
0 g
s
.327 .783 .643 r
.55053 .25807 m .54666 .26043 L .54038 .26429 L p F P
0 g
s
0 0 0 r
.54413 .26229 m .54666 .26043 L .54038 .26429 L p F P
0 g
s
.141 0 .046 r
.54038 .26429 m .53037 .26954 L .52869 .2726 L p F P
0 g
s
.873 .709 .676 r
.07313 .40107 m .07752 .40409 L .07482 .41003 L p F P
0 g
s
.867 .714 .689 r
.07585 .39563 m .07313 .40107 L .07752 .40409 L p F P
0 g
s
.736 .552 .645 r
.36678 .34857 m .36666 .34798 L .36636 .34853 L closepath p F P
0 g
s
.698 .531 .658 r
.41093 .35658 m .41293 .35653 L .41434 .36327 L p F P
0 g
s
.698 .531 .658 r
.41434 .36327 m .40543 .36348 L .41093 .35658 L p F P
0 g
s
.687 .524 .66 r
.41293 .35653 m .42671 .35574 L p .42059 .36291 L F P
0 g
s
.687 .524 .66 r
.42059 .36291 m .41434 .36327 L .41293 .35653 L p F P
0 g
s
.721 .73 .858 r
.24384 .51342 m .24501 .51279 L .25177 .51484 L p F P
0 g
s
.707 .716 .855 r
.25482 .50755 m .24501 .51279 L .25177 .51484 L p F P
0 g
s
.707 .716 .855 r
.25177 .51484 m .25818 .51166 L .25482 .50755 L p F P
0 g
s
.581 .598 .834 r
.65474 .28366 m .65114 .28402 L .64824 .2783 L p F P
0 g
s
.362 .152 .454 r
.71306 .45586 m .70728 .4594 L .70715 .46423 L p F P
0 g
s
.398 .213 .51 r
.70728 .4594 m .71306 .45586 L .71341 .4504 L p F P
0 g
s
.72 .635 .763 r
.36642 .48355 m .36706 .48308 L .36617 .48303 L closepath p F P
0 g
s
.722 .635 .761 r
.36617 .48303 m .36642 .48355 L p .35212 .48533 L F P
0 g
s
.732 .556 .654 r
.37316 .35578 m .36824 .35538 L .36678 .34857 L p F P
0 g
s
.736 .558 .653 r
.36636 .34853 m .36678 .34857 L .36824 .35538 L p F P
0 g
s
.653 .659 .843 r
.54688 .50933 m .53557 .51287 L .53256 .50797 L p F P
0 g
s
.761 .755 .848 r
.17311 .26869 m .16803 .27221 L .1645 .26854 L p F P
0 g
s
.736 .558 .653 r
.36824 .35538 m .36259 .35485 L .36636 .34853 L p F P
0 g
s
.745 .563 .649 r
.35622 .34745 m .36636 .34853 L .36259 .35485 L p F P
0 g
s
.482 0 0 r
.13521 .49893 m .13771 .50062 L .13398 .49896 L p F P
0 g
s
.482 0 0 r
.13398 .49896 m .12982 .49639 L .13521 .49893 L p F P
0 g
s
.734 .658 .774 r
.33387 .4903 m .32665 .49552 L .32344 .48992 L p F P
0 g
s
.755 .561 .634 r
.34897 .33988 m .34077 .33863 L .34346 .33268 L p F P
0 g
s
.768 .571 .632 r
.33479 .3311 m .34346 .33268 L .34077 .33863 L p F P
0 g
s
.715 .547 .661 r
.38396 .35733 m .38458 .35643 L p .3921 .36345 L F P
0 g
s
.718 .547 .657 r
.38396 .35733 m .38458 .35643 L .38376 .3564 L closepath p F P
0 g
s
.72 .635 .762 r
.37696 .47394 m .37759 .47536 L .36706 .48308 L p F P
0 g
s
.72 .635 .762 r
.36783 .47346 m .37696 .47394 L p .36706 .48308 L F P
0 g
s
.72 .635 .762 r
.36329 .47696 m .36783 .47346 L p .36706 .48308 L F P
0 g
s
.72 .635 .762 r
.36706 .48308 m .36617 .48303 L .36329 .47696 L p F P
0 g
s
.673 .506 .65 r
.43354 .34848 m .43886 .34799 L .44008 .35451 L p F P
0 g
s
.673 .506 .65 r
.44008 .35451 m .427 .35572 L .43354 .34848 L p F P
0 g
s
.728 .559 .661 r
.38376 .3564 m .38396 .35733 L .38005 .36301 L p F P
0 g
s
.728 .559 .661 r
.37316 .35578 m .38376 .3564 L p .38005 .36301 L F P
0 g
s
.66 .628 .807 r
.51524 .50101 m .50398 .5051 L .50095 .49934 L p F P
0 g
s
.735 .7 .817 r
.28687 .50751 m .28827 .5066 L .28583 .50605 L closepath p F P
0 g
s
.727 .695 .82 r
.28583 .50605 m .28687 .50751 L p .27253 .50965 L F P
0 g
s
.722 .635 .761 r
.35212 .48533 m .35613 .48232 L .36617 .48303 L p F P
0 g
s
.722 .635 .761 r
.36617 .48303 m .36329 .47696 L .35613 .48232 L closepath p F P
0 g
s
.727 .655 .778 r
.33966 .49094 m .33779 .48748 L .33387 .4903 L closepath p F P
0 g
s
.829 .384 .17 r
.1202 .49001 m .11505 .48737 L .11251 .48302 L p F P
0 g
s
.827 .375 .153 r
.10735 .48038 m .11251 .48302 L .11505 .48737 L p F P
0 g
s
.689 .614 .767 r
.4235 .48064 m .43468 .47391 L p .43453 .48295 L F P
0 g
s
.691 .609 .759 r
.43441 .47325 m .43468 .47391 L .4235 .48064 L p F P
0 g
s
.691 .609 .759 r
.4235 .48064 m .42063 .47401 L .43441 .47325 L p F P
0 g
s
.723 .749 .873 r
.19351 .26139 m .19374 .26127 L .19272 .26056 L closepath p F P
0 g
s
.746 .754 .859 r
.19272 .26056 m .19351 .26139 L p .17905 .26462 L F P
0 g
s
.69 .614 .766 r
.43848 .48271 m .43776 .48109 L .43453 .48295 L closepath p F P
0 g
s
.689 .614 .767 r
.43468 .47391 m .43776 .48109 L .43453 .48295 L p F P
0 g
s
.717 .749 .877 r
.20092 .25195 m .20441 .25555 L .19374 .26127 L p F P
0 g
s
.717 .749 .877 r
.19002 .25774 m .20092 .25195 L p .19374 .26127 L F P
0 g
s
.717 .749 .877 r
.19374 .26127 m .19272 .26056 L .19002 .25774 L p F P
0 g
s
.788 .562 .594 r
.32255 .31616 m .31495 .31421 L .31625 .30876 L p F P
0 g
s
.803 .576 .595 r
.30914 .30664 m .31625 .30876 L .31495 .31421 L p F P
0 g
s
.715 .547 .661 r
.3921 .36345 m .38527 .36327 L .38396 .35733 L p F P
0 g
s
.721 .551 .659 r
.38527 .36327 m .38396 .35733 L .38005 .36301 L closepath p F P
0 g
s
.883 .679 .621 r
.0749 .42457 m .07947 .42749 L .07782 .43311 L p F P
0 g
s
.878 .688 .642 r
.07947 .42749 m .0749 .42457 L .07692 .41884 L p F P
0 g
s
.671 .63 .801 r
.48696 .49837 m .48667 .4978 L .48448 .49873 L closepath p F P
0 g
s
.668 .624 .796 r
.48361 .4915 m .48667 .4978 L .48448 .49873 L p F P
0 g
s
.678 .605 .767 r
.46628 .48325 m .45508 .48881 L .45201 .48199 L p F P
0 g
s
.736 .699 .816 r
.29469 .49531 m .29795 .50035 L .28827 .5066 L p F P
0 g
s
.736 .699 .816 r
.28358 .50285 m .29469 .49531 L p .28827 .5066 L F P
0 g
s
.736 .699 .816 r
.28827 .5066 m .28583 .50605 L .28358 .50285 L p F P
0 g
s
.465 .364 .655 r
.72286 .41887 m .72229 .41609 L .72448 .41772 L closepath p F P
0 g
s
.811 .359 .163 r
.2678 .26888 m .26841 .26899 L p .27574 .27524 L F P
0 g
s
.626 .062 0 r
.2678 .26888 m .26737 .26856 L .26841 .26899 L closepath p F P
0 g
s
.687 .613 .767 r
.44894 .4748 m .4518 .4815 L .43848 .48271 L p F P
0 g
s
.687 .613 .767 r
.43848 .48271 m .43776 .48109 L .44894 .4748 L p F P
0 g
s
.81 .568 .572 r
.30914 .30664 m .30781 .30621 L .30752 .30057 L p F P
0 g
s
.8 .559 .574 r
.30285 .29923 m .30752 .30057 L .30781 .30621 L p F P
0 g
s
.664 .111 0 r
.12052 .49041 m .12138 .4906 L p .12982 .49639 L F P
0 g
s
.782 .291 .043 r
.12052 .49041 m .1202 .49001 L .12138 .4906 L closepath p F P
0 g
s
.545 .534 .794 r
.6972 .32162 m .69189 .32142 L .6893 .31518 L p F P
0 g
s
.726 .644 .767 r
.35212 .48533 m .35613 .48232 L .35034 .48177 L closepath p F P
0 g
s
.579 .392 .591 r
.48481 .31408 m .48434 .30844 L .49576 .30498 L p F P
0 g
s
.57 .368 .568 r
.49549 .29958 m .49576 .30498 L .48434 .30844 L p F P
0 g
s
.473 .385 .675 r
.72907 .3991 m .72316 .40344 L .72911 .40695 L p F P
0 g
s
.485 .403 .689 r
.72786 .39423 m .72907 .3991 L .72316 .40344 L p F P
0 g
s
.485 .403 .689 r
.72584 .39326 m .72786 .39423 L p .72316 .40344 L F P
0 g
s
.83 .533 .488 r
.29629 .29191 m .28997 .28949 L .28958 .28465 L p F P
0 g
s
.843 .545 .484 r
.28657 .28336 m .28958 .28465 L .28997 .28949 L p F P
0 g
s
.659 .496 .652 r
.43886 .34799 m .45178 .34626 L p .44711 .35355 L F P
0 g
s
.659 .496 .652 r
.44711 .35355 m .44008 .35451 L .43886 .34799 L p F P
0 g
s
.663 .494 .646 r
.45072 .33993 m .45178 .34626 L .43886 .34799 L p F P
0 g
s
.633 .677 .874 r
.61068 .25622 m .59923 .25901 L .59632 .25469 L p F P
0 g
s
.395 .704 .984 r
.25047 .26036 m .25001 .26035 L .25114 .26086 L closepath p F P
0 g
s
.831 .749 .774 r
.09102 .33683 m .0951 .34004 L .08936 .34697 L p F P
0 g
s
.831 .75 .773 r
.09696 .32984 m .09102 .33683 L .0951 .34004 L p F P
0 g
s
.831 .75 .773 r
.09822 .33084 m .09696 .32984 L p .0951 .34004 L F P
0 g
s
.75 .566 .646 r
.34928 .34137 m .34994 .34003 L p .35622 .34745 L F P
0 g
s
.754 .567 .643 r
.34928 .34137 m .34994 .34003 L .34897 .33988 L closepath p F P
0 g
s
.408 .248 .55 r
.72381 .43795 m .71621 .44295 L .71663 .44839 L p F P
0 g
s
.431 .287 .584 r
.71621 .44295 m .72381 .43795 L .72154 .43328 L p F P
0 g
s
.421 .258 .552 r
.71341 .4504 m .71663 .44839 L .71621 .44295 L p F P
0 g
s
.667 .629 .802 r
.4979 .49324 m .49939 .49623 L .48696 .49837 L p F P
0 g
s
.667 .629 .802 r
.48696 .49837 m .48667 .4978 L .4979 .49324 L p F P
0 g
s
.761 .755 .848 r
.1645 .26854 m .169 .26543 L .17311 .26869 L p F P
0 g
s
.76 .756 .849 r
.17552 .26097 m .169 .26543 L .17311 .26869 L p F P
0 g
s
.76 .756 .849 r
.17311 .26869 m .17905 .26462 L .17552 .26097 L p F P
0 g
s
.728 .677 .801 r
.31257 .49833 m .31231 .4979 L .31183 .49822 L closepath p F P
0 g
s
.732 .559 .658 r
.36958 .36138 m .37316 .35578 L .36824 .35538 L closepath p F P
0 g
s
.728 .559 .661 r
.36958 .36138 m .37316 .35578 L p .38005 .36301 L F P
0 g
s
.643 .476 .643 r
.45072 .33993 m .46323 .33774 L p .45615 .3455 L F P
0 g
s
.643 .476 .643 r
.45615 .3455 m .45178 .34626 L .45072 .33993 L p F P
0 g
s
.644 .472 .636 r
.46231 .33158 m .46323 .33774 L .45072 .33993 L p F P
0 g
s
.771 .56 .613 r
.32255 .31616 m .32076 .32179 L .32887 .32356 L p F P
0 g
s
.791 .576 .61 r
.31495 .31421 m .32255 .31616 L .32076 .32179 L p F P
0 g
s
.674 .511 .657 r
.42676 .35597 m .427 .35572 L .42671 .35574 L closepath p F P
0 g
s
.687 .524 .66 r
.42671 .35574 m .42676 .35597 L .42059 .36291 L p F P
0 g
s
.859 .73 .719 r
.07491 .37638 m .07916 .37949 L .07535 .38578 L p F P
0 g
s
.855 .733 .727 r
.07916 .37949 m .07491 .37638 L .079 .37 L p F P
0 g
s
.749 .564 .645 r
.34897 .33988 m .34077 .33863 L p .3468 .34614 L F P
0 g
s
.749 .564 .645 r
.3468 .34614 m .34928 .34137 L .34897 .33988 L p F P
0 g
s
.673 .514 .662 r
.427 .35572 m .44008 .35451 L p .43866 .36141 L F P
0 g
s
.673 .514 .662 r
.42676 .35597 m .427 .35572 L p .43866 .36141 L F P
0 g
s
.528 .918 .911 r
.64702 .50612 m .6492 .50617 L .65947 .50144 L p F P
0 g
s
.491 .901 .906 r
.63556 .5104 m .64702 .50612 L .6492 .50617 L p F P
0 g
s
.467 .891 .83 r
.66115 .50095 m .65947 .50144 L .6492 .50617 L p F P
0 g
s
.673 .514 .662 r
.43866 .36141 m .42811 .36246 L .42676 .35597 L p F P
0 g
s
.686 .522 .659 r
.42811 .36246 m .42676 .35597 L .42059 .36291 L closepath p F P
0 g
s
.685 .599 .754 r
.44894 .4748 m .43776 .48109 L .43468 .47391 L p F P
0 g
s
.734 .658 .774 r
.32344 .48992 m .32463 .48902 L .33387 .4903 L p F P
0 g
s
.725 .65 .775 r
.33461 .48143 m .32463 .48902 L .33387 .4903 L p F P
0 g
s
.725 .65 .775 r
.33387 .4903 m .33779 .48748 L .33461 .48143 L p F P
0 g
s
.727 .695 .82 r
.27253 .50965 m .28009 .50499 L .28583 .50605 L p F P
0 g
s
.735 .699 .816 r
.28009 .50499 m .27253 .50965 L .2692 .50529 L p F P
0 g
s
.724 .708 .835 r
.25818 .51166 m .2692 .50529 L .27253 .50965 L p F P
0 g
s
.733 .673 .792 r
.29795 .50035 m .30295 .49682 L .31183 .49822 L p F P
0 g
s
.725 .671 .796 r
.30908 .49253 m .30295 .49682 L .31183 .49822 L p F P
0 g
s
.725 .671 .796 r
.31183 .49822 m .31231 .4979 L .30908 .49253 L p F P
0 g
s
.713 .185 0 r
.26737 .26856 m .2678 .26888 L .26422 .26853 L p F P
0 g
s
.665 .613 .787 r
.4979 .49324 m .48667 .4978 L .48361 .4915 L p F P
0 g
s
.701 .538 .664 r
.40121 .36862 m .40543 .36348 L .40009 .36356 L closepath p F P
0 g
s
.704 .54 .663 r
.40009 .36356 m .3921 .36345 L p .39976 .37044 L F P
0 g
s
.704 .54 .663 r
.39976 .37044 m .40121 .36862 L .40009 .36356 L p F P
0 g
s
.704 .616 .756 r
.4065 .47441 m .40615 .47361 L .40496 .47441 L closepath p F P
0 g
s
.706 .62 .758 r
.40306 .46624 m .40615 .47361 L .40496 .47441 L p F P
0 g
s
.706 .62 .758 r
.39188 .47424 m .40306 .46624 L p .40496 .47441 L F P
0 g
s
.706 .62 .758 r
.40496 .47441 m .39194 .47437 L .39188 .47424 L p F P
0 g
s
.698 .613 .758 r
.41958 .47405 m .4065 .47441 L .40615 .47361 L p F P
0 g
s
.726 .643 .766 r
.36145 .473 m .36329 .47696 L .35613 .48232 L p F P
0 g
s
.726 .643 .766 r
.35701 .47265 m .36145 .473 L p .35613 .48232 L F P
0 g
s
.726 .643 .766 r
.34896 .47901 m .35701 .47265 L p .35613 .48232 L F P
0 g
s
.726 .643 .766 r
.35613 .48232 m .35034 .48177 L .34896 .47901 L p F P
0 g
s
.734 .66 .777 r
.32344 .48992 m .31231 .4979 L .30908 .49253 L p F P
0 g
s
.746 .754 .859 r
.17905 .26462 m .18954 .25804 L .19272 .26056 L p F P
0 g
s
.745 .754 .86 r
.19272 .26056 m .19002 .25774 L .18954 .25804 L closepath p F P
0 g
s
.71 .622 .756 r
.39194 .47437 m .39188 .47424 L .3917 .47437 L closepath p F P
0 g
s
.713 .617 .749 r
.37759 .47536 m .37937 .47403 L .3917 .47437 L p F P
0 g
s
.707 .614 .751 r
.38878 .46701 m .37937 .47403 L .3917 .47437 L p F P
0 g
s
.707 .614 .751 r
.3917 .47437 m .39188 .47424 L .38878 .46701 L p F P
0 g
s
.726 .696 .821 r
.28583 .50605 m .28358 .50285 L .28009 .50499 L closepath p F P
0 g
s
.844 .741 .75 r
.08351 .36348 m .07933 .36034 L .08423 .35369 L p F P
0 g
s
.849 .739 .742 r
.08351 .36348 m .08092 .36718 L .07729 .36324 L p F P
0 g
s
.849 .739 .742 r
.07729 .36324 m .07933 .36034 L .08351 .36348 L p F P
0 g
s
.699 .54 .668 r
.40543 .36348 m .41434 .36327 L p .41405 .37016 L F P
0 g
s
.699 .54 .668 r
.40121 .36862 m .40543 .36348 L p .41405 .37016 L F P
0 g
s
.708 .607 .741 r
.40306 .46624 m .39188 .47424 L .38878 .46701 L p F P
0 g
s
.704 .54 .663 r
.3921 .36345 m .38702 .37022 L .39976 .37044 L p F P
0 g
s
.715 .55 .664 r
.38527 .36327 m .3921 .36345 L .38702 .37022 L p F P
0 g
s
.652 .696 .878 r
.56131 .51069 m .56416 .51471 L p .54986 .51392 L F P
0 g
s
.652 .696 .878 r
.54986 .51392 m .55189 .51331 L .56131 .51069 L p F P
0 g
s
.651 .673 .858 r
.54986 .51392 m .55189 .51331 L .54984 .5139 L closepath p F P
0 g
s
.45 .338 .634 r
.72448 .41772 m .72286 .41887 L .72396 .42508 L p F P
0 g
s
.506 .451 .729 r
.72159 .37208 m .71888 .37134 L .72089 .36978 L closepath p F P
0 g
s
.515 .464 .738 r
.71854 .36248 m .72089 .36978 L .71888 .37134 L p F P
0 g
s
.515 .464 .738 r
.71773 .3623 m .71854 .36248 L p .71888 .37134 L F P
0 g
s
.651 .673 .858 r
.55189 .51331 m .54984 .5139 L .54688 .50933 L p F P
0 g
s
.255 0 .264 r
.7067 .4687 m .697 .47429 L .69613 .47831 L p F P
0 g
s
.305 .061 .37 r
.70715 .46423 m .7067 .4687 L .697 .47429 L p F P
0 g
s
.881 .692 .643 r
.07244 .41587 m .07692 .41884 L .0749 .42457 L p F P
0 g
s
.876 .699 .66 r
.07692 .41884 m .07244 .41587 L .07482 .41003 L p F P
0 g
s
.698 .613 .758 r
.40615 .47361 m .41733 .46603 L p .41958 .47405 L F P
0 g
s
.701 .601 .742 r
.41733 .46603 m .40615 .47361 L .40306 .46624 L p F P
0 g
s
.75 .566 .646 r
.35622 .34745 m .35037 .34664 L .34928 .34137 L p F P
0 g
s
.75 .566 .646 r
.35037 .34664 m .34928 .34137 L .3468 .34614 L closepath p F P
0 g
s
.867 .718 .694 r
.07585 .39563 m .07616 .39503 L .07448 .39386 L closepath p F P
0 g
s
.859 .724 .712 r
.07228 .39116 m .07535 .38578 L p .07616 .39503 L F P
0 g
s
.859 .724 .712 r
.07616 .39503 m .07448 .39386 L .07228 .39116 L p F P
0 g
s
.796 .757 .818 r
.13519 .29195 m .13113 .29552 L .12754 .29188 L p F P
0 g
s
.802 .758 .812 r
.12629 .29996 m .13113 .29552 L .12754 .29188 L p F P
0 g
s
.804 .757 .809 r
.12629 .29996 m .11988 .30597 L .11627 .30233 L p F P
0 g
s
.804 .757 .809 r
.11627 .30233 m .12231 .29667 L .12629 .29996 L p F P
0 g
s
.802 .758 .812 r
.12754 .29188 m .12231 .29667 L .12629 .29996 L p F P
0 g
s
.326 .67 .975 r
.25001 .26035 m .25047 .26036 L .24698 .25782 L p F P
0 g
s
.326 .67 .975 r
.24698 .25782 m .2445 .2576 L .25001 .26035 L p F P
0 g
s
.716 .623 .753 r
.37759 .47536 m .37937 .47403 L .37696 .47394 L closepath p F P
0 g
s
.73 .557 .658 r
.36824 .35538 m .36259 .35485 L p .36903 .36223 L F P
0 g
s
.73 .557 .658 r
.36903 .36223 m .36958 .36138 L .36824 .35538 L p F P
0 g
s
.745 .563 .649 r
.36259 .35485 m .35281 .35366 L .35622 .34745 L p F P
0 g
s
.749 .569 .652 r
.35037 .34664 m .35622 .34745 L .35281 .35366 L p F P
0 g
s
.766 .26 0 r
.1202 .49001 m .12052 .49041 L .1167 .48935 L p F P
0 g
s
.766 .26 0 r
.1167 .48935 m .11505 .48737 L .1202 .49001 L p F P
0 g
s
.393 .208 .508 r
.71663 .44839 m .71341 .4504 L .71306 .45586 L p F P
0 g
s
.687 .527 .664 r
.41548 .36851 m .42059 .36291 L .41434 .36327 L closepath p F P
0 g
s
.699 .54 .668 r
.41434 .36327 m .41548 .36851 L .41405 .37016 L p F P
0 g
s
.715 .55 .664 r
.38702 .37022 m .38686 .37021 L .38527 .36327 L p F P
0 g
s
.722 .554 .662 r
.38005 .36301 m .38527 .36327 L .38686 .37021 L p F P
0 g
s
.626 .456 .633 r
.46231 .33158 m .47445 .32896 L p .46632 .33708 L F P
0 g
s
.626 .456 .633 r
.46632 .33708 m .46323 .33774 L .46231 .33158 L p F P
0 g
s
.625 .449 .624 r
.47367 .32296 m .47445 .32896 L .46231 .33158 L p F P
0 g
s
.81 .757 .804 r
.11805 .30774 m .11988 .30597 L .11627 .30233 L p F P
0 g
s
.796 .757 .818 r
.12754 .29188 m .1312 .28866 L .13519 .29195 L p F P
0 g
s
.793 .758 .821 r
.13873 .28217 m .1312 .28866 L .13519 .29195 L p F P
0 g
s
.793 .758 .821 r
.13519 .29195 m .14231 .28582 L .13873 .28217 L p F P
0 g
s
.601 .752 .95 r
.18682 .51511 m .19748 .51282 L .20099 .51579 L p F P
0 g
s
.622 .751 .939 r
.19748 .51282 m .18682 .51511 L .18326 .51244 L p F P
0 g
s
.771 .56 .613 r
.32891 .32357 m .3289 .32349 L .32887 .32356 L closepath p F P
0 g
s
.813 .549 .539 r
.30285 .29923 m .29603 .29698 L .29629 .29191 L p F P
0 g
s
.829 .563 .538 r
.28997 .28949 m .29629 .29191 L .29603 .29698 L p F P
0 g
s
.81 .757 .804 r
.11627 .30233 m .11408 .30446 L .11805 .30774 L p F P
0 g
s
.813 .756 .8 r
.11408 .30446 m .11805 .30774 L .11052 .31528 L p F P
0 g
s
.732 .645 .761 r
.34587 .48135 m .33779 .48748 L .33461 .48143 L p F P
0 g
s
.774 .573 .626 r
.33479 .3311 m .33006 .33008 L .32891 .32357 L p F P
0 g
s
.77 .57 .628 r
.32887 .32356 m .32891 .32357 L .33006 .33008 L p F P
0 g
s
.811 .359 .163 r
.27574 .27524 m .27014 .27255 L .2678 .26888 L p F P
0 g
s
.818 .354 .115 r
.27014 .27255 m .2678 .26888 L .26422 .26853 L p F P
0 g
s
.77 .57 .628 r
.33006 .33008 m .32657 .32937 L .32887 .32356 L p F P
0 g
s
.779 .575 .624 r
.32076 .32179 m .32887 .32356 L .32657 .32937 L p F P
0 g
s
.87 .717 .69 r
.07313 .40107 m .07585 .39563 L .07448 .39386 L p F P
0 g
s
.697 .611 .756 r
.42063 .47401 m .42042 .47351 L .41958 .47405 L closepath p F P
0 g
s
.698 .613 .758 r
.41733 .46603 m .42042 .47351 L .41958 .47405 L p F P
0 g
s
.657 .649 .83 r
.51827 .50655 m .52955 .50274 L .53256 .50797 L p F P
0 g
s
.654 .637 .82 r
.52943 .50251 m .52955 .50274 L .51827 .50655 L p F P
0 g
s
.654 .637 .82 r
.51827 .50655 m .51758 .50529 L .52943 .50251 L p F P
0 g
s
.716 .623 .752 r
.38796 .46503 m .38878 .46701 L .37937 .47403 L p F P
0 g
s
.716 .623 .752 r
.37903 .46474 m .38796 .46503 L p .37937 .47403 L F P
0 g
s
.716 .623 .752 r
.37448 .46833 m .37903 .46474 L p .37937 .47403 L F P
0 g
s
.716 .623 .752 r
.37937 .47403 m .37696 .47394 L .37448 .46833 L p F P
0 g
s
.877 .533 .395 r
.10049 .47312 m .09891 .47228 L .10019 .47175 L closepath p F P
0 g
s
.566 .571 .818 r
.6795 .29462 m .66855 .29511 L .66637 .29045 L p F P
0 g
s
.696 .611 .757 r
.4316 .46639 m .43441 .47325 L .42063 .47401 L p F P
0 g
s
.696 .611 .757 r
.42063 .47401 m .42042 .47351 L .4316 .46639 L p F P
0 g
s
.556 .55 .803 r
.68605 .30765 m .68169 .30767 L .68486 .30491 L closepath p F P
0 g
s
.561 .559 .808 r
.68314 .30107 m .68486 .30491 L .68169 .30767 L p F P
0 g
s
.671 .613 .782 r
.48198 .48797 m .48361 .4915 L p .46934 .49003 L F P
0 g
s
.671 .613 .782 r
.46934 .49003 m .47019 .48964 L .48198 .48797 L p F P
0 g
s
.669 .607 .777 r
.46934 .49003 m .47019 .48964 L .46923 .48978 L closepath p F P
0 g
s
.669 .606 .776 r
.47019 .48964 m .46923 .48978 L .46628 .48325 L p F P
0 g
s
.719 .624 .751 r
.37696 .47394 m .37448 .46833 L .36783 .47346 L closepath p F P
0 g
s
.693 .596 .743 r
.4316 .46639 m .42042 .47351 L .41733 .46603 L p F P
0 g
s
.722 .554 .662 r
.38686 .37021 m .37535 .36965 L .38005 .36301 L p F P
0 g
s
.728 .563 .667 r
.36979 .36229 m .38005 .36301 L .37535 .36965 L p F P
0 g
s
.728 .559 .661 r
.38005 .36301 m .36979 .36229 L .36958 .36138 L p F P
0 g
s
.786 .758 .828 r
.14497 .28363 m .14231 .28582 L .13873 .28217 L p F P
0 g
s
.627 .874 .988 r
.62134 .51307 m .62212 .51349 L .63279 .50928 L p F P
0 g
s
.628 .891 .987 r
.63556 .5104 m .63279 .50928 L .62212 .51349 L p F P
0 g
s
.728 .703 .826 r
.2692 .50529 m .25818 .51166 L .25482 .50755 L p F P
0 g
s
.548 .352 .566 r
.49576 .30498 m .49549 .29958 L .50654 .29566 L p F P
0 g
s
.532 .315 .531 r
.50652 .29057 m .50654 .29566 L .49549 .29958 L p F P
0 g
s
.726 .643 .766 r
.35034 .48177 m .34896 .47901 L .34587 .48135 L closepath p F P
0 g
s
.327 .683 .979 r
.16694 .50946 m .16481 .50848 L .15517 .50776 L p F P
0 g
s
.284 .685 .972 r
.16481 .50848 m .15517 .50776 L .15151 .50571 L p F P
0 g
s
.691 .533 .667 r
.42059 .36291 m .42811 .36246 L p .41584 .37011 L F P
0 g
s
.691 .533 .667 r
.41584 .37011 m .41548 .36851 L .42059 .36291 L p F P
0 g
s
.746 .756 .861 r
.18954 .25804 m .17905 .26462 L .17552 .26097 L p F P
0 g
s
.664 .111 0 r
.12982 .49639 m .12445 .49383 L .12052 .49041 L p F P
0 g
s
.67 .119 0 r
.12445 .49383 m .12052 .49041 L .1167 .48935 L p F P
0 g
s
.671 .611 .78 r
.48198 .48797 m .48056 .48487 L .47019 .48964 L closepath p F P
0 g
s
.669 .606 .776 r
.4776 .47816 m .48056 .48487 L .47019 .48964 L p F P
0 g
s
.669 .606 .776 r
.47675 .47828 m .4776 .47816 L p .47019 .48964 L F P
0 g
s
.669 .606 .776 r
.46628 .48325 m .47675 .47828 L p .47019 .48964 L F P
0 g
s
.723 .632 .756 r
.36329 .47696 m .36783 .47346 L .36145 .473 L closepath p F P
0 g
s
.577 .588 .827 r
.66275 .28298 m .65474 .28366 L .66054 .27846 L closepath p F P
0 g
s
.581 .598 .834 r
.65985 .27709 m .66054 .27846 L .65474 .28366 L p F P
0 g
s
.581 .598 .834 r
.64824 .2783 m .65985 .27709 L p .65474 .28366 L F P
0 g
s
.786 .758 .828 r
.13873 .28217 m .14097 .28034 L .14497 .28363 L p F P
0 g
s
.784 .758 .83 r
.14987 .27318 m .14097 .28034 L .14497 .28363 L p F P
0 g
s
.784 .758 .83 r
.14497 .28363 m .15343 .27682 L .14987 .27318 L p F P
0 g
s
.817 .756 .795 r
.11052 .31528 m .10854 .31732 L .10492 .31366 L p F P
0 g
s
.817 .756 .795 r
.10492 .31366 m .10652 .31201 L .11052 .31528 L p F P
0 g
s
.813 .756 .8 r
.11052 .31528 m .10652 .31201 L .11408 .30446 L p F P
0 g
s
.839 .747 .762 r
.08912 .34727 m .08936 .34697 L .08727 .34533 L closepath p F P
0 g
s
.831 .749 .774 r
.08549 .3435 m .09102 .33683 L p .08936 .34697 L F P
0 g
s
.831 .749 .774 r
.08936 .34697 m .08727 .34533 L .08549 .3435 L p F P
0 g
s
.63 .905 .984 r
.63279 .50928 m .63556 .5104 L .64702 .50612 L p F P
0 g
s
.652 .693 .875 r
.56131 .51069 m .5612 .51053 L .55189 .51331 L closepath p F P
0 g
s
.651 .673 .858 r
.55822 .50591 m .5612 .51053 L .55189 .51331 L p F P
0 g
s
.651 .673 .858 r
.54688 .50933 m .55822 .50591 L p .55189 .51331 L F P
0 g
s
.774 .578 .635 r
.33006 .33008 m .33479 .3311 L .33233 .33698 L p F P
0 g
s
.768 .571 .632 r
.34077 .33863 m .33233 .33698 L .33479 .3311 L p F P
0 g
s
.699 .54 .668 r
.41405 .37016 m .40163 .37045 L .40121 .36862 L p F P
0 g
s
.708 .545 .666 r
.40163 .37045 m .40121 .36862 L .39976 .37044 L closepath p F P
0 g
s
.73 .557 .658 r
.36259 .35485 m .35866 .36123 L .36903 .36223 L p F P
0 g
s
.745 .573 .661 r
.35281 .35366 m .36259 .35485 L .35866 .36123 L p F P
0 g
s
.843 .746 .757 r
.08423 .35369 m .08912 .34727 L .08727 .34533 L p F P
0 g
s
.678 .605 .767 r
.46489 .48003 m .46628 .48325 L p .45201 .48199 L F P
0 g
s
.678 .605 .767 r
.45201 .48199 m .45329 .48133 L .46489 .48003 L p F P
0 g
s
.676 .601 .764 r
.45201 .48199 m .45329 .48133 L .4518 .4815 L closepath p F P
0 g
s
.545 .534 .794 r
.6893 .31518 m .69016 .31442 L p .6972 .32162 L F P
0 g
s
.55 .544 .801 r
.6893 .31518 m .68897 .3144 L .69016 .31442 L closepath p F P
0 g
s
.595 .617 .844 r
.63089 .26894 m .64244 .26724 L .64534 .27265 L p F P
0 g
s
.597 .624 .849 r
.63954 .26188 m .64244 .26724 L .63089 .26894 L p F P
0 g
s
.597 .624 .849 r
.63368 .26279 m .63954 .26188 L p .63089 .26894 L F P
0 g
s
.597 .624 .849 r
.63089 .26894 m .62956 .26652 L .63368 .26279 L p F P
0 g
s
.852 .739 .738 r
.079 .37 m .08092 .36718 L .07729 .36324 L p F P
0 g
s
.656 .637 .819 r
.52653 .4971 m .52943 .50251 L .51758 .50529 L p F P
0 g
s
.656 .637 .819 r
.51758 .50529 m .51524 .50101 L .52653 .4971 L p F P
0 g
s
.821 .755 .79 r
.10358 .32261 m .10854 .31732 L .10492 .31366 L p F P
0 g
s
.742 .681 .791 r
.30295 .49682 m .29795 .50035 L .29469 .49531 L p F P
0 g
s
.676 .6 .763 r
.45329 .48133 m .4518 .4815 L .44894 .4748 L p F P
0 g
s
.651 .716 .896 r
.56416 .51471 m .57553 .51139 L .57847 .51516 L p F P
0 g
s
.649 .693 .877 r
.57258 .50722 m .57553 .51139 L .56416 .51471 L p F P
0 g
s
.649 .693 .877 r
.57054 .50782 m .57258 .50722 L p .56416 .51471 L F P
0 g
s
.649 .693 .877 r
.56416 .51471 m .56131 .51069 L .57054 .50782 L p F P
0 g
s
.889 .592 .478 r
.09473 .46552 m .08988 .46274 L .08966 .45769 L p F P
0 g
s
.892 .595 .475 r
.08486 .45488 m .08966 .45769 L .08988 .46274 L p F P
0 g
s
.889 .621 .526 r
.08966 .45769 m .08486 .45488 L .08517 .44968 L p F P
0 g
s
.8 .559 .574 r
.30781 .30621 m .30198 .30452 L .30285 .29923 L p F P
0 g
s
.813 .571 .571 r
.29603 .29698 m .30285 .29923 L .30198 .30452 L p F P
0 g
s
.825 .524 .479 r
.28336 .28219 m .28657 .28336 L .28547 .28758 L p F P
0 g
s
.843 .545 .484 r
.28997 .28949 m .28547 .28758 L .28657 .28336 L p F P
0 g
s
.607 .433 .621 r
.47367 .32296 m .48545 .31991 L p .47983 .32756 L F P
0 g
s
.607 .433 .621 r
.47983 .32756 m .47445 .32896 L .47367 .32296 L p F P
0 g
s
.604 .423 .609 r
.48481 .31408 m .48545 .31991 L .47367 .32296 L p F P
0 g
s
.55 .546 .803 r
.69016 .31442 m .68897 .3144 L .68605 .30765 L p F P
0 g
s
.723 .631 .755 r
.3728 .46444 m .37448 .46833 L .36783 .47346 L p F P
0 g
s
.723 .631 .755 r
.36759 .46413 m .3728 .46444 L p .36783 .47346 L F P
0 g
s
.723 .631 .755 r
.36015 .47017 m .36759 .46413 L p .36783 .47346 L F P
0 g
s
.723 .631 .755 r
.36783 .47346 m .36145 .473 L .36015 .47017 L p F P
0 g
s
.826 .752 .781 r
.09822 .33084 m .09709 .32969 L .09696 .32984 L closepath p F P
0 g
s
.699 .543 .673 r
.40163 .37045 m .41405 .37016 L .40753 .3774 L p F P
0 g
s
.699 .543 .673 r
.40753 .3774 m .40332 .3775 L .40163 .37045 L p F P
0 g
s
.708 .549 .671 r
.39976 .37044 m .40163 .37045 L .40332 .3775 L p F P
0 g
s
.893 .625 .525 r
.08044 .44683 m .08517 .44968 L .08486 .45488 L p F P
0 g
s
.888 .644 .564 r
.08517 .44968 m .08044 .44683 L .08124 .44148 L p F P
0 g
s
.708 .549 .671 r
.40332 .3775 m .39396 .37745 L .39976 .37044 L p F P
0 g
s
.712 .555 .674 r
.38702 .37022 m .39976 .37044 L .39396 .37745 L p F P
0 g
s
.886 .554 .416 r
.09891 .47228 m .09553 .47039 L .09473 .46552 L p F P
0 g
s
.889 .556 .411 r
.08988 .46274 m .09473 .46552 L .09553 .47039 L p F P
0 g
s
.732 .645 .761 r
.33461 .48143 m .33613 .48021 L .34587 .48135 L p F P
0 g
s
.724 .638 .762 r
.34581 .47249 m .33613 .48021 L .34587 .48135 L p F P
0 g
s
.724 .638 .762 r
.34587 .48135 m .34896 .47901 L .34581 .47249 L p F P
0 g
s
.878 .703 .661 r
.07041 .40702 m .07482 .41003 L .07244 .41587 L p F P
0 g
s
.873 .709 .676 r
.07482 .41003 m .07041 .40702 L .07313 .40107 L p F P
0 g
s
.749 .569 .652 r
.35281 .35366 m .35189 .35353 L .35037 .34664 L p F P
0 g
s
.75 .57 .651 r
.3468 .34614 m .35037 .34664 L .35189 .35353 L p F P
0 g
s
.678 .603 .765 r
.46489 .48003 m .46321 .47615 L .45329 .48133 L closepath p F P
0 g
s
.676 .6 .763 r
.46096 .47069 m .46321 .47615 L .45329 .48133 L p F P
0 g
s
.676 .6 .763 r
.45542 .47129 m .46096 .47069 L p .45329 .48133 L F P
0 g
s
.676 .6 .763 r
.44894 .4748 m .45542 .47129 L p .45329 .48133 L F P
0 g
s
.668 .746 .909 r
.21176 .51235 m .20099 .51579 L .19748 .51282 L p F P
0 g
s
.654 .748 .919 r
.20099 .51579 m .21176 .51235 L .21523 .51561 L p F P
0 g
s
.722 .734 .86 r
.24384 .51342 m .24501 .51279 L .24257 .51198 L closepath p F P
0 g
s
.704 .728 .869 r
.24257 .51198 m .24384 .51342 L p .22952 .51476 L F P
0 g
s
.673 .516 .664 r
.42811 .36246 m .43866 .36141 L .43065 .36913 L p F P
0 g
s
.673 .516 .664 r
.43065 .36913 m .42955 .36924 L .42811 .36246 L p F P
0 g
s
.691 .533 .667 r
.42811 .36246 m .42955 .36924 L .41584 .37011 L p F P
0 g
s
.531 .758 .98 r
.17728 .51298 m .18326 .51244 L .1797 .50965 L p F P
0 g
s
.531 .758 .98 r
.1797 .50965 m .17096 .51076 L .17728 .51298 L p F P
0 g
s
.447 .747 .992 r
.16914 .51093 m .17096 .51076 L .17728 .51298 L p F P
0 g
s
.66 .5 .657 r
.44098 .35909 m .44711 .35355 L .44008 .35451 L closepath p F P
0 g
s
.673 .514 .662 r
.44008 .35451 m .44098 .35909 L .43866 .36141 L p F P
0 g
s
.732 .561 .66 r
.36979 .36229 m .36958 .36138 L .36903 .36223 L closepath p F P
0 g
s
.696 .536 .666 r
.41584 .37011 m .41548 .36851 L .41405 .37016 L closepath p F P
0 g
s
.685 .599 .754 r
.44786 .47216 m .44894 .4748 L p .43468 .47391 L F P
0 g
s
.685 .599 .754 r
.43468 .47391 m .43604 .47311 L .44786 .47216 L p F P
0 g
s
.684 .598 .753 r
.43468 .47391 m .43604 .47311 L .43441 .47325 L closepath p F P
0 g
s
.749 .564 .645 r
.34077 .33863 m .33785 .34466 L .3468 .34614 L p F P
0 g
s
.768 .582 .646 r
.33233 .33698 m .34077 .33863 L .33785 .34466 L p F P
0 g
s
.83 .469 .374 r
.28336 .28219 m .27721 .2797 L .27574 .27524 L p F P
0 g
s
.847 .489 .375 r
.27014 .27255 m .27574 .27524 L .27721 .2797 L p F P
0 g
s
.66 .628 .807 r
.50095 .49934 m .51221 .49514 L .51524 .50101 L p F P
0 g
s
.659 .62 .8 r
.51153 .49375 m .51221 .49514 L .50095 .49934 L p F P
0 g
s
.659 .62 .8 r
.50095 .49934 m .49939 .49623 L .51153 .49375 L p F P
0 g
s
.725 .691 .818 r
.28029 .49806 m .27232 .50324 L .28009 .50499 L p F P
0 g
s
.725 .691 .818 r
.28009 .50499 m .28358 .50285 L .28029 .49806 L p F P
0 g
s
.735 .699 .816 r
.2692 .50529 m .27232 .50324 L .28009 .50499 L p F P
0 g
s
.582 .6 .836 r
.65695 .27141 m .65985 .27709 L .64824 .2783 L p F P
0 g
s
.582 .6 .836 r
.64641 .27252 m .65695 .27141 L p .64824 .2783 L F P
0 g
s
.582 .6 .836 r
.64824 .2783 m .64564 .27323 L .64641 .27252 L p F P
0 g
s
.737 .663 .777 r
.32344 .48992 m .32463 .48902 L .32278 .48873 L closepath p F P
0 g
s
.734 .66 .777 r
.32278 .48873 m .32344 .48992 L p .30908 .49253 L F P
0 g
s
.684 .597 .752 r
.43604 .47311 m .43441 .47325 L .4316 .46639 L p F P
0 g
s
.512 .464 .74 r
.71854 .36248 m .71773 .3623 L .71833 .36182 L closepath p F P
0 g
s
.52 .478 .75 r
.71773 .3623 m .71833 .36182 L .71554 .3536 L p F P
0 g
s
.774 .757 .838 r
.156 .27488 m .15343 .27682 L .14987 .27318 L p F P
0 g
s
.712 .555 .674 r
.3869 .37037 m .38702 .37022 L p .39396 .37745 L F P
0 g
s
.715 .554 .669 r
.3869 .37037 m .38702 .37022 L .38686 .37021 L closepath p F P
0 g
s
.728 .563 .667 r
.37535 .36965 m .37151 .36938 L .36979 .36229 L p F P
0 g
s
.732 .566 .666 r
.36903 .36223 m .36979 .36229 L .37151 .36938 L p F P
0 g
s
.708 .607 .741 r
.40262 .46516 m .40306 .46624 L p .38878 .46701 L F P
0 g
s
.708 .607 .741 r
.38878 .46701 m .39132 .46509 L .40262 .46516 L p F P
0 g
s
.71 .611 .745 r
.38878 .46701 m .39132 .46509 L .38796 .46503 L closepath p F P
0 g
s
.725 .566 .674 r
.38686 .37021 m .3869 .37037 L .38168 .37707 L p F P
0 g
s
.725 .566 .674 r
.37535 .36965 m .38686 .37021 L p .38168 .37707 L F P
0 g
s
.612 .642 .856 r
.61358 .26099 m .62508 .25871 L .62799 .26374 L p F P
0 g
s
.615 .654 .865 r
.62218 .25379 m .62508 .25871 L .61358 .26099 L p F P
0 g
s
.615 .654 .865 r
.61256 .25581 m .62218 .25379 L p .61358 .26099 L F P
0 g
s
.615 .654 .865 r
.61358 .26099 m .61117 .25702 L .61256 .25581 L p F P
0 g
s
.701 .601 .742 r
.41687 .46487 m .41733 .46603 L p .40306 .46624 L F P
0 g
s
.701 .601 .742 r
.40306 .46624 m .40462 .46513 L .41687 .46487 L p F P
0 g
s
.702 .604 .744 r
.40306 .46624 m .40462 .46513 L .40262 .46516 L closepath p F P
0 g
s
.712 .555 .674 r
.39396 .37745 m .38863 .37735 L .3869 .37037 L p F P
0 g
s
.719 .559 .672 r
.38863 .37735 m .3869 .37037 L .38168 .37707 L closepath p F P
0 g
s
.45 .338 .634 r
.72396 .42508 m .72859 .42181 L .72448 .41772 L p F P
0 g
s
.448 .337 .636 r
.73196 .41233 m .72448 .41772 L .72859 .42181 L p F P
0 g
s
.464 .364 .656 r
.73118 .40851 m .73196 .41233 L .72448 .41772 L p F P
0 g
s
.464 .364 .656 r
.72911 .40695 m .73118 .40851 L p .72448 .41772 L F P
0 g
s
.891 .648 .564 r
.07658 .4386 m .08124 .44148 L .08044 .44683 L p F P
0 g
s
.886 .663 .595 r
.08124 .44148 m .07658 .4386 L .07782 .43311 L p F P
0 g
s
.697 .54 .671 r
.41405 .37016 m .41584 .37011 L .41748 .3771 L p F P
0 g
s
.697 .54 .671 r
.41748 .3771 m .40753 .3774 L .41405 .37016 L p F P
0 g
s
.824 .755 .787 r
.10358 .32261 m .09709 .32969 L .09346 .32603 L p F P
0 g
s
.824 .755 .787 r
.09346 .32603 m .09959 .31935 L .10358 .32261 L p F P
0 g
s
.821 .755 .79 r
.10492 .31366 m .09959 .31935 L .10358 .32261 L p F P
0 g
s
.73 .633 .75 r
.35701 .47265 m .34896 .47901 L .34581 .47249 L p F P
0 g
s
.741 .575 .668 r
.35866 .36123 m .36903 .36223 L .36455 .3688 L p F P
0 g
s
.732 .566 .666 r
.37151 .36938 m .36455 .3688 L .36903 .36223 L p F P
0 g
s
.737 .662 .776 r
.33383 .4799 m .33461 .48143 L .32463 .48902 L p F P
0 g
s
.737 .662 .776 r
.32665 .47898 m .33383 .4799 L p .32463 .48902 L F P
0 g
s
.737 .662 .776 r
.32024 .48412 m .32665 .47898 L p .32463 .48902 L F P
0 g
s
.737 .662 .776 r
.32463 .48902 m .32278 .48873 L .32024 .48412 L p F P
0 g
s
.723 .733 .859 r
.25146 .50335 m .25482 .50755 L .24501 .51279 L p F P
0 g
s
.723 .733 .859 r
.24045 .50959 m .25146 .50335 L p .24501 .51279 L F P
0 g
s
.723 .733 .859 r
.24501 .51279 m .24257 .51198 L .24045 .50959 L p F P
0 g
s
.704 .728 .869 r
.22952 .51476 m .23763 .51092 L .24257 .51198 L p F P
0 g
s
.714 .73 .863 r
.23763 .51092 m .22952 .51476 L .22609 .51122 L p F P
0 g
s
.685 .74 .892 r
.21523 .51561 m .22609 .51122 L .22952 .51476 L p F P
0 g
s
.862 .462 .279 r
.09891 .47228 m .10049 .47312 L .10223 .47771 L p F P
0 g
s
.862 .471 .299 r
.10735 .48038 m .10223 .47771 L .10049 .47312 L p F P
0 g
s
.686 .533 .673 r
.41584 .37011 m .42955 .36924 L p .42298 .37675 L F P
0 g
s
.686 .533 .673 r
.42298 .37675 m .41748 .3771 L .41584 .37011 L p F P
0 g
s
.685 .598 .752 r
.44786 .47216 m .44587 .46729 L .43604 .47311 L closepath p F P
0 g
s
.684 .597 .752 r
.44425 .46315 m .44587 .46729 L .43604 .47311 L p F P
0 g
s
.684 .597 .752 r
.43579 .4638 m .44425 .46315 L p .43604 .47311 L F P
0 g
s
.684 .597 .752 r
.4316 .46639 m .43579 .4638 L p .43604 .47311 L F P
0 g
s
.87 .717 .69 r
.07448 .39386 m .07184 .39197 L p .07313 .40107 L F P
0 g
s
.865 .723 .704 r
.07448 .39386 m .07228 .39116 L .07184 .39197 L closepath p F P
0 g
s
.695 .737 .883 r
.22609 .51122 m .21523 .51561 L .21176 .51235 L p F P
0 g
s
.702 .603 .743 r
.40462 .46513 m .40262 .46516 L .39997 .45856 L p F P
0 g
s
.708 .606 .741 r
.40262 .46516 m .39997 .45856 L .39132 .46509 L closepath p F P
0 g
s
.305 0 0 r
.13771 .50062 m .14168 .50208 L .14728 .50455 L p F P
0 g
s
0 .376 .722 r
.14168 .50208 m .13771 .50062 L .13398 .49896 L p F P
0 g
s
.645 .483 .65 r
.45222 .34872 m .45615 .3455 L .45178 .34626 L closepath p F P
0 g
s
.659 .496 .652 r
.45178 .34626 m .45222 .34872 L .44711 .35355 L p F P
0 g
s
.702 .603 .743 r
.41341 .45602 m .41425 .45824 L .40462 .46513 L p F P
0 g
s
.702 .603 .743 r
.40315 .45618 m .41341 .45602 L p .40462 .46513 L F P
0 g
s
.702 .603 .743 r
.39997 .45856 m .40315 .45618 L p .40462 .46513 L F P
0 g
s
.701 .6 .741 r
.41687 .46487 m .41425 .45824 L .40462 .46513 L closepath p F P
0 g
s
.803 .576 .595 r
.30829 .31032 m .30914 .30664 L p .31495 .31421 L F P
0 g
s
.809 .582 .594 r
.30829 .31032 m .30914 .30664 L .30781 .30621 L closepath p F P
0 g
s
.742 .681 .791 r
.29469 .49531 m .29488 .49517 L .30295 .49682 L p F P
0 g
s
.731 .67 .79 r
.30585 .48706 m .29488 .49517 L .30295 .49682 L p F P
0 g
s
.731 .67 .79 r
.30295 .49682 m .30908 .49253 L .30585 .48706 L p F P
0 g
s
.857 .736 .729 r
.07484 .36685 m .079 .37 L .07491 .37638 L p F P
0 g
s
.852 .739 .738 r
.07729 .36324 m .07484 .36685 L .079 .37 L p F P
0 g
s
.71 .611 .744 r
.39906 .45622 m .39997 .45856 L .39132 .46509 L p F P
0 g
s
.71 .611 .744 r
.38997 .4561 m .39906 .45622 L p .39132 .46509 L F P
0 g
s
.71 .611 .744 r
.38568 .45951 m .38997 .4561 L p .39132 .46509 L F P
0 g
s
.71 .611 .744 r
.39132 .46509 m .38796 .46503 L .38568 .45951 L p F P
0 g
s
.774 .757 .838 r
.14987 .27318 m .152 .27157 L .156 .27488 L p F P
0 g
s
.773 .758 .84 r
.16095 .2649 m .152 .27157 L .156 .27488 L p F P
0 g
s
.773 .758 .84 r
.156 .27488 m .1645 .26854 L .16095 .2649 L p F P
0 g
s
.724 .632 .754 r
.36145 .473 m .36015 .47017 L .35701 .47265 L closepath p F P
0 g
s
.718 .62 .746 r
.37448 .46833 m .37903 .46474 L .3728 .46444 L closepath p F P
0 g
s
.715 .613 .742 r
.38796 .46503 m .38568 .45951 L .37903 .46474 L closepath p F P
0 g
s
.653 .648 .833 r
.54388 .50438 m .53256 .50797 L .52955 .50274 L p F P
0 g
s
.653 .659 .843 r
.53256 .50797 m .54388 .50438 L .54688 .50933 L p F P
0 g
s
.864 .727 .709 r
.07535 .38578 m .07228 .39116 L .06868 .38691 L p F P
0 g
s
.864 .727 .709 r
.06868 .38691 m .07108 .38268 L .07535 .38578 L p F P
0 g
s
.859 .73 .719 r
.07535 .38578 m .07108 .38268 L .07491 .37638 L p F P
0 g
s
.75 .57 .651 r
.35189 .35353 m .34341 .35234 L .3468 .34614 L p F P
0 g
s
.763 .58 .649 r
.33785 .34466 m .3468 .34614 L .34341 .35234 L p F P
0 g
s
.623 .748 .937 r
.21873 .2544 m .22946 .25155 L .23293 .2548 L p F P
0 g
s
.611 .745 .94 r
.22946 .25155 m .21873 .2544 L .21525 .25091 L p F P
0 g
s
.69 .752 .899 r
.20441 .25555 m .21525 .25091 L .21873 .2544 L p F P
0 g
s
.649 .745 .919 r
.57847 .51516 m .58987 .51187 L .59277 .51515 L p F P
0 g
s
.649 .718 .899 r
.58987 .51187 m .57847 .51516 L .57553 .51139 L p F P
0 g
s
.693 .596 .743 r
.43074 .4642 m .4316 .46639 L p .41733 .46603 L F P
0 g
s
.693 .596 .743 r
.41733 .46603 m .41924 .46476 L .43074 .4642 L p F P
0 g
s
.694 .598 .744 r
.41733 .46603 m .41924 .46476 L .41687 .46487 L closepath p F P
0 g
s
.545 .534 .794 r
.69016 .31442 m .70075 .31486 L p .6972 .32162 L F P
0 g
s
.543 .535 .796 r
.69016 .31442 m .70075 .31486 L .69783 .30786 L p F P
0 g
s
.543 .535 .796 r
.69783 .30786 m .69739 .30784 L .69016 .31442 L p F P
0 g
s
.55 .546 .803 r
.68605 .30765 m .69739 .30784 L .69016 .31442 L p F P
0 g
s
.447 .319 .613 r
.72154 .43328 m .72487 .43106 L .72396 .42508 L p F P
0 g
s
.428 .286 .585 r
.72487 .43106 m .72154 .43328 L .72381 .43795 L p F P
0 g
s
0 0 0 r
.67286 .49503 m .67258 .49526 L .66115 .50095 L p F P
0 g
s
.442 .871 .768 r
.65947 .50144 m .66115 .50095 L .67258 .49526 L p F P
0 g
s
.734 .66 .777 r
.30908 .49253 m .31548 .4877 L .32278 .48873 L p F P
0 g
s
.734 .661 .778 r
.32278 .48873 m .32024 .48412 L .31548 .4877 L closepath p F P
0 g
s
.665 .613 .787 r
.48361 .4915 m .49485 .48679 L .4979 .49324 L p F P
0 g
s
.663 .608 .783 r
.4944 .48578 m .49485 .48679 L .48361 .4915 L p F P
0 g
s
.663 .608 .783 r
.48361 .4915 m .48198 .48797 L .4944 .48578 L p F P
0 g
s
.505 .294 .527 r
.50654 .29566 m .50652 .29057 L .5172 .28617 L p F P
0 g
s
.474 .232 .467 r
.51753 .28151 m .5172 .28617 L .50652 .29057 L p F P
0 g
s
.074 .558 .897 r
.14728 .50455 m .15151 .50571 L .14785 .5035 L p F P
0 g
s
.074 .558 .897 r
.14785 .5035 m .14168 .50208 L .14728 .50455 L p F P
0 g
s
.498 .446 .729 r
.72089 .36978 m .72707 .36467 L p .72763 .37391 L F P
0 g
s
.498 .446 .729 r
.72763 .37391 m .72159 .37208 L .72089 .36978 L p F P
0 g
s
.504 .459 .74 r
.72089 .36978 m .71854 .36248 L .72707 .36467 L closepath p F P
0 g
s
.694 .597 .743 r
.41924 .46476 m .41687 .46487 L .41425 .45824 L p F P
0 g
s
.627 .874 .988 r
.63279 .50928 m .63279 .50928 L .62134 .51307 L p F P
0 g
s
.636 .847 .981 r
.63279 .50928 m .62134 .51307 L .61851 .51101 L p F P
0 g
s
.638 .833 .975 r
.60707 .51452 m .61851 .51101 L .62134 .51307 L p F P
0 g
s
.504 .459 .74 r
.72707 .36467 m .71854 .36248 L .71833 .36182 L p F P
0 g
s
.51 .472 .751 r
.71559 .35356 m .71554 .3536 L .71833 .36182 L p F P
0 g
s
.51 .472 .751 r
.71833 .36182 m .72559 .3557 L .71559 .35356 L p F P
0 g
s
.504 .459 .74 r
.71833 .36182 m .72559 .3557 L p .72707 .36467 L F P
0 g
s
.687 .752 .901 r
.21525 .25091 m .20441 .25555 L .20092 .25195 L p F P
0 g
s
.774 .578 .635 r
.33233 .33698 m .33139 .33678 L .33006 .33008 L p F P
0 g
s
.77 .576 .636 r
.32657 .32937 m .33006 .33008 L .33139 .33678 L p F P
0 g
s
.738 .679 .794 r
.29469 .49531 m .28358 .50285 L .28029 .49806 L p F P
0 g
s
.498 .446 .729 r
.72324 .37747 m .72159 .37208 L .72763 .37391 L closepath p F P
0 g
s
.566 .571 .818 r
.66637 .29045 m .66817 .28879 L p .6795 .29462 L F P
0 g
s
.57 .58 .824 r
.66637 .29045 m .66565 .28894 L .66817 .28879 L closepath p F P
0 g
s
.883 .679 .621 r
.07782 .43311 m .07324 .43019 L .0749 .42457 L p F P
0 g
s
.889 .667 .596 r
.07324 .43019 m .07782 .43311 L .07658 .4386 L p F P
0 g
s
.791 .576 .61 r
.32076 .32179 m .31328 .3198 L .31495 .31421 L p F P
0 g
s
.801 .587 .613 r
.30852 .31227 m .31495 .31421 L .31328 .3198 L p F P
0 g
s
.803 .576 .595 r
.31495 .31421 m .30852 .31227 L .30829 .31032 L p F P
0 g
s
.725 .566 .674 r
.37254 .37351 m .37535 .36965 L p .38168 .37707 L F P
0 g
s
.728 .565 .67 r
.37254 .37351 m .37535 .36965 L .37151 .36938 L closepath p F P
0 g
s
.693 .595 .742 r
.43074 .4642 m .42853 .45853 L .41924 .46476 L closepath p F P
0 g
s
.694 .597 .743 r
.42736 .45542 m .42853 .45853 L .41924 .46476 L p F P
0 g
s
.694 .597 .743 r
.41766 .45584 m .42736 .45542 L p .41924 .46476 L F P
0 g
s
.694 .597 .743 r
.41425 .45824 m .41766 .45584 L p .41924 .46476 L F P
0 g
s
.651 .706 .887 r
.58199 .25413 m .5934 .25061 L .59632 .25469 L p F P
0 g
s
.664 .729 .898 r
.5934 .25061 m .58199 .25413 L .57907 .25072 L p F P
0 g
s
.676 .755 .911 r
.5677 .25492 m .57907 .25072 L .58199 .25413 L p F P
0 g
s
.696 .796 .927 r
.57907 .25072 m .5677 .25492 L .56478 .25261 L p F P
0 g
s
.665 .878 .978 r
.5677 .25492 m .56478 .25261 L p .55365 .25783 L F P
0 g
s
.718 .619 .745 r
.38426 .45597 m .38568 .45951 L .37903 .46474 L p F P
0 g
s
.718 .619 .745 r
.3778 .45571 m .38426 .45597 L p .37903 .46474 L F P
0 g
s
.718 .619 .745 r
.37136 .46106 m .3778 .45571 L p .37903 .46474 L F P
0 g
s
.718 .619 .745 r
.37903 .46474 m .3728 .46444 L .37136 .46106 L p F P
0 g
s
.795 .572 .598 r
.30781 .30621 m .30198 .30452 L p .30785 .31209 L F P
0 g
s
.795 .572 .598 r
.30785 .31209 m .30829 .31032 L .30781 .30621 L p F P
0 g
s
.73 .633 .75 r
.34581 .47249 m .34682 .47165 L .35701 .47265 L p F P
0 g
s
.722 .627 .751 r
.35693 .46326 m .34682 .47165 L .35701 .47265 L p F P
0 g
s
.722 .627 .751 r
.35706 .46328 m .35693 .46326 L p .35701 .47265 L F P
0 g
s
.722 .627 .751 r
.35701 .47265 m .36015 .47017 L .35706 .46328 L p F P
0 g
s
.669 .599 .768 r
.46628 .48325 m .47675 .47828 L .46489 .48003 L closepath p F P
0 g
s
.434 .31 .611 r
.72859 .42181 m .72396 .42508 L .72487 .43106 L p F P
0 g
s
.699 .546 .676 r
.40419 .38103 m .40753 .3774 L .40332 .3775 L closepath p F P
0 g
s
.709 .558 .681 r
.40332 .3775 m .40419 .38103 L .40093 .38467 L p F P
0 g
s
.709 .558 .681 r
.39396 .37745 m .40332 .3775 L p .40093 .38467 L F P
0 g
s
.419 0 0 r
.12982 .49639 m .13398 .49896 L .13026 .49711 L p F P
0 g
s
.419 0 0 r
.13026 .49711 m .12445 .49383 L .12982 .49639 L p F P
0 g
s
.585 .408 .608 r
.48545 .31991 m .48481 .31408 L .49624 .31061 L p F P
0 g
s
.579 .392 .591 r
.49576 .30498 m .49624 .31061 L .48481 .31408 L p F P
0 g
s
.601 .631 .853 r
.62956 .26652 m .62799 .26374 L .63368 .26279 L closepath p F P
0 g
s
.492 .432 .718 r
.72324 .37747 m .72763 .37391 L p .72728 .38343 L F P
0 g
s
.492 .432 .718 r
.72728 .38343 m .72469 .3825 L .72324 .37747 L p F P
0 g
s
.846 .745 .752 r
.08014 .35049 m .08423 .35369 L .07933 .36034 L p F P
0 g
s
.843 .746 .757 r
.08528 .34376 m .08014 .35049 L .08423 .35369 L p F P
0 g
s
.843 .746 .757 r
.08727 .34533 m .08528 .34376 L p .08423 .35369 L F P
0 g
s
.709 .558 .681 r
.38988 .38228 m .39396 .37745 L p .40093 .38467 L F P
0 g
s
.712 .557 .676 r
.38988 .38228 m .39396 .37745 L .38863 .37735 L closepath p F P
0 g
s
.745 .573 .661 r
.35218 .35474 m .35281 .35366 L p .35866 .36123 L F P
0 g
s
.749 .574 .658 r
.35218 .35474 m .35281 .35366 L .35189 .35353 L closepath p F P
0 g
s
.646 .783 .947 r
.59277 .51515 m .60419 .5118 L .60707 .51452 L p F P
0 g
s
.648 .75 .924 r
.60419 .5118 m .59277 .51515 L .58987 .51187 L p F P
0 g
s
.828 .755 .782 r
.09696 .32984 m .09709 .32969 L .09346 .32603 L p F P
0 g
s
.649 .49 .655 r
.45299 .35277 m .45222 .34872 L .45615 .3455 L p F P
0 g
s
.66 .498 .653 r
.45299 .35277 m .45222 .34872 L .44711 .35355 L closepath p F P
0 g
s
.482 .402 .69 r
.72786 .39423 m .72584 .39326 L .72733 .39214 L closepath p F P
0 g
s
.492 .421 .705 r
.72584 .39326 m .72733 .39214 L .72539 .38493 L p F P
0 g
s
.828 .755 .782 r
.09346 .32603 m .09297 .32658 L .09696 .32984 L p F P
0 g
s
.833 .753 .775 r
.09297 .32658 m .09696 .32984 L .09102 .33683 L p F P
0 g
s
.697 .548 .681 r
.40753 .3774 m .41748 .3771 L p .41538 .38434 L F P
0 g
s
.697 .548 .681 r
.40419 .38103 m .40753 .3774 L p .41538 .38434 L F P
0 g
s
.677 .594 .756 r
.44894 .4748 m .45542 .47129 L .44786 .47216 L closepath p F P
0 g
s
.628 .465 .642 r
.46346 .33913 m .46632 .33708 L .46323 .33774 L closepath p F P
0 g
s
.643 .476 .643 r
.46323 .33774 m .46346 .33913 L .45615 .3455 L p F P
0 g
s
.518 .486 .76 r
.71554 .3536 m .71553 .35355 L .71559 .35356 L closepath p F P
0 g
s
.664 .507 .662 r
.4414 .36115 m .44098 .35909 L .44711 .35355 L p F P
0 g
s
.673 .513 .66 r
.4414 .36115 m .44098 .35909 L .43866 .36141 L closepath p F P
0 g
s
.518 .486 .761 r
.71559 .35356 m .71553 .35355 L .71254 .34512 L p F P
0 g
s
.713 .557 .676 r
.38863 .37735 m .38168 .37707 L p .38802 .3845 L F P
0 g
s
.713 .557 .676 r
.38802 .3845 m .38988 .38228 L .38863 .37735 L p F P
0 g
s
.646 .792 .953 r
.61851 .51101 m .60707 .51452 L .60419 .5118 L p F P
0 g
s
.51 .474 .753 r
.72319 .34701 m .71559 .35356 L .72559 .3557 L p F P
0 g
s
.518 .486 .761 r
.71254 .34512 m .72319 .34701 L .71559 .35356 L p F P
0 g
s
.664 .507 .662 r
.44711 .35355 m .45299 .35277 L p .4414 .36115 L F P
0 g
s
.827 .375 .153 r
.11505 .48737 m .10995 .48471 L .10735 .48038 L p F P
0 g
s
.824 .367 .135 r
.10223 .47771 m .10735 .48038 L .10995 .48471 L p F P
0 g
s
.661 .621 .799 r
.50917 .48889 m .51153 .49375 L .49939 .49623 L p F P
0 g
s
.661 .621 .799 r
.49939 .49623 m .4979 .49324 L .50917 .48889 L p F P
0 g
s
.726 .629 .75 r
.36015 .47017 m .36759 .46413 L .35706 .46328 L closepath p F P
0 g
s
.825 .524 .479 r
.28547 .28758 m .28387 .28699 L .28336 .28219 L p F P
0 g
s
.835 .534 .479 r
.27721 .2797 m .28336 .28219 L .28387 .28699 L p F P
0 g
s
.744 .571 .659 r
.35189 .35353 m .34341 .35234 L p .34898 .36001 L F P
0 g
s
.744 .571 .659 r
.34898 .36001 m .35218 .35474 L .35189 .35353 L p F P
0 g
s
.726 .564 .671 r
.37151 .36938 m .36455 .3688 L p .37044 .37637 L F P
0 g
s
.726 .564 .671 r
.37044 .37637 m .37254 .37351 L .37151 .36938 L p F P
0 g
s
.876 .713 .677 r
.06881 .39802 m .07313 .40107 L .07041 .40702 L p F P
0 g
s
.87 .717 .69 r
.07184 .39197 m .06881 .39802 L .07313 .40107 L p F P
0 g
s
.779 .575 .624 r
.32657 .32937 m .31865 .32754 L .32076 .32179 L p F P
0 g
s
.793 .587 .622 r
.31328 .3198 m .32076 .32179 L .31865 .32754 L p F P
0 g
s
.674 .517 .665 r
.43866 .36141 m .4414 .36115 L .44287 .36794 L p F P
0 g
s
.674 .517 .665 r
.44287 .36794 m .43065 .36913 L .43866 .36141 L p F P
0 g
s
.735 .65 .765 r
.33461 .48143 m .33613 .48021 L .33383 .4799 L closepath p F P
0 g
s
.742 .666 .775 r
.31548 .4877 m .30908 .49253 L .30585 .48706 L p F P
0 g
s
.721 .62 .744 r
.3728 .46444 m .37136 .46106 L .36759 .46413 L closepath p F P
0 g
s
.686 .592 .745 r
.4316 .46639 m .43579 .4638 L .43074 .4642 L closepath p F P
0 g
s
.703 .728 .87 r
.24257 .51198 m .24045 .50959 L .23763 .51092 L closepath p F P
0 g
s
.649 .49 .655 r
.45615 .3455 m .46433 .34412 L p .45299 .35277 L F P
0 g
s
.646 .481 .645 r
.46433 .34412 m .46346 .33913 L .45615 .3455 L closepath p F P
0 g
s
.501 .702 .96 r
.23293 .2548 m .23942 .25469 L .2445 .2576 L p F P
0 g
s
.471 .69 .963 r
.23942 .25469 m .23293 .2548 L .22946 .25155 L p F P
0 g
s
.704 .6 .737 r
.39997 .45856 m .40315 .45618 L .39906 .45622 L closepath p F P
0 g
s
.686 .533 .673 r
.42955 .36924 m .42972 .37 L .42298 .37675 L p F P
0 g
s
.674 .521 .669 r
.42972 .37 m .43065 .36913 L .42955 .36924 L closepath p F P
0 g
s
.569 .582 .827 r
.66817 .28879 m .66565 .28894 L .66275 .28298 L p F P
0 g
s
.745 .573 .661 r
.35866 .36123 m .35359 .3606 L .35218 .35474 L p F P
0 g
s
.746 .574 .661 r
.35359 .3606 m .35218 .35474 L .34898 .36001 L closepath p F P
0 g
s
.492 .432 .717 r
.72539 .38493 m .72469 .3825 L .72728 .38343 L closepath p F P
0 g
s
.862 .462 .279 r
.09616 .4725 m .09891 .47228 L p .10223 .47771 L F P
0 g
s
.878 .507 .337 r
.09616 .4725 m .09553 .47039 L .09891 .47228 L closepath p F P
0 g
s
.736 .649 .764 r
.34533 .47148 m .34581 .47249 L .33613 .48021 L p F P
0 g
s
.736 .649 .764 r
.33693 .47055 m .34533 .47148 L p .33613 .48021 L F P
0 g
s
.736 .649 .764 r
.33144 .47517 m .33693 .47055 L p .33613 .48021 L F P
0 g
s
.736 .649 .764 r
.33613 .48021 m .33383 .4799 L .33144 .47517 L p F P
0 g
s
.541 .524 .786 r
.6972 .32162 m .70368 .32204 L p .70328 .32914 L F P
0 g
s
.539 .525 .788 r
.70368 .32204 m .6972 .32162 L .70186 .31751 L closepath p F P
0 g
s
.545 .534 .794 r
.70075 .31486 m .70186 .31751 L .6972 .32162 L p F P
0 g
s
.686 .535 .676 r
.41846 .38117 m .42298 .37675 L .41748 .3771 L closepath p F P
0 g
s
.697 .548 .681 r
.41748 .3771 m .41846 .38117 L .41538 .38434 L p F P
0 g
s
.713 .607 .738 r
.38568 .45951 m .38997 .4561 L .38426 .45597 L closepath p F P
0 g
s
.697 .548 .681 r
.41538 .38434 m .40511 .38466 L .40419 .38103 L p F P
0 g
s
.706 .553 .678 r
.40511 .38466 m .40419 .38103 L .40093 .38467 L closepath p F P
0 g
s
.741 .575 .668 r
.35513 .3668 m .35866 .36123 L p .36455 .3688 L F P
0 g
s
.745 .575 .665 r
.35513 .3668 m .35866 .36123 L .35359 .3606 L closepath p F P
0 g
s
.713 .557 .676 r
.38168 .37707 m .37627 .38396 L .38802 .3845 L p F P
0 g
s
.725 .568 .678 r
.37334 .37658 m .38168 .37707 L .37627 .38396 L p F P
0 g
s
.725 .566 .674 r
.38168 .37707 m .37334 .37658 L .37254 .37351 L p F P
0 g
s
.673 .524 .675 r
.43065 .36913 m .44287 .36794 L p .44145 .37513 L F P
0 g
s
.673 .524 .675 r
.42972 .37 m .43065 .36913 L p .44145 .37513 L F P
0 g
s
.673 .524 .675 r
.44145 .37513 m .43117 .37621 L .42972 .37 L p F P
0 g
s
.685 .532 .672 r
.43117 .37621 m .42972 .37 L .42298 .37675 L closepath p F P
0 g
s
.838 .749 .766 r
.08727 .34533 m .08549 .3435 L .08528 .34376 L closepath p F P
0 g
s
.761 .757 .849 r
.169 .26543 m .1645 .26854 L .16095 .2649 L p F P
0 g
s
.378 .197 .506 r
.72486 .443 m .71663 .44839 L .7168 .45354 L p F P
0 g
s
.408 .248 .55 r
.71663 .44839 m .72486 .443 L .72381 .43795 L p F P
0 g
s
.393 .208 .508 r
.71306 .45586 m .7168 .45354 L .71663 .44839 L p F P
0 g
s
.632 .471 .647 r
.46433 .34412 m .46346 .33913 L .46632 .33708 L p F P
0 g
s
.677 .594 .755 r
.45542 .47129 m .44786 .47216 L .44587 .46729 L p F P
0 g
s
.312 .071 .378 r
.7111 .46181 m .70715 .46423 L .7067 .4687 L p F P
0 g
s
.362 .152 .454 r
.70715 .46423 m .7111 .46181 L .71306 .45586 L p F P
0 g
s
.66 .508 .667 r
.4414 .36115 m .45432 .35941 L p .45162 .36671 L F P
0 g
s
.66 .508 .667 r
.45162 .36671 m .44287 .36794 L .4414 .36115 L p F P
0 g
s
.664 .507 .662 r
.45299 .35277 m .45432 .35941 L .4414 .36115 L p F P
0 g
s
.482 .414 .704 r
.72728 .38343 m .72539 .38493 L .72733 .39214 L p F P
0 g
s
.886 .683 .622 r
.0704 .42161 m .0749 .42457 L .07324 .43019 L p F P
0 g
s
.881 .692 .643 r
.0749 .42457 m .0704 .42161 L .07244 .41587 L p F P
0 g
s
.686 .591 .745 r
.43579 .4638 m .43074 .4642 L .42853 .45853 L p F P
0 g
s
.666 .609 .781 r
.4918 .47997 m .4944 .48578 L .48198 .48797 L p F P
0 g
s
.666 .609 .781 r
.48198 .48797 m .48056 .48487 L .4918 .47997 L p F P
0 g
s
.746 .756 .861 r
.17552 .26097 m .18552 .25473 L .18954 .25804 L p F P
0 g
s
.745 .756 .861 r
.1865 .25412 m .18552 .25473 L .18954 .25804 L p F P
0 g
s
.745 .756 .861 r
.18954 .25804 m .19002 .25774 L .1865 .25412 L p F P
0 g
s
.669 .599 .768 r
.47675 .47828 m .46489 .48003 L .46321 .47615 L p F P
0 g
s
.655 .623 .806 r
.52653 .4971 m .51524 .50101 L .51221 .49514 L p F P
0 g
s
.77 .576 .636 r
.33139 .33678 m .32402 .33528 L .32657 .32937 L p F P
0 g
s
.783 .586 .634 r
.31865 .32754 m .32657 .32937 L .32402 .33528 L p F P
0 g
s
.704 .599 .736 r
.40315 .45618 m .39906 .45622 L .39689 .45059 L p F P
0 g
s
.71 .602 .734 r
.39906 .45622 m .39689 .45059 L .38997 .4561 L closepath p F P
0 g
s
.695 .593 .737 r
.41425 .45824 m .41766 .45584 L .41341 .45602 L closepath p F P
0 g
s
.755 .248 .002 r
.26156 .26593 m .26422 .26853 L .26268 .26851 L p F P
0 g
s
.726 .628 .748 r
.36894 .45521 m .37136 .46106 L .36759 .46413 L p F P
0 g
s
.726 .628 .748 r
.36651 .45504 m .36894 .45521 L p .36759 .46413 L F P
0 g
s
.726 .628 .748 r
.35702 .46319 m .36651 .45504 L p .36759 .46413 L F P
0 g
s
.726 .628 .748 r
.36759 .46413 m .35706 .46328 L .35702 .46319 L p F P
0 g
s
.549 .546 .804 r
.69739 .30784 m .68605 .30765 L .68486 .30491 L p F P
0 g
s
.702 .595 .733 r
.41341 .45602 m .41118 .45012 L .40315 .45618 L closepath p F P
0 g
s
.704 .599 .736 r
.41019 .4474 m .41118 .45012 L .40315 .45618 L p F P
0 g
s
.704 .599 .736 r
.40079 .4475 m .41019 .4474 L p .40315 .45618 L F P
0 g
s
.704 .599 .736 r
.39689 .45059 m .40079 .4475 L p .40315 .45618 L F P
0 g
s
.72 .754 .879 r
.20092 .25195 m .19002 .25774 L .1865 .25412 L p F P
0 g
s
.729 .569 .673 r
.37334 .37658 m .37254 .37351 L .37044 .37637 L closepath p F P
0 g
s
.709 .558 .681 r
.40093 .38467 m .39049 .38458 L .38988 .38228 L p F P
0 g
s
.716 .562 .679 r
.39049 .38458 m .38988 .38228 L .38802 .3845 L closepath p F P
0 g
s
.523 .49 .761 r
.71254 .34512 m .71247 .34511 L .71252 .34507 L closepath p F P
0 g
s
.531 .501 .768 r
.70957 .33712 m .71252 .34507 L .71247 .34511 L p F P
0 g
s
.531 .501 .768 r
.70837 .33697 m .70957 .33712 L p .71247 .34511 L F P
0 g
s
.734 .649 .764 r
.33383 .4799 m .33144 .47517 L .32665 .47898 L closepath p F P
0 g
s
.713 .607 .737 r
.39574 .44751 m .39689 .45059 L .38997 .4561 L p F P
0 g
s
.713 .607 .737 r
.38781 .44736 m .39574 .44751 L p .38997 .4561 L F P
0 g
s
.713 .607 .737 r
.38258 .45174 m .38781 .44736 L p .38997 .4561 L F P
0 g
s
.713 .607 .737 r
.38997 .4561 m .38426 .45597 L .38258 .45174 L p F P
0 g
s
.633 .677 .874 r
.59632 .25469 m .60777 .25171 L .61068 .25622 L p F P
0 g
s
.641 .69 .88 r
.60777 .25171 m .59632 .25469 L .5934 .25061 L p F P
0 g
s
.739 .708 .822 r
.2692 .50529 m .27232 .50324 L .26654 .5017 L closepath p F P
0 g
s
.728 .703 .826 r
.26654 .5017 m .2692 .50529 L p .25482 .50755 L F P
0 g
s
.516 .485 .761 r
.72319 .34701 m .71254 .34512 L .71252 .34507 L p F P
0 g
s
.516 .485 .761 r
.71252 .34507 m .71987 .3386 L p .72319 .34701 L F P
0 g
s
.522 .497 .77 r
.71252 .34507 m .70957 .33712 L .71987 .3386 L closepath p F P
0 g
s
.69 .928 .968 r
.55345 .25776 m .55456 .25721 L .55365 .25783 L closepath p F P
0 g
s
.665 .878 .978 r
.56478 .25261 m .55456 .25721 L .55365 .25783 L p F P
0 g
s
.649 .656 .843 r
.55822 .50591 m .54688 .50933 L .54388 .50438 L p F P
0 g
s
.684 .538 .681 r
.42298 .37675 m .43117 .37621 L p .4321 .38329 L F P
0 g
s
.684 .538 .681 r
.41846 .38117 m .42298 .37675 L p .4321 .38329 L F P
0 g
s
.496 .756 .988 r
.17096 .51076 m .16694 .50946 L .16914 .51093 L closepath p F P
0 g
s
.706 .555 .681 r
.40093 .38467 m .40511 .38466 L .40701 .39193 L p F P
0 g
s
.706 .555 .681 r
.40701 .39193 m .3943 .39195 L .40093 .38467 L p F P
0 g
s
.709 .56 .684 r
.39049 .38458 m .40093 .38467 L .3943 .39195 L p F P
0 g
s
.697 .55 .683 r
.40511 .38466 m .41538 .38434 L .40789 .3919 L p F P
0 g
s
.697 .55 .683 r
.40789 .3919 m .40701 .39193 L .40511 .38466 L p F P
0 g
s
.726 .564 .671 r
.36455 .3688 m .35997 .37541 L .37044 .37637 L p F P
0 g
s
.741 .578 .673 r
.35538 .36778 m .36455 .3688 L .35997 .37541 L p F P
0 g
s
.741 .575 .668 r
.36455 .3688 m .35538 .36778 L .35513 .3668 L p F P
0 g
s
.695 .592 .736 r
.41766 .45584 m .41341 .45602 L .41118 .45012 L p F P
0 g
s
.632 .471 .647 r
.46632 .33708 m .47542 .33517 L p .46433 .34412 L F P
0 g
s
.629 .462 .637 r
.47542 .33517 m .4747 .3306 L .46632 .33708 L closepath p F P
0 g
s
.626 .456 .633 r
.47445 .32896 m .4747 .3306 L .46632 .33708 L p F P
0 g
s
.536 .513 .777 r
.70328 .32914 m .70662 .32945 L p .70837 .33697 L F P
0 g
s
.534 .514 .779 r
.70662 .32945 m .70328 .32914 L .7057 .32705 L closepath p F P
0 g
s
.541 .524 .786 r
.70368 .32204 m .7057 .32705 L .70328 .32914 L p F P
0 g
s
.829 .563 .538 r
.29603 .29698 m .28969 .29457 L .28997 .28949 L p F P
0 g
s
.841 .575 .537 r
.28547 .28758 m .28997 .28949 L .28969 .29457 L p F P
0 g
s
.721 .616 .74 r
.37136 .46106 m .3778 .45571 L .36894 .45521 L closepath p F P
0 g
s
.742 .666 .775 r
.30585 .48706 m .30695 .48618 L .31548 .4877 L p F P
0 g
s
.732 .657 .776 r
.31704 .4782 m .30695 .48618 L .31548 .4877 L p F P
0 g
s
.732 .657 .776 r
.31548 .4877 m .32024 .48412 L .31704 .4782 L p F P
0 g
s
.717 .609 .735 r
.38426 .45597 m .38258 .45174 L .3778 .45571 L closepath p F P
0 g
s
.438 .202 .457 r
.52632 .27732 m .51753 .28151 L .5172 .28617 L p F P
0 g
s
.376 .095 .353 r
.52795 .27584 m .52869 .2726 L p .51753 .28151 L F P
0 g
s
.376 .095 .353 r
.51753 .28151 m .52632 .27732 L .52795 .27584 L p F P
0 g
s
.716 .565 .682 r
.38802 .3845 m .39049 .38458 L .39246 .39193 L p F P
0 g
s
.709 .56 .684 r
.3943 .39195 m .39246 .39193 L .39049 .38458 L p F P
0 g
s
.773 .584 .644 r
.33172 .33829 m .33233 .33698 L .33139 .33678 L closepath p F P
0 g
s
.768 .582 .646 r
.33172 .33829 m .33233 .33698 L p .33785 .34466 L F P
0 g
s
.529 .502 .77 r
.70957 .33712 m .70837 .33697 L .70925 .33623 L closepath p F P
0 g
s
.536 .513 .777 r
.70662 .32945 m .70925 .33623 L .70837 .33697 L p F P
0 g
s
.684 .538 .681 r
.4321 .38329 m .41922 .3842 L .41846 .38117 L p F P
0 g
s
.695 .545 .679 r
.41922 .3842 m .41846 .38117 L .41538 .38434 L closepath p F P
0 g
s
.725 .568 .678 r
.37627 .38396 m .37527 .3839 L .37334 .37658 L p F P
0 g
s
.729 .571 .676 r
.37044 .37637 m .37334 .37658 L .37527 .3839 L p F P
0 g
s
.686 .592 .744 r
.44425 .46315 m .4428 .45943 L .43579 .4638 L closepath p F P
0 g
s
.686 .591 .745 r
.44093 .45442 m .4428 .45943 L .43579 .4638 L p F P
0 g
s
.686 .591 .745 r
.43409 .45492 m .44093 .45442 L p .43579 .4638 L F P
0 g
s
.686 .591 .745 r
.42853 .45853 m .43409 .45492 L p .43579 .4638 L F P
0 g
s
.716 .565 .682 r
.39246 .39193 m .38195 .3916 L .38802 .3845 L p F P
0 g
s
.721 .572 .686 r
.37627 .38396 m .38802 .3845 L .38195 .3916 L p F P
0 g
s
.354 .145 .45 r
.7168 .45354 m .71306 .45586 L .7111 .46181 L p F P
0 g
s
.646 .492 .66 r
.45299 .35277 m .46553 .3506 L p .46328 .35781 L F P
0 g
s
.646 .492 .66 r
.46328 .35781 m .45432 .35941 L .45299 .35277 L p F P
0 g
s
.649 .49 .655 r
.46433 .34412 m .46553 .3506 L .45299 .35277 L p F P
0 g
s
.263 .629 .961 r
.2445 .2576 m .24698 .25782 L .24348 .25531 L p F P
0 g
s
.263 .629 .961 r
.24348 .25531 m .23942 .25469 L .2445 .2576 L p F P
0 g
s
.695 .592 .736 r
.42422 .44688 m .42546 .45033 L .41766 .45584 L p F P
0 g
s
.695 .592 .736 r
.41508 .44723 m .42422 .44688 L p .41766 .45584 L F P
0 g
s
.695 .592 .736 r
.41118 .45012 m .41508 .44723 L p .41766 .45584 L F P
0 g
s
.695 .59 .734 r
.42736 .45542 m .42546 .45033 L .41766 .45584 L closepath p F P
0 g
s
.61 .444 .633 r
.4747 .3306 m .47983 .32756 L .47445 .32896 L closepath p F P
0 g
s
.733 .638 .754 r
.34581 .47249 m .34682 .47165 L .34533 .47148 L closepath p F P
0 g
s
.733 .637 .752 r
.3466 .46229 m .35693 .46326 L .34682 .47165 L p F P
0 g
s
.733 .637 .752 r
.34266 .46575 m .3466 .46229 L p .34682 .47165 L F P
0 g
s
.733 .637 .752 r
.34682 .47165 m .34533 .47148 L .34266 .46575 L p F P
0 g
s
.836 .752 .771 r
.09102 .33683 m .08549 .3435 L .08184 .33983 L p F P
0 g
s
.836 .752 .771 r
.08184 .33983 m .08702 .33358 L .09102 .33683 L p F P
0 g
s
.833 .753 .775 r
.09102 .33683 m .08702 .33358 L .09297 .32658 L p F P
0 g
s
.66 .61 .788 r
.50917 .48889 m .4979 .49324 L .49485 .48679 L p F P
0 g
s
.741 .573 .666 r
.35359 .3606 m .34898 .36001 L p .35456 .36768 L F P
0 g
s
.741 .573 .666 r
.35456 .36768 m .35513 .3668 L .35359 .3606 L p F P
0 g
s
.761 .757 .849 r
.16095 .2649 m .165 .26211 L .169 .26543 L p F P
0 g
s
.76 .758 .851 r
.17199 .25734 m .165 .26211 L .169 .26543 L p F P
0 g
s
.76 .758 .851 r
.169 .26543 m .17552 .26097 L .17199 .25734 L p F P
0 g
s
.729 .954 .947 r
.55456 .25721 m .55345 .25776 L .55053 .25807 L p F P
0 g
s
.765 .579 .647 r
.33139 .33678 m .32402 .33528 L p .3294 .34302 L F P
0 g
s
.765 .579 .647 r
.3294 .34302 m .33172 .33829 L .33139 .33678 L p F P
0 g
s
.695 .547 .681 r
.41538 .38434 m .41922 .3842 L .42107 .39142 L p F P
0 g
s
.695 .547 .681 r
.42107 .39142 m .40789 .3919 L .41538 .38434 L p F P
0 g
s
.721 .615 .739 r
.38081 .44714 m .38258 .45174 L .3778 .45571 L p F P
0 g
s
.721 .615 .739 r
.37583 .4469 m .38081 .44714 L p .3778 .45571 L F P
0 g
s
.721 .615 .739 r
.36825 .45355 m .37583 .4469 L p .3778 .45571 L F P
0 g
s
.721 .615 .739 r
.3778 .45571 m .36894 .45521 L .36825 .45355 L p F P
0 g
s
.763 .58 .649 r
.34341 .35234 m .33476 .35076 L .33785 .34466 L p F P
0 g
s
.767 .585 .652 r
.33292 .34368 m .33785 .34466 L .33476 .35076 L p F P
0 g
s
.768 .582 .646 r
.33785 .34466 m .33292 .34368 L .33172 .33829 L p F P
0 g
s
.861 .734 .721 r
.07074 .37324 m .07491 .37638 L .07108 .38268 L p F P
0 g
s
.857 .736 .729 r
.07491 .37638 m .07074 .37324 L .07484 .36685 L p F P
0 g
s
.706 .595 .73 r
.39689 .45059 m .40079 .4475 L .39574 .44751 L closepath p F P
0 g
s
.729 .571 .676 r
.37527 .3839 m .36531 .38316 L .37044 .37637 L p F P
0 g
s
.737 .581 .68 r
.35997 .37541 m .37044 .37637 L .36531 .38316 L p F P
0 g
s
.687 .586 .738 r
.42853 .45853 m .43409 .45492 L .42736 .45542 L closepath p F P
0 g
s
.74 .707 .821 r
.277 .49318 m .28029 .49806 L .27232 .50324 L p F P
0 g
s
.74 .707 .821 r
.26588 .50081 m .277 .49318 L p .27232 .50324 L F P
0 g
s
.74 .707 .821 r
.27232 .50324 m .26654 .5017 L .26588 .50081 L p F P
0 g
s
.559 .376 .59 r
.49624 .31061 m .49576 .30498 L .50683 .30106 L p F P
0 g
s
.548 .352 .566 r
.50654 .29566 m .50683 .30106 L .49576 .30498 L p F P
0 g
s
.677 .588 .748 r
.44587 .46729 m .45533 .46193 L .44425 .46315 L closepath p F P
0 g
s
.677 .594 .755 r
.44587 .46729 m .45533 .46193 L p .45542 .47129 L F P
0 g
s
.867 .727 .705 r
.07184 .39197 m .07228 .39116 L .06868 .38691 L p F P
0 g
s
.746 .227 0 r
.11505 .48737 m .1167 .48935 L .1129 .48802 L p F P
0 g
s
.746 .227 0 r
.1129 .48802 m .10995 .48471 L .11505 .48737 L p F P
0 g
s
.586 .608 .841 r
.64564 .27323 m .64534 .27265 L .64641 .27252 L closepath p F P
0 g
s
.793 .57 .598 r
.30852 .31227 m .30829 .31032 L .30785 .31209 L closepath p F P
0 g
s
.733 .637 .752 r
.34533 .47148 m .34266 .46575 L .33693 .47055 L closepath p F P
0 g
s
.828 .584 .57 r
.28969 .29457 m .29603 .29698 L .29522 .30226 L p F P
0 g
s
.813 .571 .571 r
.30198 .30452 m .29522 .30226 L .29603 .29698 L p F P
0 g
s
.554 .556 .811 r
.68486 .30491 m .68314 .30107 L .68898 .30105 L closepath p F P
0 g
s
.549 .546 .804 r
.68486 .30491 m .68898 .30105 L p .69739 .30784 L F P
0 g
s
.669 .599 .768 r
.46321 .47615 m .47444 .47058 L p .47675 .47828 L F P
0 g
s
.67 .592 .759 r
.47377 .4689 m .47444 .47058 L .46321 .47615 L p F P
0 g
s
.67 .592 .759 r
.46321 .47615 m .46096 .47069 L .47377 .4689 L p F P
0 g
s
.665 .6 .773 r
.49014 .47608 m .4918 .47997 L .48056 .48487 L p F P
0 g
s
.665 .6 .773 r
.48056 .48487 m .4776 .47816 L .49014 .47608 L p F P
0 g
s
.473 .397 .69 r
.72733 .39214 m .73442 .38654 L p .73231 .39658 L F P
0 g
s
.473 .397 .69 r
.73231 .39658 m .72786 .39423 L .72733 .39214 L p F P
0 g
s
.482 .414 .704 r
.72733 .39214 m .73442 .38654 L .72728 .38343 L p F P
0 g
s
.685 .541 .684 r
.41922 .3842 m .4321 .38329 L .42333 .39126 L p F P
0 g
s
.685 .541 .684 r
.42333 .39126 m .42107 .39142 L .41922 .3842 L p F P
0 g
s
.742 .654 .762 r
.32665 .47898 m .32024 .48412 L .31704 .4782 L p F P
0 g
s
.743 .683 .793 r
.29469 .49531 m .29488 .49517 L .29456 .4951 L closepath p F P
0 g
s
.738 .679 .794 r
.29456 .4951 m .29469 .49531 L p .28029 .49806 L F P
0 g
s
.884 .696 .643 r
.06802 .41287 m .07244 .41587 L .0704 .42161 L p F P
0 g
s
.878 .703 .661 r
.07244 .41587 m .06802 .41287 L .07041 .40702 L p F P
0 g
s
.673 .526 .677 r
.43272 .38271 m .44145 .37513 L .43117 .37621 L closepath p F P
0 g
s
.684 .538 .681 r
.43117 .37621 m .43272 .38271 L .4321 .38329 L p F P
0 g
s
.601 .637 .858 r
.63368 .26279 m .62799 .26374 L .62508 .25871 L p F P
0 g
s
.765 .58 .647 r
.33292 .34368 m .33172 .33829 L .3294 .34302 L closepath p F P
0 g
s
.697 .588 .73 r
.41118 .45012 m .41508 .44723 L .41019 .4474 L closepath p F P
0 g
s
.846 .745 .752 r
.07933 .36034 m .07522 .35715 L .08014 .35049 L p F P
0 g
s
.851 .743 .743 r
.07933 .36034 m .07729 .36324 L .07365 .3594 L p F P
0 g
s
.851 .743 .743 r
.07365 .3594 m .07522 .35715 L .07933 .36034 L p F P
0 g
s
.744 .682 .792 r
.30514 .48582 m .30585 .48706 L .29488 .49517 L p F P
0 g
s
.744 .682 .792 r
.29841 .48465 m .30514 .48582 L p .29488 .49517 L F P
0 g
s
.744 .682 .792 r
.29143 .49009 m .29841 .48465 L p .29488 .49517 L F P
0 g
s
.744 .682 .792 r
.29488 .49517 m .29456 .4951 L .29143 .49009 L p F P
0 g
s
.715 .604 .731 r
.38258 .45174 m .38781 .44736 L .38081 .44714 L closepath p F P
0 g
s
.729 .954 .947 r
.56305 .25173 m .55456 .25721 L p .55053 .25807 L F P
0 g
s
.688 .9 .972 r
.55456 .25721 m .56305 .25173 L .56478 .25261 L closepath p F P
0 g
s
.744 .571 .659 r
.34341 .35234 m .33987 .35859 L .34898 .36001 L p F P
0 g
s
.762 .588 .661 r
.33476 .35076 m .34341 .35234 L .33987 .35859 L p F P
0 g
s
.738 .679 .794 r
.28029 .49806 m .2865 .4936 L .29456 .4951 L p F P
0 g
s
.737 .68 .796 r
.29456 .4951 m .29143 .49009 L .2865 .4936 L closepath p F P
0 g
s
.706 .595 .729 r
.40079 .4475 m .39574 .44751 L .39381 .44231 L p F P
0 g
s
.712 .597 .727 r
.39574 .44751 m .39381 .44231 L .38781 .44736 L closepath p F P
0 g
s
.678 .596 .756 r
.46096 .47069 m .46015 .46871 L .45542 .47129 L closepath p F P
0 g
s
.677 .594 .755 r
.45739 .46171 m .46015 .46871 L .45542 .47129 L p F P
0 g
s
.677 .594 .755 r
.45533 .46193 m .45739 .46171 L p .45542 .47129 L F P
0 g
s
.704 .591 .726 r
.41019 .4474 m .40811 .44167 L .40079 .4475 L closepath p F P
0 g
s
.706 .595 .729 r
.40717 .439 m .40811 .44167 L .40079 .4475 L p F P
0 g
s
.706 .595 .729 r
.39773 .43903 m .40717 .439 L p .40079 .4475 L F P
0 g
s
.706 .595 .729 r
.39381 .44231 m .39773 .43903 L p .40079 .4475 L F P
0 g
s
.873 .722 .691 r
.0676 .38888 m .07184 .39197 L .06881 .39802 L p F P
0 g
s
.867 .727 .705 r
.06868 .38691 m .0676 .38888 L .07184 .39197 L p F P
0 g
s
0 0 0 r
.684 .48856 m .68491 .48715 L p .67286 .49503 L F P
0 g
s
.018 0 0 r
.684 .48856 m .69081 .48396 L .68491 .48715 L closepath p F P
0 g
s
.143 0 .063 r
.69537 .48044 m .69613 .47831 L p .68491 .48715 L F P
0 g
s
.143 0 .063 r
.68491 .48715 m .69081 .48396 L .69537 .48044 L p F P
0 g
s
.586 .613 .845 r
.64641 .27252 m .64534 .27265 L .64244 .26724 L p F P
0 g
s
.687 .586 .737 r
.43409 .45492 m .42736 .45542 L .42546 .45033 L p F P
0 g
s
.707 .565 .692 r
.3943 .39195 m .40701 .39193 L p .40045 .39944 L F P
0 g
s
.707 .565 .692 r
.39289 .39347 m .3943 .39195 L p .40045 .39944 L F P
0 g
s
.709 .563 .687 r
.39289 .39347 m .3943 .39195 L .39246 .39193 L closepath p F P
0 g
s
.714 .73 .863 r
.22609 .51122 m .23054 .50895 L .23763 .51092 L p F P
0 g
s
.702 .723 .866 r
.23705 .50565 m .23054 .50895 L .23763 .51092 L p F P
0 g
s
.702 .723 .866 r
.23763 .51092 m .24045 .50959 L .23705 .50565 L p F P
0 g
s
.614 .451 .638 r
.47542 .33517 m .4747 .3306 L .47983 .32756 L p F P
0 g
s
.719 .575 .692 r
.39246 .39193 m .39289 .39347 L .38755 .39927 L p F P
0 g
s
.719 .575 .692 r
.38195 .3916 m .39246 .39193 L p .38755 .39927 L F P
0 g
s
.697 .553 .686 r
.40719 .3926 m .40789 .3919 L .40701 .39193 L closepath p F P
0 g
s
.707 .565 .692 r
.40701 .39193 m .40719 .3926 L .40045 .39944 L p F P
0 g
s
0 0 0 r
.67258 .49526 m .67479 .49405 L .67286 .49503 L closepath p F P
0 g
s
0 0 0 r
.67286 .49503 m .67479 .49405 L .684 .48856 L p F P
0 g
s
.728 .703 .826 r
.25482 .50755 m .26496 .50136 L .26654 .5017 L p F P
0 g
s
.735 .702 .819 r
.26496 .50136 m .25482 .50755 L .25146 .50335 L p F P
0 g
s
.695 .555 .691 r
.40789 .3919 m .42107 .39142 L p .41482 .39915 L F P
0 g
s
.695 .555 .691 r
.40719 .3926 m .40789 .3919 L p .41482 .39915 L F P
0 g
s
.566 .571 .818 r
.66817 .28879 m .67733 .28839 L p .6795 .29462 L F P
0 g
s
.564 .573 .82 r
.67733 .28839 m .66817 .28879 L .67467 .28271 L closepath p F P
0 g
s
.569 .582 .827 r
.67443 .28221 m .67467 .28271 L .66817 .28879 L p F P
0 g
s
.569 .582 .827 r
.66275 .28298 m .67443 .28221 L p .66817 .28879 L F P
0 g
s
.721 .572 .686 r
.37553 .38487 m .37627 .38396 L p .38195 .3916 L F P
0 g
s
.725 .571 .681 r
.37553 .38487 m .37627 .38396 L .37527 .3839 L closepath p F P
0 g
s
.727 .628 .748 r
.35706 .46328 m .35702 .46319 L .35693 .46326 L closepath p F P
0 g
s
.697 .587 .729 r
.41508 .44723 m .41019 .4474 L .40811 .44167 L p F P
0 g
s
.724 .623 .744 r
.3539 .45594 m .3466 .46229 L .35693 .46326 L p F P
0 g
s
.724 .623 .744 r
.35693 .46326 m .35702 .46319 L .3539 .45594 L p F P
0 g
s
.728 .616 .733 r
.36651 .45504 m .35702 .46319 L .3539 .45594 L p F P
0 g
s
.695 .555 .691 r
.41482 .39915 m .40907 .39937 L .40719 .3926 L p F P
0 g
s
.704 .56 .689 r
.40907 .39937 m .40719 .3926 L .40045 .39944 L closepath p F P
0 g
s
.618 .66 .868 r
.61117 .25702 m .61068 .25622 L .61256 .25581 L closepath p F P
0 g
s
.797 .76 .82 r
.1312 .28866 m .12754 .29188 L .12393 .28829 L p F P
0 g
s
.803 .761 .814 r
.12231 .29667 m .12754 .29188 L .12393 .28829 L p F P
0 g
s
.806 .76 .811 r
.12231 .29667 m .11627 .30233 L .11265 .29874 L p F P
0 g
s
.806 .76 .811 r
.11265 .29874 m .11842 .29334 L .12231 .29667 L p F P
0 g
s
.803 .761 .814 r
.12393 .28829 m .11842 .29334 L .12231 .29667 L p F P
0 g
s
.521 .498 .771 r
.71987 .3386 m .70957 .33712 L .70925 .33623 L p F P
0 g
s
.473 .396 .689 r
.72907 .3991 m .72786 .39423 L .73231 .39658 L closepath p F P
0 g
s
.715 .603 .73 r
.39263 .439 m .39381 .44231 L .38781 .44736 L p F P
0 g
s
.715 .603 .73 r
.385 .43881 m .39263 .439 L p .38781 .44736 L F P
0 g
s
.715 .603 .73 r
.37949 .44369 m .385 .43881 L p .38781 .44736 L F P
0 g
s
.715 .603 .73 r
.38781 .44736 m .38081 .44714 L .37949 .44369 L p F P
0 g
s
.733 .583 .687 r
.37527 .3839 m .37553 .38487 L .37058 .39094 L p F P
0 g
s
.733 .583 .687 r
.36531 .38316 m .37527 .3839 L p .37058 .39094 L F P
0 g
s
.714 .569 .689 r
.39459 .39944 m .39289 .39347 L .38755 .39927 L closepath p F P
0 g
s
.707 .565 .692 r
.40045 .39944 m .39459 .39944 L .39289 .39347 L p F P
0 g
s
.811 .76 .805 r
.11408 .30446 m .11627 .30233 L .11265 .29874 L p F P
0 g
s
.515 .759 .985 r
.17096 .51076 m .1797 .50965 L p .16553 .50849 L F P
0 g
s
.515 .759 .985 r
.16553 .50849 m .16694 .50946 L .17096 .51076 L p F P
0 g
s
.797 .76 .82 r
.12393 .28829 m .12731 .28532 L .1312 .28866 L p F P
0 g
s
.794 .761 .822 r
.13514 .27857 m .12731 .28532 L .1312 .28866 L p F P
0 g
s
.794 .761 .822 r
.1312 .28866 m .13873 .28217 L .13514 .27857 L p F P
0 g
s
.795 .572 .598 r
.30198 .30452 m .30066 .30998 L .30785 .31209 L p F P
0 g
s
.814 .587 .594 r
.29522 .30226 m .30198 .30452 L .30066 .30998 L p F P
0 g
s
.721 .572 .686 r
.38195 .3916 m .37736 .39138 L .37553 .38487 L p F P
0 g
s
.727 .575 .684 r
.37736 .39138 m .37553 .38487 L .37058 .39094 L closepath p F P
0 g
s
.521 .498 .771 r
.70925 .33623 m .71563 .33047 L p .71987 .3386 L F P
0 g
s
.527 .509 .78 r
.70925 .33623 m .70662 .32945 L .71563 .33047 L closepath p F P
0 g
s
.677 .587 .747 r
.45533 .46193 m .44425 .46315 L .4428 .45943 L p F P
0 g
s
.724 .616 .737 r
.36894 .45521 m .36825 .45355 L .36651 .45504 L closepath p F P
0 g
s
.66 .511 .67 r
.44397 .37289 m .45162 .36671 L .44287 .36794 L closepath p F P
0 g
s
.673 .524 .675 r
.44287 .36794 m .44397 .37289 L .44145 .37513 L p F P
0 g
s
.741 .573 .666 r
.34898 .36001 m .34499 .36642 L .35456 .36768 L p F P
0 g
s
.757 .589 .668 r
.33987 .35859 m .34898 .36001 L .34499 .36642 L p F P
0 g
s
.742 .654 .762 r
.31704 .4782 m .31779 .47756 L .32665 .47898 L p F P
0 g
s
.732 .645 .762 r
.32772 .46923 m .31779 .47756 L .32665 .47898 L p F P
0 g
s
.732 .645 .762 r
.32854 .46934 m .32772 .46923 L p .32665 .47898 L F P
0 g
s
.732 .645 .762 r
.32665 .47898 m .33144 .47517 L .32854 .46934 L p F P
0 g
s
.811 .76 .805 r
.11265 .29874 m .11019 .30113 L .11408 .30446 L p F P
0 g
s
.814 .759 .801 r
.11019 .30113 m .11408 .30446 L .10652 .31201 L p F P
0 g
s
.632 .476 .653 r
.46553 .3506 m .46433 .34412 L .4765 .34153 L p F P
0 g
s
.632 .471 .647 r
.47542 .33517 m .4765 .34153 L .46433 .34412 L p F P
0 g
s
.696 .585 .727 r
.42422 .44688 m .42239 .44178 L .41508 .44723 L closepath p F P
0 g
s
.697 .587 .729 r
.42128 .43854 m .42239 .44178 L .41508 .44723 L p F P
0 g
s
.697 .587 .729 r
.4117 .43886 m .42128 .43854 L p .41508 .44723 L F P
0 g
s
.697 .587 .729 r
.40811 .44167 m .4117 .43886 L p .41508 .44723 L F P
0 g
s
.649 .692 .876 r
.56131 .51069 m .5612 .51053 L .57054 .50782 L closepath p F P
0 g
s
.743 .576 .668 r
.35538 .36778 m .35513 .3668 L .35456 .36768 L closepath p F P
0 g
s
.719 .605 .728 r
.38081 .44714 m .37949 .44369 L .37583 .4469 L closepath p F P
0 g
s
.719 .575 .692 r
.37855 .39554 m .38195 .3916 L p .38755 .39927 L F P
0 g
s
.721 .573 .688 r
.37855 .39554 m .38195 .3916 L .37736 .39138 L closepath p F P
0 g
s
.801 .587 .613 r
.31328 .3198 m .30956 .31868 L .30852 .31227 L p F P
0 g
s
.792 .581 .616 r
.30785 .31209 m .30852 .31227 L .30956 .31868 L p F P
0 g
s
.648 .671 .858 r
.57054 .50782 m .5612 .51053 L .55822 .50591 L p F P
0 g
s
.306 .015 .296 r
.52795 .27584 m .53407 .26968 L .52869 .2726 L closepath p F P
0 g
s
.141 0 .046 r
.53923 .26592 m .54038 .26429 L p .52869 .2726 L F P
0 g
s
.141 0 .046 r
.52869 .2726 m .53407 .26968 L .53923 .26592 L p F P
0 g
s
.708 .591 .723 r
.39381 .44231 m .39773 .43903 L .39263 .439 L closepath p F P
0 g
s
.721 .612 .734 r
.36473 .44617 m .35584 .45418 L .36651 .45504 L p F P
0 g
s
.721 .612 .734 r
.36532 .44622 m .36473 .44617 L p .36651 .45504 L F P
0 g
s
.721 .612 .734 r
.36651 .45504 m .36825 .45355 L .36532 .44622 L p F P
0 g
s
.728 .616 .733 r
.3539 .45594 m .35584 .45418 L .36651 .45504 L p F P
0 g
s
.741 .578 .673 r
.35997 .37541 m .35733 .37512 L .35538 .36778 L p F P
0 g
s
.743 .58 .672 r
.35456 .36768 m .35538 .36778 L .35733 .37512 L p F P
0 g
s
.688 .581 .73 r
.42546 .45033 m .43122 .44639 L .42422 .44688 L closepath p F P
0 g
s
.687 .586 .737 r
.42546 .45033 m .43122 .44639 L p .43409 .45492 L F P
0 g
s
.847 .489 .375 r
.27721 .2797 m .27146 .27705 L .27014 .27255 L p F P
0 g
s
.862 .507 .377 r
.26484 .26974 m .27014 .27255 L .27146 .27705 L p F P
0 g
s
.818 .354 .115 r
.26422 .26853 m .26484 .26974 L .27014 .27255 L p F P
0 g
s
.787 .76 .829 r
.14097 .28034 m .13873 .28217 L .13514 .27857 L p F P
0 g
s
.724 .613 .733 r
.36825 .45355 m .37583 .4469 L .36532 .44622 L closepath p F P
0 g
s
.653 .648 .833 r
.54112 .49952 m .54388 .50438 L p .52955 .50274 L F P
0 g
s
.653 .648 .833 r
.52955 .50274 m .53386 .50135 L .54112 .49952 L p F P
0 g
s
.65 .631 .818 r
.52955 .50274 m .53386 .50135 L .52943 .50251 L closepath p F P
0 g
s
.584 .606 .84 r
.64641 .27252 m .65695 .27141 L .65405 .26576 L p F P
0 g
s
.584 .606 .84 r
.65405 .26576 m .6535 .26582 L .64641 .27252 L p F P
0 g
s
.586 .613 .845 r
.64244 .26724 m .6535 .26582 L .64641 .27252 L p F P
0 g
s
.699 .583 .722 r
.40811 .44167 m .4117 .43886 L .40717 .439 L closepath p F P
0 g
s
.705 .568 .698 r
.40045 .39944 m .40907 .39937 L p .40647 .40698 L F P
0 g
s
.705 .568 .698 r
.39591 .40402 m .40045 .39944 L p .40647 .40698 L F P
0 g
s
.707 .566 .693 r
.39591 .40402 m .40045 .39944 L .39459 .39944 L closepath p F P
0 g
s
.716 .578 .699 r
.39459 .39944 m .39591 .40402 L .39299 .407 L p F P
0 g
s
.716 .578 .699 r
.38755 .39927 m .39459 .39944 L p .39299 .407 L F P
0 g
s
.743 .58 .672 r
.35733 .37512 m .35007 .37426 L .35456 .36768 L p F P
0 g
s
.753 .586 .67 r
.34499 .36642 m .35456 .36768 L .35007 .37426 L p F P
0 g
s
.855 .743 .739 r
.07484 .36685 m .07729 .36324 L .07365 .3594 L p F P
0 g
s
.687 .586 .736 r
.44093 .45442 m .43974 .45122 L .43409 .45492 L closepath p F P
0 g
s
.687 .586 .737 r
.43785 .44594 m .43974 .45122 L .43409 .45492 L p F P
0 g
s
.687 .586 .737 r
.43122 .44639 m .43785 .44594 L p .43409 .45492 L F P
0 g
s
.65 .631 .818 r
.53386 .50135 m .52943 .50251 L .52653 .4971 L p F P
0 g
s
.695 .556 .693 r
.41021 .40342 m .41482 .39915 L .40907 .39937 L closepath p F P
0 g
s
.705 .568 .698 r
.40907 .39937 m .41021 .40342 L .40647 .40698 L p F P
0 g
s
.706 .586 .719 r
.40717 .439 m .40504 .43287 L .39773 .43903 L closepath p F P
0 g
s
.708 .591 .722 r
.40434 .43077 m .40504 .43287 L .39773 .43903 L p F P
0 g
s
.708 .591 .722 r
.39408 .43074 m .40434 .43077 L p .39773 .43903 L F P
0 g
s
.708 .591 .722 r
.39074 .43371 m .39408 .43074 L p .39773 .43903 L F P
0 g
s
.708 .591 .722 r
.39773 .43903 m .39263 .439 L .39074 .43371 L p F P
0 g
s
.622 .751 .939 r
.18326 .51244 m .19396 .50974 L .19748 .51282 L p F P
0 g
s
.64 .75 .929 r
.19396 .50974 m .18326 .51244 L .1797 .50965 L p F P
0 g
s
.739 .648 .759 r
.33144 .47517 m .33693 .47055 L .32854 .46934 L closepath p F P
0 g
s
.802 .588 .612 r
.30066 .30998 m .30785 .31209 L .30603 .31772 L p F P
0 g
s
.792 .581 .616 r
.30956 .31868 m .30603 .31772 L .30785 .31209 L p F P
0 g
s
.746 .758 .862 r
.18552 .25473 m .17552 .26097 L .17199 .25734 L p F P
0 g
s
.528 .918 .911 r
.65947 .50144 m .65849 .50151 L .64702 .50612 L p F P
0 g
s
.564 .918 .959 r
.65849 .50151 m .64702 .50612 L .64427 .50526 L p F P
0 g
s
.63 .905 .984 r
.64702 .50612 m .64427 .50526 L p .63279 .50928 L F P
0 g
s
.685 .543 .687 r
.42146 .39292 m .42333 .39126 L .42107 .39142 L closepath p F P
0 g
s
.695 .555 .691 r
.42107 .39142 m .42146 .39292 L .41482 .39915 L p F P
0 g
s
.892 .595 .475 r
.08988 .46274 m .08508 .45993 L .08486 .45488 L p F P
0 g
s
.896 .597 .473 r
.08012 .45205 m .08486 .45488 L .08508 .45993 L p F P
0 g
s
.893 .625 .525 r
.08486 .45488 m .08012 .45205 L .08044 .44683 L p F P
0 g
s
.618 .67 .878 r
.61256 .25581 m .61068 .25622 L .60777 .25171 L p F P
0 g
s
.787 .76 .829 r
.13514 .27857 m .13708 .27699 L .14097 .28034 L p F P
0 g
s
.785 .761 .832 r
.14629 .26958 m .13708 .27699 L .14097 .28034 L p F P
0 g
s
.785 .761 .832 r
.14097 .28034 m .14987 .27318 L .14629 .26958 L p F P
0 g
s
.84 .752 .767 r
.08528 .34376 m .08549 .3435 L .08184 .33983 L p F P
0 g
s
.714 .593 .72 r
.39263 .439 m .39074 .43371 L .385 .43881 L closepath p F P
0 g
s
.699 .583 .721 r
.4117 .43886 m .40717 .439 L .40504 .43287 L p F P
0 g
s
.414 .276 .583 r
.73177 .4262 m .72487 .43106 L .72555 .43679 L p F P
0 g
s
.428 .286 .585 r
.72381 .43795 m .72555 .43679 L .72487 .43106 L p F P
0 g
s
.434 .31 .611 r
.72487 .43106 m .73177 .4262 L .72859 .42181 L p F P
0 g
s
.721 .573 .688 r
.37736 .39138 m .37058 .39094 L p .37575 .39875 L F P
0 g
s
.721 .573 .688 r
.37575 .39875 m .37855 .39554 L .37736 .39138 L p F P
0 g
s
.845 .75 .758 r
.08128 .34052 m .08528 .34376 L .08014 .35049 L p F P
0 g
s
.84 .752 .767 r
.08184 .33983 m .08128 .34052 L .08528 .34376 L p F P
0 g
s
.724 .612 .732 r
.37757 .43851 m .37949 .44369 L .37583 .4469 L p F P
0 g
s
.724 .612 .732 r
.37325 .43828 m .37757 .43851 L p .37583 .4469 L F P
0 g
s
.724 .612 .732 r
.36515 .44579 m .37325 .43828 L p .37583 .4469 L F P
0 g
s
.724 .612 .732 r
.37583 .4469 m .36532 .44622 L .36515 .44579 L p F P
0 g
s
.481 .415 .706 r
.73418 .37787 m .72728 .38343 L .73442 .38654 L p F P
0 g
s
.492 .432 .718 r
.73367 .3761 m .73418 .37787 L .72728 .38343 L p F P
0 g
s
.492 .432 .718 r
.72763 .37391 m .73367 .3761 L p .72728 .38343 L F P
0 g
s
.677 .587 .747 r
.4428 .45943 m .45346 .45309 L p .45533 .46193 L F P
0 g
s
.678 .582 .74 r
.4428 .45943 m .45346 .45309 L .44093 .45442 L closepath p F P
0 g
s
.673 .593 .758 r
.47138 .46288 m .47377 .4689 L .46096 .47069 L p F P
0 g
s
.673 .593 .758 r
.46096 .47069 m .46015 .46871 L .47138 .46288 L p F P
0 g
s
.818 .759 .797 r
.10652 .31201 m .10492 .31366 L .10128 .31006 L p F P
0 g
s
.818 .759 .797 r
.10128 .31006 m .10261 .3087 L .10652 .31201 L p F P
0 g
s
.814 .759 .801 r
.10652 .31201 m .10261 .3087 L .11019 .30113 L p F P
0 g
s
.716 .578 .699 r
.38158 .40573 m .38755 .39927 L p .39299 .407 L F P
0 g
s
.719 .576 .694 r
.38158 .40573 m .38755 .39927 L .37956 .39896 L closepath p F P
0 g
s
.719 .575 .692 r
.38755 .39927 m .37956 .39896 L .37855 .39554 L p F P
0 g
s
.688 .58 .729 r
.43122 .44639 m .42422 .44688 L .42239 .44178 L p F P
0 g
s
.889 .556 .411 r
.09553 .47039 m .09069 .46761 L .08988 .46274 L p F P
0 g
s
.892 .557 .406 r
.08508 .45993 m .08988 .46274 L .09069 .46761 L p F P
0 g
s
.59 .421 .621 r
.48594 .32363 m .48545 .31991 L .49689 .31645 L p F P
0 g
s
.585 .408 .608 r
.49624 .31061 m .49689 .31645 L .48545 .31991 L p F P
0 g
s
.607 .433 .621 r
.48545 .31991 m .48594 .32363 L .47983 .32756 L p F P
0 g
s
.896 .628 .524 r
.07577 .44396 m .08044 .44683 L .08012 .45205 L p F P
0 g
s
.891 .648 .564 r
.08044 .44683 m .07577 .44396 L .07658 .4386 L p F P
0 g
s
0 0 0 r
.67479 .49405 m .67258 .49526 L .66998 .49647 L p F P
0 g
s
.442 .871 .768 r
.67258 .49526 m .66998 .49647 L p .65947 .50144 L F P
0 g
s
.718 .6 .724 r
.37949 .44369 m .385 .43881 L .37757 .43851 L closepath p F P
0 g
s
.705 .568 .698 r
.40647 .40698 m .39681 .40706 L .39591 .40402 L p F P
0 g
s
.712 .572 .696 r
.39681 .40706 m .39591 .40402 L .39299 .407 L closepath p F P
0 g
s
.767 .585 .652 r
.33476 .35076 m .33458 .35073 L .33292 .34368 L p F P
0 g
s
.765 .584 .652 r
.3294 .34302 m .33292 .34368 L .33458 .35073 L p F P
0 g
s
.683 .546 .692 r
.42146 .39292 m .42333 .39126 L p .43137 .39816 L F P
0 g
s
.683 .546 .692 r
.43137 .39816 m .42307 .39879 L .42146 .39292 L p F P
0 g
s
.694 .552 .69 r
.42307 .39879 m .42146 .39292 L .41482 .39915 L closepath p F P
0 g
s
.74 .581 .676 r
.35812 .378 m .35997 .37541 L .35733 .37512 L closepath p F P
0 g
s
.737 .581 .68 r
.35812 .378 m .35997 .37541 L p .36531 .38316 L F P
0 g
s
.729 .714 .836 r
.25146 .50335 m .24045 .50959 L .23705 .50565 L p F P
0 g
s
.683 .546 .692 r
.42333 .39126 m .43469 .39045 L p .43137 .39816 L F P
0 g
s
.684 .54 .683 r
.43469 .39045 m .42333 .39126 L .4321 .38329 L p F P
0 g
s
.698 .58 .72 r
.42128 .43854 m .41933 .43284 L .4117 .43886 L closepath p F P
0 g
s
.699 .583 .721 r
.41853 .43039 m .41933 .43284 L .4117 .43886 L p F P
0 g
s
.699 .583 .721 r
.40767 .43069 m .41853 .43039 L p .4117 .43886 L F P
0 g
s
.699 .583 .721 r
.40504 .43287 m .40767 .43069 L p .4117 .43886 L F P
0 g
s
.823 .759 .791 r
.09959 .31935 m .10492 .31366 L .10128 .31006 L p F P
0 g
s
.677 .532 .681 r
.43285 .38324 m .43272 .38271 L .44145 .37513 L p F P
0 g
s
.684 .537 .68 r
.43285 .38324 m .43272 .38271 L .4321 .38329 L closepath p F P
0 g
s
.684 .54 .683 r
.4321 .38329 m .43285 .38324 L .43469 .39045 L p F P
0 g
s
.694 .559 .699 r
.41482 .39915 m .42307 .39879 L p .42162 .40644 L F P
0 g
s
.694 .559 .699 r
.41021 .40342 m .41482 .39915 L p .42162 .40644 L F P
0 g
s
.793 .587 .622 r
.31865 .32754 m .31132 .3255 L .31328 .3198 L p F P
0 g
s
.799 .594 .624 r
.30956 .31868 m .31328 .3198 L .31132 .3255 L p F P
0 g
s
.718 .599 .723 r
.3897 .43068 m .39074 .43371 L .385 .43881 L p F P
0 g
s
.718 .599 .723 r
.38166 .43042 m .3897 .43068 L p .385 .43881 L F P
0 g
s
.718 .599 .723 r
.37641 .43535 m .38166 .43042 L p .385 .43881 L F P
0 g
s
.718 .599 .723 r
.385 .43881 m .37757 .43851 L .37641 .43535 L p F P
0 g
s
.739 .647 .757 r
.34075 .46158 m .34266 .46575 L .33693 .47055 L p F P
0 g
s
.739 .647 .757 r
.33691 .46112 m .34075 .46158 L p .33693 .47055 L F P
0 g
s
.739 .647 .757 r
.32826 .46878 m .33691 .46112 L p .33693 .47055 L F P
0 g
s
.739 .647 .757 r
.33693 .47055 m .32854 .46934 L .32826 .46878 L p F P
0 g
s
.706 .571 .7 r
.39681 .40706 m .39299 .407 L p .39822 .41479 L F P
0 g
s
.706 .571 .7 r
.39822 .41479 m .39894 .4141 L .39681 .40706 L p F P
0 g
s
.705 .57 .7 r
.39894 .4141 m .40647 .40698 L .39681 .40706 L closepath p F P
0 g
s
.694 .559 .699 r
.42162 .40644 m .41122 .40691 L .41021 .40342 L p F P
0 g
s
.702 .564 .696 r
.41122 .40691 m .41021 .40342 L .40647 .40698 L closepath p F P
0 g
s
.554 .557 .811 r
.68898 .30105 m .68314 .30107 L .68023 .2946 L p F P
0 g
s
.672 .533 .686 r
.43285 .38324 m .4461 .38187 L p .44174 .38968 L F P
0 g
s
.672 .533 .686 r
.44174 .38968 m .43469 .39045 L .43285 .38324 L p F P
0 g
s
.677 .532 .681 r
.44442 .37483 m .4461 .38187 L .43285 .38324 L p F P
0 g
s
.677 .532 .681 r
.44145 .37513 m .44442 .37483 L p .43285 .38324 L F P
0 g
s
.462 .377 .674 r
.73231 .39658 m .72907 .3991 L .73062 .40584 L p F P
0 g
s
.473 .385 .675 r
.72911 .40695 m .73062 .40584 L .72907 .3991 L p F P
0 g
s
.724 .578 .691 r
.37956 .39896 m .37855 .39554 L .37575 .39875 L closepath p F P
0 g
s
.876 .713 .677 r
.07041 .40702 m .06608 .40397 L .06881 .39802 L p F P
0 g
s
.881 .707 .662 r
.06608 .40397 m .07041 .40702 L .06802 .41287 L p F P
0 g
s
.647 .496 .664 r
.45521 .36371 m .46328 .35781 L .45432 .35941 L closepath p F P
0 g
s
.66 .508 .667 r
.45432 .35941 m .45521 .36371 L .45162 .36671 L p F P
0 g
s
.701 .579 .716 r
.40504 .43287 m .40767 .43069 L .40434 .43077 L closepath p F P
0 g
s
.706 .571 .7 r
.39299 .407 m .38552 .41455 L .39822 .41479 L p F P
0 g
s
.716 .58 .701 r
.38187 .40666 m .39299 .407 L .38552 .41455 L p F P
0 g
s
.716 .578 .699 r
.39299 .407 m .38187 .40666 L .38158 .40573 L p F P
0 g
s
.711 .588 .716 r
.39074 .43371 m .39408 .43074 L .3897 .43068 L closepath p F P
0 g
s
.703 .572 .705 r
.40647 .40698 m .41122 .40691 L p .41227 .4146 L F P
0 g
s
.703 .572 .705 r
.39894 .4141 m .40647 .40698 L p .41227 .4146 L F P
0 g
s
.569 .584 .828 r
.67153 .27629 m .67443 .28221 L .66275 .28298 L p F P
0 g
s
.569 .584 .828 r
.66214 .2769 m .67153 .27629 L p .66275 .28298 L F P
0 g
s
.569 .584 .828 r
.66275 .28298 m .66054 .27846 L .66214 .2769 L p F P
0 g
s
.733 .583 .687 r
.36114 .38863 m .36531 .38316 L p .37058 .39094 L F P
0 g
s
.737 .583 .683 r
.36114 .38863 m .36531 .38316 L .35941 .38258 L closepath p F P
0 g
s
.737 .581 .68 r
.36531 .38316 m .35941 .38258 L .35812 .378 L p F P
0 g
s
.708 .582 .712 r
.40434 .43077 m .40199 .42369 L .39408 .43074 L closepath p F P
0 g
s
.701 .578 .715 r
.40767 .43069 m .40434 .43077 L .40199 .42369 L p F P
0 g
s
.46 .362 .657 r
.73118 .40851 m .72911 .40695 L .73062 .40584 L closepath p F P
0 g
s
.746 .686 .793 r
.2865 .4936 m .28029 .49806 L .277 .49318 L p F P
0 g
s
.671 .586 .751 r
.47028 .45998 m .47138 .46288 L .46015 .46871 L p F P
0 g
s
.671 .586 .751 r
.46015 .46871 m .45739 .46171 L .47028 .45998 L p F P
0 g
s
.711 .587 .715 r
.40167 .4227 m .40199 .42369 L .39408 .43074 L p F P
0 g
s
.711 .587 .715 r
.38998 .42259 m .40167 .4227 L p .39408 .43074 L F P
0 g
s
.711 .587 .715 r
.38768 .42476 m .38998 .42259 L p .39408 .43074 L F P
0 g
s
.711 .587 .715 r
.39408 .43074 m .3897 .43068 L .38768 .42476 L p F P
0 g
s
.688 .58 .729 r
.42239 .44178 m .42741 .43815 L p .43122 .44639 L F P
0 g
s
.689 .576 .723 r
.42239 .44178 m .42741 .43815 L .42128 .43854 L closepath p F P
0 g
s
.61 .439 .625 r
.48626 .32594 m .48594 .32363 L .47983 .32756 L closepath p F P
0 g
s
.614 .451 .638 r
.47983 .32756 m .48626 .32594 L p .47542 .33517 L F P
0 g
s
.88 .501 .319 r
.09553 .47039 m .09616 .4725 L .09232 .47237 L p F P
0 g
s
.88 .501 .319 r
.09069 .46761 m .09553 .47039 L p .09232 .47237 L F P
0 g
s
.694 .561 .7 r
.41324 .41373 m .42162 .40644 L .41122 .40691 L closepath p F P
0 g
s
.703 .572 .705 r
.41122 .40691 m .41324 .41373 L .41227 .4146 L p F P
0 g
s
.718 .576 .694 r
.37956 .39896 m .37575 .39875 L p .38076 .40661 L F P
0 g
s
.718 .576 .694 r
.38076 .40661 m .38158 .40573 L .37956 .39896 L p F P
0 g
s
.16 0 .12 r
.69537 .48044 m .70081 .47562 L .69613 .47831 L closepath p F P
0 g
s
.255 0 .264 r
.7066 .46926 m .7067 .4687 L p .69613 .47831 L F P
0 g
s
.255 0 .264 r
.69613 .47831 m .70081 .47562 L .7066 .46926 L p F P
0 g
s
.745 .671 .778 r
.30585 .48706 m .30695 .48618 L .30514 .48582 L closepath p F P
0 g
s
.783 .586 .634 r
.32402 .33528 m .31629 .33338 L .31865 .32754 L p F P
0 g
s
.792 .597 .637 r
.31132 .3255 m .31865 .32754 L .31629 .33338 L p F P
0 g
s
.699 .575 .712 r
.41853 .43039 m .41628 .42351 L .40767 .43069 L closepath p F P
0 g
s
.701 .578 .715 r
.41593 .4224 m .41628 .42351 L .40767 .43069 L p F P
0 g
s
.701 .578 .715 r
.40314 .42268 m .41593 .4224 L p .40767 .43069 L F P
0 g
s
.701 .578 .715 r
.40199 .42369 m .40314 .42268 L p .40767 .43069 L F P
0 g
s
.716 .59 .713 r
.3897 .43068 m .38768 .42476 L .38166 .43042 L closepath p F P
0 g
s
.673 .524 .674 r
.44442 .37483 m .44397 .37289 L .44145 .37513 L closepath p F P
0 g
s
.703 .572 .705 r
.41227 .4146 m .39916 .4148 L .39894 .4141 L p F P
0 g
s
.71 .576 .703 r
.39916 .4148 m .39894 .4141 L .39822 .41479 L closepath p F P
0 g
s
.671 .603 .771 r
.4776 .47816 m .4775 .47792 L .47675 .47828 L closepath p F P
0 g
s
.669 .599 .768 r
.47444 .47058 m .4775 .47792 L .47675 .47828 L p F P
0 g
s
0 .376 .722 r
.13398 .49896 m .13606 .49961 L .14168 .50208 L p F P
0 g
s
.142 .597 .927 r
.14168 .50208 m .14785 .5035 L .14419 .50115 L p F P
0 g
s
.142 .597 .927 r
.14419 .50115 m .13606 .49961 L .14168 .50208 L p F P
0 g
s
.703 .574 .707 r
.39916 .4148 m .41227 .4146 L .40314 .42268 L p F P
0 g
s
.703 .574 .707 r
.40314 .42268 m .40167 .4227 L .39916 .4148 L p F P
0 g
s
.71 .578 .705 r
.39822 .41479 m .39916 .4148 L .40167 .4227 L p F P
0 g
s
.894 .652 .564 r
.07198 .43568 m .07658 .4386 L .07577 .44396 L p F P
0 g
s
.889 .667 .596 r
.07658 .4386 m .07198 .43568 L .07324 .43019 L p F P
0 g
s
.737 .579 .678 r
.35733 .37512 m .35007 .37426 L p .35511 .38211 L F P
0 g
s
.737 .579 .678 r
.35511 .38211 m .35812 .378 L .35733 .37512 L p F P
0 g
s
.713 .583 .708 r
.38552 .41455 m .39822 .41479 L .38998 .42259 L p F P
0 g
s
.71 .578 .705 r
.40167 .4227 m .38998 .42259 L .39822 .41479 L p F P
0 g
s
0 .345 .771 r
.24698 .25782 m .25106 .26025 L .25615 .26315 L p F P
0 g
s
0 .242 .678 r
.25106 .26025 m .24698 .25782 L .24348 .25531 L p F P
0 g
s
.664 .518 .675 r
.44442 .37483 m .44397 .37289 L .45162 .36671 L p F P
0 g
s
.703 .575 .709 r
.40199 .42369 m .40314 .42268 L .40167 .4227 L closepath p F P
0 g
s
.736 .635 .747 r
.34266 .46575 m .3466 .46229 L .34075 .46158 L closepath p F P
0 g
s
.745 .67 .777 r
.31659 .47735 m .31704 .4782 L .30695 .48618 L p F P
0 g
s
.745 .67 .777 r
.30895 .47613 m .31659 .47735 L p .30695 .48618 L F P
0 g
s
.745 .67 .777 r
.30262 .48141 m .30895 .47613 L p .30695 .48618 L F P
0 g
s
.745 .67 .777 r
.30695 .48618 m .30514 .48582 L .30262 .48141 L p F P
0 g
s
.655 .623 .806 r
.51221 .49514 m .5235 .49115 L .52653 .4971 L p F P
0 g
s
.652 .613 .797 r
.52342 .49098 m .5235 .49115 L .51221 .49514 L p F P
0 g
s
.652 .613 .797 r
.51221 .49514 m .51153 .49375 L .52342 .49098 L p F P
0 g
s
.721 .573 .688 r
.37058 .39094 m .36485 .39794 L .37575 .39875 L p F P
0 g
s
.733 .585 .69 r
.36158 .39015 m .37058 .39094 L .36485 .39794 L p F P
0 g
s
.733 .583 .687 r
.37058 .39094 m .36158 .39015 L .36114 .38863 L p F P
0 g
s
.701 .57 .705 r
.41593 .4224 m .40314 .42268 L .41227 .4146 L p F P
0 g
s
.678 .581 .739 r
.45346 .45309 m .44093 .45442 L .43974 .45122 L p F P
0 g
s
.689 .575 .722 r
.42741 .43815 m .42128 .43854 L .41933 .43284 L p F P
0 g
s
.722 .601 .721 r
.37757 .43851 m .37641 .43535 L .37325 .43828 L closepath p F P
0 g
s
0 0 0 r
.67479 .49405 m .68282 .48985 L .684 .48856 L closepath p F P
0 g
s
0 0 0 r
.68282 .48985 m .67479 .49405 L p .66998 .49647 L F P
0 g
s
.524 .334 .565 r
.50683 .30106 m .50654 .29566 L .51723 .29126 L p F P
0 g
s
.505 .294 .527 r
.5172 .28617 m .51723 .29126 L .50654 .29566 L p F P
0 g
s
.736 .634 .746 r
.35304 .4539 m .3539 .45594 L .3466 .46229 L p F P
0 g
s
.736 .634 .746 r
.34568 .45315 m .35304 .4539 L p .3466 .46229 L F P
0 g
s
.736 .634 .746 r
.33951 .45884 m .34568 .45315 L p .3466 .46229 L F P
0 g
s
.736 .634 .746 r
.3466 .46229 m .34075 .46158 L .33951 .45884 L p F P
0 g
s
.666 .601 .772 r
.48874 .47281 m .49014 .47608 L .4776 .47816 L p F P
0 g
s
.666 .601 .772 r
.4776 .47816 m .4775 .47792 L .48874 .47281 L p F P
0 g
s
.527 .51 .78 r
.71563 .33047 m .70662 .32945 L .7057 .32705 L p F P
0 g
s
.684 .548 .694 r
.42449 .40392 m .43137 .39816 L .42307 .39879 L closepath p F P
0 g
s
.694 .559 .699 r
.42307 .39879 m .42449 .40392 L .42162 .40644 L p F P
0 g
s
.713 .584 .71 r
.38768 .42476 m .38998 .42259 L .38694 .42253 L closepath p F P
0 g
s
.713 .583 .708 r
.38462 .41545 m .38552 .41455 L p .38998 .42259 L F P
0 g
s
.713 .583 .708 r
.38998 .42259 m .38694 .42253 L .38462 .41545 L p F P
0 g
s
.688 .58 .729 r
.43498 .43767 m .43667 .44263 L .43122 .44639 L p F P
0 g
s
.688 .58 .729 r
.42741 .43815 m .43498 .43767 L p .43122 .44639 L F P
0 g
s
.688 .58 .729 r
.43785 .44594 m .43667 .44263 L .43122 .44639 L closepath p F P
0 g
s
.724 .735 .86 r
.23054 .50895 m .22609 .51122 L .22266 .50759 L p F P
0 g
s
.695 .737 .883 r
.21176 .51235 m .22266 .50759 L .22609 .51122 L p F P
0 g
s
.668 .746 .909 r
.19748 .51282 m .20829 .50898 L .21176 .51235 L p F P
0 g
s
.68 .744 .899 r
.20829 .50898 m .19748 .51282 L .19396 .50974 L p F P
0 g
s
.765 .579 .647 r
.32402 .33528 m .32126 .34126 L .3294 .34302 L p F P
0 g
s
.786 .598 .646 r
.31629 .33338 m .32402 .33528 L .32126 .34126 L p F P
0 g
s
.665 .59 .762 r
.48874 .47281 m .4775 .47792 L .47444 .47058 L p F P
0 g
s
.775 .76 .84 r
.152 .27157 m .14987 .27318 L .14629 .26958 L p F P
0 g
s
.721 .596 .716 r
.38694 .42253 m .38768 .42476 L .38166 .43042 L p F P
0 g
s
.355 .711 .986 r
.15941 .50595 m .15151 .50571 L .14785 .5035 L p F P
0 g
s
.284 .685 .972 r
.15151 .50571 m .15941 .50595 L .16481 .50848 L p F P
0 g
s
.718 .576 .694 r
.37575 .39875 m .36942 .40594 L .38076 .40661 L p F P
0 g
s
.73 .588 .697 r
.36485 .39794 m .37575 .39875 L .36942 .40594 L p F P
0 g
s
.721 .581 .697 r
.38187 .40666 m .38158 .40573 L .38076 .40661 L closepath p F P
0 g
s
.835 .534 .479 r
.28387 .28699 m .27766 .28451 L .27721 .2797 L p F P
0 g
s
.851 .549 .477 r
.27146 .27705 m .27721 .2797 L .27766 .28451 L p F P
0 g
s
.716 .58 .701 r
.38552 .41455 m .38432 .41452 L .38187 .40666 L p F P
0 g
s
.721 .583 .699 r
.38076 .40661 m .38187 .40666 L .38432 .41452 L p F P
0 g
s
.701 .57 .705 r
.41227 .4146 m .4135 .41457 L .41593 .4224 L p F P
0 g
s
.701 .569 .703 r
.4135 .41457 m .41324 .41373 L .41227 .4146 L closepath p F P
0 g
s
.739 .582 .679 r
.35941 .38258 m .35812 .378 L .35511 .38211 L closepath p F P
0 g
s
.721 .596 .716 r
.37789 .42216 m .38694 .42253 L p .38166 .43042 L F P
0 g
s
.719 .586 .706 r
.38694 .42253 m .38462 .41545 L .37789 .42216 L closepath p F P
0 g
s
.697 .567 .704 r
.4135 .41457 m .41324 .41373 L .42162 .40644 L p F P
0 g
s
.826 .758 .788 r
.09959 .31935 m .09346 .32603 L .0898 .32245 L p F P
0 g
s
.826 .758 .788 r
.0898 .32245 m .09568 .31604 L .09959 .31935 L p F P
0 g
s
.823 .759 .791 r
.10128 .31006 m .09568 .31604 L .09959 .31935 L p F P
0 g
s
.692 .566 .708 r
.4135 .41457 m .42738 .41387 L p .41778 .4223 L F P
0 g
s
.692 .566 .708 r
.41778 .4223 m .41593 .4224 L .4135 .41457 L p F P
0 g
s
.697 .567 .704 r
.42516 .40627 m .42738 .41387 L .4135 .41457 L p F P
0 g
s
.697 .567 .704 r
.42162 .40644 m .42516 .40627 L p .4135 .41457 L F P
0 g
s
.649 .718 .899 r
.57553 .51139 m .58694 .50814 L .58987 .51187 L p F P
0 g
s
.647 .695 .88 r
.58694 .50814 m .57553 .51139 L .57258 .50722 L p F P
0 g
s
.66 .61 .788 r
.5066 .48334 m .50917 .48889 L p .49485 .48679 L F P
0 g
s
.66 .61 .788 r
.49485 .48679 m .5006 .48452 L .5066 .48334 L p F P
0 g
s
.657 .6 .78 r
.49485 .48679 m .5006 .48452 L .4944 .48578 L closepath p F P
0 g
s
.716 .581 .703 r
.38462 .41545 m .38552 .41455 L .38432 .41452 L closepath p F P
0 g
s
.841 .575 .537 r
.28969 .29457 m .28522 .29269 L .28547 .28758 L p F P
0 g
s
.826 .561 .539 r
.28387 .28699 m .28547 .28758 L .28522 .29269 L p F P
0 g
s
.689 .575 .722 r
.41933 .43284 m .42288 .43014 L p .42741 .43815 L F P
0 g
s
.691 .571 .716 r
.41933 .43284 m .42288 .43014 L .41853 .43039 L closepath p F P
0 g
s
.72 .597 .718 r
.37641 .43535 m .38166 .43042 L .37453 .43008 L closepath p F P
0 g
s
.721 .596 .716 r
.37334 .4267 m .37789 .42216 L p .38166 .43042 L F P
0 g
s
.721 .596 .716 r
.38166 .43042 m .37453 .43008 L .37334 .4267 L p F P
0 g
s
.721 .583 .699 r
.38432 .41452 m .37379 .41401 L .38076 .40661 L p F P
0 g
s
.726 .59 .703 r
.36942 .40594 m .38076 .40661 L .37379 .41401 L p F P
0 g
s
.616 .458 .645 r
.4765 .34153 m .47542 .33517 L .48724 .33216 L p F P
0 g
s
.614 .451 .638 r
.48626 .32594 m .48724 .33216 L .47542 .33517 L p F P
0 g
s
.615 .655 .866 r
.62218 .25379 m .61256 .25581 L .61959 .24954 L closepath p F P
0 g
s
.618 .67 .878 r
.61927 .24901 m .61959 .24954 L .61256 .25581 L p F P
0 g
s
.618 .67 .878 r
.60777 .25171 m .61927 .24901 L p .61256 .25581 L F P
0 g
s
.723 .593 .71 r
.38432 .41452 m .38462 .41545 L .37789 .42216 L p F P
0 g
s
.723 .593 .71 r
.37379 .41401 m .38432 .41452 L p .37789 .42216 L F P
0 g
s
.691 .57 .715 r
.42288 .43014 m .41853 .43039 L .41628 .42351 L p F P
0 g
s
.732 .623 .737 r
.3539 .45594 m .35584 .45418 L .35304 .4539 L closepath p F P
0 g
s
.66 .518 .68 r
.44442 .37483 m .4573 .37304 L p .45321 .38084 L F P
0 g
s
.66 .518 .68 r
.45321 .38084 m .4461 .38187 L .44442 .37483 L p F P
0 g
s
.664 .518 .675 r
.45574 .36615 m .4573 .37304 L .44442 .37483 L p F P
0 g
s
.664 .518 .675 r
.45162 .36671 m .45574 .36615 L p .44442 .37483 L F P
0 g
s
.732 .622 .736 r
.35413 .44528 m .36473 .44617 L .35584 .45418 L p F P
0 g
s
.732 .622 .736 r
.35077 .44848 m .35413 .44528 L p .35584 .45418 L F P
0 g
s
.732 .622 .736 r
.35584 .45418 m .35304 .4539 L .35077 .44848 L p F P
0 g
s
.678 .581 .739 r
.43974 .45122 m .45018 .44468 L p .45346 .45309 L F P
0 g
s
.679 .576 .732 r
.43974 .45122 m .45018 .44468 L .43785 .44594 L closepath p F P
0 g
s
.719 .596 .718 r
.37325 .43828 m .37641 .43535 L .37453 .43008 L p F P
0 g
s
.704 .733 .873 r
.22266 .50759 m .21176 .51235 L .20829 .50898 L p F P
0 g
s
.86 .74 .73 r
.07075 .36366 m .07484 .36685 L .07074 .37324 L p F P
0 g
s
.855 .743 .739 r
.07365 .3594 m .07075 .36366 L .07484 .36685 L p F P
0 g
s
.343 0 0 r
.12445 .49383 m .13026 .49711 L .12998 .49695 L p F P
0 g
s
.343 0 0 r
.11911 .49126 m .12445 .49383 L p .12998 .49695 L F P
0 g
s
.67 .119 0 r
.1167 .48935 m .11911 .49126 L .12445 .49383 L p F P
0 g
s
.727 .613 .731 r
.36532 .44622 m .36515 .44579 L .36473 .44617 L closepath p F P
0 g
s
.727 .604 .719 r
.37325 .43828 m .36515 .44579 L .36205 .43777 L p F P
0 g
s
.727 .604 .719 r
.36205 .43777 m .36234 .43748 L .37325 .43828 L p F P
0 g
s
.719 .596 .718 r
.37017 .42981 m .36234 .43748 L .37325 .43828 L p F P
0 g
s
.719 .596 .718 r
.37453 .43008 m .37017 .42981 L p .37325 .43828 L F P
0 g
s
.692 .567 .709 r
.41628 .42351 m .41778 .4223 L .41593 .4224 L closepath p F P
0 g
s
.691 .57 .715 r
.41628 .42351 m .41778 .4223 L p .42288 .43014 L F P
0 g
s
.765 .584 .652 r
.33458 .35073 m .32622 .34914 L .3294 .34302 L p F P
0 g
s
.778 .594 .651 r
.32126 .34126 m .3294 .34302 L .32622 .34914 L p F P
0 g
s
.775 .76 .84 r
.14629 .26958 m .1481 .26822 L .152 .27157 L p F P
0 g
s
.773 .761 .842 r
.15739 .2613 m .1481 .26822 L .152 .27157 L p F P
0 g
s
.773 .761 .842 r
.152 .27157 m .16095 .2649 L .15739 .2613 L p F P
0 g
s
.867 .73 .71 r
.07108 .38268 m .06868 .38691 L .06506 .38278 L p F P
0 g
s
.867 .73 .71 r
.06506 .38278 m .06689 .37955 L .07108 .38268 L p F P
0 g
s
.861 .734 .721 r
.07108 .38268 m .06689 .37955 L .07074 .37324 L p F P
0 g
s
.724 .608 .728 r
.36205 .43777 m .35413 .44528 L .36473 .44617 L p F P
0 g
s
.724 .608 .728 r
.36473 .44617 m .36515 .44579 L .36205 .43777 L p F P
0 g
s
.728 .704 .828 r
.26654 .5017 m .26588 .50081 L .26496 .50136 L closepath p F P
0 g
s
.74 .668 .78 r
.30514 .48582 m .30262 .48141 L .29841 .48465 L closepath p F P
0 g
s
.654 .614 .796 r
.52047 .48478 m .52342 .49098 L .51153 .49375 L p F P
0 g
s
.654 .614 .796 r
.51153 .49375 m .50917 .48889 L .52047 .48478 L p F P
0 g
s
.692 .557 .697 r
.42516 .40627 m .42449 .40392 L .42162 .40644 L closepath p F P
0 g
s
.691 .57 .715 r
.41778 .4223 m .42977 .42166 L p .42288 .43014 L F P
0 g
s
.691 .564 .706 r
.42977 .42166 m .42752 .41435 L .41778 .4223 L closepath p F P
0 g
s
.692 .566 .708 r
.42738 .41387 m .42752 .41435 L .41778 .4223 L p F P
0 g
s
.532 .521 .788 r
.7057 .32705 m .70368 .32204 L .71047 .32264 L closepath p F P
0 g
s
.527 .51 .78 r
.7057 .32705 m .71047 .32264 L p .71563 .33047 L F P
0 g
s
.657 .6 .779 r
.5006 .48452 m .4944 .48578 L .4918 .47997 L p F P
0 g
s
.689 .574 .721 r
.43498 .43767 m .43362 .43363 L .42741 .43815 L closepath p F P
0 g
s
.689 .575 .722 r
.4323 .42958 m .43362 .43363 L .42741 .43815 L p F P
0 g
s
.689 .575 .722 r
.42288 .43014 m .4323 .42958 L p .42741 .43815 L F P
0 g
s
.661 .51 .668 r
.45574 .36615 m .45521 .36371 L .45162 .36671 L closepath p F P
0 g
s
.734 .581 .684 r
.35941 .38258 m .35511 .38211 L p .36006 .39 L F P
0 g
s
.734 .581 .684 r
.36006 .39 m .36114 .38863 L .35941 .38258 L p F P
0 g
s
.687 .554 .698 r
.42516 .40627 m .42449 .40392 L .43137 .39816 L p F P
0 g
s
.886 .683 .622 r
.07324 .43019 m .06872 .42723 L .0704 .42161 L p F P
0 g
s
.892 .671 .596 r
.06872 .42723 m .07324 .43019 L .07198 .43568 L p F P
0 g
s
.679 .589 .748 r
.45739 .46171 m .45708 .46092 L .45533 .46193 L closepath p F P
0 g
s
.677 .587 .747 r
.45412 .45302 m .45708 .46092 L .45533 .46193 L p F P
0 g
s
.677 .587 .747 r
.45346 .45309 m .45412 .45302 L p .45533 .46193 L F P
0 g
s
.69 .569 .714 r
.4323 .42958 m .43056 .42422 L .42288 .43014 L closepath p F P
0 g
s
.691 .57 .715 r
.42977 .42166 m .43056 .42422 L .42288 .43014 L p F P
0 g
s
.673 .534 .688 r
.43573 .39445 m .44174 .38968 L .43469 .39045 L closepath p F P
0 g
s
.683 .546 .692 r
.43469 .39045 m .43573 .39445 L .43137 .39816 L p F P
0 g
s
.762 .588 .661 r
.33464 .35097 m .33476 .35076 L p .33987 .35859 L F P
0 g
s
.767 .59 .659 r
.33464 .35097 m .33476 .35076 L .33458 .35073 L closepath p F P
0 g
s
.611 .745 .94 r
.21525 .25091 m .22598 .24829 L .22946 .25155 L p F P
0 g
s
.601 .741 .943 r
.22598 .24829 m .21525 .25091 L .21176 .24741 L p F P
0 g
s
.687 .752 .901 r
.20092 .25195 m .21176 .24741 L .21525 .25091 L p F P
0 g
s
.746 .686 .793 r
.277 .49318 m .27879 .49182 L .2865 .4936 L p F P
0 g
s
.736 .677 .794 r
.28817 .48478 m .27879 .49182 L .2865 .4936 L p F P
0 g
s
.736 .677 .794 r
.2865 .4936 m .29143 .49009 L .28817 .48478 L p F P
0 g
s
.723 .594 .711 r
.37334 .4267 m .37789 .42216 L .37165 .42181 L closepath p F P
0 g
s
.723 .593 .71 r
.37027 .41773 m .37379 .41401 L p .37789 .42216 L F P
0 g
s
.723 .593 .71 r
.37789 .42216 m .37165 .42181 L .37027 .41773 L p F P
0 g
s
.759 .586 .661 r
.33458 .35073 m .32622 .34914 L p .33116 .35704 L F P
0 g
s
.759 .586 .661 r
.33116 .35704 m .33464 .35097 L .33458 .35073 L p F P
0 g
s
.733 .622 .735 r
.35304 .4539 m .35077 .44848 L .34568 .45315 L closepath p F P
0 g
s
.822 .358 .116 r
.09717 .47501 m .10223 .47771 L .10489 .48202 L p F P
0 g
s
.862 .462 .279 r
.10223 .47771 m .09717 .47501 L .09616 .4725 L p F P
0 g
s
.824 .367 .135 r
.10995 .48471 m .10489 .48202 L .10223 .47771 L p F P
0 g
s
.407 .714 .986 r
.16553 .50849 m .16481 .50848 L .16694 .50946 L closepath p F P
0 g
s
.687 .554 .698 r
.43663 .39776 m .43866 .40517 L .42516 .40627 L p F P
0 g
s
.687 .554 .698 r
.43137 .39816 m .43663 .39776 L p .42516 .40627 L F P
0 g
s
.682 .553 .701 r
.42516 .40627 m .43866 .40517 L p .42823 .4138 L F P
0 g
s
.682 .553 .701 r
.42823 .4138 m .42738 .41387 L .42516 .40627 L p F P
0 g
s
.725 .598 .715 r
.37453 .43008 m .37334 .4267 L .37017 .42981 L closepath p F P
0 g
s
.762 .588 .661 r
.33987 .35859 m .33643 .35796 L .33464 .35097 L p F P
0 g
s
.76 .587 .662 r
.33643 .35796 m .33464 .35097 L .33116 .35704 L closepath p F P
0 g
s
.679 .575 .731 r
.45018 .44468 m .43785 .44594 L .43667 .44263 L p F P
0 g
s
.312 .071 .378 r
.7067 .4687 m .70735 .4683 L .7111 .46181 L p F P
0 g
s
.302 .06 .371 r
.71667 .45836 m .7111 .46181 L .70735 .4683 L p F P
0 g
s
.354 .145 .45 r
.7111 .46181 m .71667 .45836 L .7168 .45354 L p F P
0 g
s
.651 .503 .669 r
.45574 .36615 m .45521 .36371 L .46328 .35781 L p F P
0 g
s
.757 .589 .668 r
.33761 .36244 m .33987 .35859 L p .34499 .36642 L F P
0 g
s
.762 .591 .665 r
.33761 .36244 m .33987 .35859 L .33643 .35796 L closepath p F P
0 g
s
.404 .245 .55 r
.72555 .43679 m .72381 .43795 L .72486 .443 L p F P
0 g
s
.5 .908 .871 r
.65849 .50151 m .66708 .49778 L .65947 .50144 L closepath p F P
0 g
s
.442 .871 .768 r
.66998 .49647 m .66708 .49778 L .65947 .50144 L p F P
0 g
s
.632 .479 .658 r
.46645 .35539 m .46553 .3506 L .47766 .34796 L p F P
0 g
s
.632 .476 .653 r
.4765 .34153 m .47766 .34796 L .46553 .3506 L p F P
0 g
s
.646 .492 .66 r
.46553 .3506 m .46645 .35539 L .46328 .35781 L p F P
0 g
s
.684 .752 .903 r
.21176 .24741 m .20092 .25195 L .19742 .24837 L p F P
0 g
s
.72 .754 .879 r
.1865 .25412 m .19742 .24837 L .20092 .25195 L p F P
0 g
s
.649 .656 .843 r
.54388 .50438 m .55523 .50093 L .55822 .50591 L p F P
0 g
s
.648 .643 .831 r
.55261 .49628 m .55523 .50093 L .54388 .50438 L p F P
0 g
s
.648 .643 .831 r
.54388 .50438 m .54112 .49952 L .55261 .49628 L p F P
0 g
s
.744 .658 .765 r
.31704 .4782 m .31779 .47756 L .31659 .47735 L closepath p F P
0 g
s
.674 .586 .749 r
.46831 .45481 m .47028 .45998 L .45739 .46171 L p F P
0 g
s
.674 .586 .749 r
.45739 .46171 m .45708 .46092 L .46831 .45481 L p F P
0 g
s
.622 .056 0 r
.11911 .49126 m .1167 .48935 L .1129 .48802 L p F P
0 g
s
.745 .657 .764 r
.3186 .46788 m .32772 .46923 L .31779 .47756 L p F P
0 g
s
.745 .657 .764 r
.31384 .47209 m .3186 .46788 L p .31779 .47756 L F P
0 g
s
.745 .657 .764 r
.31779 .47756 m .31659 .47735 L .31384 .47209 L p F P
0 g
s
.753 .586 .67 r
.35007 .37426 m .3409 .37287 L .34499 .36642 L p F P
0 g
s
.757 .592 .672 r
.33839 .36532 m .34499 .36642 L .3409 .37287 L p F P
0 g
s
.757 .589 .668 r
.34499 .36642 m .33839 .36532 L .33761 .36244 L p F P
0 g
s
.735 .702 .819 r
.25146 .50335 m .25728 .49958 L .26496 .50136 L p F P
0 g
s
.726 .699 .824 r
.26255 .49619 m .25728 .49958 L .26496 .50136 L p F P
0 g
s
.726 .699 .824 r
.26496 .50136 m .26588 .50081 L .26255 .49619 L p F P
0 g
s
.722 .593 .712 r
.37017 .42981 m .37334 .4267 L .37165 .42181 L p F P
0 g
s
.652 .645 .83 r
.54112 .49952 m .54087 .49909 L .53386 .50135 L closepath p F P
0 g
s
.65 .631 .818 r
.53786 .49338 m .54087 .49909 L .53386 .50135 L p F P
0 g
s
.65 .631 .818 r
.52653 .4971 m .53786 .49338 L p .53386 .50135 L F P
0 g
s
.683 .545 .691 r
.43663 .39776 m .43573 .39445 L .43137 .39816 L closepath p F P
0 g
s
.63 .905 .984 r
.64427 .50526 m .63279 .50928 L .63279 .50928 L p F P
0 g
s
.635 .862 .985 r
.63279 .50928 m .63279 .50928 L .62998 .50739 L p F P
0 g
s
.636 .847 .981 r
.61851 .51101 m .62998 .50739 L .63279 .50928 L p F P
0 g
s
.635 .862 .985 r
.64311 .50462 m .63279 .50928 L p .62998 .50739 L F P
0 g
s
.64 .878 .985 r
.63279 .50928 m .64311 .50462 L .64427 .50526 L closepath p F P
0 g
s
.736 .584 .686 r
.36158 .39015 m .36114 .38863 L .36006 .39 L closepath p F P
0 g
s
.726 .591 .705 r
.37027 .41773 m .37379 .41401 L .36893 .41369 L closepath p F P
0 g
s
.726 .59 .703 r
.36721 .40842 m .36942 .40594 L p .37379 .41401 L F P
0 g
s
.726 .59 .703 r
.37379 .41401 m .36893 .41369 L .36721 .40842 L p F P
0 g
s
.68 .57 .725 r
.43667 .44263 m .44579 .43662 L .43498 .43767 L closepath p F P
0 g
s
.679 .575 .731 r
.43667 .44263 m .44579 .43662 L p .45018 .44468 L F P
0 g
s
.826 .561 .539 r
.28522 .29269 m .28357 .29208 L .28387 .28699 L p F P
0 g
s
.835 .569 .536 r
.27766 .28451 m .28387 .28699 L .28357 .29208 L p F P
0 g
s
.848 .749 .753 r
.07613 .34725 m .08014 .35049 L .07522 .35715 L p F P
0 g
s
.845 .75 .758 r
.08014 .35049 m .07613 .34725 L .08128 .34052 L p F P
0 g
s
.672 .579 .742 r
.46706 .45135 m .46831 .45481 L .45708 .46092 L p F P
0 g
s
.672 .579 .742 r
.45708 .46092 m .45412 .45302 L .46706 .45135 L p F P
0 g
s
.755 .248 .002 r
.26268 .26851 m .25945 .26695 L .25615 .26315 L p F P
0 g
s
.593 .427 .626 r
.48626 .32594 m .48594 .32363 L .4972 .31877 L p F P
0 g
s
.59 .421 .621 r
.49689 .31645 m .4972 .31877 L .48594 .32363 L p F P
0 g
s
.733 .585 .69 r
.36485 .39794 m .36389 .39785 L .36158 .39015 L p F P
0 g
s
.736 .587 .689 r
.36006 .39 m .36158 .39015 L .36389 .39785 L p F P
0 g
s
.83 .758 .783 r
.09297 .32658 m .09346 .32603 L .0898 .32245 L p F P
0 g
s
.736 .634 .746 r
.34075 .46158 m .33951 .45884 L .33691 .46112 L closepath p F P
0 g
s
.737 .579 .678 r
.35007 .37426 m .34553 .38086 L .35511 .38211 L p F P
0 g
s
.752 .594 .68 r
.3409 .37287 m .35007 .37426 L .34553 .38086 L p F P
0 g
s
.799 .594 .624 r
.31132 .3255 m .31085 .32536 L .30956 .31868 L p F P
0 g
s
.791 .589 .627 r
.30603 .31772 m .30956 .31868 L .31085 .32536 L p F P
0 g
s
.73 .607 .72 r
.35948 .42893 m .37017 .42981 L .36234 .43748 L p F P
0 g
s
.722 .593 .712 r
.36668 .42146 m .35948 .42893 L .37017 .42981 L p F P
0 g
s
.722 .593 .712 r
.37165 .42181 m .36668 .42146 L p .37017 .42981 L F P
0 g
s
.648 .75 .924 r
.58987 .51187 m .6013 .50858 L .60419 .5118 L p F P
0 g
s
.647 .721 .903 r
.6013 .50858 m .58987 .51187 L .58694 .50814 L p F P
0 g
s
.681 .759 .91 r
.59049 .24684 m .57907 .25072 L .57616 .24782 L p F P
0 g
s
.696 .796 .927 r
.56478 .25261 m .57616 .24782 L .57907 .25072 L p F P
0 g
s
.664 .729 .898 r
.57907 .25072 m .59049 .24684 L .5934 .25061 L p F P
0 g
s
.83 .758 .783 r
.0898 .32245 m .08907 .32327 L .09297 .32658 L p F P
0 g
s
.835 .757 .777 r
.08907 .32327 m .09297 .32658 L .08702 .33358 L p F P
0 g
s
.878 .717 .678 r
.06456 .39493 m .06881 .39802 L .06608 .40397 L p F P
0 g
s
.873 .722 .691 r
.06881 .39802 m .06456 .39493 L .0676 .38888 L p F P
0 g
s
.741 .687 .799 r
.277 .49318 m .26588 .50081 L .26255 .49619 L p F P
0 g
s
.677 .541 .692 r
.43663 .39776 m .43573 .39445 L .44174 .38968 L p F P
0 g
s
.729 .589 .699 r
.36721 .40842 m .36942 .40594 L .36635 .40571 L closepath p F P
0 g
s
.73 .588 .697 r
.36417 .39875 m .36485 .39794 L p .36942 .40594 L F P
0 g
s
.73 .588 .697 r
.36942 .40594 m .36635 .40571 L .36417 .39875 L p F P
0 g
s
.683 .554 .703 r
.42752 .41435 m .42823 .4138 L .42738 .41387 L closepath p F P
0 g
s
.748 .595 .686 r
.34553 .38086 m .35511 .38211 L .35008 .38888 L p F P
0 g
s
.734 .581 .684 r
.35511 .38211 m .35008 .38888 L .36006 .39 L p F P
0 g
s
.727 .595 .708 r
.37165 .42181 m .37027 .41773 L .36668 .42146 L closepath p F P
0 g
s
.431 .309 .613 r
.7331 .41857 m .72859 .42181 L .73177 .4262 L p F P
0 g
s
.448 .337 .636 r
.72859 .42181 m .7331 .41857 L .73196 .41233 L p F P
0 g
s
.68 .569 .724 r
.44579 .43662 m .43498 .43767 L .43362 .43363 L p F P
0 g
s
.681 .558 .709 r
.42752 .41435 m .42823 .4138 L p .43463 .42123 L F P
0 g
s
.681 .558 .709 r
.43463 .42123 m .42977 .42166 L .42752 .41435 L p F P
0 g
s
.741 .656 .765 r
.31659 .47735 m .31384 .47209 L .30895 .47613 L closepath p F P
0 g
s
.378 .197 .506 r
.7168 .45354 m .72457 .44846 L .72486 .443 L p F P
0 g
s
.338 .132 .447 r
.72457 .44846 m .7168 .45354 L .71667 .45836 L p F P
0 g
s
.566 .394 .607 r
.49689 .31645 m .49624 .31061 L .50733 .30671 L p F P
0 g
s
.559 .376 .59 r
.50683 .30106 m .50733 .30671 L .49624 .31061 L p F P
0 g
s
.736 .587 .689 r
.36389 .39785 m .35451 .39694 L .36006 .39 L p F P
0 g
s
.744 .597 .693 r
.35008 .38888 m .36006 .39 L .35451 .39694 L p F P
0 g
s
.733 .587 .692 r
.36417 .39875 m .36485 .39794 L .36389 .39785 L closepath p F P
0 g
s
.681 .558 .709 r
.42823 .4138 m .44088 .41277 L p .43463 .42123 L F P
0 g
s
.683 .553 .701 r
.44088 .41277 m .43876 .40551 L .42823 .4138 L closepath p F P
0 g
s
.682 .553 .701 r
.43866 .40517 m .43876 .40551 L .42823 .4138 L p F P
0 g
s
.648 .504 .674 r
.45574 .36615 m .46827 .36397 L p .4668 .37133 L F P
0 g
s
.648 .504 .674 r
.4668 .37133 m .4573 .37304 L .45574 .36615 L p F P
0 g
s
.651 .503 .669 r
.46682 .3572 m .46827 .36397 L .45574 .36615 L p F P
0 g
s
.651 .503 .669 r
.46328 .35781 m .46682 .3572 L p .45574 .36615 L F P
0 g
s
.45 .355 .656 r
.73062 .40584 m .73791 .4002 L p .73398 .4108 L F P
0 g
s
.45 .355 .656 r
.73398 .4108 m .73118 .40851 L .73062 .40584 L p F P
0 g
s
.462 .377 .674 r
.73062 .40584 m .73791 .4002 L .73231 .39658 L p F P
0 g
s
.737 .646 .758 r
.32854 .46934 m .32826 .46878 L .32772 .46923 L closepath p F P
0 g
s
.724 .59 .706 r
.36668 .42146 m .37027 .41773 L .36893 .41369 L p F P
0 g
s
.68 .569 .724 r
.43362 .43363 m .44054 .42882 L p .44579 .43662 L F P
0 g
s
.681 .564 .717 r
.43362 .43363 m .44054 .42882 L .4323 .42958 L closepath p F P
0 g
s
.74 .599 .699 r
.36389 .39785 m .36417 .39875 L .35879 .40504 L p F P
0 g
s
.74 .599 .699 r
.35451 .39694 m .36389 .39785 L p .35879 .40504 L F P
0 g
s
.845 .409 .189 r
.26484 .26974 m .26268 .26851 L .26422 .26853 L closepath p F P
0 g
s
.682 .559 .71 r
.43056 .42422 m .43463 .42123 L .42977 .42166 L closepath p F P
0 g
s
.733 .589 .696 r
.36635 .40571 m .36417 .39875 L .35879 .40504 L closepath p F P
0 g
s
.681 .564 .716 r
.44054 .42882 m .4323 .42958 L .43056 .42422 L p F P
0 g
s
.56 .563 .813 r
.68023 .2946 m .6795 .29462 L .68003 .29414 L closepath p F P
0 g
s
.566 .571 .818 r
.67733 .28839 m .68003 .29414 L .6795 .29462 L p F P
0 g
s
.748 .672 .777 r
.29841 .48465 m .29143 .49009 L .28817 .48478 L p F P
0 g
s
.724 .59 .706 r
.36893 .41369 m .36287 .41321 L p .36668 .42146 L F P
0 g
s
.73 .592 .702 r
.36893 .41369 m .36721 .40842 L .36287 .41321 L closepath p F P
0 g
s
.681 .564 .716 r
.43056 .42422 m .43463 .42123 L p .44054 .42882 L F P
0 g
s
.724 .735 .86 r
.22266 .50759 m .2242 .50674 L .23054 .50895 L p F P
0 g
s
.711 .721 .858 r
.23365 .50162 m .2242 .50674 L .23054 .50895 L p F P
0 g
s
.711 .721 .858 r
.23054 .50895 m .23705 .50565 L .23365 .50162 L p F P
0 g
s
.889 .687 .622 r
.06596 .41861 m .0704 .42161 L .06872 .42723 L p F P
0 g
s
.884 .696 .643 r
.0704 .42161 m .06596 .41861 L .06802 .41287 L p F P
0 g
s
.828 .584 .57 r
.29522 .30226 m .2889 .29984 L .28969 .29457 L p F P
0 g
s
.838 .594 .57 r
.28522 .29269 m .28969 .29457 L .2889 .29984 L p F P
0 g
s
.73 .608 .721 r
.36205 .43777 m .36234 .43748 L .36193 .43745 L closepath p F P
0 g
s
.73 .607 .72 r
.35896 .42947 m .35948 .42893 L p .36234 .43748 L F P
0 g
s
.73 .607 .72 r
.36234 .43748 m .36193 .43745 L .35896 .42947 L p F P
0 g
s
.735 .619 .729 r
.36193 .43745 m .36205 .43777 L .35413 .44528 L p F P
0 g
s
.735 .642 .756 r
.32509 .46218 m .3186 .46788 L .32772 .46923 L p F P
0 g
s
.735 .642 .756 r
.32772 .46923 m .32826 .46878 L .32509 .46218 L p F P
0 g
s
.737 .601 .705 r
.36635 .40571 m .36721 .40842 L .36287 .41321 L p F P
0 g
s
.737 .601 .705 r
.35879 .40504 m .36635 .40571 L p .36287 .41321 L F P
0 g
s
.597 .625 .85 r
.63954 .26188 m .63368 .26279 L .63791 .25892 L closepath p F P
0 g
s
.601 .637 .858 r
.63664 .25668 m .63791 .25892 L .63368 .26279 L p F P
0 g
s
.601 .637 .858 r
.62508 .25871 m .63664 .25668 L p .63368 .26279 L F P
0 g
s
.672 .54 .695 r
.43663 .39776 m .44978 .39627 L p .43933 .40509 L F P
0 g
s
.672 .54 .695 r
.43933 .40509 m .43866 .40517 L .43663 .39776 L p F P
0 g
s
.677 .541 .692 r
.44789 .38902 m .44978 .39627 L .43663 .39776 L p F P
0 g
s
.677 .541 .692 r
.44174 .38968 m .44789 .38902 L p .43663 .39776 L F P
0 g
s
.742 .636 .742 r
.33691 .46112 m .32826 .46878 L .32509 .46218 L p F P
0 g
s
.735 .619 .729 r
.35191 .43653 m .36193 .43745 L p .35413 .44528 L F P
0 g
s
.732 .608 .719 r
.36193 .43745 m .35896 .42947 L .35191 .43653 L closepath p F P
0 g
s
.661 .521 .682 r
.44698 .38544 m .45321 .38084 L .4461 .38187 L closepath p F P
0 g
s
.672 .533 .686 r
.4461 .38187 m .44698 .38544 L .44174 .38968 L p F P
0 g
s
0 .456 .806 r
.13606 .49961 m .13398 .49896 L .13026 .49711 L p F P
0 g
s
.489 .432 .72 r
.73367 .3761 m .72763 .37391 L .73198 .37034 L closepath p F P
0 g
s
.498 .446 .729 r
.73057 .36575 m .73198 .37034 L .72763 .37391 L p F P
0 g
s
.498 .446 .729 r
.72707 .36467 m .73057 .36575 L p .72763 .37391 L F P
0 g
s
.588 .616 .848 r
.6535 .26582 m .64244 .26724 L .63954 .26188 L p F P
0 g
s
.646 .792 .953 r
.60419 .5118 m .61565 .5084 L .61851 .51101 L p F P
0 g
s
.647 .757 .93 r
.61565 .5084 m .60419 .5118 L .6013 .50858 L p F P
0 g
s
.645 .805 .96 r
.62998 .50739 m .61851 .51101 L .61565 .5084 L p F P
0 g
s
.532 .521 .789 r
.71047 .32264 m .70368 .32204 L .70186 .31751 L p F P
0 g
s
.755 .587 .668 r
.33643 .35796 m .33116 .35704 L p .33607 .36494 L F P
0 g
s
.755 .587 .668 r
.33607 .36494 m .33761 .36244 L .33643 .35796 L p F P
0 g
s
.761 .76 .851 r
.165 .26211 m .16095 .2649 L .15739 .2613 L p F P
0 g
s
.641 .69 .88 r
.5934 .25061 m .60486 .2474 L .60777 .25171 L p F P
0 g
s
.651 .707 .888 r
.60486 .2474 m .5934 .25061 L .59049 .24684 L p F P
0 g
s
.746 .758 .862 r
.17199 .25734 m .18159 .25138 L .18552 .25473 L p F P
0 g
s
.745 .758 .863 r
.18298 .25052 m .18159 .25138 L .18552 .25473 L p F P
0 g
s
.745 .758 .863 r
.18552 .25473 m .1865 .25412 L .18298 .25052 L p F P
0 g
s
.665 .59 .762 r
.4863 .4668 m .48874 .47281 L p .47444 .47058 L F P
0 g
s
.665 .59 .762 r
.47444 .47058 m .48048 .46775 L .4863 .4668 L p F P
0 g
s
.662 .583 .756 r
.47444 .47058 m .48048 .46775 L .47377 .4689 L closepath p F P
0 g
s
.735 .62 .731 r
.35077 .44848 m .35413 .44528 L .34925 .44475 L closepath p F P
0 g
s
.735 .619 .729 r
.34766 .4408 m .35191 .43653 L p .35413 .44528 L F P
0 g
s
.735 .619 .729 r
.35413 .44528 m .34925 .44475 L .34766 .4408 L p F P
0 g
s
.733 .604 .714 r
.35626 .4205 m .36668 .42146 L .35948 .42893 L p F P
0 g
s
.724 .59 .706 r
.36287 .41321 m .35626 .4205 L .36668 .42146 L p F P
0 g
s
.673 .533 .686 r
.44789 .38902 m .44698 .38544 L .44174 .38968 L closepath p F P
0 g
s
.139 .541 .922 r
.23466 .25165 m .23987 .25279 L p .23644 .25028 L F P
0 g
s
.139 .541 .922 r
.23987 .25279 m .23996 .25281 L .23644 .25028 L p F P
0 g
s
.084 .499 .9 r
.23016 .24852 m .23644 .25028 L .2329 .24768 L p F P
0 g
s
.549 .007 0 r
.23644 .25028 m .2329 .24768 L p .23335 .24802 L F P
0 g
s
.139 .541 .922 r
.23644 .25028 m .23016 .24852 L .23466 .25165 L p F P
0 g
s
.549 .007 0 r
.23721 .25098 m .23644 .25028 L p .23335 .24802 L F P
0 g
s
.485 0 0 r
.23996 .25281 m .23644 .25028 L p .23654 .25036 L F P
0 g
s
.2 .585 .943 r
.23942 .25469 m .24344 .25531 L p .23996 .25281 L F P
0 g
s
.2 .585 .943 r
.23996 .25281 m .23466 .25165 L .23942 .25469 L p F P
0 g
s
.485 0 0 r
.24163 .25415 m .23996 .25281 L p .23654 .25036 L F P
0 g
s
.2 .585 .943 r
.24344 .25531 m .24348 .25531 L .23996 .25281 L p F P
0 g
s
.471 .69 .963 r
.22946 .25155 m .23466 .25165 L .23942 .25469 L p F P
0 g
s
.742 .636 .742 r
.32509 .46218 m .32763 .45982 L .33691 .46112 L p F P
0 g
s
.734 .631 .744 r
.3362 .45191 m .32763 .45982 L .33691 .46112 L p F P
0 g
s
.734 .631 .744 r
.33644 .45194 m .3362 .45191 L p .33691 .46112 L F P
0 g
s
.734 .631 .744 r
.33691 .46112 m .33951 .45884 L .33644 .45194 L p F P
0 g
s
.442 .677 .964 r
.23466 .25165 m .22946 .25155 L .22598 .24829 L p F P
0 g
s
.74 .632 .74 r
.34925 .44475 m .35077 .44848 L .34568 .45315 L p F P
0 g
s
.74 .632 .74 r
.34416 .44419 m .34925 .44475 L p .34568 .45315 L F P
0 g
s
.74 .632 .74 r
.33636 .45176 m .34416 .44419 L p .34568 .45315 L F P
0 g
s
.74 .632 .74 r
.34568 .45315 m .33644 .45194 L .33636 .45176 L p F P
0 g
s
.739 .633 .741 r
.33951 .45884 m .34568 .45315 L .33644 .45194 L closepath p F P
0 g
s
.607 .641 .859 r
.63664 .25668 m .62508 .25871 L .62218 .25379 L p F P
0 g
s
.574 .593 .834 r
.66054 .27846 m .65985 .27709 L .66214 .2769 L closepath p F P
0 g
s
.828 .599 .592 r
.2889 .29984 m .29522 .30226 L .29398 .3077 L p F P
0 g
s
.814 .587 .594 r
.30066 .30998 m .29398 .3077 L .29522 .30226 L p F P
0 g
s
.648 .495 .661 r
.46682 .3572 m .46645 .35539 L .46328 .35781 L closepath p F P
0 g
s
.679 .582 .74 r
.45412 .45302 m .45402 .45275 L .45346 .45309 L closepath p F P
0 g
s
.678 .581 .739 r
.4511 .44459 m .45402 .45275 L .45346 .45309 L p F P
0 g
s
.678 .581 .739 r
.45018 .44468 m .4511 .44459 L p .45346 .45309 L F P
0 g
s
.554 .557 .811 r
.68023 .2946 m .692 .29458 L p .68898 .30105 L F P
0 g
s
.552 .558 .814 r
.68909 .28816 m .692 .29458 L .68023 .2946 L p F P
0 g
s
.552 .558 .814 r
.68608 .28818 m .68909 .28816 L p .68023 .2946 L F P
0 g
s
.552 .558 .814 r
.68023 .2946 m .68003 .29414 L .68608 .28818 L p F P
0 g
s
.65 .622 .809 r
.53786 .49338 m .52653 .4971 L .5235 .49115 L p F P
0 g
s
.72 .755 .881 r
.19742 .24837 m .1865 .25412 L .18298 .25052 L p F P
0 g
s
.864 .463 .275 r
.09717 .47501 m .09232 .47237 L .09616 .4725 L closepath p F P
0 g
s
.674 .58 .741 r
.46525 .44635 m .46706 .45135 L .45412 .45302 L p F P
0 g
s
.674 .58 .741 r
.45412 .45302 m .45402 .45275 L .46525 .44635 L p F P
0 g
s
.672 .896 .977 r
.56305 .25173 m .56478 .25261 L .57616 .24782 L p F P
0 g
s
.662 .583 .755 r
.48048 .46775 m .47377 .4689 L .47138 .46288 L p F P
0 g
s
.672 .572 .735 r
.46408 .44295 m .46525 .44635 L .45402 .45275 L p F P
0 g
s
.672 .572 .735 r
.45402 .45275 m .4511 .44459 L .46408 .44295 L p F P
0 g
s
.681 .564 .716 r
.43463 .42123 m .44321 .42049 L p .44054 .42882 L F P
0 g
s
.682 .558 .708 r
.44321 .42049 m .4418 .4159 L .43463 .42123 L closepath p F P
0 g
s
.681 .558 .709 r
.44088 .41277 m .4418 .4159 L .43463 .42123 L p F P
0 g
s
.593 .427 .626 r
.4972 .31877 m .49772 .32249 L .48626 .32594 L p F P
0 g
s
.597 .438 .637 r
.48724 .33216 m .48626 .32594 L .49772 .32249 L p F P
0 g
s
.87 .73 .706 r
.0676 .38888 m .06868 .38691 L .06506 .38278 L p F P
0 g
s
0 0 0 r
.68282 .48985 m .684 .48856 L .69081 .48396 L p F P
0 g
s
.558 .568 .821 r
.68003 .29414 m .67733 .28839 L .68608 .28818 L closepath p F P
0 g
s
.725 .195 0 r
.10995 .48471 m .1129 .48802 L .11063 .4871 L p F P
0 g
s
.725 .195 0 r
.10489 .48202 m .10995 .48471 L p .11063 .4871 L F P
0 g
s
.476 .272 .523 r
.52238 .2837 m .5172 .28617 L .51723 .29126 L p F P
0 g
s
.438 .202 .457 r
.5172 .28617 m .52238 .2837 L .52632 .27732 L p F P
0 g
s
.802 .588 .612 r
.30603 .31772 m .29898 .31557 L .30066 .30998 L p F P
0 g
s
.815 .599 .61 r
.29398 .3077 m .30066 .30998 L .29898 .31557 L p F P
0 g
s
.736 .602 .708 r
.35283 .41216 m .36287 .41321 L .35626 .4205 L p F P
0 g
s
.737 .601 .705 r
.3528 .41207 m .35879 .40504 L p .36287 .41321 L F P
0 g
s
.737 .601 .705 r
.36287 .41321 m .35283 .41216 L .3528 .41207 L p F P
0 g
s
.665 .528 .687 r
.44789 .38902 m .44698 .38544 L .45321 .38084 L p F P
0 g
s
.657 .6 .779 r
.4918 .47997 m .50307 .47536 L p .5006 .48452 L F P
0 g
s
.657 .592 .77 r
.50235 .47364 m .50307 .47536 L .4918 .47997 L p F P
0 g
s
.657 .592 .77 r
.4918 .47997 m .49014 .47608 L .50235 .47364 L p F P
0 g
s
.756 .588 .669 r
.33839 .36532 m .33761 .36244 L .33607 .36494 L closepath p F P
0 g
s
.448 .725 .985 r
.16481 .50848 m .16553 .50849 L .16193 .50589 L p F P
0 g
s
.448 .725 .985 r
.16193 .50589 m .15941 .50595 L .16481 .50848 L p F P
0 g
s
.748 .672 .777 r
.28817 .48478 m .29038 .48297 L .29841 .48465 L p F P
0 g
s
.739 .665 .778 r
.29938 .47566 m .29038 .48297 L .29841 .48465 L p F P
0 g
s
.739 .665 .778 r
.29841 .48465 m .30262 .48141 L .29938 .47566 L p F P
0 g
s
.451 .355 .656 r
.73196 .41233 m .73118 .40851 L .73398 .4108 L closepath p F P
0 g
s
.632 .479 .658 r
.47766 .34796 m .4777 .34819 L .46645 .35539 L p F P
0 g
s
.635 .486 .663 r
.46682 .3572 m .46645 .35539 L .4777 .34819 L p F P
0 g
s
.672 .542 .698 r
.43876 .40551 m .43933 .40509 L .43866 .40517 L closepath p F P
0 g
s
.252 0 .288 r
.7066 .46926 m .70735 .4683 L .7067 .4687 L closepath p F P
0 g
s
.653 .604 .788 r
.51858 .48064 m .52047 .48478 L .50917 .48889 L p F P
0 g
s
.653 .604 .788 r
.50917 .48889 m .5066 .48334 L .51858 .48064 L p F P
0 g
s
.672 .546 .704 r
.43876 .40551 m .43933 .40509 L p .44742 .41199 L F P
0 g
s
.672 .546 .704 r
.44742 .41199 m .44088 .41277 L .43876 .40551 L p F P
0 g
s
.733 .606 .715 r
.35896 .42947 m .35948 .42893 L .35874 .42886 L closepath p F P
0 g
s
.733 .604 .714 r
.35587 .42091 m .35626 .4205 L p .35948 .42893 L F P
0 g
s
.733 .604 .714 r
.35948 .42893 m .35874 .42886 L .35587 .42091 L p F P
0 g
s
.659 .607 .785 r
.5066 .48334 m .50612 .48231 L .5006 .48452 L closepath p F P
0 g
s
.657 .6 .779 r
.50307 .47536 m .50612 .48231 L .5006 .48452 L p F P
0 g
s
.673 .541 .696 r
.45183 .4037 m .45 .39712 L .43933 .40509 L closepath p F P
0 g
s
.672 .54 .695 r
.44978 .39627 m .45 .39712 L .43933 .40509 L p F P
0 g
s
.672 .546 .704 r
.43933 .40509 m .45183 .4037 L p .44742 .41199 L F P
0 g
s
.804 .599 .625 r
.29898 .31557 m .30603 .31772 L .30393 .32347 L p F P
0 g
s
.791 .589 .627 r
.31085 .32536 m .30393 .32347 L .30603 .31772 L p F P
0 g
s
.739 .617 .723 r
.35874 .42886 m .35896 .42947 L .35191 .43653 L p F P
0 g
s
.744 .708 .818 r
.25728 .49958 m .25146 .50335 L .2481 .49905 L p F P
0 g
s
.729 .714 .836 r
.23705 .50565 m .2481 .49905 L .25146 .50335 L p F P
0 g
s
.761 .76 .851 r
.15739 .2613 m .16111 .25874 L .165 .26211 L p F P
0 g
s
.76 .76 .853 r
.16844 .25375 m .16111 .25874 L .165 .26211 L p F P
0 g
s
.76 .76 .853 r
.165 .26211 m .17199 .25734 L .16844 .25375 L p F P
0 g
s
.615 .462 .65 r
.4765 .34153 m .4883 .33849 L p .47862 .34772 L F P
0 g
s
.615 .462 .65 r
.47862 .34772 m .47766 .34796 L .4765 .34153 L p F P
0 g
s
.616 .458 .645 r
.48724 .33216 m .4883 .33849 L .4765 .34153 L p F P
0 g
s
.838 .756 .773 r
.08702 .33358 m .08184 .33983 L .07816 .33624 L p F P
0 g
s
.838 .756 .773 r
.07816 .33624 m .0831 .33029 L .08702 .33358 L p F P
0 g
s
.835 .757 .777 r
.08702 .33358 m .0831 .33029 L .08907 .32327 L p F P
0 g
s
.74 .6 .701 r
.3528 .41207 m .35879 .40504 L .35011 .40404 L closepath p F P
0 g
s
.74 .599 .699 r
.34973 .40291 m .35451 .39694 L p .35879 .40504 L F P
0 g
s
.74 .599 .699 r
.35879 .40504 m .35011 .40404 L .34973 .40291 L p F P
0 g
s
.736 .62 .729 r
.34925 .44475 m .34766 .4408 L .34416 .44419 L closepath p F P
0 g
s
.739 .617 .723 r
.34925 .42791 m .35874 .42886 L p .35191 .43653 L F P
0 g
s
.735 .605 .713 r
.35874 .42886 m .35587 .42091 L .34925 .42791 L closepath p F P
0 g
s
.757 .592 .672 r
.3409 .37287 m .34047 .3728 L .33839 .36532 L p F P
0 g
s
.756 .591 .673 r
.33607 .36494 m .33839 .36532 L .34047 .3728 L p F P
0 g
s
.574 .596 .837 r
.66214 .2769 m .65985 .27709 L .65695 .27141 L p F P
0 g
s
.389 .234 .547 r
.73391 .43091 m .72555 .43679 L .72599 .44224 L p F P
0 g
s
.414 .276 .583 r
.72555 .43679 m .73391 .43091 L .73177 .4262 L p F P
0 g
s
.404 .245 .55 r
.72486 .443 m .72599 .44224 L .72555 .43679 L p F P
0 g
s
.864 .738 .722 r
.06663 .37006 m .07074 .37324 L .06689 .37955 L p F P
0 g
s
.86 .74 .73 r
.07074 .37324 m .06663 .37006 L .07075 .36366 L p F P
0 g
s
.68 .569 .724 r
.44054 .42882 m .44567 .42836 L p .44579 .43662 L F P
0 g
s
.681 .564 .716 r
.44567 .42836 m .44485 .42579 L .44054 .42882 L closepath p F P
0 g
s
.681 .564 .716 r
.44321 .42049 m .44485 .42579 L .44054 .42882 L p F P
0 g
s
.648 .671 .858 r
.55822 .50591 m .56961 .50261 L p .57054 .50782 L F P
0 g
s
.645 .655 .845 r
.56961 .50261 m .55822 .50591 L .55523 .50093 L p F P
0 g
s
.68 .576 .732 r
.4511 .44459 m .45096 .44419 L .45018 .44468 L closepath p F P
0 g
s
.679 .575 .731 r
.44829 .43638 m .45096 .44419 L .45018 .44468 L p F P
0 g
s
.679 .575 .731 r
.44579 .43662 m .44829 .43638 L p .45018 .44468 L F P
0 g
s
.887 .7 .644 r
.06367 .40983 m .06802 .41287 L .06596 .41861 L p F P
0 g
s
.881 .707 .662 r
.06802 .41287 m .06367 .40983 L .06608 .40397 L p F P
0 g
s
.792 .597 .637 r
.31104 .3262 m .31132 .3255 L p .31629 .33338 L F P
0 g
s
.798 .601 .635 r
.31104 .3262 m .31132 .3255 L .31085 .32536 L closepath p F P
0 g
s
.75 .661 .763 r
.30895 .47613 m .30262 .48141 L .29938 .47566 L p F P
0 g
s
.661 .527 .69 r
.44789 .38902 m .46071 .38716 L p .45164 .396 L F P
0 g
s
.661 .527 .69 r
.45164 .396 m .44978 .39627 L .44789 .38902 L p F P
0 g
s
.665 .528 .687 r
.45895 .38004 m .46071 .38716 L .44789 .38902 L p F P
0 g
s
.665 .528 .687 r
.45321 .38084 m .45895 .38004 L p .44789 .38902 L F P
0 g
s
.674 .573 .733 r
.46219 .43747 m .46408 .44295 L .4511 .44459 L p F P
0 g
s
.674 .573 .733 r
.4511 .44459 m .45096 .44419 L .46219 .43747 L p F P
0 g
s
.744 .598 .695 r
.34973 .40291 m .35451 .39694 L .34752 .39605 L closepath p F P
0 g
s
.744 .597 .693 r
.34668 .39341 m .35008 .38888 L p .35451 .39694 L F P
0 g
s
.744 .597 .693 r
.35451 .39694 m .34752 .39605 L .34668 .39341 L p F P
0 g
s
.515 .759 .985 r
.1797 .50965 m .17614 .50675 L .16553 .50849 L p F P
0 g
s
.592 .749 .952 r
.17614 .50675 m .16553 .50849 L .16193 .50589 L p F P
0 g
s
.532 .521 .789 r
.70186 .31751 m .70441 .31509 L p .71047 .32264 L F P
0 g
s
.537 .531 .796 r
.70186 .31751 m .70075 .31486 L .70441 .31509 L closepath p F P
0 g
s
.786 .598 .646 r
.31396 .33877 m .31629 .33338 L p .32126 .34126 L F P
0 g
s
.791 .601 .644 r
.31396 .33877 m .31629 .33338 L .3124 .33229 L closepath p F P
0 g
s
.792 .597 .637 r
.31629 .33338 m .3124 .33229 L .31104 .3262 L p F P
0 g
s
.672 .566 .727 r
.4613 .43476 m .46219 .43747 L .45096 .44419 L p F P
0 g
s
.672 .566 .727 r
.45096 .44419 m .44829 .43638 L .4613 .43476 L p F P
0 g
s
.636 .491 .668 r
.46827 .36397 m .46682 .3572 L .47901 .35462 L p F P
0 g
s
.635 .486 .663 r
.4777 .34819 m .47901 .35462 L .46682 .3572 L p F P
0 g
s
.68 .57 .724 r
.44829 .43638 m .4479 .43521 L .44579 .43662 L closepath p F P
0 g
s
.68 .569 .724 r
.44567 .42836 m .4479 .43521 L .44579 .43662 L p F P
0 g
s
.672 .547 .705 r
.4418 .4159 m .44742 .41199 L .44088 .41277 L closepath p F P
0 g
s
.648 .507 .677 r
.45822 .37705 m .4668 .37133 L .4573 .37304 L closepath p F P
0 g
s
.66 .518 .68 r
.4573 .37304 m .45822 .37705 L .45321 .38084 L p F P
0 g
s
.854 .747 .745 r
.07522 .35715 m .07365 .3594 L .06998 .35566 L p F P
0 g
s
.854 .747 .745 r
.06998 .35566 m .0712 .35392 L .07522 .35715 L p F P
0 g
s
.848 .749 .753 r
.07522 .35715 m .0712 .35392 L .07613 .34725 L p F P
0 g
s
.778 .594 .651 r
.32622 .34914 m .31834 .3473 L .32126 .34126 L p F P
0 g
s
.785 .603 .654 r
.31411 .3394 m .32126 .34126 L .31834 .3473 L p F P
0 g
s
.786 .598 .646 r
.32126 .34126 m .31411 .3394 L .31396 .33877 L p F P
0 g
s
.786 .594 .64 r
.31085 .32536 m .30393 .32347 L p .30884 .33138 L F P
0 g
s
.786 .594 .64 r
.30884 .33138 m .31104 .3262 L .31085 .32536 L p F P
0 g
s
.862 .507 .377 r
.27146 .27705 m .26603 .27429 L .26484 .26974 L p F P
0 g
s
.877 .529 .389 r
.26268 .26851 m .26484 .26974 L .26603 .27429 L p F P
0 g
s
.748 .597 .689 r
.34668 .39341 m .35008 .38888 L .34505 .38818 L closepath p F P
0 g
s
.748 .595 .686 r
.34364 .38355 m .34553 .38086 L p .35008 .38888 L F P
0 g
s
.748 .595 .686 r
.35008 .38888 m .34505 .38818 L .34364 .38355 L p F P
0 g
s
.876 .726 .692 r
.06343 .38574 m .0676 .38888 L .06456 .39493 L p F P
0 g
s
.87 .73 .706 r
.06506 .38278 m .06343 .38574 L .0676 .38888 L p F P
0 g
s
.182 0 .227 r
.70735 .4683 m .71622 .46281 L p .70582 .47269 L F P
0 g
s
.182 0 .227 r
.70582 .47269 m .7066 .46926 L .70735 .4683 L p F P
0 g
s
.302 .06 .371 r
.70735 .4683 m .71622 .46281 L .71667 .45836 L p F P
0 g
s
.738 .618 .725 r
.34766 .4408 m .35191 .43653 L .34567 .43579 L closepath p F P
0 g
s
.739 .617 .723 r
.34454 .43291 m .34925 .42791 L p .35191 .43653 L F P
0 g
s
.739 .617 .723 r
.35191 .43653 m .34567 .43579 L .34454 .43291 L p F P
0 g
s
.779 .603 .662 r
.31834 .3473 m .32622 .34914 L .32291 .35532 L p F P
0 g
s
.759 .586 .661 r
.32622 .34914 m .32291 .35532 L .33116 .35704 L p F P
0 g
s
.381 .109 .371 r
.53407 .26968 m .53866 .26727 L p .52783 .27662 L F P
0 g
s
.381 .109 .371 r
.52783 .27662 m .52795 .27584 L .53407 .26968 L p F P
0 g
s
.196 0 .11 r
.53407 .26968 m .53866 .26727 L .53923 .26592 L closepath p F P
0 g
s
.671 .552 .711 r
.4418 .4159 m .44742 .41199 L p .45512 .41903 L F P
0 g
s
.671 .552 .711 r
.45512 .41903 m .44321 .42049 L .4418 .4159 L p F P
0 g
s
.755 .587 .668 r
.33116 .35704 m .32745 .36335 L .33607 .36494 L p F P
0 g
s
.773 .604 .669 r
.32291 .35532 m .33116 .35704 L .32745 .36335 L p F P
0 g
s
.752 .596 .683 r
.34364 .38355 m .34553 .38086 L .3427 .38043 L closepath p F P
0 g
s
.752 .594 .68 r
.34061 .3733 m .3409 .37287 L p .34553 .38086 L F P
0 g
s
.752 .594 .68 r
.34553 .38086 m .3427 .38043 L .34061 .3733 L p F P
0 g
s
.662 .52 .68 r
.45895 .38004 m .45822 .37705 L .45321 .38084 L closepath p F P
0 g
s
.785 .593 .64 r
.3124 .33229 m .31104 .3262 L .30884 .33138 L closepath p F P
0 g
s
.756 .591 .673 r
.34047 .3728 m .33194 .3714 L .33607 .36494 L p F P
0 g
s
.768 .6 .671 r
.32745 .36335 m .33607 .36494 L .33194 .3714 L p F P
0 g
s
.662 .583 .755 r
.47138 .46288 m .48107 .45816 L p .48048 .46775 L F P
0 g
s
.662 .576 .748 r
.47138 .46288 m .48107 .45816 L .47028 .45998 L closepath p F P
0 g
s
.756 .595 .677 r
.34061 .3733 m .3409 .37287 L .34047 .3728 L closepath p F P
0 g
s
.75 .661 .763 r
.29938 .47566 m .30071 .4745 L .30895 .47613 L p F P
0 g
s
.74 .653 .764 r
.31012 .46632 m .30071 .4745 L .30895 .47613 L p F P
0 g
s
.74 .653 .764 r
.31093 .46646 m .31012 .46632 L p .30895 .47613 L F P
0 g
s
.74 .653 .764 r
.30895 .47613 m .31384 .47209 L .31093 .46646 L p F P
0 g
s
.237 0 .247 r
.70081 .47562 m .70582 .47269 L .7066 .46926 L closepath p F P
0 g
s
.736 .604 .709 r
.35587 .42091 m .35626 .4205 L .35571 .42044 L closepath p F P
0 g
s
.736 .602 .708 r
.35626 .4205 m .35571 .42044 L .35283 .41216 L p F P
0 g
s
.675 .566 .725 r
.45914 .42817 m .4613 .43476 L .44829 .43638 L p F P
0 g
s
.675 .566 .725 r
.44829 .43638 m .4479 .43521 L .45914 .42817 L p F P
0 g
s
.671 .553 .712 r
.44485 .42579 m .45512 .41903 L .44321 .42049 L closepath p F P
0 g
s
.749 .692 .797 r
.277 .49318 m .27879 .49182 L .27555 .49099 L closepath p F P
0 g
s
.741 .687 .799 r
.27555 .49099 m .277 .49318 L p .26255 .49619 L F P
0 g
s
.659 .592 .769 r
.50002 .46803 m .50235 .47364 L .49014 .47608 L p F P
0 g
s
.659 .592 .769 r
.49014 .47608 m .48874 .47281 L .50002 .46803 L p F P
0 g
s
.742 .615 .717 r
.35571 .42044 m .35587 .42091 L .34925 .42791 L p F P
0 g
s
.63 .676 .875 r
.61927 .24901 m .60777 .25171 L .60486 .2474 L p F P
0 g
s
.672 .559 .719 r
.45869 .42674 m .45914 .42817 L .4479 .43521 L p F P
0 g
s
.672 .559 .719 r
.4479 .43521 m .44567 .42836 L .45869 .42674 L p F P
0 g
s
.751 .591 .679 r
.34047 .3728 m .33194 .3714 L p .33636 .37947 L F P
0 g
s
.751 .591 .679 r
.33636 .37947 m .34061 .3733 L .34047 .3728 L p F P
0 g
s
.734 .616 .727 r
.34416 .44419 m .34766 .4408 L .34567 .43579 L p F P
0 g
s
.798 .764 .821 r
.12731 .28532 m .12393 .28829 L .12031 .28475 L p F P
0 g
s
.805 .764 .815 r
.11842 .29334 m .12393 .28829 L .12031 .28475 L p F P
0 g
s
.807 .763 .812 r
.11842 .29334 m .11265 .29874 L .10901 .29521 L p F P
0 g
s
.807 .763 .812 r
.10901 .29521 m .11463 .28996 L .11842 .29334 L p F P
0 g
s
.805 .764 .815 r
.12031 .28475 m .11463 .28996 L .11842 .29334 L p F P
0 g
s
.742 .615 .717 r
.34624 .4194 m .35571 .42044 L p .34925 .42791 L F P
0 g
s
.738 .603 .707 r
.35273 .41215 m .35283 .41216 L .35571 .42044 L p F P
0 g
s
.738 .603 .707 r
.35571 .42044 m .34624 .4194 L .35273 .41215 L p F P
0 g
s
.752 .594 .68 r
.3427 .38043 m .34061 .3733 L .33636 .37947 L closepath p F P
0 g
s
.648 .672 .859 r
.57258 .50722 m .57054 .50782 L .57256 .5072 L closepath p F P
0 g
s
.648 .671 .858 r
.56961 .50261 m .57256 .5072 L .57054 .50782 L p F P
0 g
s
.46 .377 .676 r
.73795 .39215 m .73231 .39658 L .73791 .4002 L p F P
0 g
s
.473 .397 .69 r
.73685 .38783 m .73795 .39215 L .73231 .39658 L p F P
0 g
s
.473 .397 .69 r
.73442 .38654 m .73685 .38783 L p .73231 .39658 L F P
0 g
s
.675 .56 .718 r
.45624 .41889 m .45869 .42674 L .44567 .42836 L p F P
0 g
s
.675 .56 .718 r
.45512 .41903 m .45624 .41889 L p .44567 .42836 L F P
0 g
s
.675 .56 .718 r
.44567 .42836 m .44485 .42579 L .45512 .41903 L p F P
0 g
s
0 0 0 r
.69081 .48396 m .69475 .48177 L p .68282 .48985 L F P
0 g
s
.109 0 .025 r
.69081 .48396 m .69475 .48177 L .69537 .48044 L closepath p F P
0 g
s
.813 .763 .807 r
.11019 .30113 m .11265 .29874 L .10901 .29521 L p F P
0 g
s
.798 .764 .821 r
.12031 .28475 m .12352 .28193 L .12731 .28532 L p F P
0 g
s
.796 .764 .824 r
.13154 .27502 m .12352 .28193 L .12731 .28532 L p F P
0 g
s
.796 .764 .824 r
.12731 .28532 m .13514 .27857 L .13154 .27502 L p F P
0 g
s
.743 .623 .727 r
.34416 .44419 m .33636 .45176 L .33322 .44445 L p F P
0 g
s
.743 .623 .727 r
.33322 .44445 m .33473 .44292 L .34416 .44419 L p F P
0 g
s
.734 .616 .727 r
.34213 .43537 m .33473 .44292 L .34416 .44419 L p F P
0 g
s
.734 .616 .727 r
.34567 .43579 m .34213 .43537 L p .34416 .44419 L F P
0 g
s
.75 .691 .795 r
.28653 .48206 m .28817 .48478 L .27879 .49182 L p F P
0 g
s
.75 .691 .795 r
.2825 .48123 m .28653 .48206 L p .27879 .49182 L F P
0 g
s
.75 .691 .795 r
.2737 .48817 m .2825 .48123 L p .27879 .49182 L F P
0 g
s
.75 .691 .795 r
.27879 .49182 m .27555 .49099 L .2737 .48817 L p F P
0 g
s
.449 .214 .465 r
.52783 .27662 m .52632 .27732 L .52238 .2837 L p F P
0 g
s
.398 .123 .376 r
.52632 .27732 m .52783 .27662 L .52795 .27584 L closepath p F P
0 g
s
.816 .763 .803 r
.10639 .29776 m .11019 .30113 L .10261 .3087 L p F P
0 g
s
.813 .763 .807 r
.10901 .29521 m .10639 .29776 L .11019 .30113 L p F P
0 g
s
.748 .656 .759 r
.31384 .47209 m .3186 .46788 L .31093 .46646 L closepath p F P
0 g
s
.495 .446 .732 r
.73057 .36575 m .72707 .36467 L .72958 .36257 L closepath p F P
0 g
s
.504 .459 .74 r
.72751 .3562 m .72958 .36257 L .72707 .36467 L p F P
0 g
s
.504 .459 .74 r
.72559 .3557 m .72751 .3562 L p .72707 .36467 L F P
0 g
s
.532 .918 .921 r
.66708 .49778 m .65849 .50151 L .65578 .50098 L p F P
0 g
s
.564 .918 .959 r
.64427 .50526 m .65578 .50098 L .65849 .50151 L p F P
0 g
s
.435 .329 .635 r
.73398 .4108 m .73196 .41233 L .7331 .41857 L p F P
0 g
s
.896 .597 .473 r
.08508 .45993 m .08034 .45709 L .08012 .45205 L p F P
0 g
s
.899 .6 .47 r
.07544 .44917 m .08012 .45205 L .08034 .45709 L p F P
0 g
s
.896 .628 .524 r
.08012 .45205 m .07544 .44917 L .07577 .44396 L p F P
0 g
s
.662 .575 .747 r
.48107 .45816 m .47028 .45998 L .46831 .45481 L p F P
0 g
s
.537 .532 .797 r
.70441 .31509 m .70075 .31486 L .69783 .30786 L p F P
0 g
s
.857 .746 .74 r
.07075 .36366 m .07365 .3594 L .06998 .35566 L p F P
0 g
s
.537 .36 .589 r
.50733 .30671 m .50683 .30106 L .51755 .29668 L p F P
0 g
s
.524 .334 .565 r
.51723 .29126 m .51755 .29668 L .50683 .30106 L p F P
0 g
s
.548 .548 .806 r
.69491 .30116 m .68898 .30105 L .69314 .2971 L closepath p F P
0 g
s
.549 .546 .804 r
.68898 .30105 m .69491 .30116 L p .69739 .30784 L F P
0 g
s
.554 .557 .811 r
.692 .29458 m .69314 .2971 L .68898 .30105 L p F P
0 g
s
.748 .655 .758 r
.32367 .45917 m .32509 .46218 L .3186 .46788 L p F P
0 g
s
.748 .655 .758 r
.3187 .4584 m .32367 .45917 L p .3186 .46788 L F P
0 g
s
.748 .655 .758 r
.31064 .46588 m .3187 .4584 L p .3186 .46788 L F P
0 g
s
.748 .655 .758 r
.3186 .46788 m .31093 .46646 L .31064 .46588 L p F P
0 g
s
.892 .557 .406 r
.09069 .46761 m .0859 .4648 L .08508 .45993 L p F P
0 g
s
.895 .558 .401 r
.08034 .45709 m .08508 .45993 L .0859 .4648 L p F P
0 g
s
.734 .709 .828 r
.2481 .49905 m .23705 .50565 L .23365 .50162 L p F P
0 g
s
.201 .63 .949 r
.13606 .49961 m .14419 .50115 L .14052 .49868 L p F P
0 g
s
.201 .63 .949 r
.14052 .49868 m .1304 .49714 L .13606 .49961 L p F P
0 g
s
0 .456 .806 r
.13026 .49711 m .1304 .49714 L .13606 .49961 L p F P
0 g
s
.739 .632 .74 r
.33644 .45194 m .33636 .45176 L .3362 .45191 L closepath p F P
0 g
s
.747 .593 .685 r
.3427 .38043 m .33636 .37947 L p .34068 .38757 L F P
0 g
s
.747 .593 .685 r
.34068 .38757 m .34364 .38355 L .3427 .38043 L p F P
0 g
s
.652 .514 .682 r
.45895 .38004 m .45822 .37705 L .4668 .37133 L p F P
0 g
s
.737 .627 .738 r
.3362 .45191 m .33636 .45176 L .33322 .44445 L p F P
0 g
s
.744 .708 .818 r
.2481 .49905 m .25025 .49758 L .25728 .49958 L p F P
0 g
s
.732 .698 .818 r
.25922 .49149 m .25025 .49758 L .25728 .49958 L p F P
0 g
s
.732 .698 .818 r
.25728 .49958 m .26255 .49619 L .25922 .49149 L p F P
0 g
s
.746 .643 .746 r
.32687 .45061 m .3362 .45191 L .32763 .45982 L p F P
0 g
s
.737 .627 .738 r
.33322 .44445 m .32687 .45061 L .3362 .45191 L p F P
0 g
s
.899 .631 .523 r
.07116 .44105 m .07577 .44396 L .07544 .44917 L p F P
0 g
s
.894 .652 .564 r
.07577 .44396 m .07116 .44105 L .07198 .43568 L p F P
0 g
s
.788 .763 .831 r
.13708 .27699 m .13514 .27857 L .13154 .27502 L p F P
0 g
s
.738 .602 .705 r
.35283 .41216 m .3528 .41207 L .35273 .41215 L closepath p F P
0 g
s
.661 .529 .693 r
.45 .39712 m .45164 .396 L .44978 .39627 L closepath p F P
0 g
s
.736 .598 .703 r
.35273 .41215 m .3528 .41207 L .35011 .40404 L p F P
0 g
s
.746 .613 .711 r
.34294 .41098 m .35273 .41215 L .34624 .4194 L p F P
0 g
s
.736 .598 .703 r
.34891 .4039 m .34294 .41098 L .35273 .41215 L p F P
0 g
s
.736 .598 .703 r
.35011 .40404 m .34891 .4039 L p .35273 .41215 L F P
0 g
s
.746 .644 .747 r
.32509 .46218 m .32763 .45982 L .32367 .45917 L closepath p F P
0 g
s
.746 .643 .746 r
.32192 .45544 m .32687 .45061 L p .32763 .45982 L F P
0 g
s
.746 .643 .746 r
.32763 .45982 m .32367 .45917 L .32192 .45544 L p F P
0 g
s
.192 0 .109 r
.53866 .26727 m .53923 .26592 L .54666 .26043 L p F P
0 g
s
.041 0 0 r
.69475 .48177 m .69537 .48044 L .70081 .47562 L p F P
0 g
s
.664 .587 .759 r
.4863 .4668 m .48569 .46529 L .48048 .46775 L closepath p F P
0 g
s
.662 .583 .755 r
.48281 .45788 m .48569 .46529 L .48048 .46775 L p F P
0 g
s
.662 .583 .755 r
.48107 .45816 m .48281 .45788 L p .48048 .46775 L F P
0 g
s
.841 .755 .768 r
.08128 .34052 m .08184 .33983 L .07816 .33624 L p F P
0 g
s
.648 .643 .831 r
.55223 .49561 m .55261 .49628 L .54112 .49952 L p F P
0 g
s
.648 .643 .831 r
.54112 .49952 m .54087 .49909 L .55223 .49561 L p F P
0 g
s
.851 .549 .477 r
.27766 .28451 m .27185 .28189 L .27146 .27705 L p F P
0 g
s
.865 .563 .476 r
.26603 .27429 m .27146 .27705 L .27185 .28189 L p F P
0 g
s
.748 .595 .686 r
.34505 .38818 m .34364 .38355 L .34068 .38757 L closepath p F P
0 g
s
.661 .534 .699 r
.45 .39712 m .45164 .396 L p .46215 .40214 L F P
0 g
s
.661 .534 .699 r
.46215 .40214 m .45183 .4037 L .45 .39712 L p F P
0 g
s
.788 .763 .831 r
.13154 .27502 m .13329 .27359 L .13708 .27699 L p F P
0 g
s
.786 .764 .833 r
.1427 .26602 m .13329 .27359 L .13708 .27699 L p F P
0 g
s
.786 .764 .833 r
.13708 .27699 m .14629 .26958 L .1427 .26602 L p F P
0 g
s
.041 0 0 r
.70081 .47562 m .70582 .47269 L p .69475 .48177 L F P
0 g
s
.746 .759 .864 r
.18159 .25138 m .17199 .25734 L .16844 .25375 L p F P
0 g
s
.847 .754 .76 r
.07737 .33723 m .08128 .34052 L .07613 .34725 L p F P
0 g
s
.841 .755 .768 r
.07816 .33624 m .07737 .33723 L .08128 .34052 L p F P
0 g
s
.742 .616 .719 r
.34454 .43291 m .34925 .42791 L .34228 .42701 L closepath p F P
0 g
s
.742 .615 .717 r
.34144 .4248 m .34624 .4194 L p .34925 .42791 L F P
0 g
s
.742 .615 .717 r
.34925 .42791 m .34228 .42701 L .34144 .4248 L p F P
0 g
s
.743 .594 .691 r
.34505 .38818 m .34068 .38757 L p .34488 .39571 L F P
0 g
s
.743 .594 .691 r
.34488 .39571 m .34668 .39341 L .34505 .38818 L p F P
0 g
s
.671 .552 .711 r
.44742 .41199 m .45398 .41124 L p .45512 .41903 L F P
0 g
s
.673 .547 .704 r
.45398 .41124 m .45304 .40803 L .44742 .41199 L closepath p F P
0 g
s
.672 .546 .704 r
.45183 .4037 m .45304 .40803 L .44742 .41199 L p F P
0 g
s
.88 .501 .319 r
.09232 .47237 m .09216 .47229 L .09069 .46761 L p F P
0 g
s
.883 .5 .309 r
.0859 .4648 m .09069 .46761 L .09216 .47229 L p F P
0 g
s
.82 .762 .798 r
.10261 .3087 m .10128 .31006 L .09763 .30654 L p F P
0 g
s
.82 .762 .798 r
.09763 .30654 m .09879 .30534 L .10261 .3087 L p F P
0 g
s
.816 .763 .803 r
.10261 .3087 m .09879 .30534 L .10639 .29776 L p F P
0 g
s
.741 .599 .699 r
.35011 .40404 m .34973 .40291 L .34891 .4039 L closepath p F P
0 g
s
.657 .584 .762 r
.49858 .46441 m .50002 .46803 L .48874 .47281 L p F P
0 g
s
.657 .584 .762 r
.48874 .47281 m .4863 .4668 L .49858 .46441 L p F P
0 g
s
.569 .586 .83 r
.67153 .27629 m .66214 .2769 L .66867 .27047 L closepath p F P
0 g
s
.574 .596 .837 r
.66863 .27039 m .66867 .27047 L .66214 .2769 L p F P
0 g
s
.574 .596 .837 r
.65695 .27141 m .66863 .27039 L p .66214 .2769 L F P
0 g
s
.739 .596 .697 r
.34891 .4039 m .34973 .40291 L .34752 .39605 L p F P
0 g
s
.739 .617 .723 r
.34567 .43579 m .34454 .43291 L .34213 .43537 L closepath p F P
0 g
s
.745 .597 .692 r
.34752 .39605 m .34668 .39341 L .34488 .39571 L closepath p F P
0 g
s
.645 .627 .817 r
.55223 .49561 m .54087 .49909 L .53786 .49338 L p F P
0 g
s
.739 .596 .697 r
.34752 .39605 m .34488 .39571 L p .34891 .4039 L F P
0 g
s
.878 .717 .678 r
.06608 .40397 m .06181 .40089 L .06456 .39493 L p F P
0 g
s
.884 .711 .663 r
.06181 .40089 m .06608 .40397 L .06367 .40983 L p F P
0 g
s
.825 .762 .793 r
.09568 .31604 m .10128 .31006 L .09763 .30654 L p F P
0 g
s
.661 .534 .699 r
.45164 .396 m .46261 .39443 L p .46215 .40214 L F P
0 g
s
.663 .53 .692 r
.46261 .39443 m .46125 .3893 L .45164 .396 L closepath p F P
0 g
s
.661 .527 .69 r
.46071 .38716 m .46125 .3893 L .45164 .396 L p F P
0 g
s
.824 .583 .575 r
.28357 .29208 m .28522 .29269 L .28563 .29847 L p F P
0 g
s
.838 .594 .57 r
.2889 .29984 m .28563 .29847 L .28522 .29269 L p F P
0 g
s
.647 .695 .88 r
.57258 .50722 m .584 .504 L .58694 .50814 L p F P
0 g
s
.645 .671 .86 r
.58369 .50353 m .584 .504 L .57258 .50722 L p F P
0 g
s
.645 .671 .86 r
.57258 .50722 m .57256 .5072 L .58369 .50353 L p F P
0 g
s
.898 .655 .564 r
.06745 .43274 m .07198 .43568 L .07116 .44105 L p F P
0 g
s
.892 .671 .596 r
.07198 .43568 m .06745 .43274 L .06872 .42723 L p F P
0 g
s
.75 .612 .705 r
.33939 .40263 m .34891 .4039 L .34294 .41098 L p F P
0 g
s
.739 .596 .697 r
.34488 .39571 m .33939 .40263 L .34891 .4039 L p F P
0 g
s
.644 .67 .86 r
.58104 .49942 m .58369 .50353 L .57256 .5072 L p F P
0 g
s
.644 .67 .86 r
.57256 .5072 m .56961 .50261 L .58104 .49942 L p F P
0 g
s
.662 .569 .74 r
.46831 .45481 m .47909 .44934 L .46706 .45135 L closepath p F P
0 g
s
.662 .575 .747 r
.46831 .45481 m .47909 .44934 L p .48107 .45816 L F P
0 g
s
.64 .75 .929 r
.1797 .50965 m .19044 .50655 L .19396 .50974 L p F P
0 g
s
.654 .749 .92 r
.19044 .50655 m .1797 .50965 L .17614 .50675 L p F P
0 g
s
.654 .604 .787 r
.51742 .47809 m .51858 .48064 L .5066 .48334 L p F P
0 g
s
.654 .604 .787 r
.5066 .48334 m .50612 .48231 L .51742 .47809 L p F P
0 g
s
.649 .514 .685 r
.45895 .38004 m .47144 .37782 L p .46639 .38612 L F P
0 g
s
.649 .514 .685 r
.46639 .38612 m .46071 .38716 L .45895 .38004 L p F P
0 g
s
.652 .514 .682 r
.46978 .37081 m .47144 .37782 L .45895 .38004 L p F P
0 g
s
.652 .514 .682 r
.4668 .37133 m .46978 .37081 L p .45895 .38004 L F P
0 g
s
.573 .409 .621 r
.4972 .31877 m .49689 .31645 L .50799 .31256 L p F P
0 g
s
.566 .394 .607 r
.50733 .30671 m .50799 .31256 L .49689 .31645 L p F P
0 g
s
.343 0 0 r
.12998 .49695 m .12523 .49451 L .11911 .49126 L p F P
0 g
s
0 .272 .656 r
.11378 .48866 m .11911 .49126 L .12523 .49451 L p F P
0 g
s
.622 .056 0 r
.1129 .48802 m .11378 .48866 L .11911 .49126 L p F P
0 g
s
.781 .595 .649 r
.3124 .33229 m .30884 .33138 L p .31371 .3393 L F P
0 g
s
.781 .595 .649 r
.31371 .3393 m .31396 .33877 L .3124 .33229 L p F P
0 g
s
.415 .187 .457 r
.52754 .28132 m .52783 .27662 L .53785 .27135 L p F P
0 g
s
.381 .109 .371 r
.53866 .26727 m .53785 .27135 L .52783 .27662 L p F P
0 g
s
.449 .214 .465 r
.52238 .2837 m .52754 .28132 L .52783 .27662 L p F P
0 g
s
.725 .739 .863 r
.22266 .50759 m .2242 .50674 L .22061 .50537 L closepath p F P
0 g
s
.704 .733 .873 r
.22061 .50537 m .22266 .50759 L p .20829 .50898 L F P
0 g
s
.835 .569 .536 r
.28357 .29208 m .27738 .2896 L .27766 .28451 L p F P
0 g
s
.849 .582 .534 r
.27185 .28189 m .27766 .28451 L .27738 .2896 L p F P
0 g
s
.737 .614 .721 r
.34213 .43537 m .34454 .43291 L .34228 .42701 L p F P
0 g
s
.661 .535 .7 r
.45304 .40803 m .46215 .40214 L .45183 .4037 L closepath p F P
0 g
s
.635 .492 .671 r
.46947 .36948 m .46827 .36397 L .4804 .36132 L p F P
0 g
s
.636 .491 .668 r
.47901 .35462 m .4804 .36132 L .46827 .36397 L p F P
0 g
s
.648 .504 .674 r
.46827 .36397 m .46947 .36948 L .4668 .37133 L p F P
0 g
s
.599 .445 .644 r
.4883 .33849 m .48724 .33216 L .4987 .32871 L p F P
0 g
s
.597 .438 .637 r
.49772 .32249 m .4987 .32871 L .48724 .33216 L p F P
0 g
s
.662 .568 .739 r
.47909 .44934 m .46706 .45135 L .46525 .44635 L p F P
0 g
s
.754 .61 .699 r
.33566 .39434 m .34488 .39571 L .33939 .40263 L p F P
0 g
s
.743 .594 .691 r
.34068 .38757 m .33566 .39434 L .34488 .39571 L p F P
0 g
s
.558 .569 .821 r
.68608 .28818 m .67733 .28839 L .67467 .28271 L p F P
0 g
s
.651 .592 .775 r
.51742 .47809 m .50612 .48231 L .50307 .47536 L p F P
0 g
s
.877 .529 .389 r
.26052 .26974 m .26268 .26851 L p .26603 .27429 L F P
0 g
s
.846 .46 .316 r
.26052 .26974 m .25945 .26695 L .26268 .26851 L closepath p F P
0 g
s
.752 .68 .781 r
.28817 .48478 m .29038 .48297 L .28653 .48206 L closepath p F P
0 g
s
.65 .622 .809 r
.53515 .48799 m .53786 .49338 L p .5235 .49115 L F P
0 g
s
.65 .622 .809 r
.5235 .49115 m .52603 .4903 L .53515 .48799 L p F P
0 g
s
.647 .608 .796 r
.5235 .49115 m .52603 .4903 L .52342 .49098 L closepath p F P
0 g
s
.618 .469 .658 r
.4777 .34819 m .47862 .34772 L .47766 .34796 L closepath p F P
0 g
s
.747 .629 .729 r
.3328 .43406 m .34213 .43537 L .33473 .44292 L p F P
0 g
s
.737 .614 .721 r
.33969 .42668 m .3328 .43406 L .34213 .43537 L p F P
0 g
s
.737 .614 .721 r
.34228 .42701 m .33969 .42668 L p .34213 .43537 L F P
0 g
s
.741 .687 .799 r
.26255 .49619 m .2711 .49003 L .27555 .49099 L p F P
0 g
s
.741 .688 .801 r
.27555 .49099 m .2737 .48817 L .2711 .49003 L closepath p F P
0 g
s
.647 .607 .796 r
.52603 .4903 m .52342 .49098 L .52047 .48478 L p F P
0 g
s
.621 .476 .663 r
.47901 .35462 m .4777 .34819 L .47862 .34772 L p F P
0 g
s
.744 .642 .747 r
.32367 .45917 m .32192 .45544 L .3187 .4584 L closepath p F P
0 g
s
.776 .763 .841 r
.1481 .26822 m .14629 .26958 L .1427 .26602 L p F P
0 g
s
.746 .615 .713 r
.34144 .4248 m .34624 .4194 L .33905 .41839 L closepath p F P
0 g
s
.746 .613 .711 r
.33834 .41645 m .34294 .41098 L p .34624 .4194 L F P
0 g
s
.746 .613 .711 r
.34624 .4194 m .33905 .41839 L .33834 .41645 L p F P
0 g
s
.192 0 .109 r
.54666 .26043 m .54997 .25847 L p .53866 .26727 L F P
0 g
s
0 0 0 r
.54666 .26043 m .54997 .25847 L .55053 .25807 L closepath p F P
0 g
s
.752 .679 .78 r
.29848 .47402 m .29938 .47566 L .29038 .48297 L p F P
0 g
s
.752 .679 .78 r
.2925 .47286 m .29848 .47402 L p .29038 .48297 L F P
0 g
s
.752 .679 .78 r
.2849 .47935 m .2925 .47286 L p .29038 .48297 L F P
0 g
s
.752 .679 .78 r
.29038 .48297 m .28653 .48206 L .2849 .47935 L p F P
0 g
s
.822 .358 .116 r
.10489 .48202 m .09987 .47931 L .09717 .47501 L p F P
0 g
s
.818 .349 .097 r
.09232 .47237 m .09717 .47501 L .09987 .47931 L p F P
0 g
s
.828 .761 .79 r
.09568 .31604 m .0898 .32245 L .08613 .31894 L p F P
0 g
s
.828 .761 .79 r
.08613 .31894 m .09186 .31269 L .09568 .31604 L p F P
0 g
s
.825 .762 .793 r
.09763 .30654 m .09186 .31269 L .09568 .31604 L p F P
0 g
s
.758 .609 .693 r
.33177 .3861 m .34068 .38757 L .33566 .39434 L p F P
0 g
s
.747 .593 .685 r
.33636 .37947 m .33177 .3861 L .34068 .38757 L p F P
0 g
s
.748 .69 .796 r
.2711 .49003 m .26255 .49619 L .25922 .49149 L p F P
0 g
s
.68 .744 .899 r
.19396 .50974 m .20481 .50552 L .20829 .50898 L p F P
0 g
s
.69 .742 .891 r
.20481 .50552 m .19396 .50974 L .19044 .50655 L p F P
0 g
s
.665 .542 .705 r
.45398 .41124 m .45304 .40803 L .46215 .40214 L p F P
0 g
s
.704 .733 .873 r
.20829 .50898 m .21757 .50461 L .22061 .50537 L p F P
0 g
s
.713 .734 .867 r
.21757 .50461 m .20829 .50898 L .20481 .50552 L p F P
0 g
s
.727 .739 .861 r
.23025 .49751 m .23365 .50162 L .2242 .50674 L p F P
0 g
s
.727 .739 .861 r
.21922 .50385 m .23025 .49751 L p .2242 .50674 L F P
0 g
s
.727 .739 .861 r
.2242 .50674 m .22061 .50537 L .21922 .50385 L p F P
0 g
s
.862 .744 .731 r
.06674 .36044 m .07075 .36366 L .06663 .37006 L p F P
0 g
s
.857 .746 .74 r
.06998 .35566 m .06674 .36044 L .07075 .36366 L p F P
0 g
s
.869 .734 .71 r
.06689 .37955 m .06506 .38278 L .06141 .37879 L p F P
0 g
s
.869 .734 .71 r
.06141 .37879 m .06277 .37638 L .06689 .37955 L p F P
0 g
s
.864 .738 .722 r
.06689 .37955 m .06277 .37638 L .06663 .37006 L p F P
0 g
s
.502 .46 .743 r
.72751 .3562 m .72559 .3557 L .72696 .35453 L closepath p F P
0 g
s
.51 .474 .753 r
.72449 .34729 m .72319 .34701 L p .72559 .3557 L F P
0 g
s
.51 .474 .753 r
.72559 .3557 m .72696 .35453 L .72449 .34729 L p F P
0 g
s
.889 .687 .622 r
.06872 .42723 m .06428 .42424 L .06596 .41861 L p F P
0 g
s
.895 .675 .596 r
.06428 .42424 m .06872 .42723 L .06745 .43274 L p F P
0 g
s
.59 .622 .852 r
.64826 .25502 m .65116 .26036 L .63954 .26188 L p F P
0 g
s
.59 .622 .852 r
.64072 .25607 m .64826 .25502 L p .63954 .26188 L F P
0 g
s
.59 .622 .852 r
.63954 .26188 m .63791 .25892 L .64072 .25607 L p F P
0 g
s
.588 .616 .848 r
.63954 .26188 m .65116 .26036 L p .6535 .26582 L F P
0 g
s
.615 .462 .65 r
.4883 .33849 m .48897 .34218 L .47862 .34772 L p F P
0 g
s
.621 .476 .663 r
.47862 .34772 m .4895 .34496 L p .47901 .35462 L F P
0 g
s
.619 .468 .655 r
.4895 .34496 m .48897 .34218 L .47862 .34772 L closepath p F P
0 g
s
.824 .583 .575 r
.28563 .29847 m .28269 .29738 L .28357 .29208 L p F P
0 g
s
.834 .591 .572 r
.27738 .2896 m .28357 .29208 L .28269 .29738 L p F P
0 g
s
.662 .568 .739 r
.46525 .44635 m .47508 .44115 L p .47909 .44934 L F P
0 g
s
.662 .562 .732 r
.46525 .44635 m .47508 .44115 L .46408 .44295 L closepath p F P
0 g
s
.776 .763 .841 r
.1427 .26602 m .14431 .26481 L .1481 .26822 L p F P
0 g
s
.774 .763 .843 r
.15381 .25774 m .14431 .26481 L .1481 .26822 L p F P
0 g
s
.774 .763 .843 r
.1481 .26822 m .15739 .2613 L .15381 .25774 L p F P
0 g
s
0 .242 .678 r
.24348 .25531 m .24624 .25724 L .25106 .26025 L p F P
0 g
s
.776 .278 .018 r
.25945 .26695 m .25412 .26413 L .25106 .26025 L p F P
0 g
s
.794 .303 .024 r
.24624 .25724 m .25106 .26025 L .25412 .26413 L p F P
0 g
s
.763 .608 .687 r
.32776 .37789 m .33636 .37947 L .33177 .3861 L p F P
0 g
s
.751 .591 .679 r
.33194 .3714 m .32776 .37789 L .33636 .37947 L p F P
0 g
s
.662 .542 .707 r
.45608 .41838 m .45398 .41124 L .46672 .40931 L p F P
0 g
s
.665 .542 .705 r
.46458 .40178 m .46672 .40931 L .45398 .41124 L p F P
0 g
s
.665 .542 .705 r
.46215 .40214 m .46458 .40178 L p .45398 .41124 L F P
0 g
s
.671 .552 .711 r
.45398 .41124 m .45608 .41838 L .45512 .41903 L p F P
0 g
s
.372 .193 .504 r
.72599 .44224 m .72486 .443 L .72457 .44846 L p F P
0 g
s
.543 .537 .798 r
.69783 .30786 m .69739 .30784 L .6977 .30756 L closepath p F P
0 g
s
.549 .546 .804 r
.69491 .30116 m .6977 .30756 L .69739 .30784 L p F P
0 g
s
.658 .584 .761 r
.49696 .46033 m .49858 .46441 L .4863 .4668 L p F P
0 g
s
.658 .584 .761 r
.4863 .4668 m .48569 .46529 L .49696 .46033 L p F P
0 g
s
.661 .561 .731 r
.47508 .44115 m .46408 .44295 L .46219 .43747 L p F P
0 g
s
.767 .608 .68 r
.32366 .36971 m .33194 .3714 L .32776 .37789 L p F P
0 g
s
.768 .6 .671 r
.33194 .3714 m .32366 .36971 L .32745 .36335 L p F P
0 g
s
.828 .599 .592 r
.29398 .3077 m .28772 .30526 L .2889 .29984 L p F P
0 g
s
.835 .607 .593 r
.28563 .29847 m .2889 .29984 L .28772 .30526 L p F P
0 g
s
.746 .63 .73 r
.33322 .44445 m .33473 .44292 L .33242 .44256 L closepath p F P
0 g
s
.747 .629 .729 r
.33008 .43697 m .3328 .43406 L p .33473 .44292 L F P
0 g
s
.747 .629 .729 r
.33473 .44292 m .33242 .44256 L .33008 .43697 L p F P
0 g
s
.742 .615 .717 r
.34228 .42701 m .34144 .4248 L .33969 .42668 L closepath p F P
0 g
s
.574 .414 .626 r
.49772 .32249 m .4972 .31877 L .50849 .31628 L p F P
0 g
s
.573 .409 .621 r
.50799 .31256 m .50849 .31628 L .4972 .31877 L p F P
0 g
s
.672 .553 .711 r
.45624 .41889 m .45608 .41838 L .45512 .41903 L closepath p F P
0 g
s
.65 .507 .675 r
.46978 .37081 m .46947 .36948 L .4668 .37133 L closepath p F P
0 g
s
.773 .607 .674 r
.32023 .36174 m .32745 .36335 L .32366 .36971 L p F P
0 g
s
.773 .604 .669 r
.31994 .36071 m .32291 .35532 L p .32745 .36335 L F P
0 g
s
.773 .604 .669 r
.32745 .36335 m .32023 .36174 L .31994 .36071 L p F P
0 g
s
.75 .641 .74 r
.33242 .44256 m .33322 .44445 L .32687 .45061 L p F P
0 g
s
.826 .611 .611 r
.28772 .30526 m .29398 .3077 L .29239 .31325 L p F P
0 g
s
.815 .599 .61 r
.29898 .31557 m .29239 .31325 L .29398 .3077 L p F P
0 g
s
.78 .594 .648 r
.31411 .3394 m .31396 .33877 L .31371 .3393 L closepath p F P
0 g
s
0 .145 .585 r
.24624 .25724 m .24348 .25531 L .23996 .25281 L p F P
0 g
s
.649 .516 .688 r
.46125 .3893 m .46639 .38612 L .46071 .38716 L closepath p F P
0 g
s
.647 .721 .903 r
.58694 .50814 m .59839 .50492 L .6013 .50858 L p F P
0 g
s
.644 .698 .885 r
.59839 .50492 m .58694 .50814 L .584 .504 L p F P
0 g
s
.601 .741 .943 r
.21176 .24741 m .22248 .24501 L .22598 .24829 L p F P
0 g
s
.592 .736 .944 r
.22248 .24501 m .21176 .24741 L .20826 .24391 L p F P
0 g
s
.684 .752 .903 r
.19742 .24837 m .20826 .24391 L .21176 .24741 L p F P
0 g
s
.75 .613 .707 r
.33834 .41645 m .34294 .41098 L .33597 .40992 L closepath p F P
0 g
s
.75 .612 .705 r
.33524 .40786 m .33939 .40263 L p .34294 .41098 L F P
0 g
s
.75 .612 .705 r
.34294 .41098 m .33597 .40992 L .33524 .40786 L p F P
0 g
s
.607 .641 .859 r
.62218 .25379 m .63374 .25166 L .63664 .25668 L p F P
0 g
s
.61 .653 .868 r
.63084 .24674 m .63374 .25166 L .62218 .25379 L p F P
0 g
s
.61 .653 .868 r
.62034 .2488 m .63084 .24674 L p .62218 .25379 L F P
0 g
s
.61 .653 .868 r
.62218 .25379 m .61959 .24954 L .62034 .2488 L p F P
0 g
s
.778 .606 .666 r
.31994 .36071 m .32291 .35532 L .31806 .35416 L closepath p F P
0 g
s
.779 .603 .662 r
.31693 .35005 m .31834 .3473 L p .32291 .35532 L F P
0 g
s
.779 .603 .662 r
.32291 .35532 m .31806 .35416 L .31693 .35005 L p F P
0 g
s
.804 .599 .625 r
.30393 .32347 m .29701 .32127 L .29898 .31557 L p F P
0 g
s
.817 .61 .623 r
.29239 .31325 m .29898 .31557 L .29701 .32127 L p F P
0 g
s
.537 .532 .797 r
.69783 .30786 m .70969 .30863 L p .70441 .31509 L F P
0 g
s
.534 .532 .799 r
.70677 .30171 m .70969 .30863 L .69783 .30786 L p F P
0 g
s
.534 .532 .799 r
.70377 .30152 m .70677 .30171 L p .69783 .30786 L F P
0 g
s
.534 .532 .799 r
.69783 .30786 m .6977 .30756 L .70377 .30152 L p F P
0 g
s
.665 .549 .713 r
.45624 .41889 m .45608 .41838 L .46734 .41145 L p F P
0 g
s
.662 .542 .707 r
.46672 .40931 m .46734 .41145 L .45608 .41838 L p F P
0 g
s
.657 .576 .753 r
.49514 .45552 m .49696 .46033 L .48569 .46529 L p F P
0 g
s
.657 .576 .753 r
.48569 .46529 m .48281 .45788 L .49514 .45552 L p F P
0 g
s
.661 .561 .731 r
.46219 .43747 m .46949 .43344 L p .47508 .44115 L F P
0 g
s
.661 .555 .724 r
.46219 .43747 m .46949 .43344 L .4613 .43476 L closepath p F P
0 g
s
.661 .548 .716 r
.45624 .41889 m .469 .41698 L p .46269 .42611 L F P
0 g
s
.661 .548 .716 r
.46269 .42611 m .45869 .42674 L .45624 .41889 L p F P
0 g
s
.665 .549 .713 r
.46734 .41145 m .469 .41698 L .45624 .41889 L p F P
0 g
s
.785 .603 .654 r
.31834 .3473 m .31601 .3467 L .31411 .3394 L p F P
0 g
s
.779 .6 .656 r
.31371 .3393 m .31411 .3394 L .31601 .3467 L p F P
0 g
s
.753 .667 .767 r
.29938 .47566 m .30071 .4745 L .29848 .47402 L closepath p F P
0 g
s
.74 .612 .715 r
.33969 .42668 m .34144 .4248 L .33905 .41839 L p F P
0 g
s
.355 .711 .986 r
.14785 .5035 m .15394 .50344 L .15941 .50595 L p F P
0 g
s
.413 .728 .99 r
.15394 .50344 m .14785 .5035 L .14419 .50115 L p F P
0 g
s
.786 .594 .64 r
.30393 .32347 m .30159 .3293 L .30884 .33138 L p F P
0 g
s
.807 .609 .635 r
.29701 .32127 m .30393 .32347 L .30159 .3293 L p F P
0 g
s
.661 .555 .723 r
.46949 .43344 m .4613 .43476 L .45914 .42817 L p F P
0 g
s
.541 .543 .806 r
.6977 .30756 m .69491 .30116 L .70377 .30152 L closepath p F P
0 g
s
.575 .599 .839 r
.66863 .27039 m .65695 .27141 L .65405 .26576 L p F P
0 g
s
.753 .666 .765 r
.30162 .46476 m .31012 .46632 L .30071 .4745 L p F P
0 g
s
.753 .666 .765 r
.29615 .46977 m .30162 .46476 L p .30071 .4745 L F P
0 g
s
.753 .666 .765 r
.30071 .4745 m .29848 .47402 L .29615 .46977 L p F P
0 g
s
.784 .606 .66 r
.31693 .35005 m .31834 .3473 L .31601 .3467 L closepath p F P
0 g
s
.476 .272 .523 r
.51723 .29126 m .52255 .28874 L .52238 .2837 L p F P
0 g
s
.482 .276 .524 r
.52754 .28132 m .52238 .2837 L .52255 .28874 L p F P
0 g
s
.681 .751 .904 r
.20826 .24391 m .19742 .24837 L .1939 .2448 L p F P
0 g
s
.72 .755 .881 r
.18298 .25052 m .1939 .2448 L .19742 .24837 L p F P
0 g
s
.781 .595 .649 r
.30884 .33138 m .30612 .33735 L .31371 .3393 L p F P
0 g
s
.798 .608 .645 r
.30159 .3293 m .30884 .33138 L .30612 .33735 L p F P
0 g
s
.75 .642 .742 r
.32192 .45544 m .32687 .45061 L .31906 .44924 L closepath p F P
0 g
s
.75 .641 .74 r
.32558 .44155 m .33242 .44256 L p .32687 .45061 L F P
0 g
s
.75 .641 .74 r
.31875 .44857 m .32558 .44155 L p .32687 .45061 L F P
0 g
s
.75 .641 .74 r
.32687 .45061 m .31906 .44924 L .31875 .44857 L p F P
0 g
s
.85 .752 .755 r
.0722 .34398 m .07613 .34725 L .0712 .35392 L p F P
0 g
s
.847 .754 .76 r
.07613 .34725 m .0722 .34398 L .07737 .33723 L p F P
0 g
s
.779 .6 .656 r
.31601 .3467 m .31061 .3454 L .31371 .3393 L p F P
0 g
s
.789 .607 .653 r
.30612 .33735 m .31371 .3393 L .31061 .3454 L p F P
0 g
s
.661 .549 .717 r
.45914 .42817 m .46269 .42611 L .45869 .42674 L closepath p F P
0 g
s
.654 .882 .982 r
.64311 .50462 m .64427 .50526 L .65578 .50098 L p F P
0 g
s
.661 .555 .723 r
.45914 .42817 m .46269 .42611 L p .46949 .43344 L F P
0 g
s
.881 .721 .679 r
.06037 .3918 m .06456 .39493 L .06181 .40089 L p F P
0 g
s
.876 .726 .692 r
.06456 .39493 m .06037 .3918 L .06343 .38574 L p F P
0 g
s
.832 .761 .785 r
.08907 .32327 m .0898 .32245 L .08613 .31894 L p F P
0 g
s
.729 .954 .947 r
.55053 .25807 m .56187 .25142 L .56305 .25173 L p F P
0 g
s
0 0 0 r
.54997 .25847 m .55053 .25807 L .56187 .25142 L p F P
0 g
s
.744 .654 .76 r
.31093 .46646 m .31064 .46588 L .31012 .46632 L closepath p F P
0 g
s
.649 .619 .806 r
.53515 .48799 m .53483 .48736 L .52603 .4903 L closepath p F P
0 g
s
.647 .607 .796 r
.5318 .48094 m .53483 .48736 L .52603 .4903 L p F P
0 g
s
.647 .607 .796 r
.52047 .48478 m .5318 .48094 L p .52603 .4903 L F P
0 g
s
.433 .328 .636 r
.7409 .40547 m .73398 .4108 L .73786 .41497 L p F P
0 g
s
.45 .355 .656 r
.74019 .40207 m .7409 .40547 L .73398 .4108 L p F P
0 g
s
.45 .355 .656 r
.73791 .4002 m .74019 .40207 L p .73398 .4108 L F P
0 g
s
.435 .329 .635 r
.7331 .41857 m .73786 .41497 L .73398 .4108 L p F P
0 g
s
.653 .524 .694 r
.46261 .39443 m .46125 .3893 L .46639 .38612 L p F P
0 g
s
.751 .627 .723 r
.33048 .42532 m .33969 .42668 L .3328 .43406 L p F P
0 g
s
.74 .612 .715 r
.33689 .41809 m .33048 .42532 L .33969 .42668 L p F P
0 g
s
.74 .612 .715 r
.33905 .41839 m .33689 .41809 L p .33969 .42668 L F P
0 g
s
.745 .628 .729 r
.33242 .44256 m .33008 .43697 L .32558 .44155 L closepath p F P
0 g
s
.638 .499 .677 r
.46978 .37081 m .46947 .36948 L .48073 .36286 L p F P
0 g
s
.635 .492 .671 r
.4804 .36132 m .48073 .36286 L .46947 .36948 L p F P
0 g
s
.702 .949 .955 r
.56187 .25142 m .56727 .24851 L .56305 .25173 L closepath p F P
0 g
s
.672 .896 .977 r
.57324 .2456 m .56727 .24851 L .56305 .25173 L p F P
0 g
s
.672 .896 .977 r
.57616 .24782 m .57324 .2456 L p .56305 .25173 L F P
0 g
s
.832 .761 .785 r
.08613 .31894 m .08525 .31993 L .08907 .32327 L p F P
0 g
s
.837 .76 .778 r
.08525 .31993 m .08907 .32327 L .0831 .33029 L p F P
0 g
s
.743 .639 .745 r
.3187 .4584 m .32192 .45544 L .31906 .44924 L p F P
0 g
s
.751 .645 .744 r
.3187 .4584 m .31064 .46588 L .30744 .45949 L p F P
0 g
s
.751 .645 .744 r
.30744 .45949 m .31015 .45686 L .3187 .4584 L p F P
0 g
s
.743 .639 .745 r
.3182 .4491 m .31015 .45686 L .3187 .4584 L p F P
0 g
s
.743 .639 .745 r
.31906 .44924 m .3182 .4491 L p .3187 .4584 L F P
0 g
s
.442 .677 .964 r
.22598 .24829 m .23016 .24852 L .23466 .25165 L p F P
0 g
s
.742 .65 .758 r
.30744 .45949 m .30162 .46476 L .31012 .46632 L p F P
0 g
s
.742 .65 .758 r
.31012 .46632 m .31064 .46588 L .30744 .45949 L p F P
0 g
s
.892 .691 .623 r
.0616 .41558 m .06596 .41861 L .06428 .42424 L p F P
0 g
s
.887 .7 .644 r
.06596 .41861 m .0616 .41558 L .06367 .40983 L p F P
0 g
s
.283 .045 .366 r
.72278 .45437 m .71667 .45836 L .71622 .46281 L p F P
0 g
s
.338 .132 .447 r
.71667 .45836 m .72278 .45437 L .72457 .44846 L p F P
0 g
s
.417 .299 .611 r
.73786 .41497 m .7331 .41857 L .73402 .42458 L p F P
0 g
s
.431 .309 .613 r
.73177 .4262 m .73402 .42458 L .7331 .41857 L p F P
0 g
s
.508 .473 .754 r
.72449 .34729 m .72319 .34701 L .72412 .3462 L closepath p F P
0 g
s
.516 .485 .761 r
.7215 .33889 m .72412 .3462 L .72319 .34701 L p F P
0 g
s
.516 .485 .761 r
.71987 .3386 m .7215 .33889 L p .72319 .34701 L F P
0 g
s
.645 .655 .845 r
.55523 .50093 m .56663 .49764 L .56961 .50261 L p F P
0 g
s
.643 .64 .832 r
.56388 .49275 m .56663 .49764 L .55523 .50093 L p F P
0 g
s
.643 .64 .832 r
.55523 .50093 m .55261 .49628 L .56388 .49275 L p F P
0 g
s
.754 .61 .699 r
.33216 .39903 m .33566 .39434 L p .33939 .40263 L F P
0 g
s
.754 .61 .699 r
.33939 .40263 m .33304 .40158 L .33216 .39903 L p F P
0 g
s
.754 .612 .701 r
.33524 .40786 m .33939 .40263 L .33304 .40158 L closepath p F P
0 g
s
.639 .503 .681 r
.47144 .37782 m .46978 .37081 L .48195 .36821 L p F P
0 g
s
.638 .499 .677 r
.48073 .36286 m .48195 .36821 L .46978 .37081 L p F P
0 g
s
.479 .735 .983 r
.15941 .50595 m .16193 .50589 L .15832 .50317 L p F P
0 g
s
.479 .735 .983 r
.15832 .50317 m .15394 .50344 L .15941 .50595 L p F P
0 g
s
.498 .315 .563 r
.52255 .28874 m .51723 .29126 L .51755 .29668 L p F P
0 g
s
.748 .69 .796 r
.25922 .49149 m .2636 .48817 L .2711 .49003 L p F P
0 g
s
.739 .685 .799 r
.2704 .48306 m .2636 .48817 L .2711 .49003 L p F P
0 g
s
.739 .685 .799 r
.2711 .49003 m .2737 .48817 L .2704 .48306 L p F P
0 g
s
.532 .521 .789 r
.70441 .31509 m .71263 .31583 L p .71047 .32264 L F P
0 g
s
.53 .522 .791 r
.71263 .31583 m .70441 .31509 L .7101 .3096 L closepath p F P
0 g
s
.537 .532 .797 r
.70969 .30863 m .7101 .3096 L .70441 .31509 L p F P
0 g
s
.745 .676 .784 r
.28653 .48206 m .2849 .47935 L .2825 .48123 L closepath p F P
0 g
s
.71 .173 0 r
.09987 .47931 m .10489 .48202 L .10861 .48601 L p F P
0 g
s
.725 .195 0 r
.11063 .4871 m .10861 .48601 L .10489 .48202 L p F P
0 g
s
.872 .734 .706 r
.06343 .38574 m .06506 .38278 L .06141 .37879 L p F P
0 g
s
.664 .58 .75 r
.48281 .45788 m .48263 .45739 L .48107 .45816 L closepath p F P
0 g
s
.662 .575 .747 r
.47962 .44926 m .48263 .45739 L .48107 .45816 L p F P
0 g
s
.662 .575 .747 r
.47909 .44934 m .47962 .44926 L p .48107 .45816 L F P
0 g
s
.746 .613 .711 r
.33905 .41839 m .33834 .41645 L .33689 .41809 L closepath p F P
0 g
s
.356 .181 .501 r
.73493 .43598 m .72599 .44224 L .72617 .4474 L p F P
0 g
s
.389 .234 .547 r
.72599 .44224 m .73493 .43598 L .73391 .43091 L p F P
0 g
s
.372 .193 .504 r
.72457 .44846 m .72617 .4474 L .72599 .44224 L p F P
0 g
s
.651 .707 .888 r
.59049 .24684 m .60195 .24332 L .60486 .2474 L p F P
0 g
s
.664 .729 .898 r
.60195 .24332 m .59049 .24684 L .58757 .24344 L p F P
0 g
s
.681 .759 .91 r
.57616 .24782 m .58757 .24344 L .59049 .24684 L p F P
0 g
s
.746 .759 .864 r
.16844 .25375 m .17776 .24797 L .18159 .25138 L p F P
0 g
s
.745 .759 .865 r
.17944 .24694 m .17776 .24797 L .18159 .25138 L p F P
0 g
s
.745 .759 .865 r
.18159 .25138 m .18298 .25052 L .17944 .24694 L p F P
0 g
s
.747 .664 .768 r
.29848 .47402 m .29615 .46977 L .2925 .47286 L closepath p F P
0 g
s
.283 .017 .321 r
.54826 .26145 m .53866 .26727 L .53785 .27135 L p F P
0 g
s
.192 0 .109 r
.54997 .25847 m .54826 .26145 L .53866 .26727 L p F P
0 g
s
.469 .396 .692 r
.73685 .38783 m .73442 .38654 L .73617 .38513 L closepath p F P
0 g
s
.481 .415 .706 r
.73442 .38654 m .73617 .38513 L .73418 .37787 L p F P
0 g
s
.647 .757 .93 r
.6013 .50858 m .61277 .50529 L .61565 .5084 L p F P
0 g
s
.645 .728 .909 r
.61277 .50529 m .6013 .50858 L .59839 .50492 L p F P
0 g
s
.746 .715 .822 r
.2481 .49905 m .25025 .49758 L .24591 .4962 L closepath p F P
0 g
s
.734 .709 .828 r
.24591 .4962 m .2481 .49905 L p .23365 .50162 L F P
0 g
s
.762 .762 .853 r
.16111 .25874 m .15739 .2613 L .15381 .25774 L p F P
0 g
s
.704 .799 .924 r
.58757 .24344 m .57616 .24782 L .57324 .2456 L p F P
0 g
s
.651 .523 .695 r
.46429 .40073 m .46261 .39443 L .47505 .39215 L p F P
0 g
s
.653 .524 .694 r
.47318 .38492 m .47505 .39215 L .46261 .39443 L p F P
0 g
s
.653 .524 .694 r
.46639 .38612 m .47318 .38492 L p .46261 .39443 L F P
0 g
s
.661 .534 .699 r
.46261 .39443 m .46429 .40073 L .46215 .40214 L p F P
0 g
s
0 0 0 r
.66998 .49647 m .68146 .49074 L .68282 .48985 L p F P
0 g
s
0 0 0 r
.68146 .49074 m .69115 .48532 L .68282 .48985 L closepath p F P
0 g
s
0 0 0 r
.69294 .48423 m .69115 .48532 L .68282 .48985 L p F P
0 g
s
0 0 0 r
.69475 .48177 m .69294 .48423 L p .68282 .48985 L F P
0 g
s
.774 .601 .664 r
.31601 .3467 m .31061 .3454 L p .31505 .35348 L F P
0 g
s
.774 .601 .664 r
.31505 .35348 m .31693 .35005 L .31601 .3467 L p F P
0 g
s
.532 .918 .921 r
.66962 .49651 m .66708 .49778 L p .65578 .50098 L F P
0 g
s
.492 .904 .85 r
.66708 .49778 m .66962 .49651 L .66998 .49647 L closepath p F P
0 g
s
.744 .61 .71 r
.33689 .41809 m .33834 .41645 L .33597 .40992 L p F P
0 g
s
.411 .275 .584 r
.73402 .42458 m .73177 .4262 L .73391 .43091 L p F P
0 g
s
.487 .441 .732 r
.72958 .36257 m .73447 .35822 L p .73538 .36739 L F P
0 g
s
.487 .441 .732 r
.73538 .36739 m .73057 .36575 L .72958 .36257 L p F P
0 g
s
.494 .455 .743 r
.72958 .36257 m .72751 .3562 L .73447 .35822 L closepath p F P
0 g
s
.621 .476 .663 r
.4895 .34496 m .49082 .35159 L .47901 .35462 L p F P
0 g
s
.62 .477 .666 r
.47901 .35462 m .49082 .35159 L p .48802 .35936 L F P
0 g
s
.62 .477 .666 r
.48802 .35936 m .4804 .36132 L .47901 .35462 L p F P
0 g
s
.651 .592 .775 r
.50307 .47536 m .51438 .47105 L .51742 .47809 L p F P
0 g
s
.649 .584 .769 r
.51431 .47088 m .51438 .47105 L .50307 .47536 L p F P
0 g
s
.649 .584 .769 r
.50307 .47536 m .50235 .47364 L .51431 .47088 L p F P
0 g
s
.758 .611 .695 r
.33216 .39903 m .33566 .39434 L .33024 .39337 L closepath p F P
0 g
s
.758 .609 .693 r
.32908 .38992 m .33177 .3861 L p .33566 .39434 L F P
0 g
s
.758 .609 .693 r
.33566 .39434 m .33024 .39337 L .32908 .38992 L p F P
0 g
s
.752 .678 .779 r
.2825 .48123 m .2737 .48817 L .2704 .48306 L p F P
0 g
s
.493 .455 .743 r
.73447 .35822 m .72751 .3562 L .72696 .35453 L p F P
0 g
s
.487 .441 .731 r
.73198 .37034 m .73057 .36575 L .73538 .36739 L closepath p F P
0 g
s
.75 .628 .725 r
.33008 .43697 m .3328 .43406 L .3286 .43338 L closepath p F P
0 g
s
.751 .627 .723 r
.32695 .42931 m .33048 .42532 L p .3328 .43406 L F P
0 g
s
.751 .627 .723 r
.3328 .43406 m .3286 .43338 L .32695 .42931 L p F P
0 g
s
.663 .551 .717 r
.4714 .42479 m .47039 .42158 L .46269 .42611 L closepath p F P
0 g
s
.661 .548 .716 r
.469 .41698 m .47039 .42158 L .46269 .42611 L p F P
0 g
s
.661 .555 .723 r
.46269 .42611 m .4714 .42479 L p .46949 .43344 L F P
0 g
s
0 0 0 r
.69294 .48423 m .69475 .48177 L .70446 .47615 L p F P
0 g
s
.041 0 0 r
.70582 .47269 m .70446 .47615 L .69475 .48177 L p F P
0 g
s
.493 .455 .743 r
.72696 .35453 m .73269 .34931 L p .73447 .35822 L F P
0 g
s
.5 .468 .753 r
.72696 .35453 m .72449 .34729 L .73269 .34931 L closepath p F P
0 g
s
.514 .486 .764 r
.7215 .33889 m .71987 .3386 L .72102 .33757 L closepath p F P
0 g
s
.521 .498 .771 r
.71853 .3309 m .72102 .33757 L .71987 .3386 L p F P
0 g
s
.521 .498 .771 r
.71563 .33047 m .71853 .3309 L p .71987 .3386 L F P
0 g
s
.645 .82 .968 r
.64149 .50362 m .62998 .50739 L .62715 .50493 L p F P
0 g
s
.645 .805 .96 r
.61565 .5084 m .62715 .50493 L .62998 .50739 L p F P
0 g
s
.635 .862 .985 r
.62998 .50739 m .64149 .50362 L .64311 .50462 L p F P
0 g
s
.719 .756 .882 r
.1939 .2448 m .18298 .25052 L .17944 .24694 L p F P
0 g
s
.658 .576 .752 r
.4939 .45225 m .49514 .45552 L .48281 .45788 L p F P
0 g
s
.658 .576 .752 r
.48281 .45788 m .48263 .45739 L .4939 .45225 L p F P
0 g
s
.754 .626 .717 r
.32785 .41668 m .33689 .41809 L .33048 .42532 L p F P
0 g
s
.744 .61 .71 r
.3338 .40959 m .32785 .41668 L .33689 .41809 L p F P
0 g
s
.744 .61 .71 r
.33597 .40992 m .3338 .40959 L p .33689 .41809 L F P
0 g
s
.532 .521 .789 r
.71263 .31583 m .71403 .31929 L .71047 .32264 L p F P
0 g
s
.527 .51 .78 r
.71047 .32264 m .71557 .32323 L p .71563 .33047 L F P
0 g
s
.525 .511 .783 r
.71557 .32323 m .71047 .32264 L .71403 .31929 L closepath p F P
0 g
s
.656 .568 .744 r
.49198 .44692 m .4939 .45225 L .48263 .45739 L p F P
0 g
s
.656 .568 .744 r
.48263 .45739 m .47962 .44926 L .49198 .44692 L p F P
0 g
s
.48 .426 .72 r
.73198 .37034 m .73538 .36739 L p .73543 .37681 L F P
0 g
s
.48 .426 .72 r
.73543 .37681 m .73367 .3761 L .73198 .37034 L p F P
0 g
s
.859 .48 .328 r
.25945 .26695 m .26052 .26974 L .25936 .27051 L p F P
0 g
s
.859 .48 .328 r
.25412 .26413 m .25945 .26695 L p .25936 .27051 L F P
0 g
s
.774 .601 .664 r
.31806 .35416 m .31693 .35005 L .31505 .35348 L closepath p F P
0 g
s
.546 .38 .607 r
.50799 .31256 m .50733 .30671 L .51807 .30236 L p F P
0 g
s
.537 .36 .589 r
.51755 .29668 m .51807 .30236 L .50733 .30671 L p F P
0 g
s
.748 .714 .82 r
.25589 .48672 m .25922 .49149 L .25025 .49758 L p F P
0 g
s
.748 .714 .82 r
.24473 .49466 m .25589 .48672 L p .25025 .49758 L F P
0 g
s
.748 .714 .82 r
.25025 .49758 m .24591 .4962 L .24473 .49466 L p F P
0 g
s
.663 .536 .699 r
.46458 .40178 m .46429 .40073 L .46215 .40214 L closepath p F P
0 g
s
.414 .663 .963 r
.23016 .24852 m .22598 .24829 L .22248 .24501 L p F P
0 g
s
.601 .452 .651 r
.48897 .34218 m .4883 .33849 L .49977 .33504 L p F P
0 g
s
.599 .445 .644 r
.4987 .32871 m .49977 .33504 L .4883 .33849 L p F P
0 g
s
.646 .768 .937 r
.62715 .50493 m .61565 .5084 L .61277 .50529 L p F P
0 g
s
.595 .63 .856 r
.63791 .25892 m .63664 .25668 L .64072 .25607 L closepath p F P
0 g
s
.651 .585 .768 r
.51132 .4636 m .51431 .47088 L .50235 .47364 L p F P
0 g
s
.651 .585 .768 r
.50235 .47364 m .50002 .46803 L .51132 .4636 L p F P
0 g
s
.645 .627 .817 r
.53786 .49338 m .54922 .48988 L .55223 .49561 L p F P
0 g
s
.644 .617 .808 r
.54665 .48473 m .54922 .48988 L .53786 .49338 L p F P
0 g
s
.644 .617 .808 r
.53786 .49338 m .53515 .48799 L .54665 .48473 L p F P
0 g
s
.519 .499 .773 r
.71853 .3309 m .71563 .33047 L .71767 .32861 L closepath p F P
0 g
s
.527 .51 .78 r
.71557 .32323 m .71767 .32861 L .71563 .33047 L p F P
0 g
s
.744 .625 .728 r
.32558 .44155 m .33008 .43697 L .3286 .43338 L p F P
0 g
s
.651 .518 .688 r
.47318 .38492 m .47251 .38224 L .46639 .38612 L closepath p F P
0 g
s
.649 .514 .685 r
.47144 .37782 m .47251 .38224 L .46639 .38612 L p F P
0 g
s
.579 .425 .637 r
.4987 .32871 m .49772 .32249 L .50882 .3186 L p F P
0 g
s
.574 .414 .626 r
.50849 .31628 m .50882 .3186 L .49772 .32249 L p F P
0 g
s
.558 .569 .821 r
.67467 .28271 m .67518 .28218 L p .68608 .28818 L F P
0 g
s
.562 .578 .827 r
.67467 .28271 m .67443 .28221 L .67518 .28218 L closepath p F P
0 g
s
.762 .61 .69 r
.32908 .38992 m .33177 .3861 L .32756 .38529 L closepath p F P
0 g
s
.763 .608 .687 r
.32602 .38053 m .32776 .37789 L p .33177 .3861 L F P
0 g
s
.763 .608 .687 r
.33177 .3861 m .32756 .38529 L .32602 .38053 L p F P
0 g
s
.646 .598 .787 r
.53031 .47764 m .5318 .48094 L .52047 .48478 L p F P
0 g
s
.646 .598 .787 r
.52047 .48478 m .51858 .48064 L .53031 .47764 L p F P
0 g
s
.703 .733 .875 r
.22061 .50537 m .21922 .50385 L .21757 .50461 L closepath p F P
0 g
s
.749 .611 .705 r
.33597 .40992 m .33524 .40786 L .3338 .40959 L closepath p F P
0 g
s
.566 0 0 r
.11378 .48866 m .11063 .4871 L .1129 .48802 L closepath p F P
0 g
s
.5 .469 .754 r
.73269 .34931 m .72449 .34729 L .72412 .3462 L p F P
0 g
s
.762 .762 .853 r
.15381 .25774 m .15734 .25532 L .16111 .25874 L p F P
0 g
s
.761 .762 .854 r
.16487 .25019 m .15734 .25532 L .16111 .25874 L p F P
0 g
s
.761 .762 .854 r
.16111 .25874 m .16844 .25375 L .16487 .25019 L p F P
0 g
s
.866 .741 .723 r
.06261 .36685 m .06663 .37006 L .06277 .37638 L p F P
0 g
s
.862 .744 .731 r
.06663 .37006 m .06261 .36685 L .06674 .36044 L p F P
0 g
s
.769 .601 .67 r
.31806 .35416 m .31505 .35348 L p .31943 .36157 L F P
0 g
s
.769 .601 .67 r
.31943 .36157 m .31994 .36071 L .31806 .35416 L p F P
0 g
s
.5 .469 .754 r
.72412 .3462 m .73006 .34067 L p .73269 .34931 L F P
0 g
s
.506 .481 .764 r
.72412 .3462 m .7215 .33889 L .73006 .34067 L closepath p F P
0 g
s
.84 .759 .774 r
.0831 .33029 m .07816 .33624 L .07447 .33273 L p F P
0 g
s
.84 .759 .774 r
.07447 .33273 m .07926 .32696 L .0831 .33029 L p F P
0 g
s
.837 .76 .778 r
.0831 .33029 m .07926 .32696 L .08525 .31993 L p F P
0 g
s
.89 .704 .645 r
.05939 .40675 m .06367 .40983 L .0616 .41558 L p F P
0 g
s
.884 .711 .663 r
.06367 .40983 m .05939 .40675 L .06181 .40089 L p F P
0 g
s
.822 .597 .598 r
.28269 .29738 m .28563 .29847 L .28654 .30477 L p F P
0 g
s
.835 .607 .593 r
.28772 .30526 m .28654 .30477 L .28563 .29847 L p F P
0 g
s
.748 .609 .704 r
.3338 .40959 m .33524 .40786 L .33304 .40158 L p F P
0 g
s
.562 .581 .83 r
.67518 .28218 m .67443 .28221 L .67153 .27629 L p F P
0 g
s
.654 .531 .701 r
.46458 .40178 m .46429 .40073 L .47555 .39407 L p F P
0 g
s
.651 .523 .695 r
.47505 .39215 m .47555 .39407 L .46429 .40073 L p F P
0 g
s
.48 .426 .72 r
.73418 .37787 m .73367 .3761 L .73543 .37681 L closepath p F P
0 g
s
.754 .634 .728 r
.32558 .44155 m .31875 .44857 L .31558 .44152 L p F P
0 g
s
.754 .634 .728 r
.31558 .44152 m .31698 .44001 L .32558 .44155 L p F P
0 g
s
.744 .625 .728 r
.32386 .43263 m .31698 .44001 L .32558 .44155 L p F P
0 g
s
.744 .625 .728 r
.3286 .43338 m .32386 .43263 L p .32558 .44155 L F P
0 g
s
.651 .53 .704 r
.46458 .40178 m .47705 .39953 L p .47348 .40804 L F P
0 g
s
.651 .53 .704 r
.47348 .40804 m .46672 .40931 L .46458 .40178 L p F P
0 g
s
.654 .531 .701 r
.47555 .39407 m .47705 .39953 L .46458 .40178 L p F P
0 g
s
.014 .519 .867 r
.1304 .49714 m .12998 .49695 L .13026 .49711 L closepath p F P
0 g
s
.767 .61 .684 r
.32602 .38053 m .32776 .37789 L .32499 .37732 L closepath p F P
0 g
s
.767 .608 .68 r
.32297 .37082 m .32366 .36971 L p .32776 .37789 L F P
0 g
s
.767 .608 .68 r
.32776 .37789 m .32499 .37732 L .32297 .37082 L p F P
0 g
s
.63 .676 .875 r
.60486 .2474 m .61637 .24451 L .61927 .24901 L p F P
0 g
s
.638 .689 .881 r
.61637 .24451 m .60486 .2474 L .60195 .24332 L p F P
0 g
s
.469 .408 .706 r
.73543 .37681 m .73418 .37787 L .73617 .38513 L p F P
0 g
s
.537 .925 .858 r
.66962 .49651 m .66998 .49647 L .68146 .49074 L p F P
0 g
s
.304 .661 .972 r
.1304 .49714 m .14052 .49868 L .13724 .49636 L p F P
0 g
s
.304 .661 .972 r
.12998 .49695 m .1304 .49714 L p .13724 .49636 L F P
0 g
s
.752 .678 .779 r
.2704 .48306 m .27479 .47943 L .2825 .48123 L p F P
0 g
s
.744 .673 .782 r
.28164 .47381 m .27479 .47943 L .2825 .48123 L p F P
0 g
s
.744 .673 .782 r
.2825 .48123 m .2849 .47935 L .28164 .47381 L p F P
0 g
s
.637 .503 .683 r
.47251 .38224 m .47144 .37782 L .48356 .37516 L p F P
0 g
s
.639 .503 .681 r
.48195 .36821 m .48356 .37516 L .47144 .37782 L p F P
0 g
s
0 0 0 r
.56187 .25142 m .55919 .25212 L .54997 .25847 L p F P
0 g
s
0 0 0 r
.55919 .25212 m .54997 .25847 L .54826 .26145 L p F P
0 g
s
.856 .75 .746 r
.0712 .35392 m .06998 .35566 L .06629 .35202 L p F P
0 g
s
.856 .75 .746 r
.06629 .35202 m .06725 .35066 L .0712 .35392 L p F P
0 g
s
.85 .752 .755 r
.0712 .35392 m .06725 .35066 L .0722 .34398 L p F P
0 g
s
.878 .729 .693 r
.05933 .38257 m .06343 .38574 L .06037 .3918 L p F P
0 g
s
.872 .734 .706 r
.06141 .37879 m .05933 .38257 L .06343 .38574 L p F P
0 g
s
.759 .625 .711 r
.32495 .40811 m .3338 .40959 L .32785 .41668 L p F P
0 g
s
.748 .609 .704 r
.33047 .40117 m .32495 .40811 L .3338 .40959 L p F P
0 g
s
.748 .609 .704 r
.33304 .40158 m .33047 .40117 L p .3338 .40959 L F P
0 g
s
.661 .561 .731 r
.46949 .43344 m .47395 .43275 L p .47508 .44115 L F P
0 g
s
.663 .558 .725 r
.47395 .43275 m .47345 .43122 L .46949 .43344 L closepath p F P
0 g
s
.661 .555 .723 r
.4714 .42479 m .47345 .43122 L .46949 .43344 L p F P
0 g
s
.662 .568 .739 r
.47668 .4409 m .47956 .4491 L .47909 .44934 L p F P
0 g
s
.662 .568 .739 r
.47508 .44115 m .47668 .4409 L p .47909 .44934 L F P
0 g
s
.664 .572 .742 r
.47962 .44926 m .47956 .4491 L .47909 .44934 L closepath p F P
0 g
s
.753 .61 .699 r
.33304 .40158 m .33216 .39903 L .33047 .40117 L closepath p F P
0 g
s
.865 .563 .476 r
.27185 .28189 m .26637 .27915 L .26603 .27429 L p F P
0 g
s
.877 .576 .475 r
.26088 .27142 m .26603 .27429 L .26637 .27915 L p F P
0 g
s
.877 .529 .389 r
.26603 .27429 m .26088 .27142 L .26052 .26974 L p F P
0 g
s
.77 .602 .671 r
.32023 .36174 m .31994 .36071 L .31943 .36157 L closepath p F P
0 g
s
.749 .626 .724 r
.3286 .43338 m .32695 .42931 L .32386 .43263 L closepath p F P
0 g
s
.772 .609 .678 r
.32297 .37082 m .32366 .36971 L .32255 .36946 L closepath p F P
0 g
s
.773 .607 .674 r
.32366 .36971 m .32255 .36946 L .32023 .36174 L p F P
0 g
s
.657 .568 .743 r
.49084 .44376 m .49198 .44692 L .47962 .44926 L p F P
0 g
s
.657 .568 .743 r
.47962 .44926 m .47956 .4491 L .49084 .44376 L p F P
0 g
s
.655 .561 .736 r
.48906 .43857 m .49084 .44376 L .47956 .4491 L p F P
0 g
s
.655 .561 .736 r
.47956 .4491 m .47668 .4409 L .48906 .43857 L p F P
0 g
s
.769 .605 .675 r
.31943 .36157 m .32023 .36174 L .32255 .36946 L p F P
0 g
s
.558 .569 .821 r
.67518 .28218 m .68619 .28193 L p .68608 .28818 L F P
0 g
s
.557 .573 .825 r
.67518 .28218 m .68619 .28193 L .68329 .27579 L p F P
0 g
s
.557 .573 .825 r
.68329 .27579 m .68129 .27585 L .67518 .28218 L p F P
0 g
s
.562 .581 .83 r
.67153 .27629 m .68129 .27585 L .67518 .28218 L p F P
0 g
s
.747 .64 .741 r
.31906 .44924 m .31875 .44857 L .3182 .4491 L closepath p F P
0 g
s
.741 .71 .822 r
.24332 .49554 m .23365 .50162 L .23025 .49751 L p F P
0 g
s
.734 .709 .828 r
.23365 .50162 m .24332 .49554 L .24591 .4962 L p F P
0 g
s
.755 .668 .765 r
.2925 .47286 m .2849 .47935 L .28164 .47381 L p F P
0 g
s
.541 .544 .807 r
.70377 .30152 m .69491 .30116 L .69314 .2971 L p F P
0 g
s
.751 .608 .698 r
.33047 .40117 m .33216 .39903 L .33024 .39337 L p F P
0 g
s
.304 .661 .972 r
.12654 .49499 m .12998 .49695 L p .13724 .49636 L F P
0 g
s
0 .424 .801 r
.12654 .49499 m .12523 .49451 L .12998 .49695 L closepath p F P
0 g
s
.754 .626 .717 r
.32382 .42148 m .32785 .41668 L p .33048 .42532 L F P
0 g
s
.754 .626 .717 r
.33048 .42532 m .32496 .42435 L .32382 .42148 L p F P
0 g
s
.754 .627 .719 r
.32695 .42931 m .33048 .42532 L .32496 .42435 L closepath p F P
0 g
s
.899 .631 .523 r
.07544 .44917 m .07083 .44627 L .07116 .44105 L p F P
0 g
s
.899 .6 .47 r
.08034 .45709 m .07567 .45422 L .07544 .44917 L p F P
0 g
s
.903 .603 .468 r
.07083 .44627 m .07544 .44917 L .07567 .45422 L p F P
0 g
s
.641 .655 .848 r
.58104 .49942 m .56961 .50261 L .56663 .49764 L p F P
0 g
s
.895 .558 .401 r
.0859 .4648 m .08117 .46196 L .08034 .45709 L p F P
0 g
s
.898 .559 .396 r
.07567 .45422 m .08034 .45709 L .08117 .46196 L p F P
0 g
s
.746 .637 .739 r
.3182 .4491 m .31875 .44857 L .31558 .44152 L p F P
0 g
s
.664 .565 .733 r
.47668 .4409 m .4765 .44038 L .47508 .44115 L closepath p F P
0 g
s
.661 .561 .731 r
.47395 .43275 m .4765 .44038 L .47508 .44115 L p F P
0 g
s
.756 .652 .747 r
.30958 .44757 m .3182 .4491 L .31015 .45686 L p F P
0 g
s
.746 .637 .739 r
.31558 .44152 m .30958 .44757 L .3182 .4491 L p F P
0 g
s
.611 .75 .944 r
.17257 .50375 m .16193 .50589 L .15832 .50317 L p F P
0 g
s
.592 .749 .952 r
.16193 .50589 m .17257 .50375 L .17614 .50675 L p F P
0 g
s
.651 .532 .705 r
.46734 .41145 m .47348 .40804 L .46672 .40931 L closepath p F P
0 g
s
.78 .613 .673 r
.31148 .35975 m .31943 .36157 L .31549 .36797 L p F P
0 g
s
.769 .601 .67 r
.31505 .35348 m .31148 .35975 L .31943 .36157 L p F P
0 g
s
.769 .605 .675 r
.32255 .36946 m .31549 .36797 L .31943 .36157 L p F P
0 g
s
.799 .767 .823 r
.12352 .28193 m .12031 .28475 L .11667 .28126 L p F P
0 g
s
.806 .767 .817 r
.11463 .28996 m .12031 .28475 L .11667 .28126 L p F P
0 g
s
.809 .766 .814 r
.11463 .28996 m .10901 .29521 L .10535 .29174 L p F P
0 g
s
.809 .766 .814 r
.10535 .29174 m .11092 .28653 L .11463 .28996 L p F P
0 g
s
.806 .767 .817 r
.11667 .28126 m .11092 .28653 L .11463 .28996 L p F P
0 g
s
.751 .608 .698 r
.33024 .39337 m .32694 .39281 L p .33047 .40117 L F P
0 g
s
.757 .608 .694 r
.33024 .39337 m .32908 .38992 L .32694 .39281 L closepath p F P
0 g
s
.506 .482 .764 r
.73006 .34067 m .7215 .33889 L .72102 .33757 L p F P
0 g
s
.859 .75 .741 r
.06674 .36044 m .06998 .35566 L .06629 .35202 L p F P
0 g
s
.764 .605 .681 r
.32255 .36946 m .31549 .36797 L p .31942 .37621 L F P
0 g
s
.764 .605 .681 r
.31942 .37621 m .32297 .37082 L .32255 .36946 L p F P
0 g
s
.814 .766 .808 r
.10639 .29776 m .10901 .29521 L .10535 .29174 L p F P
0 g
s
.799 .767 .823 r
.11667 .28126 m .11983 .27849 L .12352 .28193 L p F P
0 g
s
.797 .767 .825 r
.12791 .27152 m .11983 .27849 L .12352 .28193 L p F P
0 g
s
.797 .767 .825 r
.12352 .28193 m .13154 .27502 L .12791 .27152 L p F P
0 g
s
.903 .635 .522 r
.06662 .43811 m .07116 .44105 L .07083 .44627 L p F P
0 g
s
.898 .655 .564 r
.07116 .44105 m .06662 .43811 L .06745 .43274 L p F P
0 g
s
.601 .452 .651 r
.49977 .33504 m .50026 .33774 L .48897 .34218 L p F P
0 g
s
.603 .458 .657 r
.4895 .34496 m .48897 .34218 L .50026 .33774 L p F P
0 g
s
.755 .607 .693 r
.32694 .39281 m .32908 .38992 L .32756 .38529 L p F P
0 g
s
.765 .606 .682 r
.32499 .37732 m .32297 .37082 L .31942 .37621 L closepath p F P
0 g
s
.755 .668 .765 r
.28164 .47381 m .28468 .47109 L .2925 .47286 L p F P
0 g
s
.746 .662 .767 r
.29292 .46379 m .28468 .47109 L .2925 .47286 L p F P
0 g
s
.746 .662 .767 r
.2925 .47286 m .29615 .46977 L .29292 .46379 L p F P
0 g
s
.654 .539 .711 r
.469 .41698 m .46734 .41145 L .47348 .40804 L p F P
0 g
s
.849 .582 .534 r
.27738 .2896 m .27156 .28698 L .27185 .28189 L p F P
0 g
s
.862 .594 .532 r
.26637 .27915 m .27185 .28189 L .27156 .28698 L p F P
0 g
s
.506 .482 .764 r
.72102 .33757 m .72656 .33228 L p .73006 .34067 L F P
0 g
s
.512 .494 .773 r
.72102 .33757 m .71853 .3309 L .72656 .33228 L closepath p F P
0 g
s
.786 .614 .667 r
.30739 .35155 m .31505 .35348 L .31148 .35975 L p F P
0 g
s
.774 .601 .664 r
.31061 .3454 m .30739 .35155 L .31505 .35348 L p F P
0 g
s
.755 .607 .693 r
.32756 .38529 m .32325 .38449 L p .32694 .39281 L F P
0 g
s
.761 .607 .688 r
.32756 .38529 m .32602 .38053 L .32325 .38449 L closepath p F P
0 g
s
.649 .576 .76 r
.51057 .46168 m .51132 .4636 L .50002 .46803 L p F P
0 g
s
.649 .576 .76 r
.50002 .46803 m .49858 .46441 L .51057 .46168 L p F P
0 g
s
.817 .766 .805 r
.10268 .29434 m .10639 .29776 L .09879 .30534 L p F P
0 g
s
.814 .766 .808 r
.10535 .29174 m .10268 .29434 L .10639 .29776 L p F P
0 g
s
.646 .865 .982 r
.64149 .50362 m .64311 .50462 L .65343 .49989 L p F P
0 g
s
.654 .882 .982 r
.65578 .50098 m .65343 .49989 L .64311 .50462 L p F P
0 g
s
.76 .606 .687 r
.32499 .37732 m .31942 .37621 L p .32325 .38449 L F P
0 g
s
.76 .606 .687 r
.32325 .38449 m .32602 .38053 L .32499 .37732 L p F P
0 g
s
.713 .734 .867 r
.20481 .50552 m .21067 .50256 L .21757 .50461 L p F P
0 g
s
.702 .729 .871 r
.21578 .50001 m .21067 .50256 L .21757 .50461 L p F P
0 g
s
.702 .729 .871 r
.21757 .50461 m .21922 .50385 L .21578 .50001 L p F P
0 g
s
.751 .608 .698 r
.32694 .39281 m .32183 .39961 L .33047 .40117 L p F P
0 g
s
.763 .624 .706 r
.32183 .39961 m .33047 .40117 L .32495 .40811 L p F P
0 g
s
.756 .654 .749 r
.30744 .45949 m .31015 .45686 L .30567 .45592 L closepath p F P
0 g
s
.756 .652 .747 r
.30424 .453 m .30958 .44757 L p .31015 .45686 L F P
0 g
s
.756 .652 .747 r
.31015 .45686 m .30567 .45592 L .30424 .453 L p F P
0 g
s
.883 .5 .309 r
.09216 .47229 m .08739 .46947 L .0859 .4648 L p F P
0 g
s
.884 .499 .3 r
.08117 .46196 m .0859 .4648 L .08739 .46947 L p F P
0 g
s
0 .272 .656 r
.12523 .49451 m .12013 .49184 L .11378 .48866 L p F P
0 g
s
0 .319 .706 r
.11063 .4871 m .11378 .48866 L .12013 .49184 L p F P
0 g
s
.64 .511 .689 r
.47318 .38492 m .47251 .38224 L .48378 .37607 L p F P
0 g
s
.637 .503 .683 r
.48356 .37516 m .48378 .37607 L .47251 .38224 L p F P
0 g
s
.758 .66 .754 r
.30162 .46476 m .29615 .46977 L .29292 .46379 L p F P
0 g
s
.656 .561 .735 r
.48778 .43484 m .48906 .43857 L .47668 .4409 L p F P
0 g
s
.656 .561 .735 r
.47668 .4409 m .4765 .44038 L .48778 .43484 L p F P
0 g
s
.758 .66 .754 r
.29292 .46379 m .29374 .46301 L .30162 .46476 L p F P
0 g
s
.747 .65 .753 r
.30191 .45521 m .29374 .46301 L .30162 .46476 L p F P
0 g
s
.747 .65 .753 r
.30567 .45592 m .30191 .45521 L p .30162 .46476 L F P
0 g
s
.747 .65 .753 r
.30162 .46476 m .30744 .45949 L .30567 .45592 L p F P
0 g
s
.621 .482 .671 r
.48073 .36286 m .48802 .35936 L .4804 .36132 L closepath p F P
0 g
s
.794 .615 .659 r
.30325 .34337 m .31061 .3454 L .30739 .35155 L p F P
0 g
s
.789 .607 .653 r
.31061 .3454 m .30325 .34337 L .30612 .33735 L p F P
0 g
s
.654 .553 .728 r
.48633 .43042 m .48778 .43484 L .4765 .44038 L p F P
0 g
s
.654 .553 .728 r
.4765 .44038 m .47395 .43275 L .48633 .43042 L p F P
0 g
s
.584 .607 .842 r
.65405 .26576 m .6535 .26582 L .65389 .26545 L closepath p F P
0 g
s
.588 .616 .848 r
.65116 .26036 m .65389 .26545 L .6535 .26582 L p F P
0 g
s
.1 0 .067 r
.71367 .46787 m .70582 .47269 L .70446 .47615 L p F P
0 g
s
.182 0 .227 r
.71566 .4656 m .71367 .46787 L .70582 .47269 L p F P
0 g
s
.182 0 .227 r
.71622 .46281 m .71566 .4656 L p .70582 .47269 L F P
0 g
s
.647 .598 .786 r
.52876 .47418 m .53031 .47764 L .51858 .48064 L p F P
0 g
s
.647 .598 .786 r
.51858 .48064 m .51742 .47809 L .52876 .47418 L p F P
0 g
s
.652 .539 .713 r
.47039 .42158 m .469 .41698 L .48138 .41464 L p F P
0 g
s
.654 .539 .711 r
.47914 .40701 m .48138 .41464 L .469 .41698 L p F P
0 g
s
.654 .539 .711 r
.47348 .40804 m .47914 .40701 L p .469 .41698 L F P
0 g
s
.747 .624 .722 r
.32386 .43263 m .32695 .42931 L .32496 .42435 L p F P
0 g
s
.46 .39 .692 r
.73617 .38513 m .74215 .38005 L p .74056 .38998 L F P
0 g
s
.46 .39 .692 r
.74056 .38998 m .73685 .38783 L .73617 .38513 L p F P
0 g
s
.469 .408 .706 r
.73617 .38513 m .74215 .38005 L .73543 .37681 L p F P
0 g
s
.843 .759 .769 r
.07737 .33723 m .07816 .33624 L .07447 .33273 L p F P
0 g
s
.595 .635 .861 r
.64072 .25607 m .63664 .25668 L .63374 .25166 L p F P
0 g
s
.574 .935 .924 r
.6673 .49636 m .66962 .49651 L .67958 .49128 L p F P
0 g
s
.532 .918 .921 r
.65578 .50098 m .6673 .49636 L .66962 .49651 L p F P
0 g
s
.537 .925 .858 r
.68146 .49074 m .67958 .49128 L .66962 .49651 L p F P
0 g
s
.789 .766 .833 r
.13329 .27359 m .13154 .27502 L .12791 .27152 L p F P
0 g
s
.801 .617 .652 r
.29906 .33521 m .30612 .33735 L .30325 .34337 L p F P
0 g
s
.798 .608 .645 r
.30612 .33735 m .29906 .33521 L .30159 .3293 L p F P
0 g
s
.756 .696 .795 r
.2636 .48817 m .25922 .49149 L .25589 .48672 L p F P
0 g
s
.834 .591 .572 r
.28269 .29738 m .27654 .29488 L .27738 .2896 L p F P
0 g
s
.847 .603 .569 r
.27156 .28698 m .27738 .2896 L .27654 .29488 L p F P
0 g
s
.655 .546 .719 r
.4714 .42479 m .47039 .42158 L .48166 .4156 L p F P
0 g
s
.652 .539 .713 r
.48138 .41464 m .48166 .4156 L .47039 .42158 L p F P
0 g
s
.656 .553 .727 r
.48472 .42546 m .48633 .43042 L .47395 .43275 L p F P
0 g
s
.656 .553 .727 r
.47395 .43275 m .47345 .43122 L .48472 .42546 L p F P
0 g
s
.808 .619 .646 r
.29482 .32706 m .30159 .3293 L .29906 .33521 L p F P
0 g
s
.807 .609 .635 r
.30159 .3293 m .29482 .32706 L .29701 .32127 L p F P
0 g
s
.655 .546 .719 r
.48166 .4156 m .48378 .42245 L .4714 .42479 L p F P
0 g
s
.653 .546 .72 r
.47345 .43122 m .4714 .42479 L .48378 .42245 L p F P
0 g
s
.789 .766 .833 r
.12791 .27152 m .1296 .27014 L .13329 .27359 L p F P
0 g
s
.787 .766 .835 r
.1391 .26251 m .1296 .27014 L .13329 .27359 L p F P
0 g
s
.787 .766 .835 r
.13329 .27359 m .1427 .26602 L .1391 .26251 L p F P
0 g
s
.901 .659 .563 r
.06299 .42975 m .06745 .43274 L .06662 .43811 L p F P
0 g
s
.895 .675 .596 r
.06745 .43274 m .06299 .42975 L .06428 .42424 L p F P
0 g
s
.746 .761 .865 r
.17776 .24797 m .16844 .25375 L .16487 .25019 L p F P
0 g
s
.849 .757 .761 r
.07352 .3339 m .07737 .33723 L .0722 .34398 L p F P
0 g
s
.843 .759 .769 r
.07447 .33273 m .07352 .3339 L .07737 .33723 L p F P
0 g
s
.653 .546 .72 r
.48378 .42245 m .48472 .42546 L .47345 .43122 L p F P
0 g
s
.887 .715 .664 r
.05762 .39777 m .06181 .40089 L .05939 .40675 L p F P
0 g
s
.881 .721 .679 r
.06181 .40089 m .05762 .39777 L .06037 .3918 L p F P
0 g
s
.503 .905 .798 r
.55919 .25212 m .56187 .25142 L .56727 .24851 L p F P
0 g
s
.575 .599 .839 r
.65405 .26576 m .66574 .26474 L .66863 .27039 L p F P
0 g
s
.576 .603 .843 r
.66284 .25913 m .66574 .26474 L .65405 .26576 L p F P
0 g
s
.576 .603 .843 r
.65955 .25944 m .66284 .25913 L p .65405 .26576 L F P
0 g
s
.576 .603 .843 r
.65405 .26576 m .65389 .26545 L .65955 .25944 L p F P
0 g
s
.624 .489 .677 r
.48195 .36821 m .48073 .36286 L .48802 .35936 L p F P
0 g
s
.815 .619 .637 r
.29054 .31892 m .29701 .32127 L .29482 .32706 L p F P
0 g
s
.817 .61 .623 r
.29701 .32127 m .29054 .31892 L .29239 .31325 L p F P
0 g
s
.821 .766 .8 r
.09879 .30534 m .09763 .30654 L .09395 .30308 L p F P
0 g
s
.821 .766 .8 r
.09395 .30308 m .09506 .30194 L .09879 .30534 L p F P
0 g
s
.817 .766 .805 r
.09879 .30534 m .09506 .30194 L .10268 .29434 L p F P
0 g
s
.638 .511 .692 r
.47318 .38492 m .48534 .38229 L p .4825 .3905 L F P
0 g
s
.638 .511 .692 r
.4825 .3905 m .47505 .39215 L .47318 .38492 L p F P
0 g
s
.64 .511 .689 r
.48378 .37607 m .48534 .38229 L .47318 .38492 L p F P
0 g
s
.822 .597 .598 r
.28654 .30477 m .28136 .30284 L .28269 .29738 L p F P
0 g
s
.834 .607 .595 r
.27654 .29488 m .28269 .29738 L .28136 .30284 L p F P
0 g
s
.758 .639 .73 r
.31531 .43106 m .32386 .43263 L .31698 .44001 L p F P
0 g
s
.747 .624 .722 r
.32175 .42381 m .31531 .43106 L .32386 .43263 L p F P
0 g
s
.747 .624 .722 r
.32496 .42435 m .32175 .42381 L p .32386 .43263 L F P
0 g
s
.823 .618 .625 r
.28784 .31147 m .29239 .31325 L .29054 .31892 L p F P
0 g
s
.826 .611 .611 r
.28709 .30751 m .28772 .30526 L p .29239 .31325 L F P
0 g
s
.826 .611 .611 r
.29239 .31325 m .28784 .31147 L .28709 .30751 L p F P
0 g
s
.643 .64 .832 r
.56364 .49232 m .56388 .49275 L .55261 .49628 L p F P
0 g
s
.643 .64 .832 r
.55261 .49628 m .55223 .49561 L .56364 .49232 L p F P
0 g
s
.732 .721 .84 r
.23025 .49751 m .21922 .50385 L .21578 .50001 L p F P
0 g
s
.768 .623 .7 r
.31853 .39116 m .32694 .39281 L .32183 .39961 L p F P
0 g
s
.755 .607 .693 r
.32325 .38449 m .31853 .39116 L .32694 .39281 L p F P
0 g
s
.758 .626 .714 r
.32382 .42148 m .32785 .41668 L .32147 .41547 L closepath p F P
0 g
s
.759 .625 .711 r
.3207 .41347 m .32495 .40811 L p .32785 .41668 L F P
0 g
s
.759 .625 .711 r
.32785 .41668 m .32147 .41547 L .3207 .41347 L p F P
0 g
s
.826 .765 .794 r
.09186 .31269 m .09763 .30654 L .09395 .30308 L p F P
0 g
s
.832 .616 .611 r
.28709 .30751 m .28772 .30526 L .28654 .30477 L closepath p F P
0 g
s
.818 .349 .097 r
.09219 .47235 m .09232 .47237 L p .09987 .47931 L F P
0 g
s
.86 .436 .216 r
.09219 .47235 m .09216 .47229 L .09232 .47237 L closepath p F P
0 g
s
.65 .577 .759 r
.50827 .45578 m .51057 .46168 L .49858 .46441 L p F P
0 g
s
.65 .577 .759 r
.49858 .46441 m .49696 .46033 L .50827 .45578 L p F P
0 g
s
.613 .659 .871 r
.61959 .24954 m .61927 .24901 L .62034 .2488 L closepath p F P
0 g
s
.581 .612 .848 r
.65389 .26545 m .65116 .26036 L .65955 .25944 L closepath p F P
0 g
s
.331 .125 .443 r
.72617 .4474 m .72457 .44846 L .72278 .45437 L p F P
0 g
s
.396 .264 .582 r
.74086 .41942 m .73402 .42458 L .73473 .43033 L p F P
0 g
s
.411 .275 .584 r
.73391 .43091 m .73473 .43033 L .73402 .42458 L p F P
0 g
s
.417 .299 .611 r
.73402 .42458 m .74086 .41942 L .73786 .41497 L p F P
0 g
s
.733 .71 .829 r
.24591 .4962 m .24473 .49466 L .24332 .49554 L closepath p F P
0 g
s
.45 .252 .518 r
.52759 .28642 m .52754 .28132 L .53754 .27601 L p F P
0 g
s
.482 .276 .524 r
.52255 .28874 m .52759 .28642 L .52754 .28132 L p F P
0 g
s
.415 .187 .457 r
.53785 .27135 m .53754 .27601 L .52754 .28132 L p F P
0 g
s
.46 .39 .691 r
.73795 .39215 m .73685 .38783 L .74056 .38998 L closepath p F P
0 g
s
.468 .408 .708 r
.74278 .37045 m .73543 .37681 L .74215 .38005 L p F P
0 g
s
.48 .426 .72 r
.74275 .37034 m .74278 .37045 L .73543 .37681 L p F P
0 g
s
.48 .426 .72 r
.73538 .36739 m .74275 .37034 L p .73543 .37681 L F P
0 g
s
.605 .464 .663 r
.49082 .35159 m .4895 .34496 L .50098 .34153 L p F P
0 g
s
.603 .458 .657 r
.50026 .33774 m .50098 .34153 L .4895 .34496 L p F P
0 g
s
.857 .425 .19 r
.09216 .47229 m .09219 .47235 L .08829 .47131 L p F P
0 g
s
.857 .425 .19 r
.08829 .47131 m .08739 .46947 L .09216 .47229 L p F P
0 g
s
.756 .696 .795 r
.25589 .48672 m .25662 .48614 L .2636 .48817 L p F P
0 g
s
.745 .685 .794 r
.2671 .47789 m .25662 .48614 L .2636 .48817 L p F P
0 g
s
.745 .685 .794 r
.2636 .48817 m .2704 .48306 L .2671 .47789 L p F P
0 g
s
.818 .349 .097 r
.09987 .47931 m .09491 .47656 L .09219 .47235 L p F P
0 g
s
.818 .349 .099 r
.09491 .47656 m .09219 .47235 L .08829 .47131 L p F P
0 g
s
.545 .554 .814 r
.69314 .2971 m .692 .29458 L .69554 .29465 L closepath p F P
0 g
s
.541 .544 .807 r
.69314 .2971 m .69554 .29465 L p .70377 .30152 L F P
0 g
s
.645 .591 .779 r
.52876 .47418 m .51742 .47809 L .51438 .47105 L p F P
0 g
s
.64 .625 .819 r
.56364 .49232 m .55223 .49561 L .54922 .48988 L p F P
0 g
s
.654 .749 .92 r
.17614 .50675 m .18692 .50328 L .19044 .50655 L p F P
0 g
s
.667 .748 .911 r
.18692 .50328 m .17614 .50675 L .17257 .50375 L p F P
0 g
s
.794 .303 .024 r
.25412 .26413 m .24908 .2612 L .24624 .25724 L p F P
0 g
s
.81 .325 .03 r
.24163 .25415 m .24624 .25724 L .24908 .2612 L p F P
0 g
s
0 .145 .585 r
.23996 .25281 m .24163 .25415 L .24624 .25724 L p F P
0 g
s
.512 .494 .774 r
.72656 .33228 m .71853 .3309 L .71767 .32861 L p F P
0 g
s
.752 .625 .718 r
.32496 .42435 m .32382 .42148 L .32175 .42381 L closepath p F P
0 g
s
.613 .669 .88 r
.62034 .2488 m .61927 .24901 L .61637 .24451 L p F P
0 g
s
.644 .616 .807 r
.5462 .48383 m .54665 .48473 L .53515 .48799 L p F P
0 g
s
.644 .616 .807 r
.53515 .48799 m .53483 .48736 L .5462 .48383 L p F P
0 g
s
.772 .623 .694 r
.31508 .38276 m .32325 .38449 L .31853 .39116 L p F P
0 g
s
.76 .606 .687 r
.31942 .37621 m .31508 .38276 L .32325 .38449 L p F P
0 g
s
.899 .679 .596 r
.0599 .42122 m .06428 .42424 L .06299 .42975 L p F P
0 g
s
.892 .691 .623 r
.06428 .42424 m .0599 .42122 L .0616 .41558 L p F P
0 g
s
.582 .433 .644 r
.49977 .33504 m .4987 .32871 L .50982 .32483 L p F P
0 g
s
.579 .425 .637 r
.50882 .3186 m .50982 .32483 L .4987 .32871 L p F P
0 g
s
.723 .739 .864 r
.21067 .50256 m .20481 .50552 L .20133 .50198 L p F P
0 g
s
.69 .742 .891 r
.19044 .50655 m .20133 .50198 L .20481 .50552 L p F P
0 g
s
.644 .698 .885 r
.584 .504 m .59546 .50084 L .59839 .50492 L p F P
0 g
s
.643 .672 .863 r
.59465 .49962 m .59546 .50084 L .584 .504 L p F P
0 g
s
.643 .672 .863 r
.584 .504 m .58369 .50353 L .59465 .49962 L p F P
0 g
s
.777 .766 .843 r
.14431 .26481 m .1427 .26602 L .1391 .26251 L p F P
0 g
s
.818 .608 .618 r
.28654 .30477 m .28136 .30284 L p .28605 .31084 L F P
0 g
s
.818 .608 .618 r
.28605 .31084 m .28709 .30751 L .28654 .30477 L p F P
0 g
s
.872 .738 .711 r
.06277 .37638 m .06141 .37879 L .05773 .37494 L p F P
0 g
s
.872 .738 .711 r
.05773 .37494 m .05873 .37318 L .06277 .37638 L p F P
0 g
s
.866 .741 .723 r
.06277 .37638 m .05873 .37318 L .06261 .36685 L p F P
0 g
s
.641 .603 .795 r
.5462 .48383 m .53483 .48736 L .5318 .48094 L p F P
0 g
s
.829 .765 .791 r
.09186 .31269 m .08613 .31894 L .08243 .31549 L p F P
0 g
s
.829 .765 .791 r
.08243 .31549 m .08812 .30929 L .09186 .31269 L p F P
0 g
s
.826 .765 .794 r
.09395 .30308 m .08812 .30929 L .09186 .31269 L p F P
0 g
s
.512 .494 .774 r
.71767 .32861 m .7222 .32417 L p .72656 .33228 L F P
0 g
s
.518 .506 .783 r
.71767 .32861 m .71557 .32323 L .7222 .32417 L closepath p F P
0 g
s
.648 .568 .751 r
.50716 .45281 m .50827 .45578 L .49696 .46033 L p F P
0 g
s
.648 .568 .751 r
.49696 .46033 m .49514 .45552 L .50716 .45281 L p F P
0 g
s
.864 .748 .733 r
.06279 .35717 m .06674 .36044 L .06261 .36685 L p F P
0 g
s
.859 .75 .741 r
.06629 .35202 m .06279 .35717 L .06674 .36044 L p F P
0 g
s
.699 .741 .884 r
.20133 .50198 m .19044 .50655 L .18692 .50328 L p F P
0 g
s
.757 .64 .731 r
.31558 .44152 m .31698 .44001 L .31472 .43956 L closepath p F P
0 g
s
.758 .639 .73 r
.31242 .43432 m .31531 .43106 L p .31698 .44001 L F P
0 g
s
.758 .639 .73 r
.31698 .44001 m .31472 .43956 L .31242 .43432 L p F P
0 g
s
.752 .651 .749 r
.30567 .45592 m .30424 .453 L .30191 .45521 L closepath p F P
0 g
s
.446 .354 .658 r
.74019 .40207 m .73791 .4002 L .73953 .39893 L closepath p F P
0 g
s
.46 .377 .676 r
.73791 .4002 m .73953 .39893 L .73795 .39215 L p F P
0 g
s
.498 .315 .563 r
.51755 .29668 m .52583 .29277 L .52255 .28874 L p F P
0 g
s
.502 .316 .561 r
.52759 .28642 m .52255 .28874 L .52583 .29277 L p F P
0 g
s
.512 .344 .589 r
.51807 .30236 m .51755 .29668 L .52583 .29277 L p F P
0 g
s
.751 .623 .717 r
.32175 .42381 m .32382 .42148 L .32147 .41547 L p F P
0 g
s
.763 .625 .708 r
.3207 .41347 m .32495 .40811 L .31812 .40673 L closepath p F P
0 g
s
.763 .624 .706 r
.31758 .40528 m .32183 .39961 L p .32495 .40811 L F P
0 g
s
.763 .624 .706 r
.32495 .40811 m .31812 .40673 L .31758 .40528 L p F P
0 g
s
.777 .766 .843 r
.1391 .26251 m .14064 .26135 L .14431 .26481 L p F P
0 g
s
.775 .766 .845 r
.15022 .25422 m .14064 .26135 L .14431 .26481 L p F P
0 g
s
.775 .766 .845 r
.14431 .26481 m .15381 .25774 L .15022 .25422 L p F P
0 g
s
.554 .395 .621 r
.50799 .31256 m .51877 .30823 L p .51465 .31623 L F P
0 g
s
.554 .395 .621 r
.51465 .31623 m .50849 .31628 L .50799 .31256 L p F P
0 g
s
.546 .38 .607 r
.51807 .30236 m .51877 .30823 L .50799 .31256 L p F P
0 g
s
.448 .369 .675 r
.74056 .38998 m .73795 .39215 L .73953 .39893 L p F P
0 g
s
.639 .513 .694 r
.47555 .39407 m .4825 .3905 L .47505 .39215 L closepath p F P
0 g
s
.777 .622 .688 r
.3115 .3744 m .31942 .37621 L .31508 .38276 L p F P
0 g
s
.764 .605 .681 r
.31549 .36797 m .3115 .3744 L .31942 .37621 L p F P
0 g
s
.75 .637 .735 r
.30958 .44757 m .31558 .44152 L .31472 .43956 L p F P
0 g
s
.653 .534 .706 r
.47914 .40701 m .4786 .40515 L .47348 .40804 L closepath p F P
0 g
s
.651 .53 .704 r
.47705 .39953 m .4786 .40515 L .47348 .40804 L p F P
0 g
s
.623 .49 .679 r
.48195 .36821 m .49377 .36518 L p .4887 .37383 L F P
0 g
s
.623 .49 .679 r
.4887 .37383 m .48356 .37516 L .48195 .36821 L p F P
0 g
s
.624 .489 .677 r
.49221 .35829 m .49377 .36518 L .48195 .36821 L p F P
0 g
s
.624 .489 .677 r
.48802 .35936 m .49221 .35829 L p .48195 .36821 L F P
0 g
s
.617 .666 .875 r
.62034 .2488 m .63084 .24674 L .62793 .24194 L p F P
0 g
s
.617 .666 .875 r
.62793 .24194 m .62693 .24215 L .62034 .2488 L p F P
0 g
s
.613 .669 .88 r
.61637 .24451 m .62693 .24215 L .62034 .2488 L p F P
0 g
s
.641 .671 .863 r
.59251 .49634 m .59465 .49962 L .58369 .50353 L p F P
0 g
s
.641 .671 .863 r
.58369 .50353 m .58104 .49942 L .59251 .49634 L p F P
0 g
s
.76 .684 .778 r
.27479 .47943 m .2704 .48306 L .2671 .47789 L p F P
0 g
s
.741 .71 .822 r
.23025 .49751 m .23621 .49355 L .24332 .49554 L p F P
0 g
s
.732 .707 .827 r
.24136 .49016 m .23621 .49355 L .24332 .49554 L p F P
0 g
s
.732 .707 .827 r
.24332 .49554 m .24473 .49466 L .24136 .49016 L p F P
0 g
s
.885 .535 .38 r
.26088 .27142 m .25936 .27051 L .26052 .26974 L closepath p F P
0 g
s
.507 .743 .98 r
.15394 .50344 m .15832 .50317 L .1547 .50036 L p F P
0 g
s
.507 .743 .98 r
.1547 .50036 m .14835 .50095 L .15394 .50344 L p F P
0 g
s
.413 .728 .99 r
.14419 .50115 m .14835 .50095 L .15394 .50344 L p F P
0 g
s
.751 .623 .717 r
.31934 .41509 m .3133 .4222 L .32175 .42381 L p F P
0 g
s
.751 .623 .717 r
.32147 .41547 m .31934 .41509 L p .32175 .42381 L F P
0 g
s
.762 .638 .724 r
.3133 .4222 m .32175 .42381 L .31531 .43106 L p F P
0 g
s
.642 .521 .701 r
.47705 .39953 m .47555 .39407 L .4825 .3905 L p F P
0 g
s
.545 .555 .815 r
.69554 .29465 m .692 .29458 L .68909 .28816 L p F P
0 g
s
.563 .582 .831 r
.68129 .27585 m .67153 .27629 L .66867 .27047 L p F P
0 g
s
.782 .622 .682 r
.30783 .36606 m .31549 .36797 L .3115 .3744 L p F P
0 g
s
.78 .613 .673 r
.31549 .36797 m .30783 .36606 L .31148 .35975 L p F P
0 g
s
.814 .603 .617 r
.28784 .31147 m .28709 .30751 L .28605 .31084 L closepath p F P
0 g
s
.657 .903 .981 r
.65343 .49989 m .65578 .50098 L .6673 .49636 L p F P
0 g
s
.76 .684 .778 r
.2671 .47789 m .26761 .47745 L .27479 .47943 L p F P
0 g
s
.749 .673 .777 r
.27719 .4692 m .26761 .47745 L .27479 .47943 L p F P
0 g
s
.749 .673 .777 r
.27922 .46967 m .27719 .4692 L p .27479 .47943 L F P
0 g
s
.749 .673 .777 r
.27479 .47943 m .28164 .47381 L .27922 .46967 L p F P
0 g
s
.75 .637 .735 r
.30854 .43841 m .30158 .44583 L .30958 .44757 L p F P
0 g
s
.75 .637 .735 r
.31472 .43956 m .30854 .43841 L p .30958 .44757 L F P
0 g
s
.761 .648 .736 r
.30958 .44757 m .30424 .453 L .30104 .44641 L p F P
0 g
s
.761 .648 .736 r
.30104 .44641 m .30158 .44583 L .30958 .44757 L p F P
0 g
s
.084 .499 .9 r
.2329 .24768 m .22585 .2453 L .23016 .24852 L p F P
0 g
s
.414 .663 .963 r
.22248 .24501 m .22585 .2453 L .23016 .24852 L p F P
0 g
s
.649 .568 .751 r
.50521 .44756 m .50716 .45281 L .49514 .45552 L p F P
0 g
s
.649 .568 .751 r
.49514 .45552 m .4939 .45225 L .50521 .44756 L p F P
0 g
s
.748 .695 .801 r
.25589 .48672 m .24473 .49466 L .24136 .49016 L p F P
0 g
s
.503 .905 .798 r
.56727 .24851 m .57198 .24498 L p .55919 .25212 L F P
0 g
s
.705 .909 .967 r
.56727 .24851 m .57198 .24498 L .57324 .2456 L closepath p F P
0 g
s
.884 .725 .68 r
.05626 .38864 m .06037 .3918 L .05762 .39777 L p F P
0 g
s
.878 .729 .693 r
.06037 .3918 m .05626 .38864 L .05933 .38257 L p F P
0 g
s
.592 .736 .944 r
.20826 .24391 m .21898 .2417 L .22248 .24501 L p F P
0 g
s
.584 .731 .944 r
.21898 .2417 m .20826 .24391 L .20475 .24041 L p F P
0 g
s
.681 .751 .904 r
.1939 .2448 m .20475 .24041 L .20826 .24391 L p F P
0 g
s
.754 .638 .731 r
.31472 .43956 m .31242 .43432 L .30854 .43841 L closepath p F P
0 g
s
.679 .751 .905 r
.20475 .24041 m .1939 .2448 L .19037 .24124 L p F P
0 g
s
.719 .756 .882 r
.17944 .24694 m .19037 .24124 L .1939 .2448 L p F P
0 g
s
.852 .756 .756 r
.06835 .34066 m .0722 .34398 L .06725 .35066 L p F P
0 g
s
.849 .757 .761 r
.0722 .34398 m .06835 .34066 L .07352 .3339 L p F P
0 g
s
.71 .173 0 r
.10861 .48601 m .10369 .48326 L .09987 .47931 L p F P
0 g
s
.695 .152 0 r
.09491 .47656 m .09987 .47931 L .10369 .48326 L p F P
0 g
s
.833 .764 .786 r
.08525 .31993 m .08613 .31894 L .08243 .31549 L p F P
0 g
s
.896 .695 .623 r
.05731 .41251 m .0616 .41558 L .0599 .42122 L p F P
0 g
s
.89 .704 .645 r
.0616 .41558 m .05731 .41251 L .05939 .40675 L p F P
0 g
s
.552 .56 .816 r
.68909 .28816 m .68608 .28818 L .68815 .28611 L closepath p F P
0 g
s
.558 .569 .821 r
.68619 .28193 m .68815 .28611 L .68608 .28818 L p F P
0 g
s
.312 .111 .439 r
.7347 .44144 m .72617 .4474 L .72605 .45221 L p F P
0 g
s
.331 .125 .443 r
.72278 .45437 m .72605 .45221 L .72617 .4474 L p F P
0 g
s
.356 .181 .501 r
.72617 .4474 m .7347 .44144 L .73493 .43598 L p F P
0 g
s
.767 .625 .703 r
.31758 .40528 m .32183 .39961 L .3149 .39811 L closepath p F P
0 g
s
.768 .623 .7 r
.31446 .39691 m .31853 .39116 L p .32183 .39961 L F P
0 g
s
.768 .623 .7 r
.32183 .39961 m .3149 .39811 L .31446 .39691 L p F P
0 g
s
.875 .737 .707 r
.05933 .38257 m .06141 .37879 L .05773 .37494 L p F P
0 g
s
.788 .622 .676 r
.30407 .35775 m .31148 .35975 L .30783 .36606 L p F P
0 g
s
.786 .614 .667 r
.31148 .35975 m .30407 .35775 L .30739 .35155 L p F P
0 g
s
.833 .764 .786 r
.08243 .31549 m .0815 .31654 L .08525 .31993 L p F P
0 g
s
.838 .763 .78 r
.0815 .31654 m .08525 .31993 L .07926 .32696 L p F P
0 g
s
.756 .623 .713 r
.32147 .41547 m .3207 .41347 L .31934 .41509 L closepath p F P
0 g
s
.642 .521 .701 r
.48717 .38949 m .48916 .39686 L .47705 .39953 L p F P
0 g
s
.642 .521 .701 r
.4825 .3905 m .48717 .38949 L p .47705 .39953 L F P
0 g
s
.64 .521 .702 r
.4786 .40515 m .47705 .39953 L .48916 .39686 L p F P
0 g
s
0 .319 .706 r
.1091 .48639 m .11063 .4871 L p .12013 .49184 L F P
0 g
s
.588 .019 0 r
.1091 .48639 m .10861 .48601 L .11063 .4871 L closepath p F P
0 g
s
.751 .649 .748 r
.30191 .45521 m .30424 .453 L .30104 .44641 L p F P
0 g
s
.859 .48 .328 r
.25936 .27051 m .25562 .26857 L .25412 .26413 L p F P
0 g
s
.872 .494 .326 r
.24908 .2612 m .25412 .26413 L .25562 .26857 L p F P
0 g
s
.517 .506 .783 r
.7222 .32417 m .71557 .32323 L .71403 .31929 L p F P
0 g
s
.647 .56 .743 r
.50402 .44422 m .50521 .44756 L .4939 .45225 L p F P
0 g
s
.647 .56 .743 r
.4939 .45225 m .49198 .44692 L .50402 .44422 L p F P
0 g
s
.761 .664 .755 r
.29388 .45349 m .30191 .45521 L .29374 .46301 L p F P
0 g
s
.751 .649 .748 r
.30104 .44641 m .29388 .45349 L .30191 .45521 L p F P
0 g
s
.76 .677 .771 r
.28164 .47381 m .28468 .47109 L .27922 .46967 L closepath p F P
0 g
s
.642 .703 .89 r
.60987 .50172 m .59839 .50492 L .59546 .50084 L p F P
0 g
s
.645 .728 .909 r
.59839 .50492 m .60987 .50172 L .61277 .50529 L p F P
0 g
s
.761 .676 .769 r
.29232 .46267 m .29292 .46379 L .28468 .47109 L p F P
0 g
s
.761 .676 .769 r
.28581 .46126 m .29232 .46267 L p .28468 .47109 L F P
0 g
s
.761 .676 .769 r
.27837 .4682 m .28581 .46126 L p .28468 .47109 L F P
0 g
s
.761 .676 .769 r
.28468 .47109 m .27922 .46967 L .27837 .4682 L p F P
0 g
s
.595 .635 .861 r
.64536 .24979 m .64592 .25078 L .64072 .25607 L p F P
0 g
s
.595 .635 .861 r
.63374 .25166 m .64536 .24979 L p .64072 .25607 L F P
0 g
s
.591 .623 .852 r
.64826 .25502 m .64072 .25607 L .64592 .25078 L closepath p F P
0 g
s
.606 .467 .666 r
.49202 .35738 m .49082 .35159 L .50231 .34815 L p F P
0 g
s
.62 .477 .666 r
.49082 .35159 m .49202 .35738 L .48802 .35936 L p F P
0 g
s
.605 .464 .663 r
.50098 .34153 m .50231 .34815 L .49082 .35159 L p F P
0 g
s
.755 .622 .712 r
.31934 .41509 m .3207 .41347 L .31812 .40673 L p F P
0 g
s
.506 .904 .784 r
.67958 .49128 m .68146 .49074 L .69115 .48532 L p F P
0 g
s
.794 .615 .659 r
.30739 .35155 m .30025 .34945 L .30325 .34337 L p F P
0 g
s
.794 .623 .669 r
.30025 .34945 m .30739 .35155 L .30407 .35775 L p F P
0 g
s
.459 .739 .988 r
.14835 .50095 m .14419 .50115 L .14052 .49868 L p F P
0 g
s
.761 .665 .757 r
.29292 .46379 m .29374 .46301 L .29232 .46267 L closepath p F P
0 g
s
.761 .664 .755 r
.28969 .45768 m .29388 .45349 L p .29374 .46301 L F P
0 g
s
.761 .664 .755 r
.29374 .46301 m .29232 .46267 L .28969 .45768 L p F P
0 g
s
.746 .761 .865 r
.16487 .25019 m .17403 .24452 L .17776 .24797 L p F P
0 g
s
.745 .761 .866 r
.17589 .24338 m .17403 .24452 L .17776 .24797 L p F P
0 g
s
.745 .761 .866 r
.17776 .24797 m .17944 .24694 L .17589 .24338 L p F P
0 g
s
.477 .427 .723 r
.74275 .37034 m .73538 .36739 L .74053 .36284 L closepath p F P
0 g
s
.487 .441 .732 r
.73964 .35999 m .74053 .36284 L .73538 .36739 L p F P
0 g
s
.487 .441 .732 r
.73447 .35822 m .73964 .35999 L p .73538 .36739 L F P
0 g
s
.642 .578 .768 r
.51438 .47105 m .5164 .47034 L .51431 .47088 L closepath p F P
0 g
s
.645 .591 .779 r
.52607 .46789 m .52876 .47418 L p .51438 .47105 L F P
0 g
s
.645 .591 .779 r
.51438 .47105 m .5164 .47034 L .52607 .46789 L p F P
0 g
s
.642 .578 .767 r
.5164 .47034 m .51431 .47088 L .51132 .4636 L p F P
0 g
s
.762 .639 .726 r
.31242 .43432 m .31531 .43106 L .31057 .43006 L closepath p F P
0 g
s
.762 .638 .724 r
.30925 .427 m .3133 .4222 L p .31531 .43106 L F P
0 g
s
.762 .638 .724 r
.31531 .43106 m .31057 .43006 L .30925 .427 L p F P
0 g
s
.623 .483 .671 r
.49221 .35829 m .49202 .35738 L .48802 .35936 L closepath p F P
0 g
s
.763 .765 .854 r
.15734 .25532 m .15381 .25774 L .15022 .25422 L p F P
0 g
s
.766 .637 .719 r
.311 .41344 m .31934 .41509 L .3133 .4222 L p F P
0 g
s
.755 .622 .712 r
.31665 .40645 m .311 .41344 L .31934 .41509 L p F P
0 g
s
.755 .622 .712 r
.31812 .40673 m .31665 .40645 L p .31934 .41509 L F P
0 g
s
.664 .729 .898 r
.58757 .24344 m .59904 .23952 L .60195 .24332 L p F P
0 g
s
.683 .758 .908 r
.59904 .23952 m .58757 .24344 L .58466 .24054 L p F P
0 g
s
.704 .799 .924 r
.57324 .2456 m .58466 .24054 L .58757 .24344 L p F P
0 g
s
.648 .56 .742 r
.50215 .43892 m .50402 .44422 L .49198 .44692 L p F P
0 g
s
.648 .56 .742 r
.49198 .44692 m .49084 .44376 L .50215 .43892 L p F P
0 g
s
.643 .528 .708 r
.47914 .40701 m .4786 .40515 L .48989 .39954 L p F P
0 g
s
.64 .521 .702 r
.48916 .39686 m .48989 .39954 L .4786 .40515 L p F P
0 g
s
.772 .625 .697 r
.31446 .39691 m .31853 .39116 L .31181 .38961 L closepath p F P
0 g
s
.772 .623 .694 r
.31136 .38834 m .31508 .38276 L p .31853 .39116 L F P
0 g
s
.772 .623 .694 r
.31853 .39116 m .31181 .38961 L .31136 .38834 L p F P
0 g
s
.8 .623 .662 r
.29637 .34118 m .30325 .34337 L .30025 .34945 L p F P
0 g
s
.801 .617 .652 r
.30325 .34337 m .29637 .34118 L .29906 .33521 L p F P
0 g
s
.209 0 .258 r
.71566 .4656 m .71931 .4608 L .71622 .46281 L closepath p F P
0 g
s
.283 .045 .366 r
.71622 .46281 m .71931 .4608 L .72278 .45437 L p F P
0 g
s
.641 .655 .848 r
.56663 .49764 m .57806 .49448 L .58104 .49942 L p F P
0 g
s
.638 .639 .834 r
.57508 .4892 m .57806 .49448 L .56663 .49764 L p F P
0 g
s
.638 .639 .834 r
.57071 .49039 m .57508 .4892 L p .56663 .49764 L F P
0 g
s
.638 .639 .834 r
.56663 .49764 m .56388 .49275 L .57071 .49039 L p F P
0 g
s
.812 .611 .63 r
.28605 .31084 m .28784 .31147 L .28946 .31849 L p F P
0 g
s
.823 .618 .625 r
.29054 .31892 m .28946 .31849 L .28784 .31147 L p F P
0 g
s
.385 .232 .547 r
.73473 .43033 m .73391 .43091 L .73493 .43598 L p F P
0 g
s
.624 .494 .683 r
.48378 .37607 m .4887 .37383 L .48356 .37516 L closepath p F P
0 g
s
.641 .528 .71 r
.47914 .40701 m .49127 .40436 L p .48576 .41366 L F P
0 g
s
.641 .528 .71 r
.48576 .41366 m .48138 .41464 L .47914 .40701 L p F P
0 g
s
.643 .528 .708 r
.48989 .39954 m .49127 .40436 L .47914 .40701 L p F P
0 g
s
.415 .299 .612 r
.74206 .41175 m .73786 .41497 L .74086 .41942 L p F P
0 g
s
.433 .328 .636 r
.73786 .41497 m .74206 .41175 L .7409 .40547 L p F P
0 g
s
.723 .739 .864 r
.20133 .50198 m .20449 .50028 L .21067 .50256 L p F P
0 g
s
.711 .728 .864 r
.21233 .4961 m .20449 .50028 L .21067 .50256 L p F P
0 g
s
.711 .728 .864 r
.21067 .50256 m .21578 .50001 L .21233 .4961 L p F P
0 g
s
.719 .757 .883 r
.19037 .24124 m .17944 .24694 L .17589 .24338 L p F P
0 g
s
.554 .4 .626 r
.50882 .3186 m .50849 .31628 L .51465 .31623 L closepath p F P
0 g
s
.755 .662 .758 r
.29232 .46267 m .28969 .45768 L .28581 .46126 L closepath p F P
0 g
s
.517 .506 .783 r
.71403 .31929 m .717 .31632 L p .7222 .32417 L F P
0 g
s
.523 .518 .791 r
.71403 .31929 m .71263 .31583 L .717 .31632 L closepath p F P
0 g
s
.448 .369 .675 r
.73953 .39893 m .74584 .3937 L .74056 .38998 L p F P
0 g
s
.435 .347 .657 r
.73953 .39893 m .74584 .3937 L p .74253 .40414 L F P
0 g
s
.435 .347 .657 r
.74253 .40414 m .74019 .40207 L .73953 .39893 L p F P
0 g
s
.645 .552 .735 r
.50111 .43587 m .50215 .43892 L .49084 .44376 L p F P
0 g
s
.645 .552 .735 r
.49084 .44376 m .48906 .43857 L .50111 .43587 L p F P
0 g
s
0 .469 .843 r
.12523 .49451 m .12654 .49499 L .12283 .49273 L p F P
0 g
s
0 .469 .843 r
.12283 .49273 m .12013 .49184 L .12523 .49451 L p F P
0 g
s
.627 .501 .689 r
.48534 .38229 m .48378 .37607 L .4887 .37383 L p F P
0 g
s
.807 .623 .654 r
.29339 .33326 m .29906 .33521 L .29637 .34118 L p F P
0 g
s
.808 .619 .646 r
.29295 .33163 m .29482 .32706 L p .29906 .33521 L F P
0 g
s
.808 .619 .646 r
.29906 .33521 m .29339 .33326 L .29295 .33163 L p F P
0 g
s
.754 .636 .73 r
.30854 .43841 m .31242 .43432 L .31057 .43006 L p F P
0 g
s
.644 .84 .976 r
.65303 .49967 m .64149 .50362 L .63867 .50136 L p F P
0 g
s
.645 .82 .968 r
.62715 .50493 m .63867 .50136 L .64149 .50362 L p F P
0 g
s
.646 .865 .982 r
.65343 .49989 m .65303 .49967 L .64149 .50362 L p F P
0 g
s
.877 .576 .475 r
.26637 .27915 m .26116 .27629 L .26088 .27142 L p F P
0 g
s
.887 .585 .47 r
.25936 .27051 m .26088 .27142 L .26116 .27629 L p F P
0 g
s
.646 .768 .937 r
.61277 .50529 m .62428 .50196 L .62715 .50493 L p F P
0 g
s
.644 .736 .916 r
.62428 .50196 m .61277 .50529 L .60987 .50172 L p F P
0 g
s
.362 .142 .439 r
.54589 .26638 m .53785 .27135 L .53754 .27601 L p F P
0 g
s
.283 .017 .321 r
.54767 .26394 m .54826 .26145 L p .53785 .27135 L F P
0 g
s
.283 .017 .321 r
.53785 .27135 m .54589 .26638 L .54767 .26394 L p F P
0 g
s
.648 .705 .888 r
.61346 .24017 m .60195 .24332 L .59904 .23952 L p F P
0 g
s
.638 .689 .881 r
.60195 .24332 m .61346 .24017 L .61637 .24451 L p F P
0 g
s
.893 .708 .646 r
.05518 .40364 m .05939 .40675 L .05731 .41251 L p F P
0 g
s
.887 .715 .664 r
.05939 .40675 m .05518 .40364 L .05762 .39777 L p F P
0 g
s
.585 .441 .651 r
.50026 .33774 m .49977 .33504 L .51091 .33118 L p F P
0 g
s
.582 .433 .644 r
.50982 .32483 m .51091 .33118 L .49977 .33504 L p F P
0 g
s
.76 .622 .707 r
.31812 .40673 m .31758 .40528 L .31665 .40645 L closepath p F P
0 g
s
.814 .624 .645 r
.29295 .33163 m .29482 .32706 L .29132 .32578 L closepath p F P
0 g
s
.815 .619 .637 r
.28997 .32045 m .29054 .31892 L p .29482 .32706 L F P
0 g
s
.815 .619 .637 r
.29482 .32706 m .29132 .32578 L .28997 .32045 L p F P
0 g
s
.647 .552 .734 r
.49908 .42985 m .50111 .43587 L .48906 .43857 L p F P
0 g
s
.647 .552 .734 r
.48906 .43857 m .48778 .43484 L .49908 .42985 L p F P
0 g
s
.749 .715 .82 r
.23621 .49355 m .23025 .49751 L .22684 .49334 L p F P
0 g
s
.732 .721 .84 r
.21578 .50001 m .22684 .49334 L .23025 .49751 L p F P
0 g
s
.388 .649 .961 r
.22585 .2453 m .22248 .24501 L .21898 .2417 L p F P
0 g
s
.868 .745 .725 r
.05865 .36359 m .06261 .36685 L .05873 .37318 L p F P
0 g
s
.864 .748 .733 r
.06261 .36685 m .05865 .36359 L .06279 .35717 L p F P
0 g
s
.641 .53 .712 r
.48166 .4156 m .48576 .41366 L .48138 .41464 L closepath p F P
0 g
s
.763 .765 .854 r
.15022 .25422 m .15368 .25184 L .15734 .25532 L p F P
0 g
s
.761 .765 .856 r
.1613 .24666 m .15368 .25184 L .15734 .25532 L p F P
0 g
s
.761 .765 .856 r
.15734 .25532 m .16487 .25019 L .1613 .24666 L p F P
0 g
s
.777 .624 .691 r
.31136 .38834 m .31508 .38276 L .30883 .38121 L closepath p F P
0 g
s
.777 .622 .688 r
.30826 .37957 m .3115 .3744 L p .31508 .38276 L F P
0 g
s
.777 .622 .688 r
.31508 .38276 m .30883 .38121 L .30826 .37957 L p F P
0 g
s
.644 .537 .718 r
.48378 .42245 m .48166 .4156 L .48576 .41366 L p F P
0 g
s
.641 .603 .795 r
.5318 .48094 m .54318 .47738 L .5462 .48383 L p F P
0 g
s
.639 .593 .787 r
.54182 .47435 m .54318 .47738 L .5318 .48094 L p F P
0 g
s
.639 .593 .787 r
.5318 .48094 m .53031 .47764 L .54182 .47435 L p F P
0 g
s
.842 .763 .775 r
.07926 .32696 m .07447 .33273 L .07076 .3293 L p F P
0 g
s
.842 .763 .775 r
.07076 .3293 m .0755 .32358 L .07926 .32696 L p F P
0 g
s
.838 .763 .78 r
.07926 .32696 m .0755 .32358 L .0815 .31654 L p F P
0 g
s
.642 .578 .767 r
.52266 .45955 m .52572 .46706 L .5164 .47034 L p F P
0 g
s
.642 .578 .767 r
.51132 .4636 m .52266 .45955 L p .5164 .47034 L F P
0 g
s
.645 .587 .775 r
.52607 .46789 m .52572 .46706 L .5164 .47034 L closepath p F P
0 g
s
.759 .621 .707 r
.31665 .40645 m .31758 .40528 L .3149 .39811 L p F P
0 g
s
.862 .594 .532 r
.27156 .28698 m .26607 .28424 L .26637 .27915 L p F P
0 g
s
.873 .606 .53 r
.26116 .27629 m .26637 .27915 L .26607 .28424 L p F P
0 g
s
.581 .615 .851 r
.65955 .25944 m .65116 .26036 L .64826 .25502 L p F P
0 g
s
.273 .034 .358 r
.72605 .45221 m .72278 .45437 L .71931 .4608 L p F P
0 g
s
.646 .781 .946 r
.63867 .50136 m .62715 .50493 L .62428 .50196 L p F P
0 g
s
.644 .544 .727 r
.4984 .42772 m .49908 .42985 L .48778 .43484 L p F P
0 g
s
.644 .544 .727 r
.48778 .43484 m .48633 .43042 L .4984 .42772 L p F P
0 g
s
.601 .639 .861 r
.64536 .24979 m .63374 .25166 L .63084 .24674 L p F P
0 g
s
.764 .651 .737 r
.30053 .43667 m .30854 .43841 L .30158 .44583 L p F P
0 g
s
.754 .636 .73 r
.30711 .42937 m .30053 .43667 L .30854 .43841 L p F P
0 g
s
.754 .636 .73 r
.31057 .43006 m .30711 .42937 L p .30854 .43841 L F P
0 g
s
.821 .624 .636 r
.28997 .32045 m .29054 .31892 L .28946 .31849 L closepath p F P
0 g
s
.64 .625 .819 r
.54922 .48988 m .56063 .48659 L .56364 .49232 L p F P
0 g
s
.638 .613 .809 r
.55793 .48118 m .56063 .48659 L .54922 .48988 L p F P
0 g
s
.638 .613 .809 r
.54922 .48988 m .54665 .48473 L .55793 .48118 L p F P
0 g
s
.645 .545 .726 r
.49602 .42031 m .4984 .42772 L .48633 .43042 L p F P
0 g
s
.645 .545 .726 r
.48633 .43042 m .48472 .42546 L .49602 .42031 L p F P
0 g
s
.644 .537 .718 r
.49348 .41198 m .49584 .41975 L .48378 .42245 L p F P
0 g
s
.644 .537 .718 r
.48576 .41366 m .49348 .41198 L p .48378 .42245 L F P
0 g
s
.642 .537 .719 r
.48472 .42546 m .48378 .42245 L .49584 .41975 L p F P
0 g
s
.758 .7 .797 r
.25589 .48672 m .25662 .48614 L .25518 .48569 L closepath p F P
0 g
s
.748 .695 .801 r
.25518 .48569 m .25589 .48672 L p .24136 .49016 L F P
0 g
s
.642 .537 .719 r
.49584 .41975 m .49602 .42031 L .48472 .42546 L p F P
0 g
s
.759 .699 .795 r
.26666 .47718 m .2671 .47789 L .25662 .48614 L p F P
0 g
s
.759 .699 .795 r
.26018 .47555 m .26666 .47718 L p .25662 .48614 L F P
0 g
s
.759 .699 .795 r
.25255 .48184 m .26018 .47555 L p .25662 .48614 L F P
0 g
s
.759 .699 .795 r
.25662 .48614 m .25518 .48569 L .25255 .48184 L p F P
0 g
s
.847 .603 .569 r
.27654 .29488 m .27076 .29225 L .27156 .28698 L p F P
0 g
s
.859 .614 .567 r
.26607 .28424 m .27156 .28698 L .27076 .29225 L p F P
0 g
s
.881 .733 .694 r
.0553 .37936 m .05933 .38257 L .05626 .38864 L p F P
0 g
s
.875 .737 .707 r
.05773 .37494 m .0553 .37936 L .05933 .38257 L p F P
0 g
s
.772 .634 .708 r
.30846 .40474 m .31665 .40645 L .311 .41344 L p F P
0 g
s
.759 .621 .707 r
.31373 .39787 m .30846 .40474 L .31665 .40645 L p F P
0 g
s
.759 .621 .707 r
.3149 .39811 m .31373 .39787 L p .31665 .40645 L F P
0 g
s
.812 .611 .63 r
.28946 .31849 m .28399 .31658 L .28605 .31084 L p F P
0 g
s
.824 .62 .628 r
.27969 .30843 m .28605 .31084 L .28399 .31658 L p F P
0 g
s
.818 .608 .618 r
.28136 .30284 m .27969 .30843 L .28605 .31084 L p F P
0 g
s
.903 .603 .468 r
.07567 .45422 m .07105 .45132 L .07083 .44627 L p F P
0 g
s
.906 .606 .465 r
.06629 .44333 m .07083 .44627 L .07105 .45132 L p F P
0 g
s
.903 .635 .522 r
.07083 .44627 m .06629 .44333 L .06662 .43811 L p F P
0 g
s
.368 .22 .545 r
.74291 .42418 m .73473 .43033 L .73519 .4358 L p F P
0 g
s
.396 .264 .582 r
.73473 .43033 m .74291 .42418 L .74086 .41942 L p F P
0 g
s
.385 .232 .547 r
.73493 .43598 m .73519 .4358 L .73473 .43033 L p F P
0 g
s
.641 .516 .695 r
.48717 .38949 m .48683 .38822 L .4825 .3905 L closepath p F P
0 g
s
.638 .511 .692 r
.48534 .38229 m .48683 .38822 L .4825 .3905 L p F P
0 g
s
.898 .559 .396 r
.08117 .46196 m .0765 .45909 L .07567 .45422 L p F P
0 g
s
.901 .561 .391 r
.07105 .45132 m .07567 .45422 L .0765 .45909 L p F P
0 g
s
.852 .756 .756 r
.06725 .35066 m .06338 .34735 L .06835 .34066 L p F P
0 g
s
.858 .754 .747 r
.06725 .35066 m .06629 .35202 L .06258 .34849 L p F P
0 g
s
.858 .754 .747 r
.06258 .34849 m .06338 .34735 L .06725 .35066 L p F P
0 g
s
.834 .607 .595 r
.28136 .30284 m .27528 .30032 L .27654 .29488 L p F P
0 g
s
.846 .618 .593 r
.27076 .29225 m .27654 .29488 L .27528 .30032 L p F P
0 g
s
.834 .62 .613 r
.27528 .30032 m .28136 .30284 L .27969 .30843 L p F P
0 g
s
.681 .904 .975 r
.57198 .24498 m .57324 .2456 L .58466 .24054 L p F P
0 g
s
.543 0 0 r
.10861 .48601 m .1091 .48639 L .10532 .48448 L p F P
0 g
s
.543 0 0 r
.10532 .48448 m .10369 .48326 L .10861 .48601 L p F P
0 g
s
.523 .518 .792 r
.717 .31632 m .71263 .31583 L .7101 .3096 L p F P
0 g
s
.766 .639 .721 r
.30925 .427 m .3133 .4222 L .30657 .42069 L closepath p F P
0 g
s
.766 .637 .719 r
.30609 .41956 m .311 .41344 L p .3133 .4222 L F P
0 g
s
.766 .637 .719 r
.3133 .4222 m .30657 .42069 L .30609 .41956 L p F P
0 g
s
.782 .625 .686 r
.30826 .37957 m .3115 .3744 L .30596 .37293 L closepath p F P
0 g
s
.782 .622 .682 r
.30517 .37057 m .30783 .36606 L p .3115 .3744 L F P
0 g
s
.782 .622 .682 r
.3115 .3744 m .30596 .37293 L .30517 .37057 L p F P
0 g
s
.609 .474 .672 r
.49221 .35829 m .49202 .35738 L .50333 .35309 L p F P
0 g
s
.606 .467 .666 r
.50231 .34815 m .50333 .35309 L .49202 .35738 L p F P
0 g
s
.907 .638 .52 r
.06216 .43513 m .06662 .43811 L .06629 .44333 L p F P
0 g
s
.901 .659 .563 r
.06662 .43811 m .06216 .43513 L .06299 .42975 L p F P
0 g
s
.56 .413 .638 r
.50982 .32483 m .50882 .3186 L .51465 .31623 L p F P
0 g
s
.436 .347 .656 r
.7409 .40547 m .74019 .40207 L .74253 .40414 L closepath p F P
0 g
s
.545 .555 .815 r
.68909 .28816 m .70094 .28837 L p .69554 .29465 L F P
0 g
s
.543 .555 .817 r
.69803 .28203 m .70094 .28837 L .68909 .28816 L p F P
0 g
s
.543 .555 .817 r
.69202 .28192 m .69803 .28203 L p .68909 .28816 L F P
0 g
s
.543 .555 .817 r
.68909 .28816 m .68815 .28611 L .69202 .28192 L p F P
0 g
s
.627 .502 .691 r
.48683 .38822 m .48534 .38229 L .49715 .37926 L p F P
0 g
s
.627 .501 .689 r
.49538 .37213 m .49715 .37926 L .48534 .38229 L p F P
0 g
s
.627 .501 .689 r
.4887 .37383 m .49538 .37213 L p .48534 .38229 L F P
0 g
s
.884 .499 .3 r
.08739 .46947 m .08268 .46662 L .08117 .46196 L p F P
0 g
s
.886 .498 .291 r
.0765 .45909 m .08117 .46196 L .08268 .46662 L p F P
0 g
s
.541 .544 .807 r
.69554 .29465 m .70385 .29499 L p .70377 .30152 L F P
0 g
s
.539 .545 .809 r
.70385 .29499 m .69554 .29465 L .70114 .28882 L closepath p F P
0 g
s
.545 .555 .815 r
.70094 .28837 m .70114 .28882 L .69554 .29465 L p F P
0 g
s
.758 .636 .726 r
.31057 .43006 m .30925 .427 L .30711 .42937 L closepath p F P
0 g
s
.861 .753 .742 r
.06279 .35717 m .06629 .35202 L .06258 .34849 L p F P
0 g
s
.808 .617 .643 r
.28946 .31849 m .28399 .31658 L p .28821 .32475 L F P
0 g
s
.808 .617 .643 r
.28821 .32475 m .28997 .32045 L .28946 .31849 L p F P
0 g
s
.641 .57 .759 r
.52231 .45865 m .52266 .45955 L .51132 .4636 L p F P
0 g
s
.641 .57 .759 r
.51132 .4636 m .51057 .46168 L .52231 .45865 L p F P
0 g
s
.587 .447 .657 r
.50098 .34153 m .50026 .33774 L .51159 .33487 L p F P
0 g
s
.585 .441 .651 r
.51091 .33118 m .51159 .33487 L .50026 .33774 L p F P
0 g
s
.61 .479 .677 r
.49377 .36518 m .49221 .35829 L .50371 .35487 L p F P
0 g
s
.609 .474 .672 r
.50333 .35309 m .50371 .35487 L .49221 .35829 L p F P
0 g
s
.764 .621 .702 r
.3149 .39811 m .31446 .39691 L .31373 .39787 L closepath p F P
0 g
s
.484 .442 .735 r
.73964 .35999 m .73447 .35822 L .73806 .35498 L closepath p F P
0 g
s
.493 .455 .743 r
.73657 .35045 m .73806 .35498 L .73447 .35822 L p F P
0 g
s
.493 .455 .743 r
.73269 .34931 m .73657 .35045 L p .73447 .35822 L F P
0 g
s
.748 .695 .801 r
.24136 .49016 m .24938 .48418 L .25518 .48569 L p F P
0 g
s
.747 .696 .803 r
.25518 .48569 m .25255 .48184 L .24938 .48418 L closepath p F P
0 g
s
.763 .62 .701 r
.31373 .39787 m .31446 .39691 L .31181 .38961 L p F P
0 g
s
.764 .651 .737 r
.29784 .43967 m .30053 .43667 L p .30158 .44583 L F P
0 g
s
.764 .651 .737 r
.30158 .44583 m .30066 .44562 L .29784 .43967 L p F P
0 g
s
.764 .652 .739 r
.30104 .44641 m .30158 .44583 L .30066 .44562 L closepath p F P
0 g
s
.805 .613 .642 r
.29132 .32578 m .28997 .32045 L .28821 .32475 L closepath p F P
0 g
s
.887 .585 .47 r
.26116 .27629 m .25777 .27429 L .25936 .27051 L p F P
0 g
s
.87 .561 .462 r
.25562 .26857 m .25936 .27051 L .25777 .27429 L p F P
0 g
s
.304 .661 .972 r
.13724 .49636 m .13671 .49608 L .12654 .49499 L p F P
0 g
s
.267 .662 .968 r
.13671 .49608 m .12654 .49499 L .12283 .49273 L p F P
0 g
s
.765 .663 .75 r
.30066 .44562 m .30104 .44641 L .29388 .45349 L p F P
0 g
s
.523 .365 .608 r
.51877 .30823 m .51807 .30236 L .52843 .29751 L p F P
0 g
s
.512 .344 .589 r
.52809 .29399 m .52843 .29751 L .51807 .30236 L p F P
0 g
s
.512 .344 .589 r
.52583 .29277 m .52809 .29399 L p .51807 .30236 L F P
0 g
s
.473 .294 .557 r
.52789 .29182 m .52759 .28642 L .53761 .28111 L p F P
0 g
s
.45 .252 .518 r
.53754 .27601 m .53761 .28111 L .52759 .28642 L p F P
0 g
s
.502 .316 .561 r
.52583 .29277 m .52789 .29182 L .52759 .28642 L p F P
0 g
s
.563 .582 .831 r
.66867 .27047 m .66876 .27038 L p .68129 .27585 L F P
0 g
s
.567 .591 .837 r
.66867 .27047 m .66863 .27039 L .66876 .27038 L closepath p F P
0 g
s
.753 .673 .774 r
.27922 .46967 m .27837 .4682 L .27719 .4692 L closepath p F P
0 g
s
.64 .593 .786 r
.54014 .47058 m .54182 .47435 L .53031 .47764 L p F P
0 g
s
.64 .593 .786 r
.53031 .47764 m .52876 .47418 L .54014 .47058 L p F P
0 g
s
.446 .369 .677 r
.74663 .38485 m .74056 .38998 L .74584 .3937 L p F P
0 g
s
.46 .39 .692 r
.74596 .38225 m .74663 .38485 L .74056 .38998 L p F P
0 g
s
.46 .39 .692 r
.74215 .38005 m .74596 .38225 L p .74056 .38998 L F P
0 g
s
.566 .594 .841 r
.66876 .27038 m .66863 .27039 L .66574 .26474 L p F P
0 g
s
.787 .625 .68 r
.30517 .37057 m .30783 .36606 L .3032 .36476 L closepath p F P
0 g
s
.788 .622 .676 r
.30209 .36134 m .30407 .35775 L p .30783 .36606 L F P
0 g
s
.788 .622 .676 r
.30783 .36606 m .3032 .36476 L .30209 .36134 L p F P
0 g
s
.642 .57 .759 r
.51961 .45164 m .52231 .45865 L .51057 .46168 L p F P
0 g
s
.642 .57 .759 r
.51057 .46168 m .50827 .45578 L .51961 .45164 L p F P
0 g
s
.749 .715 .82 r
.22684 .49334 m .22963 .49138 L .23621 .49355 L p F P
0 g
s
.738 .706 .821 r
.23799 .48561 m .22963 .49138 L .23621 .49355 L p F P
0 g
s
.738 .706 .821 r
.23621 .49355 m .24136 .49016 L .23799 .48561 L p F P
0 g
s
0 .3 .673 r
.11505 .48915 m .1091 .48639 L .10532 .48448 L p F P
0 g
s
0 .319 .706 r
.12013 .49184 m .11505 .48915 L .1091 .48639 L p F P
0 g
s
.611 .75 .944 r
.15832 .50317 m .169 .50067 L .17257 .50375 L p F P
0 g
s
.628 .75 .935 r
.169 .50067 m .15832 .50317 L .1547 .50036 L p F P
0 g
s
.563 .582 .831 r
.66876 .27038 m .68039 .26986 L p .68129 .27585 L F P
0 g
s
.563 .587 .836 r
.66876 .27038 m .68039 .26986 L .67749 .264 L p F P
0 g
s
.563 .587 .836 r
.67749 .264 m .67438 .26416 L .66876 .27038 L p F P
0 g
s
.566 .594 .841 r
.66574 .26474 m .67438 .26416 L .66876 .27038 L p F P
0 g
s
.905 .664 .564 r
.0586 .42673 m .06299 .42975 L .06216 .43513 L p F P
0 g
s
.899 .679 .596 r
.06299 .42975 m .0586 .42673 L .0599 .42122 L p F P
0 g
s
.738 .72 .835 r
.22684 .49334 m .21578 .50001 L .21233 .4961 L p F P
0 g
s
.763 .62 .701 r
.31063 .38935 m .30571 .3961 L .31373 .39787 L p F P
0 g
s
.763 .62 .701 r
.31181 .38961 m .31063 .38935 L p .31373 .39787 L F P
0 g
s
.775 .632 .703 r
.30571 .3961 m .31373 .39787 L .30846 .40474 L p F P
0 g
s
.845 .762 .771 r
.07352 .3339 m .07447 .33273 L .07076 .3293 L p F P
0 g
s
.759 .649 .74 r
.30066 .44562 m .29784 .43967 L .29354 .4441 L closepath p F P
0 g
s
.765 .663 .75 r
.29354 .4441 m .30066 .44562 L p .29388 .45349 L F P
0 g
s
.762 .688 .78 r
.2671 .47789 m .26761 .47745 L .26666 .47718 L closepath p F P
0 g
s
.884 .725 .68 r
.05762 .39777 m .05349 .39461 L .05626 .38864 L p F P
0 g
s
.89 .719 .665 r
.05349 .39461 m .05762 .39777 L .05518 .40364 L p F P
0 g
s
.638 .657 .852 r
.59251 .49634 m .58104 .49942 L .57806 .49448 L p F P
0 g
s
.763 .687 .779 r
.26964 .46733 m .27719 .4692 L .26761 .47745 L p F P
0 g
s
.763 .687 .779 r
.2638 .4726 m .26964 .46733 L p .26761 .47745 L F P
0 g
s
.763 .687 .779 r
.26761 .47745 m .26666 .47718 L .2638 .4726 L p F P
0 g
s
.853 .413 .164 r
.08739 .46947 m .08829 .47131 L .08441 .46999 L p F P
0 g
s
.853 .413 .164 r
.08441 .46999 m .08268 .46662 L .08739 .46947 L p F P
0 g
s
.626 .496 .684 r
.49538 .37213 m .49507 .37086 L .4887 .37383 L closepath p F P
0 g
s
.623 .49 .679 r
.49377 .36518 m .49507 .37086 L .4887 .37383 L p F P
0 g
s
.643 .533 .714 r
.49348 .41198 m .49295 .41022 L .48576 .41366 L closepath p F P
0 g
s
.641 .528 .71 r
.49127 .40436 m .49295 .41022 L .48576 .41366 L p F P
0 g
s
.757 .635 .725 r
.30711 .42937 m .30925 .427 L .30657 .42069 L p F P
0 g
s
.619 .681 .886 r
.62693 .24215 m .61637 .24451 L .61346 .24017 L p F P
0 g
s
.765 .664 .752 r
.28969 .45768 m .29388 .45349 L .2865 .45162 L closepath p F P
0 g
s
.765 .663 .75 r
.28645 .45152 m .29354 .4441 L p .29388 .45349 L F P
0 g
s
.765 .663 .75 r
.29388 .45349 m .2865 .45162 L .28645 .45152 L p F P
0 g
s
.55 .566 .824 r
.68815 .28611 m .68619 .28193 L .69202 .28192 L closepath p F P
0 g
s
.851 .761 .763 r
.06976 .33053 m .07352 .3339 L .06835 .34066 L p F P
0 g
s
.845 .762 .771 r
.07076 .3293 m .06976 .33053 L .07352 .3339 L p F P
0 g
s
.746 .763 .866 r
.17403 .24452 m .16487 .25019 L .1613 .24666 L p F P
0 g
s
.506 .904 .784 r
.69115 .48532 m .69268 .48446 L p .67958 .49128 L F P
0 g
s
0 0 0 r
.69115 .48532 m .69268 .48446 L .69294 .48423 L closepath p F P
0 g
s
.485 0 0 r
.23644 .25028 m .23721 .25098 L .24163 .25415 L p F P
0 g
s
.81 .325 .03 r
.24908 .2612 m .2443 .25817 L .24163 .25415 L p F P
0 g
s
.822 .344 .033 r
.23721 .25098 m .24163 .25415 L .2443 .25817 L p F P
0 g
s
.793 .626 .674 r
.30209 .36134 m .30407 .35775 L .30056 .35669 L closepath p F P
0 g
s
.794 .623 .669 r
.29902 .35184 m .30025 .34945 L p .30407 .35775 L F P
0 g
s
.794 .623 .669 r
.30407 .35775 m .30056 .35669 L .29902 .35184 L p F P
0 g
s
.768 .621 .696 r
.31181 .38961 m .31136 .38834 L .31063 .38935 L closepath p F P
0 g
s
.629 .509 .697 r
.48717 .38949 m .48683 .38822 L .49814 .38321 L p F P
0 g
s
.627 .502 .691 r
.49715 .37926 m .49814 .38321 L .48683 .38822 L p F P
0 g
s
.768 .62 .696 r
.31063 .38935 m .31136 .38834 L .30883 .38121 L p F P
0 g
s
.754 .661 .758 r
.28581 .46126 m .28969 .45768 L .2865 .45162 L p F P
0 g
s
.802 .617 .652 r
.29132 .32578 m .28821 .32475 L p .29236 .33294 L F P
0 g
s
.802 .617 .652 r
.29236 .33294 m .29295 .33163 L .29132 .32578 L p F P
0 g
s
.763 .667 .756 r
.28581 .46126 m .27837 .4682 L .2751 .46247 L p F P
0 g
s
.763 .667 .756 r
.2751 .46247 m .27829 .45937 L .28581 .46126 L p F P
0 g
s
.754 .661 .758 r
.28637 .45159 m .27829 .45937 L .28581 .46126 L p F P
0 g
s
.754 .661 .758 r
.2865 .45162 m .28637 .45159 L p .28581 .46126 L F P
0 g
s
.419 .319 .635 r
.74253 .40414 m .7409 .40547 L .74206 .41175 L p F P
0 g
s
.771 .635 .71 r
.311 .41344 m .30609 .41956 L .30294 .41198 L p F P
0 g
s
.771 .635 .71 r
.30294 .41198 m .30324 .41159 L .311 .41344 L p F P
0 g
s
.772 .634 .708 r
.311 .41344 m .30324 .41159 L .30846 .40474 L p F P
0 g
s
.768 .651 .732 r
.29912 .42761 m .30711 .42937 L .30053 .43667 L p F P
0 g
s
.757 .635 .725 r
.30534 .42043 m .29912 .42761 L .30711 .42937 L p F P
0 g
s
.757 .635 .725 r
.30657 .42069 m .30534 .42043 L p .30711 .42937 L F P
0 g
s
.753 .684 .785 r
.26666 .47718 m .2638 .4726 L .26018 .47555 L closepath p F P
0 g
s
.752 .671 .772 r
.2751 .46247 m .26964 .46733 L .27719 .4692 L p F P
0 g
s
.752 .671 .772 r
.27719 .4692 m .27837 .4682 L .2751 .46247 L p F P
0 g
s
.63 .511 .7 r
.48916 .39686 m .48717 .38949 L .499 .38648 L p F P
0 g
s
.629 .509 .697 r
.49814 .38321 m .499 .38648 L .48717 .38949 L p F P
0 g
s
0 0 0 r
.70446 .47615 m .70437 .47631 L .69294 .48423 L p F P
0 g
s
0 0 0 r
.69268 .48446 m .69294 .48423 L .70437 .47631 L p F P
0 g
s
.589 .453 .663 r
.50231 .34815 m .50098 .34153 L .51212 .33767 L p F P
0 g
s
.587 .447 .657 r
.51159 .33487 m .51212 .33767 L .50098 .34153 L p F P
0 g
s
.53 .75 .976 r
.14835 .50095 m .1547 .50036 L .15108 .49746 L p F P
0 g
s
.53 .75 .976 r
.15108 .49746 m .1426 .4985 L .14835 .50095 L p F P
0 g
s
.459 .739 .988 r
.14052 .49868 m .1426 .4985 L .14835 .50095 L p F P
0 g
s
.779 .632 .697 r
.30279 .38751 m .31063 .38935 L .30571 .3961 L p F P
0 g
s
.768 .62 .696 r
.30737 .38088 m .30279 .38751 L .31063 .38935 L p F P
0 g
s
.768 .62 .696 r
.30883 .38121 m .30737 .38088 L p .31063 .38935 L F P
0 g
s
.902 .684 .598 r
.05559 .41816 m .0599 .42122 L .0586 .42673 L p F P
0 g
s
.896 .695 .623 r
.0599 .42122 m .05559 .41816 L .05731 .41251 L p F P
0 g
s
.523 .518 .792 r
.7101 .3096 m .71094 .30874 L p .717 .31632 L F P
0 g
s
.528 .529 .8 r
.7101 .3096 m .70969 .30863 L .71094 .30874 L closepath p F P
0 g
s
.799 .626 .667 r
.29902 .35184 m .30025 .34945 L .29803 .34874 L closepath p F P
0 g
s
.8 .623 .662 r
.29597 .34201 m .29637 .34118 L p .30025 .34945 L F P
0 g
s
.8 .623 .662 r
.30025 .34945 m .29803 .34874 L .29597 .34201 L p F P
0 g
s
.699 .741 .884 r
.18692 .50328 m .19784 .49837 L .20133 .50198 L p F P
0 g
s
.731 .742 .86 r
.20449 .50028 m .20133 .50198 L .19784 .49837 L p F P
0 g
s
.639 .561 .751 r
.51892 .44978 m .51961 .45164 L .50827 .45578 L p F P
0 g
s
.639 .561 .751 r
.50827 .45578 m .50716 .45281 L .51892 .44978 L p F P
0 g
s
.638 .584 .777 r
.53759 .46459 m .54014 .47058 L .52876 .47418 L p F P
0 g
s
.638 .584 .777 r
.52876 .47418 m .52607 .46789 L .53759 .46459 L p F P
0 g
s
.756 .7 .799 r
.24938 .48418 m .24136 .49016 L .23799 .48561 L p F P
0 g
s
.677 .747 .904 r
.18339 .49992 m .17257 .50375 L .169 .50067 L p F P
0 g
s
.667 .748 .911 r
.17257 .50375 m .18339 .49992 L .18692 .50328 L p F P
0 g
s
.534 .534 .801 r
.70677 .30171 m .70377 .30152 L .70581 .29946 L closepath p F P
0 g
s
.541 .544 .807 r
.70385 .29499 m .70581 .29946 L .70377 .30152 L p F P
0 g
s
.772 .62 .69 r
.30883 .38121 m .30826 .37957 L .30737 .38088 L closepath p F P
0 g
s
.799 .614 .651 r
.29339 .33326 m .29295 .33163 L .29236 .33294 L closepath p F P
0 g
s
.491 .456 .746 r
.73657 .35045 m .73269 .34931 L .73538 .34683 L closepath p F P
0 g
s
.5 .469 .754 r
.73354 .34153 m .73538 .34683 L .73269 .34931 L p F P
0 g
s
.5 .469 .754 r
.73006 .34067 m .73354 .34153 L p .73269 .34931 L F P
0 g
s
.772 .62 .69 r
.30737 .38088 m .30826 .37957 L .30596 .37293 L p F P
0 g
s
.638 .638 .834 r
.56388 .49275 m .56364 .49232 L .57071 .49039 L closepath p F P
0 g
s
.528 .53 .801 r
.71094 .30874 m .70969 .30863 L .70677 .30171 L p F P
0 g
s
.875 .742 .712 r
.05873 .37318 m .05773 .37494 L .05402 .37122 L p F P
0 g
s
.875 .742 .712 r
.05402 .37122 m .05476 .36993 L .05873 .37318 L p F P
0 g
s
.868 .745 .725 r
.05873 .37318 m .05476 .36993 L .05865 .36359 L p F P
0 g
s
.611 .481 .679 r
.49507 .37086 m .49377 .36518 L .50527 .36176 L p F P
0 g
s
.61 .479 .677 r
.50371 .35487 m .50527 .36176 L .49377 .36518 L p F P
0 g
s
.638 .613 .808 r
.55762 .48054 m .55793 .48118 L .54665 .48473 L p F P
0 g
s
.638 .613 .808 r
.54665 .48473 m .5462 .48383 L .55762 .48054 L p F P
0 g
s
.807 .623 .654 r
.29637 .34118 m .29563 .34093 L .29339 .33326 L p F P
0 g
s
.798 .619 .659 r
.29236 .33294 m .29339 .33326 L .29563 .34093 L p F P
0 g
s
.866 .751 .734 r
.05893 .35387 m .06279 .35717 L .05865 .36359 L p F P
0 g
s
.861 .753 .742 r
.06258 .34849 m .05893 .35387 L .06279 .35717 L p F P
0 g
s
.126 0 .186 r
.71931 .4608 m .72559 .45664 L p .71536 .46681 L F P
0 g
s
.126 0 .186 r
.71536 .46681 m .71566 .4656 L .71931 .4608 L p F P
0 g
s
.273 .034 .358 r
.71931 .4608 m .72559 .45664 L .72605 .45221 L p F P
0 g
s
.707 .738 .875 r
.19784 .49837 m .18692 .50328 L .18339 .49992 L p F P
0 g
s
.64 .561 .75 r
.51655 .44334 m .51892 .44978 L .50716 .45281 L p F P
0 g
s
.64 .561 .75 r
.50716 .45281 m .50521 .44756 L .51655 .44334 L p F P
0 g
s
.805 .627 .661 r
.29597 .34201 m .29637 .34118 L .29563 .34093 L closepath p F P
0 g
s
.187 0 .239 r
.54767 .26394 m .55088 .25963 L .54826 .26145 L closepath p F P
0 g
s
0 0 0 r
.55897 .25234 m .55919 .25212 L p .54826 .26145 L F P
0 g
s
0 0 0 r
.54826 .26145 m .55088 .25963 L .55897 .25234 L p F P
0 g
s
.636 .623 .82 r
.57071 .49039 m .56364 .49232 L .56063 .48659 L p F P
0 g
s
.574 .935 .924 r
.67958 .49128 m .67884 .49133 L .6673 .49636 L p F P
0 g
s
.583 .926 .957 r
.67884 .49133 m .6673 .49636 L .66459 .49542 L p F P
0 g
s
.657 .903 .981 r
.6673 .49636 m .66459 .49542 L p .65343 .49989 L F P
0 g
s
.629 .512 .701 r
.48989 .39954 m .48916 .39686 L .50096 .39382 L p F P
0 g
s
.63 .511 .7 r
.499 .38648 m .50096 .39382 L .48916 .39686 L p F P
0 g
s
.772 .62 .69 r
.30596 .37293 m .30397 .37244 L p .30737 .38088 L F P
0 g
s
.777 .62 .685 r
.30596 .37293 m .30517 .37057 L .30397 .37244 L closepath p F P
0 g
s
.695 .152 0 r
.10369 .48326 m .09881 .48049 L .09491 .47656 L p F P
0 g
s
.678 .131 0 r
.08999 .47379 m .09491 .47656 L .09881 .48049 L p F P
0 g
s
.818 .349 .099 r
.08829 .47131 m .08999 .47379 L .09491 .47656 L p F P
0 g
s
.784 .631 .692 r
.29972 .37897 m .30737 .38088 L .30279 .38751 L p F P
0 g
s
.772 .62 .69 r
.30397 .37244 m .29972 .37897 L .30737 .38088 L p F P
0 g
s
.768 .652 .734 r
.29784 .43967 m .30053 .43667 L .29589 .43553 L closepath p F P
0 g
s
.768 .651 .732 r
.29464 .43284 m .29912 .42761 L p .30053 .43667 L F P
0 g
s
.768 .651 .732 r
.30053 .43667 m .29589 .43553 L .29464 .43284 L p F P
0 g
s
.777 .62 .685 r
.30397 .37244 m .30517 .37057 L .3032 .36476 L p F P
0 g
s
.027 .469 .877 r
.22585 .2453 m .2329 .24768 L .23255 .24741 L p F P
0 g
s
.027 .469 .877 r
.22172 .242 m .22585 .2453 L p .23255 .24741 L F P
0 g
s
.388 .649 .961 r
.21898 .2417 m .22172 .242 L .22585 .2453 L p F P
0 g
s
.635 .601 .797 r
.55762 .48054 m .5462 .48383 L .54318 .47738 L p F P
0 g
s
.762 .636 .721 r
.30657 .42069 m .30609 .41956 L .30534 .42043 L closepath p F P
0 g
s
.775 .638 .71 r
.30082 .40284 m .30846 .40474 L .30324 .41159 L p F P
0 g
s
.775 .632 .703 r
.30846 .40474 m .30082 .40284 L .30571 .3961 L p F P
0 g
s
0 0 0 r
.70437 .47631 m .70235 .47877 L .69268 .48446 L p F P
0 g
s
.39 .819 .652 r
.69038 .48564 m .69268 .48446 L .70235 .47877 L p F P
0 g
s
.506 .904 .784 r
.69268 .48446 m .69038 .48564 L p .67958 .49128 L F P
0 g
s
.872 .494 .326 r
.25562 .26857 m .25049 .26567 L .24908 .2612 L p F P
0 g
s
.884 .508 .322 r
.2443 .25817 m .24908 .2612 L .25049 .26567 L p F P
0 g
s
.794 .621 .667 r
.29563 .34093 m .28943 .33899 L p .29318 .34732 L F P
0 g
s
.794 .621 .667 r
.29318 .34732 m .29597 .34201 L .29563 .34093 L p F P
0 g
s
.798 .619 .659 r
.29563 .34093 m .28943 .33899 L .29236 .33294 L p F P
0 g
s
.809 .627 .656 r
.2856 .33068 m .29236 .33294 L .28943 .33899 L p F P
0 g
s
.802 .617 .652 r
.28821 .32475 m .2856 .33068 L .29236 .33294 L p F P
0 g
s
.792 .619 .666 r
.29803 .34874 m .29597 .34201 L .29318 .34732 L closepath p F P
0 g
s
.632 .519 .708 r
.49127 .40436 m .48989 .39954 L .50121 .39474 L p F P
0 g
s
.629 .512 .701 r
.50096 .39382 m .50121 .39474 L .48989 .39954 L p F P
0 g
s
.777 .62 .685 r
.3032 .36476 m .30047 .36404 L p .30397 .37244 L F P
0 g
s
.782 .619 .679 r
.3032 .36476 m .30209 .36134 L .30047 .36404 L closepath p F P
0 g
s
.642 .703 .89 r
.59546 .50084 m .60696 .49774 L .60987 .50172 L p F P
0 g
s
.64 .675 .868 r
.6054 .49542 m .60696 .49774 L .59546 .50084 L p F P
0 g
s
.64 .675 .868 r
.59546 .50084 m .59465 .49962 L .6054 .49542 L p F P
0 g
s
.731 .742 .86 r
.19784 .49837 m .19875 .49784 L .20449 .50028 L p F P
0 g
s
.719 .728 .858 r
.20887 .49213 m .19875 .49784 L .20449 .50028 L p F P
0 g
s
.719 .728 .858 r
.20449 .50028 m .21233 .4961 L .20887 .49213 L p F P
0 g
s
.783 .62 .679 r
.30047 .36404 m .30209 .36134 L .30056 .35669 L p F P
0 g
s
.761 .635 .72 r
.30534 .42043 m .30609 .41956 L .30294 .41198 L p F P
0 g
s
.887 .729 .681 r
.05222 .38543 m .05626 .38864 L .05349 .39461 L p F P
0 g
s
.881 .733 .694 r
.05626 .38864 m .05222 .38543 L .0553 .37936 L p F P
0 g
s
.878 .741 .707 r
.0553 .37936 m .05773 .37494 L .05402 .37122 L p F P
0 g
s
.564 .421 .645 r
.51091 .33118 m .50982 .32483 L .5206 .32051 L p F P
0 g
s
.56 .413 .638 r
.51985 .31591 m .5206 .32051 L .50982 .32483 L p F P
0 g
s
.56 .413 .638 r
.51465 .31623 m .51985 .31591 L p .50982 .32483 L F P
0 g
s
.787 .619 .673 r
.30056 .35669 m .29902 .35184 L .29687 .35567 L closepath p F P
0 g
s
.788 .621 .673 r
.29687 .35567 m .29902 .35184 L .29803 .34874 L p F P
0 g
s
.788 .621 .673 r
.29803 .34874 m .29318 .34732 L p .29687 .35567 L F P
0 g
s
.638 .553 .743 r
.51579 .44119 m .51655 .44334 L .50521 .44756 L p F P
0 g
s
.638 .553 .743 r
.50521 .44756 m .50402 .44422 L .51579 .44119 L p F P
0 g
s
.898 .7 .627 r
.05309 .4094 m .05731 .41251 L .05559 .41816 L p F P
0 g
s
.893 .708 .646 r
.05731 .41251 m .05309 .4094 L .05518 .40364 L p F P
0 g
s
.783 .62 .679 r
.30056 .35669 m .29687 .35567 L p .30047 .36404 L F P
0 g
s
.759 .648 .739 r
.29354 .4441 m .29784 .43967 L .29589 .43553 L p F P
0 g
s
.817 .629 .648 r
.28171 .32239 m .28821 .32475 L .2856 .33068 L p F P
0 g
s
.808 .617 .643 r
.28399 .31658 m .28171 .32239 L .28821 .32475 L p F P
0 g
s
.761 .635 .72 r
.30294 .41198 m .29741 .41864 L .30534 .42043 L p F P
0 g
s
.774 .647 .722 r
.29741 .41864 m .30534 .42043 L .29912 .42761 L p F P
0 g
s
.719 .959 .946 r
.57034 .2446 m .57686 .24081 L .57198 .24498 L closepath p F P
0 g
s
.681 .904 .975 r
.58175 .23829 m .57686 .24081 L .57198 .24498 L p F P
0 g
s
.681 .904 .975 r
.58466 .24054 m .58175 .23829 L p .57198 .24498 L F P
0 g
s
.503 .905 .798 r
.57198 .24498 m .57034 .2446 L p .55919 .25212 L F P
0 g
s
.497 .47 .757 r
.73354 .34153 m .73006 .34067 L .73246 .3384 L closepath p F P
0 g
s
.506 .482 .764 r
.73055 .33311 m .73246 .3384 L .73006 .34067 L p F P
0 g
s
.506 .482 .764 r
.72656 .33228 m .73055 .33311 L p .73006 .34067 L F P
0 g
s
.854 .76 .758 r
.06457 .3373 m .06835 .34066 L .06338 .34735 L p F P
0 g
s
.851 .761 .763 r
.06835 .34066 m .06457 .3373 L .06976 .33053 L p F P
0 g
s
.584 .731 .944 r
.20475 .24041 m .21546 .23834 L .21898 .2417 L p F P
0 g
s
.579 .727 .944 r
.21546 .23834 m .20475 .24041 L .20123 .23689 L p F P
0 g
s
.679 .751 .905 r
.19037 .24124 m .20123 .23689 L .20475 .24041 L p F P
0 g
s
.756 .7 .799 r
.23799 .48561 m .24246 .48211 L .24938 .48418 L p F P
0 g
s
.747 .694 .802 r
.24921 .4769 m .24246 .48211 L .24938 .48418 L p F P
0 g
s
.747 .694 .802 r
.24938 .48418 m .25255 .48184 L .24921 .4769 L p F P
0 g
s
.678 .75 .905 r
.20123 .23689 m .19037 .24124 L .18683 .23769 L p F P
0 g
s
.719 .757 .883 r
.17589 .24338 m .18683 .23769 L .19037 .24124 L p F P
0 g
s
.523 .518 .792 r
.71094 .30874 m .72166 .30996 L p .717 .31632 L F P
0 g
s
.52 .519 .795 r
.71094 .30874 m .72166 .30996 L .71872 .30281 L p F P
0 g
s
.52 .519 .795 r
.71872 .30281 m .71677 .30259 L .71094 .30874 L p F P
0 g
s
.528 .53 .801 r
.70677 .30171 m .71677 .30259 L .71094 .30874 L p F P
0 g
s
.55 .567 .825 r
.69202 .28192 m .68619 .28193 L .68329 .27579 L p F P
0 g
s
.516 .345 .588 r
.52809 .29399 m .52583 .29277 L .52789 .29182 L closepath p F P
0 g
s
0 0 0 r
.70437 .47631 m .70496 .47585 L .70446 .47615 L closepath p F P
0 g
s
.1 0 .067 r
.70446 .47615 m .70496 .47585 L .71367 .46787 L p F P
0 g
s
.252 .018 .352 r
.73306 .44732 m .72605 .45221 L .72559 .45664 L p F P
0 g
s
.312 .111 .439 r
.72605 .45221 m .73306 .44732 L .7347 .44144 L p F P
0 g
s
.631 .52 .709 r
.49295 .41022 m .49127 .40436 L .50308 .40134 L p F P
0 g
s
.632 .519 .708 r
.50121 .39474 m .50308 .40134 L .49127 .40436 L p F P
0 g
s
.638 .553 .742 r
.51348 .43461 m .51579 .44119 L .50402 .44422 L p F P
0 g
s
.638 .553 .742 r
.50402 .44422 m .50215 .43892 L .51348 .43461 L p F P
0 g
s
.789 .632 .687 r
.29653 .37046 m .30397 .37244 L .29972 .37897 L p F P
0 g
s
.777 .62 .685 r
.30047 .36404 m .29653 .37046 L .30397 .37244 L p F P
0 g
s
.581 .615 .851 r
.64826 .25502 m .65994 .25368 L p .65955 .25944 L F P
0 g
s
.583 .619 .854 r
.65705 .24836 m .65994 .25368 L .64826 .25502 L p F P
0 g
s
.583 .619 .854 r
.64698 .24957 m .65705 .24836 L p .64826 .25502 L F P
0 g
s
.583 .619 .854 r
.64826 .25502 m .64592 .25078 L .64698 .24957 L p F P
0 g
s
.826 .63 .638 r
.27774 .31413 m .28399 .31658 L .28171 .32239 L p F P
0 g
s
.824 .62 .628 r
.28399 .31658 m .27774 .31413 L .27969 .30843 L p F P
0 g
s
.19 0 .21 r
.71367 .46787 m .71536 .46681 L .71566 .4656 L closepath p F P
0 g
s
.768 .655 .738 r
.29354 .4441 m .28645 .45152 L .28322 .44521 L p F P
0 g
s
.768 .655 .738 r
.28322 .44521 m .28597 .44222 L .29354 .4441 L p F P
0 g
s
.759 .648 .739 r
.29279 .43483 m .28597 .44222 L .29354 .4441 L p F P
0 g
s
.759 .648 .739 r
.29589 .43553 m .29279 .43483 L p .29354 .4441 L F P
0 g
s
.807 .325 .053 r
.08999 .47379 m .08829 .47131 L .08441 .46999 L p F P
0 g
s
.613 .488 .686 r
.49538 .37213 m .49507 .37086 L .5064 .36669 L p F P
0 g
s
.611 .481 .679 r
.50527 .36176 m .5064 .36669 L .49507 .37086 L p F P
0 g
s
.645 .883 .984 r
.65303 .49967 m .6565 .49841 L .65343 .49989 L closepath p F P
0 g
s
.657 .903 .981 r
.66459 .49542 m .6565 .49841 L .65343 .49989 L p F P
0 g
s
.87 .561 .462 r
.25777 .27429 m .25605 .2734 L .25562 .26857 L p F P
0 g
s
.88 .571 .459 r
.25049 .26567 m .25562 .26857 L .25605 .2734 L p F P
0 g
s
.419 .319 .635 r
.74206 .41175 m .74621 .40838 L .74253 .40414 L p F P
0 g
s
.417 .318 .636 r
.74965 .39827 m .74253 .40414 L .74621 .40838 L p F P
0 g
s
.435 .347 .657 r
.74933 .39676 m .74965 .39827 L .74253 .40414 L p F P
0 g
s
.435 .347 .657 r
.74584 .3937 m .74933 .39676 L p .74253 .40414 L F P
0 g
s
.835 .63 .626 r
.2737 .30588 m .27969 .30843 L .27774 .31413 L p F P
0 g
s
.834 .62 .613 r
.27969 .30843 m .2737 .30588 L .27528 .30032 L p F P
0 g
s
.762 .689 .781 r
.26018 .47555 m .25255 .48184 L .24921 .4769 L p F P
0 g
s
.024 .508 .876 r
.12013 .49184 m .12283 .49273 L .11911 .49035 L p F P
0 g
s
.024 .508 .876 r
.11911 .49035 m .11505 .48915 L .12013 .49184 L p F P
0 g
s
0 0 0 r
.70235 .47877 m .70437 .47631 L .70496 .47585 L p F P
0 g
s
.638 .583 .777 r
.53709 .46343 m .53759 .46459 L .52607 .46789 L p F P
0 g
s
.638 .583 .777 r
.52607 .46789 m .52572 .46706 L .53709 .46343 L p F P
0 g
s
.351 .177 .5 r
.73519 .4358 m .73493 .43598 L .7347 .44144 L p F P
0 g
s
.779 .632 .697 r
.30571 .3961 m .29822 .39415 L .30279 .38751 L p F P
0 g
s
.78 .638 .705 r
.29822 .39415 m .30571 .3961 L .30082 .40284 L p F P
0 g
s
0 0 0 r
.70496 .47585 m .71398 .47021 L p .70235 .47877 L F P
0 g
s
.073 0 .039 r
.71536 .46681 m .71367 .46787 L .70496 .47585 L p F P
0 g
s
.073 0 .039 r
.70496 .47585 m .71398 .47021 L .71536 .46681 L p F P
0 g
s
.504 .483 .767 r
.73055 .33311 m .72656 .33228 L .72929 .32964 L closepath p F P
0 g
s
.512 .494 .774 r
.72757 .3251 m .72929 .32964 L .72656 .33228 L p F P
0 g
s
.512 .494 .774 r
.7222 .32417 m .72757 .3251 L p .72656 .33228 L F P
0 g
s
.636 .545 .734 r
.51289 .43284 m .51348 .43461 L .50215 .43892 L p F P
0 g
s
.636 .545 .734 r
.50215 .43892 m .50111 .43587 L .51289 .43284 L p F P
0 g
s
.631 .52 .709 r
.50308 .40134 m .50428 .40553 L .49295 .41022 L p F P
0 g
s
.633 .527 .716 r
.49348 .41198 m .49295 .41022 L .50428 .40553 L p F P
0 g
s
.517 .506 .783 r
.717 .31632 m .72461 .3174 L p .7222 .32417 L F P
0 g
s
.515 .508 .786 r
.72461 .3174 m .717 .31632 L .72212 .31109 L closepath p F P
0 g
s
.523 .518 .792 r
.72166 .30996 m .72212 .31109 L .717 .31632 L p F P
0 g
s
.601 .639 .861 r
.63084 .24674 m .64246 .24477 L .64536 .24979 L p F P
0 g
s
.604 .645 .864 r
.64246 .24477 m .63084 .24674 L .62793 .24194 L p F P
0 g
s
.614 .491 .689 r
.49715 .37926 m .49538 .37213 L .50689 .36873 L p F P
0 g
s
.613 .488 .686 r
.5064 .36669 m .50689 .36873 L .49538 .37213 L p F P
0 g
s
.746 .763 .866 r
.1613 .24666 m .17041 .24102 L .17403 .24452 L p F P
0 g
s
.745 .763 .867 r
.17232 .23984 m .17041 .24102 L .17403 .24452 L p F P
0 g
s
.745 .763 .867 r
.17403 .24452 m .17589 .24338 L .17232 .23984 L p F P
0 g
s
.846 .63 .61 r
.26955 .29767 m .27528 .30032 L .2737 .30588 L p F P
0 g
s
.846 .618 .593 r
.27528 .30032 m .26955 .29767 L .27076 .29225 L p F P
0 g
s
.632 .527 .717 r
.49348 .41198 m .5053 .40897 L p .50033 .41859 L F P
0 g
s
.632 .527 .717 r
.50033 .41859 m .49584 .41975 L .49348 .41198 L p F P
0 g
s
.633 .527 .716 r
.50428 .40553 m .5053 .40897 L .49348 .41198 L p F P
0 g
s
.589 .453 .663 r
.51212 .33767 m .51347 .34431 L .50231 .34815 L p F P
0 g
s
.591 .457 .667 r
.50333 .35309 m .50231 .34815 L .51347 .34431 L p F P
0 g
s
.457 .39 .694 r
.74596 .38225 m .74215 .38005 L .7448 .37777 L closepath p F P
0 g
s
.468 .408 .708 r
.74215 .38005 m .7448 .37777 L .74278 .37045 L p F P
0 g
s
.637 .545 .734 r
.51041 .42544 m .51289 .43284 L .50111 .43587 L p F P
0 g
s
.637 .545 .734 r
.50111 .43587 m .49908 .42985 L .51041 .42544 L p F P
0 g
s
.56 .41 .634 r
.51985 .31591 m .51465 .31623 L .51959 .31426 L closepath p F P
0 g
s
.554 .395 .621 r
.51877 .30823 m .51959 .31426 L .51465 .31623 L p F P
0 g
s
.757 .72 .818 r
.22963 .49138 m .22684 .49334 L .22342 .48911 L p F P
0 g
s
.738 .72 .835 r
.21233 .4961 m .22342 .48911 L .22684 .49334 L p F P
0 g
s
.635 .573 .768 r
.53709 .46343 m .52572 .46706 L .52266 .45955 L p F P
0 g
s
.532 .381 .621 r
.51959 .31426 m .51877 .30823 L .52917 .30343 L p F P
0 g
s
.523 .365 .608 r
.52843 .29751 m .52917 .30343 L .51877 .30823 L p F P
0 g
s
.51 .495 .777 r
.72757 .3251 m .7222 .32417 L .72585 .32055 L closepath p F P
0 g
s
.517 .506 .783 r
.72461 .3174 m .72585 .32055 L .7222 .32417 L p F P
0 g
s
.794 .632 .681 r
.29323 .36198 m .30047 .36404 L .29653 .37046 L p F P
0 g
s
.783 .62 .679 r
.29687 .35567 m .29323 .36198 L .30047 .36404 L p F P
0 g
s
.857 .629 .591 r
.26528 .2895 m .27076 .29225 L .26955 .29767 L p F P
0 g
s
.859 .614 .567 r
.27076 .29225 m .26528 .2895 L .26607 .28424 L p F P
0 g
s
.873 .606 .53 r
.26607 .28424 m .26085 .28139 L .26116 .27629 L p F P
0 g
s
.883 .615 .528 r
.25777 .27429 m .26116 .27629 L .26085 .28139 L p F P
0 g
s
.638 .674 .868 r
.60402 .49335 m .6054 .49542 L .59465 .49962 L p F P
0 g
s
.638 .674 .868 r
.59465 .49962 m .59251 .49634 L .60402 .49335 L p F P
0 g
s
.333 .163 .496 r
.74389 .42927 m .73519 .4358 L .73537 .44095 L p F P
0 g
s
.368 .22 .545 r
.73519 .4358 m .74389 .42927 L .74291 .42418 L p F P
0 g
s
.351 .177 .5 r
.7347 .44144 m .73537 .44095 L .73519 .4358 L p F P
0 g
s
.87 .625 .565 r
.26085 .28139 m .26607 .28424 L .26528 .2895 L p F P
0 g
s
.634 .537 .727 r
.51017 .42468 m .51041 .42544 L .49908 .42985 L p F P
0 g
s
.634 .537 .727 r
.49908 .42985 m .4984 .42772 L .51017 .42468 L p F P
0 g
s
.568 .597 .842 r
.67438 .26416 m .66574 .26474 L .66284 .25913 L p F P
0 g
s
.632 .529 .719 r
.49602 .42031 m .50033 .41859 L .49584 .41975 L closepath p F P
0 g
s
.635 .537 .726 r
.50765 .41673 m .51017 .42468 L .4984 .42772 L p F P
0 g
s
.635 .537 .726 r
.50033 .41859 m .50765 .41673 L p .4984 .42772 L F P
0 g
s
.635 .537 .726 r
.4984 .42772 m .49602 .42031 L .50033 .41859 L p F P
0 g
s
.4 .288 .61 r
.74621 .40838 m .74206 .41175 L .74301 .41778 L p F P
0 g
s
.415 .299 .612 r
.74086 .41942 m .74301 .41778 L .74206 .41175 L p F P
0 g
s
.759 .661 .754 r
.2865 .45162 m .28645 .45152 L .28637 .45159 L closepath p F P
0 g
s
.762 .689 .781 r
.24921 .4769 m .25315 .47351 L .26018 .47555 L p F P
0 g
s
.753 .683 .784 r
.26049 .46726 m .25315 .47351 L .26018 .47555 L p F P
0 g
s
.753 .683 .784 r
.26018 .47555 m .2638 .4726 L .26049 .46726 L p F P
0 g
s
.644 .736 .916 r
.60987 .50172 m .6214 .49853 L .62428 .50196 L p F P
0 g
s
.641 .71 .897 r
.6214 .49853 m .60987 .50172 L .60696 .49774 L p F P
0 g
s
.757 .659 .752 r
.28637 .45159 m .28645 .45152 L .28322 .44521 L p F P
0 g
s
.769 .675 .759 r
.27869 .44974 m .28637 .45159 L .27829 .45937 L p F P
0 g
s
.757 .659 .752 r
.28322 .44521 m .27869 .44974 L .28637 .45159 L p F P
0 g
s
.719 .758 .884 r
.18683 .23769 m .17589 .24338 L .17232 .23984 L p F P
0 g
s
.774 .648 .723 r
.29912 .42761 m .29464 .43284 L .29144 .42594 L p F P
0 g
s
.774 .648 .723 r
.29144 .42594 m .29166 .42568 L .29912 .42761 L p F P
0 g
s
.774 .647 .722 r
.29912 .42761 m .29166 .42568 L .29741 .41864 L p F P
0 g
s
.496 .746 .984 r
.1426 .4985 m .13724 .49636 L .14052 .49868 L closepath p F P
0 g
s
.607 .95 .806 r
.55996 .25153 m .56805 .24525 L .57034 .2446 L closepath p F P
0 g
s
.017 0 0 r
.55996 .25153 m .56805 .24525 L p .56805 .24526 L F P
0 g
s
.503 .905 .798 r
.57034 .2446 m .55996 .25153 L p .55919 .25212 L F P
0 g
s
.017 0 0 r
.5575 .2551 m .55996 .25153 L .56805 .24526 L F
.503 .905 .798 r
.55996 .25153 m .55919 .25212 L p .55919 .25212 L F P
0 g
s
0 0 0 r
.55897 .25234 m .55996 .25153 L .55919 .25212 L closepath p F P
0 g
s
.527 .53 .802 r
.71677 .30259 m .70677 .30171 L .70581 .29946 L p F P
0 g
s
.41 .221 .511 r
.54375 .27219 m .53754 .27601 L .53761 .28111 L p F P
0 g
s
.362 .142 .439 r
.53754 .27601 m .54375 .27219 L .54589 .26638 L p F P
0 g
s
.896 .712 .646 r
.05104 .40049 m .05518 .40364 L .05309 .4094 L p F P
0 g
s
.89 .719 .665 r
.05518 .40364 m .05104 .40049 L .05349 .39461 L p F P
0 g
s
.744 .707 .816 r
.23461 .48102 m .22346 .48908 L .22963 .49138 L p F P
0 g
s
.744 .707 .816 r
.22963 .49138 m .23799 .48561 L .23461 .48102 L p F P
0 g
s
.757 .72 .818 r
.22342 .48911 m .22346 .48908 L .22963 .49138 L p F P
0 g
s
.648 .705 .888 r
.59904 .23952 m .61055 .23605 L .61346 .24017 L p F P
0 g
s
.662 .726 .896 r
.61055 .23605 m .59904 .23952 L .59613 .23607 L p F P
0 g
s
.683 .758 .908 r
.58466 .24054 m .59613 .23607 L .59904 .23952 L p F P
0 g
s
.763 .648 .735 r
.29589 .43553 m .29464 .43284 L .29279 .43483 L closepath p F P
0 g
s
.774 .64 .713 r
.30294 .41198 m .30324 .41159 L .30272 .41146 L closepath p F P
0 g
s
.775 .638 .71 r
.29978 .40426 m .30082 .40284 L p .30324 .41159 L F P
0 g
s
.775 .638 .71 r
.30324 .41159 m .30272 .41146 L .29978 .40426 L p F P
0 g
s
.643 .861 .982 r
.6565 .49841 m .65303 .49967 L .65024 .49764 L p F P
0 g
s
.644 .84 .976 r
.63867 .50136 m .65024 .49764 L .65303 .49967 L p F P
0 g
s
.767 .681 .767 r
.26964 .46733 m .2638 .4726 L .26049 .46726 L p F P
0 g
s
.765 .636 .717 r
.29741 .41864 m .30294 .41198 L .30272 .41146 L p F P
0 g
s
.8 .633 .675 r
.28985 .35352 m .29687 .35567 L .29323 .36198 L p F P
0 g
s
.788 .621 .673 r
.29318 .34732 m .28985 .35352 L .29687 .35567 L p F P
0 g
s
.768 .676 .761 r
.2751 .46247 m .27829 .45937 L .27239 .4577 L closepath p F P
0 g
s
.769 .675 .759 r
.27183 .4567 m .27869 .44974 L p .27829 .45937 L F P
0 g
s
.769 .675 .759 r
.27829 .45937 m .27239 .4577 L .27183 .4567 L p F P
0 g
s
.506 .904 .784 r
.69038 .48564 m .68392 .48891 L .67958 .49128 L p F P
0 g
s
.543 .928 .878 r
.67884 .49133 m .68392 .48891 L .67958 .49128 L closepath p F P
0 g
s
.708 .796 .919 r
.59613 .23607 m .58466 .24054 L .58175 .23829 L p F P
0 g
s
.767 .681 .767 r
.26049 .46726 m .26258 .4653 L .26964 .46733 L p F P
0 g
s
.757 .672 .768 r
.27111 .45737 m .26258 .4653 L .26964 .46733 L p F P
0 g
s
.757 .672 .768 r
.27239 .4577 m .27111 .45737 L p .26964 .46733 L F P
0 g
s
.757 .672 .768 r
.26964 .46733 m .2751 .46247 L .27239 .4577 L p F P
0 g
s
.492 .328 .586 r
.52789 .29182 m .53794 .28654 L p .5307 .2963 L F P
0 g
s
.492 .328 .586 r
.5307 .2963 m .52809 .29399 L .52789 .29182 L p F P
0 g
s
.473 .294 .557 r
.53761 .28111 m .53794 .28654 L .52789 .29182 L p F P
0 g
s
.557 .574 .826 r
.68329 .27579 m .68129 .27585 L .68264 .27443 L closepath p F P
0 g
s
.563 .582 .831 r
.68039 .26986 m .68264 .27443 L .68129 .27585 L p F P
0 g
s
.497 0 0 r
.10369 .48326 m .10532 .48448 L .10154 .48241 L p F P
0 g
s
.497 0 0 r
.10154 .48241 m .09881 .48049 L .10369 .48326 L p F P
0 g
s
.765 .636 .717 r
.30272 .41146 m .29544 .40975 L p .29741 .41864 L F P
0 g
s
.77 .636 .713 r
.30272 .41146 m .29978 .40426 L .29544 .40975 L closepath p F P
0 g
s
.871 .749 .726 r
.05477 .36029 m .05865 .36359 L .05476 .36993 L p F P
0 g
s
.866 .751 .734 r
.05865 .36359 m .05477 .36029 L .05893 .35387 L p F P
0 g
s
.785 .639 .7 r
.29546 .3855 m .30279 .38751 L .29822 .39415 L p F P
0 g
s
.784 .631 .692 r
.30279 .38751 m .29546 .3855 L .29972 .37897 L p F P
0 g
s
.393 .262 .582 r
.74301 .41778 m .74086 .41942 L .74291 .42418 L p F P
0 g
s
.901 .561 .391 r
.0765 .45909 m .07189 .45618 L .07105 .45132 L p F P
0 g
s
.905 .563 .386 r
.06651 .44838 m .07105 .45132 L .07189 .45618 L p F P
0 g
s
.906 .606 .465 r
.07105 .45132 m .06651 .44838 L .06629 .44333 L p F P
0 g
s
.91 .609 .462 r
.06181 .44035 m .06629 .44333 L .06651 .44838 L p F P
0 g
s
.907 .638 .52 r
.06629 .44333 m .06181 .44035 L .06216 .43513 L p F P
0 g
s
.635 .642 .84 r
.58954 .49146 m .57806 .49448 L .57508 .4892 L p F P
0 g
s
.638 .657 .852 r
.57806 .49448 m .58954 .49146 L .59251 .49634 L p F P
0 g
s
.367 .636 .958 r
.22172 .242 m .21898 .2417 L .21546 .23834 L p F P
0 g
s
.884 .737 .695 r
.05134 .37611 m .0553 .37936 L .05222 .38543 L p F P
0 g
s
.878 .741 .707 r
.05402 .37122 m .05134 .37611 L .0553 .37936 L p F P
0 g
s
.303 .038 .336 r
.55088 .25963 m .5575 .2551 L p .54742 .26545 L F P
0 g
s
.303 .038 .336 r
.54742 .26545 m .54767 .26394 L .55088 .25963 L p F P
0 g
s
0 0 0 r
.55088 .25963 m .5575 .2551 L .55897 .25234 L closepath p F P
0 g
s
.886 .498 .291 r
.08268 .46662 m .07803 .46374 L .0765 .45909 L p F P
0 g
s
.888 .497 .282 r
.07189 .45618 m .0765 .45909 L .07803 .46374 L p F P
0 g
s
.646 .781 .946 r
.62428 .50196 m .63583 .49857 L .63867 .50136 L p F P
0 g
s
.644 .748 .925 r
.63583 .49857 m .62428 .50196 L .6214 .49853 L p F P
0 g
s
.91 .642 .519 r
.05777 .43212 m .06216 .43513 L .06181 .44035 L p F P
0 g
s
.905 .664 .564 r
.05776 .43208 m .0586 .42673 L p .06216 .43513 L F P
0 g
s
.905 .664 .564 r
.06216 .43513 m .05777 .43212 L .05776 .43208 L p F P
0 g
s
.854 .76 .758 r
.06338 .34735 m .0596 .344 L .06457 .3373 L p F P
0 g
s
.86 .758 .748 r
.06338 .34735 m .06258 .34849 L .05885 .34507 L p F P
0 g
s
.86 .758 .748 r
.05885 .34507 m .0596 .344 L .06338 .34735 L p F P
0 g
s
.614 .493 .691 r
.49814 .38321 m .49715 .37926 L .50865 .37585 L p F P
0 g
s
.614 .491 .689 r
.50689 .36873 m .50865 .37585 L .49715 .37926 L p F P
0 g
s
.527 .53 .802 r
.70581 .29946 m .70957 .29535 L p .71677 .30259 L F P
0 g
s
.532 .541 .809 r
.70581 .29946 m .70385 .29499 L .70957 .29535 L closepath p F P
0 g
s
.017 0 0 r
.5575 .2551 m .55897 .25234 L .55996 .25153 L p F P
0 g
s
.794 .621 .667 r
.28943 .33899 m .28638 .34509 L .29318 .34732 L p F P
0 g
s
.806 .634 .669 r
.28638 .34509 m .29318 .34732 L .28985 .35352 L p F P
0 g
s
.635 .601 .797 r
.54318 .47738 m .55459 .4741 L .55762 .48054 L p F P
0 g
s
.633 .59 .788 r
.55311 .47078 m .55459 .4741 L .54318 .47738 L p F P
0 g
s
.633 .59 .788 r
.54318 .47738 m .54182 .47435 L .55311 .47078 L p F P
0 g
s
.647 .799 .956 r
.65024 .49764 m .63867 .50136 L .63583 .49857 L p F P
0 g
s
.763 .648 .735 r
.29279 .43483 m .29464 .43284 L .29144 .42594 L p F P
0 g
s
.577 .605 .844 r
.66284 .25913 m .65955 .25944 L .66177 .25708 L closepath p F P
0 g
s
.581 .615 .851 r
.65994 .25368 m .66177 .25708 L .65955 .25944 L p F P
0 g
s
.594 .464 .673 r
.50371 .35487 m .50333 .35309 L .51468 .35011 L p F P
0 g
s
.591 .457 .667 r
.51347 .34431 m .51468 .35011 L .50333 .35309 L p F P
0 g
s
.569 .43 .652 r
.51091 .33118 m .52173 .32689 L p .52204 .33371 L F P
0 g
s
.569 .43 .652 r
.52204 .33371 m .51159 .33487 L .51091 .33118 L p F P
0 g
s
.564 .421 .645 r
.5206 .32051 m .52173 .32689 L .51091 .33118 L p F P
0 g
s
.047 0 .028 r
.72475 .46064 m .71536 .46681 L .71398 .47021 L p F P
0 g
s
.126 0 .186 r
.72559 .45664 m .72475 .46064 L .71536 .46681 L p F P
0 g
s
.742 .716 .827 r
.22342 .48911 m .21233 .4961 L .20887 .49213 L p F P
0 g
s
.864 .757 .743 r
.05893 .35387 m .06258 .34849 L .05885 .34507 L p F P
0 g
s
.636 .623 .82 r
.56063 .48659 m .57208 .4835 L p .57071 .49039 L F P
0 g
s
.632 .611 .811 r
.56907 .4775 m .57208 .4835 L .56063 .48659 L p F P
0 g
s
.632 .611 .811 r
.56651 .47819 m .56907 .4775 L p .56063 .48659 L F P
0 g
s
.632 .611 .811 r
.56063 .48659 m .55793 .48118 L .56651 .47819 L p F P
0 g
s
.774 .663 .741 r
.28519 .43295 m .29279 .43483 L .28597 .44222 L p F P
0 g
s
.763 .648 .735 r
.29144 .42594 m .28519 .43295 L .29279 .43483 L p F P
0 g
s
.79 .639 .694 r
.29256 .37689 m .29972 .37897 L .29546 .3855 L p F P
0 g
s
.789 .632 .687 r
.29972 .37897 m .29256 .37689 L .29653 .37046 L p F P
0 g
s
.635 .573 .768 r
.52266 .45955 m .53404 .45589 L .53709 .46343 L p F P
0 g
s
.633 .564 .759 r
.53383 .45532 m .53404 .45589 L .52266 .45955 L p F P
0 g
s
.633 .564 .759 r
.52266 .45955 m .52231 .45865 L .53383 .45532 L p F P
0 g
s
.475 .436 .734 r
.73806 .35498 m .74122 .35195 L p .74244 .36104 L F P
0 g
s
.475 .436 .734 r
.74244 .36104 m .73964 .35999 L .73806 .35498 L p F P
0 g
s
.483 .45 .746 r
.73806 .35498 m .73657 .35045 L .74122 .35195 L closepath p F P
0 g
s
.633 .686 .882 r
.62503 .23739 m .61346 .24017 L .61055 .23605 L p F P
0 g
s
.619 .681 .886 r
.61346 .24017 m .62503 .23739 L p .62693 .24215 L F P
0 g
s
.779 .64 .708 r
.29978 .40426 m .30082 .40284 L .299 .40235 L closepath p F P
0 g
s
.78 .638 .705 r
.29663 .39643 m .29822 .39415 L p .30082 .40284 L F P
0 g
s
.78 .638 .705 r
.30082 .40284 m .299 .40235 L .29663 .39643 L p F P
0 g
s
.813 .635 .662 r
.28285 .33667 m .28943 .33899 L .28638 .34509 L p F P
0 g
s
.809 .627 .656 r
.28943 .33899 m .28285 .33667 L .2856 .33068 L p F P
0 g
s
.909 .668 .562 r
.05776 .43208 m .0586 .42673 L .05646 .42522 L closepath p F P
0 g
s
.902 .684 .598 r
.05479 .42159 m .05559 .41816 L p .0586 .42673 L F P
0 g
s
.902 .684 .598 r
.0586 .42673 m .05646 .42522 L .05479 .42159 L p F P
0 g
s
.633 .564 .759 r
.53099 .44794 m .53383 .45532 L .52231 .45865 L p F P
0 g
s
.633 .564 .759 r
.52231 .45865 m .51961 .45164 L .53099 .44794 L p F P
0 g
s
.476 .436 .734 r
.74053 .36284 m .73964 .35999 L .74244 .36104 L closepath p F P
0 g
s
.85 .401 .137 r
.08268 .46662 m .08441 .46999 L .08135 .46876 L p F P
0 g
s
.85 .401 .137 r
.07803 .46374 m .08268 .46662 L p .08135 .46876 L F P
0 g
s
.482 .451 .746 r
.74122 .35195 m .73657 .35045 L .73538 .34683 L p F P
0 g
s
.595 .469 .678 r
.50527 .36176 m .50371 .35487 L .51488 .35103 L p F P
0 g
s
.594 .464 .673 r
.51468 .35011 m .51488 .35103 L .50371 .35487 L p F P
0 g
s
.617 .5 .698 r
.499 .38648 m .49814 .38321 L .50948 .37914 L p F P
0 g
s
.614 .493 .691 r
.50865 .37585 m .50948 .37914 L .49814 .38321 L p F P
0 g
s
.468 .421 .722 r
.74053 .36284 m .74244 .36104 L p .74285 .37038 L F P
0 g
s
.468 .421 .722 r
.74285 .37038 m .74275 .37034 L .74053 .36284 L p F P
0 g
s
.515 .75 .981 r
.1426 .4985 m .15108 .49746 L p .13686 .49609 L F P
0 g
s
.515 .75 .981 r
.13686 .49609 m .13724 .49636 L .1426 .4985 L p F P
0 g
s
.482 .451 .746 r
.73538 .34683 m .73918 .34309 L p .74122 .35195 L F P
0 g
s
.489 .464 .757 r
.73538 .34683 m .73354 .34153 L .73918 .34309 L closepath p F P
0 g
s
.765 .636 .717 r
.29544 .40975 m .29 .41668 L .29741 .41864 L p F P
0 g
s
.777 .651 .723 r
.29 .41668 m .29741 .41864 L .29166 .42568 L p F P
0 g
s
.489 .328 .589 r
.52843 .29751 m .52809 .29399 L .5307 .2963 L closepath p F P
0 g
s
.643 .861 .982 r
.66349 .49479 m .6565 .49841 L p .65024 .49764 L F P
0 g
s
.654 .879 .982 r
.6565 .49841 m .66349 .49479 L .66459 .49542 L closepath p F P
0 g
s
.635 .534 .723 r
.50765 .41673 m .50735 .41576 L .50033 .41859 L closepath p F P
0 g
s
.632 .527 .717 r
.5053 .40897 m .50735 .41576 L .50033 .41859 L p F P
0 g
s
.763 .705 .797 r
.24246 .48211 m .23799 .48561 L .23461 .48102 L p F P
0 g
s
.822 .344 .033 r
.2443 .25817 m .23973 .25504 L .23721 .25098 L p F P
0 g
s
.832 .359 .033 r
.23296 .24773 m .23721 .25098 L .23973 .25504 L p F P
0 g
s
.549 .007 0 r
.2329 .24768 m .23296 .24773 L .23721 .25098 L p F P
0 g
s
.637 .625 .822 r
.57508 .4892 m .57071 .49039 L .57495 .48896 L closepath p F P
0 g
s
.636 .623 .82 r
.57208 .4835 m .57495 .48896 L .57071 .49039 L p F P
0 g
s
.892 .724 .665 r
.04944 .39142 m .05349 .39461 L .05104 .40049 L p F P
0 g
s
.887 .729 .681 r
.05349 .39461 m .04944 .39142 L .05222 .38543 L p F P
0 g
s
.77 .636 .713 r
.29544 .40975 m .29978 .40426 L .299 .40235 L p F P
0 g
s
.548 .569 .828 r
.69222 .26967 m .69513 .27575 L .68329 .27579 L p F P
0 g
s
.548 .569 .828 r
.68673 .26971 m .69222 .26967 L p .68329 .27579 L F P
0 g
s
.548 .569 .828 r
.68329 .27579 m .68264 .27443 L .68673 .26971 L p F P
0 g
s
.55 .567 .825 r
.68329 .27579 m .69513 .27575 L p .69202 .28192 L F P
0 g
s
.633 .589 .787 r
.55156 .4673 m .55311 .47078 L .54182 .47435 L p F P
0 g
s
.633 .589 .787 r
.54182 .47435 m .54014 .47058 L .55156 .4673 L p F P
0 g
s
.82 .637 .654 r
.27925 .32828 m .2856 .33068 L .28285 .33667 L p F P
0 g
s
.817 .629 .648 r
.2856 .33068 m .27925 .32828 L .28171 .32239 L p F P
0 g
s
.298 .034 .334 r
.54589 .26638 m .54742 .26545 L .54767 .26394 L closepath p F P
0 g
s
.617 .502 .699 r
.50096 .39382 m .499 .38648 L .51052 .38308 L p F P
0 g
s
.617 .5 .698 r
.50948 .37914 m .51052 .38308 L .499 .38648 L p F P
0 g
s
.588 .627 .858 r
.64592 .25078 m .64536 .24979 L .64698 .24957 L closepath p F P
0 g
s
.628 .75 .935 r
.1547 .50036 m .16542 .4975 L .169 .50067 L p F P
0 g
s
.642 .75 .928 r
.16542 .4975 m .1547 .50036 L .15108 .49746 L p F P
0 g
s
.489 .465 .757 r
.73918 .34309 m .73354 .34153 L .73246 .3384 L p F P
0 g
s
.796 .64 .689 r
.28955 .36831 m .29653 .37046 L .29256 .37689 L p F P
0 g
s
.794 .632 .681 r
.29653 .37046 m .28955 .36831 L .29323 .36198 L p F P
0 g
s
.468 .421 .722 r
.74278 .37045 m .74275 .37034 L .74285 .37038 L closepath p F P
0 g
s
.455 .401 .707 r
.74285 .37038 m .74278 .37045 L .7448 .37777 L p F P
0 g
s
.77 .636 .713 r
.299 .40235 m .29325 .40092 L p .29544 .40975 L F P
0 g
s
.774 .636 .708 r
.299 .40235 m .29663 .39643 L .29325 .40092 L closepath p F P
0 g
s
.455 .401 .707 r
.7448 .37777 m .74919 .37375 L .74285 .37038 L p F P
0 g
s
.456 .403 .711 r
.74949 .36418 m .74285 .37038 L .74919 .37375 L p F P
0 g
s
.468 .421 .722 r
.74244 .36104 m .74949 .36418 L .74285 .37038 L p F P
0 g
s
.773 .664 .743 r
.28322 .44521 m .28597 .44222 L .28096 .44082 L closepath p F P
0 g
s
.774 .663 .741 r
.27998 .43887 m .28519 .43295 L p .28597 .44222 L F P
0 g
s
.774 .663 .741 r
.28597 .44222 m .28096 .44082 L .27998 .43887 L p F P
0 g
s
.763 .705 .797 r
.23461 .48102 m .23597 .47991 L .24246 .48211 L p F P
0 g
s
.752 .695 .797 r
.24586 .47193 m .23597 .47991 L .24246 .48211 L p F P
0 g
s
.752 .695 .797 r
.24246 .48211 m .24921 .4769 L .24586 .47193 L p F P
0 g
s
.489 .465 .757 r
.73246 .3384 m .73634 .33448 L p .73918 .34309 L F P
0 g
s
.496 .478 .767 r
.73246 .3384 m .73055 .33311 L .73634 .33448 L closepath p F P
0 g
s
.267 .662 .968 r
.12283 .49273 m .13175 .49336 L .13671 .49608 L p F P
0 g
s
.325 .684 .979 r
.13175 .49336 m .12283 .49273 L .11911 .49035 L p F P
0 g
s
.732 .745 .862 r
.19784 .49837 m .19875 .49784 L .1963 .49675 L closepath p F P
0 g
s
.707 .738 .875 r
.1963 .49675 m .19784 .49837 L p .18339 .49992 L F P
0 g
s
.828 .638 .646 r
.27559 .3199 m .28171 .32239 L .27925 .32828 L p F P
0 g
s
.826 .63 .638 r
.28171 .32239 m .27559 .3199 L .27774 .31413 L p F P
0 g
s
.906 .687 .596 r
.05479 .42159 m .05559 .41816 L .0516 .41523 L closepath p F P
0 g
s
.898 .7 .627 r
.0514 .41493 m .05309 .4094 L p .05559 .41816 L F P
0 g
s
.898 .7 .627 r
.05559 .41816 m .0516 .41523 L .0514 .41493 L p F P
0 g
s
.555 .579 .833 r
.68264 .27443 m .68039 .26986 L .68673 .26971 L closepath p F P
0 g
s
.57 .435 .658 r
.51212 .33767 m .51159 .33487 L .52204 .33371 L closepath p F P
0 g
s
.551 .928 .912 r
.68392 .48891 m .67884 .49133 L .67616 .49081 L p F P
0 g
s
.583 .926 .957 r
.66459 .49542 m .67616 .49081 L .67884 .49133 L p F P
0 g
s
.785 .639 .7 r
.29348 .38849 m .29546 .3855 L p .29822 .39415 L F P
0 g
s
.785 .639 .7 r
.29822 .39415 m .29539 .39334 L .29348 .38849 L p F P
0 g
s
.784 .64 .703 r
.29663 .39643 m .29822 .39415 L .29539 .39334 L closepath p F P
0 g
s
.532 .541 .81 r
.70957 .29535 m .70385 .29499 L .70114 .28882 L p F P
0 g
s
.37 .15 .444 r
.54742 .26545 m .54589 .26638 L .54375 .27219 L p F P
0 g
s
.541 .396 .633 r
.51959 .31426 m .53005 .30951 L p .52835 .31693 L F P
0 g
s
.541 .396 .633 r
.52835 .31693 m .51985 .31591 L .51959 .31426 L p F P
0 g
s
.532 .381 .621 r
.52917 .30343 m .53005 .30951 L .51959 .31426 L p F P
0 g
s
.762 .66 .749 r
.27869 .44974 m .28322 .44521 L .28096 .44082 L p F P
0 g
s
.734 .744 .86 r
.20541 .48812 m .20887 .49213 L .19875 .49784 L p F P
0 g
s
.734 .744 .86 r
.19434 .49467 m .20541 .48812 L p .19875 .49784 L F P
0 g
s
.734 .744 .86 r
.19875 .49784 m .1963 .49675 L .19434 .49467 L p F P
0 g
s
.634 .66 .857 r
.60402 .49335 m .59251 .49634 L .58954 .49146 L p F P
0 g
s
.631 .555 .751 r
.53044 .44645 m .53099 .44794 L .51961 .45164 L p F P
0 g
s
.631 .555 .751 r
.51961 .45164 m .51892 .44978 L .53044 .44645 L p F P
0 g
s
.883 .615 .528 r
.26085 .28139 m .2575 .27943 L .25777 .27429 L p F P
0 g
s
.868 .6 .532 r
.25605 .2734 m .25777 .27429 L .2575 .27943 L p F P
0 g
s
0 .3 .673 r
.10532 .48448 m .11 .48644 L .11505 .48915 L p F P
0 g
s
0 .364 .744 r
.11 .48644 m .10532 .48448 L .10154 .48241 L p F P
0 g
s
.587 .633 .864 r
.64698 .24957 m .64536 .24979 L .64246 .24477 L p F P
0 g
s
.678 .131 0 r
.09881 .48049 m .09398 .4777 L .08999 .47379 L p F P
0 g
s
.661 .11 0 r
.08513 .471 m .08999 .47379 L .09398 .4777 L p F P
0 g
s
.807 .325 .053 r
.08441 .46999 m .08513 .471 L .08999 .47379 L p F P
0 g
s
.835 .63 .626 r
.27774 .31413 m .27185 .31155 L .2737 .30588 L p F P
0 g
s
.836 .639 .636 r
.27185 .31155 m .27774 .31413 L .27559 .3199 L p F P
0 g
s
.802 .641 .683 r
.28644 .35975 m .29323 .36198 L .28955 .36831 L p F P
0 g
s
.8 .633 .675 r
.29323 .36198 m .28644 .35975 L .28985 .35352 L p F P
0 g
s
.631 .555 .751 r
.52792 .4396 m .53044 .44645 L .51892 .44978 L p F P
0 g
s
.631 .555 .751 r
.51892 .44978 m .51655 .44334 L .52792 .4396 L p F P
0 g
s
.884 .508 .322 r
.25049 .26567 m .24562 .26267 L .2443 .25817 L p F P
0 g
s
.895 .52 .317 r
.23973 .25504 m .2443 .25817 L .24562 .26267 L p F P
0 g
s
.677 .747 .904 r
.169 .50067 m .17985 .4965 L .18339 .49992 L p F P
0 g
s
.687 .747 .897 r
.17985 .4965 m .169 .50067 L .16542 .4975 L p F P
0 g
s
.878 .746 .713 r
.05476 .36993 m .05402 .37122 L .05029 .36766 L p F P
0 g
s
.878 .746 .713 r
.05029 .36766 m .05087 .36664 L .05476 .36993 L p F P
0 g
s
.871 .749 .726 r
.05476 .36993 m .05087 .36664 L .05477 .36029 L p F P
0 g
s
.772 .667 .748 r
.27869 .44974 m .27183 .4567 L .26856 .45083 L p F P
0 g
s
.772 .667 .748 r
.26856 .45083 m .27149 .44774 L .27869 .44974 L p F P
0 g
s
.762 .66 .749 r
.27867 .44024 m .27149 .44774 L .27869 .44974 L p F P
0 g
s
.762 .66 .749 r
.28096 .44082 m .27867 .44024 L p .27869 .44974 L F P
0 g
s
.707 .738 .875 r
.18339 .49992 m .19244 .49558 L .1963 .49675 L p F P
0 g
s
.716 .74 .871 r
.19244 .49558 m .18339 .49992 L .17985 .4965 L p F P
0 g
s
.617 .666 .875 r
.62793 .24194 m .62693 .24215 L .62762 .24145 L closepath p F P
0 g
s
.619 .681 .886 r
.62503 .23739 m .62762 .24145 L .62693 .24215 L p F P
0 g
s
.4 .288 .61 r
.74301 .41778 m .74905 .41289 L .74621 .40838 L p F P
0 g
s
.376 .251 .58 r
.74905 .41289 m .74301 .41778 L .74373 .42355 L p F P
0 g
s
.393 .262 .582 r
.74291 .42418 m .74373 .42355 L .74301 .41778 L p F P
0 g
s
.761 .672 .764 r
.27239 .4577 m .27183 .4567 L .27111 .45737 L closepath p F P
0 g
s
.496 .478 .767 r
.73634 .33448 m .73055 .33311 L .72929 .32964 L p F P
0 g
s
.617 .504 .702 r
.50121 .39474 m .50096 .39382 L .51246 .39042 L p F P
0 g
s
.617 .502 .699 r
.51052 .38308 m .51246 .39042 L .50096 .39382 L p F P
0 g
s
.869 .755 .735 r
.05513 .35052 m .05893 .35387 L .05477 .36029 L p F P
0 g
s
.864 .757 .743 r
.05885 .34507 m .05513 .35052 L .05893 .35387 L p F P
0 g
s
.782 .651 .718 r
.2881 .40775 m .29544 .40975 L .29 .41668 L p F P
0 g
s
.77 .636 .713 r
.29325 .40092 m .2881 .40775 L .29544 .40975 L p F P
0 g
s
.769 .695 .781 r
.25315 .47351 m .24921 .4769 L .24586 .47193 L p F P
0 g
s
.531 .917 .794 r
.56805 .24525 m .57034 .2446 L .57686 .24081 L p F P
0 g
s
.63 .579 .779 r
.54887 .46099 m .55156 .4673 L .54014 .47058 L p F P
0 g
s
.63 .579 .779 r
.54014 .47058 m .53759 .46459 L .54887 .46099 L p F P
0 g
s
.776 .652 .726 r
.29144 .42594 m .29166 .42568 L .29127 .42558 L closepath p F P
0 g
s
.777 .651 .723 r
.28824 .41891 m .29 .41668 L p .29166 .42568 L F P
0 g
s
.777 .651 .723 r
.29166 .42568 m .29127 .42558 L .28824 .41891 L p F P
0 g
s
.62 .511 .709 r
.50308 .40134 m .50121 .39474 L .51256 .39076 L p F P
0 g
s
.617 .504 .702 r
.51246 .39042 m .51256 .39076 L .50121 .39474 L p F P
0 g
s
.447 .384 .694 r
.7448 .37777 m .74919 .37375 L p .74807 .38357 L F P
0 g
s
.447 .384 .694 r
.74807 .38357 m .74596 .38225 L .7448 .37777 L p F P
0 g
s
.846 .64 .624 r
.26803 .30322 m .2737 .30588 L .27185 .31155 L p F P
0 g
s
.846 .63 .61 r
.2737 .30588 m .26803 .30322 L .26955 .29767 L p F P
0 g
s
.767 .649 .731 r
.28519 .43295 m .29144 .42594 L .29127 .42558 L p F P
0 g
s
.027 .469 .877 r
.23255 .24741 m .22855 .24453 L .22172 .242 L p F P
0 g
s
.022 .454 .873 r
.21773 .23864 m .22172 .242 L .22855 .24453 L p F P
0 g
s
.367 .636 .958 r
.21546 .23834 m .21773 .23864 L .22172 .242 L p F P
0 g
s
.544 .558 .819 r
.69803 .28203 m .69202 .28192 L .69598 .27757 L closepath p F P
0 g
s
.55 .567 .825 r
.69513 .27575 m .69598 .27757 L .69202 .28192 L p F P
0 g
s
.432 .346 .659 r
.74933 .39676 m .74584 .3937 L .74824 .39168 L closepath p F P
0 g
s
.446 .369 .677 r
.74584 .3937 m .74824 .39168 L .74663 .38485 L p F P
0 g
s
.597 .472 .68 r
.5064 .36669 m .50527 .36176 L .51645 .35794 L p F P
0 g
s
.595 .469 .678 r
.51488 .35103 m .51645 .35794 L .50527 .36176 L p F P
0 g
s
.774 .636 .708 r
.29325 .40092 m .29663 .39643 L .29539 .39334 L p F P
0 g
s
.568 .597 .842 r
.66284 .25913 m .6746 .2583 L p .67438 .26416 L F P
0 g
s
.568 .6 .846 r
.6717 .25272 m .6746 .2583 L .66284 .25913 L p F P
0 g
s
.568 .6 .846 r
.66501 .25323 m .6717 .25272 L p .66284 .25913 L F P
0 g
s
.568 .6 .846 r
.66284 .25913 m .66177 .25708 L .66501 .25323 L p F P
0 g
s
.769 .695 .781 r
.24586 .47193 m .24653 .47133 L .25315 .47351 L p F P
0 g
s
.758 .684 .78 r
.25565 .46322 m .24653 .47133 L .25315 .47351 L p F P
0 g
s
.758 .684 .78 r
.25849 .464 m .25565 .46322 L p .25315 .47351 L F P
0 g
s
.758 .684 .78 r
.25315 .47351 m .26049 .46726 L .25849 .464 L p F P
0 g
s
.767 .649 .731 r
.29127 .42558 m .28409 .42377 L p .28519 .43295 L F P
0 g
s
.771 .649 .727 r
.29127 .42558 m .28824 .41891 L .28409 .42377 L closepath p F P
0 g
s
.541 .4 .639 r
.5206 .32051 m .51985 .31591 L .52835 .31693 L closepath p F P
0 g
s
.573 .442 .664 r
.51347 .34431 m .51212 .33767 L .52204 .33371 L p F P
0 g
s
.305 .105 .435 r
.73537 .44095 m .7347 .44144 L .73306 .44732 L p F P
0 g
s
.496 .478 .767 r
.72929 .32964 m .73269 .32612 L p .73634 .33448 L F P
0 g
s
.502 .491 .777 r
.72929 .32964 m .72757 .3251 L .73269 .32612 L closepath p F P
0 g
s
.88 .745 .708 r
.05134 .37611 m .05402 .37122 L .05029 .36766 L p F P
0 g
s
.856 .64 .609 r
.26411 .29491 m .26955 .29767 L .26803 .30322 L p F P
0 g
s
.857 .629 .591 r
.26955 .29767 m .26411 .29491 L .26528 .2895 L p F P
0 g
s
.76 .671 .763 r
.27111 .45737 m .27183 .4567 L .26856 .45083 L p F P
0 g
s
.772 .687 .769 r
.26381 .4554 m .27111 .45737 L .26258 .4653 L p F P
0 g
s
.76 .671 .763 r
.26856 .45083 m .26381 .4554 L .27111 .45737 L p F P
0 g
s
.789 .641 .698 r
.29348 .38849 m .29546 .3855 L .29186 .38441 L closepath p F P
0 g
s
.79 .639 .694 r
.29033 .38045 m .29256 .37689 L p .29546 .3855 L F P
0 g
s
.79 .639 .694 r
.29546 .3855 m .29186 .38441 L .29033 .38045 L p F P
0 g
s
.604 .645 .864 r
.62793 .24194 m .63956 .23984 L .64246 .24477 L p F P
0 g
s
.609 .663 .877 r
.63665 .23502 m .63956 .23984 L .62793 .24194 L p F P
0 g
s
.609 .663 .877 r
.63232 .23588 m .63665 .23502 L p .62793 .24194 L F P
0 g
s
.609 .663 .877 r
.62793 .24194 m .62762 .24145 L .63232 .23588 L p F P
0 g
s
.808 .642 .677 r
.28325 .35122 m .28985 .35352 L .28644 .35975 L p F P
0 g
s
.806 .634 .669 r
.28985 .35352 m .28325 .35122 L .28638 .34509 L p F P
0 g
s
.88 .571 .459 r
.25605 .2734 m .25089 .27051 L .25049 .26567 L p F P
0 g
s
.892 .582 .455 r
.24562 .26267 m .25049 .26567 L .25089 .27051 L p F P
0 g
s
.903 .703 .623 r
.05309 .4094 m .0514 .41493 L .04783 .40991 L p F P
0 g
s
.903 .703 .623 r
.04783 .40991 m .04894 .40626 L .05309 .4094 L p F P
0 g
s
.896 .712 .646 r
.05309 .4094 m .04894 .40626 L .05104 .40049 L p F P
0 g
s
.771 .688 .771 r
.26049 .46726 m .26258 .4653 L .25849 .464 L closepath p F P
0 g
s
.772 .687 .769 r
.25718 .46186 m .26381 .4554 L p .26258 .4653 L F P
0 g
s
.772 .687 .769 r
.26258 .4653 m .25849 .464 L .25718 .46186 L p F P
0 g
s
.889 .733 .682 r
.04825 .38219 m .05222 .38543 L .04944 .39142 L p F P
0 g
s
.884 .737 .695 r
.05222 .38543 m .04825 .38219 L .05134 .37611 L p F P
0 g
s
.629 .547 .743 r
.52731 .43785 m .52792 .4396 L .51655 .44334 L p F P
0 g
s
.629 .547 .743 r
.51655 .44334 m .51579 .44119 L .52731 .43785 L p F P
0 g
s
.62 .512 .709 r
.50428 .40553 m .50308 .40134 L .51459 .39795 L p F P
0 g
s
.62 .511 .709 r
.51256 .39076 m .51459 .39795 L .50308 .40134 L p F P
0 g
s
.779 .636 .703 r
.29539 .39334 m .29348 .38849 L .29086 .39215 L closepath p F P
0 g
s
.774 .636 .708 r
.29539 .39334 m .29086 .39215 L p .29325 .40092 L F P
0 g
s
.501 .351 .61 r
.5307 .2963 m .52843 .29751 L .52917 .30343 L p F P
0 g
s
.632 .61 .81 r
.55793 .48118 m .55762 .48054 L .56651 .47819 L closepath p F P
0 g
s
.08 .541 .903 r
.11505 .48915 m .11911 .49035 L .11538 .48786 L p F P
0 g
s
.08 .541 .903 r
.11538 .48786 m .11 .48644 L .11505 .48915 L p F P
0 g
s
.867 .638 .59 r
.26007 .28665 m .26528 .2895 L .26411 .29491 L p F P
0 g
s
.87 .625 .565 r
.26528 .2895 m .26007 .28665 L .26085 .28139 L p F P
0 g
s
.587 .633 .864 r
.64246 .24477 m .65236 .24334 L .64698 .24957 L p F P
0 g
s
.588 .628 .859 r
.64698 .24957 m .65705 .24836 L .65414 .2431 L p F P
0 g
s
.588 .628 .859 r
.65414 .2431 m .65236 .24334 L .64698 .24957 L p F P
0 g
s
.629 .546 .742 r
.52486 .43083 m .52731 .43785 L .51579 .44119 L p F P
0 g
s
.629 .546 .742 r
.51579 .44119 m .51348 .43461 L .52486 .43083 L p F P
0 g
s
.91 .669 .56 r
.05646 .42522 m .05432 .42367 L p .05776 .43212 L F P
0 g
s
.91 .669 .56 r
.05776 .43212 m .05776 .43208 L .05646 .42522 L p F P
0 g
s
.905 .684 .593 r
.05646 .42522 m .05479 .42159 L .05432 .42367 L closepath p F P
0 g
s
.757 .722 .819 r
.22342 .48911 m .22346 .48908 L .22338 .48906 L closepath p F P
0 g
s
.742 .716 .827 r
.22338 .48906 m .22342 .48911 L p .20887 .49213 L F P
0 g
s
.759 .721 .817 r
.23301 .47883 m .23461 .48102 L .22346 .48908 L p F P
0 g
s
.759 .721 .817 r
.22939 .47771 m .23301 .47883 L p .22346 .48908 L F P
0 g
s
.759 .721 .817 r
.22001 .48478 m .22939 .47771 L p .22346 .48908 L F P
0 g
s
.759 .721 .817 r
.22346 .48908 m .22338 .48906 L .22001 .48478 L p F P
0 g
s
.324 .113 .431 r
.54714 .27014 m .54742 .26545 L .55663 .25906 L p F P
0 g
s
.303 .038 .336 r
.5575 .2551 m .55663 .25906 L .54742 .26545 L p F P
0 g
s
.37 .15 .444 r
.54375 .27219 m .54714 .27014 L .54742 .26545 L p F P
0 g
s
.742 .716 .827 r
.20887 .49213 m .21667 .48697 L .22338 .48906 L p F P
0 g
s
.741 .717 .829 r
.22338 .48906 m .22001 .48478 L .21667 .48697 L closepath p F P
0 g
s
.635 .642 .84 r
.57508 .4892 m .58657 .48624 L .58954 .49146 L p F P
0 g
s
.632 .623 .823 r
.58588 .48496 m .58657 .48624 L .57508 .4892 L p F P
0 g
s
.632 .623 .823 r
.57508 .4892 m .57495 .48896 L .58588 .48496 L p F P
0 g
s
.878 .633 .565 r
.2575 .27943 m .26085 .28139 L .26007 .28665 L p F P
0 g
s
.868 .6 .532 r
.2575 .27943 m .25572 .2785 L .25605 .2734 L p F P
0 g
s
.877 .609 .528 r
.25089 .27051 m .25605 .2734 L .25572 .2785 L p F P
0 g
s
.613 .668 .879 r
.62762 .24145 m .62503 .23739 L .63232 .23588 L closepath p F P
0 g
s
.678 .75 .905 r
.18683 .23769 m .1977 .23336 L .20123 .23689 L p F P
0 g
s
.677 .75 .905 r
.1977 .23336 m .18683 .23769 L .18328 .23414 L p F P
0 g
s
.719 .758 .884 r
.17232 .23984 m .18328 .23414 L .18683 .23769 L p F P
0 g
s
.579 .727 .944 r
.20123 .23689 m .21194 .23493 L .21546 .23834 L p F P
0 g
s
.576 .722 .942 r
.21194 .23493 m .20123 .23689 L .1977 .23336 L p F P
0 g
s
.447 .384 .693 r
.74663 .38485 m .74596 .38225 L .74807 .38357 L closepath p F P
0 g
s
.63 .598 .799 r
.56651 .47819 m .55762 .48054 L .55459 .4741 L p F P
0 g
s
.63 .622 .823 r
.58357 .48062 m .58588 .48496 L .57495 .48896 L p F P
0 g
s
.63 .622 .823 r
.57495 .48896 m .57208 .4835 L .58357 .48062 L p F P
0 g
s
.62 .512 .709 r
.51459 .39795 m .51563 .4016 L .50428 .40553 L p F P
0 g
s
.622 .52 .717 r
.5053 .40897 m .50428 .40553 L .51563 .4016 L p F P
0 g
s
.551 .928 .912 r
.6894 .4858 m .68392 .48891 L p .67616 .49081 L F P
0 g
s
.52 .917 .838 r
.68392 .48891 m .6894 .4858 L .69038 .48564 L closepath p F P
0 g
s
.333 .163 .496 r
.73537 .44095 m .7437 .43472 L .74389 .42927 L p F P
0 g
s
.285 .09 .43 r
.7437 .43472 m .73537 .44095 L .73526 .44576 L p F P
0 g
s
.305 .105 .435 r
.73306 .44732 m .73526 .44576 L .73537 .44095 L p F P
0 g
s
.778 .659 .731 r
.28519 .43295 m .27998 .43887 L .27674 .43245 L p F P
0 g
s
.778 .659 .731 r
.27674 .43245 m .27805 .43091 L .28519 .43295 L p F P
0 g
s
.767 .649 .731 r
.28409 .42377 m .27805 .43091 L .28519 .43295 L p F P
0 g
s
.814 .643 .67 r
.27998 .34271 m .28638 .34509 L .28325 .35122 L p F P
0 g
s
.813 .635 .662 r
.28638 .34509 m .27998 .34271 L .28285 .33667 L p F P
0 g
s
.464 .42 .724 r
.74886 .35494 m .74244 .36104 L .74949 .36418 L p F P
0 g
s
.475 .436 .734 r
.74881 .35479 m .74886 .35494 L .74244 .36104 L p F P
0 g
s
.475 .436 .734 r
.74122 .35195 m .74881 .35479 L p .74244 .36104 L F P
0 g
s
.622 .52 .717 r
.50735 .41576 m .5053 .40897 L .51682 .40559 L p F P
0 g
s
.622 .52 .717 r
.51563 .4016 m .51682 .40559 L .5053 .40897 L p F P
0 g
s
.502 .491 .777 r
.73269 .32612 m .72757 .3251 L .72585 .32055 L p F P
0 g
s
.599 .479 .687 r
.50689 .36873 m .5064 .36669 L .51777 .36363 L p F P
0 g
s
.597 .472 .68 r
.51645 .35794 m .51777 .36363 L .5064 .36669 L p F P
0 g
s
.627 .538 .735 r
.52441 .42948 m .52486 .43083 L .51348 .43461 L p F P
0 g
s
.627 .538 .735 r
.51348 .43461 m .51289 .43284 L .52441 .42948 L p F P
0 g
s
.439 .271 .555 r
.54388 .27726 m .53761 .28111 L .53794 .28654 L p F P
0 g
s
.41 .221 .511 r
.53761 .28111 m .54388 .27726 L .54375 .27219 L p F P
0 g
s
.787 .652 .713 r
.28601 .39888 m .29325 .40092 L .2881 .40775 L p F P
0 g
s
.774 .636 .708 r
.29086 .39215 m .28601 .39888 L .29325 .40092 L p F P
0 g
s
.641 .71 .897 r
.60696 .49774 m .6185 .49468 L .6214 .49853 L p F P
0 g
s
.636 .679 .874 r
.61585 .49083 m .6185 .49468 L .60696 .49774 L p F P
0 g
s
.636 .679 .874 r
.60696 .49774 m .6054 .49542 L .61585 .49083 L p F P
0 g
s
.706 .739 .877 r
.1963 .49675 m .19434 .49467 L .19244 .49558 L closepath p F P
0 g
s
.627 .538 .734 r
.52178 .42161 m .52441 .42948 L .51289 .43284 L p F P
0 g
s
.627 .538 .734 r
.51289 .43284 m .51041 .42544 L .52178 .42161 L p F P
0 g
s
.766 .66 .745 r
.28096 .44082 m .27998 .43887 L .27867 .44024 L closepath p F P
0 g
s
.574 .609 .85 r
.66177 .25708 m .65994 .25368 L .66501 .25323 L closepath p F P
0 g
s
.795 .642 .692 r
.29033 .38045 m .29256 .37689 L .28842 .37555 L closepath p F P
0 g
s
.796 .64 .689 r
.28719 .3723 m .28955 .36831 L p .29256 .37689 L F P
0 g
s
.796 .64 .689 r
.29256 .37689 m .28842 .37555 L .28719 .3723 L p F P
0 g
s
.432 .36 .676 r
.74807 .38357 m .74663 .38485 L .74824 .39168 L p F P
0 g
s
.779 .637 .704 r
.29086 .39215 m .29348 .38849 L .29186 .38441 L p F P
0 g
s
.624 .528 .725 r
.50765 .41673 m .50735 .41576 L .51871 .41187 L p F P
0 g
s
.622 .52 .717 r
.51682 .40559 m .51871 .41187 L .50735 .41576 L p F P
0 g
s
.625 .529 .726 r
.51017 .42468 m .50765 .41673 L .51918 .41337 L p F P
0 g
s
.624 .528 .725 r
.51871 .41187 m .51918 .41337 L .50765 .41673 L p F P
0 g
s
.166 0 .23 r
.72984 .45369 m .72559 .45664 L .72475 .46064 L p F P
0 g
s
.252 .018 .352 r
.72559 .45664 m .72984 .45369 L .73306 .44732 L p F P
0 g
s
.624 .53 .727 r
.51041 .42544 m .51017 .42468 L .52169 .42131 L p F P
0 g
s
.625 .529 .726 r
.51918 .41337 m .52169 .42131 L .51017 .42468 L p F P
0 g
s
.624 .53 .727 r
.52169 .42131 m .52178 .42161 L .51041 .42544 L p F P
0 g
s
.782 .651 .718 r
.28504 .41182 m .2881 .40775 L p .29 .41668 L F P
0 g
s
.782 .651 .718 r
.29 .41668 m .28681 .41576 L .28504 .41182 L p F P
0 g
s
.781 .653 .721 r
.28824 .41891 m .29 .41668 L .28681 .41576 L closepath p F P
0 g
s
.63 .579 .778 r
.54851 .46016 m .54887 .46099 L .53759 .46459 L p F P
0 g
s
.63 .579 .778 r
.53759 .46459 m .53709 .46343 L .54851 .46016 L p F P
0 g
s
.6 .482 .69 r
.50865 .37585 m .50689 .36873 L .51808 .36491 L p F P
0 g
s
.599 .479 .687 r
.51777 .36363 m .51808 .36491 L .50689 .36873 L p F P
0 g
s
.537 .551 .817 r
.70114 .28882 m .70094 .28837 L .70152 .2884 L closepath p F P
0 g
s
.532 .541 .81 r
.70114 .28882 m .70152 .2884 L p .70957 .29535 L F P
0 g
s
.908 .687 .592 r
.05432 .42367 m .05479 .42159 L .0516 .41523 L p F P
0 g
s
.554 .58 .835 r
.68673 .26971 m .68039 .26986 L .67749 .264 L p F P
0 g
s
.45 0 0 r
.09881 .48049 m .10154 .48241 L .09775 .4802 L p F P
0 g
s
.45 0 0 r
.09775 .4802 m .09398 .4777 L .09881 .48049 L p F P
0 g
s
.531 .917 .794 r
.57686 .24081 m .58049 .23763 L p .56805 .24525 L F P
0 g
s
.722 .908 .96 r
.57686 .24081 m .58049 .23763 L .58175 .23829 L closepath p F P
0 g
s
.821 .644 .663 r
.27665 .33422 m .28285 .33667 L .27998 .34271 L p F P
0 g
s
.82 .637 .654 r
.28285 .33667 m .27665 .33422 L .27925 .32828 L p F P
0 g
s
.536 .553 .819 r
.70152 .2884 m .70094 .28837 L .69803 .28203 L p F P
0 g
s
.391 .698 .982 r
.13686 .49609 m .13671 .49608 L .13724 .49636 L closepath p F P
0 g
s
.899 .717 .647 r
.04698 .3973 m .05104 .40049 L .04894 .40626 L p F P
0 g
s
.892 .724 .665 r
.05104 .40049 m .04698 .3973 L .04944 .39142 L p F P
0 g
s
.628 .569 .77 r
.54851 .46016 m .53709 .46343 L .53404 .45589 L p F P
0 g
s
.671 .883 .977 r
.66349 .49479 m .66459 .49542 L .67616 .49081 L p F P
0 g
s
.905 .563 .386 r
.07189 .45618 m .06735 .45325 L .06651 .44838 L p F P
0 g
s
.908 .565 .381 r
.06203 .44541 m .06651 .44838 L .06735 .45325 L p F P
0 g
s
.91 .609 .462 r
.06651 .44838 m .06203 .44541 L .06181 .44035 L p F P
0 g
s
.502 .491 .777 r
.72585 .32055 m .72823 .318 L p .73269 .32612 L F P
0 g
s
.508 .503 .786 r
.72585 .32055 m .72461 .3174 L .72823 .318 L closepath p F P
0 g
s
.91 .642 .519 r
.05775 .43217 m .05777 .43212 L p .06181 .44035 L F P
0 g
s
.91 .642 .519 r
.06181 .44035 m .0574 .43734 L .05775 .43217 L p F P
0 g
s
.914 .612 .46 r
.0574 .43734 m .06181 .44035 L .06203 .44541 L p F P
0 g
s
.545 .41 .648 r
.52173 .32689 m .5206 .32051 L .52835 .31693 L p F P
0 g
s
.397 .287 .611 r
.75083 .40458 m .74621 .40838 L .74905 .41289 L p F P
0 g
s
.417 .318 .636 r
.74621 .40838 m .75083 .40458 L .74965 .39827 L p F P
0 g
s
.779 .637 .704 r
.29186 .38441 m .28831 .38342 L p .29086 .39215 L F P
0 g
s
.783 .636 .698 r
.29186 .38441 m .29033 .38045 L .28831 .38342 L closepath p F P
0 g
s
.766 .66 .745 r
.27867 .44024 m .27998 .43887 L .27674 .43245 L p F P
0 g
s
.771 .649 .727 r
.28409 .42377 m .28824 .41891 L .28681 .41576 L p F P
0 g
s
.708 .796 .919 r
.58175 .23829 m .59322 .23307 L .59613 .23607 L p F P
0 g
s
.662 .726 .896 r
.59613 .23607 m .60764 .23217 L .61055 .23605 L p F P
0 g
s
.681 .752 .905 r
.60764 .23217 m .59613 .23607 L .59322 .23307 L p F P
0 g
s
.766 .66 .745 r
.27674 .43245 m .27138 .43824 L .27867 .44024 L p F P
0 g
s
.778 .675 .75 r
.27138 .43824 m .27867 .44024 L .27149 .44774 L p F P
0 g
s
.8 .643 .687 r
.28719 .3723 m .28955 .36831 L .28506 .36678 L closepath p F P
0 g
s
.802 .641 .683 r
.28404 .36404 m .28644 .35975 L p .28955 .36831 L F P
0 g
s
.802 .641 .683 r
.28955 .36831 m .28506 .36678 L .28404 .36404 L p F P
0 g
s
.888 .497 .282 r
.07803 .46374 m .07344 .46083 L .07189 .45618 L p F P
0 g
s
.89 .496 .272 r
.06735 .45325 m .07189 .45618 L .07344 .46083 L p F P
0 g
s
.532 .541 .81 r
.70152 .2884 m .71287 .28912 L p .70957 .29535 L F P
0 g
s
.53 .544 .814 r
.70152 .2884 m .71287 .28912 L .70996 .28257 L p F P
0 g
s
.53 .544 .814 r
.70996 .28257 m .70674 .28237 L .70152 .2884 L p F P
0 g
s
.536 .553 .819 r
.69803 .28203 m .70674 .28237 L .70152 .2884 L p F P
0 g
s
.873 .753 .727 r
.05097 .35696 m .05477 .36029 L .05087 .36664 L p F P
0 g
s
.869 .755 .735 r
.05477 .36029 m .05097 .35696 L .05513 .35052 L p F P
0 g
s
.577 .448 .668 r
.51347 .34431 m .5243 .34005 L p .5187 .34952 L F P
0 g
s
.577 .448 .668 r
.5187 .34952 m .51468 .35011 L .51347 .34431 L p F P
0 g
s
.573 .442 .664 r
.52297 .33359 m .5243 .34005 L .51347 .34431 L p F P
0 g
s
.573 .442 .664 r
.52204 .33371 m .52297 .33359 L p .51347 .34431 L F P
0 g
s
.365 .217 .544 r
.74373 .42355 m .74291 .42418 L .74389 .42927 L p F P
0 g
s
.425 .708 .982 r
.13671 .49608 m .13686 .49609 L .13319 .49337 L p F P
0 g
s
.425 .708 .982 r
.13319 .49337 m .13175 .49336 L .13671 .49608 L p F P
0 g
s
.828 .645 .655 r
.27325 .32575 m .27925 .32828 L .27665 .33422 L p F P
0 g
s
.828 .638 .646 r
.27925 .32828 m .27325 .32575 L .27559 .3199 L p F P
0 g
s
.908 .666 .561 r
.05777 .43212 m .05776 .43208 L .05776 .43212 L closepath p F P
0 g
s
.501 .351 .61 r
.52917 .30343 m .53645 .29956 L .5307 .2963 L p F P
0 g
s
.503 .35 .606 r
.53849 .29223 m .5307 .2963 L .53645 .29956 L p F P
0 g
s
.492 .328 .586 r
.53794 .28654 m .53849 .29223 L .5307 .2963 L p F P
0 g
s
.913 .647 .521 r
.05775 .43217 m .05776 .43212 L .05777 .43212 L closepath p F P
0 g
s
.917 .65 .518 r
.05776 .43212 m .05775 .43217 L .05579 .43621 L p F P
0 g
s
.917 .65 .518 r
.05349 .42904 m .05776 .43212 L p .05579 .43621 L F P
0 g
s
.91 .669 .56 r
.05432 .42367 m .05349 .42904 L .05776 .43212 L p F P
0 g
s
.792 .65 .705 r
.28373 .39006 m .29086 .39215 L .28601 .39888 L p F P
0 g
s
.779 .637 .704 r
.28831 .38342 m .28373 .39006 L .29086 .39215 L p F P
0 g
s
.515 .75 .981 r
.15108 .49746 m .14745 .49448 L .13686 .49609 L p F P
0 g
s
.579 .744 .955 r
.14745 .49448 m .13686 .49609 L .13319 .49337 L p F P
0 g
s
.914 .646 .518 r
.0574 .43734 m .05579 .43621 L .05775 .43217 L closepath p F P
0 g
s
.75 .721 .825 r
.21667 .48697 m .20887 .49213 L .20541 .48812 L p F P
0 g
s
.64 .72 .905 r
.63297 .49531 m .6214 .49853 L .6185 .49468 L p F P
0 g
s
.644 .748 .925 r
.6214 .49853 m .63297 .49531 L .63583 .49857 L p F P
0 g
s
.886 .741 .696 r
.04745 .37283 m .05134 .37611 L .04825 .38219 L p F P
0 g
s
.88 .745 .708 r
.05029 .36766 m .04745 .37283 L .05134 .37611 L p F P
0 g
s
.761 .683 .776 r
.25849 .464 m .25718 .46186 L .25565 .46322 L closepath p F P
0 g
s
.766 .71 .8 r
.23461 .48102 m .23597 .47991 L .23301 .47883 L closepath p F P
0 g
s
.415 .225 .512 r
.54714 .27014 m .54375 .27219 L .54388 .27726 L p F P
0 g
s
.784 .637 .699 r
.28831 .38342 m .29033 .38045 L .28842 .37555 L p F P
0 g
s
.563 .588 .836 r
.67749 .264 m .67438 .26416 L .67643 .26187 L closepath p F P
0 g
s
.568 .597 .842 r
.6746 .2583 m .67643 .26187 L .67438 .26416 L p F P
0 g
s
.767 .709 .798 r
.24514 .47085 m .24586 .47193 L .23597 .47991 L p F P
0 g
s
.767 .709 .798 r
.2397 .46922 m .24514 .47085 L p .23597 .47991 L F P
0 g
s
.767 .709 .798 r
.23122 .47635 m .2397 .46922 L p .23597 .47991 L F P
0 g
s
.767 .709 .798 r
.23597 .47991 m .23301 .47883 L .23122 .47635 L p F P
0 g
s
.794 .299 .006 r
.08513 .471 m .08135 .46876 L .08441 .46999 L closepath p F P
0 g
s
.508 .503 .786 r
.72823 .318 m .72461 .3174 L .72212 .31109 L p F P
0 g
s
.35 .624 .955 r
.21773 .23864 m .21546 .23834 L .21194 .23493 L p F P
0 g
s
.473 .437 .738 r
.74881 .35479 m .74122 .35195 L .74632 .34697 L closepath p F P
0 g
s
.482 .451 .746 r
.74573 .3452 m .74632 .34697 L .74122 .35195 L p F P
0 g
s
.482 .451 .746 r
.73918 .34309 m .74573 .3452 L p .74122 .35195 L F P
0 g
s
.633 .686 .882 r
.61055 .23605 m .62212 .23301 L .62503 .23739 L p F P
0 g
s
.644 .701 .888 r
.62212 .23301 m .61055 .23605 L .60764 .23217 L p F P
0 g
s
.602 .485 .692 r
.50948 .37914 m .50865 .37585 L .51986 .37206 L p F P
0 g
s
.6 .482 .69 r
.51808 .36491 m .51986 .37206 L .50865 .37585 L p F P
0 g
s
.836 .647 .646 r
.26979 .31729 m .27559 .3199 L .27325 .32575 L p F P
0 g
s
.836 .639 .636 r
.27559 .3199 m .26979 .31729 L .27185 .31155 L p F P
0 g
s
.85 .401 .137 r
.08135 .46876 m .08037 .46815 L .07803 .46374 L p F P
0 g
s
.849 .396 .12 r
.07344 .46083 m .07803 .46374 L .08037 .46815 L p F P
0 g
s
.782 .664 .732 r
.27695 .42172 m .28409 .42377 L .27805 .43091 L p F P
0 g
s
.771 .649 .727 r
.28271 .41467 m .27695 .42172 L .28409 .42377 L p F P
0 g
s
.771 .649 .727 r
.28681 .41576 m .28271 .41467 L p .28409 .42377 L F P
0 g
s
.777 .676 .753 r
.26856 .45083 m .27149 .44774 L .26584 .44597 L closepath p F P
0 g
s
.778 .675 .75 r
.26528 .44495 m .27138 .43824 L p .27149 .44774 L F P
0 g
s
.778 .675 .75 r
.27149 .44774 m .26584 .44597 L .26528 .44495 L p F P
0 g
s
.775 .649 .723 r
.28681 .41576 m .28504 .41182 L .28271 .41467 L closepath p F P
0 g
s
.786 .653 .716 r
.28504 .41182 m .2881 .40775 L .28243 .40601 L closepath p F P
0 g
s
.787 .652 .713 r
.28184 .40469 m .28601 .39888 L p .2881 .40775 L F P
0 g
s
.787 .652 .713 r
.2881 .40775 m .28243 .40601 L .28184 .40469 L p F P
0 g
s
.39 .819 .652 r
.70235 .47877 m .70191 .4791 L .69038 .48564 L p F P
0 g
s
.578 .943 .846 r
.6894 .4858 m .69038 .48564 L .70191 .4791 L p F P
0 g
s
.643 .861 .982 r
.65024 .49764 m .66183 .49372 L .66349 .49479 L p F P
0 g
s
.647 .82 .966 r
.66183 .49372 m .65024 .49764 L .64742 .49507 L p F P
0 g
s
.647 .799 .956 r
.63583 .49857 m .64742 .49507 L .65024 .49764 L p F P
0 g
s
.806 .645 .682 r
.28404 .36404 m .28644 .35975 L .28178 .35807 L closepath p F P
0 g
s
.808 .642 .677 r
.28091 .35568 m .28325 .35122 L p .28644 .35975 L F P
0 g
s
.808 .642 .677 r
.28644 .35975 m .28178 .35807 L .28091 .35568 L p F P
0 g
s
.915 .673 .558 r
.05012 .42056 m .05432 .42367 L .05349 .42904 L p F P
0 g
s
.908 .687 .592 r
.05136 .41506 m .05012 .42056 L .05432 .42367 L p F P
0 g
s
.908 .687 .592 r
.0516 .41523 m .05136 .41506 L p .05432 .42367 L F P
0 g
s
.645 .763 .935 r
.64742 .49507 m .63583 .49857 L .63297 .49531 L p F P
0 g
s
.716 .74 .871 r
.17985 .4965 m .1861 .49332 L .19244 .49558 L p F P
0 g
s
.705 .736 .875 r
.19084 .49092 m .1861 .49332 L .19244 .49558 L p F P
0 g
s
.705 .736 .875 r
.19244 .49558 m .19434 .49467 L .19084 .49092 L p F P
0 g
s
.432 .36 .676 r
.74824 .39168 m .75305 .38739 L .74807 .38357 L p F P
0 g
s
.42 .339 .658 r
.74824 .39168 m .75305 .38739 L p .75032 .39769 L F P
0 g
s
.42 .339 .658 r
.75032 .39769 m .74933 .39676 L .74824 .39168 L p F P
0 g
s
.593 .059 0 r
.23296 .24773 m .23255 .24741 L .2329 .24768 L closepath p F P
0 g
s
.634 .66 .857 r
.58954 .49146 m .60107 .48856 L .60402 .49335 L p F P
0 g
s
.631 .644 .845 r
.60107 .48856 m .58954 .49146 L .58657 .48624 L p F P
0 g
s
.832 .359 .033 r
.23973 .25504 m .23536 .25184 L .23296 .24773 L p F P
0 g
s
.845 .381 .044 r
.23255 .24741 m .23296 .24773 L .23536 .25184 L p F P
0 g
s
.347 .204 .541 r
.751 .41769 m .74373 .42355 L .7442 .42903 L p F P
0 g
s
.376 .251 .58 r
.74373 .42355 m .751 .41769 L .74905 .41289 L p F P
0 g
s
.365 .217 .544 r
.74389 .42927 m .7442 .42903 L .74373 .42355 L p F P
0 g
s
.765 .672 .76 r
.26381 .4554 m .26856 .45083 L .26584 .44597 L p F P
0 g
s
.431 .361 .678 r
.75495 .37732 m .74807 .38357 L .75305 .38739 L p F P
0 g
s
.447 .384 .694 r
.74919 .37375 m .75495 .37732 L .74807 .38357 L p F P
0 g
s
.69 .901 .972 r
.58049 .23763 m .58175 .23829 L .59322 .23307 L p F P
0 g
s
.784 .637 .699 r
.28842 .37555 m .28561 .37473 L p .28831 .38342 L F P
0 g
s
.788 .636 .693 r
.28842 .37555 m .28719 .3723 L .28561 .37473 L closepath p F P
0 g
s
.63 .598 .799 r
.55459 .4741 m .56605 .47109 L p .56651 .47819 L F P
0 g
s
.626 .587 .79 r
.56417 .46691 m .56605 .47109 L .55459 .4741 L p F P
0 g
s
.626 .587 .79 r
.55459 .4741 m .55311 .47078 L .56417 .46691 L p F P
0 g
s
.636 .679 .874 r
.61557 .49043 m .61585 .49083 L .6054 .49542 L p F P
0 g
s
.636 .679 .874 r
.6054 .49542 m .60402 .49335 L .61557 .49043 L p F P
0 g
s
.591 .639 .867 r
.65236 .24334 m .64246 .24477 L .63956 .23984 L p F P
0 g
s
.844 .647 .636 r
.26625 .30885 m .27185 .31155 L .26979 .31729 L p F P
0 g
s
.846 .64 .624 r
.27185 .31155 m .26625 .30885 L .26803 .30322 L p F P
0 g
s
.774 .679 .758 r
.26381 .4554 m .25718 .46186 L .25387 .4564 L p F P
0 g
s
.774 .679 .758 r
.25387 .4564 m .25695 .45328 L .26381 .4554 L p F P
0 g
s
.765 .672 .76 r
.2646 .44562 m .25695 .45328 L .26381 .4554 L p F P
0 g
s
.765 .672 .76 r
.26584 .44597 m .2646 .44562 L p .26381 .4554 L F P
0 g
s
.604 .492 .699 r
.51052 .38308 m .50948 .37914 L .52086 .37602 L p F P
0 g
s
.602 .485 .692 r
.51986 .37206 m .52086 .37602 L .50948 .37914 L p F P
0 g
s
.628 .569 .77 r
.53404 .45589 m .54546 .45262 L .54851 .46016 L p F P
0 g
s
.625 .56 .76 r
.54511 .45171 m .54546 .45262 L .53404 .45589 L p F P
0 g
s
.625 .56 .76 r
.53404 .45589 m .53383 .45532 L .54511 .45171 L p F P
0 g
s
.573 .613 .854 r
.66501 .25323 m .65994 .25368 L .65705 .24836 L p F P
0 g
s
.895 .728 .666 r
.04546 .38818 m .04944 .39142 L .04698 .3973 L p F P
0 g
s
.889 .733 .682 r
.04944 .39142 m .04546 .38818 L .04825 .38219 L p F P
0 g
s
.771 .699 .783 r
.24586 .47193 m .24653 .47133 L .24514 .47085 L closepath p F P
0 g
s
.796 .649 .7 r
.28131 .38128 m .28831 .38342 L .28373 .39006 L p F P
0 g
s
.784 .637 .699 r
.28561 .37473 m .28131 .38128 L .28831 .38342 L p F P
0 g
s
.772 .698 .781 r
.2487 .46113 m .25565 .46322 L .24653 .47133 L p F P
0 g
s
.772 .698 .781 r
.24251 .46688 m .2487 .46113 L p .24653 .47133 L F P
0 g
s
.772 .698 .781 r
.24653 .47133 m .24514 .47085 L .24251 .46688 L p F P
0 g
s
.625 .559 .76 r
.54241 .44468 m .54511 .45171 L .53383 .45532 L p F P
0 g
s
.625 .559 .76 r
.53383 .45532 m .53099 .44794 L .54241 .44468 L p F P
0 g
s
.242 .009 .346 r
.73526 .44576 m .73306 .44732 L .72984 .45369 L p F P
0 g
s
.509 .367 .623 r
.53005 .30951 m .52917 .30343 L .53645 .29956 L p F P
0 g
s
.878 .633 .565 r
.26007 .28665 m .25824 .28559 L .2575 .27943 L p F P
0 g
s
.864 .623 .573 r
.25572 .2785 m .2575 .27943 L .25824 .28559 L p F P
0 g
s
.845 .381 .044 r
.22935 .24521 m .23255 .24741 L p .23536 .25184 L F P
0 g
s
.534 0 0 r
.22935 .24521 m .22855 .24453 L .23255 .24741 L closepath p F P
0 g
s
.761 .683 .776 r
.25387 .4564 m .2487 .46113 L .25565 .46322 L p F P
0 g
s
.761 .683 .776 r
.25565 .46322 m .25718 .46186 L .25387 .4564 L p F P
0 g
s
.527 .53 .802 r
.70957 .29535 m .71579 .2959 L p .71677 .30259 L F P
0 g
s
.525 .532 .805 r
.71579 .2959 m .70957 .29535 L .71364 .29086 L closepath p F P
0 g
s
.532 .541 .81 r
.71287 .28912 m .71364 .29086 L .70957 .29535 L p F P
0 g
s
.789 .638 .694 r
.28561 .37473 m .28719 .3723 L .28506 .36678 L p F P
0 g
s
.902 .7 .62 r
.0516 .41523 m .0514 .41493 L .05136 .41506 L closepath p F P
0 g
s
.738 .729 .843 r
.20541 .48812 m .19434 .49467 L .19084 .49092 L p F P
0 g
s
.627 .613 .816 r
.58357 .48062 m .57208 .4835 L .56907 .4775 L p F P
0 g
s
.813 .646 .676 r
.28091 .35568 m .28325 .35122 L .27857 .34943 L closepath p F P
0 g
s
.814 .643 .67 r
.27777 .34721 m .27998 .34271 L p .28325 .35122 L F P
0 g
s
.814 .643 .67 r
.28325 .35122 m .27857 .34943 L .27777 .34721 L p F P
0 g
s
.578 .454 .674 r
.51488 .35103 m .51468 .35011 L .5187 .34952 L closepath p F P
0 g
s
.853 .648 .625 r
.26264 .30044 m .26803 .30322 L .26625 .30885 L p F P
0 g
s
.856 .64 .609 r
.26803 .30322 m .26264 .30044 L .26411 .29491 L p F P
0 g
s
.905 .704 .62 r
.05136 .41506 m .0514 .41493 L .04783 .40991 L p F P
0 g
s
.604 .493 .7 r
.51246 .39042 m .51052 .38308 L .52173 .3793 L p F P
0 g
s
.604 .492 .699 r
.52086 .37602 m .52173 .3793 L .51052 .38308 L p F P
0 g
s
.775 .649 .723 r
.28271 .41467 m .28504 .41182 L .28243 .40601 L p F P
0 g
s
.912 .692 .591 r
.04724 .41191 m .05136 .41506 L .05012 .42056 L p F P
0 g
s
.905 .704 .62 r
.04783 .40991 m .04724 .41191 L .05136 .41506 L p F P
0 g
s
.48 .452 .749 r
.74573 .3452 m .73918 .34309 L .74356 .33872 L closepath p F P
0 g
s
.489 .465 .757 r
.74269 .33624 m .74356 .33872 L .73918 .34309 L p F P
0 g
s
.489 .465 .757 r
.73634 .33448 m .74269 .33624 L p .73918 .34309 L F P
0 g
s
.661 .11 0 r
.09398 .4777 m .08919 .47487 L .08513 .471 L p F P
0 g
s
.639 .085 0 r
.08135 .46876 m .08513 .471 L .08919 .47487 L p F P
0 g
s
.741 .716 .828 r
.21658 .48042 m .21034 .4847 L .21667 .48697 L p F P
0 g
s
.741 .716 .828 r
.21667 .48697 m .22001 .48478 L .21658 .48042 L p F P
0 g
s
.75 .721 .825 r
.20541 .48812 m .21034 .4847 L .21667 .48697 L p F P
0 g
s
.508 .503 .786 r
.72212 .31109 m .72298 .31014 L p .72823 .318 L F P
0 g
s
.513 .515 .795 r
.72212 .31109 m .72166 .30996 L .72298 .31014 L closepath p F P
0 g
s
.642 .75 .928 r
.15108 .49746 m .16184 .49427 L .16542 .4975 L p F P
0 g
s
.653 .751 .921 r
.16184 .49427 m .15108 .49746 L .14745 .49448 L p F P
0 g
s
.58 .46 .68 r
.51645 .35794 m .51488 .35103 L .5187 .34952 L p F P
0 g
s
.137 0 .234 r
.56224 .25135 m .5575 .2551 L .55663 .25906 L p F P
0 g
s
.017 0 0 r
.56747 .24588 m .56224 .25135 L .5575 .2551 L p F P
0 g
s
.017 0 0 r
.56805 .24525 m .56747 .24588 L p .5575 .2551 L F P
0 g
s
.895 .52 .317 r
.24562 .26267 m .24098 .25957 L .23973 .25504 L p F P
0 g
s
.905 .532 .312 r
.23536 .25184 m .23973 .25504 L .24098 .25957 L p F P
0 g
s
.782 .665 .735 r
.27674 .43245 m .27805 .43091 L .27557 .43014 L closepath p F P
0 g
s
.782 .664 .732 r
.2735 .42597 m .27695 .42172 L p .27805 .43091 L F P
0 g
s
.782 .664 .732 r
.27805 .43091 m .27557 .43014 L .2735 .42597 L p F P
0 g
s
.76 .695 .789 r
.24514 .47085 m .24251 .46688 L .2397 .46922 L closepath p F P
0 g
s
.792 .651 .707 r
.28601 .39888 m .28184 .40469 L .27864 .39749 L p F P
0 g
s
.792 .651 .707 r
.27864 .39749 m .27919 .3967 L .28601 .39888 L p F P
0 g
s
.792 .65 .705 r
.28601 .39888 m .27919 .3967 L .28373 .39006 L p F P
0 g
s
.752 .706 .808 r
.23301 .47883 m .23122 .47635 L .22939 .47771 L closepath p F P
0 g
s
.863 .647 .61 r
.25972 .29251 m .26411 .29491 L .26264 .30044 L p F P
0 g
s
.867 .638 .59 r
.25929 .29032 m .26007 .28665 L p .26411 .29491 L F P
0 g
s
.867 .638 .59 r
.26411 .29491 m .25972 .29251 L .25929 .29032 L p F P
0 g
s
.656 .865 .978 r
.66183 .49372 m .66349 .49479 L .67353 .48958 L p F P
0 g
s
.671 .883 .977 r
.67616 .49081 m .67353 .48958 L .66349 .49479 L p F P
0 g
s
.55 .417 .653 r
.52292 .33336 m .52173 .32689 L .53219 .32214 L p F P
0 g
s
.545 .41 .648 r
.53127 .31712 m .53219 .32214 L .52173 .32689 L p F P
0 g
s
.545 .41 .648 r
.52835 .31693 m .53127 .31712 L p .52173 .32689 L F P
0 g
s
.569 .43 .652 r
.52173 .32689 m .52292 .33336 L .52204 .33371 L p F P
0 g
s
.513 .515 .796 r
.72298 .31014 m .72166 .30996 L .71872 .30281 L p F P
0 g
s
.626 .586 .79 r
.56302 .46434 m .56417 .46691 L .55311 .47078 L p F P
0 g
s
.626 .586 .79 r
.55311 .47078 m .55156 .4673 L .56302 .46434 L p F P
0 g
s
0 0 0 r
.70191 .4791 m .70451 .47743 L .70235 .47877 L closepath p F P
0 g
s
0 0 0 r
.71338 .47113 m .70451 .47743 L .70235 .47877 L p F P
0 g
s
0 0 0 r
.71398 .47021 m .71338 .47113 L p .70235 .47877 L F P
0 g
s
.536 .554 .82 r
.70674 .28237 m .69803 .28203 L .69598 .27757 L p F P
0 g
s
.789 .638 .694 r
.28506 .36678 m .2828 .36607 L p .28561 .37473 L F P
0 g
s
.793 .637 .688 r
.28506 .36678 m .28404 .36404 L .2828 .36607 L closepath p F P
0 g
s
.771 .661 .742 r
.27138 .43824 m .27674 .43245 L .27557 .43014 L p F P
0 g
s
.613 .677 .887 r
.63232 .23588 m .62503 .23739 L .62212 .23301 L p F P
0 g
s
.8 .649 .695 r
.27876 .37253 m .28561 .37473 L .28131 .38128 L p F P
0 g
s
.789 .638 .694 r
.2828 .36607 m .27876 .37253 L .28561 .37473 L p F P
0 g
s
.724 .745 .868 r
.1861 .49332 m .17985 .4965 L .17631 .49302 L p F P
0 g
s
.687 .747 .897 r
.16542 .4975 m .17631 .49302 L .17985 .4965 L p F P
0 g
s
.819 .648 .669 r
.27777 .34721 m .27998 .34271 L .27544 .34087 L closepath p F P
0 g
s
.821 .644 .663 r
.27464 .33859 m .27665 .33422 L p .27998 .34271 L F P
0 g
s
.821 .644 .663 r
.27998 .34271 m .27544 .34087 L .27464 .33859 L p F P
0 g
s
.775 .649 .723 r
.2811 .40564 m .27561 .4126 L .28271 .41467 L p F P
0 g
s
.775 .649 .723 r
.28243 .40601 m .2811 .40564 L p .28271 .41467 L F P
0 g
s
.787 .664 .728 r
.27561 .4126 m .28271 .41467 L .27695 .42172 L p F P
0 g
s
.88 .75 .714 r
.05087 .36664 m .05029 .36766 L .04653 .36424 L p F P
0 g
s
.88 .75 .714 r
.04653 .36424 m .04706 .36331 L .05087 .36664 L p F P
0 g
s
.873 .753 .727 r
.05087 .36664 m .04706 .36331 L .05097 .35696 L p F P
0 g
s
.554 .58 .835 r
.67749 .264 m .68932 .26368 L p .68673 .26971 L F P
0 g
s
.553 .583 .838 r
.68643 .25787 m .68932 .26368 L .67749 .264 L p F P
0 g
s
.553 .583 .838 r
.6795 .25807 m .68643 .25787 L p .67749 .264 L F P
0 g
s
.553 .583 .838 r
.67749 .264 m .67643 .26187 L .6795 .25807 L p F P
0 g
s
.874 .646 .59 r
.25929 .29032 m .26007 .28665 L .25824 .28559 L closepath p F P
0 g
s
.892 .582 .455 r
.25089 .27051 m .24599 .26751 L .24562 .26267 L p F P
0 g
s
.903 .593 .45 r
.24098 .25957 m .24562 .26267 L .24599 .26751 L p F P
0 g
s
.695 .747 .891 r
.17631 .49302 m .16542 .4975 L .16184 .49427 L p F P
0 g
s
.421 .339 .658 r
.74965 .39827 m .74933 .39676 L .75032 .39769 L closepath p F P
0 g
s
.623 .55 .752 r
.54172 .44281 m .54241 .44468 L .53099 .44794 L p F P
0 g
s
.623 .55 .752 r
.53099 .44794 m .53044 .44645 L .54172 .44281 L p F P
0 g
s
.372 .7 .984 r
.12679 .49063 m .11911 .49035 L .11538 .48786 L p F P
0 g
s
.325 .684 .979 r
.11911 .49035 m .12679 .49063 L .13175 .49336 L p F P
0 g
s
.022 .454 .873 r
.22855 .24453 m .22434 .24125 L .21773 .23864 L p F P
0 g
s
.025 .445 .871 r
.21388 .23522 m .21773 .23864 L .22434 .24125 L p F P
0 g
s
.35 .624 .955 r
.21194 .23493 m .21388 .23522 L .21773 .23864 L p F P
0 g
s
.76 .708 .803 r
.22939 .47771 m .22001 .48478 L .21658 .48042 L p F P
0 g
s
.795 .639 .689 r
.2828 .36607 m .28404 .36404 L .28178 .35807 L p F P
0 g
s
.52 .52 .796 r
.71872 .30281 m .71677 .30259 L .71806 .30121 L closepath p F P
0 g
s
.527 .53 .802 r
.71579 .2959 m .71806 .30121 L .71677 .30259 L p F P
0 g
s
.457 .304 .584 r
.53849 .29223 m .53794 .28654 L .54573 .28177 L p F P
0 g
s
.439 .271 .555 r
.53794 .28654 m .54573 .28177 L .54388 .27726 L p F P
0 g
s
.13 .57 .924 r
.11 .48644 m .11538 .48786 L .11165 .48527 L p F P
0 g
s
.13 .57 .924 r
.11165 .48527 m .10498 .48371 L .11 .48644 L p F P
0 g
s
0 .364 .744 r
.10154 .48241 m .10498 .48371 L .11 .48644 L p F P
0 g
s
.622 .55 .752 r
.53934 .43634 m .54172 .44281 L .53044 .44645 L p F P
0 g
s
.622 .55 .752 r
.53044 .44645 m .52792 .4396 L .53934 .43634 L p F P
0 g
s
.487 .466 .76 r
.74269 .33624 m .73634 .33448 L .74056 .33016 L closepath p F P
0 g
s
.496 .478 .767 r
.73969 .32777 m .74056 .33016 L .73634 .33448 L p F P
0 g
s
.496 .478 .767 r
.73269 .32612 m .73969 .32777 L p .73634 .33448 L F P
0 g
s
.877 .609 .528 r
.25572 .2785 m .25057 .2756 L .25089 .27051 L p F P
0 g
s
.889 .62 .525 r
.24599 .26751 m .25089 .27051 L .25057 .2756 L p F P
0 g
s
.864 .623 .573 r
.25824 .28559 m .25483 .2838 L .25572 .2785 L p F P
0 g
s
.874 .632 .569 r
.25057 .2756 m .25572 .2785 L .25483 .2838 L p F P
0 g
s
.606 .496 .703 r
.51256 .39076 m .51246 .39042 L .52369 .38666 L p F P
0 g
s
.604 .493 .7 r
.52173 .3793 m .52369 .38666 L .51246 .39042 L p F P
0 g
s
.608 .504 .71 r
.51459 .39795 m .51256 .39076 L .52395 .38759 L p F P
0 g
s
.606 .496 .703 r
.52369 .38666 m .52395 .38759 L .51256 .39076 L p F P
0 g
s
.883 .749 .709 r
.04745 .37283 m .05029 .36766 L .04653 .36424 L p F P
0 g
s
.401 .308 .634 r
.75032 .39769 m .74965 .39827 L .75083 .40458 L p F P
0 g
s
.632 .665 .864 r
.61557 .49043 m .60402 .49335 L .60107 .48856 L p F P
0 g
s
.906 .707 .623 r
.04894 .40626 m .04783 .40991 L .0442 .40525 L p F P
0 g
s
.906 .707 .623 r
.0442 .40525 m .04486 .40308 L .04894 .40626 L p F P
0 g
s
.899 .717 .647 r
.04894 .40626 m .04486 .40308 L .04698 .3973 L p F P
0 g
s
.781 .669 .741 r
.27138 .43824 m .26528 .44495 L .262 .43898 L p F P
0 g
s
.781 .669 .741 r
.262 .43898 m .26452 .43611 L .27138 .43824 L p F P
0 g
s
.771 .661 .742 r
.27094 .42885 m .26452 .43611 L .27138 .43824 L p F P
0 g
s
.771 .661 .742 r
.27557 .43014 m .27094 .42885 L p .27138 .43824 L F P
0 g
s
0 0 0 r
.71338 .47113 m .71672 .46841 L .71398 .47021 L closepath p F P
0 g
s
.047 0 .028 r
.72473 .46069 m .72475 .46064 L p .71398 .47021 L F P
0 g
s
.047 0 .028 r
.71398 .47021 m .71672 .46841 L .72473 .46069 L p F P
0 g
s
.631 .6 .8 r
.56907 .4775 m .56651 .47819 L .56899 .47733 L closepath p F P
0 g
s
.63 .598 .799 r
.56605 .47109 m .56899 .47733 L .56651 .47819 L p F P
0 g
s
.826 .649 .663 r
.27464 .33859 m .27665 .33422 L .2724 .33239 L closepath p F P
0 g
s
.828 .645 .655 r
.27152 .32982 m .27325 .32575 L p .27665 .33422 L F P
0 g
s
.828 .645 .655 r
.27665 .33422 m .2724 .33239 L .27152 .32982 L p F P
0 g
s
.892 .737 .683 r
.04435 .37892 m .04825 .38219 L .04546 .38818 L p F P
0 g
s
.886 .741 .696 r
.04825 .38219 m .04435 .37892 L .04745 .37283 L p F P
0 g
s
.775 .661 .737 r
.27557 .43014 m .2735 .42597 L .27094 .42885 L closepath p F P
0 g
s
0 .419 .801 r
.10498 .48371 m .10154 .48241 L .09775 .4802 L p F P
0 g
s
.513 .515 .796 r
.71872 .30281 m .72834 .30414 L .72298 .31014 L p F P
0 g
s
.508 .503 .786 r
.72298 .31014 m .73373 .31194 L p .72823 .318 L F P
0 g
s
.505 .504 .789 r
.72298 .31014 m .73373 .31194 L .73078 .30456 L p F P
0 g
s
.505 .504 .789 r
.73078 .30456 m .72834 .30414 L .72298 .31014 L p F P
0 g
s
.371 .191 .503 r
.54721 .27525 m .54714 .27014 L .55632 .2637 L p F P
0 g
s
.415 .225 .512 r
.54388 .27726 m .54721 .27525 L .54714 .27014 L p F P
0 g
s
.324 .113 .431 r
.55663 .25906 m .55632 .2637 L .54714 .27014 L p F P
0 g
s
.493 .479 .77 r
.73969 .32777 m .73269 .32612 L .7373 .32127 L closepath p F P
0 g
s
.502 .491 .777 r
.7367 .31969 m .7373 .32127 L .73269 .32612 L p F P
0 g
s
.502 .491 .777 r
.72823 .318 m .7367 .31969 L p .73269 .32612 L F P
0 g
s
.623 .576 .781 r
.55998 .45725 m .56302 .46434 L .55156 .4673 L p F P
0 g
s
.623 .576 .781 r
.55792 .45777 m .55998 .45725 L p .55156 .4673 L F P
0 g
s
.623 .576 .781 r
.55156 .4673 m .54887 .46099 L .55792 .45777 L p F P
0 g
s
.805 .649 .69 r
.2761 .36381 m .2828 .36607 L .27876 .37253 L p F P
0 g
s
.795 .639 .689 r
.27989 .35744 m .2761 .36381 L .2828 .36607 L p F P
0 g
s
.795 .639 .689 r
.28178 .35807 m .27989 .35744 L p .2828 .36607 L F P
0 g
s
.799 .638 .682 r
.28178 .35807 m .28091 .35568 L .27989 .35744 L closepath p F P
0 g
s
.796 .649 .7 r
.28373 .39006 m .27702 .38783 L .28131 .38128 L p F P
0 g
s
.796 .655 .706 r
.27702 .38783 m .28373 .39006 L .27919 .3967 L p F P
0 g
s
.779 .649 .718 r
.28243 .40601 m .28184 .40469 L .2811 .40564 L closepath p F P
0 g
s
.5 .492 .78 r
.7367 .31969 m .72823 .318 L .73377 .31203 L closepath p F P
0 g
s
.508 .503 .786 r
.73373 .31194 m .73377 .31203 L .72823 .318 L p F P
0 g
s
.769 .672 .756 r
.26584 .44597 m .26528 .44495 L .2646 .44562 L closepath p F P
0 g
s
.608 .505 .711 r
.51563 .4016 m .51459 .39795 L .52583 .3942 L p F P
0 g
s
.608 .504 .71 r
.52395 .38759 m .52583 .3942 L .51459 .39795 L p F P
0 g
s
.62 .541 .744 r
.53858 .43419 m .53934 .43634 L .52792 .4396 L p F P
0 g
s
.62 .541 .744 r
.52792 .4396 m .52731 .43785 L .53858 .43419 L p F P
0 g
s
.583 .463 .682 r
.51645 .35794 m .52732 .35371 L p .5242 .36253 L F P
0 g
s
.583 .463 .682 r
.5242 .36253 m .51777 .36363 L .51645 .35794 L p F P
0 g
s
.58 .46 .68 r
.52608 .34834 m .52732 .35371 L .51645 .35794 L p F P
0 g
s
.58 .46 .68 r
.5187 .34952 m .52608 .34834 L p .51645 .35794 L F P
0 g
s
.801 .641 .684 r
.27989 .35744 m .28091 .35568 L .27857 .34943 L p F P
0 g
s
.677 .75 .905 r
.18328 .23414 m .19415 .22982 L .1977 .23336 L p F P
0 g
s
.576 .722 .942 r
.1977 .23336 m .20841 .23146 L .21194 .23493 L p F P
0 g
s
.576 .719 .94 r
.20841 .23146 m .1977 .23336 L .19415 .22982 L p F P
0 g
s
.62 .541 .744 r
.53627 .42758 m .53858 .43419 L .52731 .43785 L p F P
0 g
s
.62 .541 .744 r
.52731 .43785 m .52486 .43083 L .53627 .42758 L p F P
0 g
s
.56 .592 .843 r
.67643 .26187 m .6746 .2583 L .6795 .25807 L closepath p F P
0 g
s
.578 .943 .846 r
.69935 .48007 m .6978 .48086 L .6894 .4858 L p F P
0 g
s
.578 .943 .846 r
.70191 .4791 m .69935 .48007 L p .6894 .4858 L F P
0 g
s
.594 .945 .914 r
.68776 .48574 m .6978 .48086 L .6894 .4858 L closepath p F P
0 g
s
.551 .928 .912 r
.67616 .49081 m .68776 .48574 L .6894 .4858 L p F P
0 g
s
.78 .65 .718 r
.2811 .40564 m .28184 .40469 L .27864 .39749 L p F P
0 g
s
0 0 0 r
.70451 .47743 m .70191 .4791 L .69935 .48007 L p F P
0 g
s
.219 0 .339 r
.7422 .44058 m .73526 .44576 L .7348 .45018 L p F P
0 g
s
.285 .09 .43 r
.73526 .44576 m .7422 .44058 L .7437 .43472 L p F P
0 g
s
.242 .009 .346 r
.72984 .45369 m .7348 .45018 L .73526 .44576 L p F P
0 g
s
.444 .384 .696 r
.75323 .37002 m .74919 .37375 L .75495 .37732 L p F P
0 g
s
.456 .403 .711 r
.75195 .36548 m .74949 .36418 L p .74919 .37375 L F P
0 g
s
.456 .403 .711 r
.74919 .37375 m .75323 .37002 L .75195 .36548 L p F P
0 g
s
.834 .651 .655 r
.27152 .32982 m .27325 .32575 L .26947 .32402 L closepath p F P
0 g
s
.836 .647 .646 r
.26841 .32082 m .26979 .31729 L p .27325 .32575 L F P
0 g
s
.836 .647 .646 r
.27325 .32575 m .26947 .32402 L .26841 .32082 L p F P
0 g
s
.611 .512 .718 r
.51682 .40559 m .51563 .4016 L .52703 .39841 L p F P
0 g
s
.608 .505 .711 r
.52583 .3942 m .52703 .39841 L .51563 .4016 L p F P
0 g
s
.76 .708 .803 r
.21658 .48042 m .22284 .47551 L .22939 .47771 L p F P
0 g
s
.752 .705 .807 r
.22783 .47164 m .22284 .47551 L .22939 .47771 L p F P
0 g
s
.752 .705 .807 r
.22939 .47771 m .23122 .47635 L .22783 .47164 L p F P
0 g
s
.786 .666 .73 r
.2735 .42597 m .27695 .42172 L .27028 .41955 L closepath p F P
0 g
s
.787 .664 .728 r
.27025 .41948 m .27561 .4126 L p .27695 .42172 L F P
0 g
s
.787 .664 .728 r
.27695 .42172 m .27028 .41955 L .27025 .41948 L p F P
0 g
s
.573 .439 .66 r
.52297 .33359 m .52204 .33371 L .52292 .33336 L closepath p F P
0 g
s
.402 0 0 r
.09398 .4777 m .09775 .4802 L .09397 .47786 L p F P
0 g
s
.402 0 0 r
.09397 .47786 m .08919 .47487 L .09398 .4777 L p F P
0 g
s
.549 .571 .829 r
.69222 .26967 m .68673 .26971 L .69027 .26559 L closepath p F P
0 g
s
.554 .58 .835 r
.68932 .26368 m .69027 .26559 L .68673 .26971 L p F P
0 g
s
.166 0 .23 r
.72475 .46064 m .72483 .46059 L .72984 .45369 L p F P
0 g
s
.152 0 .219 r
.7348 .45018 m .72984 .45369 L .72483 .46059 L p F P
0 g
s
.401 .308 .634 r
.75083 .40458 m .7538 .40199 L .75032 .39769 L p F P
0 g
s
.401 .309 .636 r
.75737 .39143 m .75032 .39769 L .7538 .40199 L p F P
0 g
s
.42 .339 .658 r
.75305 .38739 m .75737 .39143 L .75032 .39769 L p F P
0 g
s
.768 .671 .756 r
.2646 .44562 m .26528 .44495 L .262 .43898 L p F P
0 g
s
.791 .661 .719 r
.27405 .40354 m .2811 .40564 L .27561 .4126 L p F P
0 g
s
.78 .65 .718 r
.27864 .39749 m .27405 .40354 L .2811 .40564 L p F P
0 g
s
.78 .687 .761 r
.25758 .44354 m .2646 .44562 L .25695 .45328 L p F P
0 g
s
.768 .671 .756 r
.262 .43898 m .25758 .44354 L .2646 .44562 L p F P
0 g
s
.739 .957 .943 r
.57886 .23719 m .58459 .23371 L .58049 .23763 L closepath p F P
0 g
s
.69 .901 .972 r
.59031 .23065 m .58459 .23371 L .58049 .23763 L p F P
0 g
s
.69 .901 .972 r
.59322 .23307 m .59031 .23065 L p .58049 .23763 L F P
0 g
s
.531 .917 .794 r
.58049 .23763 m .57886 .23719 L p .56805 .24525 L F P
0 g
s
.611 .513 .719 r
.51871 .41187 m .51682 .40559 L .52806 .40186 L p F P
0 g
s
.611 .512 .718 r
.52703 .39841 m .52806 .40186 L .51682 .40559 L p F P
0 g
s
.86 .638 .6 r
.25824 .28559 m .25483 .2838 L p .25886 .29208 L F P
0 g
s
.86 .638 .6 r
.25886 .29208 m .25929 .29032 L .25824 .28559 L p F P
0 g
s
.536 .554 .82 r
.69598 .27757 m .69746 .2758 L p .70674 .28237 L F P
0 g
s
.541 .563 .827 r
.69598 .27757 m .69513 .27575 L .69746 .2758 L closepath p F P
0 g
s
.768 .698 .785 r
.2397 .46922 m .23122 .47635 L .22783 .47164 L p F P
0 g
s
.58 .455 .675 r
.52608 .34834 m .5187 .34952 L .52574 .34679 L closepath p F P
0 g
s
.577 .448 .668 r
.5243 .34005 m .52574 .34679 L .5187 .34952 L p F P
0 g
s
.677 .911 .975 r
.67353 .48958 m .67616 .49081 L .68776 .48574 L p F P
0 g
s
.512 .516 .797 r
.72834 .30414 m .71872 .30281 L .71806 .30121 L p F P
0 g
s
.618 .532 .736 r
.53567 .42581 m .53627 .42758 L .52486 .43083 L p F P
0 g
s
.618 .532 .736 r
.52486 .43083 m .52441 .42948 L .53567 .42581 L p F P
0 g
s
.517 .38 .634 r
.53103 .31572 m .53005 .30951 L .54011 .30423 L p F P
0 g
s
.541 .396 .633 r
.53005 .30951 m .53103 .31572 L .52835 .31693 L p F P
0 g
s
.509 .367 .623 r
.53959 .30082 m .54011 .30423 L .53005 .30951 L p F P
0 g
s
.509 .367 .623 r
.53645 .29956 m .53959 .30082 L p .53005 .30951 L F P
0 g
s
.617 .532 .735 r
.5332 .41838 m .53567 .42581 L .52441 .42948 L p F P
0 g
s
.617 .532 .735 r
.52441 .42948 m .52178 .42161 L .5332 .41838 L p F P
0 g
s
.809 .65 .685 r
.27335 .35512 m .27989 .35744 L .2761 .36381 L p F P
0 g
s
.801 .641 .684 r
.27688 .34884 m .27335 .35512 L .27989 .35744 L p F P
0 g
s
.801 .641 .684 r
.27857 .34943 m .27688 .34884 L p .27989 .35744 L F P
0 g
s
.804 .638 .676 r
.27857 .34943 m .27777 .34721 L .27688 .34884 L closepath p F P
0 g
s
0 0 0 r
.70451 .47743 m .71186 .47279 L .71338 .47113 L closepath p F P
0 g
s
0 0 0 r
.71186 .47279 m .70451 .47743 L p .69935 .48007 L F P
0 g
s
.908 .565 .381 r
.06735 .45325 m .06287 .45027 L .06203 .44541 L p F P
0 g
s
.911 .567 .376 r
.05762 .4424 m .06203 .44541 L .06287 .45027 L p F P
0 g
s
.914 .612 .46 r
.06203 .44541 m .05762 .4424 L .0574 .43734 L p F P
0 g
s
.631 .644 .845 r
.58657 .48624 m .5981 .48343 L .60107 .48856 L p F P
0 g
s
.627 .624 .828 r
.5966 .48066 m .5981 .48343 L .58657 .48624 L p F P
0 g
s
.627 .624 .828 r
.58657 .48624 m .58588 .48496 L .5966 .48066 L p F P
0 g
s
.614 .521 .726 r
.51918 .41337 m .51871 .41187 L .53012 .40867 L p F P
0 g
s
.611 .513 .719 r
.52806 .40186 m .53012 .40867 L .51871 .41187 L p F P
0 g
s
.627 .613 .816 r
.56907 .4775 m .58057 .47468 L .58357 .48062 L p F P
0 g
s
.625 .597 .802 r
.5799 .47327 m .58057 .47468 L .56907 .4775 L p F P
0 g
s
.625 .597 .802 r
.56907 .4775 m .56899 .47733 L .5799 .47327 L p F P
0 g
s
.614 .521 .726 r
.53012 .40867 m .53042 .40965 L .51918 .41337 L p F P
0 g
s
.614 .522 .727 r
.52169 .42131 m .51918 .41337 L .53042 .40965 L p F P
0 g
s
.556 .428 .661 r
.52297 .33359 m .52292 .33336 L .53344 .32868 L p F P
0 g
s
.55 .417 .653 r
.53219 .32214 m .53344 .32868 L .52292 .33336 L p F P
0 g
s
.452 .716 .981 r
.13175 .49336 m .13319 .49337 L .12951 .49057 L p F P
0 g
s
.452 .716 .981 r
.12951 .49057 m .12679 .49063 L .13175 .49336 L p F P
0 g
s
.918 .614 .454 r
.05579 .43621 m .0574 .43734 L .05762 .4424 L p F P
0 g
s
.623 .596 .802 r
.57755 .46835 m .5799 .47327 L .56899 .47733 L p F P
0 g
s
.623 .596 .802 r
.56899 .47733 m .56605 .47109 L .57755 .46835 L p F P
0 g
s
.557 .434 .667 r
.5243 .34005 m .52297 .33359 L .53441 .3335 L p F P
0 g
s
.556 .428 .661 r
.53344 .32868 m .53441 .3335 L .52297 .33359 L p F P
0 g
s
.615 .524 .728 r
.52178 .42161 m .52169 .42131 L .53295 .41762 L p F P
0 g
s
.614 .522 .727 r
.53042 .40965 m .53295 .41762 L .52169 .42131 L p F P
0 g
s
.615 .524 .728 r
.53295 .41762 m .5332 .41838 L .52178 .42161 L p F P
0 g
s
.807 .642 .678 r
.27688 .34884 m .27777 .34721 L .27544 .34087 L p F P
0 g
s
.724 .745 .868 r
.17631 .49302 m .1803 .49087 L .1861 .49332 L p F P
0 g
s
.713 .736 .869 r
.18734 .48712 m .1803 .49087 L .1861 .49332 L p F P
0 g
s
.713 .736 .869 r
.1861 .49332 m .19084 .49092 L .18734 .48712 L p F P
0 g
s
.902 .721 .648 r
.04299 .39407 m .04698 .3973 L .04486 .40308 L p F P
0 g
s
.895 .728 .666 r
.04698 .3973 m .04299 .39407 L .04546 .38818 L p F P
0 g
s
.842 .653 .646 r
.26841 .32082 m .26979 .31729 L .26667 .31578 L closepath p F P
0 g
s
.844 .647 .636 r
.26532 .3115 m .26625 .30885 L p .26979 .31729 L F P
0 g
s
.844 .647 .636 r
.26979 .31729 m .26667 .31578 L .26532 .3115 L p F P
0 g
s
.802 .656 .701 r
.27471 .379 m .28131 .38128 L .27702 .38783 L p F P
0 g
s
.8 .649 .695 r
.28131 .38128 m .27471 .379 L .27876 .37253 L p F P
0 g
s
.779 .688 .763 r
.25387 .4564 m .25695 .45328 L .25065 .45111 L closepath p F P
0 g
s
.78 .687 .761 r
.25055 .45093 m .25758 .44354 L p .25695 .45328 L F P
0 g
s
.78 .687 .761 r
.25695 .45328 m .25065 .45111 L .25055 .45093 L p F P
0 g
s
.531 .917 .794 r
.56978 .24374 m .56805 .24525 L p .56829 .24508 L F P
0 g
s
.531 .917 .794 r
.57886 .23719 m .56978 .24374 L p .56829 .24508 L F P
0 g
s
.678 .977 .835 r
.56978 .24374 m .57644 .2377 L .57886 .23719 L closepath p F P
0 g
s
0 0 0 r
.56978 .24374 m .57644 .2377 L p .57582 .23834 L F P
0 g
s
0 0 0 r
.56629 .24812 m .56978 .24374 L .57582 .23834 L F
.56747 .24588 m .56978 .24374 L .56805 .24525 L closepath p F P
0 g
s
.442 .272 .554 r
.54721 .27525 m .54388 .27726 L .54573 .28177 L p F P
0 g
s
.328 .16 .494 r
.7442 .42903 m .74389 .42927 L .7437 .43472 L p F P
0 g
s
.757 .726 .823 r
.21034 .4847 m .20541 .48812 L .20195 .48407 L p F P
0 g
s
.738 .729 .843 r
.19084 .49092 m .20195 .48407 L .20541 .48812 L p F P
0 g
s
.569 .602 .846 r
.6717 .25272 m .66501 .25323 L .6693 .24814 L closepath p F P
0 g
s
.573 .613 .854 r
.6688 .24721 m .6693 .24814 L .66501 .25323 L p F P
0 g
s
.573 .613 .854 r
.65705 .24836 m .6688 .24721 L p .66501 .25323 L F P
0 g
s
.89 .496 .272 r
.07344 .46083 m .06892 .45789 L .06735 .45325 L p F P
0 g
s
.892 .496 .263 r
.06287 .45027 m .06735 .45325 L .06892 .45789 L p F P
0 g
s
.512 .516 .797 r
.71806 .30121 m .72204 .29659 L p .72834 .30414 L F P
0 g
s
.517 .527 .805 r
.71806 .30121 m .71579 .2959 L .72204 .29659 L closepath p F P
0 g
s
.768 .698 .785 r
.22783 .47164 m .23311 .46701 L .2397 .46922 L p F P
0 g
s
.76 .694 .789 r
.23916 .4618 m .23311 .46701 L .2397 .46922 L p F P
0 g
s
.76 .694 .789 r
.2397 .46922 m .24251 .46688 L .23916 .4618 L p F P
0 g
s
.64 .72 .905 r
.6185 .49468 m .63008 .49161 L .63297 .49531 L p F P
0 g
s
.635 .687 .881 r
.62717 .48752 m .63008 .49161 L .6185 .49468 L p F P
0 g
s
.635 .687 .881 r
.6179 .48984 m .62717 .48752 L p .6185 .49468 L F P
0 g
s
.635 .687 .881 r
.6185 .49468 m .61585 .49083 L .6179 .48984 L p F P
0 g
s
.775 .662 .738 r
.27094 .42885 m .2735 .42597 L .27028 .41955 L p F P
0 g
s
.775 .691 .771 r
.2487 .46113 m .24251 .46688 L .23916 .4618 L p F P
0 g
s
.775 .691 .771 r
.23916 .4618 m .24215 .45891 L .2487 .46113 L p F P
0 g
s
.766 .684 .772 r
.25043 .45104 m .24215 .45891 L .2487 .46113 L p F P
0 g
s
.766 .684 .772 r
.25065 .45111 m .25043 .45104 L p .2487 .46113 L F P
0 g
s
.766 .684 .772 r
.2487 .46113 m .25387 .4564 L .25065 .45111 L p F P
0 g
s
.577 .616 .855 r
.6688 .24721 m .65705 .24836 L .65414 .2431 L p F P
0 g
s
.585 .47 .688 r
.51808 .36491 m .51777 .36363 L .5242 .36253 L closepath p F P
0 g
s
.917 .65 .518 r
.05579 .43621 m .05311 .43428 L .05349 .42904 L p F P
0 g
s
.921 .654 .517 r
.04929 .42594 m .05349 .42904 L .05311 .43428 L p F P
0 g
s
.915 .673 .558 r
.05349 .42904 m .04929 .42594 L .05012 .42056 L p F P
0 g
s
.308 .145 .49 r
.75195 .4228 m .7442 .42903 L .7444 .43419 L p F P
0 g
s
.347 .204 .541 r
.7442 .42903 m .75195 .4228 L .751 .41769 L p F P
0 g
s
.328 .16 .494 r
.7437 .43472 m .7444 .43419 L .7442 .42903 L p F P
0 g
s
.541 .565 .829 r
.69746 .2758 m .69513 .27575 L .69222 .26967 L p F P
0 g
s
.623 .576 .78 r
.54887 .46099 m .54851 .46016 L .55792 .45777 L closepath p F P
0 g
s
.591 .639 .867 r
.63956 .23984 m .65125 .23805 L p .65236 .24334 L F P
0 g
s
.598 .643 .866 r
.65125 .23805 m .63956 .23984 L .63665 .23502 L p F P
0 g
s
.547 .409 .645 r
.53127 .31712 m .52835 .31693 L .53103 .31572 L closepath p F P
0 g
s
.626 .623 .828 r
.59511 .47792 m .5966 .48066 L .58588 .48496 L p F P
0 g
s
.626 .623 .828 r
.58588 .48496 m .58357 .48062 L .59511 .47792 L p F P
0 g
s
.853 .629 .599 r
.25972 .29251 m .25929 .29032 L .25886 .29208 L closepath p F P
0 g
s
.586 .474 .692 r
.51986 .37206 m .51808 .36491 L .5242 .36253 L p F P
0 g
s
.373 .249 .58 r
.7518 .41064 m .74905 .41289 L .751 .41769 L p F P
0 g
s
.397 .287 .611 r
.74905 .41289 m .7518 .41064 L .75083 .40458 L p F P
0 g
s
.81 .639 .67 r
.27544 .34087 m .27464 .33859 L .2738 .34026 L closepath p F P
0 g
s
.807 .642 .678 r
.27544 .34087 m .2738 .34026 L p .27688 .34884 L F P
0 g
s
.853 .648 .625 r
.26226 .30166 m .26264 .30044 L p .26625 .30885 L F P
0 g
s
.853 .648 .625 r
.26625 .30885 m .26406 .30772 L .26226 .30166 L p F P
0 g
s
.85 .654 .637 r
.26532 .3115 m .26625 .30885 L .26406 .30772 L closepath p F P
0 g
s
.815 .651 .68 r
.27051 .34645 m .27688 .34884 L .27335 .35512 L p F P
0 g
s
.807 .642 .678 r
.2738 .34026 m .27051 .34645 L .27688 .34884 L p F P
0 g
s
.889 .745 .697 r
.04363 .3695 m .04745 .37283 L .04435 .37892 L p F P
0 g
s
.883 .749 .709 r
.04653 .36424 m .04363 .3695 L .04745 .37283 L p F P
0 g
s
.787 .676 .742 r
.26403 .42671 m .27094 .42885 L .26452 .43611 L p F P
0 g
s
.775 .662 .738 r
.27021 .41953 m .26403 .42671 L .27094 .42885 L p F P
0 g
s
.775 .662 .738 r
.27028 .41955 m .27021 .41953 L p .27094 .42885 L F P
0 g
s
.621 .566 .771 r
.55792 .45777 m .54851 .46016 L .54546 .45262 L p F P
0 g
s
.849 .396 .12 r
.08037 .46815 m .07581 .46523 L .07344 .46083 L p F P
0 g
s
.847 .39 .104 r
.06892 .45789 m .07344 .46083 L .07581 .46523 L p F P
0 g
s
.814 .644 .671 r
.2738 .34026 m .27464 .33859 L .2724 .33239 L p F P
0 g
s
.644 .701 .888 r
.60764 .23217 m .61921 .22882 L .62212 .23301 L p F P
0 g
s
.657 .719 .894 r
.61921 .22882 m .60764 .23217 L .60473 .22862 L p F P
0 g
s
.681 .752 .905 r
.59322 .23307 m .60473 .22862 L .60764 .23217 L p F P
0 g
s
.908 .707 .619 r
.04724 .41191 m .04783 .40991 L .0442 .40525 L p F P
0 g
s
.639 .085 0 r
.08054 .46838 m .08135 .46876 L p .08919 .47487 L F P
0 g
s
.788 .289 0 r
.08054 .46838 m .08037 .46815 L .08135 .46876 L closepath p F P
0 g
s
.706 .785 .913 r
.60473 .22862 m .59322 .23307 L .59031 .23065 L p F P
0 g
s
.795 .656 .709 r
.27864 .39749 m .27919 .3967 L .27812 .39634 L closepath p F P
0 g
s
.796 .655 .706 r
.27544 .39021 m .27702 .38783 L p .27919 .3967 L F P
0 g
s
.796 .655 .706 r
.27919 .3967 m .27812 .39634 L .27544 .39021 L p F P
0 g
s
.747 .717 .824 r
.21315 .47604 m .20438 .4823 L .21034 .4847 L p F P
0 g
s
.747 .717 .824 r
.21034 .4847 m .21658 .48042 L .21315 .47604 L p F P
0 g
s
.757 .726 .823 r
.20195 .48407 m .20438 .4823 L .21034 .4847 L p F P
0 g
s
.579 .744 .955 r
.13319 .49337 m .14382 .49144 L .14745 .49448 L p F P
0 g
s
.596 .746 .949 r
.14382 .49144 m .13319 .49337 L .12951 .49057 L p F P
0 g
s
.07 0 .093 r
.72473 .46069 m .72483 .46059 L .72475 .46064 L closepath p F P
0 g
s
.554 .015 0 r
.22855 .24453 m .22935 .24521 L .22579 .24258 L p F P
0 g
s
.554 .015 0 r
.22579 .24258 m .22434 .24125 L .22855 .24453 L p F P
0 g
s
.791 .661 .719 r
.27561 .4126 m .2689 .41038 L .27405 .40354 L p F P
0 g
s
.791 .661 .72 r
.27561 .4126 m .27025 .41948 L .267 .4129 L p F P
0 g
s
.791 .661 .72 r
.267 .4129 m .2689 .41038 L .27561 .4126 L p F P
0 g
s
.34 .615 .952 r
.21388 .23522 m .21194 .23493 L .20841 .23146 L p F P
0 g
s
.381 .276 .609 r
.7538 .40199 m .75083 .40458 L .7518 .41064 L p F P
0 g
s
0 0 0 r
.72483 .46059 m .73395 .45415 L p .72334 .46399 L F P
0 g
s
0 0 0 r
.72334 .46399 m .72473 .46069 L .72483 .46059 L p F P
0 g
s
.152 0 .219 r
.72483 .46059 m .73395 .45415 L .7348 .45018 L p F P
0 g
s
.863 .647 .61 r
.26264 .30044 m .26171 .29993 L .25972 .29251 L p F P
0 g
s
.849 .64 .62 r
.25886 .29208 m .25972 .29251 L .26171 .29993 L p F P
0 g
s
.022 0 .003 r
.71672 .46841 m .72334 .46399 L .72473 .46069 L closepath p F P
0 g
s
.918 .677 .558 r
.04599 .41741 m .05012 .42056 L .04929 .42594 L p F P
0 g
s
.912 .692 .591 r
.05012 .42056 m .04599 .41741 L .04724 .41191 L p F P
0 g
s
.808 .657 .696 r
.27229 .3702 m .27876 .37253 L .27471 .379 L p F P
0 g
s
.805 .649 .69 r
.27876 .37253 m .27229 .3702 L .2761 .36381 L p F P
0 g
s
.784 .652 .716 r
.27405 .40354 m .27864 .39749 L .27812 .39634 L p F P
0 g
s
0 0 0 r
.71186 .47279 m .71338 .47113 L .71672 .46841 L p F P
0 g
s
.559 .595 .846 r
.6795 .25807 m .6746 .2583 L .6717 .25272 L p F P
0 g
s
.859 .655 .625 r
.26226 .30166 m .26264 .30044 L .26171 .29993 L closepath p F P
0 g
s
.645 .763 .935 r
.63297 .49531 m .64457 .49201 L .64742 .49507 L p F P
0 g
s
.64 .732 .915 r
.64457 .49201 m .63297 .49531 L .63008 .49161 L p F P
0 g
s
.656 .865 .978 r
.67353 .48958 m .67344 .48953 L .66183 .49372 L p F P
0 g
s
.648 .846 .976 r
.67344 .48953 m .66183 .49372 L .65903 .49141 L p F P
0 g
s
.647 .82 .966 r
.64742 .49507 m .65903 .49141 L .66183 .49372 L p F P
0 g
s
.814 .644 .671 r
.2724 .33239 m .27063 .3317 L p .2738 .34026 L F P
0 g
s
.817 .64 .663 r
.2724 .33239 m .27152 .32982 L .27063 .3317 L closepath p F P
0 g
s
0 0 0 r
.71672 .46841 m .72334 .46399 L p .71186 .47279 L F P
0 g
s
.821 .645 .664 r
.27063 .3317 m .27152 .32982 L .26947 .32402 L p F P
0 g
s
.784 .652 .716 r
.27812 .39634 m .2723 .39453 L p .27405 .40354 L F P
0 g
s
.788 .651 .712 r
.27812 .39634 m .27544 .39021 L .2723 .39453 L closepath p F P
0 g
s
.471 .328 .604 r
.53921 .29812 m .53849 .29223 L .54812 .28638 L p F P
0 g
s
.457 .304 .584 r
.54793 .28454 m .54812 .28638 L .53849 .29223 L p F P
0 g
s
.457 .304 .584 r
.54573 .28177 m .54793 .28454 L p .53849 .29223 L F P
0 g
s
.503 .35 .606 r
.53645 .29956 m .53921 .29812 L .53849 .29223 L p F P
0 g
s
.821 .652 .674 r
.26759 .3378 m .2738 .34026 L .27051 .34645 L p F P
0 g
s
.814 .644 .671 r
.27063 .3317 m .26759 .3378 L .2738 .34026 L p F P
0 g
s
.743 .729 .839 r
.20195 .48407 m .19084 .49092 L .18734 .48712 L p F P
0 g
s
.452 .402 .711 r
.75195 .36548 m .74949 .36418 L .75115 .36261 L closepath p F P
0 g
s
.464 .42 .724 r
.74949 .36418 m .75115 .36261 L .74886 .35494 L p F P
0 g
s
.899 .732 .667 r
.04155 .38491 m .04546 .38818 L .04299 .39407 L p F P
0 g
s
.892 .737 .683 r
.04546 .38818 m .04155 .38491 L .04435 .37892 L p F P
0 g
s
.918 .614 .454 r
.05316 .43671 m .05579 .43621 L p .05762 .4424 L F P
0 g
s
.92 .625 .467 r
.05316 .43671 m .05311 .43428 L .05579 .43621 L closepath p F P
0 g
s
.646 .781 .946 r
.65903 .49141 m .64742 .49507 L .64457 .49201 L p F P
0 g
s
.849 .64 .62 r
.26171 .29993 m .25716 .29769 L .25886 .29208 L p F P
0 g
s
.859 .649 .617 r
.25351 .28927 m .25886 .29208 L .25716 .29769 L p F P
0 g
s
.86 .638 .6 r
.25483 .2838 m .25351 .28927 L .25886 .29208 L p F P
0 g
s
.775 .268 0 r
.08037 .46815 m .08054 .46838 L .07669 .46639 L p F P
0 g
s
.775 .268 0 r
.07669 .46639 m .07581 .46523 L .08037 .46815 L p F P
0 g
s
.557 .434 .667 r
.53441 .3335 m .53479 .33533 L .5243 .34005 L p F P
0 g
s
.559 .437 .67 r
.52574 .34679 m .5243 .34005 L .53479 .33533 L p F P
0 g
s
.787 .676 .742 r
.25871 .43301 m .26403 .42671 L p .26452 .43611 L F P
0 g
s
.787 .676 .742 r
.26452 .43611 m .25946 .43437 L .25871 .43301 L p F P
0 g
s
.786 .678 .745 r
.262 .43898 m .26452 .43611 L .25946 .43437 L closepath p F P
0 g
s
.517 .527 .805 r
.72204 .29659 m .71579 .2959 L .71364 .29086 L p F P
0 g
s
.588 .477 .694 r
.52086 .37602 m .51986 .37206 L .53076 .36788 L p F P
0 g
s
.586 .474 .692 r
.52918 .36163 m .53076 .36788 L .51986 .37206 L p F P
0 g
s
.586 .474 .692 r
.5242 .36253 m .52918 .36163 L p .51986 .37206 L F P
0 g
s
.821 .645 .664 r
.26947 .32402 m .26739 .32316 L p .27063 .3317 L F P
0 g
s
.824 .641 .655 r
.26947 .32402 m .26841 .32082 L .26739 .32316 L closepath p F P
0 g
s
.828 .647 .656 r
.26739 .32316 m .26841 .32082 L .26667 .31578 L p F P
0 g
s
.846 .649 .636 r
.26171 .29993 m .25716 .29769 L p .26067 .30615 L F P
0 g
s
.846 .649 .636 r
.26067 .30615 m .26226 .30166 L .26171 .29993 L p F P
0 g
s
.61 .661 .875 r
.63665 .23502 m .63232 .23588 L .63518 .23265 L closepath p F P
0 g
s
.613 .677 .887 r
.63375 .23038 m .63518 .23265 L .63232 .23588 L p F P
0 g
s
.613 .677 .887 r
.62212 .23301 m .63375 .23038 L p .63232 .23588 L F P
0 g
s
.84 .641 .634 r
.26406 .30772 m .26226 .30166 L .26067 .30615 L closepath p F P
0 g
s
.905 .532 .312 r
.24098 .25957 m .23655 .25639 L .23536 .25184 L p F P
0 g
s
.913 .541 .306 r
.23116 .24856 m .23536 .25184 L .23655 .25639 L p F P
0 g
s
.845 .381 .044 r
.23536 .25184 m .23116 .24856 L .22935 .24521 L p F P
0 g
s
.915 .696 .591 r
.04318 .40872 m .04724 .41191 L .04599 .41741 L p F P
0 g
s
.908 .707 .619 r
.0442 .40525 m .04318 .40872 L .04724 .41191 L p F P
0 g
s
.639 .085 0 r
.08919 .47487 m .08447 .47201 L .08054 .46838 L p F P
0 g
s
.643 .088 0 r
.08447 .47201 m .08054 .46838 L .07669 .46639 L p F P
0 g
s
.871 .647 .596 r
.2497 .2809 m .25483 .2838 L .25351 .28927 L p F P
0 g
s
.874 .632 .569 r
.25483 .2838 m .2497 .2809 L .25057 .2756 L p F P
0 g
s
.535 .557 .824 r
.69746 .2758 m .70705 .27618 L .70414 .26989 L p F P
0 g
s
.535 .557 .824 r
.70414 .26989 m .70235 .26983 L .69746 .2758 L p F P
0 g
s
.541 .565 .829 r
.69222 .26967 m .70235 .26983 L .69746 .2758 L p F P
0 g
s
.536 .554 .82 r
.69746 .2758 m .70705 .27618 L p .70674 .28237 L F P
0 g
s
.627 .682 .882 r
.63375 .23038 m .62212 .23301 L .61921 .22882 L p F P
0 g
s
.767 .713 .802 r
.22284 .47551 m .21658 .48042 L .21315 .47604 L p F P
0 g
s
.832 .641 .646 r
.26667 .31578 m .26532 .3115 L .26407 .31464 L closepath p F P
0 g
s
.837 .648 .647 r
.26407 .31464 m .26532 .3115 L .26406 .30772 L p F P
0 g
s
0 0 0 r
.56629 .24812 m .56747 .24588 L .56978 .24374 L p F P
0 g
s
0 0 0 r
.56224 .25135 m .56629 .24812 L .56747 .24588 L closepath p F P
0 g
s
.828 .647 .656 r
.26667 .31578 m .26407 .31464 L p .26739 .32316 L F P
0 g
s
.814 .657 .688 r
.26977 .36142 m .2761 .36381 L .27229 .3702 L p F P
0 g
s
.809 .65 .685 r
.2761 .36381 m .26977 .36142 L .27335 .35512 L p F P
0 g
s
.801 .658 .705 r
.27544 .39021 m .27702 .38783 L .27387 .3867 L closepath p F P
0 g
s
.802 .656 .701 r
.27223 .38292 m .27471 .379 L p .27702 .38783 L F P
0 g
s
.802 .656 .701 r
.27702 .38783 m .27387 .3867 L .27223 .38292 L p F P
0 g
s
.627 .648 .851 r
.61263 .48575 m .60107 .48856 L .5981 .48343 L p F P
0 g
s
.632 .665 .864 r
.60107 .48856 m .61263 .48575 L .61557 .49043 L p F P
0 g
s
.837 .648 .647 r
.26406 .30772 m .26067 .30615 L p .26407 .31464 L F P
0 g
s
.528 .396 .645 r
.53103 .31572 m .54116 .31052 L p .53875 .31873 L F P
0 g
s
.528 .396 .645 r
.53875 .31873 m .53127 .31712 L .53103 .31572 L p F P
0 g
s
.517 .38 .634 r
.54011 .30423 m .54116 .31052 L .53103 .31572 L p F P
0 g
s
.839 .373 .006 r
.23116 .24856 m .22935 .24521 L .22579 .24258 L p F P
0 g
s
.773 .674 .753 r
.25758 .44354 m .262 .43898 L .25946 .43437 L p F P
0 g
s
.621 .566 .771 r
.54546 .45262 m .55693 .44974 L p .55792 .45777 L F P
0 g
s
.618 .556 .763 r
.55618 .4478 m .55693 .44974 L .54546 .45262 L p F P
0 g
s
.618 .556 .763 r
.54546 .45262 m .54511 .45171 L .55618 .4478 L p F P
0 g
s
.827 .654 .668 r
.2646 .32917 m .27063 .3317 L .26759 .3378 L p F P
0 g
s
.821 .645 .664 r
.26739 .32316 m .2646 .32917 L .27063 .3317 L p F P
0 g
s
.62 .585 .793 r
.575 .46273 m .57755 .46835 L .56605 .47109 L p F P
0 g
s
.62 .585 .793 r
.56605 .47109 m .56417 .46691 L .575 .46273 L p F P
0 g
s
.884 .642 .567 r
.24567 .27261 m .25057 .2756 L .2497 .2809 L p F P
0 g
s
.889 .62 .525 r
.25057 .2756 m .24567 .27261 L .24599 .26751 L p F P
0 g
s
.903 .593 .45 r
.24599 .26751 m .24132 .26442 L .24098 .25957 L p F P
0 g
s
.913 .604 .446 r
.23655 .25639 m .24098 .25957 L .24132 .26442 L p F P
0 g
s
.617 .555 .762 r
.55387 .44186 m .55618 .4478 L .54511 .45171 L p F P
0 g
s
.617 .555 .762 r
.54511 .45171 m .54241 .44468 L .55387 .44186 L p F P
0 g
s
.653 .751 .921 r
.14745 .49448 m .15825 .49098 L .16184 .49427 L p F P
0 g
s
.664 .751 .915 r
.15825 .49098 m .14745 .49448 L .14382 .49144 L p F P
0 g
s
.512 .368 .622 r
.53959 .30082 m .53645 .29956 L .53921 .29812 L closepath p F P
0 g
s
0 .419 .801 r
.09775 .4802 m .09999 .48096 L .10498 .48371 L p F P
0 g
s
.174 .593 .939 r
.10498 .48371 m .11165 .48527 L .10792 .48259 L p F P
0 g
s
.174 .593 .939 r
.10792 .48259 m .09999 .48096 L .10498 .48371 L p F P
0 g
s
.899 .63 .521 r
.24132 .26442 m .24599 .26751 L .24567 .27261 L p F P
0 g
s
.591 .484 .701 r
.52173 .3793 m .52086 .37602 L .53228 .37384 L p F P
0 g
s
.588 .477 .694 r
.53076 .36788 m .53228 .37384 L .52086 .37602 L p F P
0 g
s
.732 .748 .865 r
.1803 .49087 m .17631 .49302 L .17276 .4895 L p F P
0 g
s
.695 .747 .891 r
.16184 .49427 m .17276 .4895 L .17631 .49302 L p F P
0 g
s
.797 .667 .721 r
.26739 .40129 m .27405 .40354 L .2689 .41038 L p F P
0 g
s
.784 .652 .716 r
.2723 .39453 m .26739 .40129 L .27405 .40354 L p F P
0 g
s
.779 .661 .733 r
.27028 .41955 m .27025 .41948 L .27021 .41953 L closepath p F P
0 g
s
.779 .661 .733 r
.27021 .41953 m .27025 .41948 L .267 .4129 L p F P
0 g
s
.79 .673 .735 r
.26329 .41738 m .27021 .41953 L .26403 .42671 L p F P
0 g
s
.779 .661 .733 r
.267 .4129 m .26329 .41738 L .27021 .41953 L p F P
0 g
s
.782 .68 .751 r
.25758 .44354 m .25055 .45093 L .24722 .44539 L p F P
0 g
s
.782 .68 .751 r
.24722 .44539 m .25096 .44132 L .25758 .44354 L p F P
0 g
s
.773 .674 .753 r
.25789 .43389 m .25096 .44132 L .25758 .44354 L p F P
0 g
s
.773 .674 .753 r
.25946 .43437 m .25789 .43389 L p .25758 .44354 L F P
0 g
s
.137 0 .234 r
.55663 .25906 m .55827 .25778 L .56224 .25135 L p F P
0 g
s
.126 0 .226 r
.56629 .24812 m .56224 .25135 L .55827 .25778 L p F P
0 g
s
.588 .628 .859 r
.65414 .2431 m .65236 .24334 L .65352 .24199 L closepath p F P
0 g
s
.591 .639 .867 r
.65125 .23805 m .65352 .24199 L .65236 .24334 L p F P
0 g
s
.527 .4 .651 r
.53219 .32214 m .53127 .31712 L .53875 .31873 L closepath p F P
0 g
s
.767 .713 .802 r
.21315 .47604 m .21665 .47317 L .22284 .47551 L p F P
0 g
s
.757 .706 .804 r
.22443 .46691 m .21665 .47317 L .22284 .47551 L p F P
0 g
s
.757 .706 .804 r
.22284 .47551 m .22783 .47164 L .22443 .46691 L p F P
0 g
s
.431 .361 .678 r
.75518 .3775 m .75495 .37732 L p .75305 .38739 L F P
0 g
s
.431 .361 .678 r
.75305 .38739 m .75675 .38405 L .75518 .3775 L p F P
0 g
s
.416 .338 .66 r
.75675 .38405 m .75305 .38739 L .75737 .39143 L p F P
0 g
s
.025 .445 .871 r
.22434 .24125 m .22033 .23787 L .21388 .23522 L p F P
0 g
s
.035 .442 .872 r
.21016 .23174 m .21388 .23522 L .22033 .23787 L p F P
0 g
s
.34 .615 .952 r
.20841 .23146 m .21016 .23174 L .21388 .23522 L p F P
0 g
s
.403 .243 .548 r
.54755 .28068 m .54721 .27525 L .55641 .26882 L p F P
0 g
s
.371 .191 .503 r
.55632 .2637 m .55641 .26882 L .54721 .27525 L p F P
0 g
s
.442 .272 .554 r
.54573 .28177 m .54755 .28068 L .54721 .27525 L p F P
0 g
s
.622 .614 .821 r
.59511 .47792 m .58357 .48062 L .58057 .47468 L p F P
0 g
s
.702 .747 .886 r
.17276 .4895 m .16184 .49427 L .15825 .49098 L p F P
0 g
s
.591 .486 .702 r
.52369 .38666 m .52173 .3793 L .53263 .37512 L p F P
0 g
s
.591 .484 .701 r
.53228 .37384 m .53263 .37512 L .52173 .3793 L p F P
0 g
s
.789 .653 .712 r
.2723 .39453 m .27544 .39021 L .27387 .3867 L p F P
0 g
s
.834 .655 .661 r
.26154 .32055 m .26739 .32316 L .2646 .32917 L p F P
0 g
s
.828 .647 .656 r
.26407 .31464 m .26154 .32055 L .26739 .32316 L p F P
0 g
s
.266 .062 .406 r
.55827 .25778 m .55663 .25906 L .55632 .2637 L p F P
0 g
s
.819 .658 .683 r
.26715 .35267 m .27335 .35512 L .26977 .36142 L p F P
0 g
s
.815 .651 .68 r
.27335 .35512 m .26715 .35267 L .27051 .34645 L p F P
0 g
s
.541 .567 .83 r
.70235 .26983 m .69222 .26967 L .69027 .26559 L p F P
0 g
s
.91 .712 .622 r
.04486 .40308 m .0442 .40525 L .04053 .40095 L p F P
0 g
s
.91 .712 .622 r
.04053 .40095 m .04086 .39986 L .04486 .40308 L p F P
0 g
s
.902 .721 .648 r
.04486 .40308 m .04086 .39986 L .04299 .39407 L p F P
0 g
s
.769 .684 .769 r
.25065 .45111 m .25055 .45093 L .25043 .45104 L closepath p F P
0 g
s
.775 .704 .784 r
.23311 .46701 m .22783 .47164 L .22443 .46691 L p F P
0 g
s
.464 .432 .737 r
.74632 .34697 m .74744 .34581 L p .74895 .35485 L F P
0 g
s
.464 .432 .737 r
.74895 .35485 m .74881 .35479 L .74632 .34697 L p F P
0 g
s
.471 .446 .749 r
.74632 .34697 m .74573 .3452 L .74744 .34581 L closepath p F P
0 g
s
.806 .659 .7 r
.27223 .38292 m .27471 .379 L .26964 .37707 L closepath p F P
0 g
s
.808 .657 .696 r
.26902 .37563 m .27229 .3702 L p .27471 .379 L F P
0 g
s
.808 .657 .696 r
.27471 .379 m .26964 .37707 L .26902 .37563 L p F P
0 g
s
.464 .431 .737 r
.74886 .35494 m .74881 .35479 L .74895 .35485 L closepath p F P
0 g
s
.451 .412 .724 r
.74895 .35485 m .74886 .35494 L .75115 .36261 L p F P
0 g
s
.517 .527 .805 r
.71364 .29086 m .71494 .2893 L p .72204 .29659 L F P
0 g
s
.523 .538 .813 r
.71364 .29086 m .71287 .28912 L .71494 .2893 L closepath p F P
0 g
s
.471 .446 .749 r
.74744 .34581 m .74573 .3452 L .74356 .33872 L p F P
0 g
s
.769 .683 .768 r
.25043 .45104 m .25055 .45093 L .24722 .44539 L p F P
0 g
s
.782 .697 .77 r
.24366 .44888 m .25043 .45104 L .24215 .45891 L p F P
0 g
s
.769 .683 .768 r
.24722 .44539 m .24366 .44888 L .25043 .45104 L p F P
0 g
s
.372 .7 .984 r
.11538 .48786 m .12182 .48789 L .12679 .49063 L p F P
0 g
s
.412 .712 .985 r
.12182 .48789 m .11538 .48786 L .11165 .48527 L p F P
0 g
s
.895 .741 .683 r
.04052 .3756 m .04435 .37892 L .04155 .38491 L p F P
0 g
s
.889 .745 .697 r
.04435 .37892 m .04052 .3756 L .04363 .3695 L p F P
0 g
s
.775 .704 .784 r
.22443 .46691 m .22688 .46469 L .23311 .46701 L p F P
0 g
s
.765 .696 .786 r
.23579 .45671 m .22688 .46469 L .23311 .46701 L p F P
0 g
s
.765 .696 .786 r
.23311 .46701 m .23916 .4618 L .23579 .45671 L p F P
0 g
s
.589 .946 .83 r
.57644 .2377 m .57886 .23719 L .58459 .23371 L p F P
0 g
s
.452 .416 .727 r
.75474 .34885 m .74895 .35485 L .7556 .35811 L p F P
0 g
s
.464 .432 .737 r
.74744 .34581 m .75474 .34885 L .74895 .35485 L p F P
0 g
s
.451 .412 .724 r
.75115 .36261 m .7556 .35811 L .74895 .35485 L p F P
0 g
s
.615 .546 .754 r
.55276 .43887 m .55387 .44186 L .54241 .44468 L p F P
0 g
s
.615 .546 .754 r
.54241 .44468 m .54172 .44281 L .55276 .43887 L p F P
0 g
s
.564 .445 .675 r
.52608 .34834 m .52574 .34679 L .53629 .34215 L p F P
0 g
s
.559 .437 .67 r
.53479 .33533 m .53629 .34215 L .52574 .34679 L p F P
0 g
s
.782 .697 .77 r
.24215 .45891 m .23916 .4618 L .23579 .45671 L p F P
0 g
s
.782 .697 .77 r
.23579 .45671 m .23593 .45657 L .24215 .45891 L p F P
0 g
s
.782 .697 .77 r
.24215 .45891 m .23593 .45657 L .24366 .44888 L p F P
0 g
s
.619 .584 .793 r
.57453 .46169 m .575 .46273 L .56417 .46691 L p F P
0 g
s
.619 .584 .793 r
.56417 .46691 m .56302 .46434 L .57453 .46169 L p F P
0 g
s
.585 .936 .936 r
.6978 .48086 m .68776 .48574 L .68507 .48491 L p F P
0 g
s
.677 .911 .975 r
.68776 .48574 m .68507 .48491 L p .67353 .48958 L F P
0 g
s
.471 .446 .749 r
.74356 .33872 m .74518 .337 L p .74744 .34581 L F P
0 g
s
.478 .46 .76 r
.74356 .33872 m .74269 .33624 L .74518 .337 L closepath p F P
0 g
s
0 .215 .633 r
.08919 .47487 m .09397 .47786 L .09039 .47555 L p F P
0 g
s
0 .215 .633 r
.08447 .47201 m .08919 .47487 L p .09039 .47555 L F P
0 g
s
.577 .616 .855 r
.65414 .2431 m .6659 .24191 L .6688 .24721 L p F P
0 g
s
.578 .623 .861 r
.663 .23666 m .6659 .24191 L .65414 .2431 L p F P
0 g
s
.578 .623 .861 r
.65698 .23734 m .663 .23666 L p .65414 .2431 L F P
0 g
s
.578 .623 .861 r
.65414 .2431 m .65352 .24199 L .65698 .23734 L p F P
0 g
s
.614 .545 .754 r
.55081 .43358 m .55276 .43887 L .54172 .44281 L p F P
0 g
s
.614 .545 .754 r
.54172 .44281 m .53934 .43634 L .55081 .43358 L p F P
0 g
s
.732 .748 .865 r
.17276 .4895 m .17487 .4883 L .1803 .49087 L p F P
0 g
s
.72 .736 .864 r
.18382 .48329 m .17487 .4883 L .1803 .49087 L p F P
0 g
s
.72 .736 .864 r
.1803 .49087 m .18734 .48712 L .18382 .48329 L p F P
0 g
s
.841 .657 .653 r
.25841 .31196 m .26407 .31464 L .26154 .32055 L p F P
0 g
s
.837 .648 .647 r
.26067 .30615 m .25841 .31196 L .26407 .31464 L p F P
0 g
s
.789 .653 .712 r
.27387 .3867 m .2704 .38556 L p .2723 .39453 L F P
0 g
s
.793 .652 .707 r
.27387 .3867 m .27223 .38292 L .2704 .38556 L closepath p F P
0 g
s
.635 .686 .881 r
.61585 .49083 m .61557 .49043 L .6179 .48984 L closepath p F P
0 g
s
.594 .489 .705 r
.52395 .38759 m .52369 .38666 L .53464 .38254 L p F P
0 g
s
.591 .486 .702 r
.53263 .37512 m .53464 .38254 L .52369 .38666 L p F P
0 g
s
.279 .084 .427 r
.7444 .43419 m .7437 .43472 L .7422 .44058 L p F P
0 g
s
.79 .672 .734 r
.26403 .42671 m .25871 .43301 L .25542 .42699 L p F P
0 g
s
.79 .672 .734 r
.25542 .42699 m .2575 .42445 L .26403 .42671 L p F P
0 g
s
.79 .673 .735 r
.26403 .42671 m .2575 .42445 L .26329 .41738 L p F P
0 g
s
.442 .395 .71 r
.75115 .36261 m .7556 .35811 L p .75568 .3676 L F P
0 g
s
.442 .395 .71 r
.75568 .3676 m .75195 .36548 L .75115 .36261 L p F P
0 g
s
.478 .461 .76 r
.74518 .337 m .74269 .33624 L .74056 .33016 L p F P
0 g
s
.381 .276 .609 r
.7518 .41064 m .7565 .40656 L .7538 .40199 L p F P
0 g
s
.355 .237 .577 r
.7565 .40656 m .7518 .41064 L .75254 .41642 L p F P
0 g
s
.373 .249 .58 r
.751 .41769 m .75254 .41642 L .7518 .41064 L p F P
0 g
s
.596 .497 .712 r
.52583 .3942 m .52395 .38759 L .53538 .38524 L p F P
0 g
s
.594 .489 .705 r
.53464 .38254 m .53538 .38524 L .52395 .38759 L p F P
0 g
s
.565 .451 .682 r
.52732 .35371 m .52608 .34834 L .53754 .34772 L p F P
0 g
s
.564 .445 .675 r
.53629 .34215 m .53754 .34772 L .52608 .34834 L p F P
0 g
s
.586 .469 .687 r
.52918 .36163 m .5242 .36253 L .52896 .3607 L closepath p F P
0 g
s
.583 .463 .682 r
.52732 .35371 m .52896 .3607 L .5242 .36253 L p F P
0 g
s
.576 .719 .94 r
.19415 .22982 m .20488 .22793 L .20841 .23146 L p F P
0 g
s
.522 .539 .814 r
.71494 .2893 m .71287 .28912 L .70996 .28257 L p F P
0 g
s
.53 .545 .815 r
.70996 .28257 m .70674 .28237 L .7088 .27997 L closepath p F P
0 g
s
.536 .554 .82 r
.70705 .27618 m .7088 .27997 L .70674 .28237 L p F P
0 g
s
.802 .666 .713 r
.26572 .39225 m .2723 .39453 L .26739 .40129 L p F P
0 g
s
.789 .653 .712 r
.2704 .38556 m .26572 .39225 L .2723 .39453 L p F P
0 g
s
.824 .659 .678 r
.26447 .34394 m .27051 .34645 L .26715 .35267 L p F P
0 g
s
.821 .652 .674 r
.27051 .34645 m .26447 .34394 L .26759 .3378 L p F P
0 g
s
.475 .724 .979 r
.12679 .49063 m .12951 .49057 L .12583 .4877 L p F P
0 g
s
.475 .724 .979 r
.12583 .4877 m .12182 .48789 L .12679 .49063 L p F P
0 g
s
.634 .666 .863 r
.6179 .48984 m .61557 .49043 L .61263 .48575 L p F P
0 g
s
.442 .395 .71 r
.75323 .37002 m .75195 .36548 L .75568 .3676 L closepath p F P
0 g
s
.764 .73 .821 r
.20438 .4823 m .20195 .48407 L .19847 .47998 L p F P
0 g
s
.743 .729 .839 r
.18734 .48712 m .19847 .47998 L .20195 .48407 L p F P
0 g
s
.796 .669 .724 r
.267 .4129 m .2689 .41038 L .26506 .409 L closepath p F P
0 g
s
.797 .667 .721 r
.26375 .40633 m .26739 .40129 L p .2689 .41038 L F P
0 g
s
.797 .667 .721 r
.2689 .41038 m .26506 .409 L .26375 .40633 L p F P
0 g
s
.601 .657 .877 r
.64544 .22826 m .64834 .23311 L .63665 .23502 L p F P
0 g
s
.601 .657 .877 r
.63733 .22971 m .64544 .22826 L p .63665 .23502 L F P
0 g
s
.601 .657 .877 r
.63665 .23502 m .63518 .23265 L .63733 .22971 L p F P
0 g
s
.598 .643 .866 r
.63665 .23502 m .64834 .23311 L .65125 .23805 L p F P
0 g
s
0 .466 .847 r
.09999 .48096 m .09775 .4802 L .09397 .47786 L p F P
0 g
s
.911 .567 .376 r
.06287 .45027 m .05847 .44727 L .05762 .4424 L p F P
0 g
s
.915 .569 .37 r
.05328 .43936 m .05762 .4424 L .05847 .44727 L p F P
0 g
s
.918 .614 .454 r
.05762 .4424 m .05328 .43936 L .05316 .43671 L p F P
0 g
s
.559 .595 .846 r
.6717 .25272 m .68353 .2521 L p .6795 .25807 L F P
0 g
s
.559 .597 .848 r
.68063 .24655 m .68353 .2521 L .6717 .25272 L p F P
0 g
s
.559 .597 .848 r
.67005 .24712 m .68063 .24655 L p .6717 .25272 L F P
0 g
s
.559 .597 .848 r
.6717 .25272 m .6693 .24814 L .67005 .24712 L p F P
0 g
s
.777 .673 .749 r
.25946 .43437 m .25871 .43301 L .25789 .43389 L closepath p F P
0 g
s
.555 .585 .839 r
.68643 .25787 m .6795 .25807 L .68383 .2527 L closepath p F P
0 g
s
.559 .595 .846 r
.68353 .2521 m .68383 .2527 L .6795 .25807 L p F P
0 g
s
.85 .658 .643 r
.25519 .30339 m .26067 .30615 L .25841 .31196 L p F P
0 g
s
.846 .649 .636 r
.25716 .29769 m .25519 .30339 L .26067 .30615 L p F P
0 g
s
.492 .354 .621 r
.53921 .29812 m .54891 .29235 L p .54273 .30267 L F P
0 g
s
.492 .354 .621 r
.54273 .30267 m .53959 .30082 L .53921 .29812 L p F P
0 g
s
.471 .328 .604 r
.54812 .28638 m .54891 .29235 L .53921 .29812 L p F P
0 g
s
.617 .576 .786 r
.57453 .46169 m .56302 .46434 L .55998 .45725 L p F P
0 g
s
.478 .461 .76 r
.74056 .33016 m .74215 .32842 L p .74518 .337 L F P
0 g
s
.485 .474 .77 r
.74056 .33016 m .73969 .32777 L .74215 .32842 L closepath p F P
0 g
s
.531 .408 .657 r
.53344 .32868 m .53219 .32214 L .53875 .31873 L p F P
0 g
s
.611 .537 .746 r
.54961 .43021 m .55081 .43358 L .53934 .43634 L p F P
0 g
s
.611 .537 .746 r
.53934 .43634 m .53858 .43419 L .54961 .43021 L p F P
0 g
s
.813 .659 .692 r
.27229 .3702 m .26902 .37563 L .26581 .36833 L p F P
0 g
s
.813 .659 .692 r
.26581 .36833 m .26615 .36774 L .27229 .3702 L p F P
0 g
s
.814 .657 .688 r
.27229 .3702 m .26615 .36774 L .26977 .36142 L p F P
0 g
s
.583 .631 .865 r
.65352 .24199 m .65125 .23805 L .65698 .23734 L closepath p F P
0 g
s
.924 .627 .462 r
.05311 .43428 m .05316 .43671 L .04961 .43671 L p F P
0 g
s
.924 .627 .462 r
.0489 .43118 m .05311 .43428 L p .04961 .43671 L F P
0 g
s
.921 .654 .517 r
.05311 .43428 m .0489 .43118 L .04929 .42594 L p F P
0 g
s
.597 .498 .713 r
.52703 .39841 m .52583 .3942 L .53678 .39009 L p F P
0 g
s
.596 .497 .712 r
.53538 .38524 m .53678 .39009 L .52583 .3942 L p F P
0 g
s
.892 .496 .263 r
.06892 .45789 m .06445 .45491 L .06287 .45027 L p F P
0 g
s
.894 .495 .253 r
.05847 .44727 m .06287 .45027 L .06445 .45491 L p F P
0 g
s
.752 .718 .82 r
.20971 .47164 m .19871 .4798 L .20438 .4823 L p F P
0 g
s
.752 .718 .82 r
.20438 .4823 m .21315 .47604 L .20971 .47164 L p F P
0 g
s
.764 .73 .821 r
.19847 .47998 m .19871 .4798 L .20438 .4823 L p F P
0 g
s
.911 .711 .619 r
.04318 .40872 m .0442 .40525 L .04053 .40095 L p F P
0 g
s
.61 .536 .746 r
.54773 .42488 m .54961 .43021 L .53858 .43419 L p F P
0 g
s
.61 .536 .746 r
.53858 .43419 m .53627 .42758 L .54773 .42488 L p F P
0 g
s
.256 .067 .421 r
.7518 .42825 m .7444 .43419 L .74429 .439 L p F P
0 g
s
.279 .084 .427 r
.7422 .44058 m .74429 .439 L .7444 .43419 L p F P
0 g
s
.308 .145 .49 r
.7444 .43419 m .7518 .42825 L .75195 .4228 L p F P
0 g
s
.795 .655 .708 r
.2704 .38556 m .27223 .38292 L .26964 .37707 L p F P
0 g
s
.126 0 .209 r
.73922 .44689 m .7348 .45018 L .73395 .45415 L p F P
0 g
s
.219 0 .339 r
.7348 .45018 m .73922 .44689 L .7422 .44058 L p F P
0 g
s
.905 .726 .648 r
.03907 .39081 m .04299 .39407 L .04086 .39986 L p F P
0 g
s
.899 .732 .667 r
.04299 .39407 m .03907 .39081 L .04155 .38491 L p F P
0 g
s
.444 .384 .696 r
.75495 .37732 m .75511 .37718 L .75323 .37002 L p F P
0 g
s
.429 .375 .696 r
.75568 .3676 m .75323 .37002 L .75511 .37718 L p F P
0 g
s
.485 .474 .77 r
.74215 .32842 m .73969 .32777 L .7373 .32127 L p F P
0 g
s
.266 .062 .406 r
.55632 .2637 m .55667 .26342 L .55827 .25778 L p F P
0 g
s
.259 .056 .403 r
.56543 .25207 m .55827 .25778 L .55667 .26342 L p F P
0 g
s
.126 0 .226 r
.55827 .25778 m .56543 .25207 L .56629 .24812 L p F P
0 g
s
.379 .275 .609 r
.75941 .39704 m .7538 .40199 L .7565 .40656 L p F P
0 g
s
.401 .309 .636 r
.75864 .39299 m .75737 .39143 L p .7538 .40199 L F P
0 g
s
.401 .309 .636 r
.7538 .40199 m .75941 .39704 L .75864 .39299 L p F P
0 g
s
.589 .946 .83 r
.58459 .23371 m .58853 .2296 L p .57644 .2377 L F P
0 g
s
.734 .895 .952 r
.58459 .23371 m .58853 .2296 L .59031 .23065 L closepath p F P
0 g
s
.597 .498 .713 r
.53678 .39009 m .53848 .39598 L .52703 .39841 L p F P
0 g
s
.599 .506 .72 r
.52806 .40186 m .52703 .39841 L .53848 .39598 L p F P
0 g
s
.461 .306 .584 r
.54793 .28454 m .54573 .28177 L .54755 .28068 L closepath p F P
0 g
s
.784 .665 .732 r
.26329 .41738 m .267 .4129 L .26506 .409 L p F P
0 g
s
.827 .654 .668 r
.26759 .3378 m .26171 .33522 L .2646 .32917 L p F P
0 g
s
.83 .66 .672 r
.26171 .33522 m .26759 .3378 L .26447 .34394 L p F P
0 g
s
.777 .673 .749 r
.25789 .43389 m .25871 .43301 L .25542 .42699 L p F P
0 g
s
.461 .432 .74 r
.7531 .33983 m .74744 .34581 L .75474 .34885 L p F P
0 g
s
.471 .446 .749 r
.74518 .337 m .7531 .33983 L .74744 .34581 L p F P
0 g
s
.924 .658 .515 r
.04515 .4228 m .04929 .42594 L .0489 .43118 L p F P
0 g
s
.918 .677 .558 r
.04929 .42594 m .04515 .4228 L .04599 .41741 L p F P
0 g
s
.859 .659 .631 r
.25188 .29485 m .25716 .29769 L .25519 .30339 L p F P
0 g
s
.859 .649 .617 r
.25716 .29769 m .25188 .29485 L .25351 .28927 L p F P
0 g
s
.601 .508 .72 r
.52806 .40186 m .53901 .39775 L p .5372 .40712 L F P
0 g
s
.601 .508 .72 r
.5372 .40712 m .53012 .40867 L .52806 .40186 L p F P
0 g
s
.599 .506 .72 r
.53848 .39598 m .53901 .39775 L .52806 .40186 L p F P
0 g
s
.789 .686 .75 r
.25117 .43169 m .25789 .43389 L .25096 .44132 L p F P
0 g
s
.777 .673 .749 r
.25542 .42699 m .25117 .43169 L .25789 .43389 L p F P
0 g
s
.541 .567 .83 r
.69027 .26559 m .69176 .26367 L p .70235 .26983 L F P
0 g
s
.546 .576 .836 r
.69027 .26559 m .68932 .26368 L .69176 .26367 L closepath p F P
0 g
s
.608 .527 .738 r
.54669 .42181 m .54773 .42488 L .53627 .42758 L p F P
0 g
s
.608 .527 .738 r
.53627 .42758 m .53567 .42581 L .54669 .42181 L p F P
0 g
s
.567 .454 .684 r
.52896 .3607 m .52732 .35371 L .53785 .34905 L p F P
0 g
s
.565 .451 .682 r
.53754 .34772 m .53785 .34905 L .52732 .35371 L p F P
0 g
s
.847 .39 .104 r
.07581 .46523 m .07131 .46228 L .06892 .45789 L p F P
0 g
s
.845 .384 .087 r
.06445 .45491 m .06892 .45789 L .07131 .46228 L p F P
0 g
s
.607 .526 .738 r
.54465 .41574 m .54669 .42181 L .53567 .42581 L p F P
0 g
s
.607 .526 .738 r
.53567 .42581 m .5332 .41838 L .54465 .41574 L p F P
0 g
s
.635 .675 .871 r
.62717 .48752 m .6179 .48984 L .62628 .48614 L closepath p F P
0 g
s
.634 .666 .863 r
.62424 .48301 m .62628 .48614 L .6179 .48984 L p F P
0 g
s
.634 .666 .863 r
.61263 .48575 m .62424 .48301 L p .6179 .48984 L F P
0 g
s
.622 .568 .773 r
.55998 .45725 m .55792 .45777 L .55991 .45708 L closepath p F P
0 g
s
.621 .566 .771 r
.55693 .44974 m .55991 .45708 L .55792 .45777 L p F P
0 g
s
.343 .202 .541 r
.75254 .41642 m .751 .41769 L .75195 .4228 L p F P
0 g
s
.603 .515 .728 r
.53042 .40965 m .53012 .40867 L .5372 .40712 L closepath p F P
0 g
s
.603 .516 .729 r
.53295 .41762 m .53042 .40965 L .5372 .40712 L p F P
0 g
s
.605 .518 .73 r
.5332 .41838 m .53295 .41762 L .54396 .4136 L p F P
0 g
s
.603 .516 .729 r
.54157 .40614 m .54396 .4136 L .53295 .41762 L p F P
0 g
s
.603 .516 .729 r
.5372 .40712 m .54157 .40614 L p .53295 .41762 L F P
0 g
s
.605 .518 .73 r
.54396 .4136 m .54465 .41574 L .5332 .41838 L p F P
0 g
s
.805 .665 .709 r
.2639 .38324 m .2704 .38556 L .26572 .39225 L p F P
0 g
s
.795 .655 .708 r
.26836 .37663 m .2639 .38324 L .2704 .38556 L p F P
0 g
s
.795 .655 .708 r
.26964 .37707 m .26836 .37663 L p .2704 .38556 L F P
0 g
s
.56 .032 0 r
.22434 .24125 m .22579 .24258 L .22223 .23973 L p F P
0 g
s
.56 .032 0 r
.22223 .23973 m .22033 .23787 L .22434 .24125 L p F P
0 g
s
.627 .648 .851 r
.5981 .48343 m .60968 .48074 L .61263 .48575 L p F P
0 g
s
.622 .626 .834 r
.60705 .47601 m .60968 .48074 L .5981 .48343 L p F P
0 g
s
.622 .626 .834 r
.5981 .48343 m .5966 .48066 L .60705 .47601 L p F P
0 g
s
.517 .527 .805 r
.71494 .2893 m .72491 .29041 L p .72204 .29659 L F P
0 g
s
.515 .529 .808 r
.71494 .2893 m .72491 .29041 L .72198 .28365 L p F P
0 g
s
.515 .529 .808 r
.72198 .28365 m .71976 .2834 L .71494 .2893 L p F P
0 g
s
.522 .539 .814 r
.70996 .28257 m .71976 .2834 L .71494 .2893 L p F P
0 g
s
.818 .663 .69 r
.26375 .35892 m .26977 .36142 L .26615 .36774 L p F P
0 g
s
.819 .658 .683 r
.26977 .36142 m .26375 .35892 L .26715 .35267 L p F P
0 g
s
.622 .614 .821 r
.58057 .47468 m .59212 .47206 L .59511 .47792 L p F P
0 g
s
.619 .597 .806 r
.59058 .4689 m .59212 .47206 L .58057 .47468 L p F P
0 g
s
.619 .597 .806 r
.58057 .47468 m .5799 .47327 L .59058 .4689 L p F P
0 g
s
.657 .719 .894 r
.60473 .22862 m .6163 .22484 L .61921 .22882 L p F P
0 g
s
.675 .742 .901 r
.6163 .22484 m .60473 .22862 L .60182 .22545 L p F P
0 g
s
.706 .785 .913 r
.59031 .23065 m .60182 .22545 L .60473 .22862 L p F P
0 g
s
.869 .659 .615 r
.24843 .28635 m .25351 .28927 L .25188 .29485 L p F P
0 g
s
.871 .647 .596 r
.25351 .28927 m .24843 .28635 L .2497 .2809 L p F P
0 g
s
.488 .355 .626 r
.54011 .30423 m .53959 .30082 L .54273 .30267 L closepath p F P
0 g
s
.64 .732 .915 r
.63008 .49161 m .6417 .48851 L .64457 .49201 L p F P
0 g
s
.635 .706 .898 r
.6417 .48851 m .63008 .49161 L .62717 .48752 L p F P
0 g
s
.485 .474 .77 r
.7373 .32127 m .73836 .32007 L p .74215 .32842 L F P
0 g
s
.492 .487 .78 r
.7373 .32127 m .7367 .31969 L .73836 .32007 L closepath p F P
0 g
s
.658 .889 .981 r
.67344 .48953 m .674 .48931 L .67353 .48958 L closepath p F P
0 g
s
.677 .911 .975 r
.68507 .48491 m .674 .48931 L .67353 .48958 L p F P
0 g
s
.922 .681 .557 r
.04193 .41423 m .04599 .41741 L .04515 .4228 L p F P
0 g
s
.915 .696 .591 r
.04599 .41741 m .04193 .41423 L .04318 .40872 L p F P
0 g
s
.427 .359 .678 r
.75518 .3775 m .75495 .37732 L .75511 .37718 L closepath p F P
0 g
s
.796 .679 .735 r
.25675 .41511 m .26329 .41738 L .2575 .42445 L p F P
0 g
s
.784 .665 .732 r
.26233 .40811 m .25675 .41511 L .26329 .41738 L p F P
0 g
s
.784 .665 .732 r
.26506 .409 m .26233 .40811 L p .26329 .41738 L F P
0 g
s
.836 .662 .666 r
.25888 .32652 m .2646 .32917 L .26171 .33522 L p F P
0 g
s
.834 .655 .661 r
.2646 .32917 m .25888 .32652 L .26154 .32055 L p F P
0 g
s
.801 .667 .715 r
.26739 .40129 m .26375 .40633 L .26049 .39976 L p F P
0 g
s
.801 .667 .715 r
.26049 .39976 m .26108 .39893 L .26739 .40129 L p F P
0 g
s
.802 .666 .713 r
.26739 .40129 m .26108 .39893 L .26572 .39225 L p F P
0 g
s
.747 .727 .833 r
.19847 .47998 m .18734 .48712 L .18382 .48329 L p F P
0 g
s
.649 .872 .982 r
.674 .48931 m .67344 .48953 L .67068 .48753 L p F P
0 g
s
.648 .846 .976 r
.65903 .49141 m .67068 .48753 L .67344 .48953 L p F P
0 g
s
.335 .609 .949 r
.21016 .23174 m .20841 .23146 L .20488 .22793 L p F P
0 g
s
.789 .686 .75 r
.25096 .44132 m .24722 .44539 L .24389 .43986 L p F P
0 g
s
.789 .686 .75 r
.24389 .43986 m .24467 .43899 L .25096 .44132 L p F P
0 g
s
.789 .686 .75 r
.25096 .44132 m .24467 .43899 L .25117 .43169 L p F P
0 g
s
.416 .351 .677 r
.75511 .37718 m .76112 .37128 L p .75969 .38123 L F P
0 g
s
.416 .351 .677 r
.75969 .38123 m .75518 .3775 L .75511 .37718 L p F P
0 g
s
.429 .375 .696 r
.75511 .37718 m .76112 .37128 L .75568 .3676 L p F P
0 g
s
.491 .487 .78 r
.73836 .32007 m .7367 .31969 L .73377 .31203 L p F P
0 g
s
.773 .718 .8 r
.21665 .47317 m .21315 .47604 L .20971 .47164 L p F P
0 g
s
.416 .351 .676 r
.75675 .38405 m .75518 .3775 L .75969 .38123 L closepath p F P
0 g
s
.545 .579 .839 r
.69176 .26367 m .68932 .26368 L .68643 .25787 L p F P
0 g
s
.596 .746 .949 r
.12951 .49057 m .14018 .48833 L .14382 .49144 L p F P
0 g
s
.61 .748 .943 r
.14018 .48833 m .12951 .49057 L .12583 .4877 L p F P
0 g
s
.884 .642 .567 r
.2497 .2809 m .24482 .2779 L .24567 .27261 L p F P
0 g
s
.881 .657 .594 r
.24482 .2779 m .2497 .2809 L .24843 .28635 L p F P
0 g
s
.649 .872 .982 r
.68322 .4839 m .674 .48931 L p .67068 .48753 L F P
0 g
s
.664 .891 .98 r
.674 .48931 m .68322 .4839 L .68507 .48491 L closepath p F P
0 g
s
.478 .461 .76 r
.74215 .32842 m .75067 .33104 L .74518 .337 L p F P
0 g
s
.469 .448 .752 r
.75067 .33104 m .74518 .337 L .7531 .33983 L p F P
0 g
s
.617 .596 .806 r
.58911 .46585 m .59058 .4689 L .5799 .47327 L p F P
0 g
s
.617 .596 .806 r
.5799 .47327 m .57755 .46835 L .58911 .46585 L p F P
0 g
s
.798 .654 .703 r
.26964 .37707 m .26902 .37563 L .26836 .37663 L closepath p F P
0 g
s
.761 .248 0 r
.07581 .46523 m .07669 .46639 L .07284 .46424 L p F P
0 g
s
.761 .248 0 r
.07284 .46424 m .07131 .46228 L .07581 .46523 L p F P
0 g
s
.773 .718 .8 r
.20971 .47164 m .21077 .47073 L .21665 .47317 L p F P
0 g
s
.763 .708 .8 r
.22091 .46227 m .21077 .47073 L .21665 .47317 L p F P
0 g
s
.763 .708 .8 r
.22116 .46236 m .22091 .46227 L p .21665 .47317 L F P
0 g
s
.763 .708 .8 r
.21665 .47317 m .22443 .46691 L .22116 .46236 L p F P
0 g
s
.605 .663 .88 r
.63518 .23265 m .63375 .23038 L .63733 .22971 L closepath p F P
0 g
s
.787 .664 .727 r
.26506 .409 m .26375 .40633 L .26233 .40811 L closepath p F P
0 g
s
.614 .564 .774 r
.57077 .45291 m .57149 .45465 L .55998 .45725 L p F P
0 g
s
.614 .564 .774 r
.55998 .45725 m .55991 .45708 L .57077 .45291 L p F P
0 g
s
.617 .576 .786 r
.55998 .45725 m .57149 .45465 L .57453 .46169 L p F P
0 g
s
.612 .562 .774 r
.56844 .44724 m .57077 .45291 L .55991 .45708 L p F P
0 g
s
.612 .562 .774 r
.55991 .45708 m .55693 .44974 L .56844 .44724 L p F P
0 g
s
.627 .682 .882 r
.61921 .22882 m .63084 .22594 L .63375 .23038 L p F P
0 g
s
.637 .695 .887 r
.63084 .22594 m .61921 .22882 L .6163 .22484 L p F P
0 g
s
.902 .736 .668 r
.03772 .3816 m .04155 .38491 L .03907 .39081 L p F P
0 g
s
.895 .741 .683 r
.04155 .38491 m .03772 .3816 L .04052 .3756 L p F P
0 g
s
.439 .29 .581 r
.54755 .28068 m .5568 .2743 L p .54883 .2859 L F P
0 g
s
.439 .29 .581 r
.54883 .2859 m .54793 .28454 L .54755 .28068 L p F P
0 g
s
.403 .243 .548 r
.55641 .26882 m .5568 .2743 L .54755 .28068 L p F P
0 g
s
.522 .54 .816 r
.71976 .2834 m .70996 .28257 L .7088 .27997 L p F P
0 g
s
.8 .656 .704 r
.26836 .37663 m .26902 .37563 L .26581 .36833 L p F P
0 g
s
.774 .686 .766 r
.24366 .44888 m .24722 .44539 L .24389 .43986 L p F P
0 g
s
.913 .541 .306 r
.23655 .25639 m .2323 .25313 L .23116 .24856 L p F P
0 g
s
.921 .549 .299 r
.22712 .24522 m .23116 .24856 L .2323 .25313 L p F P
0 g
s
.839 .373 .006 r
.22579 .24258 m .22712 .24522 L .23116 .24856 L p F P
0 g
s
.894 .651 .564 r
.24099 .26953 m .24567 .27261 L .24482 .2779 L p F P
0 g
s
.899 .63 .521 r
.24567 .27261 m .24099 .26953 L .24132 .26442 L p F P
0 g
s
.54 .418 .663 r
.53344 .32868 m .54359 .3235 L p .53765 .33387 L F P
0 g
s
.54 .418 .663 r
.53765 .33387 m .53441 .3335 L .53344 .32868 L p F P
0 g
s
.531 .408 .657 r
.54277 .3194 m .54359 .3235 L .53344 .32868 L p F P
0 g
s
.531 .408 .657 r
.53875 .31873 m .54277 .3194 L p .53344 .32868 L F P
0 g
s
.641 .748 .926 r
.65621 .48859 m .64457 .49201 L .6417 .48851 L p F P
0 g
s
.646 .781 .946 r
.64457 .49201 m .65621 .48859 L .65903 .49141 L p F P
0 g
s
.512 .516 .797 r
.72204 .29659 m .72784 .2974 L p .72834 .30414 L F P
0 g
s
.51 .517 .8 r
.72784 .2974 m .72204 .29659 L .72571 .29228 L closepath p F P
0 g
s
.517 .527 .805 r
.72491 .29041 m .72571 .29228 L .72204 .29659 L p F P
0 g
s
.922 .618 .451 r
.05328 .43936 m .04961 .43671 L .05316 .43671 L closepath p F P
0 g
s
.695 .888 .968 r
.58853 .2296 m .59031 .23065 L .60182 .22545 L p F P
0 g
s
.571 .46 .688 r
.52918 .36163 m .52896 .3607 L .53956 .35612 L p F P
0 g
s
.567 .454 .684 r
.53785 .34905 m .53956 .35612 L .52896 .3607 L p F P
0 g
s
.214 .612 .951 r
.09999 .48096 m .10792 .48259 L .10418 .47983 L p F P
0 g
s
.214 .612 .951 r
.10418 .47983 m .09504 .47819 L .09999 .48096 L p F P
0 g
s
0 .466 .847 r
.09397 .47786 m .09504 .47819 L .09999 .48096 L p F P
0 g
s
.825 .665 .684 r
.26127 .35011 m .26715 .35267 L .26375 .35892 L p F P
0 g
s
.824 .659 .678 r
.26715 .35267 m .26127 .35011 L .26447 .34394 L p F P
0 g
s
.785 .699 .769 r
.23725 .44659 m .24366 .44888 L .23593 .45657 L p F P
0 g
s
.774 .686 .766 r
.24389 .43986 m .23725 .44659 L .24366 .44888 L p F P
0 g
s
.843 .664 .659 r
.25599 .31784 m .26154 .32055 L .25888 .32652 L p F P
0 g
s
.841 .657 .653 r
.26154 .32055 m .25599 .31784 L .25841 .31196 L p F P
0 g
s
.909 .64 .518 r
.23686 .26125 m .24132 .26442 L .24099 .26953 L p F P
0 g
s
.913 .604 .446 r
.24132 .26442 m .23686 .26125 L .23655 .25639 L p F P
0 g
s
.648 .804 .958 r
.67068 .48753 m .65903 .49141 L .65621 .48859 L p F P
0 g
s
.922 .613 .441 r
.2323 .25313 m .23655 .25639 L .23686 .26125 L p F P
0 g
s
.911 .711 .619 r
.04053 .40095 m .03919 .4055 L .04318 .40872 L p F P
0 g
s
.919 .7 .59 r
.03919 .4055 m .04318 .40872 L .04193 .41423 L p F P
0 g
s
.575 .942 .88 r
.6978 .48086 m .69909 .48009 L .69935 .48007 L closepath p F P
0 g
s
.585 .936 .936 r
.69909 .48009 m .6978 .48086 L p .68507 .48491 L F P
0 g
s
.808 .665 .705 r
.26196 .37426 m .26836 .37663 L .2639 .38324 L p F P
0 g
s
.8 .656 .704 r
.26581 .36833 m .26196 .37426 L .26836 .37663 L p F P
0 g
s
.573 .467 .695 r
.53076 .36788 m .52918 .36163 L .54066 .36058 L p F P
0 g
s
.571 .46 .688 r
.53956 .35612 m .54066 .36058 L .52918 .36163 L p F P
0 g
s
0 0 0 r
.72243 .4653 m .71593 .47009 L .71186 .47279 L p F P
0 g
s
.398 .808 .6 r
.71092 .47339 m .71593 .47009 L .71186 .47279 L closepath p F P
0 g
s
0 0 0 r
.72334 .46399 m .72243 .4653 L p .71186 .47279 L F P
0 g
s
0 0 0 r
.69935 .48007 m .71092 .47339 L .71186 .47279 L p F P
0 g
s
.476 .463 .763 r
.74747 .32249 m .74215 .32842 L .75067 .33104 L p F P
0 g
s
.485 .474 .77 r
.73836 .32007 m .74747 .32249 L .74215 .32842 L p F P
0 g
s
.779 .711 .788 r
.22443 .46691 m .22688 .46469 L .22116 .46236 L closepath p F P
0 g
s
.78 .71 .786 r
.23562 .45645 m .23579 .45671 L .22688 .46469 L p F P
0 g
s
.78 .71 .786 r
.22942 .45432 m .23562 .45645 L p .22688 .46469 L F P
0 g
s
.78 .71 .786 r
.22103 .46217 m .22942 .45432 L p .22688 .46469 L F P
0 g
s
.78 .71 .786 r
.22688 .46469 m .22116 .46236 L .22103 .46217 L p F P
0 g
s
.565 .606 .853 r
.6693 .24814 m .6688 .24721 L .67005 .24712 L closepath p F P
0 g
s
.21 0 .333 r
.74429 .439 m .7422 .44058 L .73922 .44689 L p F P
0 g
s
.062 0 .201 r
.57096 .24392 m .56629 .24812 L .56543 .25207 L p F P
0 g
s
0 0 0 r
.57644 .2377 m .57599 .23812 L p .56629 .24812 L F P
0 g
s
0 0 0 r
.57599 .23812 m .57096 .24392 L .56629 .24812 L p F P
0 g
s
.739 .75 .862 r
.17487 .4883 m .17276 .4895 L .1692 .48593 L p F P
0 g
s
.702 .747 .886 r
.15825 .49098 m .1692 .48593 L .17276 .4895 L p F P
0 g
s
.622 .626 .833 r
.6067 .47538 m .60705 .47601 L .5966 .48066 L p F P
0 g
s
.622 .626 .833 r
.5966 .48066 m .59511 .47792 L .6067 .47538 L p F P
0 g
s
.496 .37 .638 r
.54273 .30267 m .54011 .30423 L .54116 .31052 L p F P
0 g
s
.784 .701 .772 r
.23579 .45671 m .23593 .45657 L .23562 .45645 L closepath p F P
0 g
s
.785 .699 .769 r
.23243 .45156 m .23725 .44659 L p .23593 .45657 L F P
0 g
s
.785 .699 .769 r
.23593 .45657 m .23562 .45645 L .23243 .45156 L p F P
0 g
s
.795 .68 .738 r
.25542 .42699 m .2575 .42445 L .25311 .4228 L closepath p F P
0 g
s
.796 .679 .735 r
.25212 .42098 m .25675 .41511 L p .2575 .42445 L F P
0 g
s
.796 .679 .735 r
.2575 .42445 m .25311 .4228 L .25212 .42098 L p F P
0 g
s
.323 .188 .537 r
.75835 .41139 m .75254 .41642 L .75303 .42192 L p F P
0 g
s
.355 .237 .577 r
.75254 .41642 m .75835 .41139 L .7565 .40656 L p F P
0 g
s
.343 .202 .541 r
.75195 .4228 m .75303 .42192 L .75254 .41642 L p F P
0 g
s
.627 .961 .883 r
.69909 .48009 m .69935 .48007 L .71092 .47339 L p F P
0 g
s
.512 .516 .797 r
.72784 .2974 m .7299 .30237 L .72834 .30414 L p F P
0 g
s
.504 .505 .791 r
.73078 .30456 m .72834 .30414 L .7299 .30237 L closepath p F P
0 g
s
.788 .666 .728 r
.26233 .40811 m .26375 .40633 L .26049 .39976 L p F P
0 g
s
.773 .696 .779 r
.23562 .45645 m .23243 .45156 L .22942 .45432 L closepath p F P
0 g
s
.664 .751 .915 r
.14382 .49144 m .15465 .48765 L .15825 .49098 L p F P
0 g
s
.673 .751 .91 r
.15465 .48765 m .14382 .49144 L .14018 .48833 L p F P
0 g
s
.583 .636 .869 r
.65698 .23734 m .65125 .23805 L .64834 .23311 L p F P
0 g
s
.484 .477 .774 r
.74348 .31417 m .73836 .32007 L .74747 .32249 L p F P
0 g
s
.491 .487 .78 r
.73383 .31196 m .74348 .31417 L .73836 .32007 L p F P
0 g
s
.491 .487 .78 r
.73377 .31203 m .73383 .31196 L p .73836 .32007 L F P
0 g
s
.806 .671 .714 r
.25947 .38985 m .26572 .39225 L .26108 .39893 L p F P
0 g
s
.805 .665 .709 r
.26572 .39225 m .25947 .38985 L .2639 .38324 L p F P
0 g
s
.527 .55 .823 r
.7088 .27997 m .70705 .27618 L .71154 .27645 L closepath p F P
0 g
s
.522 .54 .816 r
.7088 .27997 m .71154 .27645 L p .71976 .2834 L F P
0 g
s
.498 .5 .789 r
.73377 .31203 m .73373 .31194 L .73383 .31196 L closepath p F P
0 g
s
.497 .501 .79 r
.73383 .31196 m .73373 .31194 L .73078 .30456 L p F P
0 g
s
.851 .665 .651 r
.25303 .30918 m .25841 .31196 L .25599 .31784 L p F P
0 g
s
.85 .658 .643 r
.25841 .31196 m .25303 .30918 L .25519 .30339 L p F P
0 g
s
.491 .49 .784 r
.73873 .3061 m .73383 .31196 L .74348 .31417 L p F P
0 g
s
.497 .501 .79 r
.73078 .30456 m .73873 .3061 L .73383 .31196 L p F P
0 g
s
.035 .442 .872 r
.22033 .23787 m .21652 .23442 L .21016 .23174 L p F P
0 g
s
.054 .444 .876 r
.20656 .2282 m .21016 .23174 L .21652 .23442 L p F P
0 g
s
.335 .609 .949 r
.20488 .22793 m .20656 .2282 L .21016 .23174 L p F P
0 g
s
.709 .745 .88 r
.1692 .48593 m .15825 .49098 L .15465 .48765 L p F P
0 g
s
.565 .61 .857 r
.67005 .24712 m .6688 .24721 L .6659 .24191 L p F P
0 g
s
.788 .666 .728 r
.26049 .39976 m .2558 .40582 L .26233 .40811 L p F P
0 g
s
.799 .676 .728 r
.2558 .40582 m .26233 .40811 L .25675 .41511 L p F P
0 g
s
.416 .338 .66 r
.75737 .39143 m .7582 .39069 L .75675 .38405 L p F P
0 g
s
.4 .327 .658 r
.75969 .38123 m .75675 .38405 L .7582 .39069 L p F P
0 g
s
.832 .667 .678 r
.25872 .34132 m .26447 .34394 L .26127 .35011 L p F P
0 g
s
.83 .66 .672 r
.26447 .34394 m .25872 .34132 L .26171 .33522 L p F P
0 g
s
.739 .75 .862 r
.1692 .48593 m .16969 .48564 L .17487 .4883 L p F P
0 g
s
.727 .737 .859 r
.18029 .47943 m .16969 .48564 L .17487 .4883 L p F P
0 g
s
.727 .737 .859 r
.17487 .4883 m .18382 .48329 L .18029 .47943 L p F P
0 g
s
.333 .164 .496 r
.55667 .26342 m .55632 .2637 L .55641 .26882 L p F P
0 g
s
.782 .676 .747 r
.25117 .43169 m .25542 .42699 L .25311 .4228 L p F P
0 g
s
.541 .567 .83 r
.69176 .26367 m .70124 .26382 L p .70235 .26983 L F P
0 g
s
.541 .571 .834 r
.69176 .26367 m .70124 .26382 L .69834 .25781 L p F P
0 g
s
.541 .571 .834 r
.69834 .25781 m .69627 .25778 L .69176 .26367 L p F P
0 g
s
.545 .579 .839 r
.68643 .25787 m .69627 .25778 L .69176 .26367 L p F P
0 g
s
.849 .391 .018 r
.22712 .24522 m .22579 .24258 L .22223 .23973 L p F P
0 g
s
.643 .088 0 r
.07669 .46639 m .0798 .46913 L .08447 .47201 L p F P
0 g
s
.605 .047 0 r
.0798 .46913 m .07669 .46639 L .07284 .46424 L p F P
0 g
s
.576 .47 .696 r
.53076 .36788 m .54135 .36328 L p .53669 .37337 L F P
0 g
s
.576 .47 .696 r
.53669 .37337 m .53228 .37384 L .53076 .36788 L p F P
0 g
s
.573 .467 .695 r
.54066 .36058 m .54135 .36328 L .53076 .36788 L p F P
0 g
s
.625 .654 .858 r
.62424 .48301 m .61263 .48575 L .60968 .48074 L p F P
0 g
s
.61 .553 .766 r
.567 .44357 m .56844 .44724 L .55693 .44974 L p F P
0 g
s
.61 .553 .766 r
.55693 .44974 m .55618 .4478 L .567 .44357 L p F P
0 g
s
.631 .953 .935 r
.69672 .4798 m .69909 .48009 L .70858 .47405 L p F P
0 g
s
.585 .936 .936 r
.68507 .48491 m .69672 .4798 L .69909 .48009 L p F P
0 g
s
.627 .961 .883 r
.71092 .47339 m .70858 .47405 L .69909 .48009 L p F P
0 g
s
.914 .716 .622 r
.04086 .39986 m .04053 .40095 L .0368 .39703 L p F P
0 g
s
.914 .716 .622 r
.0368 .39703 m .03693 .3966 L .04086 .39986 L p F P
0 g
s
.905 .726 .648 r
.04086 .39986 m .03693 .3966 L .03907 .39081 L p F P
0 g
s
.539 .423 .669 r
.53479 .33533 m .53441 .3335 L .53765 .33387 L closepath p F P
0 g
s
.817 .665 .694 r
.26581 .36833 m .26615 .36774 L .26541 .36743 L closepath p F P
0 g
s
.818 .663 .69 r
.26259 .36099 m .26375 .35892 L p .26615 .36774 L F P
0 g
s
.818 .663 .69 r
.26615 .36774 m .26541 .36743 L .26259 .36099 L p F P
0 g
s
0 .215 .633 r
.09039 .47555 m .09014 .47539 L .08447 .47201 L p F P
0 g
s
0 .243 .666 r
.0798 .46913 m .08447 .47201 L .09014 .47539 L p F P
0 g
s
0 0 0 r
.72243 .4653 m .72709 .46135 L .72334 .46399 L closepath p F P
0 g
s
0 0 0 r
.73381 .45458 m .72709 .46135 L .72334 .46399 L p F P
0 g
s
0 0 0 r
.73395 .45415 m .73381 .45458 L p .72334 .46399 L F P
0 g
s
.613 .585 .798 r
.58609 .4593 m .58911 .46585 L .57755 .46835 L p F P
0 g
s
.613 .585 .798 r
.58018 .46053 m .58609 .4593 L p .57755 .46835 L F P
0 g
s
.613 .585 .798 r
.57755 .46835 m .575 .46273 L .58018 .46053 L p F P
0 g
s
.333 .164 .496 r
.55641 .26882 m .55681 .26851 L .55667 .26342 L p F P
0 g
s
.329 .16 .494 r
.56512 .2567 m .55667 .26342 L .55681 .26851 L p F P
0 g
s
.259 .056 .403 r
.55667 .26342 m .56512 .2567 L .56543 .25207 L p F P
0 g
s
.428 .375 .697 r
.76143 .36186 m .75568 .3676 L .76112 .37128 L p F P
0 g
s
.442 .395 .71 r
.76127 .3613 m .76143 .36186 L .75568 .3676 L p F P
0 g
s
.442 .395 .71 r
.7556 .35811 m .76127 .3613 L p .75568 .3676 L F P
0 g
s
.805 .66 .703 r
.26196 .37426 m .26581 .36833 L .26541 .36743 L p F P
0 g
s
.609 .552 .766 r
.56539 .43946 m .567 .44357 L .55618 .4478 L p F P
0 g
s
.609 .552 .766 r
.55618 .4478 m .55387 .44186 L .56539 .43946 L p F P
0 g
s
.605 .672 .887 r
.63733 .22971 m .63375 .23038 L .63084 .22594 L p F P
0 g
s
.859 .659 .631 r
.25519 .30339 m .24998 .30053 L .25188 .29485 L p F P
0 g
s
.859 .667 .641 r
.24998 .30053 m .25519 .30339 L .25303 .30918 L p F P
0 g
s
.495 .73 .977 r
.12182 .48789 m .12583 .4877 L .12214 .48476 L p F P
0 g
s
.495 .73 .977 r
.12214 .48476 m .11684 .48514 L .12182 .48789 L p F P
0 g
s
.412 .712 .985 r
.11165 .48527 m .11684 .48514 L .12182 .48789 L p F P
0 g
s
.765 .732 .823 r
.19847 .47998 m .19871 .4798 L .19807 .47952 L closepath p F P
0 g
s
.747 .727 .833 r
.19807 .47952 m .19847 .47998 L p .18382 .48329 L F P
0 g
s
.793 .69 .75 r
.2448 .42937 m .25117 .43169 L .24467 .43899 L p F P
0 g
s
.782 .676 .747 r
.25112 .42213 m .2448 .42937 L .25117 .43169 L p F P
0 g
s
.782 .676 .747 r
.25311 .4228 m .25112 .42213 L p .25117 .43169 L F P
0 g
s
.767 .731 .82 r
.20808 .46956 m .20971 .47164 L .19871 .4798 L p F P
0 g
s
.767 .731 .82 r
.20477 .46832 m .20808 .46956 L p .19871 .4798 L F P
0 g
s
.767 .731 .82 r
.19499 .47584 m .20477 .46832 L p .19871 .4798 L F P
0 g
s
.767 .731 .82 r
.19871 .4798 m .19807 .47952 L .19499 .47584 L p F P
0 g
s
.563 .604 .853 r
.67005 .24712 m .68063 .24655 L .67773 .24104 L p F P
0 g
s
.563 .604 .853 r
.67773 .24104 m .67432 .24125 L .67005 .24712 L p F P
0 g
s
.565 .61 .857 r
.6659 .24191 m .67432 .24125 L .67005 .24712 L p F P
0 g
s
.805 .66 .703 r
.26541 .36743 m .25991 .36531 L p .26196 .37426 L F P
0 g
s
.808 .659 .697 r
.26541 .36743 m .26259 .36099 L .25991 .36531 L closepath p F P
0 g
s
.542 .43 .675 r
.53629 .34215 m .53479 .33533 L .53765 .33387 L p F P
0 g
s
.397 .307 .636 r
.75864 .39299 m .75737 .39143 L .7582 .39069 L closepath p F P
0 g
s
.432 .288 .584 r
.54812 .28638 m .54793 .28454 L .54883 .2859 L closepath p F P
0 g
s
.618 .616 .826 r
.6067 .47538 m .59511 .47792 L .59212 .47206 L p F P
0 g
s
.839 .668 .671 r
.25611 .33254 m .26171 .33522 L .25872 .34132 L p F P
0 g
s
.836 .662 .666 r
.26171 .33522 m .25611 .33254 L .25888 .32652 L p F P
0 g
s
.915 .715 .618 r
.03919 .4055 m .04053 .40095 L .0368 .39703 L p F P
0 g
s
.444 .721 .984 r
.11684 .48514 m .11165 .48527 L .10792 .48259 L p F P
0 g
s
.577 .476 .703 r
.53263 .37512 m .53228 .37384 L .53669 .37337 L closepath p F P
0 g
s
.808 .665 .705 r
.2639 .38324 m .25773 .3808 L .26196 .37426 L p F P
0 g
s
.812 .673 .71 r
.25773 .3808 m .2639 .38324 L .25947 .38985 L p F P
0 g
s
.747 .727 .833 r
.18382 .48329 m .19255 .47745 L .19807 .47952 L p F P
0 g
s
.745 .727 .835 r
.19807 .47952 m .19499 .47584 L .19255 .47745 L closepath p F P
0 g
s
.915 .569 .37 r
.05847 .44727 m .05413 .44422 L .05328 .43936 L p F P
0 g
s
.918 .571 .364 r
.04961 .43671 m .05328 .43936 L .05413 .44422 L p F P
0 g
s
.578 .479 .706 r
.53464 .38254 m .53263 .37512 L .53669 .37337 L p F P
0 g
s
.527 .551 .824 r
.71154 .27645 m .70705 .27618 L .70414 .26989 L p F P
0 g
s
.868 .667 .629 r
.24685 .29192 m .25188 .29485 L .24998 .30053 L p F P
0 g
s
.869 .659 .615 r
.25188 .29485 m .24685 .29192 L .24843 .28635 L p F P
0 g
s
.894 .495 .253 r
.06445 .45491 m .06005 .4519 L .05847 .44727 L p F P
0 g
s
.896 .495 .243 r
.05413 .44422 m .05847 .44727 L .06005 .4519 L p F P
0 g
s
.546 .58 .84 r
.69627 .25778 m .68643 .25787 L .68383 .2527 L p F P
0 g
s
.601 .508 .72 r
.53901 .39775 m .5414 .40557 L .5372 .40712 L p F P
0 g
s
.602 .511 .724 r
.54157 .40614 m .5372 .40712 L .5414 .40557 L closepath p F P
0 g
s
.924 .658 .515 r
.0489 .43118 m .04476 .42804 L .04515 .4228 L p F P
0 g
s
.924 .627 .462 r
.04961 .43671 m .04902 .43627 L .0489 .43118 L p F P
0 g
s
.928 .63 .459 r
.04476 .42804 m .0489 .43118 L .04902 .43627 L p F P
0 g
s
.799 .677 .729 r
.25675 .41511 m .25212 .42098 L .24882 .41495 L p F P
0 g
s
.799 .677 .729 r
.24882 .41495 m .25053 .41272 L .25675 .41511 L p F P
0 g
s
.799 .676 .728 r
.25675 .41511 m .25053 .41272 L .2558 .40582 L p F P
0 g
s
.823 .667 .689 r
.26259 .36099 m .26375 .35892 L .26114 .35775 L closepath p F P
0 g
s
.825 .665 .684 r
.25937 .35369 m .26127 .35011 L p .26375 .35892 L F P
0 g
s
.825 .665 .684 r
.26375 .35892 m .26114 .35775 L .25937 .35369 L p F P
0 g
s
.495 .5 .791 r
.73873 .3061 m .73078 .30456 L .7299 .30237 L p F P
0 g
s
.606 .543 .757 r
.56356 .43459 m .56539 .43946 L .55387 .44186 L p F P
0 g
s
.606 .543 .757 r
.55387 .44186 m .55276 .43887 L .56356 .43459 L p F P
0 g
s
.533 .408 .655 r
.54277 .3194 m .53875 .31873 L .5423 .31692 L closepath p F P
0 g
s
.528 .396 .645 r
.54116 .31052 m .5423 .31692 L .53875 .31873 L p F P
0 g
s
.496 .37 .638 r
.54116 .31052 m .54925 .30572 L .54273 .30267 L p F P
0 g
s
.497 .369 .636 r
.54984 .29849 m .54273 .30267 L .54925 .30572 L p F P
0 g
s
.492 .354 .621 r
.54891 .29235 m .54984 .29849 L .54273 .30267 L p F P
0 g
s
.805 .673 .717 r
.26049 .39976 m .26108 .39893 L .25982 .39843 L closepath p F P
0 g
s
.806 .671 .714 r
.25723 .39317 m .25947 .38985 L p .26108 .39893 L F P
0 g
s
.806 .671 .714 r
.26108 .39893 m .25982 .39843 L .25723 .39317 L p F P
0 g
s
.184 0 .325 r
.75042 .43409 m .74429 .439 L .74384 .4434 L p F P
0 g
s
.256 .067 .421 r
.74429 .439 m .75042 .43409 L .7518 .42825 L p F P
0 g
s
.21 0 .333 r
.73922 .44689 m .74384 .4434 L .74429 .439 L p F P
0 g
s
.792 .691 .753 r
.24389 .43986 m .24467 .43899 L .24296 .43832 L closepath p F P
0 g
s
.793 .69 .75 r
.24055 .4343 m .2448 .42937 L p .24467 .43899 L F P
0 g
s
.793 .69 .75 r
.24467 .43899 m .24296 .43832 L .24055 .4343 L p F P
0 g
s
.909 .73 .649 r
.03523 .3875 m .03907 .39081 L .03693 .3966 L p F P
0 g
s
.902 .736 .668 r
.03907 .39081 m .03523 .3875 L .03772 .3816 L p F P
0 g
s
.501 .38 .646 r
.5423 .31692 m .54116 .31052 L .54925 .30572 L p F P
0 g
s
.779 .687 .763 r
.23725 .44659 m .24389 .43986 L .24296 .43832 L p F P
0 g
s
.793 .669 .726 r
.2558 .40582 m .26049 .39976 L .25982 .39843 L p F P
0 g
s
.845 .67 .665 r
.25343 .32378 m .25888 .32652 L .25611 .33254 L p F P
0 g
s
.843 .664 .659 r
.25888 .32652 m .25343 .32378 L .25599 .31784 L p F P
0 g
s
.449 .316 .608 r
.54883 .2859 m .54812 .28638 L .54891 .29235 L p F P
0 g
s
.605 .542 .757 r
.56232 .43128 m .56356 .43459 L .55276 .43887 L p F P
0 g
s
.605 .542 .757 r
.55276 .43887 m .55081 .43358 L .56232 .43128 L p F P
0 g
s
.114 0 .199 r
.74384 .4434 m .73922 .44689 L .73455 .4537 L p F P
0 g
s
.126 0 .209 r
.73395 .45415 m .73455 .4537 L .73922 .44689 L p F P
0 g
s
.845 .384 .087 r
.07131 .46228 m .06687 .4593 L .06445 .45491 L p F P
0 g
s
.843 .379 .071 r
.06005 .4519 m .06445 .45491 L .06687 .4593 L p F P
0 g
s
.785 .675 .743 r
.25311 .4228 m .25212 .42098 L .25112 .42213 L closepath p F P
0 g
s
.928 .661 .513 r
.04108 .41962 m .04515 .4228 L .04476 .42804 L p F P
0 g
s
.922 .681 .557 r
.04515 .4228 m .04108 .41962 L .04193 .41423 L p F P
0 g
s
.304 .141 .489 r
.75303 .42192 m .75195 .4228 L .7518 .42825 L p F P
0 g
s
.383 .298 .635 r
.7582 .39069 m .76378 .38535 L p .76078 .39577 L F P
0 g
s
.383 .298 .635 r
.76078 .39577 m .75864 .39299 L .7582 .39069 L p F P
0 g
s
.4 .327 .658 r
.7582 .39069 m .76378 .38535 L .75969 .38123 L p F P
0 g
s
.879 .668 .613 r
.24358 .28334 m .24843 .28635 L .24685 .29192 L p F P
0 g
s
.881 .657 .594 r
.24843 .28635 m .24358 .28334 L .24482 .2779 L p F P
0 g
s
.502 .512 .8 r
.7299 .30237 m .72784 .2974 L .73322 .29827 L closepath p F P
0 g
s
.495 .5 .791 r
.7299 .30237 m .73322 .29827 L p .73873 .3061 L F P
0 g
s
.031 .505 .881 r
.09504 .47819 m .09039 .47555 L .09397 .47786 L closepath p F P
0 g
s
.635 .706 .898 r
.62717 .48752 m .63881 .48459 L .6417 .48851 L p F P
0 g
s
.63 .673 .873 r
.63641 .48105 m .63881 .48459 L .62717 .48752 L p F P
0 g
s
.63 .673 .873 r
.62717 .48752 m .62628 .48614 L .63641 .48105 L p F P
0 g
s
.578 .479 .706 r
.54377 .37252 m .5453 .37803 L .53464 .38254 L p F P
0 g
s
.578 .479 .706 r
.53669 .37337 m .54377 .37252 L p .53464 .38254 L F P
0 g
s
.581 .483 .707 r
.53538 .38524 m .53464 .38254 L .5453 .37803 L p F P
0 g
s
.776 .722 .803 r
.20971 .47164 m .21077 .47073 L .20808 .46956 L closepath p F P
0 g
s
.379 .275 .609 r
.7565 .40656 m .7604 .40313 L .75941 .39704 L p F P
0 g
s
.353 .235 .577 r
.7604 .40313 m .7565 .40656 L .75835 .41139 L p F P
0 g
s
.613 .584 .797 r
.575 .46273 m .57453 .46169 L .58018 .46053 L closepath p F P
0 g
s
.777 .721 .8 r
.21461 .45995 m .22091 .46227 L .21077 .47073 L p F P
0 g
s
.777 .721 .8 r
.20626 .4672 m .21461 .45995 L p .21077 .47073 L F P
0 g
s
.777 .721 .8 r
.21077 .47073 m .20808 .46956 L .20626 .4672 L p F P
0 g
s
.811 .663 .699 r
.25991 .36531 m .26259 .36099 L .26114 .35775 L p F P
0 g
s
.593 .943 .797 r
.70858 .47405 m .71092 .47339 L .71593 .47009 L p F P
0 g
s
.793 .669 .726 r
.25982 .39843 m .25469 .39658 L p .2558 .40582 L F P
0 g
s
.796 .667 .721 r
.25982 .39843 m .25723 .39317 L .25469 .39658 L closepath p F P
0 g
s
.789 .696 .762 r
.23725 .44659 m .23243 .45156 L .22905 .44642 L p F P
0 g
s
.789 .696 .762 r
.22905 .44642 m .23115 .44419 L .23725 .44659 L p F P
0 g
s
.779 .687 .763 r
.23827 .43668 m .23115 .44419 L .23725 .44659 L p F P
0 g
s
.779 .687 .763 r
.24296 .43832 m .23827 .43668 L p .23725 .44659 L F P
0 g
s
.552 .034 0 r
.22033 .23787 m .22223 .23973 L .21868 .2366 L p F P
0 g
s
.552 .034 0 r
.21868 .2366 m .21652 .23442 L .22033 .23787 L p F P
0 g
s
.583 .49 .715 r
.53678 .39009 m .53538 .38524 L .54688 .3837 L p F P
0 g
s
.581 .483 .707 r
.5453 .37803 m .54688 .3837 L .53538 .38524 L p F P
0 g
s
.817 .672 .703 r
.25588 .37178 m .26196 .37426 L .25773 .3808 L p F P
0 g
s
.805 .66 .703 r
.25991 .36531 m .25588 .37178 L .26196 .37426 L p F P
0 g
s
.55 .437 .678 r
.53629 .34215 m .54648 .33703 L p .54027 .34784 L F P
0 g
s
.55 .437 .678 r
.54027 .34784 m .53754 .34772 L .53629 .34215 L p F P
0 g
s
.542 .43 .675 r
.54593 .33456 m .54648 .33703 L .53629 .34215 L p F P
0 g
s
.542 .43 .675 r
.53765 .33387 m .54593 .33456 L p .53629 .34215 L F P
0 g
s
.754 .731 .831 r
.19255 .47745 m .18382 .48329 L .18029 .47943 L p F P
0 g
s
.688 .898 .972 r
.68322 .4839 m .68507 .48491 L .69672 .4798 L p F P
0 g
s
.89 .666 .592 r
.24016 .27481 m .24482 .2779 L .24358 .28334 L p F P
0 g
s
.894 .651 .564 r
.24482 .2779 m .24016 .27481 L .24099 .26953 L p F P
0 g
s
.602 .533 .749 r
.56039 .42589 m .56232 .43128 L .55081 .43358 L p F P
0 g
s
.602 .533 .749 r
.55081 .43358 m .54961 .43021 L .56039 .42589 L p F P
0 g
s
.61 .668 .881 r
.63733 .22971 m .64544 .22826 L .64253 .22351 L p F P
0 g
s
.61 .668 .881 r
.64253 .22351 m .64206 .22361 L .63733 .22971 L p F P
0 g
s
.605 .672 .887 r
.63084 .22594 m .64206 .22361 L .63733 .22971 L p F P
0 g
s
.612 .574 .787 r
.58018 .46053 m .57453 .46169 L .57149 .45465 L p F P
0 g
s
.449 .316 .608 r
.54891 .29235 m .55265 .28981 L .54883 .2859 L p F P
0 g
s
.449 .316 .607 r
.55742 .28006 m .54883 .2859 L .55265 .28981 L p F P
0 g
s
.439 .29 .581 r
.5568 .2743 m .55742 .28006 L .54883 .2859 L p F P
0 g
s
.83 .67 .684 r
.25937 .35369 m .26127 .35011 L .25681 .348 L closepath p F P
0 g
s
.832 .667 .678 r
.25614 .34646 m .25872 .34132 L p .26127 .35011 L F P
0 g
s
.832 .667 .678 r
.26127 .35011 m .25681 .348 L .25614 .34646 L p F P
0 g
s
.535 .558 .825 r
.70414 .26989 m .70235 .26983 L .70346 .26844 L closepath p F P
0 g
s
.541 .567 .83 r
.70124 .26382 m .70346 .26844 L .70235 .26983 L p F P
0 g
s
.44 .397 .714 r
.76127 .3613 m .7556 .35811 L .75928 .35435 L closepath p F P
0 g
s
.452 .416 .727 r
.75811 .35049 m .75474 .34885 L p .7556 .35811 L F P
0 g
s
.452 .416 .727 r
.7556 .35811 m .75928 .35435 L .75811 .35049 L p F P
0 g
s
.749 .991 .879 r
.58382 .22996 m .57752 .23663 L p .58231 .23162 L F P
0 g
s
.749 .991 .879 r
.58455 .22929 m .58382 .22996 L p .58231 .23162 L F P
0 g
s
.589 .946 .83 r
.58742 .22917 m .57752 .23663 L p .57665 .23754 L F P
0 g
s
.589 .946 .83 r
.58853 .2296 m .58742 .22917 L p .57644 .2377 L F P
0 g
s
.749 .991 .879 r
.57752 .23663 m .58742 .22917 L .58455 .22929 L p F P
0 g
s
0 0 0 r
.58382 .22996 m .578 .23703 L p .58421 .22953 L F P
0 g
s
.684 .96 .723 r
.58431 .22941 m .58455 .22929 L .5839 .22989 L p F P
0 g
s
.684 .96 .723 r
.5839 .22989 m .58382 .22996 L .58431 .22941 L p F P
0 g
s
.781 .982 .905 r
.59092 .22704 m .58742 .22917 L .58455 .22929 L p F P
0 g
s
.781 .982 .905 r
.58455 .22929 m .59588 .22081 L .59092 .22704 L p F P
0 g
s
.557 .909 .702 r
.58431 .22941 m .58455 .22929 L .59588 .22081 L p F P
0 g
s
.557 .909 .702 r
.58933 .22354 m .58431 .22941 L p .58788 .22563 L F P
0 g
s
.557 .909 .702 r
.59315 .22005 m .58933 .22354 L p .58788 .22563 L F P
0 g
s
.557 .909 .702 r
.59597 .2207 m .59315 .22005 L p .58431 .22941 L F P
0 g
s
.557 .909 .702 r
.59588 .22081 m .59597 .2207 L p .58431 .22941 L F P
0 g
s
0 0 0 r
.58431 .22941 m .58242 .23208 L p .58867 .22435 L F P
0 g
s
0 0 0 r
.58933 .22354 m .58431 .22941 L p .58867 .22435 L F P
0 g
s
0 0 0 r
.58373 .23054 m .58933 .22354 L p .58277 .23164 L F P
0 g
s
0 0 0 r
.58242 .23208 m .58373 .23054 L p .58277 .23164 L F P
0 g
s
0 0 0 r
.58933 .22354 m .58373 .23054 L p .59052 .22182 L F P
0 g
s
.054 0 .213 r
.58373 .23054 m .58855 .22433 L p .58724 .22649 L F P
0 g
s
.054 0 .213 r
.58149 .23592 m .58373 .23054 L .58724 .22649 L F
0 0 0 r
.59165 .22036 m .58933 .22354 L p .59052 .22182 L F P
0 g
s
0 0 0 r
.58431 .22941 m .58382 .22996 L p .58421 .22953 L F P
0 g
s
0 0 0 r
.57752 .23663 m .58382 .22996 L p .58293 .23098 L F P
0 g
s
0 0 0 r
.57462 .24048 m .57752 .23663 L .58293 .23098 L F
.589 .946 .83 r
.57752 .23663 m .57644 .2377 L p .57665 .23754 L F P
0 g
s
.51 .828 .52 r
.57599 .23812 m .57752 .23663 L .57644 .2377 L closepath p F P
0 g
s
.782 .687 .759 r
.24296 .43832 m .24055 .4343 L .23827 .43668 L closepath p F P
0 g
s
.926 .685 .556 r
.03793 .41102 m .04193 .41423 L .04108 .41962 L p F P
0 g
s
.919 .7 .59 r
.04193 .41423 m .03793 .41102 L .03919 .4055 L p F P
0 g
s
.752 .941 .945 r
.58742 .22917 m .59092 .22704 L .58853 .2296 L closepath p F P
0 g
s
.695 .888 .968 r
.59892 .22277 m .59092 .22704 L .58853 .2296 L p F P
0 g
s
.695 .888 .968 r
.60182 .22545 m .59892 .22277 L p .58853 .2296 L F P
0 g
s
.786 .677 .743 r
.25112 .42213 m .25212 .42098 L .24882 .41495 L p F P
0 g
s
.765 .707 .797 r
.22116 .46236 m .22103 .46217 L .22091 .46227 L closepath p F P
0 g
s
.773 .697 .779 r
.22942 .45432 m .23243 .45156 L .22905 .44642 L p F P
0 g
s
.781 .701 .775 r
.22942 .45432 m .22103 .46217 L .21761 .45738 L p F P
0 g
s
.781 .701 .775 r
.21761 .45738 m .22322 .45196 L .22942 .45432 L p F P
0 g
s
.773 .697 .779 r
.22905 .44642 m .22322 .45196 L .22942 .45432 L p F P
0 g
s
.852 .672 .658 r
.25069 .31503 m .25599 .31784 L .25343 .32378 L p F P
0 g
s
.851 .665 .651 r
.25599 .31784 m .25069 .31503 L .25303 .30918 L p F P
0 g
s
.586 .493 .715 r
.53678 .39009 m .54743 .38558 L p .54579 .3949 L F P
0 g
s
.586 .493 .715 r
.54579 .3949 m .53848 .39598 L .53678 .39009 L p F P
0 g
s
.583 .49 .715 r
.54688 .3837 m .54743 .38558 L .53678 .39009 L p F P
0 g
s
.384 .298 .634 r
.75941 .39704 m .75864 .39299 L .76078 .39577 L closepath p F P
0 g
s
.601 .532 .749 r
.55925 .4227 m .56039 .42589 L .54961 .43021 L p F P
0 g
s
.601 .532 .749 r
.54961 .43021 m .54773 .42488 L .55925 .4227 L p F P
0 g
s
.544 .428 .672 r
.54593 .33456 m .53765 .33387 L .54499 .33021 L closepath p F P
0 g
s
.54 .418 .663 r
.54359 .3235 m .54499 .33021 L .53765 .33387 L p F P
0 g
s
.746 .228 0 r
.07131 .46228 m .07284 .46424 L .06899 .46193 L p F P
0 g
s
.746 .228 0 r
.06899 .46193 m .06687 .4593 L .07131 .46228 L p F P
0 g
s
.765 .706 .797 r
.21761 .45738 m .21461 .45995 L .22091 .46227 L p F P
0 g
s
.765 .706 .797 r
.22091 .46227 m .22103 .46217 L .21761 .45738 L p F P
0 g
s
.797 .688 .744 r
.2447 .41981 m .25112 .42213 L .2448 .42937 L p F P
0 g
s
.786 .677 .743 r
.24882 .41495 m .2447 .41981 L .25112 .42213 L p F P
0 g
s
.904 .661 .561 r
.23652 .26636 m .24099 .26953 L .24016 .27481 L p F P
0 g
s
.909 .64 .518 r
.24099 .26953 m .23652 .26636 L .23686 .26125 L p F P
0 g
s
.675 .742 .901 r
.60182 .22545 m .61339 .22113 L .6163 .22484 L p F P
0 g
s
.699 .77 .907 r
.61339 .22113 m .60182 .22545 L .59892 .22277 L p F P
0 g
s
.02 0 .06 r
.73381 .45458 m .73455 .4537 L .73395 .45415 L closepath p F P
0 g
s
.583 .636 .869 r
.6601 .23151 m .66067 .2325 L .65698 .23734 L p F P
0 g
s
.583 .636 .869 r
.64834 .23311 m .6601 .23151 L p .65698 .23734 L F P
0 g
s
.579 .624 .86 r
.663 .23666 m .65698 .23734 L .66067 .2325 L closepath p F P
0 g
s
.133 .567 .925 r
.09504 .47819 m .10418 .47983 L p .09018 .47541 L F P
0 g
s
.133 .567 .925 r
.09018 .47541 m .09039 .47555 L .09504 .47819 L p F P
0 g
s
.811 .663 .699 r
.26114 .35775 m .25778 .35638 L p .25991 .36531 L F P
0 g
s
.814 .661 .693 r
.26114 .35775 m .25937 .35369 L .25778 .35638 L closepath p F P
0 g
s
.811 .675 .713 r
.25723 .39317 m .25947 .38985 L .25452 .38778 L closepath p F P
0 g
s
.812 .673 .71 r
.25396 .38664 m .25773 .3808 L p .25947 .38985 L F P
0 g
s
.812 .673 .71 r
.25947 .38985 m .25452 .38778 L .25396 .38664 L p F P
0 g
s
.637 .695 .887 r
.6163 .22484 m .62793 .22166 L .63084 .22594 L p F P
0 g
s
.65 .71 .892 r
.62793 .22166 m .6163 .22484 L .61339 .22113 L p F P
0 g
s
.281 .125 .484 r
.75928 .41652 m .75303 .42192 L .75324 .42708 L p F P
0 g
s
.323 .188 .537 r
.75303 .42192 m .75928 .41652 L .75835 .41139 L p F P
0 g
s
.304 .141 .489 r
.7518 .42825 m .75324 .42708 L .75303 .42192 L p F P
0 g
s
0 0 0 r
.71593 .47009 m .7212 .46652 L .72243 .4653 L closepath p F P
0 g
s
.593 .943 .797 r
.71593 .47009 m .7212 .46652 L p .70858 .47405 L F P
0 g
s
.628 .672 .872 r
.6359 .4803 m .63641 .48105 L .62628 .48614 L p F P
0 g
s
.628 .672 .872 r
.62628 .48614 m .62424 .48301 L .6359 .4803 L p F P
0 g
s
.598 .523 .741 r
.55745 .41745 m .55925 .4227 L .54773 .42488 L p F P
0 g
s
.598 .523 .741 r
.54773 .42488 m .54669 .42181 L .55745 .41745 L p F P
0 g
s
.588 .5 .723 r
.53901 .39775 m .53848 .39598 L .54579 .3949 L closepath p F P
0 g
s
.793 .669 .726 r
.25469 .39658 m .2496 .40342 L .2558 .40582 L p F P
0 g
s
.805 .682 .729 r
.2496 .40342 m .2558 .40582 L .25053 .41272 L p F P
0 g
s
.921 .549 .299 r
.2323 .25313 m .22822 .2498 L .22712 .24522 L p F P
0 g
s
.927 .556 .289 r
.22324 .2418 m .22712 .24522 L .22822 .2498 L p F P
0 g
s
.849 .391 .018 r
.22223 .23973 m .22324 .2418 L .22712 .24522 L p F P
0 g
s
.567 .614 .859 r
.67432 .24125 m .6659 .24191 L .663 .23666 L p F P
0 g
s
.588 .501 .724 r
.5414 .40557 m .53901 .39775 L .54579 .3949 L p F P
0 g
s
.918 .649 .514 r
.23258 .258 m .23686 .26125 L .23652 .26636 L p F P
0 g
s
.922 .613 .441 r
.23686 .26125 m .23258 .258 L .2323 .25313 L p F P
0 g
s
.59 .64 .868 r
.6601 .23151 m .64834 .23311 L .64544 .22826 L p F P
0 g
s
.597 .522 .741 r
.55616 .41369 m .55745 .41745 L .54669 .42181 L p F P
0 g
s
.597 .522 .741 r
.54669 .42181 m .54465 .41574 L .55616 .41369 L p F P
0 g
s
.502 .512 .8 r
.73322 .29827 m .72784 .2974 L .72571 .29228 L p F P
0 g
s
.61 .748 .943 r
.12583 .4877 m .13653 .48517 L .14018 .48833 L p F P
0 g
s
.622 .749 .938 r
.13653 .48517 m .12583 .4877 L .12214 .48476 L p F P
0 g
s
.641 .748 .926 r
.6417 .48851 m .65336 .48532 L .65621 .48859 L p F P
0 g
s
.635 .72 .908 r
.65336 .48532 m .6417 .48851 L .63881 .48459 L p F P
0 g
s
.93 .622 .435 r
.22822 .2498 m .2323 .25313 L .23258 .258 L p F P
0 g
s
.625 .654 .858 r
.60968 .48074 m .6213 .47814 L .62424 .48301 L p F P
0 g
s
.619 .631 .841 r
.61834 .47294 m .6213 .47814 L .60968 .48074 L p F P
0 g
s
.619 .631 .841 r
.60955 .47479 m .61834 .47294 L p .60968 .48074 L F P
0 g
s
.619 .631 .841 r
.60968 .48074 m .60705 .47601 L .60955 .47479 L p F P
0 g
s
.595 .514 .733 r
.55471 .40922 m .55616 .41369 L .54465 .41574 L p F P
0 g
s
.595 .514 .733 r
.54465 .41574 m .54396 .4136 L .55471 .40922 L p F P
0 g
s
.591 .504 .725 r
.54157 .40614 m .5414 .40557 L .55213 .40118 L p F P
0 g
s
.588 .501 .724 r
.54998 .39425 m .55213 .40118 L .5414 .40557 L p F P
0 g
s
.588 .501 .724 r
.54579 .3949 m .54998 .39425 L p .5414 .40557 L F P
0 g
s
.593 .512 .733 r
.55307 .40421 m .55471 .40922 L .54396 .4136 L p F P
0 g
s
.593 .512 .733 r
.54396 .4136 m .54157 .40614 L .55307 .40421 L p F P
0 g
s
.591 .504 .725 r
.55213 .40118 m .55307 .40421 L .54157 .40614 L p F P
0 g
s
.837 .671 .676 r
.25872 .34132 m .25614 .34646 L .25291 .33927 L p F P
0 g
s
.837 .671 .676 r
.25291 .33927 m .25324 .33859 L .25872 .34132 L p F P
0 g
s
.839 .668 .671 r
.25872 .34132 m .25324 .33859 L .25611 .33254 L p F P
0 g
s
.859 .673 .649 r
.24789 .3063 m .25303 .30918 L .25069 .31503 L p F P
0 g
s
.859 .667 .641 r
.25303 .30918 m .24789 .3063 L .24998 .30053 L p F P
0 g
s
.618 .616 .826 r
.59212 .47206 m .60371 .46963 L .6067 .47538 L p F P
0 g
s
.613 .598 .812 r
.601 .46416 m .60371 .46963 L .59212 .47206 L p F P
0 g
s
.613 .598 .812 r
.59212 .47206 m .59058 .4689 L .601 .46416 L p F P
0 g
s
0 0 0 r
.73455 .4537 m .74298 .44735 L p .73253 .45747 L F P
0 g
s
0 0 0 r
.73253 .45747 m .73381 .45458 L .73455 .4537 L p F P
0 g
s
.114 0 .199 r
.73455 .4537 m .74298 .44735 L .74384 .4434 L p F P
0 g
s
.922 .704 .59 r
.03527 .40224 m .03919 .4055 L .03793 .41102 L p F P
0 g
s
.915 .715 .618 r
.0368 .39703 m .03527 .40224 L .03919 .4055 L p F P
0 g
s
.579 .476 .702 r
.54377 .37252 m .53669 .37337 L .54325 .37058 L closepath p F P
0 g
s
.576 .47 .696 r
.54135 .36328 m .54325 .37058 L .53669 .37337 L p F P
0 g
s
.821 .673 .699 r
.25393 .36279 m .25991 .36531 L .25588 .37178 L p F P
0 g
s
.811 .663 .699 r
.25778 .35638 m .25393 .36279 L .25991 .36531 L p F P
0 g
s
.549 .442 .685 r
.53785 .34905 m .53754 .34772 L .54027 .34784 L closepath p F P
0 g
s
0 0 0 r
.72709 .46135 m .73253 .45747 L .73381 .45458 L closepath p F P
0 g
s
.527 .551 .824 r
.70414 .26989 m .71607 .2706 L .71154 .27645 L p F P
0 g
s
.527 .553 .826 r
.71607 .2706 m .70414 .26989 L .70346 .26844 L p F P
0 g
s
.648 .804 .958 r
.65621 .48859 m .66788 .485 L .67068 .48753 L p F P
0 g
s
.649 .872 .982 r
.67068 .48753 m .68235 .48336 L .68322 .4839 L p F P
0 g
s
.651 .832 .97 r
.68235 .48336 m .67068 .48753 L .66788 .485 L p F P
0 g
s
.739 .752 .863 r
.1692 .48593 m .16969 .48564 L .16806 .48477 L closepath p F P
0 g
s
.709 .745 .88 r
.16806 .48477 m .1692 .48593 L p .15465 .48765 L F P
0 g
s
.373 .225 .548 r
.55681 .26851 m .55641 .26882 L .5568 .2743 L p F P
0 g
s
.741 .752 .861 r
.17676 .47555 m .18029 .47943 L .16969 .48564 L p F P
0 g
s
.741 .752 .861 r
.16564 .48231 m .17676 .47555 L p .16969 .48564 L F P
0 g
s
.741 .752 .861 r
.16969 .48564 m .16806 .48477 L .16564 .48231 L p F P
0 g
s
.399 .327 .659 r
.76505 .37603 m .75969 .38123 L .76378 .38535 L p F P
0 g
s
.416 .351 .677 r
.76457 .37407 m .76505 .37603 L .75969 .38123 L p F P
0 g
s
.416 .351 .677 r
.76112 .37128 m .76457 .37407 L p .75969 .38123 L F P
0 g
s
.759 .718 .813 r
.20808 .46956 m .20626 .4672 L .20477 .46832 L closepath p F P
0 g
s
.546 .58 .84 r
.68383 .2527 m .68428 .25208 L p .69627 .25778 L F P
0 g
s
.551 .589 .846 r
.68383 .2527 m .68353 .2521 L .68428 .25208 L closepath p F P
0 g
s
0 0 0 r
.7212 .46652 m .72243 .4653 L .72709 .46135 L p F P
0 g
s
.644 .768 .939 r
.66788 .485 m .65621 .48859 L .65336 .48532 L p F P
0 g
s
0 0 0 r
.57462 .24048 m .57599 .23812 L .57752 .23663 L p F P
0 g
s
.797 .688 .744 r
.2448 .42937 m .24055 .4343 L .23721 .42876 L p F P
0 g
s
.797 .688 .744 r
.23721 .42876 m .23873 .42694 L .2448 .42937 L p F P
0 g
s
.797 .688 .744 r
.2448 .42937 m .23873 .42694 L .2447 .41981 L p F P
0 g
s
.817 .665 .694 r
.25778 .35638 m .25937 .35369 L .25681 .348 L p F P
0 g
s
.515 .396 .655 r
.5423 .31692 m .55208 .31125 L p .54803 .32093 L F P
0 g
s
.515 .396 .655 r
.54803 .32093 m .54277 .3194 L .5423 .31692 L p F P
0 g
s
.501 .38 .646 r
.55118 .30645 m .55208 .31125 L .5423 .31692 L p F P
0 g
s
.501 .38 .646 r
.54925 .30572 m .55118 .30645 L p .5423 .31692 L F P
0 g
s
.552 .447 .689 r
.53956 .35612 m .53785 .34905 L .54027 .34784 L p F P
0 g
s
0 0 0 r
.57096 .24392 m .57462 .24048 L .57599 .23812 L closepath p F P
0 g
s
.798 .671 .723 r
.25469 .39658 m .25723 .39317 L .25452 .38778 L p F P
0 g
s
.754 .731 .831 r
.18029 .47943 m .18666 .475 L .19255 .47745 L p F P
0 g
s
.745 .727 .835 r
.1915 .47169 m .18666 .475 L .19255 .47745 L p F P
0 g
s
.745 .727 .835 r
.19255 .47745 m .19499 .47584 L .1915 .47169 L p F P
0 g
s
0 0 0 r
.72709 .46135 m .73253 .45747 L p .7212 .46652 L F P
0 g
s
.448 .414 .727 r
.75811 .35049 m .75474 .34885 L .75692 .34658 L closepath p F P
0 g
s
.461 .432 .74 r
.755 .34063 m .7531 .33983 L p .75474 .34885 L F P
0 g
s
.461 .432 .74 r
.75474 .34885 m .75692 .34658 L .755 .34063 L p F P
0 g
s
.361 .263 .607 r
.76078 .39577 m .75941 .39704 L .7604 .40313 L p F P
0 g
s
.55 .593 .849 r
.68428 .25208 m .68353 .2521 L .68063 .24655 L p F P
0 g
s
.373 .225 .548 r
.5568 .2743 m .55824 .27318 L .55681 .26851 L p F P
0 g
s
.369 .223 .548 r
.56522 .26182 m .55681 .26851 L .55824 .27318 L p F P
0 g
s
.329 .16 .494 r
.55681 .26851 m .56522 .26182 L .56512 .2567 L p F P
0 g
s
.673 .751 .91 r
.14018 .48833 m .15104 .48427 L .15465 .48765 L p F P
0 g
s
.681 .752 .905 r
.15104 .48427 m .14018 .48833 L .13653 .48517 L p F P
0 g
s
.527 .553 .826 r
.70346 .26844 m .70668 .26402 L p .71607 .2706 L F P
0 g
s
.532 .563 .832 r
.70346 .26844 m .70124 .26382 L .70668 .26402 L closepath p F P
0 g
s
.612 .574 .787 r
.57149 .45465 m .58305 .45237 L p .58018 .46053 L F P
0 g
s
.607 .562 .778 r
.58139 .44841 m .58305 .45237 L .57149 .45465 L p F P
0 g
s
.607 .562 .778 r
.57149 .45465 m .57077 .45291 L .58139 .44841 L p F P
0 g
s
.521 .542 .818 r
.71154 .27645 m .71907 .27709 L .71615 .27061 L p F P
0 g
s
.521 .542 .818 r
.71615 .27061 m .71607 .2706 L .71154 .27645 L p F P
0 g
s
.522 .54 .816 r
.71154 .27645 m .71907 .27709 L p .71976 .2834 L F P
0 g
s
.868 .667 .629 r
.24998 .30053 m .24501 .29758 L .24685 .29192 L p F P
0 g
s
.868 .675 .64 r
.24501 .29758 m .24998 .30053 L .24789 .3063 L p F P
0 g
s
.709 .745 .88 r
.15465 .48765 m .16384 .48318 L .16806 .48477 L p F P
0 g
s
.717 .748 .877 r
.16384 .48318 m .15465 .48765 L .15104 .48427 L p F P
0 g
s
.054 .444 .876 r
.21652 .23442 m .21289 .23089 L .20656 .2282 L p F P
0 g
s
.816 .673 .705 r
.25773 .3808 m .25396 .38664 L .25068 .38011 L p F P
0 g
s
.816 .673 .705 r
.25068 .38011 m .25185 .37826 L .25773 .3808 L p F P
0 g
s
.817 .672 .703 r
.25773 .3808 m .25185 .37826 L .25588 .37178 L p F P
0 g
s
0 .243 .666 r
.09014 .47539 m .08559 .47246 L .0798 .46913 L p F P
0 g
s
.605 .047 0 r
.07284 .46424 m .07519 .46621 L .0798 .46913 L p F P
0 g
s
0 .267 .693 r
.07519 .46621 m .0798 .46913 L .08559 .47246 L p F P
0 g
s
.612 .684 .893 r
.64206 .22361 m .63084 .22594 L .62793 .22166 L p F P
0 g
s
.844 .674 .672 r
.25076 .32976 m .25611 .33254 L .25324 .33859 L p F P
0 g
s
.845 .67 .665 r
.25611 .33254 m .25076 .32976 L .25343 .32378 L p F P
0 g
s
.767 .72 .809 r
.20477 .46832 m .19499 .47584 L .1915 .47169 L p F P
0 g
s
.459 .335 .623 r
.55265 .28981 m .54891 .29235 L .54984 .29849 L p F P
0 g
s
.513 .735 .974 r
.11684 .48514 m .12214 .48476 L .11845 .48176 L p F P
0 g
s
.513 .735 .974 r
.11845 .48176 m .11185 .48239 L .11684 .48514 L p F P
0 g
s
.444 .721 .984 r
.10792 .48259 m .11185 .48239 L .11684 .48514 L p F P
0 g
s
.502 .512 .8 r
.72571 .29228 m .72696 .29068 L p .73322 .29827 L F P
0 g
s
.508 .524 .808 r
.72571 .29228 m .72491 .29041 L .72696 .29068 L closepath p F P
0 g
s
.513 .399 .661 r
.54359 .3235 m .54277 .3194 L .54803 .32093 L closepath p F P
0 g
s
.605 .561 .778 r
.58001 .4451 m .58139 .44841 L .57077 .45291 L p F P
0 g
s
.605 .561 .778 r
.57077 .45291 m .56844 .44724 L .58001 .4451 L p F P
0 g
s
.546 .58 .84 r
.68428 .25208 m .69544 .25198 L p .69627 .25778 L F P
0 g
s
.547 .586 .845 r
.68428 .25208 m .69544 .25198 L .69254 .24624 L p F P
0 g
s
.547 .586 .845 r
.69254 .24624 m .68831 .2463 L .68428 .25208 L p F P
0 g
s
.55 .593 .849 r
.68063 .24655 m .68831 .2463 L .68428 .25208 L p F P
0 g
s
.783 .688 .76 r
.23827 .43668 m .24055 .4343 L .23721 .42876 L p F P
0 g
s
.207 .016 .387 r
.56753 .25018 m .56543 .25207 L .56512 .2567 L p F P
0 g
s
.062 0 .201 r
.56543 .25207 m .56753 .25018 L .57096 .24392 L p F P
0 g
s
.804 .684 .732 r
.24882 .41495 m .25053 .41272 L .2467 .41114 L closepath p F P
0 g
s
.805 .682 .729 r
.24551 .40896 m .2496 .40342 L p .25053 .41272 L F P
0 g
s
.805 .682 .729 r
.25053 .41272 m .2467 .41114 L .24551 .40896 L p F P
0 g
s
.917 .721 .622 r
.03693 .3966 m .0368 .39703 L .03302 .39351 L p F P
0 g
s
.917 .721 .622 r
.03302 .39351 m .03308 .3933 L .03693 .3966 L p F P
0 g
s
.909 .73 .649 r
.03693 .3966 m .03308 .3933 L .03523 .3875 L p F P
0 g
s
.612 .597 .812 r
.60071 .46359 m .601 .46416 L .59058 .4689 L p F P
0 g
s
.612 .597 .812 r
.59058 .4689 m .58911 .46585 L .60071 .46359 L p F P
0 g
s
.809 .681 .723 r
.24852 .39415 m .25469 .39658 L .2496 .40342 L p F P
0 g
s
.798 .671 .723 r
.25343 .38737 m .24852 .39415 L .25469 .39658 L p F P
0 g
s
.798 .671 .723 r
.25452 .38778 m .25343 .38737 L p .25469 .39658 L F P
0 g
s
.023 0 .172 r
.57462 .24048 m .57096 .24392 L .56753 .25018 L p F P
0 g
s
.825 .674 .695 r
.25191 .35381 m .25778 .35638 L .25393 .36279 L p F P
0 g
s
.817 .665 .694 r
.25557 .34747 m .25191 .35381 L .25778 .35638 L p F P
0 g
s
.817 .665 .694 r
.25681 .348 m .25557 .34747 L p .25778 .35638 L F P
0 g
s
.918 .571 .364 r
.04905 .43653 m .04961 .43671 L p .05413 .44422 L F P
0 g
s
.923 .593 .397 r
.04905 .43653 m .04902 .43627 L .04961 .43671 L closepath p F P
0 g
s
.794 .702 .763 r
.23205 .43431 m .23827 .43668 L .23115 .44419 L p F P
0 g
s
.783 .688 .76 r
.23721 .42876 m .23205 .43431 L .23827 .43668 L p F P
0 g
s
.918 .719 .618 r
.03527 .40224 m .0368 .39703 L .03302 .39351 L p F P
0 g
s
.708 .746 .881 r
.16806 .48477 m .16564 .48231 L .16384 .48318 L closepath p F P
0 g
s
.877 .676 .627 r
.24204 .2889 m .24685 .29192 L .24501 .29758 L p F P
0 g
s
.879 .668 .613 r
.24685 .29192 m .24204 .2889 L .24358 .28334 L p F P
0 g
s
.854 .403 .019 r
.22324 .2418 m .22223 .23973 L .21868 .2366 L p F P
0 g
s
.558 .453 .691 r
.53956 .35612 m .54982 .35108 L p .54692 .36055 L F P
0 g
s
.558 .453 .691 r
.54692 .36055 m .54066 .36058 L .53956 .35612 L p F P
0 g
s
.552 .447 .689 r
.54907 .34805 m .54982 .35108 L .53956 .35612 L p F P
0 g
s
.552 .447 .689 r
.54027 .34784 m .54907 .34805 L p .53956 .35612 L F P
0 g
s
.507 .525 .809 r
.72696 .29068 m .72491 .29041 L .72198 .28365 L p F P
0 g
s
.791 .68 .742 r
.2447 .41981 m .24882 .41495 L .2467 .41114 L p F P
0 g
s
.613 .578 .79 r
.58609 .4593 m .58018 .46053 L .58564 .45828 L closepath p F P
0 g
s
.612 .574 .787 r
.58305 .45237 m .58564 .45828 L .58018 .46053 L p F P
0 g
s
.82 .663 .688 r
.25681 .348 m .25614 .34646 L .25557 .34747 L closepath p F P
0 g
s
.566 .007 0 r
.07519 .46621 m .07284 .46424 L .06899 .46193 L p F P
0 g
s
.25 .062 .419 r
.75324 .42708 m .7518 .42825 L .75042 .43409 L p F P
0 g
s
.926 .594 .39 r
.04902 .43627 m .04905 .43653 L .04509 .43482 L p F P
0 g
s
.926 .594 .39 r
.04509 .43482 m .04487 .43314 L .04902 .43627 L p F P
0 g
s
.928 .63 .459 r
.04902 .43627 m .04487 .43314 L .04476 .42804 L p F P
0 g
s
.852 .677 .664 r
.24822 .32094 m .25343 .32378 L .25076 .32976 L p F P
0 g
s
.852 .672 .658 r
.25343 .32378 m .24822 .32094 L .25069 .31503 L p F P
0 g
s
.457 .43 .74 r
.755 .34063 m .7531 .33983 L .75432 .33851 L closepath p F P
0 g
s
.469 .448 .752 r
.75195 .3315 m .75067 .33104 L p .7531 .33983 L F P
0 g
s
.469 .448 .752 r
.7531 .33983 m .75432 .33851 L .75195 .3315 L p F P
0 g
s
.553 .445 .686 r
.54907 .34805 m .54027 .34784 L .5481 .344 L closepath p F P
0 g
s
.55 .437 .678 r
.54648 .33703 m .5481 .344 L .54027 .34784 L p F P
0 g
s
.896 .495 .243 r
.06005 .4519 m .05572 .44886 L .05413 .44422 L p F P
0 g
s
.898 .494 .233 r
.04986 .44114 m .05413 .44422 L .05572 .44886 L p F P
0 g
s
.918 .571 .364 r
.05413 .44422 m .04986 .44114 L .04905 .43653 L p F P
0 g
s
.623 .661 .867 r
.6359 .4803 m .62424 .48301 L .6213 .47814 L p F P
0 g
s
.767 .72 .809 r
.1915 .47169 m .19876 .4659 L .20477 .46832 L p F P
0 g
s
.759 .718 .813 r
.2028 .46273 m .19876 .4659 L .20477 .46832 L p F P
0 g
s
.759 .718 .813 r
.20477 .46832 m .20626 .4672 L .2028 .46273 L p F P
0 g
s
.793 .703 .766 r
.22905 .44642 m .23115 .44419 L .22617 .44208 L closepath p F P
0 g
s
.794 .702 .763 r
.22566 .4413 m .23205 .43431 L p .23115 .44419 L F P
0 g
s
.794 .702 .763 r
.23115 .44419 m .22617 .44208 L .22566 .4413 L p F P
0 g
s
.824 .668 .689 r
.25557 .34747 m .25614 .34646 L .25291 .33927 L p F P
0 g
s
.921 .573 .36 r
.04986 .44114 m .04905 .43653 L .04509 .43482 L p F P
0 g
s
.515 .53 .81 r
.72198 .28365 m .71976 .2834 L .72113 .28169 L closepath p F P
0 g
s
.522 .54 .816 r
.71907 .27709 m .72113 .28169 L .71976 .2834 L p F P
0 g
s
.931 .634 .456 r
.04069 .42487 m .04476 .42804 L .04487 .43314 L p F P
0 g
s
.928 .661 .513 r
.04476 .42804 m .04069 .42487 L .04108 .41962 L p F P
0 g
s
.823 .678 .704 r
.25008 .3692 m .25588 .37178 L .25185 .37826 L p F P
0 g
s
.821 .673 .699 r
.25588 .37178 m .25008 .3692 L .25393 .36279 L p F P
0 g
s
.778 .712 .79 r
.21461 .45995 m .20626 .4672 L .2028 .46273 L p F P
0 g
s
.887 .676 .611 r
.23895 .28025 m .24358 .28334 L .24204 .2889 L p F P
0 g
s
.89 .666 .592 r
.24358 .28334 m .23895 .28025 L .24016 .27481 L p F P
0 g
s
.517 .406 .667 r
.54499 .33021 m .54359 .3235 L .54803 .32093 L p F P
0 g
s
.801 .669 .718 r
.25452 .38778 m .25396 .38664 L .25343 .38737 L closepath p F P
0 g
s
.737 .873 .944 r
.59602 .22072 m .59588 .22081 L .59092 .22704 L p F P
0 g
s
.737 .873 .944 r
.59092 .22704 m .59892 .22277 L .59602 .22072 L p F P
0 g
s
.472 .727 .981 r
.11185 .48239 m .10792 .48259 L .10418 .47983 L p F P
0 g
s
.778 .7 .777 r
.22322 .45196 m .22905 .44642 L .22617 .44208 L p F P
0 g
s
.601 .551 .77 r
.57756 .43899 m .58001 .4451 L .56844 .44724 L p F P
0 g
s
.601 .551 .77 r
.56844 .44724 m .567 .44357 L .57756 .43899 L p F P
0 g
s
.36 .264 .609 r
.76718 .3897 m .76078 .39577 L .76335 .40038 L p F P
0 g
s
.383 .298 .635 r
.76378 .38535 m .76718 .3897 L .76078 .39577 L p F P
0 g
s
.361 .263 .607 r
.7604 .40313 m .76335 .40038 L .76078 .39577 L p F P
0 g
s
.609 .589 .806 r
.60071 .46359 m .58911 .46585 L .58609 .4593 L p F P
0 g
s
.558 .459 .698 r
.54135 .36328 m .54066 .36058 L .54692 .36055 L closepath p F P
0 g
s
.787 .706 .775 r
.22322 .45196 m .21761 .45738 L .21419 .4526 L p F P
0 g
s
.787 .706 .775 r
.21419 .4526 m .21731 .4495 L .22322 .45196 L p F P
0 g
s
.778 .7 .777 r
.22523 .44172 m .21731 .4495 L .22322 .45196 L p F P
0 g
s
.778 .7 .777 r
.22617 .44208 m .22523 .44172 L p .22322 .45196 L F P
0 g
s
.802 .693 .744 r
.23859 .41738 m .2447 .41981 L .23873 .42694 L p F P
0 g
s
.791 .68 .742 r
.24441 .41029 m .23859 .41738 L .2447 .41981 L p F P
0 g
s
.791 .68 .742 r
.2467 .41114 m .24441 .41029 L p .2447 .41981 L F P
0 g
s
.829 .675 .691 r
.24982 .34484 m .25557 .34747 L .25191 .35381 L p F P
0 g
s
.824 .668 .689 r
.25291 .33927 m .24982 .34484 L .25557 .34747 L p F P
0 g
s
.778 .712 .79 r
.2028 .46273 m .20862 .45751 L .21461 .45995 L p F P
0 g
s
.77 .709 .794 r
.21419 .4526 m .20862 .45751 L .21461 .45995 L p F P
0 g
s
.77 .709 .794 r
.21461 .45995 m .21761 .45738 L .21419 .4526 L p F P
0 g
s
.843 .379 .071 r
.06687 .4593 m .06249 .45628 L .06005 .4519 L p F P
0 g
s
.84 .373 .055 r
.05572 .44886 m .06005 .4519 L .06249 .45628 L p F P
0 g
s
.619 .63 .84 r
.60705 .47601 m .6067 .47538 L .60955 .47479 L closepath p F P
0 g
s
.631 .953 .935 r
.70858 .47405 m .70836 .47406 L .69672 .4798 L p F P
0 g
s
.61 .939 .95 r
.70836 .47406 m .69672 .4798 L .69403 .47875 L p F P
0 g
s
.688 .898 .972 r
.69672 .4798 m .69403 .47875 L p .68322 .4839 L F P
0 g
s
.803 .672 .719 r
.25343 .38737 m .25396 .38664 L .25068 .38011 L p F P
0 g
s
.931 .665 .511 r
.03708 .41641 m .04108 .41962 L .04069 .42487 L p F P
0 g
s
.926 .685 .556 r
.04108 .41962 m .03708 .41641 L .03793 .41102 L p F P
0 g
s
.667 .877 .977 r
.68235 .48336 m .68746 .48137 L .68322 .4839 L closepath p F P
0 g
s
.688 .898 .972 r
.69403 .47875 m .68746 .48137 L .68322 .4839 L p F P
0 g
s
.532 .564 .834 r
.70668 .26402 m .70124 .26382 L .69834 .25781 L p F P
0 g
s
.559 .462 .701 r
.54325 .37058 m .54135 .36328 L .54692 .36055 L p F P
0 g
s
.86 .679 .656 r
.24563 .31213 m .25069 .31503 L .24822 .32094 L p F P
0 g
s
.859 .673 .649 r
.25069 .31503 m .24563 .31213 L .24789 .3063 L p F P
0 g
s
.811 .681 .72 r
.24731 .38491 m .25343 .38737 L .24852 .39415 L p F P
0 g
s
.803 .672 .719 r
.25068 .38011 m .24731 .38491 L .25343 .38737 L p F P
0 g
s
.413 .353 .681 r
.76457 .37407 m .76112 .37128 L .76334 .36907 L closepath p F P
0 g
s
.428 .375 .697 r
.76112 .37128 m .76334 .36907 L .76143 .36186 L p F P
0 g
s
.899 .675 .59 r
.2357 .27164 m .24016 .27481 L .23895 .28025 L p F P
0 g
s
.904 .661 .561 r
.24016 .27481 m .2357 .27164 L .23652 .26636 L p F P
0 g
s
.618 .616 .826 r
.60955 .47479 m .6067 .47538 L .60371 .46963 L p F P
0 g
s
.809 .681 .723 r
.2496 .40342 m .24368 .40091 L .24852 .39415 L p F P
0 g
s
.809 .682 .724 r
.2496 .40342 m .24551 .40896 L .24219 .40298 L p F P
0 g
s
.809 .682 .724 r
.24219 .40298 m .24368 .40091 L .2496 .40342 L p F P
0 g
s
.567 .614 .859 r
.663 .23666 m .67483 .23566 L p .67432 .24125 L F P
0 g
s
.568 .618 .862 r
.67193 .23043 m .67483 .23566 L .663 .23666 L p F P
0 g
s
.568 .618 .862 r
.6614 .23137 m .67193 .23043 L p .663 .23666 L F P
0 g
s
.568 .618 .862 r
.663 .23666 m .66067 .2325 L .6614 .23137 L p F P
0 g
s
.76 .735 .83 r
.18666 .475 m .18029 .47943 L .17676 .47555 L p F P
0 g
s
.465 .446 .752 r
.75195 .3315 m .75067 .33104 L .75149 .33014 L closepath p F P
0 g
s
.476 .463 .763 r
.74893 .32294 m .74747 .32249 L p .75067 .33104 L F P
0 g
s
.476 .463 .763 r
.75067 .33104 m .75149 .33014 L .74893 .32294 L p F P
0 g
s
.601 .55 .77 r
.57695 .43746 m .57756 .43899 L .567 .44357 L p F P
0 g
s
.601 .55 .77 r
.567 .44357 m .56539 .43946 L .57695 .43746 L p F P
0 g
s
.32 .186 .537 r
.76116 .40894 m .75835 .41139 L .75928 .41652 L p F P
0 g
s
.353 .235 .577 r
.75835 .41139 m .76116 .40894 L .7604 .40313 L p F P
0 g
s
.528 .022 0 r
.21652 .23442 m .21868 .2366 L .21514 .23318 L p F P
0 g
s
.528 .022 0 r
.21514 .23318 m .21289 .23089 L .21652 .23442 L p F P
0 g
s
.502 .512 .8 r
.72696 .29068 m .73705 .29232 L p .73322 .29827 L F P
0 g
s
.499 .514 .803 r
.72696 .29068 m .73705 .29232 L .73411 .28535 L p F P
0 g
s
.499 .514 .803 r
.73411 .28535 m .73139 .28491 L .72696 .29068 L p F P
0 g
s
.507 .525 .809 r
.72198 .28365 m .73139 .28491 L .72696 .29068 L p F P
0 g
s
.084 0 .188 r
.74766 .44034 m .74384 .4434 L .74298 .44735 L p F P
0 g
s
.184 0 .325 r
.74384 .4434 m .74766 .44034 L .75042 .43409 L p F P
0 g
s
0 .387 .796 r
.09018 .47541 m .09014 .47539 L .09039 .47555 L closepath p F P
0 g
s
.59 .64 .868 r
.64544 .22826 m .6572 .22655 L .6601 .23151 L p F P
0 g
s
.594 .646 .872 r
.6572 .22655 m .64544 .22826 L .64253 .22351 L p F P
0 g
s
.333 .221 .574 r
.76335 .40038 m .7604 .40313 L .76116 .40894 L p F P
0 g
s
.794 .679 .737 r
.2467 .41114 m .24551 .40896 L .24441 .41029 L closepath p F P
0 g
s
.912 .67 .558 r
.23224 .26311 m .23652 .26636 L .2357 .27164 L p F P
0 g
s
.918 .649 .514 r
.23652 .26636 m .23224 .26311 L .23258 .258 L p F P
0 g
s
0 .417 .824 r
.09014 .47539 m .09018 .47541 L .0864 .47279 L p F P
0 g
s
0 .417 .824 r
.0864 .47279 m .08559 .47246 L .09014 .47539 L p F P
0 g
s
.731 .208 0 r
.06687 .4593 m .06899 .46193 L .06515 .45948 L p F P
0 g
s
.731 .208 0 r
.06515 .45948 m .06249 .45628 L .06687 .4593 L p F P
0 g
s
.459 .335 .623 r
.54984 .29849 m .5572 .29349 L .55265 .28981 L p F P
0 g
s
.467 .348 .634 r
.55087 .30477 m .54984 .29849 L .5572 .29349 L p F P
0 g
s
.497 .369 .636 r
.54925 .30572 m .55087 .30477 L .54984 .29849 L p F P
0 g
s
.133 .567 .925 r
.10418 .47983 m .10044 .477 L .09018 .47541 L p F P
0 g
s
.307 .643 .967 r
.09018 .47541 m .10044 .477 L .09669 .47411 L p F P
0 g
s
.307 .643 .967 r
.0864 .47279 m .09018 .47541 L p .09669 .47411 L F P
0 g
s
.829 .679 .698 r
.24823 .36016 m .25393 .36279 L .25008 .3692 L p F P
0 g
s
.825 .674 .695 r
.25393 .36279 m .24823 .36016 L .25191 .35381 L p F P
0 g
s
.929 .689 .555 r
.034 .40776 m .03793 .41102 L .03708 .41641 L p F P
0 g
s
.922 .704 .59 r
.03793 .41102 m .034 .40776 L .03527 .40224 L p F P
0 g
s
.225 .043 .412 r
.75917 .42198 m .75324 .42708 L .75314 .43189 L p F P
0 g
s
.25 .062 .419 r
.75042 .43409 m .75314 .43189 L .75324 .42708 L p F P
0 g
s
.281 .125 .484 r
.75324 .42708 m .75917 .42198 L .75928 .41652 L p F P
0 g
s
.207 .016 .387 r
.56512 .2567 m .56617 .25576 L .56753 .25018 L p F P
0 g
s
.184 0 .376 r
.57372 .24438 m .56753 .25018 L .56617 .25576 L p F P
0 g
s
.023 0 .172 r
.56753 .25018 m .57372 .24438 L .57462 .24048 L p F P
0 g
s
.398 .265 .581 r
.55824 .27318 m .5568 .2743 L .55742 .28006 L p F P
0 g
s
.588 .498 .72 r
.54998 .39425 m .54579 .3949 L .54969 .39328 L closepath p F P
0 g
s
.586 .493 .715 r
.54743 .38558 m .54969 .39328 L .54579 .3949 L p F P
0 g
s
.842 .677 .678 r
.25291 .33927 m .25324 .33859 L .25238 .33815 L closepath p F P
0 g
s
.844 .674 .672 r
.24966 .3321 m .25076 .32976 L p .25324 .33859 L F P
0 g
s
.844 .674 .672 r
.25324 .33859 m .25238 .33815 L .24966 .3321 L p F P
0 g
s
.473 .461 .764 r
.74893 .32294 m .74747 .32249 L .74839 .32143 L closepath p F P
0 g
s
.484 .477 .774 r
.74593 .31483 m .74348 .31417 L p .74747 .32249 L F P
0 g
s
.484 .477 .774 r
.74747 .32249 m .74839 .32143 L .74593 .31483 L p F P
0 g
s
.597 .54 .762 r
.57408 .42994 m .57695 .43746 L .56539 .43946 L p F P
0 g
s
.597 .54 .762 r
.56539 .43946 m .56356 .43459 L .57408 .42994 L p F P
0 g
s
.438 .407 .727 r
.75692 .34658 m .76014 .34295 L p .7613 .35215 L F P
0 g
s
.438 .407 .727 r
.7613 .35215 m .75811 .35049 L .75692 .34658 L p F P
0 g
s
.447 .424 .74 r
.75692 .34658 m .755 .34063 L .76014 .34295 L closepath p F P
0 g
s
.552 .595 .851 r
.68831 .2463 m .68063 .24655 L .67773 .24104 L p F P
0 g
s
.447 .424 .74 r
.76014 .34295 m .755 .34063 L .75432 .33851 L p F P
0 g
s
.447 .424 .74 r
.75432 .33851 m .75825 .33398 L p .76014 .34295 L F P
0 g
s
.455 .439 .752 r
.75432 .33851 m .75195 .3315 L .75825 .33398 L closepath p F P
0 g
s
.801 .695 .747 r
.23721 .42876 m .23873 .42694 L .23517 .42542 L closepath p F P
0 g
s
.802 .693 .744 r
.23385 .42324 m .23859 .41738 L p .23873 .42694 L F P
0 g
s
.802 .693 .744 r
.23873 .42694 m .23517 .42542 L .23385 .42324 L p F P
0 g
s
.635 .72 .908 r
.63881 .48459 m .65049 .48162 L .65336 .48532 L p F P
0 g
s
.629 .684 .882 r
.6476 .47754 m .65049 .48162 L .63881 .48459 L p F P
0 g
s
.629 .684 .882 r
.63913 .47954 m .6476 .47754 L p .63881 .48459 L F P
0 g
s
.629 .684 .882 r
.63881 .48459 m .63641 .48105 L .63913 .47954 L p F P
0 g
s
.495 .5 .791 r
.73322 .29827 m .74 .29958 L p .73873 .3061 L F P
0 g
s
.494 .502 .794 r
.74 .29958 m .73322 .29827 L .73737 .2931 L closepath p F P
0 g
s
.502 .512 .8 r
.73705 .29232 m .73737 .2931 L .73322 .29827 L p F P
0 g
s
.506 .525 .811 r
.73139 .28491 m .72198 .28365 L .72113 .28169 L p F P
0 g
s
.868 .681 .648 r
.24297 .30333 m .24789 .3063 L .24563 .31213 L p F P
0 g
s
.868 .675 .64 r
.24789 .3063 m .24297 .30333 L .24501 .29758 L p F P
0 g
s
.717 .748 .877 r
.15104 .48427 m .15807 .48068 L .16384 .48318 L p F P
0 g
s
.708 .745 .88 r
.16206 .47867 m .15807 .48068 L .16384 .48318 L p F P
0 g
s
.708 .745 .88 r
.16384 .48318 m .16564 .48231 L .16206 .47867 L p F P
0 g
s
.564 .467 .703 r
.54377 .37252 m .54325 .37058 L .55359 .36564 L p F P
0 g
s
.559 .462 .701 r
.5522 .36045 m .55359 .36564 L .54325 .37058 L p F P
0 g
s
.559 .462 .701 r
.54692 .36055 m .5522 .36045 L p .54325 .37058 L F P
0 g
s
.926 .658 .51 r
.22848 .25468 m .23258 .258 L .23224 .26311 L p F P
0 g
s
.93 .622 .435 r
.23258 .258 m .22848 .25468 L .22822 .2498 L p F P
0 g
s
.438 .407 .727 r
.75928 .35435 m .75811 .35049 L .7613 .35215 L closepath p F P
0 g
s
.829 .673 .69 r
.24982 .34484 m .25291 .33927 L .25238 .33815 L p F P
0 g
s
.65 .71 .892 r
.61339 .22113 m .62503 .21756 L .62793 .22166 L p F P
0 g
s
.666 .73 .897 r
.62503 .21756 m .61339 .22113 L .61049 .21774 L p F P
0 g
s
.699 .77 .907 r
.59892 .22277 m .61049 .21774 L .61339 .22113 L p F P
0 g
s
.76 .735 .83 r
.17676 .47555 m .18106 .47245 L .18666 .475 L p F P
0 g
s
.751 .729 .832 r
.188 .46753 m .18106 .47245 L .18666 .475 L p F P
0 g
s
.751 .729 .832 r
.18666 .475 m .1915 .47169 L .188 .46753 L p F P
0 g
s
.48 .475 .775 r
.74593 .31483 m .74348 .31417 L .74502 .31238 L closepath p F P
0 g
s
.491 .49 .784 r
.74296 .30707 m .73873 .3061 L p .74348 .31417 L F P
0 g
s
.491 .49 .784 r
.74348 .31417 m .74502 .31238 L .74296 .30707 L p F P
0 g
s
.927 .556 .289 r
.22822 .2498 m .2243 .24639 L .22324 .2418 L p F P
0 g
s
.932 .562 .278 r
.21949 .23832 m .22324 .2418 L .2243 .24639 L p F P
0 g
s
.854 .403 .019 r
.21868 .2366 m .21949 .23832 L .22324 .2418 L p F P
0 g
s
.429 .39 .713 r
.75928 .35435 m .7613 .35215 L p .76171 .36157 L F P
0 g
s
.429 .39 .713 r
.76171 .36157 m .76127 .3613 L .75928 .35435 L p F P
0 g
s
.487 .489 .785 r
.74296 .30707 m .73873 .3061 L .74135 .30294 L closepath p F P
0 g
s
.495 .5 .791 r
.74 .29958 m .74135 .30294 L .73873 .3061 L p F P
0 g
s
.787 .691 .758 r
.23205 .43431 m .23721 .42876 L .23517 .42542 L p F P
0 g
s
.938 .63 .429 r
.2243 .24639 m .22822 .2498 L .22848 .25468 L p F P
0 g
s
.528 .417 .672 r
.54499 .33021 m .55481 .32458 L p .54962 .33525 L F P
0 g
s
.528 .417 .672 r
.54962 .33525 m .54593 .33456 L .54499 .33021 L p F P
0 g
s
.517 .406 .667 r
.55436 .3225 m .55481 .32458 L .54499 .33021 L p F P
0 g
s
.517 .406 .667 r
.54803 .32093 m .55436 .3225 L p .54499 .33021 L F P
0 g
s
.455 .44 .752 r
.75825 .33398 m .75195 .3315 L .75149 .33014 L p F P
0 g
s
.566 .474 .71 r
.5453 .37803 m .54377 .37252 L .55532 .37201 L p F P
0 g
s
.564 .467 .703 r
.55359 .36564 m .55532 .37201 L .54377 .37252 L p F P
0 g
s
.541 .572 .835 r
.69834 .25781 m .69627 .25778 L .69752 .25612 L closepath p F P
0 g
s
.546 .58 .84 r
.69544 .25198 m .69752 .25612 L .69627 .25778 L p F P
0 g
s
.463 .455 .763 r
.75149 .33014 m .74893 .32294 L .75562 .32523 L closepath p F P
0 g
s
.455 .44 .752 r
.75149 .33014 m .75562 .32523 L p .75825 .33398 L F P
0 g
s
.829 .673 .69 r
.25238 .33815 m .24768 .33589 L p .24982 .34484 L F P
0 g
s
.832 .67 .682 r
.25238 .33815 m .24966 .3321 L .24768 .33589 L closepath p F P
0 g
s
.795 .681 .739 r
.24441 .41029 m .24551 .40896 L .24219 .40298 L p F P
0 g
s
.596 .539 .761 r
.57389 .42945 m .57408 .42994 L .56356 .43459 L p F P
0 g
s
.596 .539 .761 r
.56356 .43459 m .56232 .43128 L .57389 .42945 L p F P
0 g
s
.618 .616 .826 r
.61536 .46736 m .61738 .47115 L .60955 .47479 L p F P
0 g
s
.618 .616 .826 r
.60371 .46963 m .61536 .46736 L p .60955 .47479 L F P
0 g
s
.619 .624 .833 r
.61834 .47294 m .60955 .47479 L .61738 .47115 L closepath p F P
0 g
s
.46 .335 .623 r
.55821 .28603 m .55265 .28981 L .5572 .29349 L p F P
0 g
s
.449 .316 .607 r
.55265 .28981 m .55821 .28603 L .55742 .28006 L p F P
0 g
s
.821 .68 .708 r
.25068 .38011 m .25185 .37826 L .24908 .37699 L closepath p F P
0 g
s
.823 .678 .704 r
.24739 .37364 m .25008 .3692 L p .25185 .37826 L F P
0 g
s
.823 .678 .704 r
.25185 .37826 m .24908 .37699 L .24739 .37364 L p F P
0 g
s
.743 .74 .849 r
.17676 .47555 m .16564 .48231 L .16206 .47867 L p F P
0 g
s
.506 .525 .811 r
.72113 .28169 m .72411 .27763 L p .73139 .28491 L F P
0 g
s
.512 .537 .818 r
.72113 .28169 m .71907 .27709 L .72411 .27763 L closepath p F P
0 g
s
.622 .749 .938 r
.12214 .48476 m .13288 .48197 L .13653 .48517 L p F P
0 g
s
.632 .751 .933 r
.13288 .48197 m .12214 .48476 L .11845 .48176 L p F P
0 g
s
.805 .691 .739 r
.23829 .40785 m .24441 .41029 L .23859 .41738 L p F P
0 g
s
.795 .681 .739 r
.24219 .40298 m .23829 .40785 L .24441 .41029 L p F P
0 g
s
.926 .708 .589 r
.03142 .39895 m .03527 .40224 L .034 .40776 L p F P
0 g
s
.918 .719 .618 r
.03302 .39351 m .03142 .39895 L .03527 .40224 L p F P
0 g
s
.504 .382 .647 r
.55118 .30645 m .54925 .30572 L .55087 .30477 L closepath p F P
0 g
s
.73 .805 .911 r
.61049 .21774 m .59892 .22277 L .59602 .22072 L p F P
0 g
s
.654 .863 .979 r
.68746 .48137 m .68235 .48336 L .67958 .48116 L p F P
0 g
s
.651 .832 .97 r
.66788 .485 m .67958 .48116 L .68235 .48336 L p F P
0 g
s
.815 .687 .723 r
.24263 .39161 m .24852 .39415 L .24368 .40091 L p F P
0 g
s
.811 .681 .72 r
.24852 .39415 m .24263 .39161 L .24731 .38491 L p F P
0 g
s
.609 .589 .806 r
.58609 .4593 m .5977 .45715 L .60071 .46359 L p F P
0 g
s
.605 .574 .792 r
.59608 .45354 m .5977 .45715 L .58609 .4593 L p F P
0 g
s
.605 .574 .792 r
.58609 .4593 m .58564 .45828 L .59608 .45354 L p F P
0 g
s
0 0 0 r
.73151 .45888 m .72599 .46312 L .7212 .46652 L p F P
0 g
s
0 0 0 r
.73253 .45747 m .73151 .45888 L p .7212 .46652 L F P
0 g
s
.461 .852 .649 r
.71996 .46723 m .72599 .46312 L .7212 .46652 L closepath p F P
0 g
s
.593 .943 .797 r
.7212 .46652 m .71996 .46723 L p .70858 .47405 L F P
0 g
s
.566 .474 .71 r
.55532 .37201 m .55562 .37308 L .5453 .37803 L p F P
0 g
s
.571 .478 .711 r
.5453 .37803 m .55562 .37308 L p .55212 .38335 L F P
0 g
s
.571 .478 .711 r
.55212 .38335 m .54688 .3837 L .5453 .37803 L p F P
0 g
s
.849 .68 .672 r
.24966 .3321 m .25076 .32976 L .24777 .32811 L closepath p F P
0 g
s
.852 .677 .664 r
.24641 .32507 m .24822 .32094 L p .25076 .32976 L F P
0 g
s
.852 .677 .664 r
.25076 .32976 m .24777 .32811 L .24641 .32507 L p F P
0 g
s
.876 .683 .638 r
.24024 .29455 m .24501 .29758 L .24297 .30333 L p F P
0 g
s
.877 .676 .627 r
.24501 .29758 m .24024 .29455 L .24204 .2889 L p F P
0 g
s
.796 .697 .755 r
.23205 .43431 m .22566 .4413 L .22227 .43616 L p F P
0 g
s
.796 .697 .755 r
.22227 .43616 m .22611 .43183 L .23205 .43431 L p F P
0 g
s
.787 .691 .758 r
.23273 .42448 m .22611 .43183 L .23205 .43431 L p F P
0 g
s
.787 .691 .758 r
.23517 .42542 m .23273 .42448 L p .23205 .43431 L F P
0 g
s
.429 .39 .713 r
.76143 .36186 m .76127 .3613 L .76171 .36157 L closepath p F P
0 g
s
.563 .604 .852 r
.67773 .24104 m .67432 .24125 L .67636 .23846 L closepath p F P
0 g
s
.567 .614 .859 r
.67483 .23566 m .67636 .23846 L .67432 .24125 L p F P
0 g
s
.592 .529 .753 r
.57087 .42119 m .57389 .42945 L .56232 .43128 L p F P
0 g
s
.592 .529 .753 r
.56232 .43128 m .56039 .42589 L .57087 .42119 L p F P
0 g
s
.413 .365 .696 r
.76171 .36157 m .76143 .36186 L .76334 .36907 L p F P
0 g
s
.833 .681 .694 r
.24632 .35113 m .25191 .35381 L .24823 .36016 L p F P
0 g
s
.829 .675 .691 r
.25191 .35381 m .24632 .35113 L .24982 .34484 L p F P
0 g
s
.644 .768 .939 r
.65336 .48532 m .66506 .48199 L .66788 .485 L p F P
0 g
s
.637 .737 .92 r
.66506 .48199 m .65336 .48532 L .65049 .48162 L p F P
0 g
s
.773 .724 .808 r
.19876 .4659 m .1915 .47169 L .188 .46753 L p F P
0 g
s
.463 .455 .764 r
.75562 .32523 m .74893 .32294 L .74839 .32143 L p F P
0 g
s
.603 .572 .792 r
.59467 .45039 m .59608 .45354 L .58564 .45828 L p F P
0 g
s
.603 .572 .792 r
.58564 .45828 m .58305 .45237 L .59467 .45039 L p F P
0 g
s
.808 .676 .718 r
.24731 .38491 m .25068 .38011 L .24908 .37699 L p F P
0 g
s
.528 .739 .971 r
.11185 .48239 m .11845 .48176 L .11474 .47872 L p F P
0 g
s
.528 .739 .971 r
.11474 .47872 m .10682 .47963 L .11185 .48239 L p F P
0 g
s
.472 .727 .981 r
.10418 .47983 m .10682 .47963 L .11185 .48239 L p F P
0 g
s
.612 .684 .893 r
.62793 .22166 m .63963 .219 L p .64206 .22361 L F P
0 g
s
.628 .687 .886 r
.63963 .219 m .62793 .22166 L .62503 .21756 L p F P
0 g
s
.177 0 .32 r
.75314 .43189 m .75042 .43409 L .74766 .44034 L p F P
0 g
s
.369 .223 .548 r
.55824 .27318 m .56562 .26732 L .56522 .26182 L p F P
0 g
s
.398 .265 .581 r
.55742 .28006 m .56065 .27754 L .55824 .27318 L p F P
0 g
s
.395 .263 .582 r
.56562 .26732 m .55824 .27318 L .56065 .27754 L p F P
0 g
s
.463 .455 .764 r
.74839 .32143 m .75225 .3167 L p .75562 .32523 L F P
0 g
s
.471 .469 .774 r
.74839 .32143 m .74593 .31483 L .75225 .3167 L closepath p F P
0 g
s
.781 .699 .773 r
.22617 .44208 m .22566 .4413 L .22523 .44172 L closepath p F P
0 g
s
0 .267 .693 r
.08559 .47246 m .08109 .4695 L .07519 .46621 L p F P
0 g
s
.566 .007 0 r
.06899 .46193 m .07064 .46326 L .07519 .46621 L p F P
0 g
s
0 .289 .717 r
.07064 .46326 m .07519 .46621 L .08109 .4695 L p F P
0 g
s
.526 .422 .678 r
.54648 .33703 m .54593 .33456 L .54962 .33525 L closepath p F P
0 g
s
.647 .793 .952 r
.67958 .48116 m .66788 .485 L .66506 .48199 L p F P
0 g
s
.415 .37 .7 r
.7671 .3557 m .76171 .36157 L .76686 .36533 L p F P
0 g
s
.429 .39 .713 r
.7613 .35215 m .7671 .3557 L .76171 .36157 L p F P
0 g
s
.413 .365 .696 r
.76334 .36907 m .76686 .36533 L .76171 .36157 L p F P
0 g
s
.592 .529 .753 r
.57081 .42103 m .57087 .42119 L .56039 .42589 L p F P
0 g
s
.592 .529 .753 r
.56039 .42589 m .55925 .4227 L .57081 .42103 L p F P
0 g
s
.571 .485 .718 r
.54743 .38558 m .54688 .3837 L .55212 .38335 L closepath p F P
0 g
s
.723 .752 .875 r
.15807 .48068 m .15104 .48427 L .14743 .48086 L p F P
0 g
s
.681 .752 .905 r
.13653 .48517 m .14743 .48086 L .15104 .48427 L p F P
0 g
s
.688 .753 .901 r
.14743 .48086 m .13653 .48517 L .13288 .48197 L p F P
0 g
s
.572 .486 .72 r
.54969 .39328 m .54743 .38558 L .55212 .38335 L p F P
0 g
s
.605 .953 .882 r
.70836 .47406 m .70949 .47344 L .70858 .47405 L closepath p F P
0 g
s
.593 .943 .797 r
.71996 .46723 m .70949 .47344 L .70858 .47405 L p F P
0 g
s
.623 .661 .867 r
.6213 .47814 m .63297 .4756 L .6359 .4803 L p F P
0 g
s
.617 .644 .855 r
.63297 .4756 m .6213 .47814 L .61834 .47294 L p F P
0 g
s
.588 .519 .745 r
.56791 .41271 m .57081 .42103 L .55925 .4227 L p F P
0 g
s
.588 .519 .745 r
.55925 .4227 m .55745 .41745 L .56791 .41271 L p F P
0 g
s
.529 .565 .836 r
.70744 .25228 m .71034 .25822 L .69834 .25781 L p F P
0 g
s
.529 .565 .836 r
.70025 .25204 m .70744 .25228 L p .69834 .25781 L F P
0 g
s
.529 .565 .836 r
.69834 .25781 m .69752 .25612 L .70025 .25204 L p F P
0 g
s
.532 .564 .834 r
.69834 .25781 m .71034 .25822 L p .70668 .26402 L F P
0 g
s
.773 .724 .808 r
.188 .46753 m .19303 .46338 L .19876 .4659 L p F P
0 g
s
.765 .72 .811 r
.19933 .45828 m .19303 .46338 L .19876 .4659 L p F P
0 g
s
.765 .72 .811 r
.19876 .4659 m .2028 .46273 L .19933 .45828 L p F P
0 g
s
.885 .684 .626 r
.23743 .28579 m .24204 .2889 L .24024 .29455 L p F P
0 g
s
.887 .676 .611 r
.24204 .2889 m .23743 .28579 L .23895 .28025 L p F P
0 g
s
.285 .127 .484 r
.56617 .25576 m .56512 .2567 L .56522 .26182 L p F P
0 g
s
.781 .7 .774 r
.22523 .44172 m .22566 .4413 L .22227 .43616 L p F P
0 g
s
.793 .712 .775 r
.21913 .4393 m .22523 .44172 L .21731 .4495 L p F P
0 g
s
.781 .7 .774 r
.22227 .43616 m .21913 .4393 L .22523 .44172 L p F P
0 g
s
.574 .627 .866 r
.66067 .2325 m .6601 .23151 L .6614 .23137 L closepath p F P
0 g
s
.38 .298 .638 r
.76652 .3827 m .76378 .38535 L .76718 .3897 L p F P
0 g
s
.399 .327 .659 r
.76378 .38535 m .76652 .3827 L .76505 .37603 L p F P
0 g
s
.608 .601 .819 r
.61237 .46147 m .61536 .46736 L .60371 .46963 L p F P
0 g
s
.608 .601 .819 r
.60298 .46318 m .61237 .46147 L p .60371 .46963 L F P
0 g
s
.608 .601 .819 r
.60371 .46963 m .601 .46416 L .60298 .46318 L p F P
0 g
s
0 0 .15 r
.578 .23703 m .57462 .24048 L .57372 .24438 L p F P
0 g
s
0 0 0 r
.58382 .22996 m .578 .23703 L .57462 .24048 L p F P
0 g
s
.858 .683 .664 r
.24822 .32094 m .24641 .32507 L .24314 .31821 L p F P
0 g
s
.858 .683 .664 r
.24314 .31821 m .24322 .31801 L .24822 .32094 L p F P
0 g
s
.86 .679 .656 r
.24822 .32094 m .24322 .31801 L .24563 .31213 L p F P
0 g
s
.836 .677 .684 r
.24768 .33589 m .24966 .3321 L .24777 .32811 L p F P
0 g
s
.529 .427 .683 r
.5481 .344 m .54648 .33703 L .54962 .33525 L p F P
0 g
s
.518 .406 .666 r
.55436 .3225 m .54803 .32093 L .5534 .31785 L closepath p F P
0 g
s
.515 .396 .655 r
.55208 .31125 m .5534 .31785 L .54803 .32093 L p F P
0 g
s
.828 .681 .701 r
.25008 .3692 m .24739 .37364 L .24409 .36726 L p F P
0 g
s
.828 .681 .701 r
.24409 .36726 m .24453 .36652 L .25008 .3692 L p F P
0 g
s
.829 .679 .698 r
.25008 .3692 m .24453 .36652 L .24823 .36016 L p F P
0 g
s
.587 .518 .745 r
.56773 .41219 m .56791 .41271 L .55745 .41745 L p F P
0 g
s
.587 .518 .745 r
.55745 .41745 m .55616 .41369 L .56773 .41219 L p F P
0 g
s
.576 .49 .721 r
.54998 .39425 m .54969 .39328 L .56012 .38847 L p F P
0 g
s
.572 .486 .72 r
.55843 .38287 m .56012 .38847 L .54969 .39328 L p F P
0 g
s
.572 .486 .72 r
.55212 .38335 m .55843 .38287 L p .54969 .39328 L F P
0 g
s
.487 .37 .646 r
.55087 .30477 m .56024 .29853 L p .55582 .30878 L F P
0 g
s
.487 .37 .646 r
.55582 .30878 m .55118 .30645 L .55087 .30477 L p F P
0 g
s
.467 .348 .634 r
.55964 .2951 m .56024 .29853 L .55087 .30477 L p F P
0 g
s
.467 .348 .634 r
.5572 .29349 m .55964 .2951 L p .55087 .30477 L F P
0 g
s
.576 .49 .721 r
.56012 .38847 m .56154 .39314 L .54998 .39425 L p F P
0 g
s
.578 .498 .728 r
.55213 .40118 m .54998 .39425 L .56154 .39314 L p F P
0 g
s
.805 .691 .739 r
.23859 .41738 m .23385 .42324 L .23049 .41772 L p F P
0 g
s
.805 .691 .739 r
.23049 .41772 m .23276 .41485 L .23859 .41738 L p F P
0 g
s
.805 .691 .739 r
.23859 .41738 m .23276 .41485 L .23829 .40785 L p F P
0 g
s
.79 .69 .754 r
.23517 .42542 m .23385 .42324 L .23273 .42448 L closepath p F P
0 g
s
.401 .345 .679 r
.76334 .36907 m .76686 .36533 L p .76586 .37518 L F P
0 g
s
.401 .345 .679 r
.76586 .37518 m .76457 .37407 L .76334 .36907 L p F P
0 g
s
.784 .717 .79 r
.20862 .45751 m .2028 .46273 L .19933 .45828 L p F P
0 g
s
.583 .509 .737 r
.56515 .40445 m .56773 .41219 L .55616 .41369 L p F P
0 g
s
.583 .509 .737 r
.55616 .41369 m .55471 .40922 L .56515 .40445 L p F P
0 g
s
.793 .711 .774 r
.21731 .4495 m .21419 .4526 L .21076 .44784 L p F P
0 g
s
.793 .711 .774 r
.21076 .44784 m .21164 .44694 L .21731 .4495 L p F P
0 g
s
.793 .712 .775 r
.21731 .4495 m .21164 .44694 L .21913 .4393 L p F P
0 g
s
.585 .945 .896 r
.70949 .47344 m .70836 .47406 L .70572 .47357 L p F P
0 g
s
.61 .939 .95 r
.69403 .47875 m .70572 .47357 L .70836 .47406 L p F P
0 g
s
.784 .717 .79 r
.19933 .45828 m .2029 .45498 L .20862 .45751 L p F P
0 g
s
.775 .711 .792 r
.21076 .44784 m .2029 .45498 L .20862 .45751 L p F P
0 g
s
.775 .711 .792 r
.20862 .45751 m .21419 .4526 L .21076 .44784 L p F P
0 g
s
.582 .508 .736 r
.56464 .4029 m .56515 .40445 L .55471 .40922 L p F P
0 g
s
.582 .508 .736 r
.55471 .40922 m .55307 .40421 L .56464 .4029 L p F P
0 g
s
.579 .5 .729 r
.55307 .40421 m .55213 .40118 L .56257 .39638 L p F P
0 g
s
.578 .498 .728 r
.56154 .39314 m .56257 .39638 L .55213 .40118 L p F P
0 g
s
.837 .682 .69 r
.24434 .34211 m .24982 .34484 L .24632 .35113 L p F P
0 g
s
.829 .673 .69 r
.24768 .33589 m .24434 .34211 L .24982 .34484 L p F P
0 g
s
.471 .47 .775 r
.75225 .3167 m .74593 .31483 L .74502 .31238 L p F P
0 g
s
0 0 0 r
.73151 .45888 m .73633 .4546 L .73253 .45747 L closepath p F P
0 g
s
0 0 0 r
.74289 .44761 m .73633 .4546 L .73253 .45747 L p F P
0 g
s
0 0 0 r
.74298 .44735 m .74289 .44761 L p .73253 .45747 L F P
0 g
s
.579 .5 .729 r
.56257 .39638 m .56464 .4029 L .55307 .40421 L p F P
0 g
s
.808 .676 .718 r
.24908 .37699 m .24601 .37569 L p .24731 .38491 L F P
0 g
s
.811 .675 .713 r
.24908 .37699 m .24739 .37364 L .24601 .37569 L closepath p F P
0 g
s
.512 .537 .819 r
.72411 .27763 m .71907 .27709 L .71615 .27061 L p F P
0 g
s
.565 .935 .816 r
.70949 .47344 m .71788 .46769 L .71996 .46723 L closepath p F P
0 g
s
.585 .945 .896 r
.71788 .46769 m .70949 .47344 L p .70572 .47357 L F P
0 g
s
.819 .687 .718 r
.24148 .38235 m .24731 .38491 L .24263 .39161 L p F P
0 g
s
.808 .676 .718 r
.24601 .37569 m .24148 .38235 L .24731 .38491 L p F P
0 g
s
.537 .577 .842 r
.69752 .25612 m .69544 .25198 L .70025 .25204 L closepath p F P
0 g
s
.574 .632 .871 r
.6614 .23137 m .6601 .23151 L .6572 .22655 L p F P
0 g
s
.895 .685 .61 r
.2345 .27707 m .23895 .28025 L .23743 .28579 L p F P
0 g
s
.899 .675 .59 r
.23895 .28025 m .2345 .27707 L .2357 .27164 L p F P
0 g
s
.929 .595 .383 r
.04487 .43314 m .04509 .43482 L .04115 .43273 L p F P
0 g
s
.929 .595 .383 r
.04115 .43273 m .0408 .42997 L .04487 .43314 L p F P
0 g
s
.931 .634 .456 r
.04487 .43314 m .0408 .42997 L .04069 .42487 L p F P
0 g
s
.483 .373 .652 r
.55208 .31125 m .55118 .30645 L .55582 .30878 L closepath p F P
0 g
s
.815 .687 .723 r
.23886 .39705 m .24263 .39161 L p .24368 .40091 L F P
0 g
s
.815 .687 .723 r
.24368 .40091 m .2401 .39929 L .23886 .39705 L p F P
0 g
s
.813 .689 .727 r
.24219 .40298 m .24368 .40091 L .2401 .39929 L closepath p F P
0 g
s
.898 .494 .233 r
.05572 .44886 m .05146 .44577 L .04986 .44114 L p F P
0 g
s
.899 .494 .223 r
.04567 .43802 m .04986 .44114 L .05146 .44577 L p F P
0 g
s
.921 .573 .36 r
.04509 .43482 m .04567 .43802 L .04986 .44114 L p F P
0 g
s
.471 .47 .775 r
.74502 .31238 m .74817 .30839 L p .75225 .3167 L F P
0 g
s
.478 .483 .784 r
.74502 .31238 m .74296 .30707 L .74817 .30839 L closepath p F P
0 g
s
.654 .863 .979 r
.69282 .478 m .68746 .48137 L p .67958 .48116 L F P
0 g
s
.672 .881 .976 r
.68746 .48137 m .69282 .478 L .69403 .47875 L closepath p F P
0 g
s
.32 .186 .537 r
.75928 .41652 m .76166 .41444 L .76116 .40894 L p F P
0 g
s
.298 .17 .532 r
.76512 .40525 m .76116 .40894 L .76166 .41444 L p F P
0 g
s
.333 .221 .574 r
.76116 .40894 m .76512 .40525 L .76335 .40038 L p F P
0 g
s
.527 .553 .826 r
.70668 .26402 m .71324 .2644 L p .71607 .2706 L F P
0 g
s
.526 .555 .828 r
.71324 .2644 m .70668 .26402 L .71055 .25867 L closepath p F P
0 g
s
.532 .564 .834 r
.71034 .25822 m .71055 .25867 L .70668 .26402 L p F P
0 g
s
.855 .407 .01 r
.21949 .23832 m .21868 .2366 L .21514 .23318 L p F P
0 g
s
.561 .461 .698 r
.5522 .36045 m .54692 .36055 L .55164 .35828 L closepath p F P
0 g
s
.558 .453 .691 r
.54982 .35108 m .55164 .35828 L .54692 .36055 L p F P
0 g
s
.598 .561 .784 r
.59173 .44354 m .59467 .45039 L .58305 .45237 L p F P
0 g
s
.598 .561 .784 r
.58305 .45237 m .58139 .44841 L .59173 .44354 L p F P
0 g
s
.415 .292 .603 r
.56065 .27754 m .55742 .28006 L .55821 .28603 L p F P
0 g
s
.935 .637 .453 r
.03668 .42166 m .04069 .42487 L .0408 .42997 L p F P
0 g
s
.931 .665 .511 r
.04069 .42487 m .03668 .42166 L .03708 .41641 L p F P
0 g
s
.61 .668 .881 r
.64253 .22351 m .64206 .22361 L .64235 .22323 L closepath p F P
0 g
s
.612 .684 .893 r
.63963 .219 m .64235 .22323 L .64206 .22361 L p F P
0 g
s
.866 .686 .656 r
.24077 .30914 m .24563 .31213 L .24322 .31801 L p F P
0 g
s
.868 .681 .648 r
.24563 .31213 m .24077 .30914 L .24297 .30333 L p F P
0 g
s
.285 .127 .484 r
.56522 .26182 m .5663 .26086 L .56617 .25576 L p F P
0 g
s
.269 .116 .48 r
.57341 .24899 m .56617 .25576 L .5663 .26086 L p F P
0 g
s
.184 0 .376 r
.56617 .25576 m .57341 .24899 L .57372 .24438 L p F P
0 g
s
.552 .595 .851 r
.67773 .24104 m .68964 .2406 L p .68831 .2463 L F P
0 g
s
.551 .598 .854 r
.68674 .23513 m .68964 .2406 L .67773 .24104 L p F P
0 g
s
.551 .598 .854 r
.67824 .23547 m .68674 .23513 L p .67773 .24104 L F P
0 g
s
.551 .598 .854 r
.67773 .24104 m .67636 .23846 L .67824 .23547 L p F P
0 g
s
.84 .373 .055 r
.06249 .45628 m .05818 .45322 L .05572 .44886 L p F P
0 g
s
.837 .368 .039 r
.05146 .44577 m .05572 .44886 L .05818 .45322 L p F P
0 g
s
.629 .683 .882 r
.63641 .48105 m .6359 .4803 L .63913 .47954 L closepath p F P
0 g
s
.839 .673 .676 r
.24777 .32811 m .24641 .32507 L .24548 .32694 L closepath p F P
0 g
s
.836 .677 .684 r
.24777 .32811 m .24548 .32694 L p .24768 .33589 L F P
0 g
s
.8 .685 .737 r
.23829 .40785 m .24219 .40298 L .2401 .39929 L p F P
0 g
s
.594 .646 .872 r
.64253 .22351 m .6543 .22168 L .6572 .22655 L p F P
0 g
s
.598 .662 .883 r
.65139 .21689 m .6543 .22168 L .64253 .22351 L p F P
0 g
s
.598 .662 .883 r
.64544 .21793 m .65139 .21689 L p .64253 .22351 L F P
0 g
s
.598 .662 .883 r
.64253 .22351 m .64235 .22323 L .64544 .21793 L p F P
0 g
s
.402 .345 .679 r
.76505 .37603 m .76457 .37407 L .76586 .37518 L closepath p F P
0 g
s
.766 .739 .828 r
.18106 .47245 m .17676 .47555 L .17322 .47166 L p F P
0 g
s
.743 .74 .849 r
.16206 .47867 m .17322 .47166 L .17676 .47555 L p F P
0 g
s
.791 .692 .755 r
.23273 .42448 m .23385 .42324 L .23049 .41772 L p F P
0 g
s
.425 .389 .715 r
.76658 .34629 m .7613 .35215 L .7671 .3557 L p F P
0 g
s
.438 .407 .727 r
.76014 .34295 m .76658 .34629 L .7613 .35215 L p F P
0 g
s
.907 .683 .588 r
.23143 .2684 m .2357 .27164 L .2345 .27707 L p F P
0 g
s
.912 .67 .558 r
.2357 .27164 m .23143 .2684 L .23224 .26311 L p F P
0 g
s
.278 .122 .483 r
.76166 .41444 m .75928 .41652 L .75917 .42198 L p F P
0 g
s
.526 0 0 r
.07064 .46326 m .06899 .46193 L .06515 .45948 L p F P
0 g
s
.574 .628 .867 r
.6614 .23137 m .67193 .23043 L .66903 .22524 L p F P
0 g
s
.574 .628 .867 r
.66903 .22524 m .66501 .22566 L .6614 .23137 L p F P
0 g
s
.574 .632 .871 r
.6572 .22655 m .66501 .22566 L .6614 .23137 L p F P
0 g
s
.834 .685 .698 r
.24278 .35744 m .24823 .36016 L .24453 .36652 L p F P
0 g
s
.833 .681 .694 r
.24823 .36016 m .24278 .35744 L .24632 .35113 L p F P
0 g
s
.36 .264 .609 r
.76817 .39147 m .76718 .3897 L p .76335 .40038 L F P
0 g
s
.36 .264 .609 r
.76335 .40038 m .7688 .39524 L .76817 .39147 L p F P
0 g
s
.331 .22 .574 r
.7688 .39524 m .76335 .40038 L .76512 .40525 L p F P
0 g
s
.538 .436 .686 r
.5481 .344 m .55799 .33846 L p .55423 .34863 L F P
0 g
s
.538 .436 .686 r
.55423 .34863 m .54907 .34805 L .5481 .344 L p F P
0 g
s
.529 .427 .683 r
.55752 .33649 m .55799 .33846 L .5481 .344 L p F P
0 g
s
.529 .427 .683 r
.54962 .33525 m .55752 .33649 L p .5481 .344 L F P
0 g
s
.802 .703 .756 r
.22671 .42202 m .23273 .42448 L .22611 .43183 L p F P
0 g
s
.791 .692 .755 r
.23049 .41772 m .22671 .42202 L .23273 .42448 L p F P
0 g
s
.603 .668 .886 r
.64235 .22323 m .63963 .219 L .64544 .21793 L closepath p F P
0 g
s
.495 .732 .978 r
.10682 .47963 m .10418 .47983 L .10044 .477 L p F P
0 g
s
.935 .669 .51 r
.03314 .41316 m .03708 .41641 L .03668 .42166 L p F P
0 g
s
.929 .689 .555 r
.03708 .41641 m .03314 .41316 L .034 .40776 L p F P
0 g
s
.842 .684 .686 r
.24232 .33311 m .24768 .33589 L .24434 .34211 L p F P
0 g
s
.836 .677 .684 r
.24548 .32694 m .24232 .33311 L .24768 .33589 L p F P
0 g
s
.814 .679 .715 r
.24601 .37569 m .24739 .37364 L .24409 .36726 L p F P
0 g
s
.382 .315 .658 r
.76586 .37518 m .76505 .37603 L .76652 .3827 L p F P
0 g
s
.723 .752 .875 r
.14743 .48086 m .1527 .47805 L .15807 .48068 L p F P
0 g
s
.714 .746 .876 r
.15848 .475 m .1527 .47805 L .15807 .48068 L p F P
0 g
s
.714 .746 .876 r
.15807 .48068 m .16206 .47867 L .15848 .475 L p F P
0 g
s
.478 .483 .785 r
.74817 .30839 m .74296 .30707 L .74135 .30294 L p F P
0 g
s
.598 .561 .783 r
.59163 .44329 m .59173 .44354 L .58139 .44841 L p F P
0 g
s
.598 .561 .783 r
.58139 .44841 m .58001 .4451 L .59163 .44329 L p F P
0 g
s
.084 0 .188 r
.74298 .44735 m .74332 .44708 L .74766 .44034 L p F P
0 g
s
.033 0 .126 r
.75269 .43628 m .74766 .44034 L .74332 .44708 L p F P
0 g
s
.177 0 .32 r
.74766 .44034 m .75269 .43628 L .75314 .43189 L p F P
0 g
s
.629 .664 .865 r
.63913 .47954 m .6359 .4803 L .63297 .4756 L p F P
0 g
s
.844 .68 .678 r
.24548 .32694 m .24641 .32507 L .24314 .31821 L p F P
0 g
s
0 .442 .847 r
.08559 .47246 m .0864 .47279 L .08261 .47009 L p F P
0 g
s
0 .442 .847 r
.08261 .47009 m .08109 .4695 L .08559 .47246 L p F P
0 g
s
.766 .739 .828 r
.17322 .47166 m .1757 .46981 L .18106 .47245 L p F P
0 g
s
.756 .73 .829 r
.18449 .46337 m .1757 .46981 L .18106 .47245 L p F P
0 g
s
.756 .73 .829 r
.18106 .47245 m .188 .46753 L .18449 .46337 L p F P
0 g
s
.92 .679 .556 r
.22814 .25979 m .23224 .26311 L .23143 .2684 L p F P
0 g
s
.926 .658 .51 r
.23224 .26311 m .22814 .25979 L .22848 .25468 L p F P
0 g
s
.875 .688 .647 r
.23825 .30028 m .24297 .30333 L .24077 .30914 L p F P
0 g
s
.876 .683 .638 r
.24297 .30333 m .23825 .30028 L .24024 .29455 L p F P
0 g
s
.715 .189 0 r
.06249 .45628 m .06515 .45948 L .0613 .4569 L p F P
0 g
s
.715 .189 0 r
.0613 .4569 m .05818 .45322 L .06249 .45628 L p F P
0 g
s
.924 .573 .349 r
.04567 .43802 m .04509 .43482 L .04115 .43273 L p F P
0 g
s
.822 .687 .715 r
.24024 .37309 m .24601 .37569 L .24148 .38235 L p F P
0 g
s
.814 .679 .715 r
.24409 .36726 m .24024 .37309 L .24601 .37569 L p F P
0 g
s
.488 .382 .659 r
.55582 .30878 m .55208 .31125 L .5534 .31785 L p F P
0 g
s
.812 .697 .737 r
.23244 .40531 m .23829 .40785 L .23276 .41485 L p F P
0 g
s
.8 .685 .737 r
.23785 .39836 m .23244 .40531 L .23829 .40785 L p F P
0 g
s
.8 .685 .737 r
.2401 .39929 m .23785 .39836 L p .23829 .40785 L F P
0 g
s
.537 .441 .693 r
.54982 .35108 m .54907 .34805 L .55423 .34863 L closepath p F P
0 g
s
.608 .601 .818 r
.601 .46416 m .60071 .46359 L .60298 .46318 L closepath p F P
0 g
s
.933 .693 .553 r
.03014 .40447 m .034 .40776 L .03314 .41316 L p F P
0 g
s
.926 .708 .589 r
.034 .40776 m .03014 .40447 L .03142 .39895 L p F P
0 g
s
.148 0 .311 r
.7579 .42779 m .75314 .43189 L .75269 .43628 L p F P
0 g
s
.225 .043 .412 r
.75314 .43189 m .7579 .42779 L .75917 .42198 L p F P
0 g
s
.819 .687 .719 r
.24263 .39161 m .23886 .39705 L .23552 .39117 L p F P
0 g
s
.819 .687 .719 r
.23552 .39117 m .237 .38899 L .24263 .39161 L p F P
0 g
s
.819 .687 .718 r
.24263 .39161 m .237 .38899 L .24148 .38235 L p F P
0 g
s
.53 .427 .681 r
.55752 .33649 m .54962 .33525 L .55636 .33147 L closepath p F P
0 g
s
.528 .417 .672 r
.55481 .32458 m .55636 .33147 L .54962 .33525 L p F P
0 g
s
.934 .667 .506 r
.22455 .25128 m .22848 .25468 L .22814 .25979 L p F P
0 g
s
.938 .63 .429 r
.22848 .25468 m .22455 .25128 L .2243 .24639 L p F P
0 g
s
.802 .702 .755 r
.22611 .43183 m .22227 .43616 L .21887 .43106 L p F P
0 g
s
.802 .702 .755 r
.21887 .43106 m .22041 .42927 L .22611 .43183 L p F P
0 g
s
.802 .703 .756 r
.22611 .43183 m .22041 .42927 L .22671 .42202 L p F P
0 g
s
.478 .483 .785 r
.74135 .30294 m .74336 .30032 L p .74817 .30839 L F P
0 g
s
.485 .496 .794 r
.74135 .30294 m .74 .29958 L .74336 .30032 L closepath p F P
0 g
s
.607 .589 .806 r
.60298 .46318 m .60071 .46359 L .5977 .45715 L p F P
0 g
s
.593 .55 .775 r
.58858 .43581 m .59163 .44329 L .58001 .4451 L p F P
0 g
s
.593 .55 .775 r
.58233 .43671 m .58858 .43581 L p .58001 .4451 L F P
0 g
s
.593 .55 .775 r
.58001 .4451 m .57756 .43899 L .58233 .43671 L p F P
0 g
s
.558 .608 .859 r
.67636 .23846 m .67483 .23566 L .67824 .23547 L closepath p F P
0 g
s
.537 .578 .844 r
.70025 .25204 m .69544 .25198 L .69254 .24624 L p F P
0 g
s
.573 .484 .716 r
.55843 .38287 m .55212 .38335 L .55781 .3807 L closepath p F P
0 g
s
.571 .478 .711 r
.55562 .37308 m .55781 .3807 L .55212 .38335 L p F P
0 g
s
.52 .544 .82 r
.71615 .27061 m .71607 .2706 L .71612 .27054 L closepath p F P
0 g
s
.527 .553 .826 r
.71324 .2644 m .71612 .27054 L .71607 .2706 L p F P
0 g
s
.84 .687 .692 r
.24096 .34836 m .24632 .35113 L .24278 .35744 L p F P
0 g
s
.837 .682 .69 r
.24632 .35113 m .24096 .34836 L .24434 .34211 L p F P
0 g
s
.844 .68 .678 r
.24314 .31821 m .24025 .3241 L .24548 .32694 L p F P
0 g
s
.848 .686 .681 r
.24025 .3241 m .24548 .32694 L .24232 .33311 L p F P
0 g
s
.512 .537 .819 r
.71615 .27061 m .72826 .2719 L p .72411 .27763 L F P
0 g
s
.508 .537 .821 r
.72535 .26552 m .72826 .2719 L .71615 .27061 L p F P
0 g
s
.508 .537 .821 r
.71992 .26495 m .72535 .26552 L p .71615 .27061 L F P
0 g
s
.508 .537 .821 r
.71615 .27061 m .71612 .27054 L .71992 .26495 L p F P
0 g
s
.946 .638 .422 r
.22053 .24292 m .2243 .24639 L .22455 .25128 L p F P
0 g
s
.932 .562 .278 r
.2243 .24639 m .22053 .24292 L .21949 .23832 L p F P
0 g
s
.517 .55 .828 r
.71612 .27054 m .71324 .2644 L .71992 .26495 L closepath p F P
0 g
s
.539 .444 .696 r
.55164 .35828 m .54982 .35108 L .55423 .34863 L p F P
0 g
s
.936 .565 .264 r
.21588 .23478 m .21949 .23832 L .22053 .24292 L p F P
0 g
s
.855 .407 .01 r
.21514 .23318 m .21588 .23478 L .21949 .23832 L p F P
0 g
s
.307 .643 .967 r
.09669 .47411 m .09668 .47411 L .0864 .47279 L p F P
0 g
s
.288 .645 .967 r
.09668 .47411 m .0864 .47279 L .08261 .47009 L p F P
0 g
s
.637 .963 .822 r
.71788 .46769 m .71996 .46723 L .72599 .46312 L p F P
0 g
s
.382 .315 .658 r
.76652 .3827 m .76974 .37938 L .76586 .37518 L p F P
0 g
s
.383 .319 .661 r
.77145 .3693 m .76586 .37518 L .76974 .37938 L p F P
0 g
s
.401 .345 .679 r
.76686 .36533 m .77145 .3693 L .76586 .37518 L p F P
0 g
s
.435 .408 .73 r
.76473 .33775 m .76014 .34295 L .76658 .34629 L p F P
0 g
s
.447 .424 .74 r
.7644 .33672 m .76473 .33775 L .76014 .34295 L p F P
0 g
s
.447 .424 .74 r
.75825 .33398 m .7644 .33672 L p .76014 .34295 L F P
0 g
s
.547 .586 .845 r
.69254 .24624 m .68831 .2463 L .69077 .24277 L closepath p F P
0 g
s
.552 .595 .851 r
.68964 .2406 m .69077 .24277 L .68831 .2463 L p F P
0 g
s
.617 .644 .855 r
.61834 .47294 m .63002 .47057 L .63297 .4756 L p F P
0 g
s
.611 .62 .835 r
.62744 .46591 m .63002 .47057 L .61834 .47294 L p F P
0 g
s
.611 .62 .835 r
.61834 .47294 m .61738 .47115 L .62744 .46591 L p F P
0 g
s
.803 .684 .733 r
.2401 .39929 m .23886 .39705 L .23785 .39836 L closepath p F P
0 g
s
.747 .741 .846 r
.17322 .47166 m .16206 .47867 L .15848 .475 L p F P
0 g
s
.666 .73 .897 r
.61049 .21774 m .62212 .21368 L .62503 .21756 L p F P
0 g
s
.686 .753 .902 r
.62212 .21368 m .61049 .21774 L .60758 .21475 L p F P
0 g
s
.73 .805 .911 r
.59602 .22072 m .60758 .21475 L .61049 .21774 L p F P
0 g
s
.884 .691 .637 r
.23567 .29144 m .24024 .29455 L .23825 .30028 L p F P
0 g
s
.885 .684 .626 r
.24024 .29455 m .23567 .29144 L .23743 .28579 L p F P
0 g
s
.695 .887 .968 r
.69282 .478 m .69403 .47875 L .70572 .47357 L p F P
0 g
s
.778 .729 .806 r
.19303 .46338 m .188 .46753 L .18449 .46337 L p F P
0 g
s
.786 .703 .772 r
.21913 .4393 m .22227 .43616 L .21887 .43106 L p F P
0 g
s
.541 .742 .969 r
.10682 .47963 m .11474 .47872 L .11103 .47563 L p F P
0 g
s
.541 .742 .969 r
.11103 .47563 m .10177 .47687 L .10682 .47963 L p F P
0 g
s
.495 .732 .978 r
.10044 .477 m .10177 .47687 L .10682 .47963 L p F P
0 g
s
.797 .715 .774 r
.21331 .43679 m .21913 .4393 L .21164 .44694 L p F P
0 g
s
.786 .703 .772 r
.21887 .43106 m .21331 .43679 L .21913 .4393 L p F P
0 g
s
0 0 .035 r
.74289 .44761 m .74332 .44708 L .74298 .44735 L closepath p F P
0 g
s
.637 .737 .92 r
.65049 .48162 m .66221 .47855 L .66506 .48199 L p F P
0 g
s
.631 .71 .904 r
.66221 .47855 m .65049 .48162 L .6476 .47754 L p F P
0 g
s
.485 .497 .794 r
.74336 .30032 m .74 .29958 L .73737 .2931 L p F P
0 g
s
.63 .676 .876 r
.6476 .47754 m .63913 .47954 L .64644 .47577 L closepath p F P
0 g
s
.629 .664 .865 r
.64468 .47307 m .64644 .47577 L .63913 .47954 L p F P
0 g
s
.629 .664 .865 r
.63297 .4756 m .64468 .47307 L p .63913 .47954 L F P
0 g
s
.778 .729 .806 r
.18449 .46337 m .18754 .46078 L .19303 .46338 L p F P
0 g
s
.769 .722 .808 r
.19586 .45384 m .18754 .46078 L .19303 .46338 L p F P
0 g
s
.769 .722 .808 r
.19303 .46338 m .19933 .45828 L .19586 .45384 L p F P
0 g
s
.632 .751 .933 r
.11845 .48176 m .12921 .47874 L .13288 .48197 L p F P
0 g
s
.641 .752 .929 r
.12921 .47874 m .11845 .48176 L .11474 .47872 L p F P
0 g
s
.628 .687 .886 r
.62503 .21756 m .63672 .21463 L .63963 .219 L p F P
0 g
s
.639 .701 .89 r
.63672 .21463 m .62503 .21756 L .62212 .21368 L p F P
0 g
s
0 .289 .717 r
.08109 .4695 m .07665 .46651 L .07064 .46326 L p F P
0 g
s
.526 0 0 r
.06515 .45948 m .06617 .46027 L .07064 .46326 L p F P
0 g
s
0 .308 .739 r
.06617 .46027 m .07064 .46326 L .07665 .46651 L p F P
0 g
s
.427 .312 .62 r
.56383 .28166 m .55821 .28603 L .55914 .29218 L p F P
0 g
s
.415 .292 .603 r
.55821 .28603 m .56383 .28166 L .56065 .27754 L p F P
0 g
s
.46 .335 .623 r
.5572 .29349 m .55914 .29218 L .55821 .28603 L p F P
0 g
s
.361 .285 .635 r
.76974 .37938 m .76652 .3827 L .76778 .38912 L p F P
0 g
s
.38 .298 .638 r
.76718 .3897 m .76778 .38912 L .76652 .3827 L p F P
0 g
s
.331 .194 .54 r
.5663 .26086 m .56522 .26182 L .56562 .26732 L p F P
0 g
s
.832 .687 .703 r
.24409 .36726 m .24453 .36652 L .24339 .36594 L closepath p F P
0 g
s
.834 .685 .698 r
.24079 .36093 m .24278 .35744 L p .24453 .36652 L F P
0 g
s
.834 .685 .698 r
.24453 .36652 m .24339 .36594 L .24079 .36093 L p F P
0 g
s
0 0 0 r
.74332 .44708 m .75123 .44068 L p .74154 .45062 L F P
0 g
s
0 0 0 r
.74154 .45062 m .74289 .44761 L .74332 .44708 L p F P
0 g
s
.033 0 .126 r
.75197 .43962 m .75269 .43628 L p .74332 .44708 L F P
0 g
s
.033 0 .126 r
.74332 .44708 m .75123 .44068 L .75197 .43962 L p F P
0 g
s
.812 .697 .739 r
.23276 .41485 m .23049 .41772 L .22711 .41228 L p F P
0 g
s
.812 .697 .739 r
.22711 .41228 m .22715 .41223 L .23276 .41485 L p F P
0 g
s
.812 .697 .737 r
.23276 .41485 m .22715 .41223 L .23244 .40531 L p F P
0 g
s
.609 .596 .813 r
.61237 .46147 m .60298 .46318 L .61128 .4592 L closepath p F P
0 g
s
.607 .589 .806 r
.60936 .45521 m .61128 .4592 L .60298 .46318 L p F P
0 g
s
.607 .589 .806 r
.5977 .45715 m .60936 .45521 L p .60298 .46318 L F P
0 g
s
.593 .549 .775 r
.57756 .43899 m .57695 .43746 L .58233 .43671 L closepath p F P
0 g
s
0 0 0 r
.73633 .4546 m .74154 .45062 L .74289 .44761 L closepath p F P
0 g
s
0 0 0 r
.72599 .46312 m .73038 .45994 L .73151 .45888 L closepath p F P
0 g
s
.637 .963 .822 r
.72599 .46312 m .73038 .45994 L p .71788 .46769 L F P
0 g
s
.61 .619 .835 r
.62705 .46521 m .62744 .46591 L .61738 .47115 L p F P
0 g
s
.61 .619 .835 r
.61738 .47115 m .61536 .46736 L .62705 .46521 L p F P
0 g
s
.796 .716 .776 r
.21076 .44784 m .21164 .44694 L .20931 .44584 L closepath p F P
0 g
s
.797 .715 .774 r
.20732 .44308 m .21331 .43679 L p .21164 .44694 L F P
0 g
s
.797 .715 .774 r
.21164 .44694 m .20931 .44584 L .20732 .44308 L p F P
0 g
s
0 0 0 r
.578 .23703 m .58242 .23208 L .58431 .22941 L p F P
0 g
s
.789 .722 .789 r
.2029 .45498 m .19933 .45828 L .19586 .45384 L p F P
0 g
s
.789 .722 .789 r
.19586 .45384 m .19741 .45237 L .2029 .45498 L p F P
0 g
s
.78 .713 .789 r
.20589 .44441 m .19741 .45237 L .2029 .45498 L p F P
0 g
s
.78 .713 .789 r
.20931 .44584 m .20589 .44441 L p .2029 .45498 L F P
0 g
s
.78 .713 .789 r
.2029 .45498 m .21076 .44784 L .20931 .44584 L p F P
0 g
s
.893 .692 .625 r
.23301 .28261 m .23743 .28579 L .23567 .29144 L p F P
0 g
s
.895 .685 .61 r
.23743 .28579 m .23301 .28261 L .2345 .27707 L p F P
0 g
s
.863 .69 .666 r
.24314 .31821 m .24322 .31801 L .24295 .31784 L closepath p F P
0 g
s
.866 .686 .656 r
.23986 .31138 m .24077 .30914 L p .24322 .31801 L F P
0 g
s
.866 .686 .656 r
.24322 .31801 m .24295 .31784 L .23986 .31138 L p F P
0 g
s
.805 .687 .734 r
.23785 .39836 m .23886 .39705 L .23552 .39117 L p F P
0 g
s
.547 .452 .699 r
.55164 .35828 m .56162 .35286 L p .56211 .36101 L F P
0 g
s
.547 .452 .699 r
.56211 .36101 m .5522 .36045 L .55164 .35828 L p F P
0 g
s
.539 .444 .696 r
.56067 .34922 m .56162 .35286 L .55164 .35828 L p F P
0 g
s
.539 .444 .696 r
.55423 .34863 m .56067 .34922 L p .55164 .35828 L F P
0 g
s
.819 .684 .714 r
.24024 .37309 m .24409 .36726 L .24339 .36594 L p F P
0 g
s
.73 .754 .872 r
.1527 .47805 m .14743 .48086 L .1438 .47743 L p F P
0 g
s
.688 .753 .901 r
.13288 .48197 m .1438 .47743 L .14743 .48086 L p F P
0 g
s
.845 .689 .689 r
.23909 .33929 m .24434 .34211 L .24096 .34836 L p F P
0 g
s
.842 .684 .686 r
.24434 .34211 m .23909 .33929 L .24232 .33311 L p F P
0 g
s
.85 .687 .679 r
.24025 .3241 m .24314 .31821 L .24295 .31784 L p F P
0 g
s
.593 .541 .766 r
.58233 .43671 m .57695 .43746 L .57408 .42994 L p F P
0 g
s
.505 .527 .813 r
.73118 .27857 m .72411 .27763 L .72826 .27191 L closepath p F P
0 g
s
.512 .537 .819 r
.72826 .2719 m .72826 .27191 L .72411 .27763 L p F P
0 g
s
.506 .525 .811 r
.72411 .27763 m .73118 .27857 L p .73139 .28491 L F P
0 g
s
.825 .693 .718 r
.2359 .37969 m .24148 .38235 L .237 .38899 L p F P
0 g
s
.822 .687 .715 r
.24148 .38235 m .2359 .37969 L .24024 .37309 L p F P
0 g
s
.445 .426 .744 r
.7644 .33672 m .75825 .33398 L .76205 .32955 L closepath p F P
0 g
s
.455 .44 .752 r
.76132 .32744 m .76205 .32955 L .75825 .33398 L p F P
0 g
s
.455 .44 .752 r
.75562 .32523 m .76132 .32744 L p .75825 .33398 L F P
0 g
s
.503 .396 .666 r
.5534 .31785 m .5626 .31179 L p .55676 .32333 L F P
0 g
s
.503 .396 .666 r
.55676 .32333 m .55436 .3225 L .5534 .31785 L p F P
0 g
s
.488 .382 .659 r
.5534 .31785 m .5626 .31179 L .55582 .30878 L p F P
0 g
s
.85 .687 .679 r
.24295 .31784 m .23815 .3151 L p .24025 .3241 L F P
0 g
s
.853 .682 .67 r
.24295 .31784 m .23986 .31138 L .23815 .3151 L closepath p F P
0 g
s
.577 .638 .875 r
.66501 .22566 m .6572 .22655 L .6543 .22168 L p F P
0 g
s
.652 .822 .965 r
.69131 .47699 m .67958 .48116 L .67679 .47846 L p F P
0 g
s
.647 .793 .952 r
.66506 .48199 m .67679 .47846 L .67958 .48116 L p F P
0 g
s
.654 .863 .979 r
.67958 .48116 m .69131 .47699 L .69282 .478 L p F P
0 g
s
.694 .753 .897 r
.1438 .47743 m .13288 .48197 L .12921 .47874 L p F P
0 g
s
.412 .292 .605 r
.56626 .2731 m .56065 .27754 L .56383 .28166 L p F P
0 g
s
.395 .263 .582 r
.56065 .27754 m .56626 .2731 L .56562 .26732 L p F P
0 g
s
.641 .758 .934 r
.67679 .47846 m .66506 .48199 L .66221 .47855 L p F P
0 g
s
.805 .687 .734 r
.23552 .39117 m .23201 .3958 L .23785 .39836 L p F P
0 g
s
.814 .696 .735 r
.23201 .3958 m .23785 .39836 L .23244 .40531 L p F P
0 g
s
.547 .458 .706 r
.55359 .36564 m .5522 .36045 L .56211 .36101 L closepath p F P
0 g
s
.253 .104 .477 r
.76601 .4104 m .76166 .41444 L .76188 .41961 L p F P
0 g
s
.298 .17 .532 r
.76166 .41444 m .76601 .4104 L .76512 .40525 L p F P
0 g
s
.278 .122 .483 r
.75917 .42198 m .76188 .41961 L .76166 .41444 L p F P
0 g
s
.796 .696 .754 r
.22671 .42202 m .23049 .41772 L .22711 .41228 L p F P
0 g
s
.558 .611 .862 r
.67824 .23547 m .67483 .23566 L .67193 .23043 L p F P
0 g
s
0 0 0 r
.73038 .45994 m .73151 .45888 L .73633 .4546 L p F P
0 g
s
.469 .351 .636 r
.55964 .2951 m .5572 .29349 L .55914 .29218 L closepath p F P
0 g
s
0 0 0 r
.73633 .4546 m .74154 .45062 L p .73038 .45994 L F P
0 g
s
0 0 .199 r
.58242 .23208 m .578 .23703 L .57488 .24319 L p F P
0 g
s
0 0 .15 r
.57372 .24438 m .57488 .24319 L .578 .23703 L p F P
0 g
s
.819 .684 .714 r
.24339 .36594 m .23892 .36386 L p .24024 .37309 L F P
0 g
s
.821 .682 .709 r
.24339 .36594 m .24079 .36093 L .23892 .36386 L closepath p F P
0 g
s
.766 .923 .94 r
.59588 .22081 m .59597 .2207 L .59602 .22072 L closepath p F P
0 g
s
.718 .916 .962 r
.59597 .2207 m .59602 .22072 L .60758 .21475 L p F P
0 g
s
.78 .97 .919 r
.59315 .22005 m .60086 .21455 L .59597 .2207 L closepath p F P
0 g
s
.718 .916 .962 r
.60468 .21225 m .60086 .21455 L .59597 .2207 L p F P
0 g
s
.718 .916 .962 r
.60758 .21475 m .60468 .21225 L p .59597 .2207 L F P
0 g
s
.903 .693 .608 r
.23024 .27382 m .2345 .27707 L .23301 .28261 L p F P
0 g
s
.907 .683 .588 r
.2345 .27707 m .23024 .27382 L .23143 .2684 L p F P
0 g
s
.598 .575 .799 r
.60634 .44866 m .60936 .45521 L .5977 .45715 L p F P
0 g
s
.598 .575 .799 r
.60545 .44879 m .60634 .44866 L p .5977 .45715 L F P
0 g
s
.598 .575 .799 r
.5977 .45715 m .59608 .45354 L .60545 .44879 L p F P
0 g
s
.553 .463 .707 r
.55359 .36564 m .56211 .36101 L p .55752 .37206 L F P
0 g
s
.553 .463 .707 r
.55752 .37206 m .55532 .37201 L .55359 .36564 L p F P
0 g
s
.492 .509 .803 r
.73737 .2931 m .73705 .29232 L .73784 .29246 L closepath p F P
0 g
s
.485 .497 .794 r
.73737 .2931 m .73784 .29246 L p .74336 .30032 L F P
0 g
s
.331 .194 .54 r
.56562 .26732 m .56756 .26559 L .5663 .26086 L p F P
0 g
s
.319 .188 .54 r
.57352 .25413 m .5663 .26086 L .56756 .26559 L p F P
0 g
s
.269 .116 .48 r
.5663 .26086 m .57352 .25413 L .57341 .24899 L p F P
0 g
s
.807 .707 .755 r
.22095 .41946 m .22671 .42202 L .22041 .42927 L p F P
0 g
s
.796 .696 .754 r
.22711 .41228 m .22095 .41946 L .22671 .42202 L p F P
0 g
s
.221 .039 .41 r
.76188 .41961 m .75917 .42198 L .7579 .42779 L p F P
0 g
s
.871 .693 .658 r
.23986 .31138 m .24077 .30914 L .23767 .30712 L closepath p F P
0 g
s
.875 .688 .647 r
.23656 .30481 m .23825 .30028 L p .24077 .30914 L F P
0 g
s
.875 .688 .647 r
.24077 .30914 m .23767 .30712 L .23656 .30481 L p F P
0 g
s
.453 .442 .756 r
.76132 .32744 m .75562 .32523 L .75911 .32103 L closepath p F P
0 g
s
.463 .455 .764 r
.75828 .31873 m .75911 .32103 L .75562 .32523 L p F P
0 g
s
.463 .455 .764 r
.75225 .3167 m .75828 .31873 L p .75562 .32523 L F P
0 g
s
.355 .26 .608 r
.76817 .39147 m .76718 .3897 L .76778 .38912 L closepath p F P
0 g
s
.499 .515 .805 r
.73411 .28535 m .73139 .28491 L .73301 .28276 L closepath p F P
0 g
s
.506 .525 .811 r
.73118 .27857 m .73301 .28276 L .73139 .28491 L p F P
0 g
s
.839 .689 .696 r
.24278 .35744 m .24079 .36093 L .23746 .35477 L p F P
0 g
s
.839 .689 .696 r
.23746 .35477 m .23754 .35463 L .24278 .35744 L p F P
0 g
s
.84 .687 .692 r
.24278 .35744 m .23754 .35463 L .24096 .34836 L p F P
0 g
s
.932 .597 .377 r
.0408 .42997 m .04115 .43273 L .03725 .43028 L p F P
0 g
s
.932 .597 .377 r
.03725 .43028 m .03679 .42676 L .0408 .42997 L p F P
0 g
s
.935 .637 .453 r
.0408 .42997 m .03679 .42676 L .03668 .42166 L p F P
0 g
s
.899 .494 .223 r
.05146 .44577 m .04727 .44265 L .04567 .43802 L p F P
0 g
s
.901 .494 .213 r
.04155 .43487 m .04567 .43802 L .04727 .44265 L p F P
0 g
s
.924 .573 .349 r
.04115 .43273 m .04155 .43487 L .04567 .43802 L p F P
0 g
s
.491 .51 .804 r
.73784 .29246 m .73705 .29232 L .73411 .28535 L p F P
0 g
s
.593 .541 .766 r
.57408 .42994 m .57549 .42925 L p .58233 .43671 L F P
0 g
s
.588 .538 .766 r
.57408 .42994 m .57389 .42945 L .57549 .42925 L closepath p F P
0 g
s
.602 .676 .893 r
.64544 .21793 m .63963 .219 L .63672 .21463 L p F P
0 g
s
.588 .53 .758 r
.57549 .42925 m .57389 .42945 L .57087 .42119 L p F P
0 g
s
.85 .691 .685 r
.23718 .33023 m .24232 .33311 L .23909 .33929 L p F P
0 g
s
.848 .686 .681 r
.24232 .33311 m .23718 .33023 L .24025 .3241 L p F P
0 g
s
.397 .344 .681 r
.77135 .36053 m .76686 .36533 L .77145 .3693 L p F P
0 g
s
.415 .37 .7 r
.77075 .35832 m .7671 .3557 L p .76686 .36533 L F P
0 g
s
.415 .37 .7 r
.76686 .36533 m .77135 .36053 L .77075 .35832 L p F P
0 g
s
.517 .55 .829 r
.71992 .26495 m .71324 .2644 L .71055 .25867 L p F P
0 g
s
.616 .653 .864 r
.64468 .47307 m .63297 .4756 L .63002 .47057 L p F P
0 g
s
.14 0 .361 r
.57488 .24319 m .57372 .24438 L .57341 .24899 L p F P
0 g
s
.5 .399 .672 r
.55481 .32458 m .55436 .3225 L .55676 .32333 L closepath p F P
0 g
s
.771 .742 .826 r
.1757 .46981 m .17322 .47166 L .16966 .46777 L p F P
0 g
s
.747 .741 .846 r
.15848 .475 m .16966 .46777 L .17322 .47166 L p F P
0 g
s
.935 .669 .51 r
.03668 .42166 m .03274 .41842 L .03314 .41316 L p F P
0 g
s
.938 .64 .45 r
.03274 .41842 m .03668 .42166 L .03679 .42676 L p F P
0 g
s
.782 .712 .786 r
.20931 .44584 m .20732 .44308 L .20589 .44441 L closepath p F P
0 g
s
.489 .381 .659 r
.56149 .30505 m .55582 .30878 L .5626 .31179 L p F P
0 g
s
.487 .37 .646 r
.56024 .29853 m .56149 .30505 L .55582 .30878 L p F P
0 g
s
.73 .754 .872 r
.1438 .47743 m .1476 .47532 L .1527 .47805 L p F P
0 g
s
.721 .747 .873 r
.15489 .47133 m .1476 .47532 L .1527 .47805 L p F P
0 g
s
.721 .747 .873 r
.1527 .47805 m .15848 .475 L .15489 .47133 L p F P
0 g
s
.837 .368 .039 r
.05818 .45322 m .05394 .45014 L .05146 .44577 L p F P
0 g
s
.834 .363 .023 r
.04727 .44265 m .05146 .44577 L .05394 .45014 L p F P
0 g
s
.673 .868 .973 r
.69131 .47699 m .69916 .47392 L .69282 .478 L closepath p F P
0 g
s
.695 .887 .968 r
.70304 .47236 m .69916 .47392 L .69282 .478 L p F P
0 g
s
.695 .887 .968 r
.70572 .47357 m .70304 .47236 L p .69282 .478 L F P
0 g
s
.915 .692 .586 r
.22732 .26508 m .23143 .2684 L .23024 .27382 L p F P
0 g
s
.92 .679 .556 r
.23143 .2684 m .22732 .26508 L .22814 .25979 L p F P
0 g
s
.537 .578 .844 r
.69254 .24624 m .70407 .24634 L .70025 .25204 L p F P
0 g
s
.538 .581 .846 r
.70407 .24634 m .69254 .24624 L .69077 .24277 L p F P
0 g
s
.553 .469 .714 r
.55562 .37308 m .55532 .37201 L .55752 .37206 L closepath p F P
0 g
s
.461 .457 .767 r
.75828 .31873 m .75225 .3167 L .75591 .31216 L closepath p F P
0 g
s
.471 .47 .775 r
.75527 .31047 m .75591 .31216 L .75225 .3167 L p F P
0 g
s
.471 .47 .775 r
.74817 .30839 m .75527 .31047 L p .75225 .3167 L F P
0 g
s
.829 .693 .714 r
.23472 .3704 m .24024 .37309 L .2359 .37969 L p F P
0 g
s
.819 .684 .714 r
.23892 .36386 m .23472 .3704 L .24024 .37309 L p F P
0 g
s
.554 .472 .716 r
.55781 .3807 m .55562 .37308 L .55752 .37206 L p F P
0 g
s
.485 .497 .794 r
.73784 .29246 m .74764 .29462 L .74336 .30032 L p F P
0 g
s
.485 .501 .799 r
.74189 .28681 m .73784 .29246 L .74764 .29462 L p F P
0 g
s
.491 .51 .804 r
.73411 .28535 m .74189 .28681 L .73784 .29246 L p F P
0 g
s
.771 .742 .826 r
.16966 .46777 m .17054 .4671 L .1757 .46981 L p F P
0 g
s
.761 .732 .826 r
.18097 .45922 m .17054 .4671 L .1757 .46981 L p F P
0 g
s
.761 .732 .826 r
.1757 .46981 m .18449 .46337 L .18097 .45922 L p F P
0 g
s
.816 .7 .737 r
.22684 .40268 m .23244 .40531 L .22715 .41223 L p F P
0 g
s
.814 .696 .735 r
.23244 .40531 m .22684 .40268 L .23201 .3958 L p F P
0 g
s
.606 .612 .831 r
.62705 .46521 m .61536 .46736 L .61237 .46147 L p F P
0 g
s
.296 .168 .532 r
.76957 .40106 m .76512 .40525 L .76601 .4104 L p F P
0 g
s
.331 .22 .574 r
.76512 .40525 m .76957 .40106 L .7688 .39524 L p F P
0 g
s
.339 .25 .606 r
.76778 .38912 m .77296 .38379 L p .76971 .39433 L F P
0 g
s
.339 .25 .606 r
.76971 .39433 m .76817 .39147 L .76778 .38912 L p F P
0 g
s
.361 .285 .635 r
.76778 .38912 m .77296 .38379 L .76974 .37938 L p F P
0 g
s
.532 .57 .839 r
.70025 .25204 m .70744 .25228 L .70453 .24635 L p F P
0 g
s
.532 .57 .839 r
.70453 .24635 m .70407 .24634 L .70025 .25204 L p F P
0 g
s
.504 .407 .678 r
.55676 .32333 m .55481 .32458 L .55636 .33147 L p F P
0 g
s
.597 .574 .798 r
.59608 .45354 m .59467 .45039 L .60545 .44879 L closepath p F P
0 g
s
.469 .472 .778 r
.75527 .31047 m .74817 .30839 L .75243 .30294 L closepath p F P
0 g
s
.478 .483 .785 r
.75228 .30257 m .75243 .30294 L .74817 .30839 L p F P
0 g
s
.478 .483 .785 r
.74336 .30032 m .75228 .30257 L p .74817 .30839 L F P
0 g
s
.475 .484 .788 r
.74336 .30032 m .75228 .30257 L .74932 .29505 L p F P
0 g
s
.475 .484 .788 r
.74932 .29505 m .74764 .29462 L .74336 .30032 L p F P
0 g
s
.823 .694 .722 r
.23552 .39117 m .237 .38899 L .23313 .38706 L closepath p F P
0 g
s
.825 .693 .718 r
.23217 .38537 m .2359 .37969 L p .237 .38899 L F P
0 g
s
.825 .693 .718 r
.237 .38899 m .23313 .38706 L .23217 .38537 L p F P
0 g
s
.939 .673 .508 r
.02928 .40987 m .03314 .41316 L .03274 .41842 L p F P
0 g
s
.933 .693 .553 r
.03314 .41316 m .02928 .40987 L .03014 .40447 L p F P
0 g
s
.88 .695 .648 r
.23825 .30028 m .23656 .30481 L .23324 .29843 L p F P
0 g
s
.88 .695 .648 r
.23324 .29843 m .23372 .29716 L .23825 .30028 L p F P
0 g
s
.884 .691 .637 r
.23825 .30028 m .23372 .29716 L .23567 .29144 L p F P
0 g
s
.806 .709 .758 r
.21887 .43106 m .22041 .42927 L .21633 .42731 L closepath p F P
0 g
s
.807 .707 .755 r
.21545 .42599 m .22095 .41946 L p .22041 .42927 L F P
0 g
s
.807 .707 .755 r
.22041 .42927 m .21633 .42731 L .21545 .42599 L p F P
0 g
s
.588 .53 .758 r
.57087 .42119 m .57131 .42098 L p .57549 .42925 L F P
0 g
s
.583 .527 .758 r
.57087 .42119 m .57081 .42103 L .57131 .42098 L closepath p F P
0 g
s
.54 .444 .695 r
.56067 .34922 m .55423 .34863 L .55976 .3456 L closepath p F P
0 g
s
.538 .436 .686 r
.55799 .33846 m .55976 .3456 L .55423 .34863 L p F P
0 g
s
.593 .541 .766 r
.57549 .42925 m .58551 .42796 L p .58233 .43671 L F P
0 g
s
.589 .536 .763 r
.58551 .42796 m .57549 .42925 L .58441 .42501 L closepath p F P
0 g
s
.588 .53 .758 r
.58244 .41974 m .58441 .42501 L .57549 .42925 L p F P
0 g
s
.588 .53 .758 r
.57131 .42098 m .58244 .41974 L p .57549 .42925 L F P
0 g
s
.859 .69 .672 r
.23815 .3151 m .23986 .31138 L .23767 .30712 L p F P
0 g
s
.583 .52 .75 r
.57131 .42098 m .57081 .42103 L .56791 .41271 L p F P
0 g
s
.427 .312 .62 r
.55914 .29218 m .56764 .28561 L .56383 .28166 L p F P
0 g
s
.453 .34 .635 r
.55914 .29218 m .56764 .28561 L p .5622 .29705 L F P
0 g
s
.453 .34 .635 r
.5622 .29705 m .55964 .2951 L .55914 .29218 L p F P
0 g
s
0 .463 .865 r
.08109 .4695 m .08261 .47009 L .07881 .46731 L p F P
0 g
s
0 .463 .865 r
.07881 .46731 m .07665 .46651 L .08109 .4695 L p F P
0 g
s
.928 .687 .553 r
.22419 .2564 m .22814 .25979 L .22732 .26508 L p F P
0 g
s
.934 .667 .506 r
.22814 .25979 m .22419 .2564 L .22455 .25128 L p F P
0 g
s
.558 .475 .718 r
.55843 .38287 m .55781 .3807 L .5679 .37543 L p F P
0 g
s
.554 .472 .716 r
.56693 .37216 m .5679 .37543 L .55781 .3807 L p F P
0 g
s
.554 .472 .716 r
.55752 .37206 m .56693 .37216 L p .55781 .3807 L F P
0 g
s
.514 .736 .974 r
.10177 .47687 m .09669 .47411 L .10044 .477 L closepath p F P
0 g
s
.791 .706 .77 r
.21331 .43679 m .21887 .43106 L .21633 .42731 L p F P
0 g
s
.825 .687 .711 r
.23892 .36386 m .24079 .36093 L .23746 .35477 L p F P
0 g
s
.584 .525 .755 r
.58244 .41974 m .57131 .42098 L .58118 .41622 L closepath p F P
0 g
s
.583 .52 .75 r
.57936 .41113 m .58118 .41622 L .57131 .42098 L p F P
0 g
s
.583 .52 .75 r
.5692 .41207 m .57936 .41113 L p .57131 .42098 L F P
0 g
s
.583 .52 .75 r
.56791 .41271 m .5692 .41207 L p .57131 .42098 L F P
0 g
s
.697 .169 0 r
.05818 .45322 m .0613 .4569 L .0576 .4543 L p F P
0 g
s
.697 .169 0 r
.05394 .45014 m .05818 .45322 L p .0576 .4543 L F P
0 g
s
.556 .605 .857 r
.67824 .23547 m .68674 .23513 L .68384 .22968 L p F P
0 g
s
.556 .605 .857 r
.68384 .22968 m .6818 .22979 L .67824 .23547 L p F P
0 g
s
.558 .611 .862 r
.67193 .23043 m .6818 .22979 L .67824 .23547 L p F P
0 g
s
.845 .693 .693 r
.23582 .34551 m .24096 .34836 L .23754 .35463 L p F P
0 g
s
.845 .689 .689 r
.24096 .34836 m .23582 .34551 L .23909 .33929 L p F P
0 g
s
.561 .483 .725 r
.56012 .38847 m .55843 .38287 L .57005 .38269 L p F P
0 g
s
.558 .475 .718 r
.5679 .37543 m .57005 .38269 L .55843 .38287 L p F P
0 g
s
.487 0 0 r
.06617 .46027 m .06515 .45948 L .0613 .4569 L p F P
0 g
s
.856 .693 .68 r
.23524 .32117 m .24025 .3241 L .23718 .33023 L p F P
0 g
s
.85 .687 .679 r
.23815 .3151 m .23524 .32117 L .24025 .3241 L p F P
0 g
s
.81 .691 .734 r
.23201 .3958 m .23552 .39117 L .23313 .38706 L p F P
0 g
s
.578 .516 .749 r
.56791 .41271 m .56773 .41219 L .5692 .41207 L closepath p F P
0 g
s
.577 .509 .741 r
.5692 .41207 m .56773 .41219 L .56515 .40445 L p F P
0 g
s
.567 .488 .725 r
.56012 .38847 m .57021 .38321 L p .56949 .39281 L F P
0 g
s
.567 .488 .725 r
.56949 .39281 m .56154 .39314 L .56012 .38847 L p F P
0 g
s
.561 .483 .725 r
.57005 .38269 m .57021 .38321 L .56012 .38847 L p F P
0 g
s
.585 .945 .896 r
.70572 .47357 m .71741 .46769 L .71788 .46769 L p F P
0 g
s
.629 .941 .957 r
.71741 .46769 m .70572 .47357 L .70304 .47236 L p F P
0 g
s
.799 .711 .768 r
.21331 .43679 m .20732 .44308 L .20387 .43833 L p F P
0 g
s
.799 .711 .768 r
.20387 .43833 m .20772 .43418 L .21331 .43679 L p F P
0 g
s
.791 .706 .77 r
.21482 .42666 m .20772 .43418 L .21331 .43679 L p F P
0 g
s
.791 .706 .77 r
.21633 .42731 m .21482 .42666 L p .21331 .43679 L F P
0 g
s
.942 .675 .502 r
.22077 .24782 m .22455 .25128 L .22419 .2564 L p F P
0 g
s
.946 .638 .422 r
.22455 .25128 m .22077 .24782 L .22053 .24292 L p F P
0 g
s
.34 .25 .606 r
.7688 .39524 m .76817 .39147 L .76971 .39433 L closepath p F P
0 g
s
.131 0 .368 r
.58089 .23662 m .57488 .24319 L .57366 .24874 L p F P
0 g
s
0 0 .199 r
.58177 .23447 m .58242 .23208 L p .57488 .24319 L F P
0 g
s
0 0 .199 r
.57488 .24319 m .58089 .23662 L .58177 .23447 L p F P
0 g
s
.14 0 .361 r
.57341 .24899 m .57366 .24874 L .57488 .24319 L p F P
0 g
s
.597 .565 .789 r
.60545 .44879 m .59467 .45039 L .59173 .44354 L p F P
0 g
s
.567 .494 .733 r
.56257 .39638 m .56154 .39314 L .56949 .39281 L closepath p F P
0 g
s
.577 .509 .741 r
.56515 .40445 m .56872 .40264 L p .5692 .41207 L F P
0 g
s
.572 .505 .741 r
.56515 .40445 m .56464 .4029 L .56872 .40264 L closepath p F P
0 g
s
.594 .546 .771 r
.58858 .43581 m .58233 .43671 L .58791 .4341 L closepath p F P
0 g
s
.593 .541 .766 r
.58551 .42796 m .58791 .4341 L .58233 .43671 L p F P
0 g
s
.572 .498 .733 r
.56257 .39638 m .56949 .39281 L p .56872 .40264 L F P
0 g
s
.572 .498 .733 r
.56872 .40264 m .56464 .4029 L .56257 .39638 L p F P
0 g
s
.784 .733 .805 r
.18754 .46078 m .18449 .46337 L .18097 .45922 L p F P
0 g
s
.36 .238 .576 r
.56756 .26559 m .56562 .26732 L .56626 .2731 L p F P
0 g
s
.891 .698 .635 r
.23128 .28825 m .23567 .29144 L .23372 .29716 L p F P
0 g
s
.893 .692 .625 r
.23567 .29144 m .23128 .28825 L .23301 .28261 L p F P
0 g
s
.555 .471 .714 r
.56693 .37216 m .55752 .37206 L .56569 .36777 L closepath p F P
0 g
s
.553 .463 .707 r
.56381 .36108 m .56569 .36777 L .55752 .37206 L p F P
0 g
s
.553 .463 .707 r
.56211 .36101 m .56381 .36108 L p .55752 .37206 L F P
0 g
s
.784 .733 .805 r
.18097 .45922 m .18226 .45809 L .18754 .46078 L p F P
0 g
s
.774 .724 .806 r
.19203 .44971 m .18226 .45809 L .18754 .46078 L p F P
0 g
s
.774 .724 .806 r
.19289 .45009 m .19203 .44971 L p .18754 .46078 L F P
0 g
s
.774 .724 .806 r
.18754 .46078 m .19586 .45384 L .19289 .45009 L p F P
0 g
s
.489 .51 .805 r
.74189 .28681 m .73411 .28535 L .73301 .28276 L p F P
0 g
s
.448 .341 .64 r
.56024 .29853 m .55964 .2951 L .5622 .29705 L closepath p F P
0 g
s
.528 .739 .972 r
.10177 .47687 m .11103 .47563 L p .09669 .47411 L F P
0 g
s
.528 .739 .972 r
.09669 .47411 m .09669 .47411 L .10177 .47687 L p F P
0 g
s
.751 .74 .842 r
.16966 .46777 m .15848 .475 L .15489 .47133 L p F P
0 g
s
.952 .645 .414 r
.21692 .23938 m .22053 .24292 L .22077 .24782 L p F P
0 g
s
.936 .565 .264 r
.22053 .24292 m .21692 .23938 L .21588 .23478 L p F P
0 g
s
.631 .71 .904 r
.6476 .47754 m .65934 .4747 L .66221 .47855 L p F P
0 g
s
.623 .673 .877 r
.65644 .4705 m .65934 .4747 L .6476 .47754 L p F P
0 g
s
.623 .673 .877 r
.65461 .4709 m .65644 .4705 L p .6476 .47754 L F P
0 g
s
.623 .673 .877 r
.6476 .47754 m .64644 .47577 L .65461 .4709 L p F P
0 g
s
.832 .694 .711 r
.23348 .36112 m .23892 .36386 L .23472 .3704 L p F P
0 g
s
.825 .687 .711 r
.23746 .35477 m .23348 .36112 L .23892 .36386 L p F P
0 g
s
.814 .702 .74 r
.22711 .41228 m .22715 .41223 L .22705 .41218 L closepath p F P
0 g
s
.816 .7 .737 r
.22373 .40684 m .22684 .40268 L p .22715 .41223 L F P
0 g
s
.816 .7 .737 r
.22715 .41223 m .22705 .41218 L .22373 .40684 L p F P
0 g
s
.801 .699 .752 r
.22095 .41946 m .22711 .41228 L .22705 .41218 L p F P
0 g
s
.801 .699 .752 r
.22705 .41218 m .22137 .40967 L p .22095 .41946 L F P
0 g
s
.803 .697 .748 r
.22705 .41218 m .22373 .40684 L .22137 .40967 L closepath p F P
0 g
s
.41 .367 .7 r
.77075 .35832 m .7671 .3557 L .76936 .35322 L closepath p F P
0 g
s
.425 .389 .715 r
.76753 .34688 m .76658 .34629 L p .7671 .3557 L F P
0 g
s
.425 .389 .715 r
.7671 .3557 m .76936 .35322 L .76753 .34688 L p F P
0 g
s
.538 .581 .846 r
.69077 .24277 m .69211 .24058 L p .70407 .24634 L F P
0 g
s
.543 .59 .851 r
.69077 .24277 m .68964 .2406 L .69211 .24058 L closepath p F P
0 g
s
.782 .714 .787 r
.20589 .44441 m .20732 .44308 L .20387 .43833 L p F P
0 g
s
.794 .726 .789 r
.20018 .44185 m .20589 .44441 L .19741 .45237 L p F P
0 g
s
.782 .714 .787 r
.20387 .43833 m .20018 .44185 L .20589 .44441 L p F P
0 g
s
.516 .417 .681 r
.55636 .33147 m .56507 .32589 L p .56012 .33712 L F P
0 g
s
.516 .417 .681 r
.56012 .33712 m .55752 .33649 L .55636 .33147 L p F P
0 g
s
.504 .407 .678 r
.55636 .33147 m .56507 .32589 L .55676 .32333 L p F P
0 g
s
.044 0 .173 r
.75197 .43962 m .75535 .434 L .75269 .43628 L closepath p F P
0 g
s
.148 0 .311 r
.75269 .43628 m .75535 .434 L .7579 .42779 L p F P
0 g
s
.927 .574 .339 r
.04155 .43487 m .04115 .43273 L .03725 .43028 L p F P
0 g
s
.579 .515 .747 r
.57936 .41113 m .5692 .41207 L .57817 .40767 L closepath p F P
0 g
s
.577 .509 .741 r
.57627 .4021 m .57817 .40767 L .5692 .41207 L p F P
0 g
s
.577 .509 .741 r
.56872 .40264 m .57627 .4021 L p .5692 .41207 L F P
0 g
s
.505 .406 .677 r
.5643 .31849 m .55676 .32333 L .56507 .32589 L p F P
0 g
s
.503 .396 .666 r
.56285 .31189 m .5643 .31849 L .55676 .32333 L p F P
0 g
s
.503 .396 .666 r
.5626 .31179 m .56285 .31189 L p .55676 .32333 L F P
0 g
s
.792 .727 .791 r
.19586 .45384 m .19741 .45237 L .19289 .45009 L closepath p F P
0 g
s
.794 .726 .789 r
.19237 .44942 m .20018 .44185 L p .19741 .45237 L F P
0 g
s
.794 .726 .789 r
.19741 .45237 m .19289 .45009 L .19237 .44942 L p F P
0 g
s
.56 .615 .864 r
.6818 .22979 m .67193 .23043 L .66903 .22524 L p F P
0 g
s
.859 .69 .672 r
.23767 .30712 m .236 .30611 L p .23815 .3151 L F P
0 g
s
.862 .685 .662 r
.23767 .30712 m .23656 .30481 L .236 .30611 L closepath p F P
0 g
s
.829 .694 .715 r
.2359 .37969 m .23217 .38537 L .2288 .37964 L p F P
0 g
s
.829 .694 .715 r
.2288 .37964 m .23054 .37694 L .2359 .37969 L p F P
0 g
s
.829 .693 .714 r
.2359 .37969 m .23054 .37694 L .23472 .3704 L p F P
0 g
s
.288 .645 .967 r
.08261 .47009 m .09227 .47112 L .09668 .47411 L p F P
0 g
s
.319 .656 .971 r
.09227 .47112 m .08261 .47009 L .07881 .46731 L p F P
0 g
s
.517 .55 .829 r
.71055 .25867 m .71083 .25825 L p .71992 .26495 L F P
0 g
s
.523 .56 .835 r
.71055 .25867 m .71034 .25822 L .71083 .25825 L closepath p F P
0 g
s
.81 .691 .734 r
.23148 .38631 m .22642 .39315 L .23201 .3958 L p F P
0 g
s
.81 .691 .734 r
.23313 .38706 m .23148 .38631 L p .23201 .3958 L F P
0 g
s
.82 .701 .733 r
.22642 .39315 m .23201 .3958 L .22684 .40268 L p F P
0 g
s
.577 .638 .875 r
.6543 .22168 m .66613 .22018 L p .66501 .22566 L F P
0 g
s
.585 .642 .873 r
.66613 .22018 m .6543 .22168 L .65139 .21689 L p F P
0 g
s
.862 .696 .676 r
.23327 .31211 m .23815 .3151 L .23524 .32117 L p F P
0 g
s
.859 .69 .672 r
.236 .30611 m .23327 .31211 L .23815 .3151 L p F P
0 g
s
.852 .696 .688 r
.23406 .33639 m .23909 .33929 L .23582 .34551 L p F P
0 g
s
.85 .691 .685 r
.23909 .33929 m .23406 .33639 L .23718 .33023 L p F P
0 g
s
.639 .701 .89 r
.62212 .21368 m .63381 .2104 L .63672 .21463 L p F P
0 g
s
.653 .716 .895 r
.63381 .2104 m .62212 .21368 L .6192 .21006 L p F P
0 g
s
.686 .753 .902 r
.60758 .21475 m .6192 .21006 L .62212 .21368 L p F P
0 g
s
0 .308 .739 r
.07665 .46651 m .07227 .46349 L .06617 .46027 L p F P
0 g
s
.487 0 0 r
.0613 .4569 m .06176 .45725 L .06617 .46027 L p F P
0 g
s
0 .325 .758 r
.06176 .45725 m .06617 .46027 L .07227 .46349 L p F P
0 g
s
.489 .51 .805 r
.73301 .28276 m .73543 .27924 L p .74189 .28681 L F P
0 g
s
.496 .522 .813 r
.73301 .28276 m .73118 .27857 L .73543 .27924 L closepath p F P
0 g
s
.522 .562 .838 r
.71083 .25825 m .71034 .25822 L .70744 .25228 L p F P
0 g
s
.713 .781 .905 r
.6192 .21006 m .60758 .21475 L .60468 .21225 L p F P
0 g
s
.9 .7 .623 r
.22876 .27936 m .23301 .28261 L .23128 .28825 L p F P
0 g
s
.903 .693 .608 r
.23301 .28261 m .22876 .27936 L .23024 .27382 L p F P
0 g
s
.641 .752 .929 r
.11474 .47872 m .12554 .47547 L .12921 .47874 L p F P
0 g
s
.649 .753 .925 r
.12554 .47547 m .11474 .47872 L .11103 .47563 L p F P
0 g
s
.143 0 .308 r
.76179 .42442 m .7579 .42779 L .75535 .434 L p F P
0 g
s
.221 .039 .41 r
.7579 .42779 m .76179 .42442 L .76188 .41961 L p F P
0 g
s
.36 .285 .636 r
.77462 .37429 m .76974 .37938 L .77296 .38379 L p F P
0 g
s
.383 .319 .661 r
.77413 .37215 m .77145 .3693 L p .76974 .37938 L F P
0 g
s
.383 .319 .661 r
.76974 .37938 m .77462 .37429 L .77413 .37215 L p F P
0 g
s
.6 .659 .88 r
.65139 .21689 m .64544 .21793 L .64888 .21284 L closepath p F P
0 g
s
.602 .676 .893 r
.64848 .21222 m .64888 .21284 L .64544 .21793 L p F P
0 g
s
.602 .676 .893 r
.63672 .21463 m .64848 .21222 L p .64544 .21793 L F P
0 g
s
.516 .554 .833 r
.71083 .25825 m .72243 .25918 L .71953 .25307 L p F P
0 g
s
.516 .554 .833 r
.71953 .25307 m .71432 .25267 L .71083 .25825 L p F P
0 g
s
.522 .562 .838 r
.70744 .25228 m .71432 .25267 L .71083 .25825 L p F P
0 g
s
.517 .55 .829 r
.71083 .25825 m .72243 .25918 L p .71992 .26495 L F P
0 g
s
.193 .018 .402 r
.76594 .41585 m .76188 .41961 L .76179 .42442 L p F P
0 g
s
.253 .104 .477 r
.76188 .41961 m .76594 .41585 L .76601 .4104 L p F P
0 g
s
0 0 0 r
.74061 .45188 m .73495 .45644 L .73038 .45994 L p F P
0 g
s
0 0 0 r
.74154 .45062 m .74061 .45188 L p .73038 .45994 L F P
0 g
s
.51 .883 .679 r
.72905 .46064 m .73495 .45644 L .73038 .45994 L closepath p F P
0 g
s
.637 .963 .822 r
.73038 .45994 m .72905 .46064 L p .71788 .46769 L F P
0 g
s
.735 .757 .87 r
.1476 .47532 m .1438 .47743 L .14017 .47397 L p F P
0 g
s
.694 .753 .897 r
.12921 .47874 m .14017 .47397 L .1438 .47743 L p F P
0 g
s
.456 .354 .651 r
.5622 .29705 m .56024 .29853 L .56149 .30505 L p F P
0 g
s
.868 .694 .663 r
.236 .30611 m .23656 .30481 L .23324 .29843 L p F P
0 g
s
.606 .612 .831 r
.61237 .46147 m .62407 .45948 L .62705 .46521 L p F P
0 g
s
.599 .591 .815 r
.62126 .45384 m .62407 .45948 L .61237 .46147 L p F P
0 g
s
.599 .591 .815 r
.61237 .46147 m .61128 .4592 L .62126 .45384 L p F P
0 g
s
.809 .705 .75 r
.22095 .41946 m .21545 .42599 L .21203 .42094 L p F P
0 g
s
.809 .705 .75 r
.21203 .42094 m .21543 .41681 L .22095 .41946 L p F P
0 g
s
.801 .699 .752 r
.22137 .40967 m .21543 .41681 L .22095 .41946 L p F P
0 g
s
.309 .205 .57 r
.76971 .39433 m .7688 .39524 L .76957 .40106 L p F P
0 g
s
.514 .421 .688 r
.55799 .33846 m .55752 .33649 L .56012 .33712 L closepath p F P
0 g
s
.641 .758 .934 r
.66221 .47855 m .67396 .4753 L .67679 .47846 L p F P
0 g
s
.633 .729 .917 r
.67396 .4753 m .66221 .47855 L .65934 .4747 L p F P
0 g
s
.657 .856 .976 r
.69916 .47392 m .69131 .47699 L .68854 .47464 L p F P
0 g
s
.652 .822 .965 r
.67679 .47846 m .68854 .47464 L .69131 .47699 L p F P
0 g
s
.616 .653 .864 r
.63002 .47057 m .64175 .46824 L .64468 .47307 L p F P
0 g
s
.609 .628 .844 r
.6388 .46309 m .64175 .46824 L .63002 .47057 L p F P
0 g
s
.609 .628 .844 r
.62941 .46479 m .6388 .46309 L p .63002 .47057 L F P
0 g
s
.609 .628 .844 r
.63002 .47057 m .62744 .46591 L .62941 .46479 L p F P
0 g
s
.542 .593 .854 r
.69211 .24058 m .68964 .2406 L .68674 .23513 L p F P
0 g
s
.812 .69 .729 r
.23313 .38706 m .23217 .38537 L .23148 .38631 L closepath p F P
0 g
s
.574 .626 .866 r
.66903 .22524 m .66501 .22566 L .66728 .22217 L closepath p F P
0 g
s
.577 .638 .875 r
.66613 .22018 m .66728 .22217 L .66501 .22566 L p F P
0 g
s
.597 .565 .789 r
.59173 .44354 m .59241 .44319 L p .60545 .44879 L F P
0 g
s
.592 .562 .79 r
.59173 .44354 m .59163 .44329 L .59241 .44319 L closepath p F P
0 g
s
.7 .754 .894 r
.14017 .47397 m .12921 .47874 L .12554 .47547 L p F P
0 g
s
.592 .553 .78 r
.59241 .44319 m .59163 .44329 L .58858 .43581 L p F P
0 g
s
.623 .673 .877 r
.64644 .47577 m .64468 .47307 L .65461 .4709 L closepath p F P
0 g
s
.637 .963 .897 r
.71741 .46769 m .71959 .46645 L .71788 .46769 L closepath p F P
0 g
s
.637 .963 .822 r
.72905 .46064 m .71959 .46645 L .71788 .46769 L p F P
0 g
s
.793 .704 .767 r
.21633 .42731 m .21545 .42599 L .21482 .42666 L closepath p F P
0 g
s
.843 .695 .698 r
.23746 .35477 m .23754 .35463 L .23731 .3545 L closepath p F P
0 g
s
.845 .693 .693 r
.23413 .34865 m .23582 .34551 L p .23754 .35463 L F P
0 g
s
.845 .693 .693 r
.23754 .35463 m .23731 .3545 L .23413 .34865 L p F P
0 g
s
.517 .427 .692 r
.55976 .3456 m .55799 .33846 L .56012 .33712 L p F P
0 g
s
.83 .692 .711 r
.23348 .36112 m .23746 .35477 L .23731 .3545 L p F P
0 g
s
.868 .699 .67 r
.23127 .30306 m .236 .30611 L .23327 .31211 L p F P
0 g
s
.868 .694 .663 r
.23324 .29843 m .23127 .30306 L .236 .30611 L p F P
0 g
s
.911 .701 .607 r
.22614 .2705 m .23024 .27382 L .22876 .27936 L p F P
0 g
s
.915 .692 .586 r
.23024 .27382 m .22614 .2705 L .22732 .26508 L p F P
0 g
s
.83 .692 .711 r
.23731 .3545 m .2322 .35185 L p .23348 .36112 L F P
0 g
s
.833 .69 .705 r
.23731 .3545 m .23413 .34865 L .2322 .35185 L closepath p F P
0 g
s
.646 .785 .948 r
.68854 .47464 m .67679 .47846 L .67396 .4753 L p F P
0 g
s
.857 .698 .684 r
.23226 .32728 m .23718 .33023 L .23406 .33639 L p F P
0 g
s
.856 .693 .68 r
.23718 .33023 m .23226 .32728 L .23524 .32117 L p F P
0 g
s
.618 .679 .886 r
.64848 .21222 m .63672 .21463 L .63381 .2104 L p F P
0 g
s
.597 .565 .789 r
.59241 .44319 m .6033 .44171 L p .60545 .44879 L F P
0 g
s
.593 .56 .786 r
.6033 .44171 m .59241 .44319 L .60192 .43842 L closepath p F P
0 g
s
.592 .553 .78 r
.60026 .43444 m .60192 .43842 L .59241 .44319 L p F P
0 g
s
.592 .553 .78 r
.58858 .43581 m .60026 .43444 L p .59241 .44319 L F P
0 g
s
.36 .238 .576 r
.56626 .2731 m .56967 .27007 L .56756 .26559 L p F P
0 g
s
.35 .234 .577 r
.57395 .25965 m .56756 .26559 L .56967 .27007 L p F P
0 g
s
.319 .188 .54 r
.56756 .26559 m .57395 .25965 L .57352 .25413 L p F P
0 g
s
.42 .387 .715 r
.76753 .34688 m .76658 .34629 L .76717 .34563 L closepath p F P
0 g
s
.435 .408 .73 r
.76658 .34629 m .76717 .34563 L .76473 .33775 L p F P
0 g
s
.496 .522 .814 r
.73543 .27924 m .73118 .27857 L .72826 .27191 L p F P
0 g
s
.425 .312 .621 r
.56708 .27911 m .56383 .28166 L .56764 .28561 L p F P
0 g
s
.412 .292 .605 r
.56383 .28166 m .56708 .27911 L .56626 .2731 L p F P
0 g
s
.599 .59 .814 r
.62108 .45346 m .62126 .45384 L .61128 .4592 L p F P
0 g
s
.599 .59 .814 r
.61128 .4592 m .60936 .45521 L .62108 .45346 L p F P
0 g
s
.836 .699 .713 r
.22942 .36762 m .23472 .3704 L .23054 .37694 L p F P
0 g
s
.832 .694 .711 r
.23472 .3704 m .22942 .36762 L .23348 .36112 L p F P
0 g
s
.82 .701 .734 r
.22684 .40268 m .22373 .40684 L .22033 .4015 L p F P
0 g
s
.82 .701 .734 r
.22033 .4015 m .22145 .39997 L .22684 .40268 L p F P
0 g
s
.82 .701 .733 r
.22684 .40268 m .22145 .39997 L .22642 .39315 L p F P
0 g
s
.735 .757 .87 r
.14017 .47397 m .14271 .47251 L .1476 .47532 L p F P
0 g
s
.726 .748 .87 r
.15128 .46765 m .14271 .47251 L .1476 .47532 L p F P
0 g
s
.726 .748 .87 r
.1476 .47532 m .15489 .47133 L .15128 .46765 L p F P
0 g
s
.574 .505 .739 r
.57627 .4021 m .56872 .40264 L .57536 .39934 L closepath p F P
0 g
s
.572 .498 .733 r
.57316 .39264 m .57536 .39934 L .56872 .40264 L p F P
0 g
s
.572 .498 .733 r
.56949 .39281 m .57316 .39264 L p .56872 .40264 L F P
0 g
s
.815 .693 .731 r
.23148 .38631 m .23217 .38537 L .2288 .37964 L p F P
0 g
s
.751 .74 .842 r
.16753 .46544 m .16966 .46777 L p .15489 .47133 L F P
0 g
s
.772 .745 .828 r
.16966 .46777 m .17054 .4671 L .16753 .46544 L closepath p F P
0 g
s
.901 .494 .213 r
.04727 .44265 m .04316 .4395 L .04155 .43487 L p F P
0 g
s
.902 .494 .203 r
.03751 .43167 m .04155 .43487 L .04316 .4395 L p F P
0 g
s
.927 .574 .339 r
.03725 .43028 m .03751 .43167 L .04155 .43487 L p F P
0 g
s
.935 .599 .371 r
.03679 .42676 m .03725 .43028 L .03336 .42748 L p F P
0 g
s
.935 .599 .371 r
.03336 .42748 m .03284 .42352 L .03679 .42676 L p F P
0 g
s
.938 .64 .45 r
.03679 .42676 m .03284 .42352 L .03274 .41842 L p F P
0 g
s
.775 .744 .826 r
.17809 .45586 m .18097 .45922 L .17054 .4671 L p F P
0 g
s
.775 .744 .826 r
.17705 .45538 m .17809 .45586 L p .17054 .4671 L F P
0 g
s
.775 .744 .826 r
.1661 .46387 m .17705 .45538 L p .17054 .4671 L F P
0 g
s
.775 .744 .826 r
.17054 .4671 m .16753 .46544 L .1661 .46387 L p F P
0 g
s
.794 .707 .768 r
.21482 .42666 m .21545 .42599 L .21203 .42094 L p F P
0 g
s
.822 .701 .731 r
.22592 .38364 m .23148 .38631 L .22642 .39315 L p F P
0 g
s
.815 .693 .731 r
.2288 .37964 m .22592 .38364 L .23148 .38631 L p F P
0 g
s
.804 .717 .769 r
.20913 .42407 m .21482 .42666 L .20772 .43418 L p F P
0 g
s
.794 .707 .768 r
.21203 .42094 m .20913 .42407 L .21482 .42666 L p F P
0 g
s
.339 .25 .606 r
.77296 .38379 m .77548 .38843 L .76971 .39433 L p F P
0 g
s
.309 .205 .57 r
.76957 .40106 m .7714 .39923 L .76971 .39433 L p F P
0 g
s
.308 .206 .572 r
.77548 .38843 m .76971 .39433 L .7714 .39923 L p F P
0 g
s
.231 .088 .47 r
.57366 .24874 m .57341 .24899 L .57352 .25413 L p F P
0 g
s
.42 .399 .729 r
.76524 .33713 m .76473 .33775 L .76717 .34563 L p F P
0 g
s
.435 .419 .743 r
.76473 .33775 m .7644 .33672 L .76524 .33713 L closepath p F P
0 g
s
.25 .102 .476 r
.77009 .40658 m .76601 .4104 L .76594 .41585 L p F P
0 g
s
.296 .168 .532 r
.76601 .4104 m .77009 .40658 L .76957 .40106 L p F P
0 g
s
.922 .7 .584 r
.22338 .26169 m .22732 .26508 L .22614 .2705 L p F P
0 g
s
.928 .687 .553 r
.22732 .26508 m .22338 .26169 L .22419 .2564 L p F P
0 g
s
.434 .42 .743 r
.76524 .33713 m .7644 .33672 L .76205 .32955 L p F P
0 g
s
.834 .363 .023 r
.05394 .45014 m .04976 .44701 L .04727 .44265 L p F P
0 g
s
.831 .358 .007 r
.04316 .4395 m .04727 .44265 L .04976 .44701 L p F P
0 g
s
.379 .268 .6 r
.56967 .27007 m .56626 .2731 L .56708 .27911 L p F P
0 g
s
.942 .644 .447 r
.02887 .41513 m .03274 .41842 L .03284 .42352 L p F P
0 g
s
.939 .673 .508 r
.03274 .41842 m .02887 .41513 L .02928 .40987 L p F P
0 g
s
.608 .952 .905 r
.71959 .46645 m .71741 .46769 L .71478 .46707 L p F P
0 g
s
.629 .941 .957 r
.70304 .47236 m .71478 .46707 L .71741 .46769 L p F P
0 g
s
.434 .42 .743 r
.76205 .32955 m .76312 .3282 L p .76524 .33713 L F P
0 g
s
.443 .436 .755 r
.76205 .32955 m .76132 .32744 L .76312 .3282 L closepath p F P
0 g
s
.51 .541 .824 r
.72535 .26552 m .71992 .26495 L .723 .26039 L closepath p F P
0 g
s
.517 .55 .829 r
.72243 .25918 m .723 .26039 L .71992 .26495 L p F P
0 g
s
0 0 0 r
.74061 .45188 m .74466 .44809 L .74154 .45062 L closepath p F P
0 g
s
0 0 0 r
.75123 .44068 m .74466 .44809 L .74154 .45062 L p F P
0 g
s
.409 .379 .715 r
.76717 .34563 m .77133 .34058 L p .77215 .34992 L F P
0 g
s
.409 .379 .715 r
.77215 .34992 m .76753 .34688 L .76717 .34563 L p F P
0 g
s
.42 .399 .729 r
.76717 .34563 m .77133 .34058 L .76524 .33713 L p F P
0 g
s
.213 .074 .465 r
.57986 .24211 m .57366 .24874 L .5738 .25384 L p F P
0 g
s
.131 0 .368 r
.57366 .24874 m .57986 .24211 L .58089 .23662 L p F P
0 g
s
.231 .088 .47 r
.57352 .25413 m .5738 .25384 L .57366 .24874 L p F P
0 g
s
.527 .436 .695 r
.55976 .3456 m .56934 .33962 L p .5661 .35011 L F P
0 g
s
.527 .436 .695 r
.5661 .35011 m .56067 .34922 L .55976 .3456 L p F P
0 g
s
.517 .427 .692 r
.5692 .33909 m .56934 .33962 L .55976 .3456 L p F P
0 g
s
.517 .427 .692 r
.56012 .33712 m .5692 .33909 L p .55976 .3456 L F P
0 g
s
.886 .703 .649 r
.23324 .29843 m .23372 .29716 L .23167 .29566 L closepath p F P
0 g
s
.891 .698 .635 r
.22989 .29231 m .23128 .28825 L p .23372 .29716 L F P
0 g
s
.891 .698 .635 r
.23372 .29716 m .23167 .29566 L .22989 .29231 L p F P
0 g
s
.443 .436 .756 r
.76312 .3282 m .76132 .32744 L .75911 .32103 L p F P
0 g
s
.409 .379 .714 r
.76936 .35322 m .76753 .34688 L .77215 .34992 L closepath p F P
0 g
s
.538 .581 .846 r
.69211 .24058 m .70163 .24065 L p .70407 .24634 L F P
0 g
s
.539 .586 .85 r
.69211 .24058 m .70163 .24065 L .69873 .23498 L p F P
0 g
s
.539 .586 .85 r
.69873 .23498 m .69546 .23498 L .69211 .24058 L p F P
0 g
s
.542 .593 .854 r
.68674 .23513 m .69546 .23498 L .69211 .24058 L p F P
0 g
s
.851 .698 .692 r
.23582 .34551 m .23413 .34865 L .23077 .34277 L p F P
0 g
s
.851 .698 .692 r
.23077 .34277 m .23088 .34258 L .23582 .34551 L p F P
0 g
s
.852 .696 .688 r
.23582 .34551 m .23088 .34258 L .23406 .33639 L p F P
0 g
s
.456 .354 .651 r
.56149 .30505 m .56749 .30054 L .5622 .29705 L p F P
0 g
s
.455 .355 .652 r
.56921 .29171 m .5622 .29705 L .56749 .30054 L p F P
0 g
s
.453 .34 .635 r
.56818 .28606 m .56921 .29171 L .5622 .29705 L p F P
0 g
s
.453 .34 .635 r
.56764 .28561 m .56818 .28606 L p .5622 .29705 L F P
0 g
s
.583 .54 .773 r
.59801 .42886 m .60026 .43444 L .58858 .43581 L p F P
0 g
s
.583 .54 .773 r
.58858 .43581 m .58791 .4341 L .59801 .42886 L p F P
0 g
s
.805 .701 .75 r
.22137 .40967 m .22373 .40684 L .22033 .4015 L p F P
0 g
s
.489 .381 .659 r
.5626 .31179 m .5628 .31166 L .56149 .30505 L p F P
0 g
s
.461 .363 .657 r
.5628 .31166 m .56149 .30505 L .56749 .30054 L p F P
0 g
s
.863 .701 .679 r
.23044 .31816 m .23524 .32117 L .23226 .32728 L p F P
0 g
s
.862 .696 .676 r
.23524 .32117 m .23044 .31816 L .23327 .31211 L p F P
0 g
s
.03 .481 .88 r
.07665 .46651 m .07881 .46731 L .07501 .46445 L p F P
0 g
s
.03 .481 .88 r
.07501 .46445 m .07227 .46349 L .07665 .46651 L p F P
0 g
s
.804 .716 .767 r
.20772 .43418 m .20387 .43833 L .20041 .43364 L p F P
0 g
s
.804 .716 .767 r
.20041 .43364 m .20235 .4315 L .20772 .43418 L p F P
0 g
s
.804 .717 .769 r
.20772 .43418 m .20235 .4315 L .20913 .42407 L p F P
0 g
s
.608 .952 .905 r
.727 .46101 m .71959 .46645 L p .71478 .46707 L F P
0 g
s
.598 .95 .832 r
.71959 .46645 m .727 .46101 L .72905 .46064 L closepath p F P
0 g
s
.582 .539 .772 r
.5972 .42684 m .59801 .42886 L .58791 .4341 L p F P
0 g
s
.582 .539 .772 r
.58791 .4341 m .58551 .42796 L .5972 .42684 L p F P
0 g
s
.443 .436 .756 r
.75911 .32103 m .76031 .31947 L p .76312 .3282 L F P
0 g
s
.452 .451 .767 r
.75911 .32103 m .75828 .31873 L .76031 .31947 L closepath p F P
0 g
s
.936 .696 .55 r
.22041 .25293 m .22419 .2564 L .22338 .26169 L p F P
0 g
s
.942 .675 .502 r
.22419 .2564 m .22041 .25293 L .22077 .24782 L p F P
0 g
s
.422 .404 .734 r
.76978 .33145 m .76524 .33713 L .77133 .34058 L p F P
0 g
s
.434 .42 .743 r
.76312 .3282 m .76978 .33145 L .76524 .33713 L p F P
0 g
s
.517 .426 .691 r
.5692 .33909 m .56012 .33712 L .56757 .33247 L closepath p F P
0 g
s
.516 .417 .681 r
.56604 .32615 m .56757 .33247 L .56012 .33712 L p F P
0 g
s
.516 .417 .681 r
.56507 .32589 m .56604 .32615 L p .56012 .33712 L F P
0 g
s
.522 .563 .839 r
.71432 .25267 m .70744 .25228 L .70453 .24635 L p F P
0 g
s
0 0 .079 r
.75535 .434 m .76134 .42881 L p .75182 .44019 L F P
0 g
s
0 0 .079 r
.75182 .44019 m .75197 .43962 L .75535 .434 L p F P
0 g
s
.143 0 .308 r
.75535 .434 m .76134 .42881 L .76179 .42442 L p F P
0 g
s
.526 .44 .702 r
.56162 .35286 m .56067 .34922 L .5661 .35011 L closepath p F P
0 g
s
.697 .169 0 r
.0576 .4543 m .05744 .45418 L .05394 .45014 L p F P
0 g
s
.686 .158 0 r
.04976 .44701 m .05394 .45014 L .05744 .45418 L p F P
0 g
s
.398 .359 .699 r
.76936 .35322 m .77215 .34992 L p .77226 .35948 L F P
0 g
s
.398 .359 .699 r
.77226 .35948 m .77075 .35832 L .76936 .35322 L p F P
0 g
s
0 0 .062 r
.58177 .23447 m .58373 .23054 L .58242 .23208 L closepath p F P
0 g
s
.875 .702 .665 r
.23127 .30306 m .23324 .29843 L .23167 .29566 L p F P
0 g
s
.776 .723 .803 r
.19289 .45009 m .19237 .44942 L .19203 .44971 L closepath p F P
0 g
s
.397 .344 .681 r
.77145 .3693 m .77309 .36754 L .77135 .36053 L p F P
0 g
s
.378 .316 .661 r
.77413 .37215 m .77145 .3693 L .77309 .36754 L closepath p F P
0 g
s
.786 .737 .808 r
.18097 .45922 m .18226 .45809 L .17809 .45586 L closepath p F P
0 g
s
.815 .71 .75 r
.21581 .40702 m .22137 .40967 L .21543 .41681 L p F P
0 g
s
.805 .701 .75 r
.22033 .4015 m .21581 .40702 L .22137 .40967 L p F P
0 g
s
.452 .451 .767 r
.76031 .31947 m .75828 .31873 L .75591 .31216 L p F P
0 g
s
.594 .584 .812 r
.62108 .45346 m .60936 .45521 L .60634 .44866 L p F P
0 g
s
.788 .736 .805 r
.18644 .44711 m .19203 .44971 L .18226 .45809 L p F P
0 g
s
.788 .736 .805 r
.17743 .45508 m .18644 .44711 L p .18226 .45809 L F P
0 g
s
.788 .736 .805 r
.18226 .45809 m .17809 .45586 L .17743 .45508 L p F P
0 g
s
.787 .717 .786 r
.20018 .44185 m .20387 .43833 L .20041 .43364 L p F P
0 g
s
.623 .656 .862 r
.65461 .4709 m .64468 .47307 L .64175 .46824 L p F P
0 g
s
.839 .7 .71 r
.22826 .3583 m .23348 .36112 L .22942 .36762 L p F P
0 g
s
.83 .692 .711 r
.2322 .35185 m .22826 .3583 L .23348 .36112 L p F P
0 g
s
.56 .615 .864 r
.66903 .22524 m .68094 .22441 L p .6818 .22979 L F P
0 g
s
.561 .619 .868 r
.67804 .21923 m .68094 .22441 L .66903 .22524 L p F P
0 g
s
.561 .619 .868 r
.66844 .21998 m .67804 .21923 L p .66903 .22524 L F P
0 g
s
.561 .619 .868 r
.66903 .22524 m .66728 .22217 L .66844 .21998 L p F P
0 g
s
.794 .72 .782 r
.20018 .44185 m .19237 .44942 L .18887 .445 L p F P
0 g
s
.794 .72 .782 r
.18887 .445 m .1947 .4392 L .20018 .44185 L p F P
0 g
s
.787 .717 .786 r
.20041 .43364 m .1947 .4392 L .20018 .44185 L p F P
0 g
s
.392 .682 .976 r
.09669 .47411 m .09668 .47411 L .09669 .47411 L closepath p F P
0 g
s
.411 .687 .975 r
.09668 .47411 m .09669 .47411 L .09293 .47114 L p F P
0 g
s
.411 .687 .975 r
.09293 .47114 m .09227 .47112 L .09668 .47411 L p F P
0 g
s
.528 .739 .972 r
.11103 .47563 m .10731 .4725 L .09669 .47411 L p F P
0 g
s
.569 .738 .956 r
.10731 .4725 m .09669 .47411 L .09293 .47114 L p F P
0 g
s
.549 .46 .706 r
.56381 .36108 m .56211 .36101 L .56357 .36022 L closepath p F P
0 g
s
.547 .452 .699 r
.56162 .35286 m .56357 .36022 L .56211 .36101 L p F P
0 g
s
.896 .706 .638 r
.23128 .28825 m .22989 .29231 L .22652 .28652 L p F P
0 g
s
.896 .706 .638 r
.22652 .28652 m .22704 .28499 L .23128 .28825 L p F P
0 g
s
.9 .7 .623 r
.23128 .28825 m .22704 .28499 L .22876 .27936 L p F P
0 g
s
.527 .443 .704 r
.56357 .36022 m .56162 .35286 L .5661 .35011 L p F P
0 g
s
.609 .627 .844 r
.62744 .46591 m .62705 .46521 L .62941 .46479 L closepath p F P
0 g
s
.95 .683 .497 r
.21715 .24428 m .22077 .24782 L .22041 .25293 L p F P
0 g
s
.952 .645 .414 r
.22077 .24782 m .21715 .24428 L .21692 .23938 L p F P
0 g
s
.776 .724 .804 r
.18887 .445 m .18644 .44711 L .19203 .44971 L p F P
0 g
s
.776 .724 .804 r
.19203 .44971 m .19237 .44942 L .18887 .445 L p F P
0 g
s
.783 .998 .821 r
.58933 .22354 m .59165 .22036 L .59315 .22005 L closepath p F P
0 g
s
.826 .706 .733 r
.22105 .39042 m .22642 .39315 L .22145 .39997 L p F P
0 g
s
.822 .701 .731 r
.22642 .39315 m .22105 .39042 L .22592 .38364 L p F P
0 g
s
.67 .975 .834 r
.59165 .22036 m .59315 .22005 L .60086 .21455 L p F P
0 g
s
.657 .856 .976 r
.70225 .47184 m .69916 .47392 L p .68854 .47464 L F P
0 g
s
.677 .875 .973 r
.69916 .47392 m .70225 .47184 L .70304 .47236 L closepath p F P
0 g
s
.585 .642 .873 r
.65139 .21689 m .66323 .21529 L .66613 .22018 L p F P
0 g
s
.586 .653 .883 r
.66032 .21046 m .66323 .21529 L .65139 .21689 L p F P
0 g
s
.586 .653 .883 r
.64924 .2121 m .66032 .21046 L p .65139 .21689 L F P
0 g
s
.586 .653 .883 r
.65139 .21689 m .64888 .21284 L .64924 .2121 L p F P
0 g
s
.756 .742 .84 r
.16529 .4644 m .15489 .47133 L .15128 .46765 L p F P
0 g
s
.751 .74 .842 r
.15489 .47133 m .16529 .4644 L .16753 .46544 L p F P
0 g
s
.834 .701 .718 r
.2288 .37964 m .23054 .37694 L .22551 .37419 L closepath p F P
0 g
s
.836 .699 .713 r
.22542 .37405 m .22942 .36762 L p .23054 .37694 L F P
0 g
s
.836 .699 .713 r
.23054 .37694 m .22551 .37419 L .22542 .37405 L p F P
0 g
s
.496 .522 .814 r
.72826 .27191 m .72827 .2719 L p .73543 .27924 L F P
0 g
s
.502 .533 .821 r
.72826 .27191 m .72826 .2719 L .72827 .2719 L closepath p F P
0 g
s
.398 .359 .699 r
.77135 .36053 m .77075 .35832 L .77226 .35948 L closepath p F P
0 g
s
.501 .535 .824 r
.72827 .2719 m .72826 .2719 L .72535 .26552 L p F P
0 g
s
.496 .522 .814 r
.72827 .2719 m .73923 .27363 L .73543 .27924 L p F P
0 g
s
.497 .527 .818 r
.73179 .26635 m .72827 .2719 L .73923 .27363 L p F P
0 g
s
.501 .535 .824 r
.72535 .26552 m .73179 .26635 L .72827 .2719 L p F P
0 g
s
.837 .696 .708 r
.2322 .35185 m .23413 .34865 L .23077 .34277 L p F P
0 g
s
.449 0 0 r
.06176 .45725 m .0576 .4543 L .0613 .4569 L closepath p F P
0 g
s
.272 .151 .527 r
.7714 .39923 m .76957 .40106 L .77009 .40658 L p F P
0 g
s
.577 .529 .765 r
.59444 .41967 m .5972 .42684 L .58551 .42796 L p F P
0 g
s
.577 .529 .765 r
.58551 .42796 m .58441 .42501 L .59444 .41967 L p F P
0 g
s
.452 .451 .767 r
.75591 .31216 m .75681 .31096 L p .76031 .31947 L F P
0 g
s
.46 .466 .778 r
.75591 .31216 m .75527 .31047 L .75681 .31096 L closepath p F P
0 g
s
.857 .701 .687 r
.22922 .33341 m .23406 .33639 L .23088 .34258 L p F P
0 g
s
.857 .698 .684 r
.23406 .33639 m .22922 .33341 L .23226 .32728 L p F P
0 g
s
.609 .613 .83 r
.62941 .46479 m .62705 .46521 L .62407 .45948 L p F P
0 g
s
.869 .704 .675 r
.2286 .30904 m .23327 .31211 L .23044 .31816 L p F P
0 g
s
.868 .699 .67 r
.23327 .31211 m .2286 .30904 L .23127 .30306 L p F P
0 g
s
.543 .595 .856 r
.69546 .23498 m .68674 .23513 L .68384 .22968 L p F P
0 g
s
.379 .332 .679 r
.77226 .35948 m .77135 .36053 L .77309 .36754 L p F P
0 g
s
.432 .422 .747 r
.76752 .32253 m .76312 .3282 L .76978 .33145 L p F P
0 g
s
.443 .436 .756 r
.76031 .31947 m .76752 .32253 L .76312 .3282 L p F P
0 g
s
.567 .488 .725 r
.57021 .38321 m .57271 .39119 L .56949 .39281 L p F P
0 g
s
.568 .494 .732 r
.57316 .39264 m .56949 .39281 L .57271 .39119 L closepath p F P
0 g
s
.459 .466 .778 r
.75681 .31096 m .75527 .31047 L .75243 .30294 L p F P
0 g
s
.749 .741 .845 r
.16753 .46544 m .1661 .46387 L .16529 .4644 L closepath p F P
0 g
s
.576 .528 .764 r
.59413 .41887 m .59444 .41967 L .58441 .42501 L p F P
0 g
s
.576 .528 .764 r
.58441 .42501 m .58244 .41974 L .59413 .41887 L p F P
0 g
s
.875 .702 .665 r
.23167 .29566 m .22924 .294 L p .23127 .30306 L F P
0 g
s
.878 .696 .652 r
.23167 .29566 m .22989 .29231 L .22924 .294 L closepath p F P
0 g
s
0 .325 .758 r
.07227 .46349 m .06795 .46044 L .06176 .45725 L p F P
0 g
s
0 .34 .775 r
.0576 .4543 m .06176 .45725 L .06795 .46044 L p F P
0 g
s
.494 .392 .668 r
.56285 .31189 m .5626 .31179 L .5628 .31166 L closepath p F P
0 g
s
.815 .71 .75 r
.21543 .41681 m .21011 .41409 L .21581 .40702 L p F P
0 g
s
.815 .71 .75 r
.21543 .41681 m .21203 .42094 L .20859 .41597 L p F P
0 g
s
.815 .71 .75 r
.20859 .41597 m .21011 .41409 L .21543 .41681 L p F P
0 g
s
.537 .452 .707 r
.56357 .36022 m .57328 .35441 L p .57489 .36226 L F P
0 g
s
.537 .452 .707 r
.57489 .36226 m .56381 .36108 L .56357 .36022 L p F P
0 g
s
.527 .443 .704 r
.57235 .35104 m .57328 .35441 L .56357 .36022 L p F P
0 g
s
.527 .443 .704 r
.5661 .35011 m .57235 .35104 L p .56357 .36022 L F P
0 g
s
.82 .699 .731 r
.22592 .38364 m .2288 .37964 L .22551 .37419 L p F P
0 g
s
.908 .707 .62 r
.22467 .27604 m .22876 .27936 L .22704 .28499 L p F P
0 g
s
.911 .701 .607 r
.22876 .27936 m .22467 .27604 L .22614 .2705 L p F P
0 g
s
.536 .457 .714 r
.56569 .36777 m .56381 .36108 L .57489 .36226 L closepath p F P
0 g
s
.48 .383 .667 r
.5628 .31166 m .57186 .30496 L p .56927 .31487 L F P
0 g
s
.48 .383 .667 r
.56927 .31487 m .56285 .31189 L .5628 .31166 L p F P
0 g
s
.461 .363 .657 r
.57142 .30286 m .57186 .30496 L .5628 .31166 L p F P
0 g
s
.461 .363 .657 r
.56749 .30054 m .57142 .30286 L p .5628 .31166 L F P
0 g
s
.671 .735 .898 r
.6309 .20635 m .6192 .21006 L .6163 .20673 L p F P
0 g
s
.713 .781 .905 r
.60468 .21225 m .6163 .20673 L .6192 .21006 L p F P
0 g
s
.653 .716 .895 r
.6192 .21006 m .6309 .20635 L .63381 .2104 L p F P
0 g
s
.477 .385 .673 r
.5643 .31849 m .56285 .31189 L .56927 .31487 L closepath p F P
0 g
s
.021 0 .116 r
.75123 .44068 m .75182 .44019 L .75197 .43962 L closepath p F P
0 g
s
.67 .975 .834 r
.727 .46101 m .72905 .46064 L .73495 .45644 L p F P
0 g
s
.487 .512 .808 r
.73543 .27924 m .74342 .28072 L .74048 .27386 L p F P
0 g
s
.487 .512 .808 r
.74048 .27386 m .73923 .27363 L .73543 .27924 L p F P
0 g
s
.489 .51 .805 r
.73543 .27924 m .74342 .28072 L p .74189 .28681 L F P
0 g
s
.67 .975 .834 r
.60086 .21455 m .60295 .21109 L p .59165 .22036 L F P
0 g
s
.762 .887 .934 r
.60086 .21455 m .60295 .21109 L .60468 .21225 L closepath p F P
0 g
s
.319 .656 .971 r
.07881 .46731 m .08789 .4681 L .09227 .47112 L p F P
0 g
s
.345 .665 .974 r
.08789 .4681 m .07881 .46731 L .07501 .46445 L p F P
0 g
s
.842 .702 .708 r
.22707 .34898 m .2322 .35185 L .22826 .3583 L p F P
0 g
s
.837 .696 .708 r
.23077 .34277 m .22707 .34898 L .2322 .35185 L p F P
0 g
s
.393 .29 .617 r
.57246 .27433 m .56708 .27911 L .56804 .28529 L p F P
0 g
s
.379 .268 .6 r
.56708 .27911 m .57246 .27433 L .56967 .27007 L p F P
0 g
s
.425 .312 .621 r
.56764 .28561 m .56804 .28529 L .56708 .27911 L p F P
0 g
s
.598 .571 .794 r
.60634 .44866 m .60545 .44879 L .60623 .44841 L closepath p F P
0 g
s
.597 .565 .789 r
.6033 .44171 m .60623 .44841 L .60545 .44879 L p F P
0 g
s
.57 .517 .757 r
.59115 .4108 m .59413 .41887 L .58244 .41974 L p F P
0 g
s
.57 .517 .757 r
.58244 .41974 m .58118 .41622 L .59115 .4108 L p F P
0 g
s
.633 .729 .917 r
.65934 .4747 m .67111 .47174 L .67396 .4753 L p F P
0 g
s
.626 .704 .901 r
.67111 .47174 m .65934 .4747 L .65644 .4705 L p F P
0 g
s
.442 .438 .76 r
.76456 .31383 m .76031 .31947 L .76752 .32253 L p F P
0 g
s
.452 .451 .767 r
.75681 .31096 m .76456 .31383 L .76031 .31947 L p F P
0 g
s
0 0 0 r
.75182 .44019 m .75123 .44068 L .74466 .44809 L p F P
0 g
s
.93 .575 .33 r
.03751 .43167 m .03725 .43028 L .03336 .42748 L p F P
0 g
s
.74 .759 .868 r
.14271 .47251 m .14017 .47397 L .13652 .4705 L p F P
0 g
s
.7 .754 .894 r
.12554 .47547 m .13652 .4705 L .14017 .47397 L p F P
0 g
s
.702 .881 .964 r
.70225 .47184 m .70304 .47236 L .71478 .46707 L p F P
0 g
s
.054 0 .213 r
.58149 .23592 m .58177 .23447 L .58373 .23054 L p F P
0 g
s
0 0 0 r
.59031 .22166 m .59165 .22036 L p .58373 .23054 L F P
0 g
s
0 0 0 r
.58373 .23054 m .58855 .22433 L .59031 .22166 L p F P
0 g
s
.649 .753 .925 r
.11103 .47563 m .12185 .47217 L .12554 .47547 L p F P
0 g
s
.656 .754 .922 r
.12185 .47217 m .11103 .47563 L .10731 .4725 L p F P
0 g
s
.11 0 .297 r
.76479 .42164 m .76179 .42442 L .76134 .42881 L p F P
0 g
s
.193 .018 .402 r
.76179 .42442 m .76479 .42164 L .76594 .41585 L p F P
0 g
s
.61 .624 .84 r
.6388 .46309 m .62941 .46479 L .63736 .46043 L closepath p F P
0 g
s
.609 .613 .83 r
.63583 .4576 m .63736 .46043 L .62941 .46479 L p F P
0 g
s
.609 .613 .83 r
.62407 .45948 m .63583 .4576 L p .62941 .46479 L F P
0 g
s
.544 .463 .715 r
.56569 .36777 m .57489 .36226 L p .57277 .37257 L F P
0 g
s
.544 .463 .715 r
.57277 .37257 m .56693 .37216 L .56569 .36777 L p F P
0 g
s
.799 .71 .767 r
.20913 .42407 m .21203 .42094 L .20859 .41597 L p F P
0 g
s
.57 .517 .756 r
.59105 .41052 m .59115 .4108 L .58118 .41622 L p F P
0 g
s
.57 .517 .756 r
.58118 .41622 m .57936 .41113 L .59105 .41052 L p F P
0 g
s
.876 .707 .669 r
.22674 .29992 m .23127 .30306 L .2286 .30904 L p F P
0 g
s
.875 .702 .665 r
.22924 .294 m .22674 .29992 L .23127 .30306 L p F P
0 g
s
.864 .705 .683 r
.22753 .32424 m .23226 .32728 L .22922 .33341 L p F P
0 g
s
.863 .701 .679 r
.23226 .32728 m .22753 .32424 L .23044 .31816 L p F P
0 g
s
.824 .708 .737 r
.22033 .4015 m .22145 .39997 L .21823 .39825 L closepath p F P
0 g
s
.826 .706 .733 r
.21692 .39623 m .22105 .39042 L p .22145 .39997 L F P
0 g
s
.826 .706 .733 r
.22145 .39997 m .21823 .39825 L .21692 .39623 L p F P
0 g
s
.568 .628 .872 r
.66728 .22217 m .66613 .22018 L .66844 .21998 L closepath p F P
0 g
s
.59 .567 .796 r
.61624 .44303 m .61806 .44707 L .60634 .44866 L p F P
0 g
s
.59 .567 .796 r
.60634 .44866 m .60623 .44841 L .61624 .44303 L p F P
0 g
s
.594 .584 .812 r
.60634 .44866 m .61806 .44707 L .62108 .45346 L p F P
0 g
s
.485 .501 .799 r
.74636 .28779 m .74189 .28681 L p .74764 .29462 L F P
0 g
s
.481 .499 .799 r
.74636 .28779 m .74189 .28681 L .74446 .28318 L closepath p F P
0 g
s
.489 .51 .805 r
.74342 .28072 m .74446 .28318 L .74189 .28681 L p F P
0 g
s
.335 .249 .608 r
.7759 .38074 m .77296 .38379 L .77548 .38843 L p F P
0 g
s
.36 .285 .636 r
.77296 .38379 m .7759 .38074 L .77462 .37429 L p F P
0 g
s
.839 .701 .711 r
.22942 .36762 m .22542 .37405 L .22203 .36851 L p F P
0 g
s
.839 .701 .711 r
.22203 .36851 m .22433 .36476 L .22942 .36762 L p F P
0 g
s
.839 .7 .71 r
.22942 .36762 m .22433 .36476 L .22826 .3583 L p F P
0 g
s
.459 .466 .778 r
.75243 .30294 m .75263 .30266 L p .75681 .31096 L F P
0 g
s
.467 .48 .788 r
.75243 .30294 m .75228 .30257 L .75263 .30266 L closepath p F P
0 g
s
.588 .565 .796 r
.61504 .44037 m .61624 .44303 L .60623 .44841 L p F P
0 g
s
.588 .565 .796 r
.60623 .44841 m .6033 .44171 L .61504 .44037 L p F P
0 g
s
.532 .572 .841 r
.70453 .24635 m .70407 .24634 L .70433 .24594 L closepath p F P
0 g
s
.538 .581 .846 r
.70163 .24065 m .70433 .24594 L .70407 .24634 L p F P
0 g
s
.705 .755 .892 r
.13652 .4705 m .12554 .47547 L .12185 .47217 L p F P
0 g
s
.379 .332 .679 r
.77309 .36754 m .77661 .36352 L .77226 .35948 L p F P
0 g
s
.381 .337 .684 r
.77715 .35375 m .77226 .35948 L .77661 .36352 L p F P
0 g
s
.398 .359 .699 r
.77215 .34992 m .77715 .35375 L .77226 .35948 L p F P
0 g
s
.618 .679 .886 r
.63381 .2104 m .64557 .20775 L .64848 .21222 L p F P
0 g
s
.627 .69 .889 r
.64557 .20775 m .63381 .2104 L .6309 .20635 L p F P
0 g
s
.364 .307 .659 r
.77309 .36754 m .77661 .36352 L p .77533 .3735 L F P
0 g
s
.364 .307 .659 r
.77533 .3735 m .77413 .37215 L .77309 .36754 L p F P
0 g
s
.451 .455 .772 r
.76089 .30535 m .75681 .31096 L .76456 .31383 L p F P
0 g
s
.459 .466 .778 r
.75263 .30266 m .76089 .30535 L .75681 .31096 L p F P
0 g
s
.467 .481 .789 r
.75263 .30266 m .75228 .30257 L .74932 .29505 L p F P
0 g
s
0 0 0 r
.73495 .45644 m .73936 .45303 L .74061 .45188 L closepath p F P
0 g
s
.67 .975 .834 r
.73495 .45644 m .73936 .45303 L p .727 .46101 L F P
0 g
s
.81 .721 .767 r
.20367 .4214 m .20913 .42407 L .20235 .4315 L p F P
0 g
s
.799 .71 .767 r
.20859 .41597 m .20367 .4214 L .20913 .42407 L p F P
0 g
s
.918 .709 .606 r
.2222 .26711 m .22614 .2705 L .22467 .27604 L p F P
0 g
s
.922 .7 .584 r
.22614 .2705 m .2222 .26711 L .22338 .26169 L p F P
0 g
s
.543 .469 .722 r
.5679 .37543 m .56693 .37216 L .57277 .37257 L closepath p F P
0 g
s
.828 .707 .73 r
.22059 .38088 m .22592 .38364 L .22105 .39042 L p F P
0 g
s
.82 .699 .731 r
.22537 .37412 m .22059 .38088 L .22592 .38364 L p F P
0 g
s
.82 .699 .731 r
.22551 .37419 m .22537 .37412 L p .22592 .38364 L F P
0 g
s
0 0 0 r
.75835 .43449 m .75182 .44019 L .75037 .44343 L p F P
0 g
s
0 0 0 r
.74466 .44809 m .75037 .44343 L .75182 .44019 L p F P
0 g
s
0 0 .079 r
.76103 .43034 m .75835 .43449 L .75182 .44019 L p F P
0 g
s
0 0 .079 r
.76134 .42881 m .76103 .43034 L p .75182 .44019 L F P
0 g
s
.74 .759 .868 r
.13652 .4705 m .13798 .46964 L .14271 .47251 L p F P
0 g
s
.731 .75 .867 r
.14766 .46397 m .13798 .46964 L .14271 .47251 L p F P
0 g
s
.731 .75 .867 r
.14271 .47251 m .15128 .46765 L .14766 .46397 L p F P
0 g
s
.71 .878 .96 r
.60295 .21109 m .60468 .21225 L .6163 .20673 L p F P
0 g
s
.756 .742 .84 r
.15128 .46765 m .15989 .46174 L .16529 .4644 L p F P
0 g
s
.749 .741 .845 r
.16253 .45996 m .15989 .46174 L .16529 .4644 L p F P
0 g
s
.749 .741 .845 r
.16529 .4644 m .1661 .46387 L .16253 .45996 L p F P
0 g
s
.885 .705 .654 r
.22924 .294 m .22989 .29231 L .22652 .28652 L p F P
0 g
s
.565 .506 .749 r
.5881 .40218 m .59105 .41052 L .57936 .41113 L p F P
0 g
s
.565 .506 .749 r
.57936 .41113 m .57817 .40767 L .5881 .40218 L p F P
0 g
s
.474 .485 .79 r
.74932 .29505 m .74764 .29462 L .74862 .29328 L closepath p F P
0 g
s
.485 .501 .799 r
.74764 .29462 m .74862 .29328 L .74636 .28779 L p F P
0 g
s
.81 .705 .749 r
.21581 .40702 m .22033 .4015 L .21823 .39825 L p F P
0 g
s
.25 .102 .476 r
.76594 .41585 m .77032 .41176 L .77009 .40658 L p F P
0 g
s
.189 .016 .4 r
.77032 .41176 m .76594 .41585 L .76479 .42164 L p F P
0 g
s
.55 .474 .723 r
.5679 .37543 m .57277 .37257 L p .57105 .38272 L F P
0 g
s
.55 .474 .723 r
.57105 .38272 m .57005 .38269 L .5679 .37543 L p F P
0 g
s
.522 .563 .839 r
.70453 .24635 m .71662 .247 L p .71432 .25267 L F P
0 g
s
.518 .565 .842 r
.71372 .24115 m .71662 .247 L .70453 .24635 L p F P
0 g
s
.518 .565 .842 r
.70722 .24082 m .71372 .24115 L p .70453 .24635 L F P
0 g
s
.518 .565 .842 r
.70453 .24635 m .70433 .24594 L .70722 .24082 L p F P
0 g
s
.459 .47 .783 r
.75652 .29709 m .75263 .30266 L .76089 .30535 L p F P
0 g
s
.467 .481 .789 r
.74932 .29505 m .75652 .29709 L .75263 .30266 L p F P
0 g
s
.773 .734 .817 r
.17705 .45538 m .1661 .46387 L .16253 .45996 L p F P
0 g
s
.285 .163 .533 r
.5738 .25384 m .57352 .25413 L .57395 .25965 L p F P
0 g
s
.494 .825 .527 r
.73936 .45303 m .74061 .45188 L .74466 .44809 L p F P
0 g
s
.494 .825 .527 r
.74466 .44809 m .75037 .44343 L p .73936 .45303 L F P
0 g
s
.564 .505 .748 r
.58796 .40178 m .5881 .40218 L .57817 .40767 L p F P
0 g
s
.564 .505 .748 r
.57817 .40767 m .57627 .4021 L .58796 .40178 L p F P
0 g
s
.646 .785 .948 r
.67396 .4753 m .68575 .47182 L .68854 .47464 L p F P
0 g
s
.638 .752 .931 r
.68575 .47182 m .67396 .4753 L .67111 .47174 L p F P
0 g
s
.556 .606 .858 r
.68384 .22968 m .6818 .22979 L .68292 .22799 L closepath p F P
0 g
s
.56 .615 .864 r
.68094 .22441 m .68292 .22799 L .6818 .22979 L p F P
0 g
s
.528 .576 .848 r
.70433 .24594 m .70163 .24065 L .70722 .24082 L closepath p F P
0 g
s
.657 .856 .976 r
.68854 .47464 m .70032 .47045 L .70225 .47184 L p F P
0 g
s
.652 .816 .962 r
.70032 .47045 m .68854 .47464 L .68575 .47182 L p F P
0 g
s
.371 .265 .603 r
.57463 .26547 m .56967 .27007 L .57246 .27433 L p F P
0 g
s
.35 .234 .577 r
.56967 .27007 m .57463 .26547 L .57395 .25965 L p F P
0 g
s
.55 .48 .73 r
.57021 .38321 m .57005 .38269 L .57105 .38272 L closepath p F P
0 g
s
.559 .496 .741 r
.58526 .3938 m .58796 .40178 L .57627 .4021 L p F P
0 g
s
.559 .496 .741 r
.57627 .4021 m .57536 .39934 L .58526 .3938 L p F P
0 g
s
.551 .483 .732 r
.57271 .39119 m .57021 .38321 L .57105 .38272 L p F P
0 g
s
.501 .535 .824 r
.73179 .26635 m .72535 .26552 L .723 .26039 L p F P
0 g
s
.259 .141 .523 r
.58 .24723 m .5738 .25384 L .57497 .25862 L p F P
0 g
s
.213 .074 .465 r
.5738 .25384 m .58 .24723 L .57986 .24211 L p F P
0 g
s
.285 .163 .533 r
.57395 .25965 m .57497 .25862 L .5738 .25384 L p F P
0 g
s
.558 .494 .74 r
.58486 .39261 m .58526 .3938 L .57536 .39934 L p F P
0 g
s
.558 .494 .74 r
.57536 .39934 m .57316 .39264 L .58486 .39261 L p F P
0 g
s
.902 .494 .203 r
.04316 .4395 m .03912 .4363 L .03751 .43167 L p F P
0 g
s
.903 .494 .193 r
.03354 .42844 m .03751 .43167 L .03912 .4363 L p F P
0 g
s
.93 .575 .33 r
.03336 .42748 m .03354 .42844 L .03751 .43167 L p F P
0 g
s
.505 .406 .677 r
.56507 .32589 m .56586 .32539 L .5643 .31849 L p F P
0 g
s
.479 .39 .676 r
.56586 .32539 m .5643 .31849 L .56927 .31487 L p F P
0 g
s
.766 .733 .822 r
.17809 .45586 m .17743 .45508 L .17705 .45538 L closepath p F P
0 g
s
.554 .486 .733 r
.57316 .39264 m .57271 .39119 L .58259 .38561 L p F P
0 g
s
.551 .483 .732 r
.58175 .383 m .58259 .38561 L .57271 .39119 L p F P
0 g
s
.551 .483 .732 r
.57105 .38272 m .58175 .383 L p .57271 .39119 L F P
0 g
s
.938 .602 .366 r
.03284 .42352 m .03336 .42748 L .0295 .42435 L p F P
0 g
s
.938 .602 .366 r
.0295 .42435 m .02896 .42024 L .03284 .42352 L p F P
0 g
s
.942 .644 .447 r
.03284 .42352 m .02896 .42024 L .02887 .41513 L p F P
0 g
s
.554 .486 .733 r
.58259 .38561 m .58486 .39261 L .57316 .39264 L p F P
0 g
s
.272 .151 .527 r
.77009 .40658 m .77227 .4044 L .7714 .39923 L p F P
0 g
s
.27 .151 .527 r
.77723 .39333 m .7714 .39923 L .77227 .4044 L p F P
0 g
s
.308 .206 .572 r
.7714 .39923 m .77723 .39333 L .77548 .38843 L p F P
0 g
s
.855 .704 .694 r
.23077 .34277 m .23088 .34258 L .23053 .34236 L closepath p F P
0 g
s
.857 .701 .687 r
.2274 .33697 m .22922 .33341 L p .23088 .34258 L F P
0 g
s
.857 .701 .687 r
.23088 .34258 m .23053 .34236 L .2274 .33697 L p F P
0 g
s
.81 .721 .767 r
.20235 .4315 m .20041 .43364 L .19693 .42899 L p F P
0 g
s
.81 .721 .767 r
.19693 .42899 m .19715 .42874 L .20235 .4315 L p F P
0 g
s
.81 .721 .767 r
.20235 .4315 m .19715 .42874 L .20367 .4214 L p F P
0 g
s
.93 .709 .582 r
.21959 .25823 m .22338 .26169 L .2222 .26711 L p F P
0 g
s
.936 .696 .55 r
.22338 .26169 m .21959 .25823 L .22041 .25293 L p F P
0 g
s
.842 .702 .708 r
.22707 .34898 m .23077 .34277 L .23053 .34236 L p F P
0 g
s
.883 .711 .663 r
.22485 .2908 m .22924 .294 L .22674 .29992 L p F P
0 g
s
.885 .705 .654 r
.22652 .28652 m .22485 .2908 L .22924 .294 L p F P
0 g
s
0 0 .163 r
.58089 .23662 m .58149 .23592 L .58177 .23447 L closepath p F P
0 g
s
.831 .358 .007 r
.04976 .44701 m .04565 .44385 L .04316 .4395 L p F P
0 g
s
.828 .354 0 r
.03912 .4363 m .04316 .4395 L .04565 .44385 L p F P
0 g
s
.678 .862 .969 r
.70032 .47045 m .70935 .46688 L .70225 .47184 L closepath p F P
0 g
s
.702 .881 .964 r
.7121 .46575 m .70935 .46688 L .70225 .47184 L p F P
0 g
s
.702 .881 .964 r
.71478 .46707 m .7121 .46575 L p .70225 .47184 L F P
0 g
s
.623 .656 .862 r
.64175 .46824 m .65353 .4659 L p .65461 .4709 L F P
0 g
s
.609 .647 .862 r
.65353 .4659 m .64175 .46824 L .6388 .46309 L p F P
0 g
s
.87 .708 .679 r
.22583 .31507 m .23044 .31816 L .22753 .32424 L p F P
0 g
s
.869 .704 .675 r
.23044 .31816 m .22583 .31507 L .2286 .30904 L p F P
0 g
s
.365 .307 .659 r
.77462 .37429 m .77413 .37215 L .77533 .3735 L closepath p F P
0 g
s
.596 .598 .823 r
.63284 .45178 m .63583 .4576 L .62407 .45948 L p F P
0 g
s
.596 .598 .823 r
.62217 .45331 m .63284 .45178 L p .62407 .45948 L F P
0 g
s
.596 .598 .823 r
.62407 .45948 m .62126 .45384 L .62217 .45331 L p F P
0 g
s
.842 .702 .708 r
.23053 .34236 m .22586 .33966 L p .22707 .34898 L F P
0 g
s
.844 .699 .702 r
.23053 .34236 m .2274 .33697 L .22586 .33966 L closepath p F P
0 g
s
.792 .72 .785 r
.1947 .4392 m .20041 .43364 L .19693 .42899 L p F P
0 g
s
.567 .633 .876 r
.66844 .21998 m .66613 .22018 L .66323 .21529 L p F P
0 g
s
.82 .715 .749 r
.21048 .40428 m .21581 .40702 L .21011 .41409 L p F P
0 g
s
.81 .705 .749 r
.21612 .39723 m .21048 .40428 L .21581 .40702 L p F P
0 g
s
.81 .705 .749 r
.21823 .39825 m .21612 .39723 L p .21581 .40702 L F P
0 g
s
.552 .482 .731 r
.58175 .383 m .57105 .38272 L .58007 .37759 L closepath p F P
0 g
s
.55 .474 .723 r
.57862 .37291 m .58007 .37759 L .57105 .38272 L p F P
0 g
s
.55 .474 .723 r
.57277 .37257 m .57862 .37291 L p .57105 .38272 L F P
0 g
s
.591 .66 .885 r
.64888 .21284 m .64848 .21222 L .64924 .2121 L closepath p F P
0 g
s
.437 .332 .637 r
.56818 .28606 m .56764 .28561 L .56804 .28529 L closepath p F P
0 g
s
.058 .496 .892 r
.07227 .46349 m .07501 .46445 L .0712 .46152 L p F P
0 g
s
.058 .496 .892 r
.0712 .46152 m .06795 .46044 L .07227 .46349 L p F P
0 g
s
.773 .734 .817 r
.16253 .45996 m .17162 .45272 L .17705 .45538 L p F P
0 g
s
.767 .734 .823 r
.17389 .45094 m .17162 .45272 L .17705 .45538 L p F P
0 g
s
.767 .734 .823 r
.17705 .45538 m .17743 .45508 L .17389 .45094 L p F P
0 g
s
.799 .724 .782 r
.1947 .4392 m .18887 .445 L .18536 .44061 L p F P
0 g
s
.799 .724 .782 r
.18536 .44061 m .18942 .43648 L .1947 .4392 L p F P
0 g
s
.792 .72 .785 r
.19693 .42899 m .18942 .43648 L .1947 .4392 L p F P
0 g
s
.787 .729 .798 r
.18644 .44711 m .17743 .45508 L .17389 .45094 L p F P
0 g
s
.846 .707 .709 r
.22325 .3554 m .22826 .3583 L .22433 .36476 L p F P
0 g
s
.842 .702 .708 r
.22826 .3583 m .22325 .3554 L .22707 .34898 L p F P
0 g
s
.464 .479 .79 r
.75652 .29709 m .74932 .29505 L .74862 .29328 L p F P
0 g
s
.509 .414 .683 r
.56604 .32615 m .56507 .32589 L .56586 .32539 L closepath p F P
0 g
s
.528 .444 .704 r
.57235 .35104 m .5661 .35011 L .57127 .34697 L closepath p F P
0 g
s
.527 .436 .695 r
.56934 .33962 m .57127 .34697 L .5661 .35011 L p F P
0 g
s
.542 .598 .86 r
.69293 .22404 m .69583 .22944 L .68384 .22968 L p F P
0 g
s
.542 .598 .86 r
.68486 .22425 m .69293 .22404 L p .68384 .22968 L F P
0 g
s
.542 .598 .86 r
.68384 .22968 m .68292 .22799 L .68486 .22425 L p F P
0 g
s
.543 .595 .856 r
.68384 .22968 m .69583 .22944 L p .69546 .23498 L F P
0 g
s
.787 .729 .798 r
.17389 .45094 m .18108 .44442 L .18644 .44711 L p F P
0 g
s
.781 .727 .803 r
.18536 .44061 m .18108 .44442 L .18644 .44711 L p F P
0 g
s
.781 .727 .803 r
.18644 .44711 m .18887 .445 L .18536 .44061 L p F P
0 g
s
.34 .271 .633 r
.77533 .3735 m .77462 .37429 L .7759 .38074 L p F P
0 g
s
.581 .553 .788 r
.612 .43336 m .61504 .44037 L .6033 .44171 L p F P
0 g
s
.581 .553 .788 r
.61066 .43349 m .612 .43336 L p .6033 .44171 L F P
0 g
s
.581 .553 .788 r
.6033 .44171 m .60192 .43842 L .61066 .43349 L p F P
0 g
s
.425 .324 .636 r
.56804 .28529 m .57578 .27844 L p .57187 .28943 L F P
0 g
s
.425 .324 .636 r
.57187 .28943 m .56818 .28606 L .56804 .28529 L p F P
0 g
s
.393 .29 .617 r
.56804 .28529 m .57578 .27844 L .57246 .27433 L p F P
0 g
s
.828 .707 .73 r
.22105 .39042 m .21589 .38761 L .22059 .38088 L p F P
0 g
s
.828 .707 .73 r
.22105 .39042 m .21692 .39623 L .2135 .39102 L p F P
0 g
s
.828 .707 .73 r
.2135 .39102 m .21589 .38761 L .22105 .39042 L p F P
0 g
s
.943 .704 .548 r
.21678 .2494 m .22041 .25293 L .21959 .25823 L p F P
0 g
s
.95 .683 .497 r
.22041 .25293 m .21678 .2494 L .21715 .24428 L p F P
0 g
s
.223 .082 .469 r
.77227 .4044 m .77009 .40658 L .77032 .41176 L p F P
0 g
s
.686 .158 0 r
.05744 .45418 m .05329 .45105 L .04976 .44701 L p F P
0 g
s
.675 .147 0 r
.04565 .44385 m .04976 .44701 L .05329 .45105 L p F P
0 g
s
.822 .697 .726 r
.22551 .37419 m .22542 .37405 L .22537 .37412 L closepath p F P
0 g
s
.394 .359 .701 r
.77695 .3442 m .77215 .34992 L .77715 .35375 L p F P
0 g
s
.409 .379 .715 r
.77133 .34058 m .77695 .3442 L .77215 .34992 L p F P
0 g
s
.591 .667 .892 r
.64924 .2121 m .64848 .21222 L .64557 .20775 L p F P
0 g
s
.464 .479 .79 r
.74862 .29328 m .75146 .28904 L p .75652 .29709 L F P
0 g
s
.472 .493 .799 r
.74862 .29328 m .74636 .28779 L .75146 .28904 L closepath p F P
0 g
s
.825 .701 .728 r
.22537 .37412 m .22542 .37405 L .22203 .36851 L p F P
0 g
s
.83 .707 .729 r
.22009 .37133 m .22537 .37412 L .22059 .38088 L p F P
0 g
s
.825 .701 .728 r
.22203 .36851 m .22009 .37133 L .22537 .37412 L p F P
0 g
s
.082 0 .345 r
.58149 .23592 m .58089 .23662 L .57986 .24211 L p F P
0 g
s
.426 .692 .975 r
.09227 .47112 m .09293 .47114 L .08916 .46812 L p F P
0 g
s
.426 .692 .975 r
.08916 .46812 m .08789 .4681 L .09227 .47112 L p F P
0 g
s
.419 .323 .64 r
.56921 .29171 m .56818 .28606 L .57187 .28943 L closepath p F P
0 g
s
.649 .892 .553 r
.59031 .22166 m .59384 .21742 L .59165 .22036 L closepath p F P
0 g
s
.67 .975 .834 r
.60179 .21053 m .59384 .21742 L .59165 .22036 L p F P
0 g
s
.67 .975 .834 r
.60295 .21109 m .60179 .21053 L p .59165 .22036 L F P
0 g
s
.516 .554 .834 r
.71953 .25307 m .71432 .25267 L .71716 .24811 L closepath p F P
0 g
s
.522 .563 .839 r
.71662 .247 m .71716 .24811 L .71432 .25267 L p F P
0 g
s
.812 .704 .745 r
.21823 .39825 m .21692 .39623 L .21612 .39723 L closepath p F P
0 g
s
.908 .707 .62 r
.22311 .28118 m .22467 .27604 L p .22704 .28499 L F P
0 g
s
.908 .707 .62 r
.22704 .28499 m .22383 .28237 L .22311 .28118 L p F P
0 g
s
.902 .714 .638 r
.22652 .28652 m .22704 .28499 L .22383 .28237 L closepath p F P
0 g
s
.496 .405 .683 r
.56586 .32539 m .575 .31881 L p .57307 .32857 L F P
0 g
s
.496 .405 .683 r
.57307 .32857 m .56604 .32615 L .56586 .32539 L p F P
0 g
s
.479 .39 .676 r
.57462 .31718 m .575 .31881 L .56586 .32539 L p F P
0 g
s
.479 .39 .676 r
.56927 .31487 m .57462 .31718 L p .56586 .32539 L F P
0 g
s
.595 .666 .889 r
.64924 .2121 m .66032 .21046 L .65741 .20571 L p F P
0 g
s
.595 .666 .889 r
.65741 .20571 m .65177 .20666 L .64924 .2121 L p F P
0 g
s
.591 .667 .892 r
.64557 .20775 m .65177 .20666 L .64924 .2121 L p F P
0 g
s
.862 .707 .688 r
.22922 .33341 m .2274 .33697 L .22401 .33143 L p F P
0 g
s
.862 .707 .688 r
.22401 .33143 m .22455 .33036 L .22922 .33341 L p F P
0 g
s
.864 .705 .683 r
.22922 .33341 m .22455 .33036 L .22753 .32424 L p F P
0 g
s
.624 .669 .873 r
.65644 .4705 m .65461 .4709 L .65615 .47003 L closepath p F P
0 g
s
.623 .656 .862 r
.65353 .4659 m .65615 .47003 L .65461 .4709 L p F P
0 g
s
.761 .746 .839 r
.15989 .46174 m .15128 .46765 L .14766 .46397 L p F P
0 g
s
.493 .409 .689 r
.56757 .33247 m .56604 .32615 L .57307 .32857 L closepath p F P
0 g
s
.876 .711 .674 r
.22412 .30589 m .2286 .30904 L .22583 .31507 L p F P
0 g
s
.876 .707 .669 r
.2286 .30904 m .22412 .30589 L .22674 .29992 L p F P
0 g
s
.569 .738 .956 r
.09293 .47114 m .10357 .46934 L .10731 .4725 L p F P
0 g
s
.578 .74 .953 r
.10357 .46934 m .09293 .47114 L .08916 .46812 L p F P
0 g
s
.581 .553 .788 r
.60192 .43842 m .60026 .43444 L .61066 .43349 L closepath p F P
0 g
s
.568 .629 .872 r
.66844 .21998 m .67804 .21923 L .67514 .21411 L p F P
0 g
s
.568 .629 .872 r
.67514 .21411 m .67132 .21446 L .66844 .21998 L p F P
0 g
s
.567 .633 .876 r
.66323 .21529 m .67132 .21446 L .66844 .21998 L p F P
0 g
s
.501 .535 .824 r
.723 .26039 m .72365 .25931 L p .73179 .26635 L F P
0 g
s
.507 .546 .831 r
.723 .26039 m .72243 .25918 L .72365 .25931 L closepath p F P
0 g
s
.82 .715 .749 r
.20514 .41107 m .21048 .40428 L p .21011 .41409 L F P
0 g
s
.82 .715 .749 r
.21011 .41409 m .20549 .41158 L .20514 .41107 L p F P
0 g
s
.819 .717 .753 r
.20859 .41597 m .21011 .41409 L .20549 .41158 L closepath p F P
0 g
s
.55 .608 .864 r
.68292 .22799 m .68094 .22441 L .68486 .22425 L closepath p F P
0 g
s
.34 .274 .636 r
.78038 .36776 m .77533 .3735 L .7784 .37796 L p F P
0 g
s
.364 .307 .659 r
.77661 .36352 m .78038 .36776 L .77533 .3735 L p F P
0 g
s
.34 .271 .633 r
.7759 .38074 m .7784 .37796 L .77533 .3735 L p F P
0 g
s
.05 0 .333 r
.58606 .23031 m .58149 .23592 L .5812 .24056 L p F P
0 g
s
.054 0 .213 r
.58855 .22433 m .58606 .23031 L .58149 .23592 L p F P
0 g
s
.082 0 .345 r
.57986 .24211 m .5812 .24056 L .58149 .23592 L p F P
0 g
s
.533 0 0 r
.05745 .45419 m .05744 .45418 L .0576 .4543 L closepath p F P
0 g
s
0 .34 .775 r
.05745 .45419 m .0576 .4543 L p .06795 .46044 L F P
0 g
s
.804 .714 .766 r
.20367 .4214 m .20859 .41597 L .20549 .41158 L p F P
0 g
s
.892 .715 .655 r
.22485 .2908 m .22652 .28652 L .22383 .28237 L p F P
0 g
s
.461 .365 .66 r
.57142 .30286 m .56749 .30054 L .57048 .29827 L closepath p F P
0 g
s
.455 .355 .652 r
.56749 .30054 m .57048 .29827 L .56921 .29171 L p F P
0 g
s
.608 .952 .905 r
.71478 .46707 m .7265 .461 L .727 .46101 L p F P
0 g
s
.642 .942 .959 r
.7265 .461 m .71478 .46707 L .7121 .46575 L p F P
0 g
s
.511 0 0 r
.05744 .45418 m .05745 .45419 L .05361 .45133 L p F P
0 g
s
.511 0 0 r
.05361 .45133 m .05329 .45105 L .05744 .45418 L p F P
0 g
s
.506 .548 .833 r
.72365 .25931 m .72243 .25918 L .71953 .25307 L p F P
0 g
s
.849 .709 .707 r
.22214 .34604 m .22707 .34898 L .22325 .3554 L p F P
0 g
s
.842 .702 .708 r
.22586 .33966 m .22214 .34604 L .22707 .34898 L p F P
0 g
s
0 .34 .775 r
.06795 .46044 m .0637 .45735 L .05745 .45419 L p F P
0 g
s
0 .339 .773 r
.0637 .45735 m .05745 .45419 L .05361 .45133 L p F P
0 g
s
.527 .578 .849 r
.70722 .24082 m .70163 .24065 L .69873 .23498 L p F P
0 g
s
.626 .704 .901 r
.65644 .4705 m .66824 .46779 L .67111 .47174 L p F P
0 g
s
.619 .666 .874 r
.66574 .46407 m .66824 .46779 L .65644 .4705 L p F P
0 g
s
.619 .666 .874 r
.65644 .4705 m .65615 .47003 L .66574 .46407 L p F P
0 g
s
.913 .716 .623 r
.22467 .27604 m .22311 .28118 L .21967 .27614 L p F P
0 g
s
.913 .716 .623 r
.21967 .27614 m .22073 .27265 L .22467 .27604 L p F P
0 g
s
.918 .709 .606 r
.22467 .27604 m .22073 .27265 L .2222 .26711 L p F P
0 g
s
.471 .493 .799 r
.75146 .28904 m .74636 .28779 L .74446 .28318 L p F P
0 g
s
.814 .707 .747 r
.21612 .39723 m .21692 .39623 L .2135 .39102 L p F P
0 g
s
.086 0 .271 r
.77024 .41657 m .76479 .42164 L .76242 .42781 L p F P
0 g
s
.189 .016 .4 r
.76479 .42164 m .77024 .41657 L .77032 .41176 L p F P
0 g
s
.11 0 .297 r
.76134 .42881 m .76242 .42781 L .76479 .42164 L p F P
0 g
s
.581 .545 .779 r
.61066 .43349 m .60026 .43444 L .59801 .42886 L p F P
0 g
s
.821 .715 .747 r
.21079 .39448 m .21612 .39723 L .21048 .40428 L p F P
0 g
s
.814 .707 .747 r
.2135 .39102 m .21079 .39448 L .21612 .39723 L p F P
0 g
s
.407 .382 .719 r
.77475 .33638 m .77133 .34058 L .77695 .3442 L p F P
0 g
s
.422 .404 .734 r
.77393 .33376 m .76978 .33145 L p .77133 .34058 L F P
0 g
s
.422 .404 .734 r
.77133 .34058 m .77475 .33638 L .77393 .33376 L p F P
0 g
s
.319 .211 .572 r
.57497 .25862 m .57395 .25965 L .57463 .26547 L p F P
0 g
s
.775 .927 .935 r
.60179 .21053 m .60469 .20864 L .60295 .21109 L closepath p F P
0 g
s
.71 .878 .96 r
.61339 .20378 m .60469 .20864 L .60295 .21109 L p F P
0 g
s
.71 .878 .96 r
.6163 .20673 m .61339 .20378 L p .60295 .21109 L F P
0 g
s
.505 .418 .691 r
.56757 .33247 m .57307 .32857 L p .56985 .33927 L F P
0 g
s
.505 .418 .691 r
.56985 .33927 m .5692 .33909 L .56757 .33247 L p F P
0 g
s
.617 .665 .874 r
.66535 .46349 m .66574 .46407 L .65615 .47003 L p F P
0 g
s
.617 .665 .874 r
.65615 .47003 m .65353 .4659 L .66535 .46349 L p F P
0 g
s
.596 .597 .823 r
.62126 .45384 m .62108 .45346 L .62217 .45331 L closepath p F P
0 g
s
.846 .707 .709 r
.22433 .36476 m .21942 .36183 L .22325 .3554 L p F P
0 g
s
.844 .707 .712 r
.22433 .36476 m .22203 .36851 L .21862 .36315 L p F P
0 g
s
.844 .707 .712 r
.21862 .36315 m .21942 .36183 L .22433 .36476 L p F P
0 g
s
.814 .724 .766 r
.19842 .41865 m .20367 .4214 L .19715 .42874 L p F P
0 g
s
.804 .714 .766 r
.20493 .4113 m .19842 .41865 L .20367 .4214 L p F P
0 g
s
.804 .714 .766 r
.20549 .41158 m .20493 .4113 L p .20367 .4214 L F P
0 g
s
.87 .711 .682 r
.22298 .32114 m .22753 .32424 L .22455 .33036 L p F P
0 g
s
.87 .708 .679 r
.22753 .32424 m .22298 .32114 L .22583 .31507 L p F P
0 g
s
.596 .585 .811 r
.62217 .45331 m .62108 .45346 L .61806 .44707 L p F P
0 g
s
.835 .712 .729 r
.21547 .37804 m .22059 .38088 L .21589 .38761 L p F P
0 g
s
.83 .707 .729 r
.22059 .38088 m .21547 .37804 L .22009 .37133 L p F P
0 g
s
.745 .761 .866 r
.13798 .46964 m .13652 .4705 L .13286 .46702 L p F P
0 g
s
.705 .755 .892 r
.12185 .47217 m .13286 .46702 L .13652 .4705 L p F P
0 g
s
.849 .706 .704 r
.22586 .33966 m .2274 .33697 L .22401 .33143 L p F P
0 g
s
.883 .715 .669 r
.2224 .29671 m .22674 .29992 L .22412 .30589 L p F P
0 g
s
.883 .711 .663 r
.22674 .29992 m .2224 .29671 L .22485 .2908 L p F P
0 g
s
.671 .735 .898 r
.6163 .20673 m .62799 .20249 L .6309 .20635 L p F P
0 g
s
.692 .757 .901 r
.62799 .20249 m .6163 .20673 L .61339 .20378 L p F P
0 g
s
.754 .744 .843 r
.15894 .45607 m .15471 .459 L .15989 .46174 L p F P
0 g
s
.754 .744 .843 r
.15989 .46174 m .16253 .45996 L .15894 .45607 L p F P
0 g
s
.761 .746 .839 r
.14766 .46397 m .15471 .459 L .15989 .46174 L p F P
0 g
s
.427 .336 .65 r
.57187 .28943 m .56921 .29171 L .57048 .29827 L p F P
0 g
s
.312 .233 .604 r
.7784 .37796 m .7759 .38074 L .77696 .38691 L p F P
0 g
s
.335 .249 .608 r
.77548 .38843 m .77696 .38691 L .7759 .38074 L p F P
0 g
s
.506 .548 .833 r
.71953 .25307 m .72687 .25382 L .72365 .25931 L p F P
0 g
s
.499 .539 .829 r
.72365 .25931 m .73463 .2607 L .73172 .25442 L p F P
0 g
s
.499 .539 .829 r
.73172 .25442 m .72687 .25382 L .72365 .25931 L p F P
0 g
s
.501 .535 .824 r
.72365 .25931 m .73463 .2607 L p .73179 .26635 L F P
0 g
s
.538 .586 .85 r
.69873 .23498 m .69546 .23498 L .69721 .23204 L closepath p F P
0 g
s
.543 .595 .856 r
.69583 .22944 m .69721 .23204 L .69546 .23498 L p F P
0 g
s
.656 .754 .922 r
.10731 .4725 m .11816 .46886 L .12185 .47217 L p F P
0 g
s
.662 .755 .919 r
.11816 .46886 m .10731 .4725 L .10357 .46934 L p F P
0 g
s
.545 .471 .723 r
.57862 .37291 m .57277 .37257 L .57768 .36971 L closepath p F P
0 g
s
.544 .463 .715 r
.57549 .36232 m .57768 .36971 L .57277 .37257 L p F P
0 g
s
.544 .463 .715 r
.57489 .36226 m .57549 .36232 L p .57277 .37257 L F P
0 g
s
.345 .665 .974 r
.07501 .46445 m .08357 .46505 L .08789 .4681 L p F P
0 g
s
.367 .671 .974 r
.08357 .46505 m .07501 .46445 L .0712 .46152 L p F P
0 g
s
.745 .761 .866 r
.13286 .46702 m .13337 .46671 L .13798 .46964 L p F P
0 g
s
.736 .751 .865 r
.14403 .4603 m .13337 .46671 L .13798 .46964 L p F P
0 g
s
.736 .751 .865 r
.13798 .46964 m .14766 .46397 L .14403 .4603 L p F P
0 g
s
.639 .703 .893 r
.64266 .2034 m .6309 .20635 L .62799 .20249 L p F P
0 g
s
.627 .69 .889 r
.6309 .20635 m .64266 .2034 L .64557 .20775 L p F P
0 g
s
.609 .647 .862 r
.6388 .46309 m .65059 .46097 L .65353 .4659 L p F P
0 g
s
.602 .62 .842 r
.64764 .45574 m .65059 .46097 L .6388 .46309 L p F P
0 g
s
.602 .62 .842 r
.64407 .45631 m .64764 .45574 L p .6388 .46309 L F P
0 g
s
.602 .62 .842 r
.6388 .46309 m .63736 .46043 L .64407 .45631 L p F P
0 g
s
.933 .577 .322 r
.03354 .42844 m .03336 .42748 L .0295 .42435 L p F P
0 g
s
.597 .595 .821 r
.63284 .45178 m .62217 .45331 L .63111 .44823 L closepath p F P
0 g
s
.596 .585 .811 r
.62984 .44565 m .63111 .44823 L .62217 .45331 L p F P
0 g
s
.596 .585 .811 r
.61806 .44707 m .62984 .44565 L p .62217 .45331 L F P
0 g
s
.778 .739 .817 r
.17162 .45272 m .16253 .45996 L .15894 .45607 L p F P
0 g
s
.924 .717 .605 r
.21841 .26365 m .2222 .26711 L .22073 .27265 L p F P
0 g
s
.93 .709 .582 r
.2222 .26711 m .21841 .26365 L .21959 .25823 L p F P
0 g
s
.709 .756 .888 r
.13286 .46702 m .12185 .47217 L .11816 .46886 L p F P
0 g
s
.304 .204 .572 r
.77696 .38691 m .77548 .38843 L .77723 .39333 L p F P
0 g
s
.479 .506 .808 r
.74446 .28318 m .74342 .28072 L .74573 .28121 L closepath p F P
0 g
s
.471 .493 .799 r
.74446 .28318 m .74573 .28121 L p .75146 .28904 L F P
0 g
s
.581 .545 .779 r
.59801 .42886 m .60215 .42649 L p .61066 .43349 L F P
0 g
s
.575 .541 .779 r
.59801 .42886 m .5972 .42684 L .60215 .42649 L closepath p F P
0 g
s
.01 0 .166 r
.76103 .43034 m .76242 .42781 L .76134 .42881 L closepath p F P
0 g
s
.638 .752 .931 r
.67111 .47174 m .68293 .46857 L .68575 .47182 L p F P
0 g
s
.63 .724 .915 r
.68293 .46857 m .67111 .47174 L .66824 .46779 L p F P
0 g
s
.494 .825 .527 r
.74975 .44428 m .74304 .45 L .73936 .45303 L p F P
0 g
s
.494 .825 .527 r
.75037 .44343 m .74975 .44428 L p .73936 .45303 L F P
0 g
s
.549 .904 .695 r
.73817 .45363 m .74304 .45 L .73936 .45303 L closepath p F P
0 g
s
.67 .975 .834 r
.73936 .45303 m .73817 .45363 L p .727 .46101 L F P
0 g
s
.812 .725 .769 r
.19693 .42899 m .19715 .42874 L .19643 .42834 L closepath p F P
0 g
s
.814 .724 .766 r
.19344 .42437 m .19842 .41865 L p .19715 .42874 L F P
0 g
s
.814 .724 .766 r
.19715 .42874 m .19643 .42834 L .19344 .42437 L p F P
0 g
s
.503 .422 .698 r
.56934 .33962 m .5692 .33909 L .56985 .33927 L closepath p F P
0 g
s
.796 .723 .783 r
.18942 .43648 m .19693 .42899 L .19643 .42834 L p F P
0 g
s
.853 .711 .705 r
.22104 .33666 m .22586 .33966 L .22214 .34604 L p F P
0 g
s
.849 .706 .704 r
.22401 .33143 m .22104 .33666 L .22586 .33966 L p F P
0 g
s
.571 .639 .88 r
.67132 .21446 m .66323 .21529 L .66032 .21046 L p F P
0 g
s
.223 .082 .469 r
.77032 .41176 m .77224 .40985 L .77227 .4044 L p F P
0 g
s
.219 .079 .467 r
.77813 .39849 m .77227 .4044 L .77224 .40985 L p F P
0 g
s
.27 .151 .527 r
.77227 .4044 m .77813 .39849 L .77723 .39333 L p F P
0 g
s
.506 .428 .703 r
.56985 .33927 m .56934 .33962 L .57127 .34697 L p F P
0 g
s
.296 .197 .57 r
.58103 .25206 m .57497 .25862 L .5769 .26316 L p F P
0 g
s
.259 .141 .523 r
.57497 .25862 m .58103 .25206 L .58 .24723 L p F P
0 g
s
.319 .211 .572 r
.57463 .26547 m .5769 .26316 L .57497 .25862 L p F P
0 g
s
.66 .853 .974 r
.70935 .46688 m .70032 .47045 L .69756 .46801 L p F P
0 g
s
.652 .816 .962 r
.68575 .47182 m .69756 .46801 L .70032 .47045 L p F P
0 g
s
.661 .97 .903 r
.7265 .461 m .72863 .45974 L .727 .46101 L closepath p F P
0 g
s
.67 .975 .834 r
.73817 .45363 m .72863 .45974 L .727 .46101 L p F P
0 g
s
.418 .401 .734 r
.77393 .33376 m .76978 .33145 L .77223 .32836 L closepath p F P
0 g
s
.432 .422 .747 r
.77082 .32414 m .76752 .32253 L p .76978 .33145 L F P
0 g
s
.432 .422 .747 r
.76978 .33145 m .77223 .32836 L .77082 .32414 L p F P
0 g
s
.83 .707 .728 r
.22009 .37133 m .22203 .36851 L .21862 .36315 L p F P
0 g
s
.549 .611 .867 r
.68486 .22425 m .68094 .22441 L .67804 .21923 L p F P
0 g
s
.575 .533 .771 r
.60215 .42649 m .5972 .42684 L .59444 .41967 L p F P
0 g
s
.822 .714 .746 r
.21048 .40428 m .20514 .41107 L .20167 .40621 L p F P
0 g
s
.822 .714 .746 r
.20167 .40621 m .20533 .40147 L .21048 .40428 L p F P
0 g
s
.821 .715 .747 r
.21048 .40428 m .20533 .40147 L .21079 .39448 L p F P
0 g
s
.891 .719 .663 r
.22066 .28752 m .22485 .2908 L .2224 .29671 L p F P
0 g
s
.892 .715 .655 r
.22294 .28168 m .22066 .28752 L .22485 .2908 L p F P
0 g
s
.892 .715 .655 r
.22383 .28237 m .22294 .28168 L p .22485 .2908 L F P
0 g
s
.903 .494 .193 r
.03912 .4363 m .03515 .43307 L .03354 .42844 L p F P
0 g
s
.904 .494 .183 r
.02965 .42516 m .03354 .42844 L .03515 .43307 L p F P
0 g
s
.933 .577 .322 r
.0295 .42435 m .02965 .42516 L .03354 .42844 L p F P
0 g
s
.778 .739 .817 r
.15894 .45607 m .1664 .44998 L .17162 .45272 L p F P
0 g
s
.771 .737 .821 r
.17034 .44683 m .1664 .44998 L .17162 .45272 L p F P
0 g
s
.771 .737 .821 r
.17162 .45272 m .17389 .45094 L .17034 .44683 L p F P
0 g
s
.876 .715 .678 r
.2214 .31191 m .22583 .31507 L .22298 .32114 L p F P
0 g
s
.876 .711 .674 r
.22583 .31507 m .2214 .31191 L .22412 .30589 L p F P
0 g
s
.804 .729 .781 r
.18942 .43648 m .18536 .44061 L .18184 .43627 L p F P
0 g
s
.804 .729 .781 r
.18184 .43627 m .18432 .43369 L .18942 .43648 L p F P
0 g
s
.796 .723 .783 r
.19181 .42602 m .18432 .43369 L .18942 .43648 L p F P
0 g
s
.796 .723 .783 r
.19643 .42834 m .19181 .42602 L p .18942 .43648 L F P
0 g
s
.478 .507 .809 r
.74573 .28121 m .74342 .28072 L .74048 .27386 L p F P
0 g
s
.644 .78 .946 r
.69756 .46801 m .68575 .47182 L .68293 .46857 L p F P
0 g
s
.179 .049 .455 r
.5812 .24056 m .57986 .24211 L .58 .24723 L p F P
0 g
s
.797 .721 .781 r
.19643 .42834 m .19344 .42437 L .19181 .42602 L closepath p F P
0 g
s
.506 .428 .703 r
.5786 .33319 m .56985 .33927 L .57901 .34163 L p F P
0 g
s
.505 .418 .691 r
.5778 .3301 m .5786 .33319 L .56985 .33927 L p F P
0 g
s
.505 .418 .691 r
.57307 .32857 m .5778 .3301 L p .56985 .33927 L F P
0 g
s
.506 .428 .703 r
.57127 .34697 m .57901 .34163 L .56985 .33927 L p F P
0 g
s
.381 .337 .684 r
.7804 .35672 m .77715 .35375 L p .77661 .36352 L F P
0 g
s
.381 .337 .684 r
.77661 .36352 m .78088 .35859 L .7804 .35672 L p F P
0 g
s
.359 .305 .661 r
.78088 .35859 m .77661 .36352 L .78038 .36776 L p F P
0 g
s
.497 .527 .818 r
.73756 .26724 m .73179 .26635 L p .73923 .27363 L F P
0 g
s
.493 .526 .819 r
.73756 .26724 m .73179 .26635 L .73494 .26136 L closepath p F P
0 g
s
.501 .535 .824 r
.73463 .2607 m .73494 .26136 L .73179 .26635 L p F P
0 g
s
.851 .712 .708 r
.21841 .35243 m .22325 .3554 L .21942 .36183 L p F P
0 g
s
.849 .709 .707 r
.22325 .3554 m .21841 .35243 L .22214 .34604 L p F P
0 g
s
.937 .717 .581 r
.21596 .2547 m .21959 .25823 L .21841 .26365 L p F P
0 g
s
.943 .704 .548 r
.21959 .25823 m .21596 .2547 L .21678 .2494 L p F P
0 g
s
.792 .733 .798 r
.18108 .44442 m .17389 .45094 L .17034 .44683 L p F P
0 g
s
.479 .392 .679 r
.57462 .31718 m .56927 .31487 L .57339 .31184 L closepath p F P
0 g
s
.48 .383 .667 r
.57186 .30496 m .57339 .31184 L .56927 .31487 L p F P
0 g
s
.792 .733 .798 r
.17034 .44683 m .17591 .44166 L .18108 .44442 L p F P
0 g
s
.785 .73 .801 r
.18184 .43627 m .17591 .44166 L .18108 .44442 L p F P
0 g
s
.785 .73 .801 r
.18108 .44442 m .18536 .44061 L .18184 .43627 L p F P
0 g
s
.828 .354 0 r
.04565 .44385 m .04162 .44066 L .03912 .4363 L p F P
0 g
s
.824 .35 0 r
.03515 .43307 m .03912 .4363 L .04162 .44066 L p F P
0 g
s
.386 .288 .62 r
.57549 .27153 m .57246 .27433 L .57578 .27844 L p F P
0 g
s
.371 .265 .603 r
.57246 .27433 m .57549 .27153 L .57463 .26547 L p F P
0 g
s
.896 .708 .639 r
.22383 .28237 m .22311 .28118 L .22294 .28168 L closepath p F P
0 g
s
.835 .712 .729 r
.21589 .38761 m .2109 .38473 L .21547 .37804 L p F P
0 g
s
.834 .713 .73 r
.21589 .38761 m .2135 .39102 L .21006 .38594 L p F P
0 g
s
.834 .713 .73 r
.21006 .38594 m .2109 .38473 L .21589 .38761 L p F P
0 g
s
.083 .508 .901 r
.06795 .46044 m .0712 .46152 L .06739 .45853 L p F P
0 g
s
.083 .508 .901 r
.06739 .45853 m .0637 .45735 L .06795 .46044 L p F P
0 g
s
.601 .619 .841 r
.63736 .46043 m .63583 .4576 L .64407 .45631 L closepath p F P
0 g
s
.837 .713 .728 r
.21502 .36846 m .22009 .37133 L .21547 .37804 L p F P
0 g
s
.83 .707 .728 r
.21862 .36315 m .21502 .36846 L .22009 .37133 L p F P
0 g
s
.506 .549 .834 r
.72687 .25382 m .71953 .25307 L .71716 .24811 L p F P
0 g
s
0 0 0 r
.58961 .22282 m .59031 .22166 L .59384 .21742 L p F P
0 g
s
0 0 0 r
.59384 .21742 m .5975 .21157 L p .58961 .22282 L F P
0 g
s
.828 .98 .883 r
.59891 .21008 m .5975 .21157 L .59384 .21742 L p F P
0 g
s
.828 .98 .883 r
.59384 .21742 m .60179 .21053 L .59891 .21008 L p F P
0 g
s
.597 .677 .897 r
.65177 .20666 m .64557 .20775 L .64266 .2034 L p F P
0 g
s
.159 0 .391 r
.77224 .40985 m .77032 .41176 L .77024 .41657 L p F P
0 g
s
.517 .437 .704 r
.57127 .34697 m .57901 .34163 L p .57691 .35197 L F P
0 g
s
.517 .437 .704 r
.57691 .35197 m .57235 .35104 L .57127 .34697 L p F P
0 g
s
.449 .357 .66 r
.57048 .29827 m .57647 .29315 L p .57309 .30395 L F P
0 g
s
.449 .357 .66 r
.57309 .30395 m .57142 .30286 L .57048 .29827 L p F P
0 g
s
.427 .336 .65 r
.57048 .29827 m .57647 .29315 L .57187 .28943 L p F P
0 g
s
.428 .419 .747 r
.77082 .32414 m .76752 .32253 L .76945 .32002 L closepath p F P
0 g
s
.442 .438 .76 r
.76776 .31519 m .76456 .31383 L p .76752 .32253 L F P
0 g
s
.442 .438 .76 r
.76752 .32253 m .76945 .32002 L .76776 .31519 L p F P
0 g
s
0 0 .073 r
.76242 .42781 m .76887 .42178 L p .76044 .43266 L F P
0 g
s
0 0 .073 r
.76044 .43266 m .76103 .43034 L .76242 .42781 L p F P
0 g
s
.086 0 .271 r
.77 .41904 m .77024 .41657 L p .76242 .42781 L F P
0 g
s
.086 0 .271 r
.76242 .42781 m .76887 .42178 L .77 .41904 L p F P
0 g
s
.815 .961 .905 r
.60469 .20864 m .60179 .21053 L .59891 .21008 L p F P
0 g
s
.805 .713 .763 r
.20549 .41158 m .20514 .41107 L .20493 .4113 L closepath p F P
0 g
s
.575 .533 .771 r
.59444 .41967 m .59597 .41878 L p .60215 .42649 L F P
0 g
s
.569 .529 .771 r
.59444 .41967 m .59413 .41887 L .59597 .41878 L closepath p F P
0 g
s
.583 .57 .805 r
.62683 .43919 m .62984 .44565 L .61806 .44707 L p F P
0 g
s
.583 .57 .805 r
.62178 .43971 m .62683 .43919 L p .61806 .44707 L F P
0 g
s
.583 .57 .805 r
.61806 .44707 m .61624 .44303 L .62178 .43971 L p F P
0 g
s
.527 .578 .849 r
.69873 .23498 m .71037 .23529 L .70722 .24082 L p F P
0 g
s
.528 .581 .852 r
.71037 .23529 m .69873 .23498 L .69721 .23204 L p F P
0 g
s
.569 .522 .763 r
.59597 .41878 m .59413 .41887 L .59115 .4108 L p F P
0 g
s
.904 .718 .64 r
.22294 .28168 m .22311 .28118 L .21967 .27614 L p F P
0 g
s
.626 .958 .907 r
.72863 .45974 m .7265 .461 L .72388 .46031 L p F P
0 g
s
.642 .942 .959 r
.7121 .46575 m .72388 .46031 L .7265 .461 L p F P
0 g
s
.675 .147 0 r
.05329 .45105 m .0492 .44788 L .04565 .44385 L p F P
0 g
s
.664 .138 0 r
.04162 .44066 m .04565 .44385 L .0492 .44788 L p F P
0 g
s
.439 .696 .974 r
.08789 .4681 m .08916 .46812 L .08539 .46506 L p F P
0 g
s
.439 .696 .974 r
.08539 .46506 m .08357 .46505 L .08789 .4681 L p F P
0 g
s
.515 .441 .711 r
.57328 .35441 m .57235 .35104 L .57691 .35197 L closepath p F P
0 g
s
.867 .714 .69 r
.22401 .33143 m .22455 .33036 L .22232 .32881 L closepath p F P
0 g
s
.87 .711 .682 r
.2206 .32608 m .22298 .32114 L p .22455 .33036 L F P
0 g
s
.87 .711 .682 r
.22455 .33036 m .22232 .32881 L .2206 .32608 L p F P
0 g
s
.486 .513 .81 r
.74048 .27386 m .73923 .27363 L .73993 .27257 L closepath p F P
0 g
s
.497 .527 .818 r
.73923 .27363 m .73993 .27257 L .73756 .26724 L p F P
0 g
s
.807 .716 .764 r
.20493 .4113 m .20514 .41107 L .20167 .40621 L p F P
0 g
s
.807 .716 .764 r
.20167 .40621 m .19963 .40855 L .20493 .4113 L p F P
0 g
s
.814 .724 .765 r
.19963 .40855 m .20493 .4113 L .19842 .41865 L p F P
0 g
s
.904 .718 .64 r
.21967 .27614 m .21891 .27833 L .22294 .28168 L p F P
0 g
s
.9 .724 .655 r
.21891 .27833 m .22294 .28168 L .22066 .28752 L p F P
0 g
s
.342 .244 .598 r
.5769 .26316 m .57463 .26547 L .57549 .27153 L p F P
0 g
s
0 0 0 r
.58855 .22433 m .58961 .22282 L .59031 .22166 L closepath p F P
0 g
s
.819 .712 .747 r
.21079 .39448 m .2135 .39102 L .21006 .38594 L p F P
0 g
s
.312 .233 .604 r
.77696 .38691 m .7808 .38265 L .7784 .37796 L p F P
0 g
s
.279 .186 .567 r
.7808 .38265 m .77696 .38691 L .77776 .39278 L p F P
0 g
s
.304 .204 .572 r
.77723 .39333 m .77776 .39278 L .77696 .38691 L p F P
0 g
s
.765 .749 .838 r
.15471 .459 m .14766 .46397 L .14403 .4603 L p F P
0 g
s
.882 .719 .674 r
.21981 .30267 m .22412 .30589 L .2214 .31191 L p F P
0 g
s
.883 .715 .669 r
.22412 .30589 m .21981 .30267 L .2224 .29671 L p F P
0 g
s
.815 .961 .905 r
.59891 .21008 m .60796 .20291 L .60469 .20864 L p F P
0 g
s
.747 .845 .924 r
.61048 .20127 m .60796 .20291 L .60469 .20864 L p F P
0 g
s
.747 .845 .924 r
.60469 .20864 m .61339 .20378 L .61048 .20127 L p F P
0 g
s
.626 .958 .907 r
.73594 .454 m .72863 .45974 L p .72388 .46031 L F P
0 g
s
.623 .959 .837 r
.72863 .45974 m .73594 .454 L .73817 .45363 L closepath p F P
0 g
s
.516 .444 .713 r
.57539 .36196 m .57328 .35441 L .57691 .35197 L p F P
0 g
s
.537 .452 .707 r
.57328 .35441 m .57539 .36196 L .57489 .36226 L p F P
0 g
s
.437 .436 .76 r
.76776 .31519 m .76456 .31383 L .76641 .31134 L closepath p F P
0 g
s
.451 .455 .772 r
.76473 .30677 m .76089 .30535 L p .76456 .31383 L F P
0 g
s
.451 .455 .772 r
.76456 .31383 m .76641 .31134 L .76473 .30677 L p F P
0 g
s
.609 .659 .873 r
.66535 .46349 m .65353 .4659 L .65059 .46097 L p F P
0 g
s
.855 .713 .705 r
.22104 .33666 m .22401 .33143 L .22232 .32881 L p F P
0 g
s
0 0 0 r
.74975 .44428 m .75226 .44178 L .75037 .44343 L closepath p F P
0 g
s
0 0 0 r
.75037 .44343 m .75226 .44178 L .75835 .43449 L p F P
0 g
s
0 0 .113 r
.75835 .43449 m .76044 .43266 L .76103 .43034 L closepath p F P
0 g
s
.523 .57 .844 r
.70722 .24082 m .71372 .24115 L .71081 .23531 L p F P
0 g
s
.523 .57 .844 r
.71081 .23531 m .71037 .23529 L .70722 .24082 L p F P
0 g
s
.422 .336 .654 r
.57771 .28425 m .57187 .28943 L .57647 .29315 L p F P
0 g
s
.425 .324 .636 r
.57682 .27949 m .57771 .28425 L .57187 .28943 L p F P
0 g
s
.425 .324 .636 r
.57578 .27844 m .57682 .27949 L p .57187 .28943 L F P
0 g
s
.538 .46 .715 r
.57549 .36232 m .57489 .36226 L .57539 .36196 L closepath p F P
0 g
s
.855 .715 .707 r
.2174 .34302 m .22214 .34604 L .21841 .35243 L p F P
0 g
s
.853 .711 .705 r
.22214 .34604 m .2174 .34302 L .22104 .33666 L p F P
0 g
s
.472 .498 .804 r
.74918 .2757 m .74573 .28121 L .75514 .28349 L p F P
0 g
s
.471 .493 .799 r
.74573 .28121 m .75514 .28349 L .75146 .28904 L p F P
0 g
s
.478 .507 .809 r
.74048 .27386 m .74918 .2757 L .74573 .28121 L p F P
0 g
s
.562 .517 .763 r
.59115 .4108 m .59105 .41052 L .59163 .41051 L closepath p F P
0 g
s
.569 .522 .763 r
.59115 .4108 m .59163 .41051 L p .59597 .41878 L F P
0 g
s
.563 .511 .755 r
.59163 .41051 m .59105 .41052 L .5881 .40218 L p F P
0 g
s
.578 .74 .953 r
.08916 .46812 m .09983 .46616 L .10357 .46934 L p F P
0 g
s
.586 .741 .95 r
.09983 .46616 m .08916 .46812 L .08539 .46506 L p F P
0 g
s
.601 .607 .83 r
.64407 .45631 m .63583 .4576 L .63284 .45178 L p F P
0 g
s
.444 .358 .665 r
.57186 .30496 m .57142 .30286 L .57309 .30395 L closepath p F P
0 g
s
.179 .049 .455 r
.58 .24723 m .58132 .2457 L .5812 .24056 L p F P
0 g
s
.151 .028 .446 r
.58507 .23579 m .5812 .24056 L .58132 .2457 L p F P
0 g
s
.05 0 .333 r
.5812 .24056 m .58507 .23579 L .58606 .23031 L p F P
0 g
s
0 0 .031 r
.58961 .22282 m .58855 .22433 L .58606 .23031 L p F P
0 g
s
.446 .452 .772 r
.76473 .30677 m .76089 .30535 L .76308 .30228 L closepath p F P
0 g
s
.459 .47 .783 r
.76173 .29876 m .75652 .29709 L p .76089 .30535 L F P
0 g
s
.459 .47 .783 r
.76089 .30535 m .76308 .30228 L .76173 .29876 L p F P
0 g
s
.827 .72 .746 r
.20565 .39165 m .21079 .39448 L .20533 .40147 L p F P
0 g
s
.819 .712 .747 r
.21006 .38594 m .20565 .39165 L .21079 .39448 L p F P
0 g
s
.575 .533 .771 r
.59597 .41878 m .60588 .41826 L p .60215 .42649 L F P
0 g
s
.57 .529 .77 r
.60588 .41826 m .59597 .41878 L .60426 .41401 L closepath p F P
0 g
s
.569 .522 .763 r
.60281 .4102 m .60426 .41401 L .59597 .41878 L p F P
0 g
s
.569 .522 .763 r
.59163 .41051 m .60281 .4102 L p .59597 .41878 L F P
0 g
s
.476 .507 .811 r
.74918 .2757 m .74048 .27386 L .73993 .27257 L p F P
0 g
s
.583 .57 .804 r
.61624 .44303 m .61504 .44037 L .62178 .43971 L closepath p F P
0 g
s
.548 .606 .863 r
.68486 .22425 m .69293 .22404 L .69003 .21867 L p F P
0 g
s
.548 .606 .863 r
.69003 .21867 m .68772 .21875 L .68486 .22425 L p F P
0 g
s
.549 .611 .867 r
.67804 .21923 m .68772 .21875 L .68486 .22425 L p F P
0 g
s
.464 .479 .79 r
.75146 .28904 m .75875 .29107 L p .75652 .29709 L F P
0 g
s
.461 .481 .792 r
.75146 .28904 m .75875 .29107 L .75578 .28367 L p F P
0 g
s
.461 .481 .792 r
.75578 .28367 m .75514 .28349 L .75146 .28904 L p F P
0 g
s
.527 .453 .716 r
.57539 .36196 m .58482 .35574 L p .58651 .36391 L F P
0 g
s
.527 .453 .716 r
.58651 .36391 m .57549 .36232 L .57539 .36196 L p F P
0 g
s
.516 .444 .713 r
.58412 .35335 m .58482 .35574 L .57539 .36196 L p F P
0 g
s
.516 .444 .713 r
.57691 .35197 m .58412 .35335 L p .57539 .36196 L F P
0 g
s
.526 .458 .723 r
.57768 .36971 m .57549 .36232 L .58651 .36391 L closepath p F P
0 g
s
.815 .723 .763 r
.19842 .41865 m .19344 .42437 L .18994 .41981 L p F P
0 g
s
.815 .723 .763 r
.18994 .41981 m .19334 .41582 L .19842 .41865 L p F P
0 g
s
.814 .724 .765 r
.19842 .41865 m .19334 .41582 L .19963 .40855 L p F P
0 g
s
.49 0 0 r
.05329 .45105 m .05361 .45133 L .04976 .44836 L p F P
0 g
s
.49 0 0 r
.04976 .44836 m .0492 .44788 L .05329 .45105 L p F P
0 g
s
.454 .468 .783 r
.76173 .29876 m .75652 .29709 L .75945 .29283 L closepath p F P
0 g
s
.464 .479 .79 r
.75875 .29107 m .75945 .29283 L .75652 .29709 L p F P
0 g
s
.564 .518 .763 r
.60281 .4102 m .59163 .41051 L .60092 .40506 L closepath p F P
0 g
s
.563 .511 .755 r
.59972 .40177 m .60092 .40506 L .59163 .41051 L p F P
0 g
s
.563 .511 .755 r
.58877 .40178 m .59972 .40177 L p .59163 .41051 L F P
0 g
s
.563 .511 .755 r
.5881 .40218 m .58877 .40178 L p .59163 .41051 L F P
0 g
s
.376 .334 .683 r
.7804 .35672 m .77715 .35375 L .77907 .35148 L closepath p F P
0 g
s
.394 .359 .701 r
.7771 .34432 m .77695 .3442 L p .77715 .35375 L F P
0 g
s
.394 .359 .701 r
.77715 .35375 m .77907 .35148 L .7771 .34432 L p F P
0 g
s
.849 .714 .714 r
.21862 .36315 m .21942 .36183 L .21655 .36002 L closepath p F P
0 g
s
.851 .712 .708 r
.21519 .35793 m .21841 .35243 L p .21942 .36183 L F P
0 g
s
.851 .712 .708 r
.21942 .36183 m .21655 .36002 L .21519 .35793 L p F P
0 g
s
.84 .717 .728 r
.21052 .37512 m .21547 .37804 L .2109 .38473 L p F P
0 g
s
.837 .713 .728 r
.21547 .37804 m .21052 .37512 L .21502 .36846 L p F P
0 g
s
.919 .724 .623 r
.22073 .27265 m .21967 .27614 L .21618 .27171 L p F P
0 g
s
.919 .724 .623 r
.21618 .27171 m .21695 .26919 L .22073 .27265 L p F P
0 g
s
.924 .717 .605 r
.22073 .27265 m .21695 .26919 L .21841 .26365 L p F P
0 g
s
.312 .234 .605 r
.78353 .37221 m .7784 .37796 L .7808 .38265 L p F P
0 g
s
.34 .274 .636 r
.7784 .37796 m .78353 .37221 L .78038 .36776 L p F P
0 g
s
.765 .749 .838 r
.14403 .4603 m .14973 .45618 L .15471 .459 L p F P
0 g
s
.758 .746 .841 r
.15534 .4522 m .14973 .45618 L .15471 .459 L p F P
0 g
s
.758 .746 .841 r
.15471 .459 m .15894 .45607 L .15534 .4522 L p F P
0 g
s
.476 .507 .811 r
.73993 .27257 m .74255 .26814 L p .74918 .2757 L F P
0 g
s
.484 .52 .819 r
.73993 .27257 m .73756 .26724 L .74255 .26814 L closepath p F P
0 g
s
.528 .581 .852 r
.69721 .23204 m .69851 .22946 L p .71037 .23529 L F P
0 g
s
.533 .59 .857 r
.69721 .23204 m .69583 .22944 L .69851 .22946 L closepath p F P
0 g
s
.451 .369 .673 r
.57309 .30395 m .57186 .30496 L .57339 .31184 L p F P
0 g
s
.556 .506 .755 r
.5881 .40218 m .58796 .40178 L .58877 .40178 L closepath p F P
0 g
s
.874 .717 .683 r
.22298 .32114 m .2206 .32608 L .21716 .32094 L p F P
0 g
s
.874 .717 .683 r
.21716 .32094 m .21859 .31796 L .22298 .32114 L p F P
0 g
s
.876 .715 .678 r
.22298 .32114 m .21859 .31796 L .2214 .31191 L p F P
0 g
s
.581 .545 .779 r
.60215 .42649 m .60895 .42597 L p .61066 .43349 L F P
0 g
s
.576 .541 .778 r
.60895 .42597 m .60215 .42649 L .60787 .42326 L closepath p F P
0 g
s
.575 .533 .771 r
.60588 .41826 m .60787 .42326 L .60215 .42649 L p F P
0 g
s
.556 .499 .747 r
.58877 .40178 m .58796 .40178 L .58526 .3938 L p F P
0 g
s
.535 .465 .723 r
.57768 .36971 m .58651 .36391 L p .58612 .3737 L F P
0 g
s
.535 .465 .723 r
.58612 .3737 m .57862 .37291 L .57768 .36971 L p F P
0 g
s
0 .339 .773 r
.05361 .45133 m .05951 .45422 L .0637 .45735 L p F P
0 g
s
0 .359 .794 r
.05951 .45422 m .05361 .45133 L .04976 .44836 L p F P
0 g
s
.506 .549 .834 r
.71716 .24811 m .71773 .24709 L p .72687 .25382 L F P
0 g
s
.512 .559 .841 r
.71716 .24811 m .71662 .247 L .71773 .24709 L closepath p F P
0 g
s
0 0 0 r
.76044 .43266 m .75835 .43449 L .75226 .44178 L p F P
0 g
s
.89 .723 .669 r
.21823 .29342 m .2224 .29671 L .21981 .30267 L p F P
0 g
s
.891 .719 .663 r
.2224 .29671 m .21823 .29342 L .22066 .28752 L p F P
0 g
s
.66 .853 .974 r
.7115 .46534 m .70935 .46688 L p .69756 .46801 L F P
0 g
s
.682 .872 .97 r
.70935 .46688 m .7115 .46534 L .7121 .46575 L closepath p F P
0 g
s
.836 .713 .728 r
.21502 .36846 m .21862 .36315 L .21655 .36002 L p F P
0 g
s
.534 .47 .731 r
.58007 .37759 m .57862 .37291 L .58612 .3737 L closepath p F P
0 g
s
.745 .763 .867 r
.13286 .46702 m .13337 .46671 L .13068 .46494 L closepath p F P
0 g
s
.709 .756 .888 r
.13068 .46494 m .13286 .46702 L p .11816 .46886 L F P
0 g
s
.556 .499 .747 r
.58526 .3938 m .58706 .39269 L p .58877 .40178 L F P
0 g
s
.549 .494 .747 r
.58526 .3938 m .58486 .39261 L .58706 .39269 L closepath p F P
0 g
s
.542 .476 .731 r
.58007 .37759 m .58612 .3737 L p .58625 .38331 L F P
0 g
s
.542 .476 .731 r
.58625 .38331 m .58175 .383 L .58007 .37759 L p F P
0 g
s
.583 .561 .795 r
.62178 .43971 m .61504 .44037 L .612 .43336 L p F P
0 g
s
.549 .488 .739 r
.58706 .39269 m .58486 .39261 L .58259 .38561 L p F P
0 g
s
.748 .762 .865 r
.14039 .45663 m .14403 .4603 L .13337 .46671 L p F P
0 g
s
.748 .762 .865 r
.12919 .46353 m .14039 .45663 L p .13337 .46671 L F P
0 g
s
.748 .762 .865 r
.13337 .46671 m .13068 .46494 L .12919 .46353 L p F P
0 g
s
.552 .616 .87 r
.68772 .21875 m .67804 .21923 L .67514 .21411 L p F P
0 g
s
.541 .482 .739 r
.58259 .38561 m .58175 .383 L .58625 .38331 L closepath p F P
0 g
s
.549 .488 .739 r
.58259 .38561 m .58625 .38331 L p .58706 .39269 L F P
0 g
s
.799 .725 .782 r
.19181 .42602 m .19344 .42437 L .18994 .41981 L p F P
0 g
s
.557 .507 .755 r
.59972 .40177 m .58877 .40178 L .59781 .39636 L closepath p F P
0 g
s
.556 .499 .747 r
.59662 .39296 m .59781 .39636 L .58877 .40178 L p F P
0 g
s
.556 .499 .747 r
.58706 .39269 m .59662 .39296 L p .58877 .40178 L F P
0 g
s
.855 .713 .705 r
.22232 .32881 m .21994 .32727 L p .22104 .33666 L F P
0 g
s
.857 .71 .698 r
.22232 .32881 m .2206 .32608 L .21994 .32727 L closepath p F P
0 g
s
.696 .982 .835 r
.73594 .454 m .73817 .45363 L .74304 .45 L p F P
0 g
s
.571 .639 .88 r
.66032 .21046 m .67223 .2091 L p .67132 .21446 L F P
0 g
s
.579 .643 .878 r
.67223 .2091 m .66032 .21046 L .65741 .20571 L p F P
0 g
s
.782 .742 .816 r
.1664 .44998 m .15894 .45607 L .15534 .4522 L p F P
0 g
s
.159 0 .391 r
.77024 .41657 m .77119 .41562 L .77224 .40985 L p F P
0 g
s
.147 0 .383 r
.77809 .40396 m .77224 .40985 L .77119 .41562 L p F P
0 g
s
.219 .079 .467 r
.77224 .40985 m .77809 .40396 L .77813 .39849 L p F P
0 g
s
.511 .561 .843 r
.71773 .24709 m .71662 .247 L .71372 .24115 L p F P
0 g
s
.808 .734 .782 r
.18661 .42325 m .19181 .42602 L .18432 .43369 L p F P
0 g
s
.799 .725 .782 r
.18994 .41981 m .18661 .42325 L .19181 .42602 L p F P
0 g
s
.639 .703 .893 r
.62799 .20249 m .63975 .19919 L .64266 .2034 L p F P
0 g
s
.653 .718 .896 r
.63975 .19919 m .62799 .20249 L .62507 .19886 L p F P
0 g
s
.692 .757 .901 r
.61339 .20378 m .62507 .19886 L .62799 .20249 L p F P
0 g
s
.662 .755 .919 r
.10357 .46934 m .11445 .46553 L .11816 .46886 L p F P
0 g
s
.667 .756 .917 r
.11445 .46553 m .10357 .46934 L .09983 .46616 L p F P
0 g
s
.63 .724 .915 r
.66824 .46779 m .68008 .46492 L .68293 .46857 L p F P
0 g
s
.622 .683 .887 r
.67721 .46091 m .68008 .46492 L .66824 .46779 L p F P
0 g
s
.622 .683 .887 r
.66717 .4631 m .67721 .46091 L p .66824 .46779 L F P
0 g
s
.622 .683 .887 r
.66824 .46779 m .66574 .46407 L .66717 .4631 L p F P
0 g
s
.495 .414 .694 r
.5778 .3301 m .57307 .32857 L .57676 .32595 L closepath p F P
0 g
s
.496 .405 .683 r
.575 .31881 m .57676 .32595 L .57307 .32857 L p F P
0 g
s
.859 .718 .705 r
.2164 .33359 m .22104 .33666 L .2174 .34302 L p F P
0 g
s
.855 .713 .705 r
.21994 .32727 m .2164 .33359 L .22104 .33666 L p F P
0 g
s
.931 .726 .604 r
.21477 .26013 m .21841 .26365 L .21695 .26919 L p F P
0 g
s
.937 .717 .581 r
.21841 .26365 m .21477 .26013 L .21596 .2547 L p F P
0 g
s
.827 .72 .746 r
.20533 .40147 m .20167 .40621 L .19819 .40144 L p F P
0 g
s
.827 .72 .746 r
.19819 .40144 m .20036 .39859 L .20533 .40147 L p F P
0 g
s
.827 .72 .746 r
.20533 .40147 m .20036 .39859 L .20565 .39165 L p F P
0 g
s
.367 .671 .974 r
.0712 .46152 m .0793 .46198 L .08357 .46505 L p F P
0 g
s
.385 .676 .974 r
.0793 .46198 m .0712 .46152 L .06739 .45853 L p F P
0 g
s
.264 .147 .527 r
.77776 .39278 m .77723 .39333 L .77813 .39849 L p F P
0 g
s
.709 .756 .888 r
.11816 .46886 m .12853 .46385 L .13068 .46494 L p F P
0 g
s
.714 .758 .887 r
.12853 .46385 m .11816 .46886 L .11445 .46553 L p F P
0 g
s
.719 .782 .902 r
.62507 .19886 m .61339 .20378 L .61048 .20127 L p F P
0 g
s
.708 .878 .961 r
.7115 .46534 m .7121 .46575 L .72388 .46031 L p F P
0 g
s
0 0 0 r
.74304 .45 m .74815 .44576 L .74975 .44428 L closepath p F P
0 g
s
.696 .982 .835 r
.74304 .45 m .74815 .44576 L p .73594 .454 L F P
0 g
s
.782 .742 .816 r
.15534 .4522 m .16137 .44717 L .1664 .44998 L p F P
0 g
s
.776 .74 .82 r
.16677 .44275 m .16137 .44717 L .1664 .44998 L p F P
0 g
s
.776 .74 .82 r
.1664 .44998 m .17034 .44683 L .16677 .44275 L p F P
0 g
s
.406 .393 .733 r
.77223 .32836 m .77408 .32583 L p .77586 .33491 L F P
0 g
s
.406 .393 .733 r
.77586 .33491 m .77393 .33376 L .77223 .32836 L p F P
0 g
s
.416 .412 .746 r
.77223 .32836 m .77082 .32414 L .77408 .32583 L closepath p F P
0 g
s
.238 .128 .52 r
.58132 .2457 m .58 .24723 L .58103 .25206 L p F P
0 g
s
.406 .393 .733 r
.77475 .33638 m .77393 .33376 L .77586 .33491 L closepath p F P
0 g
s
.809 .733 .781 r
.18432 .43369 m .18184 .43627 L .1783 .43198 L p F P
0 g
s
.809 .733 .781 r
.1783 .43198 m .17938 .43084 L .18432 .43369 L p F P
0 g
s
.808 .734 .782 r
.18432 .43369 m .17938 .43084 L .18661 .42325 L p F P
0 g
s
.358 .268 .616 r
.57944 .26751 m .57549 .27153 L .57651 .27777 L p F P
0 g
s
.342 .244 .598 r
.57549 .27153 m .57944 .26751 L .5769 .26316 L p F P
0 g
s
.386 .288 .62 r
.57578 .27844 m .57651 .27777 L .57549 .27153 L p F P
0 g
s
.596 .661 .884 r
.65741 .20571 m .65177 .20666 L .65472 .20142 L closepath p F P
0 g
s
.597 .677 .897 r
.6545 .20107 m .65472 .20142 L .65177 .20666 L p F P
0 g
s
.597 .677 .897 r
.64266 .2034 m .6545 .20107 L p .65177 .20666 L F P
0 g
s
.451 .369 .673 r
.57339 .31184 m .57884 .30733 L .57309 .30395 L p F P
0 g
s
.448 .37 .676 r
.58048 .29764 m .57309 .30395 L .57884 .30733 L p F P
0 g
s
.449 .357 .66 r
.58007 .29578 m .58048 .29764 L .57309 .30395 L p F P
0 g
s
.449 .357 .66 r
.57647 .29315 m .58007 .29578 L p .57309 .30395 L F P
0 g
s
.389 .371 .718 r
.77586 .33491 m .77475 .33638 L .77704 .34409 L p F P
0 g
s
.407 .382 .719 r
.77695 .3442 m .77704 .34409 L .77475 .33638 L p F P
0 g
s
.53 .842 .533 r
.74815 .44576 m .74975 .44428 L .75226 .44178 L p F P
0 g
s
.53 .842 .533 r
.75226 .44178 m .759 .43587 L p .74815 .44576 L F P
0 g
s
0 0 0 r
.75226 .44178 m .759 .43587 L .76044 .43266 L p F P
0 g
s
.416 .412 .747 r
.77408 .32583 m .77082 .32414 L .76945 .32002 L p F P
0 g
s
0 0 .026 r
.59279 .21829 m .58961 .22282 L .58865 .22661 L p F P
0 g
s
0 0 .021 r
.59279 .21829 m .59028 .22429 L p .5941 .21643 L F P
0 g
s
0 0 0 r
.5975 .21157 m .59279 .21829 L p .59172 .21981 L F P
0 g
s
.622 .79 .35 r
.59824 .21022 m .5975 .21157 L .59279 .21829 L p F P
0 g
s
.622 .79 .35 r
.5961 .21236 m .59824 .21022 L p .59279 .21829 L F P
0 g
s
.622 .79 .35 r
.59279 .21829 m .59597 .21259 L .5961 .21236 L p F P
0 g
s
0 0 .021 r
.59597 .21259 m .59279 .21829 L p .5941 .21643 L F P
0 g
s
0 0 0 r
.59279 .21829 m .58961 .22282 L p .59172 .21981 L F P
0 g
s
0 0 .031 r
.58606 .23031 m .58865 .22661 L .58961 .22282 L p F P
0 g
s
.506 .549 .834 r
.71773 .24709 m .72881 .24819 L p .72687 .25382 L F P
0 g
s
.505 .553 .839 r
.71773 .24709 m .72881 .24819 L .7259 .24218 L p F P
0 g
s
.505 .553 .839 r
.7259 .24218 m .7206 .24167 L .71773 .24709 L p F P
0 g
s
.511 .561 .843 r
.71372 .24115 m .7206 .24167 L .71773 .24709 L p F P
0 g
s
.532 .592 .86 r
.69851 .22946 m .69583 .22944 L .69293 .22404 L p F P
0 g
s
.796 .737 .798 r
.17591 .44166 m .17034 .44683 L .16677 .44275 L p F P
0 g
s
.796 .737 .798 r
.16677 .44275 m .17091 .43883 L .17591 .44166 L p F P
0 g
s
.789 .733 .8 r
.1783 .43198 m .17091 .43883 L .17591 .44166 L p F P
0 g
s
.789 .733 .8 r
.17591 .44166 m .18184 .43627 L .1783 .43198 L p F P
0 g
s
.416 .412 .747 r
.76945 .32002 m .77162 .31695 L p .77408 .32583 L F P
0 g
s
.426 .429 .759 r
.76945 .32002 m .76776 .31519 L .77162 .31695 L closepath p F P
0 g
s
.882 .722 .678 r
.21713 .30867 m .2214 .31191 L .21859 .31796 L p F P
0 g
s
.882 .719 .674 r
.2214 .31191 m .21713 .30867 L .21981 .30267 L p F P
0 g
s
.854 .715 .708 r
.21841 .35243 m .21519 .35793 L .21175 .35285 L p F P
0 g
s
.854 .715 .708 r
.21175 .35285 m .21375 .34939 L .21841 .35243 L p F P
0 g
s
.855 .715 .707 r
.21841 .35243 m .21375 .34939 L .2174 .34302 L p F P
0 g
s
.582 .552 .786 r
.612 .43336 m .61066 .43349 L .61179 .43286 L closepath p F P
0 g
s
.581 .545 .779 r
.60895 .42597 m .61179 .43286 L .61066 .43349 L p F P
0 g
s
.898 .728 .663 r
.21665 .28416 m .22066 .28752 L .21823 .29342 L p F P
0 g
s
.9 .724 .655 r
.22066 .28752 m .21665 .28416 L .21891 .27833 L p F P
0 g
s
.469 .385 .678 r
.57339 .31184 m .57884 .30733 L p .57612 .31791 L F P
0 g
s
.469 .385 .678 r
.57612 .31791 m .57462 .31718 L .57339 .31184 L p F P
0 g
s
.326 .238 .601 r
.58244 .25707 m .5769 .26316 L .57944 .26751 L p F P
0 g
s
.296 .197 .57 r
.58222 .25518 m .58103 .25206 L p .5769 .26316 L F P
0 g
s
.296 .197 .57 r
.5769 .26316 m .58244 .25707 L .58222 .25518 L p F P
0 g
s
.568 .627 .871 r
.67514 .21411 m .67132 .21446 L .67327 .21087 L closepath p F P
0 g
s
.571 .639 .88 r
.67223 .2091 m .67327 .21087 L .67132 .21446 L p F P
0 g
s
.388 .356 .701 r
.7771 .34432 m .77695 .3442 L .77704 .34409 L closepath p F P
0 g
s
.84 .717 .728 r
.2066 .38097 m .21052 .37512 L p .2109 .38473 L F P
0 g
s
.84 .717 .728 r
.2109 .38473 m .20796 .38294 L .2066 .38097 L p F P
0 g
s
.838 .719 .733 r
.21006 .38594 m .2109 .38473 L .20796 .38294 L closepath p F P
0 g
s
.843 .719 .727 r
.21014 .36551 m .21502 .36846 L .21052 .37512 L p F P
0 g
s
.836 .713 .728 r
.21458 .35886 m .21014 .36551 L .21502 .36846 L p F P
0 g
s
.836 .713 .728 r
.21655 .36002 m .21458 .35886 L p .21502 .36846 L F P
0 g
s
.236 .127 .52 r
.78247 .38758 m .77776 .39278 L .7783 .39832 L p F P
0 g
s
.279 .186 .567 r
.77776 .39278 m .78247 .38758 L .7808 .38265 L p F P
0 g
s
.264 .147 .527 r
.77813 .39849 m .7783 .39832 L .77776 .39278 L p F P
0 g
s
.911 .728 .641 r
.21891 .27833 m .21967 .27614 L .21618 .27171 L p F P
0 g
s
.375 .347 .7 r
.77704 .34409 m .78118 .33863 L p .7817 .34811 L F P
0 g
s
.375 .347 .7 r
.7817 .34811 m .7771 .34432 L .77704 .34409 L p F P
0 g
s
.389 .371 .718 r
.77704 .34409 m .78118 .33863 L .77586 .33491 L p F P
0 g
s
.483 .52 .819 r
.74255 .26814 m .73756 .26724 L .73494 .26136 L p F P
0 g
s
.375 .347 .699 r
.77907 .35148 m .7771 .34432 L .7817 .34811 L closepath p F P
0 g
s
.904 .494 .183 r
.03515 .43307 m .03126 .4298 L .02965 .42516 L p F P
0 g
s
.426 .429 .759 r
.77162 .31695 m .76776 .31519 L .76641 .31134 L p F P
0 g
s
.55 .496 .747 r
.59662 .39296 m .58706 .39269 L .5949 .38788 L closepath p F P
0 g
s
.549 .488 .739 r
.59351 .38375 m .5949 .38788 L .58706 .39269 L p F P
0 g
s
.549 .488 .739 r
.58625 .38331 m .59351 .38375 L p .58706 .39269 L F P
0 g
s
.635 .748 .93 r
.69477 .46512 m .68293 .46857 L .68008 .46492 L p F P
0 g
s
.644 .78 .946 r
.68293 .46857 m .69477 .46512 L .69756 .46801 L p F P
0 g
s
.614 .68 .889 r
.6545 .20107 m .64266 .2034 L .63975 .19919 L p F P
0 g
s
.812 .72 .764 r
.19963 .40855 m .20167 .40621 L .19819 .40144 L p F P
0 g
s
.824 .717 .747 r
.20565 .39165 m .21006 .38594 L .20796 .38294 L p F P
0 g
s
.517 .445 .714 r
.58412 .35335 m .57691 .35197 L .58264 .3481 L closepath p F P
0 g
s
.517 .437 .704 r
.58096 .3421 m .58264 .3481 L .57691 .35197 L p F P
0 g
s
.517 .437 .704 r
.57901 .34163 m .58096 .3421 L p .57691 .35197 L F P
0 g
s
.824 .35 0 r
.04162 .44066 m .03765 .43742 L .03515 .43307 L p F P
0 g
s
.821 .346 0 r
.03126 .4298 m .03515 .43307 L .03765 .43742 L p F P
0 g
s
0 0 .29 r
.58865 .22661 m .58606 .23031 L .58507 .23579 L p F P
0 g
s
.601 .607 .83 r
.63284 .45178 m .64467 .45016 L p .64407 .45631 L F P
0 g
s
.588 .59 .822 r
.64168 .44429 m .64467 .45016 L .63284 .45178 L p F P
0 g
s
.588 .59 .822 r
.63635 .44491 m .64168 .44429 L p .63284 .45178 L F P
0 g
s
.588 .59 .822 r
.63284 .45178 m .63111 .44823 L .63635 .44491 L p F P
0 g
s
.862 .717 .701 r
.21994 .32727 m .2206 .32608 L .21716 .32094 L p F P
0 g
s
.66 .853 .974 r
.69756 .46801 m .70938 .46377 L .7115 .46534 L p F P
0 g
s
.653 .814 .961 r
.70938 .46377 m .69756 .46801 L .69477 .46512 L p F P
0 g
s
.103 .517 .909 r
.0637 .45735 m .06739 .45853 L .06357 .45548 L p F P
0 g
s
.103 .517 .909 r
.06357 .45548 m .05951 .45422 L .0637 .45735 L p F P
0 g
s
.837 .71 .724 r
.21655 .36002 m .21519 .35793 L .21458 .35886 L closepath p F P
0 g
s
.426 .429 .759 r
.76641 .31134 m .7685 .30827 L p .77162 .31695 L F P
0 g
s
.435 .445 .771 r
.76641 .31134 m .76473 .30677 L .7685 .30827 L closepath p F P
0 g
s
.583 .561 .795 r
.612 .43336 m .6238 .43241 L p .62178 .43971 L F P
0 g
s
.572 .546 .787 r
.62147 .427 m .6238 .43241 L .612 .43336 L p F P
0 g
s
.572 .546 .787 r
.612 .43336 m .61179 .43286 L .62147 .427 L p F P
0 g
s
.609 .659 .873 r
.65059 .46097 m .66243 .45881 L .66535 .46349 L p F P
0 g
s
.602 .642 .863 r
.66243 .45881 m .65059 .46097 L .64764 .45574 L p F P
0 g
s
.683 .86 .966 r
.70938 .46377 m .71828 .46018 L .7115 .46534 L closepath p F P
0 g
s
.708 .878 .961 r
.72122 .45896 m .71828 .46018 L .7115 .46534 L p F P
0 g
s
.708 .878 .961 r
.72388 .46031 m .72122 .45896 L p .7115 .46534 L F P
0 g
s
.812 .72 .764 r
.19819 .40144 m .19453 .40572 L .19963 .40855 L p F P
0 g
s
.82 .728 .764 r
.19453 .40572 m .19963 .40855 L .19334 .41582 L p F P
0 g
s
.57 .545 .787 r
.62075 .42533 m .62147 .427 L .61179 .43286 L p F P
0 g
s
.57 .545 .787 r
.61179 .43286 m .60895 .42597 L .62075 .42533 L p F P
0 g
s
.077 0 .29 r
.77 .41904 m .77119 .41562 L .77024 .41657 L closepath p F P
0 g
s
.864 .721 .704 r
.21542 .32415 m .21994 .32727 L .2164 .33359 L p F P
0 g
s
.862 .717 .701 r
.21716 .32094 m .21542 .32415 L .21994 .32727 L p F P
0 g
s
0 0 0 r
.76492 .42844 m .76044 .43266 L .759 .43587 L p F P
0 g
s
0 0 .073 r
.76887 .42178 m .76492 .42844 L .76044 .43266 L p F P
0 g
s
.336 .273 .637 r
.78244 .36539 m .78038 .36776 L .78353 .37221 L p F P
0 g
s
.359 .305 .661 r
.78038 .36776 m .78244 .36539 L .78088 .35859 L p F P
0 g
s
.465 .387 .684 r
.575 .31881 m .57462 .31718 L .57612 .31791 L closepath p F P
0 g
s
.45 .699 .973 r
.08357 .46505 m .08539 .46506 L .0816 .46196 L p F P
0 g
s
.45 .699 .973 r
.0816 .46196 m .0793 .46198 L .08357 .46505 L p F P
0 g
s
.362 .324 .682 r
.77907 .35148 m .7817 .34811 L p .78152 .3578 L F P
0 g
s
.362 .324 .682 r
.78152 .3578 m .7804 .35672 L .77907 .35148 L p F P
0 g
s
.401 .31 .637 r
.57682 .27949 m .57578 .27844 L .57651 .27777 L closepath p F P
0 g
s
.435 .446 .771 r
.7685 .30827 m .76473 .30677 L .76308 .30228 L p F P
0 g
s
.664 .138 0 r
.0492 .44788 m .04517 .44468 L .04162 .44066 L p F P
0 g
s
.654 .129 0 r
.03765 .43742 m .04162 .44066 L .04517 .44468 L p F P
0 g
s
.707 .756 .89 r
.13068 .46494 m .12919 .46353 L .12853 .46385 L closepath p F P
0 g
s
.889 .726 .674 r
.21567 .29937 m .21981 .30267 L .21713 .30867 L p F P
0 g
s
.89 .723 .669 r
.21981 .30267 m .21567 .29937 L .21823 .29342 L p F P
0 g
s
.907 .733 .655 r
.21506 .27489 m .21891 .27833 L .21665 .28416 L p F P
0 g
s
.911 .728 .641 r
.21618 .27171 m .21506 .27489 L .21891 .27833 L p F P
0 g
s
.769 .752 .838 r
.14973 .45618 m .14403 .4603 L .14039 .45663 L p F P
0 g
s
.469 .394 .69 r
.57612 .31791 m .575 .31881 L .57676 .32595 L p F P
0 g
s
.499 .539 .829 r
.73172 .25442 m .72687 .25382 L .72941 .24945 L closepath p F P
0 g
s
.506 .549 .834 r
.72881 .24819 m .72941 .24945 L .72687 .25382 L p F P
0 g
s
.238 .128 .52 r
.58103 .25206 m .58175 .25122 L .58132 .2457 L p F P
0 g
s
.212 .109 .513 r
.58521 .24091 m .58132 .2457 L .58175 .25122 L p F P
0 g
s
.151 .028 .446 r
.58132 .2457 m .58521 .24091 L .58507 .23579 L p F P
0 g
s
.528 .581 .852 r
.69851 .22946 m .70791 .22969 L p .71037 .23529 L F P
0 g
s
.529 .586 .856 r
.69851 .22946 m .70791 .22969 L .70501 .22411 L p F P
0 g
s
.529 .586 .856 r
.70501 .22411 m .70119 .22404 L .69851 .22946 L p F P
0 g
s
.532 .592 .86 r
.69293 .22404 m .70119 .22404 L .69851 .22946 L p F P
0 g
s
.392 .376 .722 r
.77997 .32935 m .77586 .33491 L .78118 .33863 L p F P
0 g
s
.406 .393 .733 r
.77408 .32583 m .77997 .32935 L .77586 .33491 L p F P
0 g
s
.861 .721 .706 r
.21283 .33993 m .2174 .34302 L .21375 .34939 L p F P
0 g
s
.859 .718 .705 r
.2174 .34302 m .21283 .33993 L .2164 .33359 L p F P
0 g
s
.832 .725 .746 r
.2007 .38875 m .20565 .39165 L .20036 .39859 L p F P
0 g
s
.824 .717 .747 r
.20597 .38182 m .2007 .38875 L .20565 .39165 L p F P
0 g
s
.824 .717 .747 r
.20796 .38294 m .20597 .38182 L p .20565 .39165 L F P
0 g
s
.435 .446 .771 r
.76308 .30228 m .76471 .2998 L p .7685 .30827 L F P
0 g
s
.444 .461 .782 r
.76308 .30228 m .76173 .29876 L .76471 .2998 L closepath p F P
0 g
s
.841 .716 .726 r
.21458 .35886 m .21519 .35793 L .21175 .35285 L p F P
0 g
s
.511 .563 .844 r
.7206 .24167 m .71372 .24115 L .71081 .23531 L p F P
0 g
s
.82 .728 .763 r
.19334 .41582 m .18994 .41981 L .18642 .41532 L p F P
0 g
s
.82 .728 .763 r
.18642 .41532 m .18843 .41294 L .19334 .41582 L p F P
0 g
s
.82 .728 .764 r
.19334 .41582 m .18843 .41294 L .19453 .40572 L p F P
0 g
s
.587 .59 .822 r
.63111 .44823 m .62984 .44565 L .63635 .44491 L closepath p F P
0 g
s
.543 .484 .74 r
.59351 .38375 m .58625 .38331 L .59216 .3796 L closepath p F P
0 g
s
.542 .476 .731 r
.59039 .37411 m .59216 .3796 L .58625 .38331 L p F P
0 g
s
.542 .476 .731 r
.58612 .3737 m .59039 .37411 L p .58625 .38331 L F P
0 g
s
.602 .618 .839 r
.64764 .45574 m .64407 .45631 L .647 .45455 L closepath p F P
0 g
s
.601 .607 .83 r
.64467 .45016 m .647 .45455 L .64407 .45631 L p F P
0 g
s
.394 .305 .636 r
.57651 .27777 m .58246 .27173 L p .57959 .28241 L F P
0 g
s
.394 .305 .636 r
.57959 .28241 m .57682 .27949 L .57651 .27777 L p F P
0 g
s
.358 .268 .616 r
.57651 .27777 m .58246 .27173 L .57944 .26751 L p F P
0 g
s
.842 .719 .727 r
.21052 .37512 m .2066 .38097 L .20313 .37609 L p F P
0 g
s
.842 .719 .727 r
.20313 .37609 m .20575 .37214 L .21052 .37512 L p F P
0 g
s
.843 .719 .727 r
.21052 .37512 m .20575 .37214 L .21014 .36551 L p F P
0 g
s
.841 .716 .726 r
.21175 .35285 m .20977 .35587 L .21458 .35886 L p F P
0 g
s
.845 .721 .727 r
.20977 .35587 m .21458 .35886 L .21014 .36551 L p F P
0 g
s
.362 .325 .682 r
.78088 .35859 m .7804 .35672 L .78152 .3578 L closepath p F P
0 g
s
0 0 .233 r
.77119 .41562 m .777 .40975 L p .76978 .42093 L F P
0 g
s
0 0 .233 r
.76978 .42093 m .77 .41904 L .77119 .41562 L p F P
0 g
s
.147 0 .383 r
.77119 .41562 m .777 .40975 L .77809 .40396 L p F P
0 g
s
.762 .748 .84 r
.15173 .44835 m .14491 .4533 L .14973 .45618 L p F P
0 g
s
.762 .748 .84 r
.14973 .45618 m .15534 .4522 L .15173 .44835 L p F P
0 g
s
.769 .752 .838 r
.14039 .45663 m .14491 .4533 L .14973 .45618 L p F P
0 g
s
.483 .52 .819 r
.73494 .26136 m .73526 .2608 L p .74255 .26814 L F P
0 g
s
.49 .532 .827 r
.73494 .26136 m .73463 .2607 L .73526 .2608 L closepath p F P
0 g
s
.552 .616 .87 r
.67514 .21411 m .68713 .21344 L p .68772 .21875 L F P
0 g
s
.551 .619 .873 r
.68423 .20833 m .68713 .21344 L .67514 .21411 L p F P
0 g
s
.551 .619 .873 r
.67406 .20896 m .68423 .20833 L p .67514 .21411 L F P
0 g
s
.551 .619 .873 r
.67514 .21411 m .67327 .21087 L .67406 .20896 L p F P
0 g
s
.564 .533 .78 r
.6177 .41792 m .62075 .42533 L .60895 .42597 L p F P
0 g
s
.564 .533 .78 r
.61626 .41797 m .6177 .41792 L p .60895 .42597 L F P
0 g
s
.564 .533 .78 r
.60895 .42597 m .60787 .42326 L .61626 .41797 L p F P
0 g
s
.586 .741 .95 r
.08539 .46506 m .09608 .46294 L .09983 .46616 L p F P
0 g
s
.592 .743 .948 r
.09608 .46294 m .08539 .46506 L .0816 .46196 L p F P
0 g
s
.471 0 0 r
.0492 .44788 m .04976 .44836 L .04591 .4453 L p F P
0 g
s
.471 0 0 r
.04591 .4453 m .04517 .44468 L .0492 .44788 L p F P
0 g
s
.444 .461 .783 r
.76471 .2998 m .76173 .29876 L .75945 .29283 L p F P
0 g
s
.825 .715 .743 r
.20796 .38294 m .2066 .38097 L .20597 .38182 L closepath p F P
0 g
s
.338 .291 .658 r
.78152 .3578 m .78088 .35859 L .78244 .36539 L p F P
0 g
s
.622 .682 .886 r
.66574 .46407 m .66535 .46349 L .66717 .4631 L closepath p F P
0 g
s
.489 .533 .829 r
.73526 .2608 m .73463 .2607 L .73172 .25442 L p F P
0 g
s
.584 .569 .803 r
.62683 .43919 m .62178 .43971 L .62596 .43725 L closepath p F P
0 g
s
.583 .561 .795 r
.6238 .43241 m .62596 .43725 L .62178 .43971 L p F P
0 g
s
.88 .724 .684 r
.21859 .31796 m .21716 .32094 L .21369 .3161 L p F P
0 g
s
.88 .724 .684 r
.21369 .3161 m .21435 .31472 L .21859 .31796 L p F P
0 g
s
.882 .722 .678 r
.21859 .31796 m .21435 .31472 L .21713 .30867 L p F P
0 g
s
.803 .728 .782 r
.18661 .42325 m .18994 .41981 L .18642 .41532 L p F P
0 g
s
.469 .394 .69 r
.57676 .32595 m .58296 .32098 L .57612 .31791 L p F P
0 g
s
.467 .396 .693 r
.58374 .31164 m .57612 .31791 L .58296 .32098 L p F P
0 g
s
.469 .385 .678 r
.58328 .30977 m .58374 .31164 L .57612 .31791 L p F P
0 g
s
.469 .385 .678 r
.57884 .30733 m .58328 .30977 L p .57612 .31791 L F P
0 g
s
.387 .304 .64 r
.57771 .28425 m .57682 .27949 L .57959 .28241 L closepath p F P
0 g
s
.925 .732 .623 r
.21695 .26919 m .21618 .27171 L .21263 .26786 L p F P
0 g
s
.925 .732 .623 r
.21263 .26786 m .2133 .26567 L .21695 .26919 L p F P
0 g
s
.931 .726 .604 r
.21695 .26919 m .2133 .26567 L .21477 .26013 L p F P
0 g
s
.579 .643 .878 r
.65741 .20571 m .66933 .20424 L .67223 .2091 L p F P
0 g
s
.578 .653 .887 r
.66642 .19945 m .66933 .20424 L .65741 .20571 L p F P
0 g
s
.578 .653 .887 r
.65488 .20101 m .66642 .19945 L p .65741 .20571 L F P
0 g
s
.578 .653 .887 r
.65741 .20571 m .65472 .20142 L .65488 .20101 L p F P
0 g
s
.485 .407 .694 r
.57676 .32595 m .58296 .32098 L p .58103 .3313 L F P
0 g
s
.485 .407 .694 r
.58103 .3313 m .5778 .3301 L .57676 .32595 L p F P
0 g
s
.896 .731 .669 r
.21424 .29006 m .21823 .29342 L .21567 .29937 L p F P
0 g
s
.898 .728 .663 r
.21823 .29342 m .21424 .29006 L .21665 .28416 L p F P
0 g
s
.714 .758 .887 r
.11445 .46553 m .12346 .46105 L .12853 .46385 L p F P
0 g
s
.708 .756 .89 r
.12551 .46003 m .12346 .46105 L .12853 .46385 L p F P
0 g
s
.708 .756 .89 r
.12853 .46385 m .12919 .46353 L .12551 .46003 L p F P
0 g
s
.563 .533 .779 r
.60787 .42326 m .60588 .41826 L .61626 .41797 L closepath p F P
0 g
s
.813 .737 .78 r
.18159 .4204 m .18661 .42325 L .17938 .43084 L p F P
0 g
s
.803 .728 .782 r
.18642 .41532 m .18159 .4204 L .18661 .42325 L p F P
0 g
s
.278 .186 .568 r
.78486 .37812 m .7808 .38265 L .78247 .38758 L p F P
0 g
s
.312 .234 .605 r
.78399 .37311 m .78353 .37221 L p .7808 .38265 L F P
0 g
s
.312 .234 .605 r
.7808 .38265 m .78486 .37812 L .78399 .37311 L p F P
0 g
s
.404 .396 .737 r
.77806 .32028 m .77408 .32583 L .77997 .32935 L p F P
0 g
s
.416 .412 .747 r
.77162 .31695 m .77806 .32028 L .77408 .32583 L p F P
0 g
s
.485 .526 .824 r
.73819 .2554 m .73526 .2608 L .74575 .26267 L p F P
0 g
s
.489 .533 .829 r
.73172 .25442 m .73819 .2554 L .73526 .2608 L p F P
0 g
s
.483 .52 .819 r
.73526 .2608 m .74575 .26267 L .74255 .26814 L p F P
0 g
s
.622 .665 .87 r
.66717 .4631 m .66535 .46349 L .66243 .45881 L p F P
0 g
s
.534 .595 .862 r
.70119 .22404 m .69293 .22404 L .69003 .21867 L p F P
0 g
s
.588 .58 .812 r
.63635 .44491 m .62984 .44565 L .62683 .43919 L p F P
0 g
s
.747 .756 .859 r
.14039 .45663 m .12919 .46353 L .12551 .46003 L p F P
0 g
s
.626 .958 .907 r
.72388 .46031 m .73564 .45399 L .73594 .454 L p F P
0 g
s
.653 .946 .957 r
.73564 .45399 m .72388 .46031 L .72122 .45896 L p F P
0 g
s
.786 .746 .816 r
.16137 .44717 m .15534 .4522 L .15173 .44835 L p F P
0 g
s
.429 .347 .662 r
.58007 .29578 m .57647 .29315 L .57904 .29088 L closepath p F P
0 g
s
.422 .336 .654 r
.57647 .29315 m .57904 .29088 L .57771 .28425 L p F P
0 g
s
0 .359 .794 r
.04976 .44836 m .0554 .45106 L .05951 .45422 L p F P
0 g
s
0 .375 .811 r
.0554 .45106 m .04976 .44836 L .04591 .4453 L p F P
0 g
s
.832 .725 .746 r
.20036 .39859 m .19819 .40144 L .1947 .39679 L p F P
0 g
s
.832 .725 .746 r
.1947 .39679 m .19555 .39565 L .20036 .39859 L p F P
0 g
s
.832 .725 .746 r
.20036 .39859 m .19555 .39565 L .2007 .38875 L p F P
0 g
s
.865 .724 .705 r
.21193 .33045 m .2164 .33359 L .21283 .33993 L p F P
0 g
s
.864 .721 .704 r
.2164 .33359 m .21193 .33045 L .21542 .32415 L p F P
0 g
s
.212 .074 .465 r
.7783 .39832 m .77813 .39849 L .77809 .40396 L p F P
0 g
s
.482 .41 .7 r
.5786 .33319 m .5778 .3301 L .58103 .3313 L closepath p F P
0 g
s
.508 .433 .706 r
.58096 .3421 m .57901 .34163 L .58055 .34057 L closepath p F P
0 g
s
.506 .428 .703 r
.57901 .34163 m .58055 .34057 L .5786 .33319 L p F P
0 g
s
.786 .746 .816 r
.15173 .44835 m .1565 .44429 L .16137 .44717 L p F P
0 g
s
.78 .742 .819 r
.16318 .43871 m .1565 .44429 L .16137 .44717 L p F P
0 g
s
.78 .742 .819 r
.16137 .44717 m .16677 .44275 L .16318 .43871 L p F P
0 g
s
.717 .987 .828 r
.59824 .21022 m .59891 .21008 L .60796 .20291 L p F P
0 g
s
.835 .999 .802 r
.5975 .21157 m .59824 .21022 L .59891 .21008 L closepath p F P
0 g
s
.362 .324 .682 r
.7817 .34811 m .78592 .35221 L .78152 .3578 L p F P
0 g
s
.338 .291 .658 r
.78244 .36539 m .7851 .3621 L .78152 .3578 L p F P
0 g
s
.339 .295 .661 r
.78592 .35221 m .78152 .3578 L .7851 .3621 L p F P
0 g
s
.444 .461 .783 r
.75945 .29283 m .76027 .29153 L p .76471 .2998 L F P
0 g
s
.453 .476 .793 r
.75945 .29283 m .75875 .29107 L .76027 .29153 L closepath p F P
0 g
s
.811 .738 .783 r
.1783 .43198 m .17938 .43084 L .17524 .42832 L closepath p F P
0 g
s
.813 .737 .78 r
.17475 .42774 m .18159 .4204 L p .17938 .43084 L F P
0 g
s
.813 .737 .78 r
.17938 .43084 m .17524 .42832 L .17475 .42774 L p F P
0 g
s
.653 .718 .896 r
.62507 .19886 m .63683 .19512 L .63975 .19919 L p F P
0 g
s
.67 .734 .898 r
.63683 .19512 m .62507 .19886 L .62216 .19549 L p F P
0 g
s
.719 .782 .902 r
.61048 .20127 m .62216 .19549 L .62507 .19886 L p F P
0 g
s
.18 .05 .456 r
.78334 .39276 m .7783 .39832 L .77854 .4035 L p F P
0 g
s
.236 .127 .52 r
.7783 .39832 m .78334 .39276 L .78247 .38758 L p F P
0 g
s
.212 .074 .465 r
.77809 .40396 m .77854 .4035 L .7783 .39832 L p F P
0 g
s
.793 .736 .8 r
.17091 .43883 m .1783 .43198 L .17524 .42832 L p F P
0 g
s
.078 0 .266 r
.76887 .42178 m .76978 .42093 L .77 .41904 L closepath p F P
0 g
s
.667 .756 .917 r
.09983 .46616 m .11073 .46219 L .11445 .46553 L p F P
0 g
s
.671 .758 .915 r
.11073 .46219 m .09983 .46616 L .09608 .46294 L p F P
0 g
s
.564 .526 .771 r
.61626 .41797 m .60588 .41826 L .60426 .41401 L p F P
0 g
s
.801 .741 .797 r
.17091 .43883 m .16677 .44275 L .16318 .43871 L p F P
0 g
s
.801 .741 .797 r
.16318 .43871 m .16607 .43594 L .17091 .43883 L p F P
0 g
s
.793 .736 .8 r
.17454 .42794 m .16607 .43594 L .17091 .43883 L p F P
0 g
s
.793 .736 .8 r
.17524 .42832 m .17454 .42794 L p .17091 .43883 L F P
0 g
s
.278 .182 .563 r
.58222 .25518 m .58103 .25206 L .58175 .25122 L closepath p F P
0 g
s
.828 .72 .745 r
.20597 .38182 m .2066 .38097 L .20313 .37609 L p F P
0 g
s
.09 0 .428 r
.58832 .23119 m .58507 .23579 L .58521 .24091 L p F P
0 g
s
0 0 .29 r
.58507 .23579 m .58832 .23119 L .58865 .22661 L p F P
0 g
s
.868 .725 .702 r
.21542 .32415 m .21716 .32094 L .21369 .3161 L p F P
0 g
s
.602 .642 .863 r
.64764 .45574 m .65949 .45383 L .66243 .45881 L p F P
0 g
s
.594 .614 .841 r
.65654 .44856 m .65949 .45383 L .64764 .45574 L p F P
0 g
s
.594 .614 .841 r
.65587 .44865 m .65654 .44856 L p .64764 .45574 L F P
0 g
s
.594 .614 .841 r
.64764 .45574 m .647 .45455 L .65587 .44865 L p F P
0 g
s
.484 .415 .703 r
.58103 .3313 m .5786 .33319 L .58055 .34057 L p F P
0 g
s
.415 .415 .751 r
.77546 .31142 m .77162 .31695 L .77806 .32028 L p F P
0 g
s
.426 .429 .759 r
.7685 .30827 m .77546 .31142 L .77162 .31695 L p F P
0 g
s
.718 .76 .886 r
.12346 .46105 m .11445 .46553 L .11073 .46219 L p F P
0 g
s
.622 .682 .885 r
.67721 .46091 m .66717 .4631 L .67514 .4578 L closepath p F P
0 g
s
.622 .665 .87 r
.67431 .45655 m .67514 .4578 L .66717 .4631 L p F P
0 g
s
.622 .665 .87 r
.66243 .45881 m .67431 .45655 L p .66717 .4631 L F P
0 g
s
.816 .725 .764 r
.19453 .40572 m .19819 .40144 L .1947 .39679 L p F P
0 g
s
.86 .722 .709 r
.21375 .34939 m .21175 .35285 L .20828 .34797 L p F P
0 g
s
.86 .722 .709 r
.20828 .34797 m .20925 .34628 L .21375 .34939 L p F P
0 g
s
.861 .721 .706 r
.21375 .34939 m .20925 .34628 L .21283 .33993 L p F P
0 g
s
.452 .476 .793 r
.76027 .29153 m .75875 .29107 L .75578 .28367 L p F P
0 g
s
.476 .507 .811 r
.74255 .26814 m .74989 .26967 L p .74918 .2757 L F P
0 g
s
.475 .509 .814 r
.74255 .26814 m .74989 .26967 L .74695 .26292 L p F P
0 g
s
.475 .509 .814 r
.74695 .26292 m .74575 .26267 L .74255 .26814 L p F P
0 g
s
.535 .473 .732 r
.59039 .37411 m .58612 .3737 L .58957 .37149 L closepath p F P
0 g
s
.535 .465 .723 r
.58726 .36401 m .58957 .37149 L .58612 .3737 L p F P
0 g
s
.535 .465 .723 r
.58651 .36391 m .58726 .36401 L p .58612 .3737 L F P
0 g
s
.828 .72 .745 r
.20313 .37609 m .20105 .37888 L .20597 .38182 L p F P
0 g
s
.833 .726 .746 r
.20105 .37888 m .20597 .38182 L .2007 .38875 L p F P
0 g
s
.918 .738 .642 r
.21506 .27489 m .21618 .27171 L .21263 .26786 L p F P
0 g
s
.888 .729 .678 r
.21301 .30538 m .21713 .30867 L .21435 .31472 L p F P
0 g
s
.889 .726 .674 r
.21713 .30867 m .21301 .30538 L .21567 .29937 L p F P
0 g
s
.848 .724 .727 r
.20543 .36249 m .21014 .36551 L .20575 .37214 L p F P
0 g
s
.845 .721 .727 r
.21014 .36551 m .20543 .36249 L .20977 .35587 L p F P
0 g
s
.385 .676 .974 r
.06739 .45853 m .07508 .45887 L .0793 .46198 L p F P
0 g
s
.4 .679 .974 r
.07508 .45887 m .06739 .45853 L .06357 .45548 L p F P
0 g
s
.397 .319 .651 r
.57959 .28241 m .57771 .28425 L .57904 .29088 L p F P
0 g
s
.313 .257 .633 r
.7851 .3621 m .78244 .36539 L .78378 .37192 L p F P
0 g
s
.336 .273 .637 r
.78353 .37221 m .78378 .37192 L .78244 .36539 L p F P
0 g
s
.904 .736 .663 r
.21281 .28073 m .21665 .28416 L .21424 .29006 L p F P
0 g
s
.907 .733 .655 r
.21665 .28416 m .21281 .28073 L .21506 .27489 L p F P
0 g
s
.717 .987 .828 r
.60796 .20291 m .60909 .20029 L p .59824 .21022 L F P
0 g
s
.779 .885 .922 r
.60796 .20291 m .60909 .20029 L .61048 .20127 L closepath p F P
0 g
s
.564 .526 .771 r
.60426 .41401 m .6102 .41019 L p .61626 .41797 L F P
0 g
s
.556 .521 .771 r
.60426 .41401 m .60281 .4102 L .6102 .41019 L closepath p F P
0 g
s
.522 .572 .846 r
.71081 .23531 m .71037 .23529 L .7106 .23488 L closepath p F P
0 g
s
.528 .581 .852 r
.70791 .22969 m .7106 .23488 L .71037 .23529 L p F P
0 g
s
.614 .68 .889 r
.63975 .19919 m .65159 .19661 L .6545 .20107 L p F P
0 g
s
.623 .69 .892 r
.65159 .19661 m .63975 .19919 L .63683 .19512 L p F P
0 g
s
.594 .613 .841 r
.647 .45455 m .64467 .45016 L .65587 .44865 L closepath p F P
0 g
s
.56 .629 .877 r
.67327 .21087 m .67223 .2091 L .67406 .20896 L closepath p F P
0 g
s
.635 .748 .93 r
.68008 .46492 m .69195 .4618 L .69477 .46512 L p F P
0 g
s
.626 .721 .915 r
.69195 .4618 m .68008 .46492 L .67721 .46091 L p F P
0 g
s
.435 .446 .771 r
.76471 .2998 m .77218 .30277 L .7685 .30827 L p F P
0 g
s
.425 .433 .764 r
.77218 .30277 m .7685 .30827 L .77546 .31142 L p F P
0 g
s
.825 .732 .763 r
.1896 .40282 m .19453 .40572 L .18843 .41294 L p F P
0 g
s
.816 .725 .764 r
.1947 .39679 m .1896 .40282 L .19453 .40572 L p F P
0 g
s
.472 .498 .804 r
.75283 .27659 m .74918 .2757 L p .75514 .28349 L F P
0 g
s
.468 .496 .805 r
.75283 .27659 m .74918 .2757 L .75114 .27254 L closepath p F P
0 g
s
.476 .507 .811 r
.74989 .26967 m .75114 .27254 L .74918 .2757 L p F P
0 g
s
.511 .563 .844 r
.71081 .23531 m .72299 .23619 L p .7206 .24167 L F P
0 g
s
.507 .563 .848 r
.72009 .23043 m .72299 .23619 L .71081 .23531 L p F P
0 g
s
.507 .563 .848 r
.7129 .22994 m .72009 .23043 L p .71081 .23531 L F P
0 g
s
.507 .563 .848 r
.71081 .23531 m .7106 .23488 L .7129 .22994 L p F P
0 g
s
.344 .264 .621 r
.58337 .26321 m .57944 .26751 L .58246 .27173 L p F P
0 g
s
.326 .238 .601 r
.57944 .26751 m .58337 .26321 L .58244 .25707 L p F P
0 g
s
.72 .876 .954 r
.60909 .20029 m .61048 .20127 L .62216 .19549 L p F P
0 g
s
.548 .606 .863 r
.69003 .21867 m .68772 .21875 L .68886 .21654 L closepath p F P
0 g
s
.552 .616 .87 r
.68713 .21344 m .68886 .21654 L .68772 .21875 L p F P
0 g
s
.283 .186 .564 r
.58175 .25122 m .58619 .24577 L p .58279 .25666 L F P
0 g
s
.283 .186 .564 r
.58279 .25666 m .58222 .25518 L .58175 .25122 L p F P
0 g
s
.212 .109 .513 r
.58175 .25122 m .58619 .24577 L .58521 .24091 L p F P
0 g
s
.498 .427 .707 r
.58055 .34057 m .58891 .33408 L p .58794 .34409 L F P
0 g
s
.498 .427 .707 r
.58794 .34409 m .58096 .3421 L .58055 .34057 L p F P
0 g
s
.484 .415 .703 r
.58055 .34057 m .58891 .33408 L .58103 .3313 L p F P
0 g
s
0 0 .108 r
.76978 .42093 m .76887 .42178 L .76492 .42844 L p F P
0 g
s
.663 .854 .973 r
.71828 .46018 m .70938 .46377 L .70663 .46128 L p F P
0 g
s
.653 .814 .961 r
.69477 .46512 m .70663 .46128 L .70938 .46377 L p F P
0 g
s
.121 .525 .914 r
.05951 .45422 m .06357 .45548 L .05974 .45238 L p F P
0 g
s
.121 .525 .914 r
.05974 .45238 m .0554 .45106 L .05951 .45422 L p F P
0 g
s
.557 .514 .763 r
.6102 .41019 m .60281 .4102 L .60092 .40506 L p F P
0 g
s
.517 .576 .853 r
.7106 .23488 m .70791 .22969 L .7129 .22994 L closepath p F P
0 g
s
.821 .346 0 r
.03765 .43742 m .03376 .43415 L .03126 .4298 L p F P
0 g
s
.496 .43 .713 r
.58264 .3481 m .58096 .3421 L .58794 .34409 L closepath p F P
0 g
s
.435 .45 .776 r
.76822 .29433 m .76471 .2998 L .77218 .30277 L p F P
0 g
s
.444 .461 .783 r
.76027 .29153 m .76822 .29433 L .76471 .2998 L p F P
0 g
s
.489 .534 .83 r
.73819 .2554 m .73172 .25442 L .72941 .24945 L p F P
0 g
s
.87 .728 .704 r
.21107 .32095 m .21542 .32415 L .21193 .33045 L p F P
0 g
s
.868 .725 .702 r
.21369 .3161 m .21107 .32095 L .21542 .32415 L p F P
0 g
s
.46 .482 .795 r
.75578 .28367 m .75514 .28349 L .75549 .28295 L closepath p F P
0 g
s
.472 .498 .804 r
.75514 .28349 m .75549 .28295 L .75283 .27659 L p F P
0 g
s
0 0 .286 r
.59028 .22429 m .58865 .22661 L .58832 .23119 L p F P
0 g
s
0 0 .026 r
.58865 .22661 m .59028 .22429 L .59279 .21829 L p F P
0 g
s
.846 .723 .727 r
.20977 .35587 m .21175 .35285 L .20828 .34797 L p F P
0 g
s
.681 .975 .902 r
.73564 .45399 m .73682 .45327 L .73594 .454 L closepath p F P
0 g
s
.696 .982 .835 r
.74733 .44618 m .73682 .45327 L .73594 .454 L p F P
0 g
s
.696 .982 .835 r
.74815 .44576 m .74733 .44618 L p .73594 .454 L F P
0 g
s
.444 .466 .788 r
.7636 .28609 m .76027 .29153 L .76822 .29433 L p F P
0 g
s
.452 .476 .793 r
.75578 .28367 m .7636 .28609 L .76027 .29153 L p F P
0 g
s
.644 .779 .945 r
.70663 .46128 m .69477 .46512 L .69195 .4618 L p F P
0 g
s
.718 .914 .559 r
.5961 .21236 m .60096 .20576 L .59824 .21022 L closepath p F P
0 g
s
.717 .987 .828 r
.60759 .19951 m .60096 .20576 L .59824 .21022 L p F P
0 g
s
.717 .987 .828 r
.60909 .20029 m .60759 .19951 L p .59824 .21022 L F P
0 g
s
.588 .58 .812 r
.62683 .43919 m .63868 .4381 L p .63635 .44491 L F P
0 g
s
.573 .563 .804 r
.63566 .43162 m .63868 .4381 L .62683 .43919 L p F P
0 g
s
.573 .563 .804 r
.63442 .43171 m .63566 .43162 L p .62683 .43919 L F P
0 g
s
.573 .563 .804 r
.62683 .43919 m .62596 .43725 L .63442 .43171 L p F P
0 g
s
.53 .842 .533 r
.75042 .44374 m .74815 .44576 L p .74815 .44575 L F P
0 g
s
.53 .842 .533 r
.75889 .43602 m .75042 .44374 L p .74815 .44575 L F P
0 g
s
.53 .842 .533 r
.759 .43587 m .75889 .43602 L p .74815 .44576 L F P
0 g
s
0 0 0 r
.75042 .44374 m .75673 .43812 L .75889 .43602 L closepath p F P
0 g
s
.504 .877 .669 r
.74482 .44663 m .75671 .43814 L .75042 .44374 L F
.75673 .43812 m .75042 .44374 L p .75671 .43814 L F P
0 g
s
.579 .916 .697 r
.74733 .44618 m .75042 .44374 L .74815 .44576 L closepath p F P
0 g
s
.459 .701 .972 r
.0793 .46198 m .0816 .46196 L .07781 .45882 L p F P
0 g
s
.459 .701 .972 r
.07781 .45882 m .07508 .45887 L .0793 .46198 L p F P
0 g
s
.549 .509 .763 r
.60092 .40506 m .59972 .40177 L .60567 .40194 L closepath p F P
0 g
s
.557 .514 .763 r
.60092 .40506 m .60567 .40194 L p .6102 .41019 L F P
0 g
s
.838 .729 .744 r
.19591 .38578 m .2007 .38875 L .19555 .39565 L p F P
0 g
s
.833 .726 .746 r
.2007 .38875 m .19591 .38578 L .20105 .37888 L p F P
0 g
s
.773 .755 .837 r
.14491 .4533 m .14039 .45663 L .13674 .45299 L p F P
0 g
s
.747 .756 .859 r
.12551 .46003 m .13674 .45299 L .14039 .45663 L p F P
0 g
s
.895 .733 .674 r
.21169 .29601 m .21567 .29937 L .21301 .30538 L p F P
0 g
s
.896 .731 .669 r
.21567 .29937 m .21169 .29601 L .21424 .29006 L p F P
0 g
s
.358 .324 .684 r
.78602 .34252 m .7817 .34811 L .78592 .35221 L p F P
0 g
s
.375 .347 .7 r
.78118 .33863 m .78602 .34252 L .7817 .34811 L p F P
0 g
s
.508 .439 .715 r
.58264 .3481 m .58794 .34409 L p .58712 .35404 L F P
0 g
s
.508 .439 .715 r
.58712 .35404 m .58412 .35335 L .58264 .3481 L p F P
0 g
s
.449 .475 .795 r
.7636 .28609 m .75578 .28367 L .75549 .28295 L p F P
0 g
s
.867 .727 .706 r
.20842 .33677 m .21283 .33993 L .20925 .34628 L p F P
0 g
s
.865 .724 .705 r
.21283 .33993 m .20842 .33677 L .21193 .33045 L p F P
0 g
s
.654 .129 0 r
.04517 .44468 m .04121 .44144 L .03765 .43742 L p F P
0 g
s
.644 .122 0 r
.03376 .43415 m .03765 .43742 L .04121 .44144 L p F P
0 g
s
.914 .742 .655 r
.21139 .27138 m .21506 .27489 L .21281 .28073 L p F P
0 g
s
.918 .738 .642 r
.21263 .26786 m .21139 .27138 L .21506 .27489 L p F P
0 g
s
.559 .633 .881 r
.67406 .20896 m .67223 .2091 L .66933 .20424 L p F P
0 g
s
.452 .377 .681 r
.58328 .30977 m .57884 .30733 L .58206 .30459 L closepath p F P
0 g
s
.448 .37 .676 r
.57884 .30733 m .58206 .30459 L .58048 .29764 L p F P
0 g
s
.449 .475 .795 r
.75549 .28295 m .75832 .27807 L p .7636 .28609 L F P
0 g
s
.457 .49 .804 r
.75549 .28295 m .75283 .27659 L .75832 .27807 L closepath p F P
0 g
s
.825 .732 .763 r
.18843 .41294 m .18642 .41532 L .18289 .41092 L p F P
0 g
s
.825 .732 .763 r
.18289 .41092 m .18366 .40999 L .18843 .41294 L p F P
0 g
s
.825 .732 .763 r
.18843 .41294 m .18366 .40999 L .1896 .40282 L p F P
0 g
s
.55 .503 .756 r
.60567 .40194 m .59972 .40177 L .59781 .39636 L p F P
0 g
s
.573 .563 .804 r
.62596 .43725 m .6238 .43241 L .63442 .43171 L closepath p F P
0 g
s
.305 .23 .604 r
.78399 .37311 m .78353 .37221 L .78378 .37192 L closepath p F P
0 g
s
.701 .962 .943 r
.73682 .45327 m .73564 .45399 L .73303 .4533 L p F P
0 g
s
.653 .946 .957 r
.72122 .45896 m .73303 .4533 L .73564 .45399 L p F P
0 g
s
0 0 .09 r
.7747 .41592 m .76978 .42093 L .76885 .42473 L p F P
0 g
s
0 0 .233 r
.777 .40975 m .7747 .41592 L .76978 .42093 L p F P
0 g
s
0 0 .108 r
.76492 .42844 m .76885 .42473 L .76978 .42093 L p F P
0 g
s
.847 .725 .728 r
.20575 .37214 m .20313 .37609 L .19964 .37137 L p F P
0 g
s
.847 .725 .728 r
.19964 .37137 m .20113 .36909 L .20575 .37214 L p F P
0 g
s
.848 .724 .727 r
.20575 .37214 m .20113 .36909 L .20543 .36249 L p F P
0 g
s
.422 .342 .661 r
.57904 .29088 m .58374 .28628 L p .58138 .29679 L F P
0 g
s
.422 .342 .661 r
.58138 .29679 m .58007 .29578 L .57904 .29088 L p F P
0 g
s
.397 .319 .651 r
.57904 .29088 m .58374 .28628 L .57959 .28241 L p F P
0 g
s
.846 .723 .727 r
.20828 .34797 m .20514 .35281 L .20977 .35587 L p F P
0 g
s
.851 .727 .727 r
.20514 .35281 m .20977 .35587 L .20543 .36249 L p F P
0 g
s
.506 .444 .721 r
.58482 .35574 m .58412 .35335 L .58712 .35404 L closepath p F P
0 g
s
.585 .66 .889 r
.65472 .20142 m .6545 .20107 L .65488 .20101 L closepath p F P
0 g
s
.773 .755 .837 r
.13674 .45299 m .14022 .45036 L .14491 .4533 L p F P
0 g
s
.766 .751 .839 r
.1481 .44454 m .14022 .45036 L .14491 .4533 L p F P
0 g
s
.766 .751 .839 r
.14491 .4533 m .15173 .44835 L .1481 .44454 L p F P
0 g
s
.527 .461 .725 r
.58726 .36401 m .58651 .36391 L .58711 .36352 L closepath p F P
0 g
s
.527 .453 .716 r
.58482 .35574 m .58711 .36352 L .58651 .36391 L p F P
0 g
s
.807 .732 .781 r
.18159 .4204 m .18642 .41532 L .18289 .41092 L p F P
0 g
s
.639 .965 .83 r
.74482 .44663 m .74424 .44699 L .73682 .45327 L p F P
0 g
s
.639 .965 .83 r
.73682 .45327 m .74733 .44618 L .74482 .44663 L p F P
0 g
s
.701 .962 .943 r
.73303 .4533 m .74424 .44699 L .73682 .45327 L p F P
0 g
s
.534 .595 .862 r
.69003 .21867 m .70211 .21862 L p .70119 .22404 L F P
0 g
s
.532 .597 .865 r
.69921 .21329 m .70211 .21862 L .69003 .21867 L p F P
0 g
s
.532 .597 .865 r
.69017 .21337 m .69921 .21329 L p .69003 .21867 L F P
0 g
s
.532 .597 .865 r
.69003 .21867 m .68886 .21654 L .69017 .21337 L p F P
0 g
s
.507 .446 .723 r
.58711 .36352 m .58482 .35574 L .58712 .35404 L p F P
0 g
s
.55 .503 .756 r
.59781 .39636 m .60237 .3933 L p .60567 .40194 L F P
0 g
s
.542 .497 .755 r
.59781 .39636 m .59662 .39296 L .60237 .3933 L closepath p F P
0 g
s
.483 .416 .706 r
.58746 .32619 m .58103 .3313 L .58891 .33408 L p F P
0 g
s
.485 .407 .694 r
.58648 .32247 m .58746 .32619 L .58103 .3313 L p F P
0 g
s
.485 .407 .694 r
.58296 .32098 m .58648 .32247 L p .58103 .3313 L F P
0 g
s
.287 .217 .601 r
.78378 .37192 m .78809 .36661 L p .78585 .37693 L F P
0 g
s
.287 .217 .601 r
.78585 .37693 m .78399 .37311 L .78378 .37192 L p F P
0 g
s
.313 .257 .633 r
.78378 .37192 m .78809 .36661 L .7851 .3621 L p F P
0 g
s
.584 .666 .896 r
.65488 .20101 m .6545 .20107 L .65159 .19661 L p F P
0 g
s
.388 .318 .657 r
.58569 .27605 m .57959 .28241 L .58374 .28628 L p F P
0 g
s
.394 .305 .636 r
.58557 .27545 m .58569 .27605 L .57959 .28241 L p F P
0 g
s
.394 .305 .636 r
.58246 .27173 m .58557 .27545 L p .57959 .28241 L F P
0 g
s
.543 .491 .748 r
.60237 .3933 m .59662 .39296 L .5949 .38788 L p F P
0 g
s
.603 .656 .874 r
.67431 .45655 m .66243 .45881 L .65949 .45383 L p F P
0 g
s
.588 .589 .821 r
.64168 .44429 m .63635 .44491 L .64067 .44221 L closepath p F P
0 g
s
.588 .58 .812 r
.63868 .4381 m .64067 .44221 L .63635 .44491 L p F P
0 g
s
.505 .553 .839 r
.7259 .24218 m .7206 .24167 L .72323 .23668 L closepath p F P
0 g
s
.511 .563 .844 r
.72299 .23619 m .72323 .23668 L .7206 .24167 L p F P
0 g
s
.588 .666 .893 r
.65488 .20101 m .66642 .19945 L .6635 .19474 L p F P
0 g
s
.588 .666 .893 r
.6635 .19474 m .65661 .1958 L .65488 .20101 L p F P
0 g
s
.584 .666 .896 r
.65159 .19661 m .65661 .1958 L .65488 .20101 L p F P
0 g
s
.519 .456 .725 r
.58711 .36352 m .59623 .35687 L p .59752 .36579 L F P
0 g
s
.519 .456 .725 r
.59752 .36579 m .58726 .36401 L .58711 .36352 L p F P
0 g
s
.507 .446 .723 r
.59596 .356 m .59623 .35687 L .58711 .36352 L p F P
0 g
s
.507 .446 .723 r
.58712 .35404 m .59596 .356 L p .58711 .36352 L F P
0 g
s
.718 .76 .886 r
.11073 .46219 m .11863 .45815 L .12346 .46105 L p F P
0 g
s
.712 .758 .888 r
.12182 .45654 m .11863 .45815 L .12346 .46105 L p F P
0 g
s
.712 .758 .888 r
.12346 .46105 m .12551 .46003 L .12182 .45654 L p F P
0 g
s
.813 .735 .778 r
.18159 .4204 m .17475 .42774 L .17118 .42353 L p F P
0 g
s
.813 .735 .778 r
.17118 .42353 m .17673 .41749 L .18159 .4204 L p F P
0 g
s
.807 .732 .781 r
.18289 .41092 m .17673 .41749 L .18159 .4204 L p F P
0 g
s
.594 .603 .83 r
.65587 .44865 m .64467 .45016 L .64168 .44429 L p F P
0 g
s
.543 .491 .748 r
.5949 .38788 m .60004 .38436 L p .60237 .3933 L F P
0 g
s
.534 .485 .748 r
.5949 .38788 m .59351 .38375 L .60004 .38436 L closepath p F P
0 g
s
.517 .46 .732 r
.58957 .37149 m .58726 .36401 L .59752 .36579 L closepath p F P
0 g
s
.885 .731 .685 r
.21435 .31472 m .21369 .3161 L .21019 .31156 L p F P
0 g
s
.885 .731 .685 r
.21019 .31156 m .21026 .31142 L .21435 .31472 L p F P
0 g
s
.888 .729 .678 r
.21435 .31472 m .21026 .31142 L .21301 .30538 L p F P
0 g
s
.272 .18 .564 r
.58244 .25707 m .58222 .25518 L .58279 .25666 L closepath p F P
0 g
s
.288 .217 .601 r
.78486 .37812 m .78399 .37311 L .78585 .37693 L closepath p F P
0 g
s
0 0 0 r
.759 .43587 m .75928 .43561 L .76492 .42844 L p F P
0 g
s
0 0 0 r
.76885 .42473 m .76492 .42844 L .75928 .43561 L p F P
0 g
s
.455 0 0 r
.04517 .44468 m .04591 .4453 L .04206 .44215 L p F P
0 g
s
.455 0 0 r
.04206 .44215 m .04121 .44144 L .04517 .44468 L p F P
0 g
s
.559 .629 .878 r
.67406 .20896 m .68423 .20833 L .68132 .20326 L p F P
0 g
s
.559 .629 .878 r
.68132 .20326 m .6762 .20365 L .67406 .20896 L p F P
0 g
s
.559 .633 .881 r
.66933 .20424 m .6762 .20365 L .67406 .20896 L p F P
0 g
s
.535 .479 .74 r
.60004 .38436 m .59351 .38375 L .59216 .3796 L p F P
0 g
s
.527 .468 .733 r
.58957 .37149 m .59752 .36579 L p .59849 .37517 L F P
0 g
s
.527 .468 .733 r
.59849 .37517 m .59039 .37411 L .58957 .37149 L p F P
0 g
s
.525 .473 .74 r
.59216 .3796 m .59039 .37411 L .59849 .37517 L closepath p F P
0 g
s
.535 .479 .74 r
.59216 .3796 m .59849 .37517 L p .60004 .38436 L F P
0 g
s
.142 0 .381 r
.77854 .4035 m .77809 .40396 L .777 .40975 L p F P
0 g
s
.794 .735 .798 r
.17524 .42832 m .17475 .42774 L .17454 .42794 L closepath p F P
0 g
s
.592 .743 .948 r
.0816 .46196 m .09232 .45971 L .09608 .46294 L p F P
0 g
s
.597 .744 .946 r
.09232 .45971 m .0816 .46196 L .07781 .45882 L p F P
0 g
s
.495 .545 .837 r
.72941 .24945 m .72881 .24819 L .72997 .24834 L closepath p F P
0 g
s
.489 .534 .83 r
.72941 .24945 m .72997 .24834 L p .73819 .2554 L F P
0 g
s
.902 .739 .67 r
.2104 .28663 m .21424 .29006 L .21169 .29601 L p F P
0 g
s
.904 .736 .663 r
.21424 .29006 m .2104 .28663 L .21281 .28073 L p F P
0 g
s
.235 .127 .52 r
.78568 .384 m .78247 .38758 L .78334 .39276 L p F P
0 g
s
.278 .186 .568 r
.78247 .38758 m .78568 .384 L .78486 .37812 L p F P
0 g
s
.79 .75 .816 r
.1565 .44429 m .15173 .44835 L .1481 .44454 L p F P
0 g
s
.835 .73 .748 r
.1947 .39679 m .19555 .39565 L .19211 .39344 L closepath p F P
0 g
s
.838 .729 .744 r
.19118 .39223 m .19591 .38578 L p .19555 .39565 L F P
0 g
s
.838 .729 .744 r
.19555 .39565 m .19211 .39344 L .19118 .39223 L p F P
0 g
s
.833 .726 .746 r
.20105 .37888 m .20313 .37609 L .19964 .37137 L p F P
0 g
s
.874 .733 .703 r
.21107 .32095 m .21369 .3161 L .21019 .31156 L p F P
0 g
s
.417 .343 .666 r
.58048 .29764 m .58007 .29578 L .58138 .29679 L closepath p F P
0 g
s
.374 .35 .704 r
.78438 .33437 m .78118 .33863 L .78602 .34252 L p F P
0 g
s
.392 .376 .722 r
.78363 .33187 m .77997 .32935 L p .78118 .33863 L F P
0 g
s
.392 .376 .722 r
.78118 .33863 m .78438 .33437 L .78363 .33187 L p F P
0 g
s
.75 .758 .859 r
.13674 .45299 m .12551 .46003 L .12182 .45654 L p F P
0 g
s
.574 .555 .796 r
.63442 .43171 m .6238 .43241 L .62147 .427 L p F P
0 g
s
.79 .75 .816 r
.1481 .44454 m .15177 .44136 L .1565 .44429 L p F P
0 g
s
.784 .745 .818 r
.15959 .43473 m .15177 .44136 L .1565 .44429 L p F P
0 g
s
.784 .745 .818 r
.1565 .44429 m .16318 .43871 L .15959 .43473 L p F P
0 g
s
.871 .731 .705 r
.20763 .32724 m .21193 .33045 L .20842 .33677 L p F P
0 g
s
.87 .728 .704 r
.21193 .33045 m .20763 .32724 L .21107 .32095 L p F P
0 g
s
.821 .729 .764 r
.1896 .40282 m .1947 .39679 L .19211 .39344 L p F P
0 g
s
.796 .738 .799 r
.17454 .42794 m .17475 .42774 L .17118 .42353 L p F P
0 g
s
.803 .746 .799 r
.16957 .42507 m .17454 .42794 L .16607 .43594 L p F P
0 g
s
.796 .738 .799 r
.17118 .42353 m .16957 .42507 L .17454 .42794 L p F P
0 g
s
.787 .922 .927 r
.60759 .19951 m .61087 .19727 L .60909 .20029 L closepath p F P
0 g
s
.72 .876 .954 r
.61924 .19243 m .61087 .19727 L .60909 .20029 L p F P
0 g
s
.72 .876 .954 r
.62216 .19549 m .61924 .19243 L p .60909 .20029 L F P
0 g
s
.541 .608 .869 r
.68886 .21654 m .68713 .21344 L .69017 .21337 L closepath p F P
0 g
s
.166 .081 .506 r
.58846 .23634 m .58521 .24091 L .58619 .24577 L p F P
0 g
s
.09 0 .428 r
.58521 .24091 m .58846 .23634 L .58832 .23119 L p F P
0 g
s
.457 .49 .805 r
.75832 .27807 m .75283 .27659 L .75114 .27254 L p F P
0 g
s
.18 .05 .456 r
.77854 .4035 m .78332 .39823 L .78334 .39276 L p F P
0 g
s
.105 0 .369 r
.78332 .39823 m .77854 .4035 L .77844 .40828 L p F P
0 g
s
.142 0 .381 r
.777 .40975 m .77844 .40828 L .77854 .4035 L p F P
0 g
s
.494 .547 .839 r
.72997 .24834 m .72881 .24819 L .7259 .24218 L p F P
0 g
s
.303 .222 .597 r
.58279 .25666 m .58244 .25707 L .58337 .26321 L p F P
0 g
s
.805 .745 .797 r
.16607 .43594 m .16318 .43871 L .15959 .43473 L p F P
0 g
s
.805 .745 .797 r
.15959 .43473 m .16136 .43299 L .16607 .43594 L p F P
0 g
s
.803 .746 .799 r
.16607 .43594 m .16136 .43299 L .16957 .42507 L p F P
0 g
s
.517 .577 .855 r
.7129 .22994 m .70791 .22969 L .70501 .22411 L p F P
0 g
s
0 0 0 r
.75889 .43602 m .75928 .43561 L .759 .43587 L closepath p F P
0 g
s
.424 .355 .675 r
.58138 .29679 m .58048 .29764 L .58206 .30459 L p F P
0 g
s
0 .375 .811 r
.04591 .4453 m .05136 .44786 L .0554 .45106 L p F P
0 g
s
0 .387 .824 r
.05136 .44786 m .04591 .4453 L .04206 .44215 L p F P
0 g
s
.833 .726 .746 r
.19964 .37137 m .19631 .37588 L .20105 .37888 L p F P
0 g
s
.839 .731 .745 r
.19631 .37588 m .20105 .37888 L .19591 .38578 L p F P
0 g
s
.663 .854 .973 r
.72052 .45847 m .71828 .46018 L p .70663 .46128 L F P
0 g
s
.686 .872 .969 r
.71828 .46018 m .72052 .45847 L .72122 .45896 L closepath p F P
0 g
s
.504 .877 .669 r
.75042 .44374 m .74733 .44618 L .74482 .44663 L p F P
0 g
s
.865 .728 .71 r
.20925 .34628 m .20828 .34797 L .20478 .3433 L p F P
0 g
s
.865 .728 .71 r
.20478 .3433 m .20489 .3431 L .20925 .34628 L p F P
0 g
s
.867 .727 .706 r
.20925 .34628 m .20489 .3431 L .20842 .33677 L p F P
0 g
s
0 0 .286 r
.58832 .23119 m .58931 .22977 L .59028 .22429 L p F P
0 g
s
0 0 .275 r
.59384 .21846 m .59028 .22429 L .58931 .22977 L p F P
0 g
s
0 0 .021 r
.59028 .22429 m .59384 .21846 L .59597 .21259 L p F P
0 g
s
.853 .73 .727 r
.20088 .3594 m .20543 .36249 L .20113 .36909 L p F P
0 g
s
.851 .727 .727 r
.20543 .36249 m .20088 .3594 L .20514 .35281 L p F P
0 g
s
.557 .848 .524 r
.75673 .43812 m .75889 .43602 L .75928 .43561 L p F P
0 g
s
.557 .848 .524 r
.75928 .43561 m .76549 .42966 L p .75673 .43812 L F P
0 g
s
0 0 0 r
.76803 .42668 m .76885 .42473 L p .75928 .43561 L F P
0 g
s
0 0 0 r
.75928 .43561 m .76549 .42966 L .76803 .42668 L p F P
0 g
s
.303 .222 .597 r
.58337 .26321 m .5852 .26107 L .58279 .25666 L p F P
0 g
s
.267 .194 .585 r
.58783 .25042 m .58279 .25666 L .5852 .26107 L p F P
0 g
s
.283 .186 .564 r
.58619 .24577 m .58783 .25042 L .58279 .25666 L p F P
0 g
s
.671 .758 .915 r
.09608 .46294 m .107 .45885 L .11073 .46219 L p F P
0 g
s
.675 .759 .914 r
.107 .45885 m .09608 .46294 L .09232 .45971 L p F P
0 g
s
.722 .762 .885 r
.11863 .45815 m .11073 .46219 L .107 .45885 L p F P
0 g
s
.895 .735 .676 r
.20905 .30201 m .21301 .30538 L .21026 .31142 L p F P
0 g
s
.895 .733 .674 r
.21301 .30538 m .20905 .30201 L .21169 .29601 L p F P
0 g
s
.67 .734 .898 r
.62216 .19549 m .63391 .19122 L .63683 .19512 L p F P
0 g
s
.691 .754 .9 r
.63391 .19122 m .62216 .19549 L .61924 .19243 L p F P
0 g
s
.529 .586 .856 r
.70501 .22411 m .70119 .22404 L .70302 .22032 L closepath p F P
0 g
s
.534 .595 .862 r
.70211 .21862 m .70302 .22032 L .70119 .22404 L p F P
0 g
s
.489 .534 .83 r
.72997 .24834 m .7411 .24997 L p .73819 .2554 L F P
0 g
s
.487 .538 .835 r
.72997 .24834 m .7411 .24997 L .73819 .24381 L p F P
0 g
s
.487 .538 .835 r
.73819 .24381 m .73259 .243 L .72997 .24834 L p F P
0 g
s
.494 .547 .839 r
.7259 .24218 m .73259 .243 L .72997 .24834 L p F P
0 g
s
.507 .448 .725 r
.59596 .356 m .58712 .35404 L .59387 .34901 L closepath p F P
0 g
s
.508 .439 .715 r
.59281 .34542 m .59387 .34901 L .58712 .35404 L p F P
0 g
s
.508 .439 .715 r
.58794 .34409 m .59281 .34542 L p .58712 .35404 L F P
0 g
s
.83 .736 .761 r
.18483 .39985 m .1896 .40282 L .18366 .40999 L p F P
0 g
s
.821 .729 .764 r
.19081 .39267 m .18483 .39985 L .1896 .40282 L p F P
0 g
s
.821 .729 .764 r
.19211 .39344 m .19081 .39267 L p .1896 .40282 L F P
0 g
s
.626 .721 .915 r
.67721 .46091 m .6891 .45811 L .69195 .4618 L p F P
0 g
s
.618 .68 .886 r
.68623 .45407 m .6891 .45811 L .67721 .46091 L p F P
0 g
s
.618 .68 .886 r
.67787 .45581 m .68623 .45407 L p .67721 .46091 L F P
0 g
s
.618 .68 .886 r
.67721 .46091 m .67514 .4578 L .67787 .45581 L p F P
0 g
s
.314 .259 .635 r
.78959 .35649 m .7851 .3621 L .78809 .36661 L p F P
0 g
s
.339 .295 .661 r
.7851 .3621 m .78959 .35649 L .78592 .35221 L p F P
0 g
s
.852 .729 .728 r
.20514 .35281 m .20828 .34797 L .20478 .3433 L p F P
0 g
s
.91 .745 .664 r
.20914 .27722 m .21281 .28073 L .2104 .28663 L p F P
0 g
s
.914 .742 .655 r
.21281 .28073 m .20914 .27722 L .21139 .27138 L p F P
0 g
s
.623 .69 .892 r
.63683 .19512 m .64867 .19226 L .65159 .19661 L p F P
0 g
s
.634 .702 .895 r
.64867 .19226 m .63683 .19512 L .63391 .19122 L p F P
0 g
s
.465 .503 .813 r
.75114 .27254 m .74989 .26967 L .7524 .27025 L closepath p F P
0 g
s
.457 .49 .805 r
.75114 .27254 m .7524 .27025 L p .75832 .27807 L F P
0 g
s
.4 .679 .974 r
.06357 .45548 m .07092 .45573 L .07508 .45887 L p F P
0 g
s
.412 .681 .973 r
.07092 .45573 m .06357 .45548 L .05974 .45238 L p F P
0 g
s
.574 .555 .796 r
.62147 .427 m .62418 .42519 L p .63442 .43171 L F P
0 g
s
.566 .55 .796 r
.62147 .427 m .62075 .42533 L .62418 .42519 L closepath p F P
0 g
s
.387 .373 .722 r
.78363 .33187 m .77997 .32935 L .78201 .32654 L closepath p F P
0 g
s
.404 .396 .737 r
.78047 .32173 m .77806 .32028 L p .77997 .32935 L F P
0 g
s
.404 .396 .737 r
.77997 .32935 m .78201 .32654 L .78047 .32173 L p F P
0 g
s
.716 .879 .957 r
.72052 .45847 m .72122 .45896 L .73303 .4533 L p F P
0 g
s
.424 .355 .675 r
.58206 .30459 m .58656 .30036 L .58138 .29679 L p F P
0 g
s
.417 .355 .68 r
.58817 .29009 m .58138 .29679 L .58656 .30036 L p F P
0 g
s
.422 .342 .661 r
.58374 .28628 m .58817 .29009 L .58138 .29679 L p F P
0 g
s
.251 .167 .562 r
.78585 .37693 m .78486 .37812 L .78568 .384 L p F P
0 g
s
.47 .401 .697 r
.58648 .32247 m .58296 .32098 L .58555 .31886 L closepath p F P
0 g
s
.467 .396 .693 r
.58296 .32098 m .58555 .31886 L .58374 .31164 L p F P
0 g
s
.875 .735 .704 r
.20689 .31768 m .21107 .32095 L .20763 .32724 L p F P
0 g
s
.874 .733 .703 r
.21019 .31156 m .20689 .31768 L .21107 .32095 L p F P
0 g
s
.567 .543 .787 r
.62418 .42519 m .62075 .42533 L .6177 .41792 L p F P
0 g
s
.135 .53 .918 r
.0554 .45106 m .05974 .45238 L .0559 .44921 L p F P
0 g
s
.135 .53 .918 r
.0559 .44921 m .05136 .44786 L .0554 .45106 L p F P
0 g
s
.445 .372 .681 r
.58206 .30459 m .58656 .30036 L p .58481 .31066 L F P
0 g
s
.445 .372 .681 r
.58481 .31066 m .58328 .30977 L .58206 .30459 L p F P
0 g
s
.562 .639 .884 r
.6762 .20365 m .66933 .20424 L .66642 .19945 L p F P
0 g
s
.579 .585 .823 r
.65058 .43705 m .65357 .44293 L .64168 .44429 L p F P
0 g
s
.579 .585 .823 r
.6478 .4373 m .65058 .43705 L p .64168 .44429 L F P
0 g
s
.579 .585 .823 r
.64168 .44429 m .64067 .44221 L .6478 .4373 L p F P
0 g
s
.594 .603 .83 r
.64168 .44429 m .65357 .44293 L p .65587 .44865 L F P
0 g
s
.564 .526 .771 r
.6102 .41019 m .61463 .41016 L p .61626 .41797 L F P
0 g
s
.557 .522 .772 r
.61463 .41016 m .6102 .41019 L .61377 .4079 L closepath p F P
0 g
s
.557 .514 .763 r
.61155 .40207 m .61377 .4079 L .6102 .41019 L p F P
0 g
s
.557 .514 .763 r
.60567 .40194 m .61155 .40207 L p .6102 .41019 L F P
0 g
s
.839 .73 .744 r
.19591 .38578 m .19118 .39223 L .18765 .38775 L p F P
0 g
s
.839 .73 .744 r
.18765 .38775 m .19128 .38275 L .19591 .38578 L p F P
0 g
s
.839 .731 .745 r
.19591 .38578 m .19128 .38275 L .19631 .37588 L p F P
0 g
s
.081 0 .424 r
.58931 .22977 m .58832 .23119 L .58846 .23634 L p F P
0 g
s
.54 .611 .873 r
.69017 .21337 m .68713 .21344 L .68423 .20833 L p F P
0 g
s
.465 .504 .814 r
.7524 .27025 m .74989 .26967 L .74695 .26292 L p F P
0 g
s
.55 .503 .756 r
.60845 .39363 m .61037 .39886 L .60567 .40194 L p F P
0 g
s
.55 .503 .756 r
.60237 .3933 m .60845 .39363 L p .60567 .40194 L F P
0 g
s
.55 .511 .765 r
.61155 .40207 m .60567 .40194 L .61037 .39886 L closepath p F P
0 g
s
.644 .779 .945 r
.69195 .4618 m .70384 .45835 L .70663 .46128 L p F P
0 g
s
.634 .748 .93 r
.70384 .45835 m .69195 .4618 L .6891 .45811 L p F P
0 g
s
.466 .702 .971 r
.07508 .45887 m .07781 .45882 L .074 .45564 L p F P
0 g
s
.466 .702 .971 r
.074 .45564 m .07092 .45573 L .07508 .45887 L p F P
0 g
s
.358 .284 .635 r
.58557 .27545 m .58246 .27173 L .58446 .26954 L closepath p F P
0 g
s
.344 .264 .621 r
.58246 .27173 m .58446 .26954 L .58337 .26321 L p F P
0 g
s
.872 .732 .705 r
.20416 .33355 m .20842 .33677 L .20489 .3431 L p F P
0 g
s
.871 .731 .705 r
.20842 .33677 m .20416 .33355 L .20763 .32724 L p F P
0 g
s
.777 .758 .836 r
.14022 .45036 m .13674 .45299 L .13307 .44936 L p F P
0 g
s
.75 .758 .859 r
.12182 .45654 m .13307 .44936 L .13674 .45299 L p F P
0 g
s
.485 .526 .824 r
.74403 .25642 m .73819 .2554 L p .74575 .26267 L F P
0 g
s
.481 .524 .824 r
.74403 .25642 m .73819 .2554 L .74111 .24998 L closepath p F P
0 g
s
.489 .534 .83 r
.7411 .24997 m .74111 .24998 L .73819 .2554 L p F P
0 g
s
.827 .737 .765 r
.18289 .41092 m .18366 .40999 L .18036 .40785 L closepath p F P
0 g
s
.83 .736 .761 r
.17934 .4066 m .18483 .39985 L p .18366 .40999 L F P
0 g
s
.83 .736 .761 r
.18366 .40999 m .18036 .40785 L .17934 .4066 L p F P
0 g
s
.603 .656 .874 r
.65949 .45383 m .6714 .45184 L .67431 .45655 L p F P
0 g
s
.596 .639 .864 r
.6714 .45184 m .65949 .45383 L .65654 .44856 L p F P
0 g
s
.9 .741 .675 r
.20787 .29258 m .21169 .29601 L .20905 .30201 L p F P
0 g
s
.902 .739 .67 r
.21169 .29601 m .20787 .29258 L .2104 .28663 L p F P
0 g
s
.654 .815 .961 r
.71851 .45696 m .70663 .46128 L .70384 .45835 L p F P
0 g
s
.663 .854 .973 r
.70663 .46128 m .71851 .45696 L .72052 .45847 L p F P
0 g
s
.811 .736 .781 r
.17673 .41749 m .18289 .41092 L .18036 .40785 L p F P
0 g
s
.564 .534 .779 r
.6177 .41792 m .61626 .41797 L .61743 .41724 L closepath p F P
0 g
s
.564 .526 .771 r
.61463 .41016 m .61743 .41724 L .61626 .41797 L p F P
0 g
s
.398 .393 .737 r
.78047 .32173 m .77806 .32028 L .7794 .31838 L closepath p F P
0 g
s
.415 .415 .751 r
.77737 .31242 m .77546 .31142 L p .77806 .32028 L F P
0 g
s
.415 .415 .751 r
.77806 .32028 m .7794 .31838 L .77737 .31242 L p F P
0 g
s
.852 .731 .729 r
.20113 .36909 m .19964 .37137 L .19612 .36681 L p F P
0 g
s
.852 .731 .729 r
.19612 .36681 m .19666 .36599 L .20113 .36909 L p F P
0 g
s
.853 .73 .727 r
.20113 .36909 m .19666 .36599 L .20088 .3594 L p F P
0 g
s
.852 .729 .728 r
.20478 .3433 m .20068 .34968 L .20514 .35281 L p F P
0 g
s
.856 .733 .727 r
.20068 .34968 m .20514 .35281 L .20088 .3594 L p F P
0 g
s
.046 0 .262 r
.77844 .40828 m .777 .40975 L .7747 .41592 L p F P
0 g
s
.644 .122 0 r
.04121 .44144 m .03732 .43817 L .03376 .43415 L p F P
0 g
s
.822 .728 .761 r
.19211 .39344 m .19118 .39223 L .19081 .39267 L closepath p F P
0 g
s
.321 .248 .617 r
.5852 .26107 m .58337 .26321 L .58446 .26954 L p F P
0 g
s
.777 .758 .836 r
.13307 .44936 m .13567 .44737 L .14022 .45036 L p F P
0 g
s
.77 .753 .838 r
.14446 .44076 m .13567 .44737 L .14022 .45036 L p F P
0 g
s
.77 .753 .838 r
.14022 .45036 m .1481 .44454 L .14446 .44076 L p F P
0 g
s
.579 .584 .822 r
.64067 .44221 m .63868 .4381 L .6478 .4373 L closepath p F P
0 g
s
.689 .861 .964 r
.71851 .45696 m .72618 .45377 L .72052 .45847 L closepath p F P
0 g
s
.716 .879 .957 r
.73038 .45196 m .72618 .45377 L .72052 .45847 L p F P
0 g
s
.716 .879 .957 r
.73303 .4533 m .73038 .45196 L p .72052 .45847 L F P
0 g
s
.494 .547 .84 r
.73259 .243 m .7259 .24218 L .72323 .23668 L p F P
0 g
s
.59 .676 .899 r
.65661 .1958 m .65159 .19661 L .64867 .19226 L p F P
0 g
s
.543 .499 .757 r
.60845 .39363 m .60237 .3933 L .60719 .39007 L closepath p F P
0 g
s
.543 .491 .748 r
.60535 .38483 m .60719 .39007 L .60237 .3933 L p F P
0 g
s
.543 .491 .748 r
.60004 .38436 m .60535 .38483 L p .60237 .3933 L F P
0 g
s
.44 .374 .686 r
.58374 .31164 m .58328 .30977 L .58481 .31066 L closepath p F P
0 g
s
.287 .217 .601 r
.78809 .36661 m .79043 .37133 L .78585 .37693 L p F P
0 g
s
.251 .167 .562 r
.78568 .384 m .78745 .38188 L .78585 .37693 L p F P
0 g
s
.249 .167 .564 r
.79043 .37133 m .78585 .37693 L .78745 .38188 L p F P
0 g
s
.818 .739 .778 r
.17673 .41749 m .17118 .42353 L .1676 .4194 L p F P
0 g
s
.818 .739 .778 r
.1676 .4194 m .17202 .41452 L .17673 .41749 L p F P
0 g
s
.811 .736 .781 r
.17896 .40701 m .17202 .41452 L .17673 .41749 L p F P
0 g
s
.811 .736 .781 r
.18036 .40785 m .17896 .40701 L p .17673 .41749 L F P
0 g
s
.829 .945 .899 r
.61087 .19727 m .60759 .19951 L .60471 .19882 L p F P
0 g
s
.855 .967 .871 r
.60096 .20576 m .60759 .19951 L .60471 .19882 L p F P
0 g
s
.722 .762 .885 r
.107 .45885 m .114 .45519 L .11863 .45815 L p F P
0 g
s
.716 .76 .887 r
.11812 .45306 m .114 .45519 L .11863 .45815 L p F P
0 g
s
.716 .76 .887 r
.11863 .45815 m .12182 .45654 L .11812 .45306 L p F P
0 g
s
.445 .382 .692 r
.58481 .31066 m .58374 .31164 L .58555 .31886 L p F P
0 g
s
.838 .731 .746 r
.19631 .37588 m .19964 .37137 L .19612 .36681 L p F P
0 g
s
.855 .967 .871 r
.60471 .19882 m .60344 .20026 L .60096 .20576 L p F P
0 g
s
0 0 0 r
.59604 .21246 m .5961 .21236 L .60096 .20576 L p F P
0 g
s
0 0 0 r
.60096 .20576 m .60344 .20026 L p .59604 .21246 L F P
0 g
s
.517 .577 .855 r
.70501 .22411 m .7154 .22457 L .7129 .22994 L p F P
0 g
s
.517 .58 .857 r
.7154 .22457 m .70501 .22411 L .70302 .22032 L p F P
0 g
s
.497 .435 .718 r
.59281 .34542 m .58794 .34409 L .59162 .34127 L closepath p F P
0 g
s
.498 .427 .707 r
.58965 .33433 m .59162 .34127 L .58794 .34409 L p F P
0 g
s
.498 .427 .707 r
.58891 .33408 m .58965 .33433 L p .58794 .34409 L F P
0 g
s
.553 .527 .781 r
.62673 .41083 m .62958 .4177 L .6177 .41792 L p F P
0 g
s
.553 .527 .781 r
.6177 .41792 m .61743 .41724 L .62673 .41083 L p F P
0 g
s
.567 .543 .787 r
.6177 .41792 m .62958 .4177 L p .62418 .42519 L F P
0 g
s
.473 .511 .816 r
.74695 .26292 m .74575 .26267 L .74637 .26159 L closepath p F P
0 g
s
.485 .526 .824 r
.74575 .26267 m .74637 .26159 L .74403 .25642 L p F P
0 g
s
.336 .294 .663 r
.78836 .34908 m .78592 .35221 L .78959 .35649 L p F P
0 g
s
.358 .324 .684 r
.78688 .34335 m .78602 .34252 L p .78592 .35221 L F P
0 g
s
.358 .324 .684 r
.78592 .35221 m .78836 .34908 L .78688 .34335 L p F P
0 g
s
.409 .412 .751 r
.77737 .31242 m .77546 .31142 L .77651 .30988 L closepath p F P
0 g
s
.425 .433 .764 r
.77432 .30375 m .77218 .30277 L p .77546 .31142 L F P
0 g
s
.425 .433 .764 r
.77546 .31142 m .77651 .30988 L .77432 .30375 L p F P
0 g
s
.552 .526 .78 r
.62652 .41031 m .62673 .41083 L .61743 .41724 L p F P
0 g
s
.552 .526 .78 r
.61743 .41724 m .61463 .41016 L .62652 .41031 L p F P
0 g
s
.89 .738 .686 r
.21019 .31156 m .21026 .31142 L .20964 .31089 L closepath p F P
0 g
s
.895 .735 .676 r
.20667 .30724 m .20905 .30201 L p .21026 .31142 L F P
0 g
s
.895 .735 .676 r
.21026 .31142 m .20964 .31089 L .20667 .30724 L p F P
0 g
s
.879 .74 .704 r
.20689 .31768 m .21019 .31156 L .20964 .31089 L p F P
0 g
s
.18 .051 .457 r
.78623 .38956 m .78334 .39276 L .78332 .39823 L p F P
0 g
s
.235 .127 .52 r
.78334 .39276 m .78623 .38956 L .78568 .384 L p F P
0 g
s
.512 .57 .851 r
.7129 .22994 m .72009 .23043 L .71718 .22469 L p F P
0 g
s
.512 .57 .851 r
.71718 .22469 m .7154 .22457 L .7129 .22994 L p F P
0 g
s
.824 .732 .763 r
.19081 .39267 m .19118 .39223 L .18765 .38775 L p F P
0 g
s
.618 .679 .886 r
.67514 .4578 m .67431 .45655 L .67787 .45581 L closepath p F P
0 g
s
.829 .737 .763 r
.18607 .38968 m .19081 .39267 L .18483 .39985 L p F P
0 g
s
.824 .732 .763 r
.18765 .38775 m .18607 .38968 L .19081 .39267 L p F P
0 g
s
.829 .945 .899 r
.60471 .19882 m .61323 .1918 L .61087 .19727 L p F P
0 g
s
.752 .836 .915 r
.61633 .18973 m .61323 .1918 L .61087 .19727 L p F P
0 g
s
.752 .836 .915 r
.61087 .19727 m .61924 .19243 L .61633 .18973 L p F P
0 g
s
.574 .555 .796 r
.62418 .42519 m .63262 .4248 L p .63442 .43171 L F P
0 g
s
.567 .552 .797 r
.63262 .4248 m .62418 .42519 L .63087 .42073 L closepath p F P
0 g
s
.567 .543 .787 r
.62958 .4177 m .63087 .42073 L .62418 .42519 L p F P
0 g
s
.794 .753 .815 r
.15177 .44136 m .1481 .44454 L .14446 .44076 L p F P
0 g
s
0 .083 .555 r
.04121 .44144 m .04206 .44215 L .0382 .4389 L p F P
0 g
s
0 .083 .555 r
.0382 .4389 m .03732 .43817 L .04121 .44144 L p F P
0 g
s
.081 0 .424 r
.58846 .23634 m .58946 .2349 L .58931 .22977 L p F P
0 g
s
.034 0 .408 r
.59302 .22391 m .58931 .22977 L .58946 .2349 L p F P
0 g
s
0 0 .275 r
.58931 .22977 m .59302 .22391 L .59384 .21846 L p F P
0 g
s
.799 .742 .799 r
.16957 .42507 m .17118 .42353 L .1676 .4194 L p F P
0 g
s
.794 .753 .815 r
.14446 .44076 m .14718 .43837 L .15177 .44136 L p F P
0 g
s
.787 .748 .817 r
.15597 .43079 m .14718 .43837 L .15177 .44136 L p F P
0 g
s
.787 .748 .817 r
.15177 .44136 m .15959 .43473 L .15597 .43079 L p F P
0 g
s
.535 .488 .75 r
.60535 .38483 m .60004 .38436 L .60421 .3815 L closepath p F P
0 g
s
.535 .479 .74 r
.60223 .37564 m .60421 .3815 L .60004 .38436 L p F P
0 g
s
.535 .479 .74 r
.59849 .37517 m .60223 .37564 L p .60004 .38436 L F P
0 g
s
.807 .749 .798 r
.16478 .42213 m .16957 .42507 L .16136 .43299 L p F P
0 g
s
.799 .742 .799 r
.1676 .4194 m .16478 .42213 L .16957 .42507 L p F P
0 g
s
.538 .606 .869 r
.69017 .21337 m .69921 .21329 L .6963 .20799 L p F P
0 g
s
.538 .606 .869 r
.6963 .20799 m .69232 .20807 L .69017 .21337 L p F P
0 g
s
.54 .611 .873 r
.68423 .20833 m .69232 .20807 L .69017 .21337 L p F P
0 g
s
.908 .747 .67 r
.20673 .28313 m .2104 .28663 L .20787 .29258 L p F P
0 g
s
.91 .745 .664 r
.2104 .28663 m .20673 .28313 L .20914 .27722 L p F P
0 g
s
.597 .744 .946 r
.07781 .45882 m .08854 .45646 L .09232 .45971 L p F P
0 g
s
.602 .745 .945 r
.08854 .45646 m .07781 .45882 L .074 .45564 L p F P
0 g
s
.457 .49 .805 r
.7524 .27025 m .76143 .27266 L .75832 .27807 L p F P
0 g
s
.459 .496 .81 r
.75529 .26489 m .7524 .27025 L .76143 .27266 L p F P
0 g
s
.465 .504 .814 r
.74695 .26292 m .75529 .26489 L .7524 .27025 L p F P
0 g
s
.876 .737 .705 r
.20349 .32396 m .20763 .32724 L .20416 .33355 L p F P
0 g
s
.875 .735 .704 r
.20763 .32724 m .20349 .32396 L .20689 .31768 L p F P
0 g
s
.435 .45 .776 r
.7713 .29555 m .76822 .29433 L p .77218 .30277 L F P
0 g
s
.435 .45 .776 r
.77218 .30277 m .77334 .301 L .7713 .29555 L p F P
0 g
s
.42 .43 .764 r
.77432 .30375 m .77218 .30277 L .77334 .301 L closepath p F P
0 g
s
.166 .081 .506 r
.58619 .24577 m .58894 .24192 L .58846 .23634 L p F P
0 g
s
.215 .143 .555 r
.58894 .24192 m .58619 .24577 L .58783 .25042 L p F P
0 g
s
.879 .74 .704 r
.20964 .31089 m .20623 .30808 L p .20689 .31768 L F P
0 g
s
.882 .738 .698 r
.20964 .31089 m .20667 .30724 L .20623 .30808 L closepath p F P
0 g
s
.753 .76 .858 r
.13307 .44936 m .12182 .45654 L .11812 .45306 L p F P
0 g
s
.808 .749 .797 r
.16136 .43299 m .15959 .43473 L .15597 .43079 L p F P
0 g
s
.808 .749 .797 r
.15597 .43079 m .15678 .42999 L .16136 .43299 L p F P
0 g
s
.807 .749 .798 r
.16136 .43299 m .15678 .42999 L .16478 .42213 L p F P
0 g
s
.462 .504 .816 r
.75529 .26489 m .74695 .26292 L .74637 .26159 L p F P
0 g
s
.838 .731 .746 r
.19612 .36681 m .19173 .37281 L .19631 .37588 L p F P
0 g
s
.843 .736 .745 r
.19173 .37281 m .19631 .37588 L .19128 .38275 L p F P
0 g
s
0 0 0 r
.76803 .42668 m .77105 .4225 L .76885 .42473 L closepath p F P
0 g
s
0 0 .09 r
.76885 .42473 m .77105 .4225 L .7747 .41592 L p F P
0 g
s
.579 .576 .813 r
.6478 .4373 m .63868 .4381 L .63566 .43162 L p F P
0 g
s
.205 .105 .513 r
.78745 .38188 m .78568 .384 L .78623 .38956 L p F P
0 g
s
.463 .396 .697 r
.58555 .31886 m .59093 .31397 L p .58991 .32403 L F P
0 g
s
.463 .396 .697 r
.58991 .32403 m .58648 .32247 L .58555 .31886 L p F P
0 g
s
.445 .382 .692 r
.58555 .31886 m .59093 .31397 L .58481 .31066 L p F P
0 g
s
.395 .328 .664 r
.5871 .28279 m .58374 .28628 L .58817 .29009 L p F P
0 g
s
.388 .318 .657 r
.58374 .28628 m .5871 .28279 L .58569 .27605 L p F P
0 g
s
.441 .383 .697 r
.59192 .3039 m .58481 .31066 L .59093 .31397 L p F P
0 g
s
.445 .372 .681 r
.58656 .30036 m .59192 .3039 L .58481 .31066 L p F P
0 g
s
.449 .475 .795 r
.75832 .27807 m .76532 .28019 L p .7636 .28609 L F P
0 g
s
.446 .477 .798 r
.75832 .27807 m .76532 .28019 L .76236 .27294 L p F P
0 g
s
.446 .477 .798 r
.76236 .27294 m .76143 .27266 L .75832 .27807 L p F P
0 g
s
.43 .447 .776 r
.7713 .29555 m .76822 .29433 L .76986 .29172 L closepath p F P
0 g
s
.444 .466 .788 r
.7683 .28773 m .7636 .28609 L p .76822 .29433 L F P
0 g
s
.444 .466 .788 r
.76822 .29433 m .76986 .29172 L .7683 .28773 L p F P
0 g
s
.004 0 .246 r
.78233 .404 m .77844 .40828 L .77796 .4126 L p F P
0 g
s
.105 0 .369 r
.77844 .40828 m .78233 .404 L .78332 .39823 L p F P
0 g
s
.046 0 .262 r
.7747 .41592 m .77796 .4126 L .77844 .40828 L p F P
0 g
s
.859 .735 .725 r
.19649 .35625 m .20088 .3594 L .19666 .36599 L p F P
0 g
s
.856 .733 .727 r
.20088 .3594 m .19649 .35625 L .20068 .34968 L p F P
0 g
s
.869 .735 .712 r
.20478 .3433 m .20489 .3431 L .20424 .3426 L closepath p F P
0 g
s
.872 .732 .705 r
.20127 .33878 m .20416 .33355 L p .20489 .3431 L F P
0 g
s
.872 .732 .705 r
.20489 .3431 m .20424 .3426 L .20127 .33878 L p F P
0 g
s
.439 .463 .788 r
.7683 .28773 m .7636 .28609 L .76606 .28201 L closepath p F P
0 g
s
.449 .475 .795 r
.76532 .28019 m .76606 .28201 L .7636 .28609 L p F P
0 g
s
.857 .735 .729 r
.20068 .34968 m .20478 .3433 L .20424 .3426 L p F P
0 g
s
.462 .504 .816 r
.74637 .26159 m .74851 .25733 L p .75529 .26489 L F P
0 g
s
.47 .517 .824 r
.74637 .26159 m .74403 .25642 L .74851 .25733 L closepath p F P
0 g
s
.618 .663 .871 r
.67787 .45581 m .67431 .45655 L .6714 .45184 L p F P
0 g
s
.662 .952 .951 r
.74424 .44699 m .73303 .4533 L .73038 .45196 L p F P
0 g
s
.544 .515 .773 r
.62344 .40257 m .62652 .41031 L .61463 .41016 L p F P
0 g
s
.544 .515 .773 r
.62141 .40249 m .62344 .40257 L p .61463 .41016 L F P
0 g
s
.544 .515 .773 r
.61463 .41016 m .61377 .4079 L .62141 .40249 L p F P
0 g
s
.673 .828 .396 r
.59597 .21259 m .59604 .21246 L .5961 .21236 L closepath p F P
0 g
s
0 0 0 r
.59604 .21246 m .59597 .21259 L .59384 .21846 L p F P
0 g
s
0 .387 .824 r
.04206 .44215 m .04739 .44463 L .05136 .44786 L p F P
0 g
s
0 .395 .833 r
.04739 .44463 m .04206 .44215 L .0382 .4389 L p F P
0 g
s
.46 .399 .702 r
.58746 .32619 m .58648 .32247 L .58991 .32403 L closepath p F P
0 g
s
.829 .737 .763 r
.18483 .39985 m .18022 .39683 L .18607 .38968 L p F P
0 g
s
.831 .737 .761 r
.18483 .39985 m .17934 .4066 L .17577 .40234 L p F P
0 g
s
.831 .737 .761 r
.17577 .40234 m .18022 .39683 L .18483 .39985 L p F P
0 g
s
.321 .248 .617 r
.58446 .26954 m .58804 .26535 L .5852 .26107 L p F P
0 g
s
.359 .285 .636 r
.58446 .26954 m .58804 .26535 L p .58589 .27583 L F P
0 g
s
.359 .285 .636 r
.58589 .27583 m .58557 .27545 L .58446 .26954 L p F P
0 g
s
.373 .364 .72 r
.78201 .32654 m .78381 .32385 L p .78528 .33308 L F P
0 g
s
.373 .364 .72 r
.78528 .33308 m .78363 .33187 L .78201 .32654 L p F P
0 g
s
.386 .384 .735 r
.78201 .32654 m .78047 .32173 L .78381 .32385 L closepath p F P
0 g
s
.385 .384 .736 r
.78381 .32385 m .78047 .32173 L .7794 .31838 L p F P
0 g
s
.385 .384 .736 r
.7794 .31838 m .78169 .31483 L p .78381 .32385 L F P
0 g
s
.397 .404 .75 r
.7794 .31838 m .77737 .31242 L .78169 .31483 L closepath p F P
0 g
s
.594 .603 .83 r
.65357 .44293 m .6564 .4483 L .65587 .44865 L p F P
0 g
s
.594 .613 .84 r
.65654 .44856 m .65587 .44865 L .6564 .4483 L closepath p F P
0 g
s
0 0 0 r
.59919 .20685 m .59604 .21246 L p .59861 .20822 L F P
0 g
s
0 0 0 r
.60344 .20026 m .59919 .20685 L p .59861 .20822 L F P
0 g
s
.775 .883 .464 r
.60397 .19886 m .60344 .20026 L .59919 .20685 L p F P
0 g
s
.775 .883 .464 r
.60188 .20041 m .60397 .19886 L p .59919 .20685 L F P
0 g
s
0 0 0 r
.59919 .20685 m .59693 .21277 L p .59978 .20545 L F P
0 g
s
.775 .883 .464 r
.60134 .20145 m .60188 .20041 L p .60077 .20308 L F P
0 g
s
.775 .883 .464 r
.59919 .20685 m .60134 .20145 L p .60077 .20308 L F P
0 g
s
0 0 0 r
.60134 .20145 m .5994 .20727 L p .6015 .201 L F P
0 g
s
.823 .911 .51 r
.60134 .20145 m .60155 .20082 L .60188 .20041 L closepath p F P
0 g
s
0 0 0 r
.60155 .20082 m .60134 .20145 L p .6015 .201 L F P
0 g
s
0 0 0 r
.60134 .20145 m .59919 .20685 L p .59978 .20545 L F P
0 g
s
0 0 0 r
.59919 .20685 m .59604 .21246 L .59503 .21618 L p F P
0 g
s
0 0 0 r
.59384 .21846 m .59503 .21618 L .59604 .21246 L p F P
0 g
s
.544 .514 .773 r
.61377 .4079 m .61155 .40207 L .62141 .40249 L closepath p F P
0 g
s
.898 .742 .68 r
.20905 .30201 m .20667 .30724 L .20311 .30323 L p F P
0 g
s
.898 .742 .68 r
.20311 .30323 m .20523 .29858 L .20905 .30201 L p F P
0 g
s
.9 .741 .675 r
.20905 .30201 m .20523 .29858 L .20787 .29258 L p F P
0 g
s
.812 .735 .779 r
.18036 .40785 m .17934 .4066 L .17896 .40701 L closepath p F P
0 g
s
.725 .765 .884 r
.114 .45519 m .107 .45885 L .10326 .45549 L p F P
0 g
s
.675 .759 .914 r
.09232 .45971 m .10326 .45549 L .107 .45885 L p F P
0 g
s
.678 .76 .913 r
.10326 .45549 m .09232 .45971 L .08854 .45646 L p F P
0 g
s
.373 .364 .72 r
.78438 .33437 m .78363 .33187 L .78528 .33308 L closepath p F P
0 g
s
0 0 .028 r
.77796 .4126 m .7747 .41592 L .77105 .4225 L p F P
0 g
s
.857 .735 .729 r
.20424 .3426 m .20055 .33991 L p .20068 .34968 L F P
0 g
s
.858 .733 .724 r
.20424 .3426 m .20127 .33878 L .20055 .33991 L closepath p F P
0 g
s
.527 .476 .743 r
.60223 .37564 m .59849 .37517 L .6014 .37312 L closepath p F P
0 g
s
.527 .468 .733 r
.5991 .36605 m .6014 .37312 L .59849 .37517 L p F P
0 g
s
.527 .468 .733 r
.59752 .36579 m .5991 .36605 L p .59849 .37517 L F P
0 g
s
.397 .404 .75 r
.78169 .31483 m .77737 .31242 L .77651 .30988 L p F P
0 g
s
.494 .547 .84 r
.72323 .23668 m .72344 .23623 L p .73259 .243 L F P
0 g
s
.501 .558 .846 r
.72323 .23668 m .72299 .23619 L .72344 .23623 L closepath p F P
0 g
s
.296 .237 .62 r
.58998 .25492 m .5852 .26107 L .58804 .26535 L p F P
0 g
s
.267 .194 .585 r
.5852 .26107 m .58998 .25492 L .58783 .25042 L p F P
0 g
s
.353 .337 .702 r
.78528 .33308 m .78438 .33437 L .7865 .34189 L p F P
0 g
s
.374 .35 .704 r
.78602 .34252 m .7865 .34189 L .78438 .33437 L p F P
0 g
s
.351 .32 .684 r
.78688 .34335 m .78602 .34252 L .7865 .34189 L closepath p F P
0 g
s
.596 .639 .864 r
.65654 .44856 m .66846 .44683 L .6714 .45184 L p F P
0 g
s
.588 .61 .842 r
.66559 .44171 m .66846 .44683 L .65654 .44856 L p F P
0 g
s
.588 .61 .842 r
.65654 .44856 m .6564 .4483 L .66559 .44171 L p F P
0 g
s
.517 .58 .857 r
.70302 .22032 m .7037 .21866 L p .7154 .22457 L F P
0 g
s
.523 .589 .862 r
.70302 .22032 m .70211 .21862 L .7037 .21866 L closepath p F P
0 g
s
.462 .403 .705 r
.58991 .32403 m .58746 .32619 L .58946 .33364 L p F P
0 g
s
.483 .416 .706 r
.58891 .33408 m .58946 .33364 L .58746 .32619 L p F P
0 g
s
.634 .702 .895 r
.63391 .19122 m .64575 .18802 L .64867 .19226 L p F P
0 g
s
.647 .715 .897 r
.64575 .18802 m .63391 .19122 L .63099 .18751 L p F P
0 g
s
.691 .754 .9 r
.61924 .19243 m .63099 .18751 L .63391 .19122 L p F P
0 g
s
.542 .615 .875 r
.69232 .20807 m .68423 .20833 L .68132 .20326 L p F P
0 g
s
.397 .404 .75 r
.77651 .30988 m .77892 .30599 L p .78169 .31483 L F P
0 g
s
.408 .422 .763 r
.77651 .30988 m .77432 .30375 L .77892 .30599 L closepath p F P
0 g
s
.571 .643 .882 r
.67841 .19825 m .66642 .19945 L .6635 .19474 L p F P
0 g
s
.562 .639 .884 r
.66642 .19945 m .67841 .19825 L p .6762 .20365 L F P
0 g
s
.597 .672 .892 r
.65661 .1958 m .6635 .19474 L .66059 .1901 L p F P
0 g
s
.597 .672 .892 r
.66059 .1901 m .65882 .19041 L .65661 .1958 L p F P
0 g
s
.59 .676 .899 r
.64867 .19226 m .65882 .19041 L .65661 .1958 L p F P
0 g
s
.587 .609 .841 r
.66551 .44155 m .66559 .44171 L .6564 .4483 L p F P
0 g
s
.587 .609 .841 r
.6564 .4483 m .65357 .44293 L .66551 .44155 L p F P
0 g
s
.499 .56 .849 r
.72344 .23623 m .72299 .23619 L .72009 .23043 L p F P
0 g
s
.716 .775 .899 r
.63099 .18751 m .61924 .19243 L .61633 .18973 L p F P
0 g
s
.156 .073 .503 r
.58946 .2349 m .58846 .23634 L .58894 .24192 L p F P
0 g
s
.486 .421 .71 r
.58965 .33433 m .58891 .33408 L .58946 .33364 L closepath p F P
0 g
s
.412 .681 .973 r
.05974 .45238 m .06683 .45256 L .07092 .45573 L p F P
0 g
s
.421 .683 .971 r
.06683 .45256 m .05974 .45238 L .0559 .44921 L p F P
0 g
s
.283 .216 .603 r
.79136 .36255 m .78809 .36661 L .79043 .37133 L p F P
0 g
s
.314 .259 .635 r
.79033 .35761 m .78959 .35649 L p .78809 .36661 L F P
0 g
s
.314 .259 .635 r
.78809 .36661 m .79136 .36255 L .79033 .35761 L p F P
0 g
s
.56 .627 .875 r
.68132 .20326 m .6762 .20365 L .67849 .1984 L closepath p F P
0 g
s
.562 .639 .884 r
.67841 .19825 m .67849 .1984 L .6762 .20365 L p F P
0 g
s
.494 .547 .84 r
.72344 .23623 m .73521 .23763 L .73259 .243 L p F P
0 g
s
.498 .554 .844 r
.72571 .23096 m .72344 .23623 L .73521 .23763 L p F P
0 g
s
.499 .56 .849 r
.72009 .23043 m .72571 .23096 L .72344 .23623 L p F P
0 g
s
.881 .743 .705 r
.20288 .31434 m .20689 .31768 L .20349 .32396 L p F P
0 g
s
.879 .74 .704 r
.20623 .30808 m .20288 .31434 L .20689 .31768 L p F P
0 g
s
.545 .508 .765 r
.62141 .40249 m .61155 .40207 L .61037 .39886 L p F P
0 g
s
.574 .564 .804 r
.63566 .43162 m .63442 .43171 L .63541 .43107 L closepath p F P
0 g
s
.574 .555 .796 r
.63262 .4248 m .63541 .43107 L .63442 .43171 L p F P
0 g
s
.844 .736 .745 r
.19128 .38275 m .18765 .38775 L .1841 .3834 L p F P
0 g
s
.844 .736 .745 r
.1841 .3834 m .1868 .37965 L .19128 .38275 L p F P
0 g
s
.843 .736 .745 r
.19128 .38275 m .1868 .37965 L .19173 .37281 L p F P
0 g
s
.407 .422 .764 r
.77892 .30599 m .77432 .30375 L .77334 .301 L p F P
0 g
s
.147 .533 .921 r
.05136 .44786 m .0559 .44921 L .05205 .44599 L p F P
0 g
s
.147 .533 .921 r
.05205 .44599 m .04739 .44463 L .05136 .44786 L p F P
0 g
s
.335 .31 .682 r
.7865 .34189 m .78986 .33705 L p .79009 .34666 L F P
0 g
s
.335 .31 .682 r
.79009 .34666 m .78688 .34335 L .7865 .34189 L p F P
0 g
s
.353 .337 .702 r
.7865 .34189 m .78986 .33705 L .78528 .33308 L p F P
0 g
s
.814 .739 .781 r
.17896 .40701 m .17934 .4066 L .17577 .40234 L p F P
0 g
s
.545 .508 .765 r
.61037 .39886 m .61673 .39425 L p .62141 .40249 L F P
0 g
s
.536 .502 .765 r
.61037 .39886 m .60845 .39363 L .61673 .39425 L closepath p F P
0 g
s
.82 .745 .781 r
.17424 .40402 m .17896 .40701 L .17202 .41452 L p F P
0 g
s
.814 .739 .781 r
.17577 .40234 m .17424 .40402 L .17896 .40701 L p F P
0 g
s
.479 .417 .71 r
.58946 .33364 m .59693 .32709 L p .59677 .33689 L F P
0 g
s
.479 .417 .71 r
.59677 .33689 m .58965 .33433 L .58946 .33364 L p F P
0 g
s
.462 .403 .705 r
.58946 .33364 m .59693 .32709 L .58991 .32403 L p F P
0 g
s
.634 .748 .93 r
.6891 .45811 m .70103 .45501 L .70384 .45835 L p F P
0 g
s
.624 .721 .916 r
.70103 .45501 m .6891 .45811 L .68623 .45407 L p F P
0 g
s
.407 .422 .764 r
.77334 .301 m .77551 .29736 L p .77892 .30599 L F P
0 g
s
.418 .44 .776 r
.77334 .301 m .7713 .29555 L .77551 .29736 L closepath p F P
0 g
s
.618 .68 .887 r
.68623 .45407 m .67787 .45581 L .68428 .45112 L closepath p F P
0 g
s
.618 .663 .871 r
.68334 .4497 m .68428 .45112 L .67787 .45581 L p F P
0 g
s
.618 .663 .871 r
.6714 .45184 m .68334 .4497 L p .67787 .45581 L F P
0 g
s
.522 .592 .865 r
.7037 .21866 m .70211 .21862 L .69921 .21329 L p F P
0 g
s
.476 .42 .716 r
.59162 .34127 m .58965 .33433 L .59677 .33689 L closepath p F P
0 g
s
.875 .738 .707 r
.20416 .33355 m .20127 .33878 L .19772 .33447 L p F P
0 g
s
.875 .738 .707 r
.19772 .33447 m .20005 .33026 L .20416 .33355 L p F P
0 g
s
.876 .737 .705 r
.20416 .33355 m .20005 .33026 L .20349 .32396 L p F P
0 g
s
.336 .31 .681 r
.78836 .34908 m .78688 .34335 L .79009 .34666 L closepath p F P
0 g
s
.78 .761 .836 r
.13567 .44737 m .13307 .44936 L .12939 .44575 L p F P
0 g
s
.753 .76 .858 r
.11812 .45306 m .12939 .44575 L .13307 .44936 L p F P
0 g
s
.472 .703 .969 r
.07092 .45573 m .074 .45564 L .07019 .45244 L p F P
0 g
s
.472 .703 .969 r
.07019 .45244 m .06683 .45256 L .07092 .45573 L p F P
0 g
s
.579 .576 .813 r
.63566 .43162 m .64757 .43084 L p .6478 .4373 L F P
0 g
s
.564 .558 .806 r
.64461 .4245 m .64757 .43084 L .63566 .43162 L p F P
0 g
s
.564 .558 .806 r
.63566 .43162 m .63541 .43107 L .64461 .4245 L p F P
0 g
s
.47 .518 .825 r
.74851 .25733 m .74403 .25642 L .74111 .24998 L p F P
0 g
s
.856 .737 .731 r
.19612 .36681 m .19666 .36599 L .19377 .36388 L closepath p F P
0 g
s
.859 .735 .725 r
.19259 .36239 m .19649 .35625 L p .19666 .36599 L F P
0 g
s
.859 .735 .725 r
.19666 .36599 m .19377 .36388 L .19259 .36239 L p F P
0 g
s
.861 .739 .727 r
.19638 .34648 m .20068 .34968 L .19649 .35625 L p F P
0 g
s
.857 .735 .729 r
.20055 .33991 m .19638 .34648 L .20068 .34968 L p F P
0 g
s
.667 .857 .972 r
.72618 .45377 m .71851 .45696 L .71576 .45445 L p F P
0 g
s
.654 .815 .961 r
.70384 .45835 m .71576 .45445 L .71851 .45696 L p F P
0 g
s
.906 .749 .676 r
.20419 .28908 m .20787 .29258 L .20523 .29858 L p F P
0 g
s
.908 .747 .67 r
.20787 .29258 m .20419 .28908 L .20673 .28313 L p F P
0 g
s
.78 .761 .836 r
.12939 .44575 m .13122 .44433 L .13567 .44737 L p F P
0 g
s
.773 .756 .837 r
.1408 .43702 m .13122 .44433 L .13567 .44737 L p F P
0 g
s
.773 .756 .837 r
.13567 .44737 m .14446 .44076 L .1408 .43702 L p F P
0 g
s
.598 .686 .904 r
.65882 .19041 m .64867 .19226 L .64575 .18802 L p F P
0 g
s
.563 .557 .805 r
.64456 .42438 m .64461 .4245 L .63541 .43107 L p F P
0 g
s
.563 .557 .805 r
.63541 .43107 m .63262 .4248 L .64456 .42438 L p F P
0 g
s
.352 .283 .638 r
.58569 .27605 m .58557 .27545 L .58589 .27583 L closepath p F P
0 g
s
.537 .496 .758 r
.61673 .39425 m .60845 .39363 L .60719 .39007 L p F P
0 g
s
.842 .737 .747 r
.19173 .37281 m .19612 .36681 L .19377 .36388 L p F P
0 g
s
.518 .464 .735 r
.5991 .36605 m .59752 .36579 L .59874 .36491 L closepath p F P
0 g
s
.519 .456 .725 r
.59623 .35687 m .59874 .36491 L .59752 .36579 L p F P
0 g
s
.49 .431 .718 r
.59162 .34127 m .59677 .33689 L p .59677 .34661 L F P
0 g
s
.49 .431 .718 r
.59677 .34661 m .59281 .34542 L .59162 .34127 L p F P
0 g
s
.367 .304 .654 r
.58589 .27583 m .58569 .27605 L .5871 .28279 L p F P
0 g
s
.358 .344 .708 r
.78896 .32764 m .78528 .33308 L .78986 .33705 L p F P
0 g
s
.373 .364 .72 r
.78381 .32385 m .78896 .32764 L .78528 .33308 L p F P
0 g
s
.644 .78 .946 r
.71576 .45445 m .70384 .45835 L .70103 .45501 L p F P
0 g
s
.106 0 .37 r
.78648 .39475 m .78332 .39823 L .78233 .404 L p F P
0 g
s
.18 .051 .457 r
.78332 .39823 m .78648 .39475 L .78623 .38956 L p F P
0 g
s
.537 .496 .758 r
.60719 .39007 m .6131 .38568 L p .61673 .39425 L F P
0 g
s
.527 .489 .757 r
.60719 .39007 m .60535 .38483 L .6131 .38568 L closepath p F P
0 g
s
.821 .744 .778 r
.17202 .41452 m .1676 .4194 L .164 .41534 L p F P
0 g
s
.821 .744 .778 r
.164 .41534 m .16745 .41148 L .17202 .41452 L p F P
0 g
s
.82 .745 .781 r
.17202 .41452 m .16745 .41148 L .17424 .40402 L p F P
0 g
s
.205 .105 .513 r
.78623 .38956 m .7883 .38708 L .78745 .38188 L p F P
0 g
s
.203 .104 .513 r
.79208 .37628 m .78745 .38188 L .7883 .38708 L p F P
0 g
s
.249 .167 .564 r
.78745 .38188 m .79208 .37628 L .79043 .37133 L p F P
0 g
s
.417 .355 .68 r
.58883 .2906 m .58817 .29009 L p .58656 .30036 L F P
0 g
s
.417 .355 .68 r
.58656 .30036 m .59027 .29668 L .58883 .2906 L p F P
0 g
s
.422 .361 .684 r
.59027 .29668 m .58656 .30036 L .59192 .3039 L p F P
0 g
s
.418 .44 .776 r
.77551 .29736 m .7713 .29555 L .76986 .29172 L p F P
0 g
s
.725 .765 .884 r
.10326 .45549 m .10953 .45216 L .114 .45519 L p F P
0 g
s
.72 .762 .886 r
.1144 .44959 m .10953 .45216 L .114 .45519 L p F P
0 g
s
.72 .762 .886 r
.114 .45519 m .11812 .45306 L .1144 .44959 L p F P
0 g
s
.829 .738 .764 r
.18607 .38968 m .18765 .38775 L .1841 .3834 L p F P
0 g
s
.346 .294 .656 r
.59125 .26953 m .58589 .27583 L .58978 .27979 L p F P
0 g
s
.359 .285 .636 r
.58804 .26535 m .59125 .26953 L .58589 .27583 L p F P
0 g
s
.367 .304 .654 r
.5871 .28279 m .58978 .27979 L .58589 .27583 L p F P
0 g
s
.662 .952 .951 r
.74467 .44662 m .74424 .44699 L p .73038 .45196 L F P
0 g
s
.689 .975 .912 r
.74424 .44699 m .74467 .44662 L .74482 .44663 L closepath p F P
0 g
s
.487 .434 .724 r
.59387 .34901 m .59281 .34542 L .59677 .34661 L closepath p F P
0 g
s
0 0 0 r
.77105 .4225 m .77682 .41664 L p .76736 .42787 L F P
0 g
s
0 0 0 r
.76736 .42787 m .76803 .42668 L .77105 .4225 L p F P
0 g
s
0 0 .028 r
.77713 .41612 m .77796 .4126 L p .77105 .4225 L F P
0 g
s
0 0 .028 r
.77105 .4225 m .77682 .41664 L .77713 .41612 L p F P
0 g
s
.888 .746 .699 r
.20623 .30808 m .20667 .30724 L .20311 .30323 L p F P
0 g
s
.504 .877 .669 r
.74482 .44663 m .75652 .43824 L .75673 .43812 L p F P
0 g
s
.75 .987 .897 r
.74467 .44662 m .74482 .44663 L .75652 .43824 L p F P
0 g
s
.517 .58 .857 r
.7037 .21866 m .71428 .2191 L p .7154 .22457 L F P
0 g
s
.518 .586 .862 r
.7037 .21866 m .71428 .2191 L .71138 .21361 L p F P
0 g
s
.518 .586 .862 r
.71138 .21361 m .70573 .21341 L .7037 .21866 L p F P
0 g
s
.522 .592 .865 r
.69921 .21329 m .70573 .21341 L .7037 .21866 L p F P
0 g
s
.312 .278 .659 r
.79009 .34666 m .78836 .34908 L .78999 .35598 L p F P
0 g
s
.336 .294 .663 r
.78959 .35649 m .78999 .35598 L .78836 .34908 L p F P
0 g
s
.156 .073 .503 r
.58894 .24192 m .59044 .23976 L .58946 .2349 L p F P
0 g
s
.103 .033 .485 r
.59316 .22904 m .58946 .2349 L .59044 .23976 L p F P
0 g
s
.034 0 .408 r
.58946 .2349 m .59316 .22904 L .59302 .22391 L p F P
0 g
s
.529 .484 .75 r
.6131 .38568 m .60535 .38483 L .60421 .3815 L p F P
0 g
s
.5 .444 .725 r
.59387 .34901 m .59677 .34661 L p .59699 .35626 L F P
0 g
s
.5 .444 .725 r
.59699 .35626 m .59596 .356 L .59387 .34901 L p F P
0 g
s
.487 .538 .835 r
.73259 .243 m .73819 .24381 L .73528 .23764 L p F P
0 g
s
.487 .538 .835 r
.73528 .23764 m .73521 .23763 L .73259 .243 L p F P
0 g
s
.834 .742 .763 r
.18148 .38662 m .18607 .38968 L .18022 .39683 L p F P
0 g
s
.829 .738 .764 r
.1841 .3834 m .18148 .38662 L .18607 .38968 L p F P
0 g
s
0 0 .216 r
.59503 .21618 m .59384 .21846 L .59302 .22391 L p F P
0 g
s
.529 .484 .75 r
.60421 .3815 m .61033 .37685 L p .6131 .38568 L F P
0 g
s
.519 .477 .75 r
.60421 .3815 m .60223 .37564 L .61033 .37685 L closepath p F P
0 g
s
.886 .749 .705 r
.20237 .30467 m .20623 .30808 L .20288 .31434 L p F P
0 g
s
.888 .746 .699 r
.20311 .30323 m .20237 .30467 L .20623 .30808 L p F P
0 g
s
.803 .746 .799 r
.16478 .42213 m .1676 .4194 L .164 .41534 L p F P
0 g
s
.145 .026 .447 r
.7883 .38708 m .78623 .38956 L .78648 .39475 L p F P
0 g
s
.75 .987 .897 r
.75403 .43883 m .75075 .44096 L .74467 .44662 L p F P
0 g
s
.75 .987 .897 r
.75652 .43824 m .75403 .43883 L p .74467 .44662 L F P
0 g
s
.718 .966 .938 r
.74223 .44601 m .75075 .44096 L .74467 .44662 L closepath p F P
0 g
s
.662 .952 .951 r
.73038 .45196 m .74223 .44601 L .74467 .44662 L p F P
0 g
s
.418 .44 .776 r
.76986 .29172 m .77146 .28892 L p .77551 .29736 L F P
0 g
s
.428 .456 .787 r
.76986 .29172 m .7683 .28773 L .77146 .28892 L closepath p F P
0 g
s
.813 .752 .795 r
.16013 .41913 m .16478 .42213 L .15678 .42999 L p F P
0 g
s
.803 .746 .799 r
.164 .41534 m .16013 .41913 L .16478 .42213 L p F P
0 g
s
.797 .756 .815 r
.14718 .43837 m .14446 .44076 L .1408 .43702 L p F P
0 g
s
.498 .448 .732 r
.59623 .35687 m .59596 .356 L .59699 .35626 L closepath p F P
0 g
s
.499 .451 .734 r
.59699 .35626 m .59623 .35687 L .59874 .36491 L p F P
0 g
s
.52 .472 .743 r
.61033 .37685 m .60223 .37564 L .6014 .37312 L p F P
0 g
s
.797 .756 .815 r
.1408 .43702 m .1427 .43533 L .14718 .43837 L p F P
0 g
s
.791 .752 .817 r
.15231 .42694 m .1427 .43533 L .14718 .43837 L p F P
0 g
s
.791 .752 .817 r
.15248 .42705 m .15231 .42694 L p .14718 .43837 L F P
0 g
s
.791 .752 .817 r
.14718 .43837 m .15597 .43079 L .15248 .42705 L p F P
0 g
s
.509 .464 .742 r
.6014 .37312 m .5991 .36605 L .60824 .36779 L closepath p F P
0 g
s
.52 .472 .743 r
.6014 .37312 m .60824 .36779 L p .61033 .37685 L F P
0 g
s
.511 .46 .736 r
.59874 .36491 m .60667 .35856 L p .60824 .36779 L F P
0 g
s
.511 .46 .736 r
.60824 .36779 m .5991 .36605 L .59874 .36491 L p F P
0 g
s
.499 .451 .734 r
.59874 .36491 m .60667 .35856 L .59699 .35626 L p F P
0 g
s
.598 .654 .877 r
.68334 .4497 m .6714 .45184 L .66846 .44683 L p F P
0 g
s
.459 .405 .71 r
.59589 .31857 m .58991 .32403 L .59693 .32709 L p F P
0 g
s
.463 .396 .697 r
.59524 .31621 m .59589 .31857 L .58991 .32403 L p F P
0 g
s
.463 .396 .697 r
.59093 .31397 m .59524 .31621 L p .58991 .32403 L F P
0 g
s
.579 .606 .844 r
.66551 .44155 m .65357 .44293 L .65058 .43705 L p F P
0 g
s
.81 .753 .799 r
.15597 .43079 m .15678 .42999 L .15248 .42705 L closepath p F P
0 g
s
.813 .752 .795 r
.15234 .4269 m .16013 .41913 L p .15678 .42999 L F P
0 g
s
.813 .752 .795 r
.15678 .42999 m .15248 .42705 L .15234 .4269 L p F P
0 g
s
0 0 0 r
.76549 .42966 m .76736 .42787 L .76803 .42668 L closepath p F P
0 g
s
.602 .923 .687 r
.75652 .43824 m .75727 .43761 L .75673 .43812 L closepath p F P
0 g
s
.557 .848 .524 r
.76549 .42966 m .75727 .43761 L .75673 .43812 L p F P
0 g
s
.881 .744 .706 r
.19949 .32062 m .20349 .32396 L .20005 .33026 L p F P
0 g
s
.881 .743 .705 r
.20349 .32396 m .19949 .32062 L .20288 .31434 L p F P
0 g
s
.842 .737 .747 r
.19227 .36284 m .18731 .36968 L .19173 .37281 L p F P
0 g
s
.842 .737 .747 r
.19377 .36388 m .19227 .36284 L p .19173 .37281 L F P
0 g
s
.848 .741 .745 r
.18731 .36968 m .19173 .37281 L .1868 .37965 L p F P
0 g
s
.863 .74 .726 r
.20055 .33991 m .20127 .33878 L .19772 .33447 L p F P
0 g
s
.307 .255 .634 r
.79033 .35761 m .78959 .35649 L .78999 .35598 L closepath p F P
0 g
s
.371 .367 .725 r
.78738 .31842 m .78381 .32385 L .78896 .32764 L p F P
0 g
s
.385 .384 .736 r
.78169 .31483 m .78738 .31842 L .78381 .32385 L p F P
0 g
s
.499 .562 .85 r
.72571 .23096 m .72009 .23043 L .71718 .22469 L p F P
0 g
s
.755 .762 .858 r
.12939 .44575 m .11812 .45306 L .1144 .44959 L p F P
0 g
s
.248 .185 .587 r
.58968 .24783 m .58783 .25042 L .58998 .25492 L p F P
0 g
s
.215 .143 .555 r
.58783 .25042 m .58968 .24783 L .58894 .24192 L p F P
0 g
s
.602 .745 .945 r
.074 .45564 m .08476 .45319 L .08854 .45646 L p F P
0 g
s
.605 .746 .944 r
.08476 .45319 m .074 .45564 L .07019 .45244 L p F P
0 g
s
.428 .456 .787 r
.77146 .28892 m .7683 .28773 L .76606 .28201 L p F P
0 g
s
.556 .546 .798 r
.64152 .41757 m .64456 .42438 L .63262 .4248 L p F P
0 g
s
.556 .546 .798 r
.63508 .41765 m .64152 .41757 L p .63262 .4248 L F P
0 g
s
.556 .546 .798 r
.63262 .4248 m .63087 .42073 L .63508 .41765 L p F P
0 g
s
.582 .902 .645 r
.76736 .42787 m .76549 .42966 L .75727 .43761 L p F P
0 g
s
.498 .453 .738 r
.60498 .34967 m .59699 .35626 L .60667 .35856 L p F P
0 g
s
.5 .444 .725 r
.60475 .34895 m .60498 .34967 L .59699 .35626 L p F P
0 g
s
.5 .444 .725 r
.59677 .34661 m .60475 .34895 L p .59699 .35626 L F P
0 g
s
.861 .739 .727 r
.19649 .35625 m .19259 .36239 L .18903 .35811 L p F P
0 g
s
.861 .739 .727 r
.18903 .35811 m .19223 .35304 L .19649 .35625 L p F P
0 g
s
.861 .739 .727 r
.19649 .35625 m .19223 .35304 L .19638 .34648 L p F P
0 g
s
.864 .743 .728 r
.19636 .33666 m .20055 .33991 L .19638 .34648 L p F P
0 g
s
.863 .74 .726 r
.19772 .33447 m .19636 .33666 L .20055 .33991 L p F P
0 g
s
.373 .314 .662 r
.58978 .27979 m .5871 .28279 L .5886 .28963 L p F P
0 g
s
.395 .328 .664 r
.58817 .29009 m .5886 .28963 L .5871 .28279 L p F P
0 g
s
.542 .615 .875 r
.68132 .20326 m .6934 .20277 L p .69232 .20807 L F P
0 g
s
.541 .617 .878 r
.69049 .19772 m .6934 .20277 L .68132 .20326 L p F P
0 g
s
.541 .617 .878 r
.67854 .19825 m .69049 .19772 L p .68132 .20326 L F P
0 g
s
.541 .617 .878 r
.68132 .20326 m .67849 .1984 L .67854 .19825 L p F P
0 g
s
.203 .134 .551 r
.59044 .23976 m .58894 .24192 L .58968 .24783 L p F P
0 g
s
.67 .971 .799 r
.75727 .43761 m .75652 .43824 L .75403 .43883 L p F P
0 g
s
.67 .971 .799 r
.75403 .43883 m .76332 .4317 L .75727 .43761 L p F P
0 g
s
.582 .902 .645 r
.76572 .42958 m .76736 .42787 L p .75727 .43761 L F P
0 g
s
.582 .902 .645 r
.75727 .43761 m .76332 .4317 L .76572 .42958 L p F P
0 g
s
.834 .742 .763 r
.18022 .39683 m .17574 .39374 L .18148 .38662 L p F P
0 g
s
.835 .742 .761 r
.18022 .39683 m .17577 .40234 L .17219 .39819 L p F P
0 g
s
.835 .742 .761 r
.17219 .39819 m .17574 .39374 L .18022 .39683 L p F P
0 g
s
.47 .518 .825 r
.74111 .24998 m .74111 .24998 L p .74851 .25733 L F P
0 g
s
.478 .53 .832 r
.74111 .24998 m .7411 .24997 L .74111 .24998 L closepath p F P
0 g
s
.476 .532 .835 r
.74111 .24998 m .7411 .24997 L .73819 .24381 L p F P
0 g
s
.47 .518 .825 r
.74111 .24998 m .75114 .25201 L .74851 .25733 L p F P
0 g
s
.473 .524 .83 r
.74348 .24471 m .74111 .24998 L .75114 .25201 L p F P
0 g
s
.476 .532 .835 r
.73819 .24381 m .74348 .24471 L .74111 .24998 L p F P
0 g
s
.288 .242 .631 r
.78999 .35598 m .79357 .35101 L p .79249 .36103 L F P
0 g
s
.288 .242 .631 r
.79249 .36103 m .79033 .35761 L .78999 .35598 L p F P
0 g
s
.312 .278 .659 r
.78999 .35598 m .79357 .35101 L .79009 .34666 L p F P
0 g
s
.667 .857 .972 r
.72931 .45121 m .72618 .45377 L p .71576 .45445 L F P
0 g
s
.692 .876 .967 r
.72618 .45377 m .72931 .45121 L .73038 .45196 L closepath p F P
0 g
s
.571 .643 .882 r
.6635 .19474 m .6755 .19343 L .67841 .19825 L p F P
0 g
s
.574 .648 .885 r
.6755 .19343 m .6635 .19474 L .66059 .1901 L p F P
0 g
s
0 .395 .833 r
.0382 .4389 m .04349 .44135 L .04739 .44463 L p F P
0 g
s
.579 .585 .823 r
.65058 .43705 m .6478 .4373 L .64998 .4358 L closepath p F P
0 g
s
.579 .576 .813 r
.64757 .43084 m .64998 .4358 L .6478 .4373 L p F P
0 g
s
.844 .735 .744 r
.19377 .36388 m .19259 .36239 L .19227 .36284 L closepath p F P
0 g
s
.904 .75 .681 r
.20523 .29858 m .20311 .30323 L .19951 .29955 L p F P
0 g
s
.904 .75 .681 r
.19951 .29955 m .20155 .29509 L .20523 .29858 L p F P
0 g
s
.906 .749 .676 r
.20523 .29858 m .20155 .29509 L .20419 .28908 L p F P
0 g
s
.384 .388 .741 r
.78513 .30941 m .78169 .31483 L .78738 .31842 L p F P
0 g
s
.397 .404 .75 r
.77892 .30599 m .78513 .30941 L .78169 .31483 L p F P
0 g
s
.727 .766 .884 r
.10953 .45216 m .10326 .45549 L .09951 .45214 L p F P
0 g
s
.678 .76 .913 r
.08854 .45646 m .09951 .45214 L .10326 .45549 L p F P
0 g
s
.289 .242 .631 r
.79136 .36255 m .79033 .35761 L .79249 .36103 L closepath p F P
0 g
s
.523 .595 .867 r
.70573 .21341 m .69921 .21329 L .6963 .20799 L p F P
0 g
s
.681 .761 .912 r
.09951 .45214 m .08854 .45646 L .08476 .45319 L p F P
0 g
s
0 0 .077 r
.77713 .41612 m .78022 .41012 L .77796 .4126 L closepath p F P
0 g
s
.004 0 .246 r
.77796 .4126 m .78022 .41012 L .78233 .404 L p F P
0 g
s
.556 .545 .798 r
.63087 .42073 m .62958 .4177 L .63508 .41765 L closepath p F P
0 g
s
.428 .456 .787 r
.76606 .28201 m .76679 .28068 L p .77146 .28892 L F P
0 g
s
.437 .472 .798 r
.76606 .28201 m .76532 .28019 L .76679 .28068 L closepath p F P
0 g
s
.774 .996 .861 r
.60397 .19886 m .60471 .19882 L .61323 .1918 L p F P
0 g
s
.878 .99 .81 r
.60344 .20026 m .60397 .19886 L .60471 .19882 L closepath p F P
0 g
s
.647 .715 .897 r
.63099 .18751 m .64283 .1839 L .64575 .18802 L p F P
0 g
s
.663 .729 .899 r
.64283 .1839 m .63099 .18751 L .62807 .184 L p F P
0 g
s
.716 .775 .899 r
.61633 .18973 m .62807 .184 L .63099 .18751 L p F P
0 g
s
.404 .342 .674 r
.58883 .2906 m .58817 .29009 L .5886 .28963 L closepath p F P
0 g
s
.462 .504 .816 r
.74851 .25733 m .75646 .25915 L p .75529 .26489 L F P
0 g
s
.461 .507 .82 r
.74851 .25733 m .75646 .25915 L .75353 .25256 L p F P
0 g
s
.461 .507 .82 r
.75353 .25256 m .75114 .25201 L .74851 .25733 L p F P
0 g
s
.818 .744 .781 r
.17424 .40402 m .17577 .40234 L .17219 .39819 L p F P
0 g
s
.848 .741 .745 r
.1868 .37965 m .1841 .3834 L .18053 .37919 L p F P
0 g
s
.848 .741 .745 r
.18053 .37919 m .18245 .3765 L .1868 .37965 L p F P
0 g
s
.848 .741 .745 r
.1868 .37965 m .18245 .3765 L .18731 .36968 L p F P
0 g
s
.886 .75 .706 r
.19902 .31093 m .20288 .31434 L .19949 .32062 L p F P
0 g
s
.886 .749 .705 r
.20288 .31434 m .19902 .31093 L .20237 .30467 L p F P
0 g
s
.512 .571 .852 r
.71718 .22469 m .7154 .22457 L .71621 .22278 L closepath p F P
0 g
s
.517 .58 .857 r
.71428 .2191 m .71621 .22278 L .7154 .22457 L p F P
0 g
s
.296 .237 .62 r
.59114 .25686 m .58998 .25492 L p .58804 .26535 L F P
0 g
s
.296 .237 .62 r
.58804 .26535 m .5918 .26044 L .59114 .25686 L p F P
0 g
s
.315 .262 .638 r
.5918 .26044 m .58804 .26535 L .59125 .26953 L p F P
0 g
s
.437 .472 .799 r
.76679 .28068 m .76532 .28019 L .76236 .27294 L p F P
0 g
s
.824 .749 .781 r
.16967 .40097 m .17424 .40402 L .16745 .41148 L p F P
0 g
s
.818 .744 .781 r
.17219 .39819 m .16967 .40097 L .17424 .40402 L p F P
0 g
s
.624 .721 .916 r
.68623 .45407 m .69819 .45132 L .70103 .45501 L p F P
0 g
s
.615 .679 .887 r
.69532 .44729 m .69819 .45132 L .68623 .45407 L p F P
0 g
s
.615 .679 .887 r
.68707 .44895 m .69532 .44729 L p .68623 .45407 L F P
0 g
s
.615 .679 .887 r
.68623 .45407 m .68428 .45112 L .68707 .44895 L p F P
0 g
s
0 0 .22 r
.7864 .39953 m .78233 .404 L .78022 .41012 L p F P
0 g
s
.106 0 .37 r
.78233 .404 m .7864 .39953 L .78648 .39475 L p F P
0 g
s
.421 .683 .971 r
.0559 .44921 m .0628 .44935 L .06683 .45256 L p F P
0 g
s
.429 .683 .97 r
.0628 .44935 m .0559 .44921 L .05205 .44599 L p F P
0 g
s
.245 .165 .564 r
.79248 .3688 m .79043 .37133 L .79208 .37628 L p F P
0 g
s
.283 .216 .603 r
.79043 .37133 m .79248 .3688 L .79136 .36255 L p F P
0 g
s
.774 .996 .861 r
.61323 .1918 m .61422 .18807 L p .60397 .19886 L F P
0 g
s
.783 .869 .912 r
.61323 .1918 m .61422 .18807 L .61633 .18973 L closepath p F P
0 g
s
.396 .409 .755 r
.78221 .3006 m .77892 .30599 L .78513 .30941 L p F P
0 g
s
.407 .422 .764 r
.77551 .29736 m .78221 .3006 L .77892 .30599 L p F P
0 g
s
.539 .605 .868 r
.6963 .20799 m .69232 .20807 L .69404 .2039 L closepath p F P
0 g
s
.542 .615 .875 r
.6934 .20277 m .69404 .2039 L .69232 .20807 L p F P
0 g
s
.403 .341 .674 r
.5886 .28963 m .59391 .2837 L p .59296 .29379 L F P
0 g
s
.403 .341 .674 r
.59296 .29379 m .58883 .2906 L .5886 .28963 L p F P
0 g
s
.373 .314 .662 r
.5886 .28963 m .59391 .2837 L .58978 .27979 L p F P
0 g
s
0 0 .225 r
.59693 .21277 m .59503 .21618 L .59468 .22074 L p F P
0 g
s
0 0 0 r
.59503 .21618 m .59693 .21277 L .59919 .20685 L p F P
0 g
s
0 0 .216 r
.59302 .22391 m .59468 .22074 L .59503 .21618 L p F P
0 g
s
.725 .884 .954 r
.72931 .45121 m .73038 .45196 L .74223 .44601 L p F P
0 g
s
.155 .534 .922 r
.04739 .44463 m .05205 .44599 L .0482 .44272 L p F P
0 g
s
.155 .534 .922 r
.0482 .44272 m .04349 .44135 L .04739 .44463 L p F P
0 g
s
.557 .538 .79 r
.63508 .41765 m .62958 .4177 L .62673 .41083 L p F P
0 g
s
.316 .284 .664 r
.79396 .3412 m .79009 .34666 L .79357 .35101 L p F P
0 g
s
.335 .31 .682 r
.78986 .33705 m .79396 .3412 L .79009 .34666 L p F P
0 g
s
.486 .439 .73 r
.60475 .34895 m .59677 .34661 L .60254 .3417 L closepath p F P
0 g
s
.49 .431 .718 r
.60159 .33858 m .60254 .3417 L .59677 .34661 L p F P
0 g
s
.49 .431 .718 r
.59677 .33689 m .60159 .33858 L p .59677 .34661 L F P
0 g
s
.444 .388 .701 r
.59524 .31621 m .59093 .31397 L .59391 .31115 L closepath p F P
0 g
s
.441 .383 .697 r
.59205 .30398 m .59192 .3039 L p .59093 .31397 L F P
0 g
s
.441 .383 .697 r
.59093 .31397 m .59391 .31115 L .59205 .30398 L p F P
0 g
s
.847 .741 .746 r
.19227 .36284 m .19259 .36239 L .18903 .35811 L p F P
0 g
s
.397 .341 .678 r
.59027 .29668 m .58883 .2906 L .59296 .29379 L closepath p F P
0 g
s
.88 .745 .709 r
.20005 .33026 m .19772 .33447 L .19415 .3304 L p F P
0 g
s
.88 .745 .709 r
.19415 .3304 m .19607 .32691 L .20005 .33026 L p F P
0 g
s
.881 .744 .706 r
.20005 .33026 m .19607 .32691 L .19949 .32062 L p F P
0 g
s
.783 .763 .836 r
.13122 .44433 m .12939 .44575 L .12569 .44218 L p F P
0 g
s
.755 .762 .858 r
.1144 .44959 m .12569 .44218 L .12939 .44575 L p F P
0 g
s
.849 .744 .747 r
.18793 .35966 m .19227 .36284 L .18731 .36968 L p F P
0 g
s
.847 .741 .746 r
.18903 .35811 m .18793 .35966 L .19227 .36284 L p F P
0 g
s
.459 .496 .81 r
.75941 .26598 m .75529 .26489 L p .76143 .27266 L F P
0 g
s
.462 .504 .816 r
.75646 .25915 m .75731 .26107 L .75529 .26489 L p F P
0 g
s
.454 .493 .81 r
.75941 .26598 m .75529 .26489 L .75731 .26107 L closepath p F P
0 g
s
.866 .745 .728 r
.19222 .34321 m .19638 .34648 L .19223 .35304 L p F P
0 g
s
.864 .743 .728 r
.19638 .34648 m .19222 .34321 L .19636 .33666 L p F P
0 g
s
.477 .703 .968 r
.06683 .45256 m .07019 .45244 L .06637 .4492 L p F P
0 g
s
.477 .703 .968 r
.06637 .4492 m .0628 .44935 L .06683 .45256 L p F P
0 g
s
.598 .686 .904 r
.64575 .18802 m .65767 .18561 L p .65882 .19041 L F P
0 g
s
.616 .688 .894 r
.65767 .18561 m .64575 .18802 L .64283 .1839 L p F P
0 g
s
.719 .858 .948 r
.61422 .18807 m .61633 .18973 L .62807 .184 L p F P
0 g
s
.579 .606 .844 r
.65058 .43705 m .66254 .43593 L .66551 .44155 L p F P
0 g
s
.571 .581 .824 r
.65955 .43006 m .66254 .43593 L .65058 .43705 L p F P
0 g
s
.571 .581 .824 r
.65745 .4302 m .65955 .43006 L p .65058 .43705 L F P
0 g
s
.571 .581 .824 r
.65058 .43705 m .64998 .4358 L .65745 .4302 L p F P
0 g
s
.783 .763 .836 r
.12569 .44218 m .12688 .44124 L .13122 .44433 L p F P
0 g
s
.776 .759 .837 r
.13713 .43332 m .12688 .44124 L .13122 .44433 L p F P
0 g
s
.776 .759 .837 r
.13122 .44433 m .1408 .43702 L .13713 .43332 L p F P
0 g
s
0 0 .379 r
.59468 .22074 m .59302 .22391 L .59316 .22904 L p F P
0 g
s
.408 .428 .769 r
.77864 .29199 m .77551 .29736 L .78221 .3006 L p F P
0 g
s
.418 .44 .776 r
.77146 .28892 m .77864 .29199 L .77551 .29736 L p F P
0 g
s
.833 .743 .765 r
.18148 .38662 m .1841 .3834 L .18053 .37919 L p F P
0 g
s
.145 .026 .447 r
.78648 .39475 m .78832 .39255 L .7883 .38708 L p F P
0 g
s
.14 .021 .444 r
.79295 .38148 m .7883 .38708 L .78832 .39255 L p F P
0 g
s
.203 .104 .513 r
.7883 .38708 m .79295 .38148 L .79208 .37628 L p F P
0 g
s
0 0 0 r
.76572 .42958 m .77126 .42381 L .76736 .42787 L closepath p F P
0 g
s
0 0 0 r
.77126 .42381 m .7755 .41944 L .77705 .4164 L p F P
0 g
s
.678 .938 .654 r
.77126 .42381 m .7755 .41944 L p .77524 .4197 L F P
0 g
s
0 0 0 r
.77682 .41664 m .77126 .42381 L p .76758 .42761 L F P
0 g
s
0 0 0 r
.77705 .4164 m .77682 .41664 L .77126 .42381 L p F P
0 g
s
.678 .938 .654 r
.76505 .43002 m .77126 .42381 L .77524 .4197 L F
0 0 0 r
.77126 .42381 m .76736 .42787 L p .76758 .42761 L F P
0 g
s
.255 .197 .598 r
.79249 .36103 m .79136 .36255 L .79248 .3688 L p F P
0 g
s
.825 .748 .779 r
.16745 .41148 m .164 .41534 L .16039 .41136 L p F P
0 g
s
.825 .748 .779 r
.16039 .41136 m .16301 .4084 L .16745 .41148 L p F P
0 g
s
.824 .749 .781 r
.16745 .41148 m .16301 .4084 L .16967 .40097 L p F P
0 g
s
.445 .478 .8 r
.76236 .27294 m .76143 .27266 L .7619 .27182 L closepath p F P
0 g
s
.459 .496 .81 r
.76143 .27266 m .7619 .27182 L .75941 .26598 L p F P
0 g
s
.419 .445 .781 r
.77443 .28358 m .77146 .28892 L .77864 .29199 L p F P
0 g
s
.428 .456 .787 r
.76679 .28068 m .77443 .28358 L .77146 .28892 L p F P
0 g
s
.727 .766 .884 r
.09951 .45214 m .10518 .44907 L .10953 .45216 L p F P
0 g
s
.723 .764 .885 r
.11067 .44614 m .10518 .44907 L .10953 .45216 L p F P
0 g
s
.723 .764 .885 r
.10953 .45216 m .1144 .44959 L .11067 .44614 L p F P
0 g
s
.499 .562 .85 r
.71718 .22469 m .72798 .22567 L .72571 .23096 L p F P
0 g
s
.499 .564 .853 r
.72798 .22567 m .71718 .22469 L .71621 .22278 L p F P
0 g
s
.571 .58 .824 r
.64998 .4358 m .64757 .43084 L .65745 .4302 L closepath p F P
0 g
s
.429 .462 .793 r
.76958 .27537 m .76679 .28068 L .77443 .28358 L p F P
0 g
s
.437 .472 .799 r
.76236 .27294 m .76958 .27537 L .76679 .28068 L p F P
0 g
s
.598 .654 .877 r
.66846 .44683 m .68043 .44498 L .68334 .4497 L p F P
0 g
s
.591 .625 .854 r
.6775 .43999 m .68043 .44498 L .66846 .44683 L p F P
0 g
s
.591 .625 .854 r
.66585 .44151 m .6775 .43999 L p .66846 .44683 L F P
0 g
s
.591 .625 .854 r
.66846 .44683 m .66559 .44171 L .66585 .44151 L p F P
0 g
s
.644 .78 .946 r
.70103 .45501 m .71298 .45152 L .71576 .45445 L p F P
0 g
s
.633 .75 .932 r
.71298 .45152 m .70103 .45501 L .69819 .45132 L p F P
0 g
s
.894 .755 .701 r
.20237 .30467 m .20311 .30323 L .19951 .29955 L p F P
0 g
s
.203 .134 .551 r
.58968 .24783 m .59205 .24443 L .59044 .23976 L p F P
0 g
s
.144 .092 .535 r
.59404 .23394 m .59044 .23976 L .59205 .24443 L p F P
0 g
s
.103 .033 .485 r
.59044 .23976 m .59404 .23394 L .59316 .22904 L p F P
0 g
s
.476 .532 .835 r
.74348 .24471 m .73819 .24381 L .73528 .23764 L p F P
0 g
s
.667 .857 .972 r
.71576 .45445 m .72768 .44999 L .72931 .45121 L p F P
0 g
s
.657 .82 .962 r
.72768 .44999 m .71576 .45445 L .71298 .45152 L p F P
0 g
s
.816 .964 .641 r
.60188 .20041 m .60595 .19473 L .60397 .19886 L closepath p F P
0 g
s
.774 .996 .861 r
.61342 .18755 m .60595 .19473 L .60397 .19886 L p F P
0 g
s
.774 .996 .861 r
.61422 .18807 m .61342 .18755 L p .60397 .19886 L F P
0 g
s
.838 .747 .763 r
.17704 .3835 m .18148 .38662 L .17574 .39374 L p F P
0 g
s
.833 .743 .765 r
.18053 .37919 m .17704 .3835 L .18148 .38662 L p F P
0 g
s
.236 .176 .584 r
.59205 .24443 m .58968 .24783 L .59064 .25401 L p F P
0 g
s
.248 .185 .587 r
.58998 .25492 m .59064 .25401 L .58968 .24783 L p F P
0 g
s
.807 .75 .799 r
.16013 .41913 m .164 .41534 L .16039 .41136 L p F P
0 g
s
.066 0 .357 r
.78832 .39255 m .78648 .39475 L .7864 .39953 L p F P
0 g
s
.422 .361 .684 r
.59192 .3039 m .592 .30381 L .59027 .29668 L p F P
0 g
s
.402 .348 .683 r
.59296 .29379 m .59027 .29668 L .592 .30381 L p F P
0 g
s
.812 .751 .796 r
.16013 .41913 m .15234 .4269 L .1487 .42306 L p F P
0 g
s
.812 .751 .796 r
.1487 .42306 m .15562 .41607 L .16013 .41913 L p F P
0 g
s
.807 .75 .799 r
.16039 .41136 m .15562 .41607 L .16013 .41913 L p F P
0 g
s
.8 .759 .815 r
.1427 .43533 m .1408 .43702 L .13713 .43332 L p F P
0 g
s
.597 .67 .891 r
.66059 .1901 m .65882 .19041 L .65962 .1886 L closepath p F P
0 g
s
.598 .686 .904 r
.65767 .18561 m .65962 .1886 L .65882 .19041 L p F P
0 g
s
.433 .471 .8 r
.76958 .27537 m .76236 .27294 L .7619 .27182 L p F P
0 g
s
.8 .759 .815 r
.13713 .43332 m .13833 .43224 L .1427 .43533 L p F P
0 g
s
.798 .76 .818 r
.14773 .42391 m .15231 .42694 L .1427 .43533 L p F P
0 g
s
.798 .76 .818 r
.1427 .43533 m .13833 .43224 L .14773 .42391 L p F P
0 g
s
.557 .538 .79 r
.62673 .41083 m .62741 .41032 L p .63508 .41765 L F P
0 g
s
.548 .533 .79 r
.62673 .41083 m .62652 .41031 L .62741 .41032 L closepath p F P
0 g
s
.891 .757 .706 r
.19867 .30118 m .20237 .30467 L .19902 .31093 L p F P
0 g
s
.894 .755 .701 r
.19951 .29955 m .19867 .30118 L .20237 .30467 L p F P
0 g
s
.549 .526 .782 r
.62741 .41032 m .62652 .41031 L .62344 .40257 L p F P
0 g
s
.79 .751 .817 r
.15248 .42705 m .15234 .4269 L .15231 .42694 L closepath p F P
0 g
s
.55 .627 .881 r
.67849 .1984 m .67841 .19825 L .67854 .19825 L closepath p F P
0 g
s
.868 .748 .728 r
.19636 .33666 m .19772 .33447 L .19415 .3304 L p F P
0 g
s
.544 .516 .775 r
.62344 .40257 m .62141 .40249 L .62298 .40137 L closepath p F P
0 g
s
.545 .508 .765 r
.62036 .39451 m .62298 .40137 L .62141 .40249 L p F P
0 g
s
.545 .508 .765 r
.61673 .39425 m .62036 .39451 L p .62141 .40249 L F P
0 g
s
.433 .471 .8 r
.7619 .27182 m .7641 .26736 L p .76958 .27537 L F P
0 g
s
.442 .486 .809 r
.7619 .27182 m .75941 .26598 L .7641 .26736 L closepath p F P
0 g
s
.549 .631 .886 r
.67854 .19825 m .67841 .19825 L .6755 .19343 L p F P
0 g
s
.792 .754 .818 r
.1487 .42306 m .14773 .42391 L .15231 .42694 L p F P
0 g
s
.792 .754 .818 r
.15231 .42694 m .15234 .4269 L .1487 .42306 L p F P
0 g
s
.498 .554 .844 r
.73237 .23173 m .72571 .23096 L p .73521 .23763 L F P
0 g
s
.494 .554 .846 r
.72571 .23096 m .73237 .23173 L .72946 .22584 L p F P
0 g
s
.494 .554 .846 r
.72946 .22584 m .72798 .22567 L .72571 .23096 L p F P
0 g
s
.499 .564 .853 r
.71621 .22278 m .71749 .21932 L p .72798 .22567 L F P
0 g
s
.506 .574 .859 r
.71621 .22278 m .71428 .2191 L .71749 .21932 L closepath p F P
0 g
s
.537 .496 .758 r
.61726 .38612 m .61951 .39222 L .61673 .39425 L p F P
0 g
s
.537 .496 .758 r
.6131 .38568 m .61726 .38612 L p .61673 .39425 L F P
0 g
s
.536 .505 .768 r
.62036 .39451 m .61673 .39425 L .61951 .39222 L closepath p F P
0 g
s
.549 .629 .884 r
.67854 .19825 m .69049 .19772 L .68758 .1927 L p F P
0 g
s
.549 .629 .884 r
.68758 .1927 m .67995 .19313 L .67854 .19825 L p F P
0 g
s
.549 .631 .886 r
.6755 .19343 m .67995 .19313 L .67854 .19825 L p F P
0 g
s
.333 .311 .685 r
.79358 .33168 m .78986 .33705 L .79396 .3412 L p F P
0 g
s
.358 .344 .708 r
.79352 .33148 m .78896 .32764 L p .78986 .33705 L F P
0 g
s
.358 .344 .708 r
.78986 .33705 m .79358 .33168 L .79352 .33148 L p F P
0 g
s
.849 .744 .747 r
.18731 .36968 m .18303 .36649 L .18793 .35966 L p F P
0 g
s
.852 .746 .746 r
.18303 .36649 m .18731 .36968 L .18245 .3765 L p F P
0 g
s
.359 .313 .669 r
.59458 .27387 m .58978 .27979 L .59391 .2837 L p F P
0 g
s
.346 .294 .656 r
.59445 .27326 m .59125 .26953 L p .58978 .27979 L F P
0 g
s
.346 .294 .656 r
.58978 .27979 m .59458 .27387 L .59445 .27326 L p F P
0 g
s
.886 .751 .707 r
.19564 .31721 m .19949 .32062 L .19607 .32691 L p F P
0 g
s
.886 .75 .706 r
.19949 .32062 m .19564 .31721 L .19902 .31093 L p F P
0 g
s
.475 .425 .722 r
.60159 .33858 m .59677 .33689 L .60021 .33386 L closepath p F P
0 g
s
.479 .417 .71 r
.59843 .32771 m .60021 .33386 L .59677 .33689 L p F P
0 g
s
.479 .417 .71 r
.59693 .32709 m .59843 .32771 L p .59677 .33689 L F P
0 g
s
.696 .865 .962 r
.72768 .44999 m .73335 .44754 L .72931 .45121 L closepath p F P
0 g
s
.725 .884 .954 r
.73959 .44473 m .73335 .44754 L .72931 .45121 L p F P
0 g
s
.725 .884 .954 r
.74223 .44601 m .73959 .44473 L p .72931 .45121 L F P
0 g
s
.557 .538 .79 r
.62741 .41032 m .63847 .4105 L p .63508 .41765 L F P
0 g
s
.548 .536 .793 r
.63847 .4105 m .62741 .41032 L .63576 .40399 L closepath p F P
0 g
s
.549 .526 .782 r
.63541 .40316 m .63576 .40399 L .62741 .41032 L p F P
0 g
s
.549 .526 .782 r
.62344 .40257 m .63541 .40316 L p .62741 .41032 L F P
0 g
s
.615 .678 .887 r
.68428 .45112 m .68334 .4497 L .68707 .44895 L closepath p F P
0 g
s
.758 .764 .858 r
.12569 .44218 m .1144 .44959 L .11067 .44614 L p F P
0 g
s
.865 .745 .728 r
.19223 .35304 m .18903 .35811 L .18545 .35401 L p F P
0 g
s
.865 .745 .728 r
.18545 .35401 m .18812 .34976 L .19223 .35304 L p F P
0 g
s
.866 .745 .728 r
.19223 .35304 m .18812 .34976 L .19222 .34321 L p F P
0 g
s
.523 .595 .867 r
.6963 .20799 m .70779 .20813 L .70573 .21341 L p F P
0 g
s
.525 .598 .87 r
.70779 .20813 m .6963 .20799 L .69404 .2039 L p F P
0 g
s
.528 .493 .761 r
.61726 .38612 m .6131 .38568 L .61626 .38331 L closepath p F P
0 g
s
.529 .484 .75 r
.61415 .37739 m .61626 .38331 L .6131 .38568 L p F P
0 g
s
.529 .484 .75 r
.61033 .37685 m .61415 .37739 L p .6131 .38568 L F P
0 g
s
.574 .648 .885 r
.66059 .1901 m .67259 .18867 L .6755 .19343 L p F P
0 g
s
.574 .659 .895 r
.66967 .18397 m .67259 .18867 L .66059 .1901 L p F P
0 g
s
.574 .659 .895 r
.66034 .18523 m .66967 .18397 L p .66059 .1901 L F P
0 g
s
.574 .659 .895 r
.66059 .1901 m .65962 .1886 L .66034 .18523 L p F P
0 g
s
.869 .75 .729 r
.19233 .33333 m .19636 .33666 L .19222 .34321 L p F P
0 g
s
.868 .748 .728 r
.19415 .3304 m .19233 .33333 L .19636 .33666 L p F P
0 g
s
0 0 0 r
.78022 .41012 m .78541 .40441 L p .77705 .4164 L F P
0 g
s
0 0 0 r
.77705 .4164 m .77713 .41612 L .78022 .41012 L p F P
0 g
s
0 0 .22 r
.78608 .40263 m .7864 .39953 L p .78022 .41012 L F P
0 g
s
0 0 .22 r
.78022 .41012 m .78541 .40441 L .78608 .40263 L p F P
0 g
s
.275 .22 .613 r
.59114 .25686 m .58998 .25492 L .59064 .25401 L closepath p F P
0 g
s
.428 .371 .692 r
.59205 .30398 m .59192 .3039 L .592 .30381 L closepath p F P
0 g
s
.839 .747 .762 r
.17574 .39374 m .17219 .39819 L .16858 .39414 L p F P
0 g
s
.839 .747 .762 r
.16858 .39414 m .17139 .3906 L .17574 .39374 L p F P
0 g
s
.838 .747 .763 r
.17574 .39374 m .17139 .3906 L .17704 .3835 L p F P
0 g
s
.605 .746 .944 r
.07019 .45244 m .08096 .44991 L .08476 .45319 L p F P
0 g
s
.607 .746 .943 r
.08096 .44991 m .07019 .45244 L .06637 .4492 L p F P
0 g
s
.255 .197 .598 r
.79248 .3688 m .79472 .36579 L .79249 .36103 L p F P
0 g
s
.255 .2 .6 r
.79648 .35556 m .79249 .36103 L .79472 .36579 L p F P
0 g
s
.288 .242 .631 r
.79357 .35101 m .79648 .35556 L .79249 .36103 L p F P
0 g
s
.426 .37 .692 r
.592 .30381 m .59793 .29746 L p .59757 .30736 L F P
0 g
s
.426 .37 .692 r
.59757 .30736 m .59205 .30398 L .592 .30381 L p F P
0 g
s
.402 .348 .683 r
.592 .30381 m .59793 .29746 L .59296 .29379 L p F P
0 g
s
.422 .371 .696 r
.59391 .31115 m .59205 .30398 L .59757 .30736 L closepath p F P
0 g
s
.571 .573 .816 r
.65745 .4302 m .64757 .43084 L .64461 .4245 L p F P
0 g
s
.532 .509 .776 r
.63233 .3955 m .63541 .40316 L .62344 .40257 L p F P
0 g
s
.532 .509 .776 r
.63067 .39537 m .63233 .3955 L p .62344 .40257 L F P
0 g
s
.532 .509 .776 r
.62344 .40257 m .62298 .40137 L .63067 .39537 L p F P
0 g
s
.214 .144 .557 r
.79472 .36579 m .79248 .3688 L .79333 .37473 L p F P
0 g
s
.245 .165 .564 r
.79208 .37628 m .79333 .37473 L .79248 .3688 L p F P
0 g
s
.674 .959 .943 r
.75075 .44096 m .74223 .44601 L .73959 .44473 L p F P
0 g
s
.531 .508 .775 r
.62298 .40137 m .62036 .39451 L .63067 .39537 L closepath p F P
0 g
s
.519 .481 .754 r
.61415 .37739 m .61033 .37685 L .6132 .37463 L closepath p F P
0 g
s
.52 .472 .743 r
.61103 .36831 m .6132 .37463 L .61033 .37685 L p F P
0 g
s
.52 .472 .743 r
.60824 .36779 m .61103 .36831 L p .61033 .37685 L F P
0 g
s
.521 .588 .863 r
.70573 .21341 m .71138 .21361 L .70847 .20815 L p F P
0 g
s
.521 .588 .863 r
.70847 .20815 m .70779 .20813 L .70573 .21341 L p F P
0 g
s
.556 .548 .8 r
.64152 .41757 m .63508 .41765 L .63999 .41403 L closepath p F P
0 g
s
.557 .538 .79 r
.63847 .4105 m .63999 .41403 L .63508 .41765 L p F P
0 g
s
.822 .748 .782 r
.16967 .40097 m .17219 .39819 L .16858 .39414 L p F P
0 g
s
.73 .768 .884 r
.10518 .44907 m .09951 .45214 L .09574 .44879 L p F P
0 g
s
.681 .761 .912 r
.08476 .45319 m .09574 .44879 L .09951 .45214 L p F P
0 g
s
.616 .663 .872 r
.68707 .44895 m .68334 .4497 L .68043 .44498 L p F P
0 g
s
.351 .34 .707 r
.79352 .33148 m .78896 .32764 L .79137 .32403 L closepath p F P
0 g
s
.371 .367 .725 r
.7903 .32055 m .78738 .31842 L p .78896 .32764 L F P
0 g
s
.371 .367 .725 r
.78896 .32764 m .79137 .32403 L .7903 .32055 L p F P
0 g
s
.442 .486 .81 r
.7641 .26736 m .75941 .26598 L .75731 .26107 L p F P
0 g
s
.683 .763 .912 r
.09574 .44879 m .08476 .45319 L .08096 .44991 L p F P
0 g
s
.29 .231 .616 r
.59064 .25401 m .59416 .24895 L p .59266 .25926 L F P
0 g
s
.29 .231 .616 r
.59266 .25926 m .59114 .25686 L .59064 .25401 L p F P
0 g
s
.236 .176 .584 r
.59064 .25401 m .59416 .24895 L .59205 .24443 L p F P
0 g
s
.486 .54 .838 r
.73528 .23764 m .73521 .23763 L .73524 .23757 L closepath p F P
0 g
s
.498 .554 .844 r
.73521 .23763 m .73524 .23757 L .73237 .23173 L p F P
0 g
s
.582 .667 .897 r
.65962 .1886 m .65767 .18561 L .66034 .18523 L closepath p F P
0 g
s
.441 .386 .701 r
.59391 .31115 m .59757 .30736 L p .59721 .31725 L F P
0 g
s
.441 .386 .701 r
.59721 .31725 m .59524 .31621 L .59391 .31115 L p F P
0 g
s
.476 .532 .835 r
.73528 .23764 m .74582 .23944 L .74348 .24471 L p F P
0 g
s
.474 .533 .838 r
.74582 .23944 m .73528 .23764 L .73524 .23757 L p F P
0 g
s
.852 .746 .746 r
.18245 .3765 m .18053 .37919 L .17694 .37511 L p F P
0 g
s
.852 .746 .746 r
.17694 .37511 m .17822 .37329 L .18245 .3765 L p F P
0 g
s
.852 .746 .746 r
.18245 .3765 m .17822 .37329 L .18303 .36649 L p F P
0 g
s
.474 .533 .838 r
.73524 .23757 m .73728 .23243 L p .74582 .23944 L F P
0 g
s
.482 .545 .845 r
.73524 .23757 m .73237 .23173 L .73728 .23243 L closepath p F P
0 g
s
.828 .753 .781 r
.16524 .39786 m .16967 .40097 L .16301 .4084 L p F P
0 g
s
.822 .748 .782 r
.16858 .39414 m .16524 .39786 L .16967 .40097 L p F P
0 g
s
.505 .576 .861 r
.71749 .21932 m .71428 .2191 L .71138 .21361 L p F P
0 g
s
.663 .729 .899 r
.62807 .184 m .6399 .17992 L .64283 .1839 L p F P
0 g
s
.681 .745 .899 r
.6399 .17992 m .62807 .184 L .62515 .18073 L p F P
0 g
s
.719 .858 .948 r
.62807 .184 m .62515 .18073 L p .61422 .18807 L F P
0 g
s
.59 .624 .854 r
.66559 .44171 m .66551 .44155 L .66585 .44151 L closepath p F P
0 g
s
.852 .747 .748 r
.18793 .35966 m .18903 .35811 L .18545 .35401 L p F P
0 g
s
.891 .757 .708 r
.19532 .30745 m .19902 .31093 L .19564 .31721 L p F P
0 g
s
.891 .757 .706 r
.19902 .31093 m .19532 .30745 L .19867 .30118 L p F P
0 g
s
.197 .101 .512 r
.79333 .37473 m .79208 .37628 L .79295 .38148 L p F P
0 g
s
.591 .612 .841 r
.66585 .44151 m .66551 .44155 L .66254 .43593 L p F P
0 g
s
0 0 .193 r
.5994 .20727 m .59693 .21277 L .59607 .21824 L p F P
0 g
s
0 0 0 r
.59693 .21277 m .5994 .20727 L .60134 .20145 L p F P
0 g
s
0 0 .225 r
.59468 .22074 m .59607 .21824 L .59693 .21277 L p F P
0 g
s
.14 .021 .444 r
.78832 .39255 m .79297 .38695 L .79295 .38148 L p F P
0 g
s
.066 0 .357 r
.7864 .39953 m .78742 .3983 L .78832 .39255 L p F P
0 g
s
.052 0 .347 r
.79297 .38695 m .78832 .39255 L .78742 .3983 L p F P
0 g
s
.048 0 .473 r
.59482 .2259 m .59316 .22904 L .59404 .23394 L p F P
0 g
s
0 0 .379 r
.59316 .22904 m .59482 .2259 L .59468 .22074 L p F P
0 g
s
.591 .612 .841 r
.66254 .43593 m .67447 .43475 L .66585 .44151 L p F P
0 g
s
.581 .608 .844 r
.66585 .44151 m .6775 .43999 L .67455 .43474 L p F P
0 g
s
.581 .608 .844 r
.67455 .43474 m .67447 .43475 L .66585 .44151 L p F P
0 g
s
.462 .41 .714 r
.59843 .32771 m .59693 .32709 L .59798 .32614 L closepath p F P
0 g
s
.459 .405 .71 r
.59693 .32709 m .59798 .32614 L .59589 .31857 L p F P
0 g
s
.429 .683 .97 r
.05205 .44599 m .05885 .4461 L .0628 .44935 L p F P
0 g
s
.434 .682 .968 r
.05885 .4461 m .05205 .44599 L .0482 .44272 L p F P
0 g
s
.533 .503 .768 r
.63067 .39537 m .62036 .39451 L .61951 .39222 L p F P
0 g
s
.784 .899 .924 r
.61342 .18755 m .61498 .18651 L .61422 .18807 L closepath p F P
0 g
s
.719 .858 .948 r
.62515 .18073 m .61498 .18651 L .61422 .18807 L p F P
0 g
s
0 0 .385 r
.59607 .21824 m .59468 .22074 L .59482 .2259 L p F P
0 g
s
.854 .75 .748 r
.18374 .35642 m .18793 .35966 L .18303 .36649 L p F P
0 g
s
.852 .747 .748 r
.18545 .35401 m .18374 .35642 L .18793 .35966 L p F P
0 g
s
.437 .388 .706 r
.59589 .31857 m .59524 .31621 L .59721 .31725 L closepath p F P
0 g
s
.837 .748 .766 r
.17704 .3835 m .18053 .37919 L .17694 .37511 L p F P
0 g
s
.509 .468 .747 r
.61103 .36831 m .60824 .36779 L .61031 .36614 L closepath p F P
0 g
s
.511 .46 .736 r
.6079 .35884 m .61031 .36614 L .60824 .36779 L p F P
0 g
s
.511 .46 .736 r
.60667 .35856 m .6079 .35884 L p .60824 .36779 L F P
0 g
s
.885 .752 .71 r
.19607 .32691 m .19415 .3304 L .19055 .32656 L p F P
0 g
s
.885 .752 .71 r
.19055 .32656 m .19223 .32351 L .19607 .32691 L p F P
0 g
s
.886 .751 .707 r
.19607 .32691 m .19223 .32351 L .19564 .31721 L p F P
0 g
s
.616 .688 .894 r
.64283 .1839 m .65475 .18123 L .65767 .18561 L p F P
0 g
s
.625 .697 .897 r
.65475 .18123 m .64283 .1839 L .6399 .17992 L p F P
0 g
s
.785 .766 .836 r
.12688 .44124 m .12569 .44218 L .12198 .43863 L p F P
0 g
s
.758 .764 .858 r
.11067 .44614 m .12198 .43863 L .12569 .44218 L p F P
0 g
s
.869 .75 .729 r
.19222 .34321 m .18822 .33988 L .19233 .33333 L p F P
0 g
s
.87 .751 .729 r
.18822 .33988 m .19222 .34321 L .18812 .34976 L p F P
0 g
s
0 0 .014 r
.77682 .41664 m .77705 .4164 L .77713 .41612 L closepath p F P
0 g
s
.533 .503 .768 r
.61951 .39222 m .62584 .38714 L p .63067 .39537 L F P
0 g
s
.522 .496 .768 r
.61951 .39222 m .61726 .38612 L .62584 .38714 L closepath p F P
0 g
s
.779 .762 .837 r
.13345 .42966 m .12264 .43811 L .12688 .44124 L p F P
0 g
s
.779 .762 .837 r
.12688 .44124 m .13713 .43332 L .13345 .42966 L p F P
0 g
s
.785 .766 .836 r
.12198 .43863 m .12264 .43811 L .12688 .44124 L p F P
0 g
s
.283 .228 .617 r
.5918 .26044 m .59114 .25686 L .59266 .25926 L closepath p F P
0 g
s
.441 .393 .709 r
.59721 .31725 m .59589 .31857 L .59798 .32614 L p F P
0 g
s
.327 .278 .65 r
.59445 .27326 m .59125 .26953 L .59313 .26708 L closepath p F P
0 g
s
.315 .262 .638 r
.59125 .26953 m .59313 .26708 L .5918 .26044 L p F P
0 g
s
.48 .703 .967 r
.0628 .44935 m .06637 .4492 L .06253 .44594 L p F P
0 g
s
.48 .703 .967 r
.06253 .44594 m .05885 .4461 L .0628 .44935 L p F P
0 g
s
.828 .752 .78 r
.16301 .4084 m .16039 .41136 L .15675 .40746 L p F P
0 g
s
.828 .752 .78 r
.15675 .40746 m .15869 .40526 L .16301 .4084 L p F P
0 g
s
.828 .753 .781 r
.16301 .4084 m .15869 .40526 L .16524 .39786 L p F P
0 g
s
.365 .363 .724 r
.7903 .32055 m .78738 .31842 L .78891 .31605 L closepath p F P
0 g
s
.384 .388 .741 r
.78715 .31069 m .78513 .30941 L p .78738 .31842 L F P
0 g
s
.384 .388 .741 r
.78738 .31842 m .78891 .31605 L .78715 .31069 L p F P
0 g
s
.525 .598 .87 r
.69404 .2039 m .69439 .20277 L p .70779 .20813 L F P
0 g
s
.53 .607 .874 r
.69404 .2039 m .6934 .20277 L .69439 .20277 L closepath p F P
0 g
s
.674 .959 .943 r
.75313 .43878 m .75075 .44096 L p .73959 .44473 L F P
0 g
s
.701 .98 .899 r
.75075 .44096 m .75313 .43878 L .75403 .43883 L closepath p F P
0 g
s
.391 .349 .691 r
.59792 .28799 m .59296 .29379 L .59793 .29746 L p F P
0 g
s
.403 .341 .674 r
.59769 .28705 m .59792 .28799 L .59296 .29379 L p F P
0 g
s
.403 .341 .674 r
.59391 .2837 m .59769 .28705 L p .59296 .29379 L F P
0 g
s
.284 .242 .633 r
.7972 .34596 m .79357 .35101 L .79648 .35556 L p F P
0 g
s
.316 .284 .664 r
.79693 .34483 m .79396 .3412 L p .79357 .35101 L F P
0 g
s
.316 .284 .664 r
.79357 .35101 m .7972 .34596 L .79693 .34483 L p F P
0 g
s
0 0 0 r
.78186 .41098 m .77705 .4164 L .7755 .41944 L p F P
0 g
s
0 0 0 r
.78541 .40441 m .78186 .41098 L .77705 .4164 L p F P
0 g
s
.451 .5 .819 r
.75731 .26107 m .75646 .25915 L .75802 .25955 L closepath p F P
0 g
s
.442 .486 .81 r
.75731 .26107 m .75802 .25955 L p .7641 .26736 L F P
0 g
s
.473 .524 .83 r
.7506 .24612 m .74348 .24471 L p .75114 .25201 L F P
0 g
s
.467 .522 .831 r
.74348 .24471 m .7506 .24612 L .74768 .23981 L p F P
0 g
s
.467 .522 .831 r
.74768 .23981 m .74582 .23944 L .74348 .24471 L p F P
0 g
s
.73 .768 .884 r
.09574 .44879 m .10095 .44593 L .10518 .44907 L p F P
0 g
s
.725 .766 .885 r
.10692 .4427 m .10095 .44593 L .10518 .44907 L p F P
0 g
s
.725 .766 .885 r
.10518 .44907 m .11067 .44614 L .10692 .4427 L p F P
0 g
s
.571 .573 .816 r
.64461 .4245 m .64479 .42437 L p .65745 .4302 L F P
0 g
s
.563 .568 .816 r
.64461 .4245 m .64456 .42438 L .64479 .42437 L closepath p F P
0 g
s
.633 .75 .932 r
.69819 .45132 m .71017 .44821 L .71298 .45152 L p F P
0 g
s
.622 .723 .919 r
.71017 .44821 m .69819 .45132 L .69532 .44729 L p F P
0 g
s
.564 .559 .806 r
.64479 .42437 m .64456 .42438 L .64152 .41757 L p F P
0 g
s
.81 .754 .8 r
.15562 .41607 m .16039 .41136 L .15675 .40746 L p F P
0 g
s
.615 .681 .889 r
.69532 .44729 m .68707 .44895 L .69316 .44402 L closepath p F P
0 g
s
.616 .663 .872 r
.69244 .44294 m .69316 .44402 L .68707 .44895 L p F P
0 g
s
.616 .663 .872 r
.68043 .44498 m .69244 .44294 L p .68707 .44895 L F P
0 g
s
.842 .752 .764 r
.17275 .38032 m .17704 .3835 L .17139 .3906 L p F P
0 g
s
.837 .748 .766 r
.17694 .37511 m .17275 .38032 L .17704 .3835 L p F P
0 g
s
.524 .491 .761 r
.62584 .38714 m .61726 .38612 L .61626 .38331 L p F P
0 g
s
.571 .573 .816 r
.64479 .42437 m .65654 .42388 L p .65745 .4302 L F P
0 g
s
.563 .571 .82 r
.65654 .42388 m .64479 .42437 L .65355 .41752 L closepath p F P
0 g
s
.564 .559 .806 r
.65353 .41747 m .65355 .41752 L .64479 .42437 L p F P
0 g
s
.564 .559 .806 r
.64152 .41757 m .65353 .41747 L p .64479 .42437 L F P
0 g
s
.673 .864 .972 r
.73335 .44754 m .72768 .44999 L .72494 .44752 L p F P
0 g
s
.657 .82 .962 r
.71298 .45152 m .72494 .44752 L .72768 .44999 L p F P
0 g
s
.184 .148 .58 r
.5955 .23867 m .59205 .24443 L .59416 .24895 L p F P
0 g
s
.144 .092 .535 r
.59205 .24443 m .5955 .23867 L .59404 .23394 L p F P
0 g
s
.459 .408 .714 r
.59798 .32614 m .60366 .3205 L p .6041 .33013 L F P
0 g
s
.459 .408 .714 r
.6041 .33013 m .59843 .32771 L .59798 .32614 L p F P
0 g
s
.441 .393 .709 r
.59798 .32614 m .60366 .3205 L .59721 .31725 L p F P
0 g
s
.815 .755 .796 r
.15562 .41607 m .1487 .42306 L .14504 .41928 L p F P
0 g
s
.815 .755 .796 r
.14504 .41928 m .15125 .41295 L .15562 .41607 L p F P
0 g
s
.81 .754 .8 r
.15675 .40746 m .15125 .41295 L .15562 .41607 L p F P
0 g
s
.552 .637 .888 r
.67995 .19313 m .6755 .19343 L .67259 .18867 L p F P
0 g
s
.524 .491 .761 r
.61626 .38331 m .62196 .37862 L p .62584 .38714 L F P
0 g
s
.513 .483 .761 r
.61626 .38331 m .61415 .37739 L .62196 .37862 L closepath p F P
0 g
s
.765 .992 .883 r
.75313 .43878 m .75403 .43883 L .76332 .4317 L p F P
0 g
s
.455 .411 .719 r
.60021 .33386 m .59843 .32771 L .6041 .33013 L closepath p F P
0 g
s
.45 .501 .82 r
.75802 .25955 m .75646 .25915 L .75353 .25256 L p F P
0 g
s
.803 .762 .816 r
.13833 .43224 m .13713 .43332 L .13345 .42966 L p F P
0 g
s
.803 .762 .816 r
.13345 .42966 m .13406 .42911 L .13833 .43224 L p F P
0 g
s
.801 .763 .818 r
.14329 .42082 m .14773 .42391 L .13833 .43224 L p F P
0 g
s
.801 .763 .818 r
.13833 .43224 m .13406 .42911 L .14329 .42082 L p F P
0 g
s
0 0 .237 r
.78608 .40263 m .78742 .3983 L .7864 .39953 L closepath p F P
0 g
s
.529 .61 .878 r
.69439 .20277 m .6934 .20277 L .69049 .19772 L p F P
0 g
s
.873 .755 .73 r
.19233 .33333 m .19415 .3304 L .19055 .32656 L p F P
0 g
s
.301 .253 .635 r
.59266 .25926 m .5918 .26044 L .59313 .26708 L p F P
0 g
s
.499 .456 .74 r
.6079 .35884 m .60667 .35856 L .60757 .35782 L closepath p F P
0 g
s
.498 .453 .738 r
.60667 .35856 m .60757 .35782 L .60498 .34967 L p F P
0 g
s
.646 .786 .949 r
.72494 .44752 m .71298 .45152 L .71017 .44821 L p F P
0 g
s
.795 .757 .819 r
.14504 .41928 m .14329 .42082 L .14773 .42391 L p F P
0 g
s
.795 .757 .819 r
.14773 .42391 m .1487 .42306 L .14504 .41928 L p F P
0 g
s
.378 .385 .74 r
.78715 .31069 m .78513 .30941 L .78617 .30772 L closepath p F P
0 g
s
.396 .409 .755 r
.78406 .30162 m .78221 .3006 L p .78513 .30941 L F P
0 g
s
.396 .409 .755 r
.78513 .30941 m .78617 .30772 L .78406 .30162 L p F P
0 g
s
.822 .926 .903 r
.61498 .18651 m .61342 .18755 L .61053 .18625 L p F P
0 g
s
.863 .933 .868 r
.60595 .19473 m .61342 .18755 L .61053 .18625 L p F P
0 g
s
.515 .478 .754 r
.62196 .37862 m .61415 .37739 L .6132 .37463 L p F P
0 g
s
.471 .423 .722 r
.60021 .33386 m .6041 .33013 L p .60469 .3397 L F P
0 g
s
.471 .423 .722 r
.60469 .3397 m .60159 .33858 L .60021 .33386 L p F P
0 g
s
.678 .938 .654 r
.76505 .43002 m .76572 .42958 L .77126 .42381 L p F P
0 g
s
.162 .076 .503 r
.7963 .37077 m .79333 .37473 L .7939 .38031 L p F P
0 g
s
.214 .144 .557 r
.79333 .37473 m .7963 .37077 L .79472 .36579 L p F P
0 g
s
.197 .101 .512 r
.79295 .38148 m .7939 .38031 L .79333 .37473 L p F P
0 g
s
.499 .564 .853 r
.71749 .21932 m .72656 .22012 L p .72798 .22567 L F P
0 g
s
.5 .569 .857 r
.71749 .21932 m .72656 .22012 L .72365 .21448 L p F P
0 g
s
.5 .569 .857 r
.72365 .21448 m .71936 .21413 L .71749 .21932 L p F P
0 g
s
.505 .576 .861 r
.71138 .21361 m .71936 .21413 L .71749 .21932 L p F P
0 g
s
.46 .508 .821 r
.75353 .25256 m .75114 .25201 L .75225 .24969 L closepath p F P
0 g
s
.473 .524 .83 r
.75114 .25201 m .75225 .24969 L .7506 .24612 L p F P
0 g
s
.854 .75 .748 r
.18303 .36649 m .17889 .36323 L .18374 .35642 L p F P
0 g
s
.856 .751 .746 r
.17889 .36323 m .18303 .36649 L .17822 .37329 L p F P
0 g
s
.863 .933 .868 r
.61053 .18625 m .60774 .18942 L .60595 .19473 L p F P
0 g
s
.634 .85 .466 r
.60595 .19473 m .60774 .18942 L p .60155 .20082 L F P
0 g
s
.634 .85 .466 r
.60155 .20082 m .60188 .20041 L .60595 .19473 L p F P
0 g
s
.515 .478 .754 r
.6132 .37463 m .61884 .36985 L p .62196 .37862 L F P
0 g
s
.503 .47 .753 r
.6132 .37463 m .61103 .36831 L .61884 .36985 L closepath p F P
0 g
s
.822 .926 .903 r
.61053 .18625 m .617 .18111 L .61498 .18651 L p F P
0 g
s
.746 .816 .907 r
.62222 .17773 m .617 .18111 L .61498 .18651 L p F P
0 g
s
.746 .816 .907 r
.61498 .18651 m .62515 .18073 L .62222 .17773 L p F P
0 g
s
.581 .672 .902 r
.66034 .18523 m .65767 .18561 L .65475 .18123 L p F P
0 g
s
.468 .426 .727 r
.60254 .3417 m .60159 .33858 L .60469 .3397 L closepath p F P
0 g
s
.525 .598 .87 r
.69439 .20277 m .70557 .20287 L p .70779 .20813 L F P
0 g
s
.527 .606 .875 r
.69439 .20277 m .70557 .20287 L .70266 .19765 L p F P
0 g
s
.527 .606 .875 r
.70266 .19765 m .69587 .19765 L .69439 .20277 L p F P
0 g
s
.529 .61 .878 r
.69049 .19772 m .69587 .19765 L .69439 .20277 L p F P
0 g
s
.434 .395 .716 r
.60333 .31082 m .59721 .31725 L .60366 .3205 L p F P
0 g
s
.441 .386 .701 r
.59757 .30736 m .60333 .31082 L .59721 .31725 L p F P
0 g
s
.891 .758 .709 r
.19194 .31373 m .19564 .31721 L .19223 .32351 L p F P
0 g
s
.891 .757 .708 r
.19564 .31721 m .19194 .31373 L .19532 .30745 L p F P
0 g
s
.765 .992 .883 r
.76332 .4317 m .76505 .43002 L p .75313 .43878 L F P
0 g
s
.577 .899 .64 r
.76332 .4317 m .76505 .43002 L .76572 .42958 L closepath p F P
0 g
s
.483 .437 .73 r
.60254 .3417 m .60469 .3397 L p .60552 .34919 L F P
0 g
s
.483 .437 .73 r
.60552 .34919 m .60475 .34895 L .60254 .3417 L p F P
0 g
s
.506 .466 .747 r
.61884 .36985 m .61103 .36831 L .61031 .36614 L p F P
0 g
s
.481 .546 .846 r
.73728 .23243 m .73237 .23173 L .72946 .22584 L p F P
0 g
s
.493 .457 .746 r
.61031 .36614 m .6079 .35884 L .61633 .3609 L closepath p F P
0 g
s
.506 .466 .747 r
.61031 .36614 m .61633 .3609 L p .61884 .36985 L F P
0 g
s
.87 .751 .729 r
.18812 .34976 m .18545 .35401 L .18184 .35008 L p F P
0 g
s
.87 .751 .729 r
.18184 .35008 m .18413 .34643 L .18812 .34976 L p F P
0 g
s
.87 .751 .729 r
.18812 .34976 m .18413 .34643 L .18822 .33988 L p F P
0 g
s
.76 .767 .859 r
.12198 .43863 m .11067 .44614 L .10692 .4427 L p F P
0 g
s
.842 .751 .763 r
.17139 .3906 m .16858 .39414 L .16496 .3902 L p F P
0 g
s
.842 .751 .763 r
.16496 .3902 m .16716 .3874 L .17139 .3906 L p F P
0 g
s
.842 .752 .764 r
.17139 .3906 m .16716 .3874 L .17275 .38032 L p F P
0 g
s
.873 .756 .731 r
.18845 .32994 m .19233 .33333 L .18822 .33988 L p F P
0 g
s
.873 .755 .73 r
.19055 .32656 m .18845 .32994 L .19233 .33333 L p F P
0 g
s
.48 .44 .735 r
.60498 .34967 m .60475 .34895 L .60552 .34919 L closepath p F P
0 g
s
.39 .405 .755 r
.78406 .30162 m .78221 .3006 L .78315 .29901 L closepath p F P
0 g
s
.408 .428 .769 r
.78101 .29313 m .77864 .29199 L p .78221 .3006 L F P
0 g
s
.408 .428 .769 r
.78221 .3006 m .78315 .29901 L .78101 .29313 L p F P
0 g
s
.482 .443 .738 r
.60552 .34919 m .60498 .34967 L .60757 .35782 L p F P
0 g
s
.496 .453 .74 r
.61633 .3609 m .6079 .35884 L .60757 .35782 L p F P
0 g
s
.496 .453 .74 r
.60757 .35782 m .61431 .35178 L p .61633 .3609 L F P
0 g
s
.482 .443 .738 r
.60757 .35782 m .61431 .35178 L .60552 .34919 L p F P
0 g
s
.581 .599 .835 r
.67447 .43475 m .66254 .43593 L .65955 .43006 L p F P
0 g
s
.442 .486 .81 r
.75802 .25955 m .76666 .26208 L .7641 .26736 L p F P
0 g
s
.445 .493 .815 r
.76037 .25432 m .75802 .25955 L .76666 .26208 L p F P
0 g
s
.45 .501 .82 r
.75353 .25256 m .76037 .25432 L .75802 .25955 L p F P
0 g
s
.593 .655 .88 r
.69244 .44294 m .68043 .44498 L .6775 .43999 L p F P
0 g
s
.607 .746 .943 r
.06637 .4492 m .07715 .44662 L .08096 .44991 L p F P
0 g
s
.608 .747 .943 r
.07715 .44662 m .06637 .4492 L .06253 .44594 L p F P
0 g
s
.506 .578 .862 r
.71936 .21413 m .71138 .21361 L .70847 .20815 L p F P
0 g
s
.255 .2 .6 r
.79472 .36579 m .79877 .36031 L .79648 .35556 L p F P
0 g
s
.216 .146 .559 r
.79877 .36031 m .79472 .36579 L .7963 .37077 L p F P
0 g
s
.333 .311 .685 r
.79396 .3412 m .79551 .33897 L .79358 .33168 L p F P
0 g
s
.309 .279 .663 r
.79693 .34483 m .79396 .3412 L .79551 .33897 L closepath p F P
0 g
s
.673 .864 .972 r
.73789 .44358 m .73335 .44754 L p .72494 .44752 L F P
0 g
s
.699 .884 .966 r
.73335 .44754 m .73789 .44358 L .73959 .44473 L closepath p F P
0 g
s
.547 .542 .801 r
.65049 .41073 m .65353 .41747 L .64152 .41757 L p F P
0 g
s
.547 .542 .801 r
.64424 .41062 m .65049 .41073 L p .64152 .41757 L F P
0 g
s
.547 .542 .801 r
.64152 .41757 m .63999 .41403 L .64424 .41062 L p F P
0 g
s
.29 .231 .616 r
.59416 .24895 m .59666 .25335 L .59266 .25926 L p F P
0 g
s
.301 .253 .635 r
.59313 .26708 m .59578 .26347 L .59266 .25926 L p F P
0 g
s
.256 .221 .626 r
.59666 .25335 m .59266 .25926 L .59578 .26347 L p F P
0 g
s
.402 .424 .769 r
.78101 .29313 m .77864 .29199 L .77983 .2899 L closepath p F P
0 g
s
.419 .445 .781 r
.77799 .28509 m .77443 .28358 L p .77864 .29199 L F P
0 g
s
.419 .445 .781 r
.77864 .29199 m .77983 .2899 L .77799 .28509 L p F P
0 g
s
0 0 .17 r
.78742 .3983 m .79202 .39273 L p .78592 .40384 L F P
0 g
s
0 0 .17 r
.78592 .40384 m .78608 .40263 L .78742 .3983 L p F P
0 g
s
.052 0 .347 r
.78742 .3983 m .79202 .39273 L .79297 .38695 L p F P
0 g
s
.479 .446 .743 r
.61266 .34253 m .60552 .34919 L .61431 .35178 L p F P
0 g
s
.483 .437 .73 r
.60469 .3397 m .61266 .34253 L .60552 .34919 L p F P
0 g
s
.431 .474 .804 r
.7641 .26736 m .77201 .26995 L .76905 .26287 L p F P
0 g
s
.431 .474 .804 r
.76905 .26287 m .76666 .26208 L .7641 .26736 L p F P
0 g
s
.433 .471 .8 r
.7641 .26736 m .77201 .26995 L p .76958 .27537 L F P
0 g
s
.366 .322 .676 r
.59769 .28705 m .59391 .2837 L .59621 .28088 L closepath p F P
0 g
s
.359 .313 .669 r
.59391 .2837 m .59621 .28088 L .59458 .27387 L p F P
0 g
s
0 0 .354 r
.59866 .2127 m .59607 .21824 L .59621 .22338 L p F P
0 g
s
0 0 .193 r
.59607 .21824 m .59866 .2127 L .5994 .20727 L p F P
0 g
s
0 0 .385 r
.59482 .2259 m .59621 .22338 L .59607 .21824 L p F P
0 g
s
.826 .753 .783 r
.16524 .39786 m .16858 .39414 L .16496 .3902 L p F P
0 g
s
.413 .442 .781 r
.77799 .28509 m .77443 .28358 L .77618 .28036 L closepath p F P
0 g
s
.429 .462 .793 r
.77499 .27739 m .76958 .27537 L p .77443 .28358 L F P
0 g
s
.429 .462 .793 r
.77443 .28358 m .77618 .28036 L .77499 .27739 L p F P
0 g
s
.423 .459 .793 r
.77499 .27739 m .76958 .27537 L .77218 .27035 L closepath p F P
0 g
s
.433 .471 .8 r
.77201 .26995 m .77218 .27035 L .76958 .27537 L p F P
0 g
s
.338 .286 .651 r
.59313 .26708 m .59578 .26347 L p .59477 .27362 L F P
0 g
s
.338 .286 .651 r
.59477 .27362 m .59445 .27326 L .59313 .26708 L p F P
0 g
s
.586 .67 .897 r
.66034 .18523 m .66967 .18397 L .66675 .17934 L p F P
0 g
s
.586 .67 .897 r
.66675 .17934 m .66151 .18014 L .66034 .18523 L p F P
0 g
s
.581 .672 .902 r
.65475 .18123 m .66151 .18014 L .66034 .18523 L p F P
0 g
s
.731 .77 .883 r
.10095 .44593 m .09574 .44879 L .09196 .44544 L p F P
0 g
s
.683 .763 .912 r
.08096 .44991 m .09196 .44544 L .09574 .44879 L p F P
0 g
s
.35 .353 .723 r
.78891 .31605 m .79066 .31306 L p .79247 .32223 L F P
0 g
s
.35 .353 .723 r
.79247 .32223 m .7903 .32055 L .78891 .31605 L p F P
0 g
s
.364 .375 .739 r
.78891 .31605 m .78715 .31069 L .79066 .31306 L closepath p F P
0 g
s
.731 .972 .929 r
.75147 .43841 m .75683 .43503 L .75313 .43878 L closepath p F P
0 g
s
.674 .959 .943 r
.73959 .44473 m .75147 .43841 L .75313 .43878 L p F P
0 g
s
.765 .992 .883 r
.76328 .43056 m .75683 .43503 L .75313 .43878 L p F P
0 g
s
.765 .992 .883 r
.76505 .43002 m .76328 .43056 L p .75313 .43878 L F P
0 g
s
.831 .757 .781 r
.16095 .39469 m .16524 .39786 L .15869 .40526 L p F P
0 g
s
.826 .753 .783 r
.16496 .3902 m .16095 .39469 L .16524 .39786 L p F P
0 g
s
.856 .752 .748 r
.17822 .37329 m .17694 .37511 L .17332 .37116 L p F P
0 g
s
.856 .752 .748 r
.17332 .37116 m .17412 .37003 L .17822 .37329 L p F P
0 g
s
.856 .751 .746 r
.17822 .37329 m .17412 .37003 L .17889 .36323 L p F P
0 g
s
.135 .017 .443 r
.7939 .38031 m .79295 .38148 L .79297 .38695 L p F P
0 g
s
.856 .754 .749 r
.18374 .35642 m .18545 .35401 L .18184 .35008 L p F P
0 g
s
.448 .501 .821 r
.76037 .25432 m .75353 .25256 L .75225 .24969 L p F P
0 g
s
.363 .375 .739 r
.79066 .31306 m .78715 .31069 L .78617 .30772 L p F P
0 g
s
.35 .353 .722 r
.79137 .32403 m .7903 .32055 L .79247 .32223 L closepath p F P
0 g
s
.061 .008 .476 r
.59621 .22338 m .59482 .2259 L .59533 .23152 L p F P
0 g
s
.048 0 .473 r
.59404 .23394 m .59533 .23152 L .59482 .2259 L p F P
0 g
s
.363 .375 .739 r
.78617 .30772 m .78822 .30408 L p .79066 .31306 L F P
0 g
s
.377 .396 .754 r
.78617 .30772 m .78406 .30162 L .78822 .30408 L closepath p F P
0 g
s
.684 .764 .912 r
.09196 .44544 m .08096 .44991 L .07715 .44662 L p F P
0 g
s
.552 .637 .888 r
.67259 .18867 m .68147 .18796 L .67995 .19313 L p F P
0 g
s
.554 .633 .884 r
.67995 .19313 m .68758 .1927 L .68467 .18774 L p F P
0 g
s
.554 .633 .884 r
.68467 .18774 m .68147 .18796 L .67995 .19313 L p F P
0 g
s
.336 .33 .705 r
.79137 .32403 m .79247 .32223 L p .79364 .33158 L F P
0 g
s
.336 .33 .705 r
.79364 .33158 m .79352 .33148 L .79137 .32403 L p F P
0 g
s
.546 .541 .8 r
.63999 .41403 m .63847 .4105 L .64424 .41062 L closepath p F P
0 g
s
.111 .073 .531 r
.59533 .23152 m .59404 .23394 L .5955 .23867 L p F P
0 g
s
.493 .555 .848 r
.72946 .22584 m .72798 .22567 L .72862 .22414 L closepath p F P
0 g
s
.499 .564 .853 r
.72656 .22012 m .72862 .22414 L .72798 .22567 L p F P
0 g
s
.841 .753 .767 r
.17275 .38032 m .17694 .37511 L .17332 .37116 L p F P
0 g
s
.571 .583 .826 r
.65955 .43006 m .65745 .4302 L .65903 .429 L closepath p F P
0 g
s
.571 .573 .816 r
.65654 .42388 m .65903 .429 L .65745 .4302 L p F P
0 g
s
.416 .375 .706 r
.60176 .30271 m .59757 .30736 L .60333 .31082 L p F P
0 g
s
.426 .37 .692 r
.60091 .29955 m .60176 .30271 L .59757 .30736 L p F P
0 g
s
.426 .37 .692 r
.59793 .29746 m .60091 .29955 L p .59757 .30736 L F P
0 g
s
.376 .396 .754 r
.78822 .30408 m .78406 .30162 L .78315 .29901 L p F P
0 g
s
.858 .756 .749 r
.1797 .35311 m .18374 .35642 L .17889 .36323 L p F P
0 g
s
.856 .754 .749 r
.18184 .35008 m .1797 .35311 L .18374 .35642 L p F P
0 g
s
.689 .974 .782 r
.76328 .43056 m .76891 .4259 L .76505 .43002 L closepath p F P
0 g
s
.678 .938 .654 r
.7755 .41944 m .77492 .42011 L p .76505 .43002 L F P
0 g
s
.678 .938 .654 r
.77492 .42011 m .76891 .4259 L .76505 .43002 L p F P
0 g
s
.634 .85 .466 r
.60363 .19597 m .60155 .20082 L p .60327 .19765 L F P
0 g
s
.634 .85 .466 r
.60774 .18942 m .60363 .19597 L p .60327 .19765 L F P
0 g
s
0 0 0 r
.60363 .19597 m .60155 .20082 L .60042 .20438 L p F P
0 g
s
0 0 0 r
.60147 .20188 m .60363 .19597 L p .60091 .20308 L F P
0 g
s
0 0 0 r
.60042 .20438 m .60147 .20188 L p .60091 .20308 L F P
0 g
s
0 0 .11 r
.60147 .20188 m .60066 .20734 L p .60251 .19964 L F P
0 g
s
0 0 0 r
.60363 .19597 m .60147 .20188 L p .60403 .19413 L F P
0 g
s
0 0 .11 r
.60326 .19657 m .60147 .20188 L p .60251 .19964 L F P
0 g
s
0 0 0 r
.60515 .19074 m .60363 .19597 L p .60403 .19413 L F P
0 g
s
0 0 0 r
.5994 .20727 m .60042 .20438 L .60155 .20082 L p F P
0 g
s
.681 .745 .899 r
.62515 .18073 m .63697 .17607 L .6399 .17992 L p F P
0 g
s
.702 .762 .898 r
.63697 .17607 m .62515 .18073 L .62222 .17773 L p F P
0 g
s
.636 .708 .898 r
.65182 .17694 m .6399 .17992 L .63697 .17607 L p F P
0 g
s
.625 .697 .897 r
.6399 .17992 m .65182 .17694 L .65475 .18123 L p F P
0 g
s
.376 .396 .754 r
.78315 .29901 m .78516 .29529 L p .78822 .30408 L F P
0 g
s
.389 .416 .767 r
.78315 .29901 m .78101 .29313 L .78516 .29529 L closepath p F P
0 g
s
.787 .768 .836 r
.12264 .43811 m .12198 .43863 L .11826 .43511 L p F P
0 g
s
.76 .767 .859 r
.10692 .4427 m .11826 .43511 L .12198 .43863 L p F P
0 g
s
.434 .682 .968 r
.0482 .44272 m .05496 .44281 L .05885 .4461 L p F P
0 g
s
.874 .757 .73 r
.18435 .3365 m .18822 .33988 L .18413 .34643 L p F P
0 g
s
.873 .756 .731 r
.18822 .33988 m .18435 .3365 L .18845 .32994 L p F P
0 g
s
.787 .768 .836 r
.11826 .43511 m .11848 .43493 L .12264 .43811 L p F P
0 g
s
.782 .765 .838 r
.12974 .42606 m .11848 .43493 L .12264 .43811 L p F P
0 g
s
.782 .765 .838 r
.12264 .43811 m .13345 .42966 L .12974 .42606 L p F P
0 g
s
.336 .33 .705 r
.79358 .33168 m .79352 .33148 L .79364 .33158 L closepath p F P
0 g
s
.889 .758 .711 r
.19223 .32351 m .19055 .32656 L .18692 .32295 L p F P
0 g
s
.889 .758 .711 r
.18692 .32295 m .18853 .32004 L .19223 .32351 L p F P
0 g
s
.891 .758 .709 r
.19223 .32351 m .18853 .32004 L .19194 .31373 L p F P
0 g
s
.309 .295 .682 r
.79364 .33158 m .79358 .33168 L .79551 .33897 L p F P
0 g
s
.309 .299 .685 r
.79691 .32626 m .79364 .33158 L .79752 .3358 L p F P
0 g
s
.336 .33 .705 r
.79247 .32223 m .79691 .32626 L .79364 .33158 L p F P
0 g
s
.309 .295 .682 r
.79551 .33897 m .79752 .3358 L .79364 .33158 L p F P
0 g
s
.832 .757 .78 r
.15869 .40526 m .15675 .40746 L .1531 .40365 L p F P
0 g
s
.832 .757 .78 r
.1531 .40365 m .15448 .40207 L .15869 .40526 L p F P
0 g
s
.831 .757 .781 r
.15869 .40526 m .15448 .40207 L .16095 .39469 L p F P
0 g
s
.448 .501 .821 r
.75225 .24969 m .75347 .24676 L p .76037 .25432 L F P
0 g
s
.457 .515 .83 r
.75225 .24969 m .7506 .24612 L .75347 .24676 L closepath p F P
0 g
s
.737 .892 .95 r
.73789 .44358 m .73959 .44473 L .75147 .43841 L p F P
0 g
s
.466 .431 .735 r
.61077 .33377 m .60469 .3397 L .61266 .34253 L p F P
0 g
s
.471 .423 .722 r
.61047 .33281 m .61077 .33377 L .60469 .3397 L p F P
0 g
s
.471 .423 .722 r
.6041 .33013 m .61047 .33281 L p .60469 .3397 L F P
0 g
s
.622 .723 .919 r
.69532 .44729 m .70734 .44454 L .71017 .44821 L p F P
0 g
s
.614 .681 .89 r
.70448 .44055 m .70734 .44454 L .69532 .44729 L p F P
0 g
s
.614 .681 .89 r
.6951 .44241 m .70448 .44055 L p .69532 .44729 L F P
0 g
s
.614 .681 .89 r
.69532 .44729 m .69316 .44402 L .6951 .44241 L p F P
0 g
s
.482 .702 .966 r
.05885 .4461 m .06253 .44594 L .05869 .44265 L p F P
0 g
s
.482 .702 .966 r
.05869 .44265 m .05496 .44281 L .05885 .4461 L p F P
0 g
s
.547 .535 .793 r
.64424 .41062 m .63847 .4105 L .63576 .40399 L p F P
0 g
s
.556 .643 .891 r
.68147 .18796 m .67259 .18867 L .66967 .18397 L p F P
0 g
s
.531 .614 .88 r
.69587 .19765 m .69049 .19772 L .68758 .1927 L p F P
0 g
s
.813 .758 .801 r
.15125 .41295 m .15675 .40746 L .1531 .40365 L p F P
0 g
s
.731 .77 .883 r
.09196 .44544 m .09682 .44275 L .10095 .44593 L p F P
0 g
s
.728 .768 .885 r
.10316 .43928 m .09682 .44275 L .10095 .44593 L p F P
0 g
s
.728 .768 .885 r
.10095 .44593 m .10692 .4427 L .10316 .43928 L p F P
0 g
s
.331 .284 .654 r
.59458 .27387 m .59445 .27326 L .59477 .27362 L closepath p F P
0 g
s
0 0 .212 r
.78541 .40441 m .78592 .40384 L .78608 .40263 L closepath p F P
0 g
s
.481 .546 .846 r
.72946 .22584 m .7393 .22722 L .73728 .23243 L p F P
0 g
s
.48 .548 .848 r
.7393 .22722 m .72946 .22584 L .72862 .22414 L p F P
0 g
s
.845 .756 .765 r
.1686 .37709 m .17275 .38032 L .16716 .3874 L p F P
0 g
s
.841 .753 .767 r
.17332 .37116 m .1686 .37709 L .17275 .38032 L p F P
0 g
s
.094 0 .43 r
.79714 .37599 m .7939 .38031 L .79416 .3855 L p F P
0 g
s
.162 .076 .503 r
.7939 .38031 m .79714 .37599 L .7963 .37077 L p F P
0 g
s
.135 .017 .443 r
.79297 .38695 m .79416 .3855 L .7939 .38031 L p F P
0 g
s
.345 .303 .668 r
.59477 .27362 m .59458 .27387 L .59621 .28088 L p F P
0 g
s
.388 .416 .768 r
.78516 .29529 m .78101 .29313 L .77983 .2899 L p F P
0 g
s
.818 .759 .797 r
.15125 .41295 m .14504 .41928 L .14136 .41556 L p F P
0 g
s
.818 .759 .797 r
.14136 .41556 m .14699 .40979 L .15125 .41295 L p F P
0 g
s
.813 .758 .801 r
.1531 .40365 m .14699 .40979 L .15125 .41295 L p F P
0 g
s
.581 .599 .835 r
.65955 .43006 m .67158 .42916 L p .67447 .43475 L F P
0 g
s
.564 .579 .827 r
.66859 .42334 m .67158 .42916 L .65955 .43006 L p F P
0 g
s
.564 .579 .827 r
.66581 .42347 m .66859 .42334 L p .65955 .43006 L F P
0 g
s
.564 .579 .827 r
.65955 .43006 m .65903 .429 L .66581 .42347 L p F P
0 g
s
.251 .198 .601 r
.79862 .3526 m .79648 .35556 L .79877 .36031 L p F P
0 g
s
.284 .242 .633 r
.79648 .35556 m .79862 .3526 L .7972 .34596 L p F P
0 g
s
.52 .59 .865 r
.70847 .20815 m .70779 .20813 L .70807 .2074 L closepath p F P
0 g
s
.525 .598 .87 r
.70557 .20287 m .70807 .2074 L .70779 .20813 L p F P
0 g
s
.345 .303 .668 r
.59621 .28088 m .59875 .27758 L .59477 .27362 L p F P
0 g
s
.308 .277 .66 r
.59916 .26762 m .59477 .27362 L .59875 .27758 L p F P
0 g
s
.338 .286 .651 r
.59578 .26347 m .59916 .26762 L .59477 .27362 L p F P
0 g
s
.4 .434 .78 r
.77983 .2899 m .77799 .28509 L .78148 .28669 L closepath p F P
0 g
s
.388 .416 .768 r
.77983 .2899 m .78148 .28669 L p .78516 .29529 L F P
0 g
s
.805 .765 .816 r
.13406 .42911 m .13345 .42966 L .12974 .42606 L p F P
0 g
s
.805 .765 .816 r
.12974 .42606 m .12988 .42593 L .13406 .42911 L p F P
0 g
s
.804 .765 .818 r
.13898 .41768 m .14329 .42082 L .13406 .42911 L p F P
0 g
s
.804 .765 .818 r
.13406 .42911 m .12988 .42593 L .13898 .41768 L p F P
0 g
s
.219 .19 .611 r
.59716 .24377 m .59416 .24895 L .59666 .25335 L p F P
0 g
s
.184 .148 .58 r
.59684 .24185 m .5955 .23867 L p .59416 .24895 L F P
0 g
s
.184 .148 .58 r
.59416 .24895 m .59716 .24377 L .59684 .24185 L p F P
0 g
s
.878 .762 .731 r
.18845 .32994 m .19055 .32656 L .18692 .32295 L p F P
0 g
s
.29 .267 .66 r
.79551 .33897 m .79752 .3358 L p .79748 .34554 L F P
0 g
s
.29 .267 .66 r
.79748 .34554 m .79693 .34483 L .79551 .33897 L p F P
0 g
s
.798 .761 .819 r
.14136 .41556 m .13898 .41768 L .14329 .42082 L p F P
0 g
s
.798 .761 .819 r
.14329 .42082 m .14504 .41928 L .14136 .41556 L p F P
0 g
s
.563 .578 .827 r
.65903 .429 m .65654 .42388 L .66581 .42347 L closepath p F P
0 g
s
.474 .537 .842 r
.73728 .23243 m .74477 .23367 L .74185 .22763 L p F P
0 g
s
.474 .537 .842 r
.74185 .22763 m .7393 .22722 L .73728 .23243 L p F P
0 g
s
.474 .533 .838 r
.73728 .23243 m .74477 .23367 L p .74582 .23944 L F P
0 g
s
0 0 .036 r
.78592 .40384 m .78541 .40441 L .78186 .41098 L p F P
0 g
s
.506 .578 .862 r
.70847 .20815 m .72074 .20889 L p .71936 .21413 L F P
0 g
s
.5 .579 .866 r
.71784 .20349 m .72074 .20889 L .70847 .20815 L p F P
0 g
s
.5 .579 .866 r
.7093 .20302 m .71784 .20349 L p .70847 .20815 L F P
0 g
s
.5 .579 .866 r
.70847 .20815 m .70807 .2074 L .7093 .20302 L p F P
0 g
s
.48 .548 .848 r
.72862 .22414 m .72985 .22049 L p .7393 .22722 L F P
0 g
s
.488 .559 .855 r
.72862 .22414 m .72656 .22012 L .72985 .22049 L closepath p F P
0 g
s
.584 .639 .871 r
.68953 .43825 m .6775 .43999 L .67455 .43474 L p F P
0 g
s
.593 .655 .88 r
.6775 .43999 m .68953 .43825 L .69244 .44294 L p F P
0 g
s
.646 .786 .949 r
.71017 .44821 m .72217 .44463 L .72494 .44752 L p F P
0 g
s
.634 .755 .935 r
.72217 .44463 m .71017 .44821 L .70734 .44454 L p F P
0 g
s
.588 .681 .905 r
.66151 .18014 m .65475 .18123 L .65182 .17694 L p F P
0 g
s
.673 .864 .972 r
.72494 .44752 m .73691 .44286 L .73789 .44358 L p F P
0 g
s
.662 .829 .964 r
.73691 .44286 m .72494 .44752 L .72217 .44463 L p F P
0 g
s
.858 .756 .749 r
.17889 .36323 m .17488 .35992 L .1797 .35311 L p F P
0 g
s
.86 .757 .747 r
.17488 .35992 m .17889 .36323 L .17412 .37003 L p F P
0 g
s
.456 .516 .831 r
.75347 .24676 m .7506 .24612 L .74768 .23981 L p F P
0 g
s
.331 .33 .707 r
.79563 .3169 m .79247 .32223 L .79691 .32626 L p F P
0 g
s
.35 .353 .723 r
.79066 .31306 m .79563 .3169 L .79247 .32223 L p F P
0 g
s
.547 .535 .793 r
.63576 .40399 m .63669 .40323 L p .64424 .41062 L F P
0 g
s
.537 .529 .793 r
.63576 .40399 m .63541 .40316 L .63669 .40323 L closepath p F P
0 g
s
.512 .592 .871 r
.70807 .2074 m .70557 .20287 L .7093 .20302 L closepath p F P
0 g
s
.396 .356 .696 r
.60091 .29955 m .59793 .29746 L .59979 .29529 L closepath p F P
0 g
s
.391 .349 .691 r
.59793 .29746 m .59979 .29529 L .59792 .28799 L p F P
0 g
s
.4 .434 .781 r
.78148 .28669 m .77799 .28509 L .77618 .28036 L p F P
0 g
s
0 0 .11 r
.60042 .20438 m .5994 .20727 L .59866 .2127 L p F P
0 g
s
.451 .415 .727 r
.61047 .33281 m .6041 .33013 L .60835 .32581 L closepath p F P
0 g
s
.459 .408 .714 r
.60729 .32227 m .60835 .32581 L .6041 .33013 L p F P
0 g
s
.459 .408 .714 r
.60366 .3205 m .60729 .32227 L p .6041 .33013 L F P
0 g
s
.539 .522 .785 r
.63669 .40323 m .63541 .40316 L .63233 .3955 L p F P
0 g
s
0 0 .013 r
.79 .39885 m .78592 .40384 L .78494 .40754 L p F P
0 g
s
0 0 .17 r
.79202 .39273 m .79 .39885 L .78592 .40384 L p F P
0 g
s
0 0 .036 r
.78186 .41098 m .78494 .40754 L .78592 .40384 L p F P
0 g
s
.845 .756 .765 r
.16716 .3874 m .16305 .38415 L .1686 .37709 L p F P
0 g
s
.845 .756 .764 r
.16716 .3874 m .16496 .3902 L .16132 .38637 L p F P
0 g
s
.845 .756 .764 r
.16132 .38637 m .16305 .38415 L .16716 .3874 L p F P
0 g
s
.874 .757 .731 r
.18413 .34643 m .18184 .35008 L .17821 .34634 L p F P
0 g
s
.874 .757 .731 r
.17821 .34634 m .18027 .34305 L .18413 .34643 L p F P
0 g
s
.874 .757 .73 r
.18413 .34643 m .18027 .34305 L .18435 .3365 L p F P
0 g
s
.373 .327 .677 r
.59621 .28088 m .59875 .27758 L p .59828 .28755 L F P
0 g
s
.373 .327 .677 r
.59828 .28755 m .59769 .28705 L .59621 .28088 L p F P
0 g
s
.761 .768 .859 r
.11826 .43511 m .10692 .4427 L .10316 .43928 L p F P
0 g
s
.877 .763 .732 r
.18473 .32649 m .18845 .32994 L .18435 .3365 L p F P
0 g
s
.878 .762 .731 r
.18692 .32295 m .18473 .32649 L .18845 .32994 L p F P
0 g
s
0 0 .448 r
.5988 .21785 m .59621 .22338 L .59712 .22828 L p F P
0 g
s
0 0 .354 r
.59621 .22338 m .5988 .21785 L .59866 .2127 L p F P
0 g
s
.061 .008 .476 r
.59533 .23152 m .59712 .22828 L .59621 .22338 L p F P
0 g
s
.12 .079 .533 r
.59712 .22828 m .59533 .23152 L .59613 .2375 L p F P
0 g
s
.111 .073 .531 r
.5955 .23867 m .59613 .2375 L .59533 .23152 L p F P
0 g
s
.531 .512 .779 r
.63233 .3955 m .63067 .39537 L .6319 .39438 L closepath p F P
0 g
s
.533 .503 .768 r
.62925 .38753 m .6319 .39438 L .63067 .39537 L p F P
0 g
s
.533 .503 .768 r
.62584 .38714 m .62925 .38753 L p .63067 .39537 L F P
0 g
s
.165 .079 .505 r
.80039 .36528 m .7963 .37077 L .79714 .37599 L p F P
0 g
s
.216 .146 .559 r
.7963 .37077 m .80039 .36528 L .79877 .36031 L p F P
0 g
s
.522 .5 .772 r
.62925 .38753 m .62584 .38714 L .62833 .38509 L closepath p F P
0 g
s
.524 .491 .761 r
.62615 .37926 m .62833 .38509 L .62584 .38714 L p F P
0 g
s
.524 .491 .761 r
.62196 .37862 m .62615 .37926 L p .62584 .38714 L F P
0 g
s
.291 .268 .66 r
.7972 .34596 m .79693 .34483 L .79748 .34554 L closepath p F P
0 g
s
.829 .758 .784 r
.16095 .39469 m .16496 .3902 L .16132 .38637 L p F P
0 g
s
.051 0 .347 r
.79416 .3855 m .79297 .38695 L .79202 .39273 L p F P
0 g
s
.608 .747 .943 r
.06253 .44594 m .07333 .44332 L .07715 .44662 L p F P
0 g
s
.609 .747 .943 r
.07333 .44332 m .06253 .44594 L .05869 .44265 L p F P
0 g
s
.256 .223 .628 r
.79748 .34554 m .7972 .34596 L .79862 .3526 L p F P
0 g
s
.466 .523 .833 r
.74768 .23981 m .74582 .23944 L .74663 .23755 L closepath p F P
0 g
s
.474 .533 .838 r
.74477 .23367 m .74663 .23755 L .74582 .23944 L p F P
0 g
s
.4 .434 .781 r
.77618 .28036 m .77719 .27828 L p .78148 .28669 L F P
0 g
s
.411 .451 .792 r
.77618 .28036 m .77499 .27739 L .77719 .27828 L closepath p F P
0 g
s
.547 .535 .793 r
.63669 .40323 m .64744 .40375 L p .64424 .41062 L F P
0 g
s
.537 .533 .798 r
.64744 .40375 m .63669 .40323 L .64444 .39665 L closepath p F P
0 g
s
.539 .522 .785 r
.64438 .39651 m .64444 .39665 L .63669 .40323 L p F P
0 g
s
.539 .522 .785 r
.63233 .3955 m .64438 .39651 L p .63669 .40323 L F P
0 g
s
.513 .487 .766 r
.62615 .37926 m .62196 .37862 L .62498 .37606 L closepath p F P
0 g
s
.515 .478 .754 r
.62303 .37067 m .62498 .37606 L .62196 .37862 L p F P
0 g
s
.515 .478 .754 r
.61884 .36985 m .62303 .37067 L p .62196 .37862 L F P
0 g
s
.35 .358 .728 r
.79371 .30774 m .79066 .31306 L .79563 .3169 L p F P
0 g
s
.363 .375 .739 r
.78822 .30408 m .79371 .30774 L .79066 .31306 L p F P
0 g
s
0 0 0 r
.77492 .42011 m .77675 .41803 L .7755 .41944 L closepath p F P
0 g
s
0 0 0 r
.7755 .41944 m .77675 .41803 L .78186 .41098 L p F P
0 g
s
.613 .68 .889 r
.69316 .44402 m .69244 .44294 L .6951 .44241 L closepath p F P
0 g
s
.737 .892 .95 r
.75147 .43841 m .74885 .43725 L p .73789 .44358 L F P
0 g
s
.687 .968 .93 r
.75683 .43503 m .75147 .43841 L .74885 .43725 L p F P
0 g
s
.256 .223 .628 r
.79862 .3526 m .80025 .35013 L .79748 .34554 L p F P
0 g
s
.255 .225 .631 r
.8009 .34019 m .79748 .34554 L .80025 .35013 L p F P
0 g
s
.29 .267 .66 r
.79752 .3358 m .8009 .34019 L .79748 .34554 L p F P
0 g
s
.86 .76 .751 r
.1797 .35311 m .18184 .35008 L .17821 .34634 L p F P
0 g
s
.834 .761 .782 r
.1568 .39146 m .16095 .39469 L .15448 .40207 L p F P
0 g
s
.829 .758 .784 r
.16132 .38637 m .1568 .39146 L .16095 .39469 L p F P
0 g
s
.564 .572 .819 r
.66581 .42347 m .65654 .42388 L .65355 .41752 L p F P
0 g
s
.368 .326 .68 r
.59792 .28799 m .59769 .28705 L .59828 .28755 L closepath p F P
0 g
s
.804 .978 .899 r
.60851 .18585 m .61053 .18625 L .617 .18111 L p F P
0 g
s
.895 .963 .829 r
.60774 .18942 m .60851 .18585 L .61053 .18625 L closepath p F P
0 g
s
.859 .757 .749 r
.17412 .37003 m .17332 .37116 L .16968 .36736 L p F P
0 g
s
.859 .757 .749 r
.16968 .36736 m .17014 .36671 L .17412 .37003 L p F P
0 g
s
.86 .757 .747 r
.17412 .37003 m .17014 .36671 L .17488 .35992 L p F P
0 g
s
.284 .259 .654 r
.59948 .25767 m .59578 .26347 L .59916 .26762 L p F P
0 g
s
.256 .221 .626 r
.59578 .26347 m .59948 .25767 L .59666 .25335 L p F P
0 g
s
0 0 0 r
.78494 .40754 m .78186 .41098 L .77675 .41803 L p F P
0 g
s
.411 .452 .792 r
.77719 .27828 m .77499 .27739 L .77218 .27035 L p F P
0 g
s
.733 .771 .884 r
.09682 .44275 m .09196 .44544 L .08817 .4421 L p F P
0 g
s
.684 .764 .912 r
.07715 .44662 m .08817 .4421 L .09196 .44544 L p F P
0 g
s
.377 .339 .689 r
.59828 .28755 m .59792 .28799 L .59979 .29529 L p F P
0 g
s
.52 .505 .78 r
.6413 .38896 m .64438 .39651 L .63233 .3955 L p F P
0 g
s
.52 .505 .78 r
.63855 .38864 m .6413 .38896 L p .63233 .3955 L F P
0 g
s
.52 .505 .78 r
.63233 .3955 m .6319 .39438 L .63855 .38864 L p F P
0 g
s
.487 .561 .857 r
.72985 .22049 m .72656 .22012 L .72365 .21448 L p F P
0 g
s
.502 .475 .759 r
.62303 .37067 m .61884 .36985 L .62183 .36724 L closepath p F P
0 g
s
.506 .466 .747 r
.61991 .36175 m .62183 .36724 L .61884 .36985 L p F P
0 g
s
.506 .466 .747 r
.61633 .3609 m .61991 .36175 L p .61884 .36985 L F P
0 g
s
.5 .569 .857 r
.72365 .21448 m .71936 .21413 L .72104 .20944 L closepath p F P
0 g
s
.506 .578 .862 r
.72074 .20889 m .72104 .20944 L .71936 .21413 L p F P
0 g
s
.155 .126 .571 r
.59684 .24185 m .5955 .23867 L .59613 .2375 L closepath p F P
0 g
s
.704 .873 .961 r
.73691 .44286 m .74005 .44143 L .73789 .44358 L closepath p F P
0 g
s
.737 .892 .95 r
.74885 .43725 m .74005 .44143 L .73789 .44358 L p F P
0 g
s
.845 .759 .768 r
.1686 .37709 m .17332 .37116 L .16968 .36736 L p F P
0 g
s
.519 .504 .779 r
.6319 .39438 m .62925 .38753 L .63855 .38864 L closepath p F P
0 g
s
.53 .609 .876 r
.69587 .19765 m .70266 .19765 L .69975 .19247 L p F P
0 g
s
.53 .609 .876 r
.69975 .19247 m .69738 .19249 L .69587 .19765 L p F P
0 g
s
.531 .614 .88 r
.68758 .1927 m .69738 .19249 L .69587 .19765 L p F P
0 g
s
.685 .765 .912 r
.08817 .4421 m .07715 .44662 L .07333 .44332 L p F P
0 g
s
.872 .941 .573 r
.60851 .18585 m .60774 .18942 L .60363 .19597 L p F P
0 g
s
.448 .501 .821 r
.75347 .24676 m .76268 .24908 L .76037 .25432 L p F P
0 g
s
.451 .509 .827 r
.75555 .24157 m .75347 .24676 L .76268 .24908 L p F P
0 g
s
.456 .516 .831 r
.74768 .23981 m .75555 .24157 L .75347 .24676 L p F P
0 g
s
.437 .399 .719 r
.60729 .32227 m .60366 .3205 L .60604 .31798 L closepath p F P
0 g
s
.434 .395 .716 r
.60411 .31126 m .60333 .31082 L p .60366 .3205 L F P
0 g
s
.434 .395 .716 r
.60366 .3205 m .60604 .31798 L .60411 .31126 L p F P
0 g
s
.534 .618 .882 r
.69738 .19249 m .68758 .1927 L .68467 .18774 L p F P
0 g
s
.364 .381 .745 r
.79114 .29878 m .78822 .30408 L .79371 .30774 L p F P
0 g
s
.376 .396 .754 r
.78516 .29529 m .79114 .29878 L .78822 .30408 L p F P
0 g
s
.804 .978 .899 r
.617 .18111 m .61784 .17609 L p .60851 .18585 L F P
0 g
s
.774 .842 .903 r
.6193 .17501 m .61784 .17609 L .617 .18111 L p F P
0 g
s
.774 .842 .903 r
.617 .18111 m .62222 .17773 L .6193 .17501 L p F P
0 g
s
.546 .545 .805 r
.65049 .41073 m .64424 .41062 L .6488 .40686 L closepath p F P
0 g
s
.547 .535 .793 r
.64744 .40375 m .6488 .40686 L .64424 .41062 L p F P
0 g
s
.614 .665 .875 r
.6951 .44241 m .69244 .44294 L .68953 .43825 L p F P
0 g
s
.356 .332 .694 r
.60292 .2815 m .59828 .28755 L .60304 .29129 L p F P
0 g
s
.377 .339 .689 r
.59979 .29529 m .60304 .29129 L .59828 .28755 L p F P
0 g
s
.373 .327 .677 r
.59875 .27758 m .60292 .2815 L .59828 .28755 L p F P
0 g
s
.556 .643 .891 r
.66967 .18397 m .68175 .18287 L p .68147 .18796 L F P
0 g
s
.565 .646 .889 r
.68175 .18287 m .66967 .18397 L .66675 .17934 L p F P
0 g
s
.862 .761 .751 r
.17581 .34974 m .1797 .35311 L .17488 .35992 L p F P
0 g
s
.86 .76 .751 r
.17821 .34634 m .17581 .34974 L .1797 .35311 L p F P
0 g
s
.454 .516 .833 r
.75555 .24157 m .74768 .23981 L .74663 .23755 L p F P
0 g
s
.711 .985 .88 r
.75683 .43503 m .76137 .43056 L .76328 .43056 L closepath p F P
0 g
s
.687 .968 .93 r
.76137 .43056 m .75683 .43503 L p .74885 .43725 L F P
0 g
s
.788 .771 .837 r
.11826 .43511 m .11848 .43493 L .1158 .43282 L closepath p F P
0 g
s
.761 .768 .859 r
.1158 .43282 m .11826 .43511 L p .10316 .43928 L F P
0 g
s
.636 .708 .898 r
.63697 .17607 m .64889 .17275 L .65182 .17694 L p F P
0 g
s
.649 .72 .9 r
.64889 .17275 m .63697 .17607 L .63404 .17238 L p F P
0 g
s
.702 .762 .898 r
.62222 .17773 m .63404 .17238 L .63697 .17607 L p F P
0 g
s
.791 .77 .834 r
.12831 .42469 m .12974 .42606 L .11848 .43493 L p F P
0 g
s
.791 .77 .834 r
.12572 .42273 m .12831 .42469 L p .11848 .43493 L F P
0 g
s
.791 .77 .834 r
.11452 .43162 m .12572 .42273 L p .11848 .43493 L F P
0 g
s
.791 .77 .834 r
.11848 .43493 m .1158 .43282 L .11452 .43162 L p F P
0 g
s
.877 .763 .732 r
.18435 .3365 m .18062 .33304 L .18473 .32649 L p F P
0 g
s
.878 .763 .732 r
.18062 .33304 m .18435 .3365 L .18027 .34305 L p F P
0 g
s
.834 .761 .781 r
.15448 .40207 m .1531 .40365 L .14943 .39992 L p F P
0 g
s
.834 .761 .781 r
.14943 .39992 m .15038 .39883 L .15448 .40207 L p F P
0 g
s
.834 .761 .782 r
.15448 .40207 m .15038 .39883 L .1568 .39146 L p F P
0 g
s
.581 .61 .847 r
.67455 .43474 m .67447 .43475 L .67453 .43471 L closepath p F P
0 g
s
.581 .599 .835 r
.67158 .42916 m .67453 .43471 L .67447 .43475 L p F P
0 g
s
.584 .639 .871 r
.67455 .43474 m .6866 .43331 L .68953 .43825 L p F P
0 g
s
.576 .608 .847 r
.68365 .42811 m .6866 .43331 L .67455 .43474 L p F P
0 g
s
.576 .608 .847 r
.68216 .42824 m .68365 .42811 L p .67455 .43474 L F P
0 g
s
.576 .608 .847 r
.67455 .43474 m .67453 .43471 L .68216 .42824 L p F P
0 g
s
.575 .607 .847 r
.67453 .43471 m .67158 .42916 L .68216 .42824 L closepath p F P
0 g
s
.445 .493 .815 r
.7661 .25597 m .76037 .25432 L p .76666 .26208 L F P
0 g
s
.438 .489 .815 r
.76037 .25432 m .7661 .25597 L .76315 .24921 L p F P
0 g
s
.438 .489 .815 r
.76315 .24921 m .76268 .24908 L .76037 .25432 L p F P
0 g
s
.004 0 .33 r
.79718 .38146 m .79416 .3855 L .79406 .39026 L p F P
0 g
s
.051 0 .347 r
.79202 .39273 m .79406 .39026 L .79416 .3855 L p F P
0 g
s
.094 0 .43 r
.79416 .3855 m .79718 .38146 L .79714 .37599 L p F P
0 g
s
.492 .462 .752 r
.61991 .36175 m .61633 .3609 L .61884 .35862 L closepath p F P
0 g
s
.496 .453 .74 r
.61677 .35249 m .61884 .35862 L .61633 .3609 L p F P
0 g
s
.496 .453 .74 r
.61431 .35178 m .61677 .35249 L p .61633 .3609 L F P
0 g
s
.816 .762 .802 r
.14699 .40979 m .1531 .40365 L .14943 .39992 L p F P
0 g
s
.401 .359 .696 r
.59979 .29529 m .60304 .29129 L p .60315 .30107 L F P
0 g
s
.401 .359 .696 r
.60315 .30107 m .60091 .29955 L .59979 .29529 L p F P
0 g
s
.377 .402 .76 r
.78793 .29001 m .78516 .29529 L .79114 .29878 L p F P
0 g
s
.388 .416 .768 r
.78148 .28669 m .78793 .29001 L .78516 .29529 L p F P
0 g
s
.511 .594 .873 r
.7093 .20302 m .70557 .20287 L .70266 .19765 L p F P
0 g
s
.219 .176 .594 r
.80025 .35013 m .79862 .3526 L .79978 .35892 L p F P
0 g
s
.251 .198 .601 r
.79877 .36031 m .79978 .35892 L .79862 .3526 L p F P
0 g
s
.733 .771 .884 r
.08817 .4421 m .09278 .43952 L .09682 .44275 L p F P
0 g
s
.729 .77 .885 r
.09938 .43588 m .09278 .43952 L .09682 .44275 L p F P
0 g
s
.729 .77 .885 r
.09682 .44275 m .10316 .43928 L .09938 .43588 L p F P
0 g
s
.521 .499 .772 r
.63855 .38864 m .62925 .38753 L .62833 .38509 L p F P
0 g
s
.849 .761 .766 r
.16457 .37379 m .1686 .37709 L .16305 .38415 L p F P
0 g
s
.845 .759 .768 r
.16968 .36736 m .16457 .37379 L .1686 .37709 L p F P
0 g
s
.726 .78 .895 r
.63404 .17238 m .62222 .17773 L .6193 .17501 L p F P
0 g
s
0 0 0 r
.78409 .40936 m .78494 .40754 L p .77675 .41803 L F P
0 g
s
0 0 0 r
.78172 .41238 m .78409 .40936 L p .77691 .41784 L F P
0 g
s
0 0 0 r
.77675 .41803 m .78172 .41238 L p .77691 .41784 L F P
0 g
s
0 0 0 r
.78172 .41238 m .78336 .41052 L .78409 .40936 L closepath p F P
0 g
s
.675 .95 .697 r
.78172 .41238 m .77428 .42015 L p .78333 .41055 L F P
0 g
s
.675 .95 .697 r
.78336 .41052 m .78172 .41238 L p .78333 .41055 L F P
0 g
s
.685 .927 .615 r
.77675 .41803 m .78172 .41238 L p .77312 .42149 L F P
0 g
s
.685 .927 .615 r
.77312 .42149 m .77492 .42011 L .77675 .41803 L p F P
0 g
s
.821 .763 .798 r
.14699 .40979 m .14136 .41556 L .13767 .41192 L p F P
0 g
s
.821 .763 .798 r
.13767 .41192 m .14285 .40657 L .14699 .40979 L p F P
0 g
s
.816 .762 .802 r
.14943 .39992 m .14285 .40657 L .14699 .40979 L p F P
0 g
s
.454 .516 .833 r
.74663 .23755 m .74783 .23426 L p .75555 .24157 L F P
0 g
s
.462 .529 .84 r
.74663 .23755 m .74477 .23367 L .74783 .23426 L closepath p F P
0 g
s
.411 .452 .792 r
.77218 .27035 m .77231 .27006 L p .77719 .27828 L F P
0 g
s
.421 .468 .803 r
.77218 .27035 m .77201 .26995 L .77231 .27006 L closepath p F P
0 g
s
.595 .675 .896 r
.66151 .18014 m .66675 .17934 L .66382 .17477 L p F P
0 g
s
.595 .675 .896 r
.66382 .17477 m .6631 .1749 L .66151 .18014 L p F P
0 g
s
.588 .681 .905 r
.65182 .17694 m .6631 .1749 L .66151 .18014 L p F P
0 g
s
.778 .996 .862 r
.76137 .43056 m .76328 .43056 L .76891 .4259 L p F P
0 g
s
.194 .154 .581 r
.59613 .2375 m .5986 .233 L p .59748 .24324 L F P
0 g
s
.194 .154 .581 r
.59748 .24324 m .59684 .24185 L .59613 .2375 L p F P
0 g
s
.12 .079 .533 r
.59613 .2375 m .5986 .233 L .59712 .22828 L p F P
0 g
s
.39 .422 .774 r
.7841 .28144 m .78148 .28669 L .78793 .29001 L p F P
0 g
s
.4 .434 .781 r
.77719 .27828 m .7841 .28144 L .78148 .28669 L p F P
0 g
s
.521 .499 .772 r
.62833 .38509 m .63359 .38042 L p .63855 .38864 L F P
0 g
s
.51 .491 .772 r
.62833 .38509 m .62615 .37926 L .63359 .38042 L closepath p F P
0 g
s
.429 .475 .806 r
.76905 .26287 m .76666 .26208 L .76775 .25977 L closepath p F P
0 g
s
.445 .493 .815 r
.76666 .26208 m .76775 .25977 L .7661 .25597 L p F P
0 g
s
.42 .468 .805 r
.77231 .27006 m .77201 .26995 L .76905 .26287 L p F P
0 g
s
.396 .359 .7 r
.60176 .30271 m .60091 .29955 L .60315 .30107 L closepath p F P
0 g
s
.581 .886 .599 r
.76891 .4259 m .77312 .42149 L .77492 .42011 L closepath p F P
0 g
s
.309 .299 .685 r
.79752 .3358 m .80087 .33045 L .79691 .32626 L p F P
0 g
s
.288 .27 .664 r
.80087 .33045 m .79752 .3358 L .8009 .34019 L p F P
0 g
s
.613 .685 .894 r
.70448 .44055 m .6951 .44241 L .70172 .43644 L closepath p F P
0 g
s
.614 .665 .875 r
.7016 .43626 m .70172 .43644 L .6951 .44241 L p F P
0 g
s
.614 .665 .875 r
.68953 .43825 m .7016 .43626 L p .6951 .44241 L F P
0 g
s
0 0 .308 r
.60002 .20886 m .59866 .2127 L .5988 .21785 L p F P
0 g
s
0 0 .11 r
.59866 .2127 m .60002 .20886 L .60042 .20438 L p F P
0 g
s
.806 .768 .818 r
.12974 .42606 m .12988 .42593 L .12831 .42469 L closepath p F P
0 g
s
.81 .768 .814 r
.13481 .41448 m .13898 .41768 L .12988 .42593 L p F P
0 g
s
.81 .768 .814 r
.12602 .42249 m .13481 .41448 L p .12988 .42593 L F P
0 g
s
.81 .768 .814 r
.12988 .42593 m .12831 .42469 L .12602 .42249 L p F P
0 g
s
.209 .143 .558 r
.79978 .35892 m .79877 .36031 L .80039 .36528 L p F P
0 g
s
.402 .441 .787 r
.77965 .27306 m .77719 .27828 L .7841 .28144 L p F P
0 g
s
.411 .452 .792 r
.77231 .27006 m .77965 .27306 L .77719 .27828 L p F P
0 g
s
.778 .996 .862 r
.76891 .4259 m .77312 .42149 L p .76137 .43056 L F P
0 g
s
.413 .459 .798 r
.77459 .26487 m .77231 .27006 L .77965 .27306 L p F P
0 g
s
.42 .468 .805 r
.76905 .26287 m .77459 .26487 L .77231 .27006 L p F P
0 g
s
.801 .765 .82 r
.13767 .41192 m .13481 .41448 L .13898 .41768 L p F P
0 g
s
.801 .765 .82 r
.13898 .41768 m .14136 .41556 L .13767 .41192 L p F P
0 g
s
0 0 .142 r
.60147 .20188 m .60042 .20438 L .60002 .20886 L p F P
0 g
s
.596 .69 .908 r
.6631 .1749 m .65182 .17694 L .64889 .17275 L p F P
0 g
s
.556 .643 .891 r
.68175 .18287 m .6826 .18427 L .68147 .18796 L p F P
0 g
s
.554 .632 .883 r
.68467 .18774 m .68147 .18796 L .6826 .18427 L closepath p F P
0 g
s
.401 .366 .705 r
.60315 .30107 m .60176 .30271 L .60383 .31026 L p F P
0 g
s
.416 .375 .706 r
.60333 .31082 m .60383 .31026 L .60176 .30271 L p F P
0 g
s
.681 .875 .971 r
.74005 .44143 m .73691 .44286 L .73418 .44046 L p F P
0 g
s
.662 .829 .964 r
.72217 .44463 m .73418 .44046 L .73691 .44286 L p F P
0 g
s
.564 .572 .819 r
.65355 .41752 m .6536 .41747 L p .66581 .42347 L F P
0 g
s
.555 .566 .82 r
.65355 .41752 m .65353 .41747 L .6536 .41747 L closepath p F P
0 g
s
.634 .755 .935 r
.70734 .44454 m .71938 .44137 L .72217 .44463 L p F P
0 g
s
.622 .729 .923 r
.71938 .44137 m .70734 .44454 L .70448 .44055 L p F P
0 g
s
.557 .558 .81 r
.6536 .41747 m .65353 .41747 L .65049 .41073 L p F P
0 g
s
.546 .552 .812 r
.6536 .41747 m .66559 .41724 L .66257 .4109 L p F P
0 g
s
.546 .552 .812 r
.66257 .4109 m .66129 .41089 L .6536 .41747 L p F P
0 g
s
.557 .558 .81 r
.65049 .41073 m .66129 .41089 L .6536 .41747 L p F P
0 g
s
.564 .572 .819 r
.6536 .41747 m .66559 .41724 L p .66581 .42347 L F P
0 g
s
.421 .383 .711 r
.60411 .31126 m .60333 .31082 L .60383 .31026 L closepath p F P
0 g
s
.872 .941 .573 r
.60765 .18611 m .60851 .18585 L p .60363 .19597 L F P
0 g
s
.872 .941 .573 r
.60363 .19597 m .60515 .19074 L .60765 .18611 L p F P
0 g
s
.24 .215 .629 r
.59842 .25033 m .59666 .25335 L .59948 .25767 L p F P
0 g
s
.219 .19 .611 r
.59666 .25335 m .59842 .25033 L .59716 .24377 L p F P
0 g
s
.48 .448 .745 r
.61677 .35249 m .61431 .35178 L .61601 .35018 L closepath p F P
0 g
s
.479 .446 .743 r
.61363 .34286 m .61266 .34253 L p .61431 .35178 L F P
0 g
s
.479 .446 .743 r
.61431 .35178 m .61601 .35018 L .61363 .34286 L p F P
0 g
s
.48 .548 .848 r
.72985 .22049 m .73894 .22172 L p .7393 .22722 L F P
0 g
s
.48 .553 .853 r
.72985 .22049 m .73894 .22172 L .73603 .21595 L p F P
0 g
s
.48 .553 .853 r
.73603 .21595 m .73153 .21536 L .72985 .22049 L p F P
0 g
s
.487 .561 .857 r
.72365 .21448 m .73153 .21536 L .72985 .22049 L p F P
0 g
s
.862 .761 .751 r
.17488 .35992 m .171 .35655 L .17581 .34974 L p F P
0 g
s
.863 .762 .749 r
.171 .35655 m .17488 .35992 L .17014 .36671 L p F P
0 g
s
0 0 .212 r
.79406 .39026 m .79202 .39273 L .79 .39885 L p F P
0 g
s
.512 .487 .766 r
.63359 .38042 m .62615 .37926 L .62498 .37606 L p F P
0 g
s
.512 .487 .766 r
.62498 .37606 m .62948 .37194 L p .63359 .38042 L F P
0 g
s
.499 .478 .765 r
.62498 .37606 m .62303 .37067 L .62948 .37194 L closepath p F P
0 g
s
.33 .308 .682 r
.60277 .27171 m .59875 .27758 L .60292 .2815 L p F P
0 g
s
.308 .277 .66 r
.59875 .27758 m .60277 .27171 L .59916 .26762 L p F P
0 g
s
.649 .794 .952 r
.73418 .44046 m .72217 .44463 L .71938 .44137 L p F P
0 g
s
.096 0 .431 r
.80126 .3705 m .79714 .37599 L .79718 .38146 L p F P
0 g
s
.165 .079 .505 r
.80126 .37046 m .80039 .36528 L p .79714 .37599 L F P
0 g
s
.165 .079 .505 r
.79714 .37599 m .80126 .3705 L .80126 .37046 L p F P
0 g
s
0 0 .448 r
.59712 .22828 m .59963 .22278 L .5988 .21785 L p F P
0 g
s
.034 .02 .508 r
.59963 .22278 m .59712 .22828 L .5986 .233 L p F P
0 g
s
.849 .761 .766 r
.16305 .38415 m .16132 .38637 L .15765 .38265 L p F P
0 g
s
.849 .761 .766 r
.15765 .38265 m .15906 .38085 L .16305 .38415 L p F P
0 g
s
.849 .761 .766 r
.16305 .38415 m .15906 .38085 L .16457 .37379 L p F P
0 g
s
.424 .385 .711 r
.60383 .31026 m .60862 .30462 L p .60939 .31419 L F P
0 g
s
.424 .385 .711 r
.60939 .31419 m .60411 .31126 L .60383 .31026 L p F P
0 g
s
.401 .366 .705 r
.60383 .31026 m .60862 .30462 L .60315 .30107 L p F P
0 g
s
.877 .763 .733 r
.18027 .34305 m .17821 .34634 L .17455 .34278 L p F P
0 g
s
.877 .763 .733 r
.17455 .34278 m .17654 .3396 L .18027 .34305 L p F P
0 g
s
.878 .763 .732 r
.18027 .34305 m .17654 .3396 L .18062 .33304 L p F P
0 g
s
.419 .386 .715 r
.60604 .31798 m .60411 .31126 L .60939 .31419 L closepath p F P
0 g
s
.761 .768 .859 r
.10316 .43928 m .11435 .43174 L .1158 .43282 L p F P
0 g
s
.763 .771 .86 r
.11435 .43174 m .10316 .43928 L .09938 .43588 L p F P
0 g
s
.486 .562 .858 r
.73153 .21536 m .72365 .21448 L .72104 .20944 L p F P
0 g
s
.681 .875 .971 r
.74629 .43559 m .74005 .44143 L p .73418 .44046 L F P
0 g
s
.708 .895 .964 r
.74005 .44143 m .74629 .43559 L .74885 .43725 L closepath p F P
0 g
s
.502 .474 .759 r
.62948 .37194 m .62303 .37067 L .62183 .36724 L p F P
0 g
s
.188 .151 .581 r
.59716 .24377 m .59684 .24185 L .59748 .24324 L closepath p F P
0 g
s
.461 .53 .842 r
.74783 .23426 m .74477 .23367 L .74185 .22763 L p F P
0 g
s
.833 .763 .786 r
.1568 .39146 m .16132 .38637 L .15765 .38265 L p F P
0 g
s
.307 .299 .687 r
.80017 .32091 m .79691 .32626 L .80087 .33045 L p F P
0 g
s
.331 .33 .707 r
.79691 .32626 m .80017 .32091 L .79563 .3169 L p F P
0 g
s
.782 .767 .839 r
.12831 .42469 m .12602 .42249 L .12572 .42273 L closepath p F P
0 g
s
.502 .474 .759 r
.62183 .36724 m .62607 .36324 L p .62948 .37194 L F P
0 g
s
.489 .465 .758 r
.62183 .36724 m .61991 .36175 L .62607 .36324 L closepath p F P
0 g
s
.439 .401 .719 r
.60604 .31798 m .60939 .31419 L p .61028 .32371 L F P
0 g
s
.439 .401 .719 r
.61028 .32371 m .60729 .32227 L .60604 .31798 L p F P
0 g
s
.759 .768 .861 r
.1158 .43282 m .11452 .43162 L .11435 .43174 L closepath p F P
0 g
s
.416 .467 .805 r
.77459 .26487 m .76905 .26287 L .76775 .25977 L p F P
0 g
s
.468 .434 .738 r
.61363 .34286 m .61266 .34253 L .61332 .34189 L closepath p F P
0 g
s
.466 .431 .735 r
.61266 .34253 m .61332 .34189 L .61077 .33377 L p F P
0 g
s
.508 .588 .87 r
.7093 .20302 m .71784 .20349 L .71493 .19812 L p F P
0 g
s
.508 .588 .87 r
.71493 .19812 m .7107 .19792 L .7093 .20302 L p F P
0 g
s
.511 .594 .873 r
.70266 .19765 m .7107 .19792 L .7093 .20302 L p F P
0 g
s
.609 .747 .943 r
.05869 .44265 m .0695 .44001 L .07333 .44332 L p F P
0 g
s
.173 .118 .549 r
.80243 .35492 m .79978 .35892 L .80067 .3649 L p F P
0 g
s
.209 .143 .558 r
.80039 .36528 m .80067 .3649 L .79978 .35892 L p F P
0 g
s
.219 .176 .594 r
.79978 .35892 m .80243 .35492 L .80025 .35013 L p F P
0 g
s
.435 .402 .724 r
.60835 .32581 m .60729 .32227 L .61028 .32371 L closepath p F P
0 g
s
.534 .618 .882 r
.68467 .18774 m .69684 .1874 L p .69738 .19249 L F P
0 g
s
.531 .62 .886 r
.69393 .18244 m .69684 .1874 L .68467 .18774 L p F P
0 g
s
.531 .62 .886 r
.68286 .18282 m .69393 .18244 L p .68467 .18774 L F P
0 g
s
.531 .62 .886 r
.68467 .18774 m .6826 .18427 L .68286 .18282 L p F P
0 g
s
.491 .461 .752 r
.62607 .36324 m .61991 .36175 L .61884 .35862 L p F P
0 g
s
.576 .599 .839 r
.68216 .42824 m .67158 .42916 L .66859 .42334 L p F P
0 g
s
.221 .191 .611 r
.59748 .24324 m .59716 .24377 L .59842 .25033 L p F P
0 g
s
.59 .658 .885 r
.7016 .43626 m .68953 .43825 L .6866 .43331 L p F P
0 g
s
.453 .416 .727 r
.60835 .32581 m .61028 .32371 L p .61134 .33317 L F P
0 g
s
.453 .416 .727 r
.61134 .33317 m .61047 .33281 L .60835 .32581 L p F P
0 g
s
.865 .767 .753 r
.17581 .34974 m .17821 .34634 L .17455 .34278 L p F P
0 g
s
.837 .765 .783 r
.15276 .38818 m .1568 .39146 L .15038 .39883 L p F P
0 g
s
.833 .763 .786 r
.15765 .38265 m .15276 .38818 L .1568 .39146 L p F P
0 g
s
.491 .461 .752 r
.61884 .35862 m .62323 .35435 L p .62607 .36324 L F P
0 g
s
.477 .451 .75 r
.61884 .35862 m .61677 .35249 L .62323 .35435 L closepath p F P
0 g
s
.473 .538 .843 r
.74185 .22763 m .7393 .22722 L .74033 .2245 L closepath p F P
0 g
s
.48 .548 .848 r
.73894 .22172 m .74033 .2245 L .7393 .22722 L p F P
0 g
s
.387 .365 .713 r
.60791 .29502 m .60315 .30107 L .60862 .30462 L p F P
0 g
s
.401 .359 .696 r
.60304 .29129 m .60791 .29502 L .60315 .30107 L p F P
0 g
s
.862 .762 .75 r
.17014 .36671 m .16968 .36736 L .16602 .36369 L p F P
0 g
s
.862 .762 .75 r
.16602 .36369 m .16627 .36334 L .17014 .36671 L p F P
0 g
s
.863 .762 .749 r
.17014 .36671 m .16627 .36334 L .171 .35655 L p F P
0 g
s
.547 .546 .805 r
.66129 .41089 m .65049 .41073 L .6488 .40686 L p F P
0 g
s
.48 .448 .745 r
.62323 .35435 m .61677 .35249 L .61601 .35018 L p F P
0 g
s
.449 .418 .732 r
.61077 .33377 m .61047 .33281 L .61134 .33317 L closepath p F P
0 g
s
.565 .646 .889 r
.66675 .17934 m .67884 .17813 L .68175 .18287 L p F P
0 g
s
.568 .651 .892 r
.67884 .17813 m .66675 .17934 L .66382 .17477 L p F P
0 g
s
.452 .422 .735 r
.61134 .33317 m .61077 .33377 L .61332 .34189 L p F P
0 g
s
.48 .448 .745 r
.61601 .35018 m .62084 .34532 L p .62323 .35435 L F P
0 g
s
.465 .438 .743 r
.61601 .35018 m .61363 .34286 L .62084 .34532 L closepath p F P
0 g
s
.848 .765 .77 r
.16457 .37379 m .16968 .36736 L .16602 .36369 L p F P
0 g
s
.734 .773 .884 r
.09278 .43952 m .08817 .4421 L .08436 .43876 L p F P
0 g
s
.685 .765 .912 r
.07333 .44332 m .08436 .43876 L .08817 .4421 L p F P
0 g
s
.221 .179 .596 r
.80373 .34477 m .80025 .35013 L .80243 .35492 L p F P
0 g
s
.255 .225 .631 r
.80025 .35013 m .80373 .34477 L .8009 .34019 L p F P
0 g
s
.468 .435 .738 r
.61332 .34189 m .61881 .33616 L p .62084 .34532 L F P
0 g
s
.468 .435 .738 r
.62084 .34532 m .61363 .34286 L .61332 .34189 L p F P
0 g
s
.452 .422 .735 r
.61332 .34189 m .61881 .33616 L .61134 .33317 L p F P
0 g
s
0 0 0 r
.78409 .40936 m .78674 .40535 L .78494 .40754 L closepath p F P
0 g
s
0 0 .013 r
.78494 .40754 m .78674 .40535 L .79 .39885 L p F P
0 g
s
.416 .467 .805 r
.76775 .25977 m .76895 .25687 L p .77459 .26487 L F P
0 g
s
.427 .483 .815 r
.76775 .25977 m .7661 .25597 L .76895 .25687 L closepath p F P
0 g
s
.513 .597 .875 r
.7107 .19792 m .70266 .19765 L .69975 .19247 L p F P
0 g
s
.885 .99 .748 r
.60765 .18611 m .60909 .18423 L .60851 .18585 L closepath p F P
0 g
s
.804 .978 .899 r
.61784 .17609 m .60909 .18423 L .60851 .18585 L p F P
0 g
s
.221 .191 .611 r
.59842 .25033 m .60001 .24764 L .59748 .24324 L p F P
0 g
s
.168 .153 .596 r
.60053 .23759 m .59748 .24324 L .60001 .24764 L p F P
0 g
s
.194 .154 .581 r
.5986 .233 m .60053 .23759 L .59748 .24324 L p F P
0 g
s
.685 .766 .913 r
.08436 .43876 m .07333 .44332 L .0695 .44001 L p F P
0 g
s
.327 .329 .709 r
.79795 .31296 m .79563 .3169 L .80017 .32091 L p F P
0 g
s
.35 .358 .728 r
.79712 .31035 m .79371 .30774 L p .79563 .3169 L F P
0 g
s
.35 .358 .728 r
.79563 .3169 m .79795 .31296 L .79712 .31035 L p F P
0 g
s
.865 .767 .752 r
.17206 .3463 m .17581 .34974 L .171 .35655 L p F P
0 g
s
.865 .767 .753 r
.17455 .34278 m .17206 .3463 L .17581 .34974 L p F P
0 g
s
.297 .275 .665 r
.60142 .26404 m .59916 .26762 L .60277 .27171 L p F P
0 g
s
.284 .259 .654 r
.60018 .2586 m .59948 .25767 L p .59916 .26762 L F P
0 g
s
.284 .259 .654 r
.59916 .26762 m .60142 .26404 L .60018 .2586 L p F P
0 g
s
0 0 .142 r
.60002 .20886 m .60066 .20734 L .60147 .20188 L p F P
0 g
s
0 0 .026 r
.60326 .19657 m .60254 .202 L p .60362 .19557 L F P
0 g
s
0 0 0 r
.60326 .19657 m .60515 .19074 L p .6029 .19756 L F P
0 g
s
.762 .762 .252 r
.60577 .18738 m .60515 .19074 L .60326 .19657 L p F P
0 g
s
.762 .762 .252 r
.60486 .18941 m .60577 .18738 L p .60326 .19657 L F P
0 g
s
0 0 .026 r
.6043 .19148 m .60326 .19657 L p .60362 .19557 L F P
0 g
s
0 0 0 r
.60147 .20188 m .60326 .19657 L p .6029 .19756 L F P
0 g
s
.763 .771 .86 r
.09938 .43588 m .11024 .42852 L .11435 .43174 L p F P
0 g
s
.759 .771 .863 r
.11076 .42817 m .11024 .42852 L .11435 .43174 L p F P
0 g
s
.759 .771 .863 r
.11435 .43174 m .11452 .43162 L .11076 .42817 L p F P
0 g
s
.787 .77 .838 r
.12572 .42273 m .11452 .43162 L .11076 .42817 L p F P
0 g
s
.444 .424 .742 r
.61707 .3269 m .61134 .33317 L .61881 .33616 L p F P
0 g
s
.453 .416 .727 r
.61028 .32371 m .61707 .3269 L .61134 .33317 L p F P
0 g
s
0 0 0 r
.79356 .39453 m .79 .39885 L .78674 .40535 L p F P
0 g
s
0 0 .212 r
.79 .39885 m .79356 .39453 L .79406 .39026 L p F P
0 g
s
.563 .583 .831 r
.66859 .42334 m .66581 .42347 L .66782 .42177 L closepath p F P
0 g
s
.564 .572 .819 r
.66559 .41724 m .66782 .42177 L .66581 .42347 L p F P
0 g
s
.837 .765 .783 r
.15038 .39883 m .14943 .39992 L .14574 .39628 L p F P
0 g
s
.837 .765 .783 r
.14574 .39628 m .14638 .39554 L .15038 .39883 L p F P
0 g
s
.837 .765 .783 r
.15038 .39883 m .14638 .39554 L .15276 .38818 L p F P
0 g
s
.649 .72 .9 r
.63404 .17238 m .64596 .16865 L .64889 .17275 L p F P
0 g
s
.664 .732 .9 r
.64596 .16865 m .63404 .17238 L .63111 .16885 L p F P
0 g
s
.726 .78 .895 r
.6193 .17501 m .63111 .16885 L .63404 .17238 L p F P
0 g
s
.819 .766 .803 r
.14285 .40657 m .14943 .39992 L .14574 .39628 L p F P
0 g
s
.547 .546 .805 r
.6488 .40686 m .65211 .40395 L p .66129 .41089 L F P
0 g
s
.537 .539 .805 r
.6488 .40686 m .64744 .40375 L .65211 .40395 L closepath p F P
0 g
s
0 0 .425 r
.60017 .21404 m .5988 .21785 L .59963 .22278 L p F P
0 g
s
0 0 .308 r
.5988 .21785 m .60017 .21404 L .60002 .20886 L p F P
0 g
s
.687 .968 .93 r
.74885 .43725 m .76075 .43044 L .76137 .43056 L p F P
0 g
s
.751 .904 .945 r
.74629 .43559 m .74885 .43725 L .76075 .43044 L p F P
0 g
s
.452 .52 .837 r
.74783 .23426 m .75729 .23631 L .75437 .23015 L p F P
0 g
s
.452 .52 .837 r
.75437 .23015 m .74962 .22912 L .74783 .23426 L p F P
0 g
s
.461 .53 .842 r
.74185 .22763 m .74962 .22912 L .74783 .23426 L p F P
0 g
s
.454 .516 .833 r
.74783 .23426 m .75729 .23631 L p .75555 .24157 L F P
0 g
s
0 0 .191 r
.79634 .38722 m .79406 .39026 L .79356 .39453 L p F P
0 g
s
.004 0 .33 r
.79406 .39026 m .79634 .38722 L .79718 .38146 L p F P
0 g
s
.734 .773 .884 r
.08436 .43876 m .08883 .43625 L .09278 .43952 L p F P
0 g
s
.731 .772 .886 r
.09559 .43251 m .08883 .43625 L .09278 .43952 L p F P
0 g
s
.731 .772 .886 r
.09278 .43952 m .09938 .43588 L .09559 .43251 L p F P
0 g
s
.852 .766 .767 r
.16067 .37043 m .16457 .37379 L .15906 .38085 L p F P
0 g
s
.848 .765 .77 r
.16602 .36369 m .16067 .37043 L .16457 .37379 L p F P
0 g
s
.426 .483 .815 r
.76895 .25687 m .7661 .25597 L .76315 .24921 L p F P
0 g
s
.823 .767 .8 r
.14285 .40657 m .13767 .41192 L .13395 .40835 L p F P
0 g
s
.823 .767 .8 r
.13395 .40835 m .13883 .40329 L .14285 .40657 L p F P
0 g
s
.819 .766 .803 r
.14574 .39628 m .13883 .40329 L .14285 .40657 L p F P
0 g
s
.486 .562 .858 r
.72104 .20944 m .72118 .20892 L p .73153 .21536 L F P
0 g
s
.494 .573 .864 r
.72104 .20944 m .72074 .20889 L .72118 .20892 L closepath p F P
0 g
s
.239 .215 .629 r
.60001 .24764 m .59842 .25033 L .59983 .25707 L p F P
0 g
s
.24 .215 .629 r
.59948 .25767 m .59983 .25707 L .59842 .25033 L p F P
0 g
s
.46 .531 .843 r
.74962 .22912 m .74185 .22763 L .74033 .2245 L p F P
0 g
s
.155 .072 .503 r
.80126 .37046 m .80039 .36528 L .80067 .3649 L closepath p F P
0 g
s
.342 .354 .728 r
.79712 .31035 m .79371 .30774 L .79536 .3048 L closepath p F P
0 g
s
.364 .381 .745 r
.79398 .30067 m .79114 .29878 L p .79371 .30774 L F P
0 g
s
.364 .381 .745 r
.79371 .30774 m .79536 .3048 L .79398 .30067 L p F P
0 g
s
.492 .575 .867 r
.72118 .20892 m .72074 .20889 L .71784 .20349 L p F P
0 g
s
.787 .77 .838 r
.11076 .42817 m .12163 .4195 L .12572 .42273 L p F P
0 g
s
.783 .77 .841 r
.12229 .41898 m .12163 .4195 L .12572 .42273 L p F P
0 g
s
.783 .77 .841 r
.12572 .42273 m .12602 .42249 L .12229 .41898 L p F P
0 g
s
.596 .69 .908 r
.64889 .17275 m .66089 .17035 L p .6631 .1749 L F P
0 g
s
.613 .691 .899 r
.66089 .17035 m .64889 .17275 L .64596 .16865 L p F P
0 g
s
.622 .729 .923 r
.70448 .44055 m .71655 .43776 L .71938 .44137 L p F P
0 g
s
.614 .685 .893 r
.7137 .43384 m .71655 .43776 L .70448 .44055 L p F P
0 g
s
.614 .685 .893 r
.70203 .43617 m .7137 .43384 L p .70448 .44055 L F P
0 g
s
.614 .685 .893 r
.70448 .44055 m .70172 .43644 L .70203 .43617 L p F P
0 g
s
.365 .343 .702 r
.60694 .28587 m .60304 .29129 L .60791 .29502 L p F P
0 g
s
.356 .332 .694 r
.60667 .28487 m .60292 .2815 L p .60304 .29129 L F P
0 g
s
.356 .332 .694 r
.60304 .29129 m .60694 .28587 L .60667 .28487 L p F P
0 g
s
.807 .769 .818 r
.13481 .41448 m .12602 .42249 L .12229 .41898 L p F P
0 g
s
.807 .769 .818 r
.12229 .41898 m .13075 .41122 L .13481 .41448 L p F P
0 g
s
.803 .769 .821 r
.13395 .40835 m .13075 .41122 L .13481 .41448 L p F P
0 g
s
.803 .769 .821 r
.13481 .41448 m .13767 .41192 L .13395 .40835 L p F P
0 g
s
.538 .534 .798 r
.65211 .40395 m .64744 .40375 L .64444 .39665 L p F P
0 g
s
.096 0 .431 r
.80127 .37055 m .80126 .3705 L p .79718 .38146 L F P
0 g
s
.096 0 .431 r
.79718 .38146 m .80131 .37598 L .80127 .37055 L p F P
0 g
s
0 0 .325 r
.80131 .37598 m .79718 .38146 L .79634 .38722 L p F P
0 g
s
.881 .965 .845 r
.61802 .17395 m .61784 .17609 L .60909 .18423 L p F P
0 g
s
.802 .865 .895 r
.61784 .17609 m .61802 .17395 L .6193 .17501 L closepath p F P
0 g
s
.486 .562 .858 r
.72118 .20892 m .73312 .2102 L p .73153 .21536 L F P
0 g
s
.486 .568 .864 r
.72118 .20892 m .73312 .2102 L .73021 .20468 L p F P
0 g
s
.486 .568 .864 r
.73021 .20468 m .72247 .20388 L .72118 .20892 L p F P
0 g
s
.492 .575 .867 r
.71784 .20349 m .72247 .20388 L .72118 .20892 L p F P
0 g
s
.53 .609 .876 r
.69975 .19247 m .69738 .19249 L .69819 .18971 L closepath p F P
0 g
s
.534 .618 .882 r
.69684 .1874 m .69819 .18971 L .69738 .19249 L p F P
0 g
s
.541 .63 .889 r
.6826 .18427 m .68175 .18287 L .68286 .18282 L closepath p F P
0 g
s
.801 .968 .659 r
.60909 .18423 m .61055 .17899 L p .60577 .18738 L F P
0 g
s
.801 .968 .659 r
.60577 .18738 m .60765 .18611 L .60909 .18423 L p F P
0 g
s
.881 .965 .845 r
.61638 .17281 m .61802 .17395 L p .60909 .18423 L F P
0 g
s
.881 .965 .845 r
.60909 .18423 m .61055 .17899 L .61638 .17281 L p F P
0 g
s
0 0 .334 r
.60066 .20734 m .60002 .20886 L .60017 .21404 L p F P
0 g
s
.126 .052 .494 r
.80067 .3649 m .80397 .35993 L p .80127 .3705 L F P
0 g
s
.126 .052 .494 r
.80127 .3705 m .80126 .37046 L .80067 .3649 L p F P
0 g
s
.173 .118 .549 r
.80067 .3649 m .80397 .35993 L .80243 .35492 L p F P
0 g
s
.733 .855 .938 r
.61802 .17395 m .6193 .17501 L .63111 .16885 L p F P
0 g
s
.253 .224 .632 r
.80403 .33527 m .8009 .34019 L .80373 .34477 L p F P
0 g
s
.288 .27 .664 r
.80375 .33412 m .80087 .33045 L p .8009 .34019 L F P
0 g
s
.288 .27 .664 r
.8009 .34019 m .80403 .33527 L .80375 .33412 L p F P
0 g
s
.778 .996 .862 r
.77254 .42171 m .76264 .42916 L .76137 .43056 L p F P
0 g
s
.778 .996 .862 r
.77312 .42149 m .77254 .42171 L p .76137 .43056 L F P
0 g
s
.745 .98 .915 r
.76075 .43044 m .76264 .42916 L .76137 .43056 L closepath p F P
0 g
s
.451 .509 .827 r
.76022 .24274 m .75555 .24157 L p .76268 .24908 L F P
0 g
s
.445 .506 .827 r
.76022 .24274 m .75555 .24157 L .75747 .23669 L closepath p F P
0 g
s
.454 .516 .833 r
.75729 .23631 m .75747 .23669 L .75555 .24157 L p F P
0 g
s
.429 .408 .734 r
.61553 .31757 m .61028 .32371 L .61707 .3269 L p F P
0 g
s
.439 .401 .719 r
.60939 .31419 m .61553 .31757 L .61028 .32371 L p F P
0 g
s
.865 .767 .752 r
.171 .35655 m .16725 .35312 L .17206 .3463 L p F P
0 g
s
.867 .767 .75 r
.16725 .35312 m .171 .35655 L .16627 .36334 L p F P
0 g
s
.576 .599 .839 r
.66859 .42334 m .68069 .42261 L p .68216 .42824 L F P
0 g
s
.558 .58 .832 r
.67771 .41688 m .68069 .42261 L .66859 .42334 L p F P
0 g
s
.558 .58 .832 r
.67317 .41701 m .67771 .41688 L p .66859 .42334 L F P
0 g
s
.558 .58 .832 r
.66859 .42334 m .66782 .42177 L .67317 .41701 L p F P
0 g
s
.924 .957 .632 r
.60515 .19074 m .60577 .18738 L .60765 .18611 L closepath p F P
0 g
s
.356 .377 .744 r
.79398 .30067 m .79114 .29878 L .79249 .29626 L closepath p F P
0 g
s
.377 .402 .76 r
.79089 .29173 m .78793 .29001 L p .79114 .29878 L F P
0 g
s
.377 .402 .76 r
.79114 .29878 m .79249 .29626 L .79089 .29173 L p F P
0 g
s
.261 .241 .647 r
.60018 .2586 m .59948 .25767 L .59983 .25707 L closepath p F P
0 g
s
.077 .079 .557 r
.60098 .22755 m .5986 .233 L .60053 .23759 L p F P
0 g
s
.034 .02 .508 r
.5986 .233 m .60098 .22755 L .59963 .22278 L p F P
0 g
s
.852 .766 .767 r
.15906 .38085 m .15765 .38265 L .15396 .37905 L p F P
0 g
s
.852 .766 .767 r
.15396 .37905 m .15517 .3775 L .15906 .38085 L p F P
0 g
s
.852 .766 .767 r
.15906 .38085 m .15517 .3775 L .16067 .37043 L p F P
0 g
s
.681 .875 .971 r
.73418 .44046 m .74619 .43552 L .74629 .43559 L p F P
0 g
s
.668 .841 .966 r
.74619 .43552 m .73418 .44046 L .73143 .43765 L p F P
0 g
s
.649 .794 .952 r
.71938 .44137 m .73143 .43765 L .73418 .44046 L p F P
0 g
s
.636 .764 .94 r
.73143 .43765 m .71938 .44137 L .71655 .43776 L p F P
0 g
s
.59 .658 .885 r
.6866 .43331 m .6987 .43164 L .7016 .43626 L p F P
0 g
s
.58 .641 .876 r
.6987 .43164 m .6866 .43331 L .68365 .42811 L p F P
0 g
s
0 0 0 r
.78674 .40535 m .79125 .3998 L p .78336 .41052 L F P
0 g
s
0 0 0 r
.78336 .41052 m .78409 .40936 L .78674 .40535 L p F P
0 g
s
0 0 0 r
.79313 .3963 m .79356 .39453 L p .78674 .40535 L F P
0 g
s
0 0 0 r
.78674 .40535 m .79125 .3998 L .79313 .3963 L p F P
0 g
s
.557 .578 .831 r
.66782 .42177 m .66559 .41724 L .67317 .41701 L closepath p F P
0 g
s
.764 .774 .861 r
.11024 .42852 m .09938 .43588 L .09559 .43251 L p F P
0 g
s
.468 .543 .85 r
.74033 .2245 m .73894 .22172 L .74108 .22207 L closepath p F P
0 g
s
.46 .531 .843 r
.74033 .2245 m .74108 .22207 L p .74962 .22912 L F P
0 g
s
.54 .634 .893 r
.68286 .18282 m .68175 .18287 L .67884 .17813 L p F P
0 g
s
.436 .491 .818 r
.76315 .24921 m .76268 .24908 L .76288 .2486 L closepath p F P
0 g
s
.451 .509 .827 r
.76268 .24908 m .76288 .2486 L .76022 .24274 L p F P
0 g
s
.836 .768 .787 r
.15276 .38818 m .15765 .38265 L .15396 .37905 L p F P
0 g
s
.512 .487 .766 r
.63511 .37304 m .6368 .37744 L .63359 .38042 L p F P
0 g
s
.512 .487 .766 r
.62948 .37194 m .63511 .37304 L p .63359 .38042 L F P
0 g
s
.521 .499 .772 r
.63359 .38042 m .63821 .38114 L p .63855 .38864 L F P
0 g
s
.508 .496 .778 r
.63821 .38114 m .63359 .38042 L .6368 .37744 L closepath p F P
0 g
s
.518 .508 .785 r
.6413 .38896 m .63855 .38864 L .64049 .3869 L closepath p F P
0 g
s
.521 .499 .772 r
.63821 .38114 m .64049 .3869 L .63855 .38864 L p F P
0 g
s
.37 .398 .76 r
.79089 .29173 m .78793 .29001 L .78932 .28732 L closepath p F P
0 g
s
.39 .422 .774 r
.78783 .28335 m .7841 .28144 L p .78793 .29001 L F P
0 g
s
.39 .422 .774 r
.78793 .29001 m .78932 .28732 L .78783 .28335 L p F P
0 g
s
.7 .971 .751 r
.77254 .42171 m .77428 .42015 L .77312 .42149 L closepath p F P
0 g
s
.685 .927 .615 r
.78172 .41238 m .77428 .42015 L .77312 .42149 L p F P
0 g
s
.595 .675 .896 r
.66382 .17477 m .6631 .1749 L .66336 .17406 L closepath p F P
0 g
s
.596 .69 .908 r
.66089 .17035 m .66336 .17406 L .6631 .1749 L p F P
0 g
s
.286 .259 .652 r
.59983 .25707 m .60284 .25196 L p .60279 .26184 L F P
0 g
s
.286 .259 .652 r
.60279 .26184 m .60018 .2586 L .59983 .25707 L p F P
0 g
s
.239 .215 .629 r
.59983 .25707 m .60284 .25196 L .60001 .24764 L p F P
0 g
s
.513 .597 .875 r
.69975 .19247 m .71202 .19279 L p .7107 .19792 L F P
0 g
s
.508 .597 .878 r
.70911 .18765 m .71202 .19279 L .69975 .19247 L p F P
0 g
s
.508 .597 .878 r
.69861 .18741 m .70911 .18765 L p .69975 .19247 L F P
0 g
s
.508 .597 .878 r
.69975 .19247 m .69819 .18971 L .69861 .18741 L p F P
0 g
s
.426 .483 .815 r
.76315 .24921 m .77099 .25172 L .76895 .25687 L p F P
0 g
s
.422 .483 .817 r
.77099 .25172 m .76315 .24921 L .76288 .2486 L p F P
0 g
s
.538 .534 .798 r
.64444 .39665 m .64458 .39652 L p .65211 .40395 L F P
0 g
s
.528 .527 .798 r
.64444 .39665 m .64438 .39651 L .64458 .39652 L closepath p F P
0 g
s
.53 .521 .79 r
.64458 .39652 m .64438 .39651 L .6413 .38896 L p F P
0 g
s
.416 .467 .805 r
.76895 .25687 m .77683 .25968 L .77459 .26487 L p F P
0 g
s
.42 .475 .811 r
.77099 .25172 m .76895 .25687 L .77683 .25968 L p F P
0 g
s
.497 .483 .772 r
.63511 .37304 m .62948 .37194 L .63333 .36824 L closepath p F P
0 g
s
.502 .474 .759 r
.632 .36465 m .63333 .36824 L .62948 .37194 L p F P
0 g
s
.502 .474 .759 r
.62607 .36324 m .632 .36465 L p .62948 .37194 L F P
0 g
s
.337 .317 .689 r
.60667 .28487 m .60292 .2815 L .60499 .27845 L closepath p F P
0 g
s
.33 .308 .682 r
.60344 .2724 m .60277 .27171 L p .60292 .2815 L F P
0 g
s
.33 .308 .682 r
.60292 .2815 m .60499 .27845 L .60344 .2724 L p F P
0 g
s
.433 .498 .826 r
.76288 .2486 m .76022 .24274 L .76456 .24395 L closepath p F P
0 g
s
.422 .483 .817 r
.76288 .2486 m .76456 .24395 L p .77099 .25172 L F P
0 g
s
.54 .631 .89 r
.68286 .18282 m .69393 .18244 L .69101 .17753 L p F P
0 g
s
.54 .631 .89 r
.69101 .17753 m .68362 .17786 L .68286 .18282 L p F P
0 g
s
.54 .634 .893 r
.67884 .17813 m .68362 .17786 L .68286 .18282 L p F P
0 g
s
.281 .257 .654 r
.60142 .26404 m .60018 .2586 L .60279 .26184 L closepath p F P
0 g
s
.518 .514 .791 r
.64458 .39652 m .65649 .39742 L .65343 .39031 L p F P
0 g
s
.518 .514 .791 r
.65343 .39031 m .6515 .3901 L .64458 .39652 L p F P
0 g
s
.53 .521 .79 r
.6413 .38896 m .6515 .3901 L .64458 .39652 L p F P
0 g
s
.538 .534 .798 r
.64458 .39652 m .65649 .39742 L p .65211 .40395 L F P
0 g
s
.566 .662 .901 r
.67299 .16881 m .67591 .17344 L .66382 .17477 L p F P
0 g
s
.566 .662 .901 r
.66365 .16998 m .67299 .16881 L p .66382 .17477 L F P
0 g
s
.566 .662 .901 r
.66382 .17477 m .66336 .17406 L .66365 .16998 L p F P
0 g
s
.568 .651 .892 r
.66382 .17477 m .67591 .17344 L .67884 .17813 L p F P
0 g
s
.383 .418 .774 r
.78783 .28335 m .7841 .28144 L .78581 .27793 L closepath p F P
0 g
s
.402 .441 .787 r
.78481 .27538 m .77965 .27306 L p .7841 .28144 L F P
0 g
s
.402 .441 .787 r
.7841 .28144 m .78581 .27793 L .78481 .27538 L p F P
0 g
s
.744 .96 .94 r
.76264 .42916 m .76075 .43044 L .75815 .42945 L p F P
0 g
s
.751 .904 .945 r
.76075 .43044 m .75815 .42945 L p .74629 .43559 L F P
0 g
s
0 0 .334 r
.60017 .21404 m .60082 .21249 L .60066 .20734 L p F P
0 g
s
0 0 .299 r
.60254 .202 m .60066 .20734 L .60082 .21249 L p F P
0 g
s
0 0 .11 r
.60066 .20734 m .60254 .202 L .60326 .19657 L p F P
0 g
s
.839 .769 .784 r
.14885 .38484 m .15276 .38818 L .14638 .39554 L p F P
0 g
s
.836 .768 .787 r
.15396 .37905 m .14885 .38484 L .15276 .38818 L p F P
0 g
s
.411 .39 .726 r
.61355 .30903 m .60939 .31419 L .61553 .31757 L p F P
0 g
s
.424 .385 .711 r
.61308 .30746 m .61355 .30903 L .60939 .31419 L p F P
0 g
s
.424 .385 .711 r
.60862 .30462 m .61308 .30746 L p .60939 .31419 L F P
0 g
s
.413 .459 .798 r
.78181 .26773 m .77459 .26487 L p .77965 .27306 L F P
0 g
s
.403 .453 .798 r
.77459 .26487 m .78181 .26773 L .77883 .26048 L p F P
0 g
s
.403 .453 .798 r
.77883 .26048 m .77683 .25968 L .77459 .26487 L p F P
0 g
s
.395 .437 .787 r
.78481 .27538 m .77965 .27306 L .78195 .26808 L closepath p F P
0 g
s
.413 .459 .798 r
.77965 .27306 m .78195 .26808 L .78181 .26773 L p F P
0 g
s
.744 .96 .94 r
.75815 .42945 m .76783 .42346 L .76264 .42916 L p F P
0 g
s
.714 .987 .848 r
.77005 .42194 m .76783 .42346 L .76264 .42916 L p F P
0 g
s
.714 .987 .848 r
.76264 .42916 m .77254 .42171 L .77005 .42194 L p F P
0 g
s
.866 .768 .752 r
.16627 .36334 m .16602 .36369 L .16234 .36017 L p F P
0 g
s
.866 .768 .752 r
.16234 .36017 m .16251 .35992 L .16627 .36334 L p F P
0 g
s
.867 .767 .75 r
.16627 .36334 m .16251 .35992 L .16725 .35312 L p F P
0 g
s
.48 .553 .853 r
.73603 .21595 m .73153 .21536 L .73316 .21028 L closepath p F P
0 g
s
.486 .562 .858 r
.73312 .2102 m .73316 .21028 L .73153 .21536 L p F P
0 g
s
.307 .299 .687 r
.80035 .3211 m .80017 .32091 L p .80087 .33045 L F P
0 g
s
.307 .299 .687 r
.80087 .33045 m .80227 .32817 L .80035 .3211 L p F P
0 g
s
.279 .264 .663 r
.80375 .33412 m .80087 .33045 L .80227 .32817 L closepath p F P
0 g
s
.852 .771 .772 r
.16067 .37043 m .16602 .36369 L .16234 .36017 L p F P
0 g
s
.486 .47 .765 r
.632 .36465 m .62607 .36324 L .63006 .35927 L closepath p F P
0 g
s
.491 .461 .752 r
.62888 .35597 m .63006 .35927 L .62607 .36324 L p F P
0 g
s
.491 .461 .752 r
.62323 .35435 m .62888 .35597 L p .62607 .36324 L F P
0 g
s
.575 .669 .903 r
.66336 .17406 m .66089 .17035 L .66365 .16998 L closepath p F P
0 g
s
.221 .179 .596 r
.80243 .35492 m .80596 .34956 L .80373 .34477 L p F P
0 g
s
.177 .122 .552 r
.80596 .34956 m .80243 .35492 L .80397 .35993 L p F P
0 g
s
.734 .774 .885 r
.08883 .43625 m .08436 .43876 L .08054 .43543 L p F P
0 g
s
.685 .766 .913 r
.0695 .44001 m .08054 .43543 L .08436 .43876 L p F P
0 g
s
.467 .545 .852 r
.74108 .22207 m .73894 .22172 L .73603 .21595 L p F P
0 g
s
.797 .891 .912 r
.61638 .17281 m .61901 .17094 L .61802 .17395 L closepath p F P
0 g
s
.733 .855 .938 r
.62817 .16549 m .61901 .17094 L .61802 .17395 L p F P
0 g
s
.733 .855 .938 r
.63111 .16885 m .62817 .16549 L p .61802 .17395 L F P
0 g
s
.547 .546 .805 r
.65211 .40395 m .65954 .40427 L p .66129 .41089 L F P
0 g
s
.536 .544 .811 r
.65954 .40427 m .65211 .40395 L .65727 .39919 L closepath p F P
0 g
s
.538 .534 .798 r
.65649 .39742 m .65727 .39919 L .65211 .40395 L p F P
0 g
s
.558 .572 .824 r
.67317 .41701 m .66559 .41724 L .66257 .4109 L p F P
0 g
s
.174 .173 .617 r
.60283 .24208 m .60001 .24764 L .60284 .25196 L p F P
0 g
s
.168 .153 .596 r
.60001 .24764 m .60283 .24208 L .60053 .23759 L p F P
0 g
s
.492 .577 .869 r
.72247 .20388 m .71784 .20349 L .71493 .19812 L p F P
0 g
s
.764 .774 .861 r
.09559 .43251 m .10625 .42524 L .11024 .42852 L p F P
0 g
s
.761 .774 .863 r
.10699 .42475 m .10625 .42524 L .11024 .42852 L p F P
0 g
s
.761 .774 .863 r
.11024 .42852 m .11076 .42817 L .10699 .42475 L p F P
0 g
s
.292 .271 .664 r
.60279 .26184 m .60142 .26404 L .60312 .27115 L p F P
0 g
s
.297 .275 .665 r
.60277 .27171 m .60312 .27115 L .60142 .26404 L p F P
0 g
s
.789 .774 .839 r
.12163 .4195 m .11076 .42817 L .10699 .42475 L p F P
0 g
s
.84 .769 .784 r
.14638 .39554 m .14574 .39628 L .14203 .39274 L p F P
0 g
s
.84 .769 .784 r
.14203 .39274 m .14249 .3922 L .14638 .39554 L p F P
0 g
s
.839 .769 .784 r
.14638 .39554 m .14249 .3922 L .14885 .38484 L p F P
0 g
s
.735 .991 .828 r
.77428 .42015 m .77254 .42171 L .77005 .42194 L p F P
0 g
s
0 0 .498 r
.60074 .21973 m .59963 .22278 L .60098 .22755 L p F P
0 g
s
0 0 .425 r
.59963 .22278 m .60074 .21973 L .60017 .21404 L p F P
0 g
s
.735 .991 .828 r
.77005 .42194 m .77907 .41454 L .77428 .42015 L p F P
0 g
s
.675 .95 .697 r
.78179 .41195 m .78336 .41052 L p .77428 .42015 L F P
0 g
s
.675 .95 .697 r
.77428 .42015 m .77907 .41454 L .78179 .41195 L p F P
0 g
s
.474 .456 .758 r
.62888 .35597 m .62323 .35435 L .62696 .35049 L closepath p F P
0 g
s
.48 .448 .745 r
.62574 .34698 m .62696 .35049 L .62323 .35435 L p F P
0 g
s
.48 .448 .745 r
.62084 .34532 m .62574 .34698 L p .62323 .35435 L F P
0 g
s
.822 .771 .804 r
.13883 .40329 m .14574 .39628 L .14203 .39274 L p F P
0 g
s
0 0 .191 r
.79356 .39453 m .79449 .3933 L .79634 .38722 L p F P
0 g
s
0 0 .169 r
.80042 .38176 m .79634 .38722 L .79449 .3933 L p F P
0 g
s
0 0 .325 r
.79634 .38722 m .80042 .38176 L .80131 .37598 L p F P
0 g
s
.52 .509 .785 r
.6515 .3901 m .6413 .38896 L .64049 .3869 L p F P
0 g
s
.575 .612 .852 r
.68365 .42811 m .68216 .42824 L .68322 .4273 L closepath p F P
0 g
s
.576 .599 .839 r
.68069 .42261 m .68322 .4273 L .68216 .42824 L p F P
0 g
s
.52 .609 .882 r
.69819 .18971 m .69684 .1874 L .69861 .18741 L closepath p F P
0 g
s
.613 .684 .893 r
.70172 .43644 m .7016 .43626 L .70203 .43617 L closepath p F P
0 g
s
.508 .588 .87 r
.71493 .19812 m .7107 .19792 L .71208 .1929 L closepath p F P
0 g
s
.513 .597 .875 r
.71202 .19279 m .71208 .1929 L .7107 .19792 L p F P
0 g
s
.326 .343 .725 r
.79536 .3048 m .79654 .30248 L p .79867 .3116 L F P
0 g
s
.326 .343 .725 r
.79867 .3116 m .79712 .31035 L .79536 .3048 L p F P
0 g
s
.341 .367 .742 r
.79536 .3048 m .79398 .30067 L .79654 .30248 L closepath p F P
0 g
s
.664 .732 .9 r
.63111 .16885 m .64302 .16466 L .64596 .16865 L p F P
0 g
s
.681 .745 .899 r
.64302 .16466 m .63111 .16885 L .62817 .16549 L p F P
0 g
s
.326 .343 .725 r
.79795 .31296 m .79712 .31035 L .79867 .3116 L closepath p F P
0 g
s
.301 .312 .705 r
.79867 .3116 m .79795 .31296 L .80025 .32076 L p F P
0 g
s
.327 .329 .709 r
.80017 .32091 m .80025 .32076 L .79795 .31296 L p F P
0 g
s
.614 .669 .879 r
.70203 .43617 m .7016 .43626 L .6987 .43164 L p F P
0 g
s
.128 .053 .495 r
.80126 .3705 m .80126 .37046 L .80127 .3705 L closepath p F P
0 g
s
.057 0 .421 r
.80127 .37055 m .80127 .3705 L .80126 .3705 L closepath p F P
0 g
s
0 0 .395 r
.80127 .3705 m .80481 .36516 L p .80152 .37569 L F P
0 g
s
0 0 .395 r
.80152 .37569 m .80127 .37055 L .80127 .3705 L p F P
0 g
s
.126 .052 .494 r
.80397 .35993 m .80481 .36516 L .80127 .3705 L p F P
0 g
s
.085 0 .427 r
.80131 .37598 m .80152 .37569 L .80127 .37055 L closepath p F P
0 g
s
.341 .367 .742 r
.79654 .30248 m .79398 .30067 L .79249 .29626 L p F P
0 g
s
.52 .509 .785 r
.64049 .3869 m .6454 .3822 L p .6515 .3901 L F P
0 g
s
.508 .501 .784 r
.64049 .3869 m .63821 .38114 L .6454 .3822 L closepath p F P
0 g
s
.734 .774 .885 r
.08054 .43543 m .08497 .43294 L .08883 .43625 L p F P
0 g
s
.732 .774 .886 r
.09178 .42915 m .08497 .43294 L .08883 .43625 L p F P
0 g
s
.732 .774 .886 r
.08883 .43625 m .09559 .43251 L .09178 .42915 L p F P
0 g
s
.854 .771 .769 r
.1569 .36702 m .16067 .37043 L .15517 .3775 L p F P
0 g
s
.852 .771 .772 r
.16234 .36017 m .1569 .36702 L .16067 .37043 L p F P
0 g
s
.391 .371 .716 r
.61308 .30746 m .60862 .30462 L .61125 .30119 L closepath p F P
0 g
s
.387 .365 .713 r
.60988 .29645 m .60791 .29502 L p .60862 .30462 L F P
0 g
s
.387 .365 .713 r
.60862 .30462 m .61125 .30119 L .60988 .29645 L p F P
0 g
s
.31 .292 .676 r
.60344 .2724 m .60277 .27171 L .60312 .27115 L closepath p F P
0 g
s
.826 .771 .801 r
.13883 .40329 m .13395 .40835 L .13022 .40484 L p F P
0 g
s
.826 .771 .801 r
.13022 .40484 m .13491 .39997 L .13883 .40329 L p F P
0 g
s
.822 .771 .804 r
.14203 .39274 m .13491 .39997 L .13883 .40329 L p F P
0 g
s
.601 .664 .883 r
.70203 .43617 m .7137 .43384 L .71083 .42963 L p F P
0 g
s
.601 .664 .883 r
.71083 .42963 m .70872 .42998 L .70203 .43617 L p F P
0 g
s
.614 .669 .879 r
.6987 .43164 m .70872 .42998 L .70203 .43617 L p F P
0 g
s
0 0 .444 r
.60082 .21249 m .60017 .21404 L .60074 .21973 L p F P
0 g
s
.341 .367 .742 r
.79249 .29626 m .7938 .29354 L p .79654 .30248 L F P
0 g
s
.356 .389 .758 r
.79249 .29626 m .79089 .29173 L .7938 .29354 L closepath p F P
0 g
s
.298 .293 .686 r
.80035 .3211 m .80017 .32091 L .80025 .32076 L closepath p F P
0 g
s
.613 .691 .899 r
.64596 .16865 m .65796 .16601 L .66089 .17035 L p F P
0 g
s
.621 .7 .901 r
.65796 .16601 m .64596 .16865 L .64302 .16466 L p F P
0 g
s
.432 .498 .827 r
.76456 .24395 m .76022 .24274 L .75747 .23669 L p F P
0 g
s
.46 .531 .843 r
.74108 .22207 m .75138 .22398 L .74962 .22912 L p F P
0 g
s
.465 .539 .848 r
.74255 .217 m .74108 .22207 L .75138 .22398 L p F P
0 g
s
.467 .545 .852 r
.73603 .21595 m .74255 .217 L .74108 .22207 L p F P
0 g
s
.789 .774 .839 r
.10699 .42475 m .11766 .41621 L .12163 .4195 L p F P
0 g
s
.785 .774 .842 r
.11853 .41552 m .11766 .41621 L .12163 .4195 L p F P
0 g
s
.785 .774 .842 r
.12163 .4195 m .12229 .41898 L .11853 .41552 L p F P
0 g
s
.279 .281 .682 r
.80025 .32076 m .80295 .31568 L p .80394 .32517 L F P
0 g
s
.279 .281 .682 r
.80394 .32517 m .80035 .3211 L .80025 .32076 L p F P
0 g
s
.301 .312 .705 r
.80025 .32076 m .80295 .31568 L .79867 .3116 L p F P
0 g
s
.809 .773 .819 r
.13075 .41122 m .12229 .41898 L .11853 .41552 L p F P
0 g
s
.809 .773 .819 r
.11853 .41552 m .12681 .40792 L .13075 .41122 L p F P
0 g
s
.805 .773 .823 r
.13022 .40484 m .12681 .40792 L .13075 .41122 L p F P
0 g
s
.805 .773 .823 r
.13075 .41122 m .13395 .40835 L .13022 .40484 L p F P
0 g
s
.28 .281 .682 r
.80227 .32817 m .80035 .3211 L .80394 .32517 L closepath p F P
0 g
s
.58 .641 .876 r
.68365 .42811 m .69577 .42677 L .6987 .43164 L p F P
0 g
s
.572 .61 .852 r
.69283 .42165 m .69577 .42677 L .68365 .42811 L p F P
0 g
s
.572 .61 .852 r
.68903 .42195 m .69283 .42165 L p .68365 .42811 L F P
0 g
s
.572 .61 .852 r
.68365 .42811 m .68322 .4273 L .68903 .42195 L p F P
0 g
s
.461 .442 .751 r
.62574 .34698 m .62084 .34532 L .62402 .34189 L closepath p F P
0 g
s
.468 .435 .738 r
.62259 .33765 m .62402 .34189 L .62084 .34532 L p F P
0 g
s
.468 .435 .738 r
.61881 .33616 m .62259 .33765 L p .62084 .34532 L F P
0 g
s
.355 .389 .758 r
.7938 .29354 m .79089 .29173 L .78932 .28732 L p F P
0 g
s
.329 .304 .679 r
.60312 .27115 m .60638 .26595 L p .60683 .27567 L F P
0 g
s
.329 .304 .679 r
.60683 .27567 m .60344 .2724 L .60312 .27115 L p F P
0 g
s
.292 .271 .664 r
.60312 .27115 m .60638 .26595 L .60279 .26184 L p F P
0 g
s
0 0 .02 r
.79313 .3963 m .79449 .3933 L .79356 .39453 L closepath p F P
0 g
s
.715 .883 .959 r
.74619 .43552 m .74648 .43538 L .74629 .43559 L closepath p F P
0 g
s
.751 .904 .945 r
.75815 .42945 m .74648 .43538 L .74629 .43559 L p F P
0 g
s
.545 .556 .817 r
.66257 .4109 m .66129 .41089 L .66219 .41008 L closepath p F P
0 g
s
.547 .546 .805 r
.65954 .40427 m .66219 .41008 L .66129 .41089 L p F P
0 g
s
.324 .304 .681 r
.60499 .27845 m .60344 .2724 L .60683 .27567 L closepath p F P
0 g
s
.572 .609 .851 r
.68322 .4273 m .68069 .42261 L .68903 .42195 L closepath p F P
0 g
s
.51 .497 .778 r
.6454 .3822 m .63821 .38114 L .6368 .37744 L p F P
0 g
s
.668 .841 .966 r
.73143 .43765 m .74348 .43323 L .74619 .43552 L p F P
0 g
s
.701 .851 .954 r
.74648 .43538 m .74619 .43552 L .74348 .43323 L p F P
0 g
s
.355 .389 .758 r
.78932 .28732 m .79047 .28479 L p .7938 .29354 L F P
0 g
s
.369 .409 .772 r
.78932 .28732 m .78783 .28335 L .79047 .28479 L closepath p F P
0 g
s
.701 .851 .954 r
.74348 .43323 m .7515 .42972 L .74648 .43538 L p F P
0 g
s
.718 .911 .962 r
.75551 .42789 m .7515 .42972 L .74648 .43538 L p F P
0 g
s
.718 .911 .962 r
.74648 .43538 m .75815 .42945 L .75551 .42789 L p F P
0 g
s
.543 .639 .895 r
.68362 .17786 m .67884 .17813 L .67591 .17344 L p F P
0 g
s
.216 .177 .597 r
.80551 .34199 m .80373 .34477 L .80596 .34956 L p F P
0 g
s
.253 .224 .632 r
.80373 .34477 m .80551 .34199 L .80403 .33527 L p F P
0 g
s
.518 .612 .885 r
.69861 .18741 m .69684 .1874 L .69393 .18244 L p F P
0 g
s
0 0 0 r
.6043 .19148 m .60369 .19689 L p .60439 .19096 L F P
0 g
s
.818 .797 .303 r
.6043 .19148 m .60442 .19066 L .60486 .18941 L closepath p F P
0 g
s
0 0 0 r
.60442 .19066 m .6043 .19148 L p .60439 .19096 L F P
0 g
s
.762 .762 .252 r
.6043 .19148 m .60486 .18941 L p .60399 .19329 L F P
0 g
s
.762 .762 .252 r
.60326 .19657 m .6043 .19148 L p .60399 .19329 L F P
0 g
s
0 0 0 r
.78629 .40683 m .78336 .41052 L p .78368 .41008 L F P
0 g
s
0 0 0 r
.79125 .3998 m .78629 .40683 L p .78368 .41008 L F P
0 g
s
0 0 0 r
.79102 .40098 m .79256 .39819 L p .78629 .40683 L F P
0 g
s
0 0 0 r
.78629 .40683 m .79079 .40128 L .79102 .40098 L p F P
0 g
s
.759 .969 .688 r
.78629 .40683 m .79079 .40128 L p .79018 .40196 L F P
0 g
s
0 0 0 r
.79256 .39819 m .79125 .3998 L .78629 .40683 L p F P
0 g
s
.759 .969 .688 r
.7809 .41243 m .78629 .40683 L .79018 .40196 L F
.626 .886 .557 r
.78179 .41195 m .78629 .40683 L .78336 .41052 L closepath p F P
0 g
s
.259 .251 .659 r
.80227 .32817 m .80394 .32517 L p .80428 .33484 L F P
0 g
s
.259 .251 .659 r
.80428 .33484 m .80375 .33412 L .80227 .32817 L p F P
0 g
s
.636 .764 .94 r
.71655 .43776 m .72864 .43447 L .73143 .43765 L p F P
0 g
s
.624 .737 .928 r
.72864 .43447 m .71655 .43776 L .7137 .43384 L p F P
0 g
s
.854 .771 .769 r
.15517 .3775 m .1514 .37409 L .1569 .36702 L p F P
0 g
s
.854 .771 .769 r
.15517 .3775 m .15396 .37905 L .15025 .37556 L p F P
0 g
s
.854 .771 .769 r
.15025 .37556 m .1514 .37409 L .15517 .3775 L p F P
0 g
s
.125 .134 .597 r
.60275 .23222 m .60053 .23759 L .60283 .24208 L p F P
0 g
s
.077 .079 .557 r
.60273 .23214 m .60098 .22755 L p .60053 .23759 L F P
0 g
s
.077 .079 .557 r
.60053 .23759 m .60275 .23222 L .60273 .23214 L p F P
0 g
s
.51 .497 .778 r
.6368 .37744 m .64028 .37401 L p .6454 .3822 L F P
0 g
s
.497 .488 .777 r
.6368 .37744 m .63511 .37304 L .64028 .37401 L closepath p F P
0 g
s
.303 .316 .709 r
.80134 .30639 m .79867 .3116 L .80295 .31568 L p F P
0 g
s
.326 .343 .725 r
.79654 .30248 m .80134 .30639 L .79867 .3116 L p F P
0 g
s
.558 .572 .824 r
.66257 .4109 m .67471 .41089 L p .67317 .41701 L F P
0 g
s
.539 .553 .817 r
.67169 .40466 m .67471 .41089 L .66257 .4109 L p F P
0 g
s
.539 .553 .817 r
.66809 .40455 m .67169 .40466 L p .66257 .4109 L F P
0 g
s
.539 .553 .817 r
.66257 .4109 m .66219 .41008 L .66809 .40455 L p F P
0 g
s
.368 .409 .772 r
.79047 .28479 m .78783 .28335 L .78581 .27793 L p F P
0 g
s
.37 .351 .707 r
.60988 .29645 m .60791 .29502 L .60904 .29347 L closepath p F P
0 g
s
.365 .343 .702 r
.60791 .29502 m .60904 .29347 L .60694 .28587 L p F P
0 g
s
.466 .546 .854 r
.74255 .217 m .73603 .21595 L .73316 .21028 L p F P
0 g
s
.446 .427 .744 r
.62259 .33765 m .61881 .33616 L .62121 .33346 L closepath p F P
0 g
s
.444 .424 .742 r
.61943 .32799 m .61707 .3269 L p .61881 .33616 L F P
0 g
s
.444 .424 .742 r
.61881 .33616 m .62121 .33346 L .61943 .32799 L p F P
0 g
s
.452 .521 .838 r
.74962 .22912 m .75437 .23015 L .75144 .22399 L p F P
0 g
s
.452 .521 .838 r
.75144 .22399 m .75138 .22398 L .74962 .22912 L p F P
0 g
s
.765 .777 .862 r
.10625 .42524 m .09559 .43251 L .09178 .42915 L p F P
0 g
s
.839 .773 .789 r
.14885 .38484 m .15396 .37905 L .15025 .37556 L p F P
0 g
s
.353 .327 .691 r
.60499 .27845 m .60683 .27567 L p .60728 .28538 L F P
0 g
s
.353 .327 .691 r
.60728 .28538 m .60667 .28487 L .60499 .27845 L p F P
0 g
s
.655 .806 .956 r
.74348 .43323 m .73143 .43765 L .72864 .43447 L p F P
0 g
s
.538 .552 .817 r
.66219 .41008 m .65954 .40427 L .66809 .40455 L closepath p F P
0 g
s
0 0 .444 r
.60074 .21973 m .6017 .21741 L .60082 .21249 L p F P
0 g
s
0 0 .41 r
.60268 .20716 m .60082 .21249 L .6017 .21741 L p F P
0 g
s
0 0 .299 r
.60082 .21249 m .60268 .20716 L .60254 .202 L p F P
0 g
s
.238 .239 .657 r
.60591 .25622 m .60279 .26184 L .60638 .26595 L p F P
0 g
s
.286 .259 .652 r
.60284 .25196 m .60591 .25622 L .60279 .26184 L p F P
0 g
s
.83 .902 .889 r
.61901 .17094 m .61638 .17281 L .61346 .17122 L p F P
0 g
s
.88 .913 .846 r
.61055 .17899 m .61638 .17281 L .61346 .17122 L p F P
0 g
s
.574 .673 .907 r
.66365 .16998 m .66089 .17035 L .65796 .16601 L p F P
0 g
s
.5 .484 .772 r
.64028 .37401 m .63511 .37304 L .63333 .36824 L p F P
0 g
s
0 0 0 r
.79449 .3933 m .79848 .38787 L p .79256 .39819 L F P
0 g
s
0 0 0 r
.79256 .39819 m .79313 .3963 L .79449 .3933 L p F P
0 g
s
0 0 .169 r
.79449 .3933 m .79848 .38787 L .80042 .38176 L p F P
0 g
s
.487 .57 .865 r
.72247 .20388 m .73021 .20468 L .72731 .19918 L p F P
0 g
s
.487 .57 .865 r
.72731 .19918 m .72372 .19883 L .72247 .20388 L p F P
0 g
s
.492 .577 .869 r
.71493 .19812 m .72372 .19883 L .72247 .20388 L p F P
0 g
s
.516 .608 .883 r
.69861 .18741 m .70911 .18765 L .7062 .18255 L p F P
0 g
s
.516 .608 .883 r
.7062 .18255 m .69944 .18245 L .69861 .18741 L p F P
0 g
s
.518 .612 .885 r
.69393 .18244 m .69944 .18245 L .69861 .18741 L p F P
0 g
s
.83 .902 .889 r
.61346 .17122 m .61995 .16584 L .61901 .17094 L p F P
0 g
s
.753 .81 .898 r
.62522 .16232 m .61995 .16584 L .61901 .17094 L p F P
0 g
s
.753 .81 .898 r
.61901 .17094 m .62817 .16549 L .62522 .16232 L p F P
0 g
s
.757 .811 .335 r
.60486 .18941 m .60631 .18561 L .60577 .18738 L closepath p F P
0 g
s
.801 .968 .659 r
.61055 .17899 m .60631 .18561 L .60577 .18738 L p F P
0 g
s
.381 .429 .785 r
.78581 .27793 m .78481 .27538 L .78655 .27622 L closepath p F P
0 g
s
.368 .409 .772 r
.78581 .27793 m .78655 .27622 L p .79047 .28479 L F P
0 g
s
.493 .58 .87 r
.72372 .19883 m .71493 .19812 L .71208 .1929 L p F P
0 g
s
.432 .498 .827 r
.75747 .23669 m .75757 .23638 L p .76456 .24395 L F P
0 g
s
.442 .512 .835 r
.75747 .23669 m .75729 .23631 L .75757 .23638 L closepath p F P
0 g
s
.26 .251 .659 r
.80403 .33527 m .80375 .33412 L .80428 .33484 L closepath p F P
0 g
s
.842 .773 .786 r
.14506 .38145 m .14885 .38484 L .14249 .3922 L p F P
0 g
s
.839 .773 .789 r
.15025 .37556 m .14506 .38145 L .14885 .38484 L p F P
0 g
s
.88 .913 .846 r
.61346 .17122 m .6112 .17401 L .61055 .17899 L p F P
0 g
s
.913 .963 .646 r
.6112 .17401 m .61055 .17899 L .60631 .18561 L p F P
0 g
s
.323 .345 .729 r
.79909 .29728 m .79654 .30248 L .80134 .30639 L p F P
0 g
s
.341 .367 .742 r
.7938 .29354 m .79909 .29728 L .79654 .30248 L p F P
0 g
s
.349 .327 .693 r
.60694 .28587 m .60667 .28487 L .60728 .28538 L closepath p F P
0 g
s
.44 .514 .838 r
.75757 .23638 m .75729 .23631 L .75437 .23015 L p F P
0 g
s
.5 .484 .772 r
.63333 .36824 m .63596 .36556 L p .64028 .37401 L F P
0 g
s
.486 .475 .77 r
.63333 .36824 m .632 .36465 L .63596 .36556 L closepath p F P
0 g
s
.357 .338 .701 r
.60728 .28538 m .60694 .28587 L .60904 .29347 L p F P
0 g
s
.221 .203 .625 r
.80428 .33484 m .80403 .33527 L .80551 .34199 L p F P
0 g
s
.119 .047 .493 r
.80755 .35455 m .80397 .35993 L .80481 .36516 L p F P
0 g
s
.177 .122 .552 r
.80397 .35993 m .80755 .35455 L .80596 .34956 L p F P
0 g
s
.437 .506 .833 r
.75914 .23132 m .75757 .23638 L .76635 .23884 L p F P
0 g
s
.44 .514 .838 r
.75437 .23015 m .75914 .23132 L .75757 .23638 L p F P
0 g
s
.432 .498 .827 r
.75757 .23638 m .76635 .23884 L .76456 .24395 L p F P
0 g
s
.381 .429 .786 r
.78655 .27622 m .78481 .27538 L .78195 .26808 L p F P
0 g
s
.431 .412 .737 r
.61943 .32799 m .61707 .3269 L .61854 .32517 L closepath p F P
0 g
s
.429 .408 .734 r
.61626 .31795 m .61553 .31757 L p .61707 .3269 L F P
0 g
s
.429 .408 .734 r
.61707 .3269 m .61854 .32517 L .61626 .31795 L p F P
0 g
s
.025 .02 .512 r
.6017 .21741 m .60074 .21973 L .60162 .22582 L p F P
0 g
s
0 0 .498 r
.60098 .22755 m .60162 .22582 L .60074 .21973 L p F P
0 g
s
.489 .472 .765 r
.63596 .36556 m .632 .36465 L .63006 .35927 L p F P
0 g
s
.221 .203 .625 r
.80551 .34199 m .80697 .33947 L .80428 .33484 L p F P
0 g
s
.219 .205 .628 r
.80721 .3296 m .80428 .33484 L .80697 .33947 L p F P
0 g
s
.259 .251 .659 r
.80394 .32517 m .80721 .3296 L .80428 .33484 L p F P
0 g
s
.602 .651 .871 r
.70872 .42998 m .6987 .43164 L .69577 .42677 L p F P
0 g
s
.573 .601 .843 r
.68903 .42195 m .68069 .42261 L .67771 .41688 L p F P
0 g
s
0 0 .321 r
.80152 .37569 m .80131 .37598 L .80042 .38176 L p F P
0 g
s
.357 .338 .701 r
.60904 .29347 m .61207 .28914 L .60728 .28538 L p F P
0 g
s
.319 .314 .697 r
.61109 .27959 m .60728 .28538 L .61207 .28914 L p F P
0 g
s
.353 .327 .691 r
.60683 .27567 m .61109 .27959 L .60728 .28538 L p F P
0 g
s
0 0 0 r
.79125 .3998 m .79256 .39819 L .79313 .3963 L closepath p F P
0 g
s
.343 .374 .749 r
.79622 .28836 m .7938 .29354 L .79909 .29728 L p F P
0 g
s
.355 .389 .758 r
.79047 .28479 m .79622 .28836 L .7938 .29354 L p F P
0 g
s
.579 .672 .903 r
.66365 .16998 m .67299 .16881 L .67006 .16424 L p F P
0 g
s
.579 .672 .903 r
.67006 .16424 m .66405 .1651 L .66365 .16998 L p F P
0 g
s
.574 .673 .907 r
.65796 .16601 m .66405 .1651 L .66365 .16998 L p F P
0 g
s
.556 .584 .837 r
.67771 .41688 m .67317 .41701 L .6763 .41407 L closepath p F P
0 g
s
.558 .572 .824 r
.67471 .41089 m .6763 .41407 L .67317 .41701 L p F P
0 g
s
.382 .359 .709 r
.60904 .29347 m .61207 .28914 L p .61311 .29867 L F P
0 g
s
.382 .359 .709 r
.61311 .29867 m .60988 .29645 L .60904 .29347 L p F P
0 g
s
.765 .777 .862 r
.09178 .42915 m .10239 .42191 L .10625 .42524 L p F P
0 g
s
.762 .776 .865 r
.1032 .42138 m .10239 .42191 L .10625 .42524 L p F P
0 g
s
.762 .776 .865 r
.10625 .42524 m .10699 .42475 L .1032 .42138 L p F P
0 g
s
.039 .053 .545 r
.60273 .23214 m .60098 .22755 L .60162 .22582 L closepath p F P
0 g
s
.422 .483 .817 r
.76456 .24395 m .7729 .24654 L p .77099 .25172 L F P
0 g
s
.421 .487 .822 r
.76456 .24395 m .7729 .24654 L .76996 .23997 L p F P
0 g
s
.421 .487 .822 r
.76996 .23997 m .76635 .23884 L .76456 .24395 L p F P
0 g
s
.489 .472 .765 r
.63006 .35927 m .63229 .35691 L p .63596 .36556 L F P
0 g
s
.474 .462 .764 r
.63006 .35927 m .62888 .35597 L .63229 .35691 L closepath p F P
0 g
s
.842 .773 .786 r
.14249 .3922 m .14203 .39274 L .1383 .38928 L p F P
0 g
s
.842 .773 .786 r
.1383 .38928 m .1387 .38882 L .14249 .3922 L p F P
0 g
s
.842 .773 .786 r
.14249 .3922 m .1387 .38882 L .14506 .38145 L p F P
0 g
s
.79 .777 .841 r
.11766 .41621 m .10699 .42475 L .1032 .42138 L p F P
0 g
s
0 0 .395 r
.80481 .36516 m .80488 .37065 L .80152 .37569 L p F P
0 g
s
0 0 .301 r
.80488 .37065 m .80152 .37569 L .80141 .38042 L p F P
0 g
s
0 0 .321 r
.80042 .38176 m .80141 .38042 L .80152 .37569 L p F P
0 g
s
.824 .775 .806 r
.13491 .39997 m .14203 .39274 L .1383 .38928 L p F P
0 g
s
.54 .546 .81 r
.66809 .40455 m .65954 .40427 L .65727 .39919 L p F P
0 g
s
.378 .359 .712 r
.61125 .30119 m .60988 .29645 L .61311 .29867 L closepath p F P
0 g
s
.545 .635 .891 r
.68362 .17786 m .69101 .17753 L .68809 .17266 L p F P
0 g
s
.545 .635 .891 r
.68809 .17266 m .68442 .17287 L .68362 .17786 L p F P
0 g
s
.543 .639 .895 r
.67591 .17344 m .68442 .17287 L .68362 .17786 L p F P
0 g
s
.208 .216 .648 r
.60541 .24648 m .60284 .25196 L .60591 .25622 L p F P
0 g
s
.174 .173 .617 r
.60284 .25196 m .60541 .24648 L .60283 .24208 L p F P
0 g
s
.477 .458 .758 r
.63229 .35691 m .62888 .35597 L .62696 .35049 L p F P
0 g
s
.703 .957 .948 r
.76783 .42346 m .75815 .42945 L .75551 .42789 L p F P
0 g
s
.357 .396 .765 r
.79275 .27963 m .79047 .28479 L .79622 .28836 L p F P
0 g
s
.368 .409 .772 r
.78655 .27622 m .79275 .27963 L .79047 .28479 L p F P
0 g
s
.401 .377 .717 r
.61125 .30119 m .61311 .29867 L p .61423 .30815 L F P
0 g
s
.401 .377 .717 r
.61423 .30815 m .61308 .30746 L .61125 .30119 L p F P
0 g
s
.42 .475 .811 r
.77586 .25344 m .77099 .25172 L p .77683 .25968 L F P
0 g
s
.412 .471 .811 r
.77586 .25344 m .77099 .25172 L .77295 .24665 L closepath p F P
0 g
s
.422 .483 .817 r
.7729 .24654 m .77295 .24665 L .77099 .25172 L p F P
0 g
s
.828 .775 .803 r
.13491 .39997 m .13022 .40484 L .12646 .40142 L p F P
0 g
s
.828 .775 .803 r
.12646 .40142 m .1311 .3966 L .13491 .39997 L p F P
0 g
s
.824 .775 .806 r
.1383 .38928 m .1311 .3966 L .13491 .39997 L p F P
0 g
s
.415 .396 .729 r
.61626 .31795 m .61553 .31757 L .61597 .31702 L closepath p F P
0 g
s
.411 .39 .726 r
.61553 .31757 m .61597 .31702 L .61355 .30903 L p F P
0 g
s
.462 .448 .756 r
.62696 .35049 m .62574 .34698 L .62915 .34809 L closepath p F P
0 g
s
.477 .458 .758 r
.62696 .35049 m .62915 .34809 L p .63229 .35691 L F P
0 g
s
.381 .429 .786 r
.78195 .26808 m .78205 .26783 L p .78655 .27622 L F P
0 g
s
.393 .447 .797 r
.78195 .26808 m .78181 .26773 L .78205 .26783 L closepath p F P
0 g
s
.621 .7 .901 r
.64302 .16466 m .65502 .16174 L .65796 .16601 L p F P
0 g
s
.632 .709 .902 r
.65502 .16174 m .64302 .16466 L .64008 .16077 L p F P
0 g
s
.681 .745 .899 r
.62817 .16549 m .64008 .16077 L .64302 .16466 L p F P
0 g
s
.7 .758 .897 r
.64008 .16077 m .62817 .16549 L .62522 .16232 L p F P
0 g
s
.392 .447 .799 r
.78205 .26783 m .78181 .26773 L .77883 .26048 L p F P
0 g
s
0 0 0 r
.60442 .19066 m .60486 .18941 L .60631 .18561 L p F P
0 g
s
0 0 0 r
.60631 .18561 m .60748 .18046 L p .60442 .19066 L F P
0 g
s
.913 .963 .646 r
.60631 .18561 m .60748 .18046 L .6112 .17401 L p F P
0 g
s
.371 .417 .779 r
.78868 .27108 m .78655 .27622 L .79275 .27963 L p F P
0 g
s
.381 .429 .786 r
.78205 .26783 m .78868 .27108 L .78655 .27622 L p F P
0 g
s
.466 .546 .854 r
.73316 .21028 m .73318 .21021 L p .74255 .217 L F P
0 g
s
.474 .557 .86 r
.73316 .21028 m .73312 .2102 L .73318 .21021 L closepath p F P
0 g
s
.473 .559 .863 r
.73318 .21021 m .73312 .2102 L .73021 .20468 L p F P
0 g
s
.465 .445 .751 r
.62915 .34809 m .62574 .34698 L .62402 .34189 L p F P
0 g
s
0 0 .228 r
.60369 .19689 m .60254 .202 L .60268 .20716 L p F P
0 g
s
0 0 .026 r
.60254 .202 m .60369 .19689 L .6043 .19148 L p F P
0 g
s
.401 .454 .8 r
.77883 .26048 m .77683 .25968 L .77767 .25765 L closepath p F P
0 g
s
.42 .475 .811 r
.77683 .25968 m .77767 .25765 L .77586 .25344 L p F P
0 g
s
.397 .378 .721 r
.61355 .30903 m .61308 .30746 L .61423 .30815 L closepath p F P
0 g
s
.79 .777 .841 r
.1032 .42138 m .11382 .41286 L .11766 .41621 L p F P
0 g
s
.787 .777 .844 r
.11476 .41212 m .11382 .41286 L .11766 .41621 L p F P
0 g
s
.787 .777 .844 r
.11766 .41621 m .11853 .41552 L .11476 .41212 L p F P
0 g
s
.466 .546 .854 r
.73318 .21021 m .74398 .21192 L .74255 .217 L p F P
0 g
s
.473 .554 .858 r
.73431 .20522 m .73318 .21021 L .74398 .21192 L p F P
0 g
s
.473 .559 .863 r
.73021 .20468 m .73431 .20522 L .73318 .21021 L p F P
0 g
s
.811 .777 .821 r
.12681 .40792 m .11853 .41552 L .11476 .41212 L p F P
0 g
s
.811 .777 .821 r
.11476 .41212 m .12298 .40456 L .12681 .40792 L p F P
0 g
s
.808 .777 .824 r
.12646 .40142 m .12298 .40456 L .12681 .40792 L p F P
0 g
s
.808 .777 .824 r
.12681 .40792 m .13022 .40484 L .12646 .40142 L p F P
0 g
s
.18 .152 .588 r
.80697 .33947 m .80551 .34199 L .80672 .34838 L p F P
0 g
s
.216 .177 .597 r
.80596 .34956 m .80672 .34838 L .80551 .34199 L p F P
0 g
s
.401 .384 .725 r
.61423 .30815 m .61355 .30903 L .61597 .31702 L p F P
0 g
s
.378 .43 .789 r
.78401 .26273 m .78205 .26783 L .78868 .27108 L p F P
0 g
s
.392 .447 .799 r
.77883 .26048 m .78401 .26273 L .78205 .26783 L p F P
0 g
s
.52 .616 .888 r
.69944 .18245 m .69393 .18244 L .69101 .17753 L p F P
0 g
s
.547 .645 .898 r
.68442 .17287 m .67591 .17344 L .67299 .16881 L p F P
0 g
s
.465 .445 .751 r
.62402 .34189 m .62646 .33912 L p .62915 .34809 L F P
0 g
s
.448 .433 .749 r
.62402 .34189 m .62259 .33765 L .62646 .33912 L closepath p F P
0 g
s
.452 .431 .744 r
.62646 .33912 m .62259 .33765 L .62121 .33346 L p F P
0 g
s
.422 .401 .73 r
.61597 .31702 m .62019 .31159 L p .62204 .32085 L F P
0 g
s
.422 .401 .73 r
.62204 .32085 m .61626 .31795 L .61597 .31702 L p F P
0 g
s
.401 .384 .725 r
.61597 .31702 m .62019 .31159 L .61423 .30815 L p F P
0 g
s
.419 .402 .734 r
.61854 .32517 m .61626 .31795 L .62204 .32085 L closepath p F P
0 g
s
.452 .431 .744 r
.62121 .33346 m .62411 .33003 L p .62646 .33912 L F P
0 g
s
.434 .418 .742 r
.62121 .33346 m .61943 .32799 L .62411 .33003 L closepath p F P
0 g
s
.438 .416 .737 r
.61854 .32517 m .62204 .32085 L p .62411 .33003 L F P
0 g
s
.438 .416 .737 r
.62411 .33003 m .61943 .32799 L .61854 .32517 L p F P
0 g
s
.279 .281 .682 r
.80295 .31568 m .80679 .31993 L .80394 .32517 L p F P
0 g
s
.254 .25 .661 r
.80679 .31993 m .80394 .32517 L .80721 .3296 L p F P
0 g
s
.3 .303 .695 r
.61014 .27001 m .60683 .27567 L .61109 .27959 L p F P
0 g
s
.329 .304 .679 r
.60638 .26595 m .61014 .27001 L .60683 .27567 L p F P
0 g
s
.438 .513 .838 r
.75914 .23132 m .75437 .23015 L .75144 .22399 L p F P
0 g
s
.54 .546 .81 r
.65727 .39919 m .65894 .39758 L p .66809 .40455 L F P
0 g
s
.529 .539 .81 r
.65727 .39919 m .65649 .39742 L .65894 .39758 L closepath p F P
0 g
s
.624 .737 .928 r
.7137 .43384 m .72583 .43095 L .72864 .43447 L p F P
0 g
s
.612 .713 .917 r
.72583 .43095 m .7137 .43384 L .71083 .42963 L p F P
0 g
s
.169 .117 .551 r
.80672 .34838 m .80596 .34956 L .80755 .35455 L p F P
0 g
s
.493 .58 .87 r
.71208 .1929 m .7121 .1928 L p .72372 .19883 L F P
0 g
s
.5 .589 .875 r
.71208 .1929 m .71202 .19279 L .7121 .1928 L closepath p F P
0 g
s
.107 .101 .567 r
.60162 .22582 m .60313 .22216 L p .60276 .2322 L F P
0 g
s
.107 .101 .567 r
.60276 .2322 m .60273 .23214 L .60162 .22582 L p F P
0 g
s
.025 .02 .512 r
.60162 .22582 m .60313 .22216 L .6017 .21741 L p F P
0 g
s
.498 .592 .879 r
.7121 .1928 m .71202 .19279 L .70911 .18765 L p F P
0 g
s
.493 .58 .87 r
.7121 .1928 m .72439 .19373 L p .72372 .19883 L F P
0 g
s
.493 .586 .876 r
.7121 .1928 m .72439 .19373 L .72149 .18846 L p F P
0 g
s
.493 .586 .876 r
.72149 .18846 m .71291 .18786 L .7121 .1928 L p F P
0 g
s
.498 .592 .879 r
.70911 .18765 m .71291 .18786 L .7121 .1928 L p F P
0 g
s
.384 .382 .733 r
.6185 .30227 m .61423 .30815 L .62019 .31159 L p F P
0 g
s
.401 .377 .717 r
.61311 .29867 m .6185 .30227 L .61423 .30815 L p F P
0 g
s
.531 .534 .803 r
.65894 .39758 m .65649 .39742 L .65343 .39031 L p F P
0 g
s
0 0 .479 r
.60348 .21211 m .6017 .21741 L .60313 .22216 L p F P
0 g
s
0 0 .41 r
.6017 .21741 m .60348 .21211 L .60268 .20716 L p F P
0 g
s
.51 .497 .778 r
.64028 .37401 m .64727 .37531 L p .6454 .3822 L F P
0 g
s
.494 .494 .785 r
.64727 .37531 m .64028 .37401 L .64485 .36918 L closepath p F P
0 g
s
.5 .484 .772 r
.64417 .36745 m .64485 .36918 L .64028 .37401 L p F P
0 g
s
.5 .484 .772 r
.63596 .36556 m .64417 .36745 L p .64028 .37401 L F P
0 g
s
.741 .982 .91 r
.76783 .42346 m .76933 .42183 L .77005 .42194 L closepath p F P
0 g
s
.703 .957 .948 r
.76933 .42183 m .76783 .42346 L p .75551 .42789 L F P
0 g
s
.152 .165 .618 r
.60413 .23894 m .60283 .24208 L .60541 .24648 L p F P
0 g
s
.125 .134 .597 r
.60283 .24208 m .60413 .23894 L .60275 .23222 L p F P
0 g
s
.52 .509 .785 r
.6454 .3822 m .65036 .38293 L p .6515 .3901 L F P
0 g
s
.505 .507 .791 r
.65036 .38293 m .6454 .3822 L .6487 .37885 L closepath p F P
0 g
s
.51 .497 .778 r
.64727 .37531 m .6487 .37885 L .6454 .3822 L p F P
0 g
s
.58 .681 .91 r
.66405 .1651 m .65796 .16601 L .65502 .16174 L p F P
0 g
s
.678 .855 .967 r
.7515 .42972 m .74348 .43323 L .74074 .43053 L p F P
0 g
s
.655 .806 .956 r
.72864 .43447 m .74074 .43053 L .74348 .43323 L p F P
0 g
s
.759 .969 .688 r
.7809 .41243 m .78179 .41195 L .78629 .40683 L p F P
0 g
s
.482 .481 .779 r
.64417 .36745 m .63596 .36556 L .64123 .35977 L closepath p F P
0 g
s
.489 .472 .765 r
.64106 .35933 m .64123 .35977 L .63596 .36556 L p F P
0 g
s
.489 .472 .765 r
.63229 .35691 m .64106 .35933 L p .63596 .36556 L F P
0 g
s
.553 .582 .838 r
.6869 .41065 m .68987 .41627 L .67771 .41688 L p F P
0 g
s
.553 .582 .838 r
.67967 .41079 m .6869 .41065 L p .67771 .41688 L F P
0 g
s
.553 .582 .838 r
.67771 .41688 m .6763 .41407 L .67967 .41079 L p F P
0 g
s
.573 .601 .843 r
.67771 .41688 m .68987 .41627 L p .68903 .42195 L F P
0 g
s
.803 .988 .885 r
.76933 .42183 m .77005 .42194 L .77907 .41454 L p F P
0 g
s
.387 .445 .799 r
.78401 .26273 m .77883 .26048 L .77767 .25765 L p F P
0 g
s
.641 .775 .945 r
.74074 .43053 m .72864 .43447 L .72583 .43095 L p F P
0 g
s
.465 .539 .848 r
.74853 .2181 m .74255 .217 L p .75138 .22398 L F P
0 g
s
.459 .537 .85 r
.74255 .217 m .74853 .2181 L .74562 .21222 L p F P
0 g
s
.459 .537 .85 r
.74562 .21222 m .74398 .21192 L .74255 .217 L p F P
0 g
s
.516 .519 .798 r
.65343 .39031 m .6515 .3901 L .6528 .38881 L closepath p F P
0 g
s
.52 .509 .785 r
.65036 .38293 m .6528 .38881 L .6515 .3901 L p F P
0 g
s
0 0 .172 r
.80141 .38042 m .80042 .38176 L .79848 .38787 L p F P
0 g
s
0 0 0 r
.79102 .40098 m .79534 .39436 L .79256 .39819 L closepath p F P
0 g
s
0 0 0 r
.79848 .38787 m .79534 .39436 L .79256 .39819 L p F P
0 g
s
.041 0 .411 r
.80825 .36003 m .80481 .36516 L .80488 .37065 L p F P
0 g
s
.119 .047 .493 r
.80788 .35659 m .80755 .35455 L p .80481 .36516 L F P
0 g
s
.119 .047 .493 r
.80481 .36516 m .80825 .36003 L .80788 .35659 L p F P
0 g
s
.46 .453 .763 r
.63229 .35691 m .64106 .35933 L .63794 .35094 L p F P
0 g
s
.46 .453 .763 r
.63794 .35094 m .63762 .35084 L .63229 .35691 L p F P
0 g
s
.477 .458 .758 r
.62915 .34809 m .63762 .35084 L .63229 .35691 L p F P
0 g
s
.28 .287 .689 r
.80571 .31045 m .80295 .31568 L .80679 .31993 L p F P
0 g
s
.303 .316 .709 r
.80295 .31568 m .80571 .31045 L .80134 .30639 L p F P
0 g
s
.602 .651 .871 r
.69577 .42677 m .70794 .42512 L p .70872 .42998 L F P
0 g
s
.577 .646 .882 r
.70794 .42512 m .69577 .42677 L .69283 .42165 L p F P
0 g
s
.667 .945 .688 r
.77907 .41454 m .7809 .41243 L .78179 .41195 L closepath p F P
0 g
s
.803 .988 .885 r
.77907 .41454 m .7809 .41243 L p .76933 .42183 L F P
0 g
s
.268 .274 .681 r
.60919 .26042 m .60638 .26595 L .61014 .27001 L p F P
0 g
s
.238 .239 .657 r
.60638 .26595 m .60919 .26042 L .60591 .25622 L p F P
0 g
s
.18 .152 .588 r
.80672 .34838 m .8091 .34429 L .80697 .33947 L p F P
0 g
s
.128 .088 .54 r
.8091 .34429 m .80672 .34838 L .80764 .3544 L p F P
0 g
s
.169 .117 .551 r
.80755 .35455 m .80764 .3544 L .80672 .34838 L p F P
0 g
s
.387 .445 .799 r
.77767 .25765 m .77878 .25455 L p .78401 .26273 L F P
0 g
s
.399 .463 .81 r
.77767 .25765 m .77586 .25344 L .77878 .25455 L closepath p F P
0 g
s
.363 .362 .724 r
.61694 .2929 m .61311 .29867 L .6185 .30227 L p F P
0 g
s
.382 .359 .709 r
.61207 .28914 m .61694 .2929 L .61311 .29867 L p F P
0 g
s
.54 .546 .81 r
.65894 .39758 m .66866 .39819 L p .66809 .40455 L F P
0 g
s
.517 .529 .807 r
.65894 .39758 m .66866 .39819 L .66562 .39151 L p F P
0 g
s
.517 .529 .807 r
.66562 .39151 m .66493 .39144 L .65894 .39758 L p F P
0 g
s
.531 .534 .803 r
.65343 .39031 m .66493 .39144 L .65894 .39758 L p F P
0 g
s
.552 .581 .837 r
.6763 .41407 m .67471 .41089 L .67967 .41079 L closepath p F P
0 g
s
.456 .452 .766 r
.63423 .34206 m .62915 .34809 L .63762 .35084 L p F P
0 g
s
.465 .445 .751 r
.62646 .33912 m .63423 .34206 L .62915 .34809 L p F P
0 g
s
.472 .561 .864 r
.73431 .20522 m .73021 .20468 L .72731 .19918 L p F P
0 g
s
.52 .521 .797 r
.66493 .39144 m .65343 .39031 L .6528 .38881 L p F P
0 g
s
.107 .101 .567 r
.60275 .23222 m .60273 .23214 L .60276 .2322 L closepath p F P
0 g
s
.181 .155 .591 r
.80995 .33422 m .80697 .33947 L .8091 .34429 L p F P
0 g
s
.219 .205 .628 r
.80697 .33947 m .80995 .33422 L .80721 .3296 L p F P
0 g
s
.45 .523 .841 r
.75144 .22399 m .75138 .22398 L .7514 .2239 L closepath p F P
0 g
s
.465 .539 .848 r
.75138 .22398 m .7514 .2239 L .74853 .2181 L p F P
0 g
s
.573 .601 .843 r
.68987 .41627 m .6916 .41941 L .68903 .42195 L p F P
0 g
s
.571 .615 .858 r
.69283 .42165 m .68903 .42195 L .6916 .41941 L closepath p F P
0 g
s
.15 .151 .604 r
.60276 .2322 m .60275 .23222 L .60413 .23894 L p F P
0 g
s
.15 .151 .604 r
.60413 .23894 m .60516 .23665 L .60276 .2322 L p F P
0 g
s
.089 .108 .585 r
.60498 .22679 m .60276 .2322 L .60516 .23665 L p F P
0 g
s
.107 .101 .567 r
.60313 .22216 m .60498 .22679 L .60276 .2322 L p F P
0 g
s
.438 .513 .838 r
.75144 .22399 m .76065 .22625 L .75914 .23132 L p F P
0 g
s
.435 .514 .841 r
.76065 .22625 m .75144 .22399 L .7514 .2239 L p F P
0 g
s
.829 .954 .898 r
.6113 .17042 m .61346 .17122 L .61995 .16584 L p F P
0 g
s
.91 .932 .814 r
.6112 .17401 m .6113 .17042 L .61346 .17122 L closepath p F P
0 g
s
.435 .514 .841 r
.7514 .2239 m .75266 .21897 L p .76065 .22625 L F P
0 g
s
.445 .528 .848 r
.7514 .2239 m .74853 .2181 L .75266 .21897 L closepath p F P
0 g
s
.299 .316 .711 r
.80398 .30116 m .80134 .30639 L .80571 .31045 L p F P
0 g
s
.323 .345 .729 r
.80134 .30639 m .80398 .30116 L .79909 .29728 L p F P
0 g
s
.763 .968 .927 r
.76749 .42125 m .77251 .41788 L .76933 .42183 L closepath p F P
0 g
s
.703 .957 .948 r
.75551 .42789 m .76749 .42125 L .76933 .42183 L p F P
0 g
s
.803 .988 .885 r
.77936 .41276 m .77251 .41788 L .76933 .42183 L p F P
0 g
s
.803 .988 .885 r
.7809 .41243 m .77936 .41276 L p .76933 .42183 L F P
0 g
s
.52 .521 .797 r
.6528 .38881 m .6576 .38389 L p .66493 .39144 L F P
0 g
s
.508 .514 .797 r
.6528 .38881 m .65036 .38293 L .6576 .38389 L closepath p F P
0 g
s
.6 .67 .889 r
.71083 .42963 m .70872 .42998 L .71013 .42854 L closepath p F P
0 g
s
.602 .651 .871 r
.70794 .42512 m .71013 .42854 L .70872 .42998 L p F P
0 g
s
.519 .611 .884 r
.69944 .18245 m .7062 .18255 L .70329 .17748 L p F P
0 g
s
.519 .611 .884 r
.70329 .17748 m .70027 .17746 L .69944 .18245 L p F P
0 g
s
.52 .616 .888 r
.69101 .17753 m .70027 .17746 L .69944 .18245 L p F P
0 g
s
0 0 .148 r
.80408 .37641 m .80141 .38042 L .80088 .38464 L p F P
0 g
s
0 0 .301 r
.80141 .38042 m .80408 .37641 L .80488 .37065 L p F P
0 g
s
0 0 .172 r
.79848 .38787 m .80088 .38464 L .80141 .38042 L p F P
0 g
s
0 0 0 r
.60552 .18631 m .60442 .19066 L p .60531 .1877 L F P
0 g
s
0 0 0 r
.60748 .18046 m .60552 .18631 L p .60531 .1877 L F P
0 g
s
.852 .832 .359 r
.60798 .17551 m .60748 .18046 L .60552 .18631 L p F P
0 g
s
0 0 0 r
.60552 .18631 m .60479 .19177 L p .60576 .18475 L F P
0 g
s
.852 .832 .359 r
.60623 .1813 m .60798 .17551 L p .60634 .18269 L F P
0 g
s
.852 .832 .359 r
.60552 .18631 m .60623 .1813 L p .60634 .18269 L F P
0 g
s
0 0 0 r
.60623 .1813 m .60552 .18631 L p .60576 .18475 L F P
0 g
s
0 0 0 r
.60557 .18674 m .60623 .1813 L p .60537 .18754 L F P
0 g
s
0 0 0 r
.60479 .19177 m .60557 .18674 L p .60537 .18754 L F P
0 g
s
0 0 .091 r
.60557 .18674 m .60572 .19191 L p .60578 .18593 L F P
0 g
s
.769 .677 .128 r
.60623 .1813 m .60557 .18674 L p .60612 .17991 L F P
0 g
s
.769 .677 .128 r
.60581 .18187 m .60639 .17646 L p .60586 .18311 L F P
0 g
s
.769 .677 .128 r
.60557 .18674 m .60581 .18187 L p .60586 .18311 L F P
0 g
s
0 0 .091 r
.60572 .19191 m .60597 .18704 L .60581 .18187 L p F P
0 g
s
0 0 .026 r
.60581 .18187 m .60597 .18704 L p .60578 .18084 L F P
0 g
s
0 0 .026 r
.6057 .17829 m .60581 .18187 L p .60578 .18084 L F P
0 g
s
0 0 .091 r
.60581 .18187 m .60557 .18674 L p .60578 .18593 L F P
0 g
s
.769 .677 .128 r
.60639 .17646 m .60623 .1813 L p .60612 .17991 L F P
0 g
s
0 0 .013 r
.60552 .18631 m .60442 .19066 L .60397 .19508 L p F P
0 g
s
0 0 0 r
.60369 .19689 m .60397 .19508 L .60442 .19066 L p F P
0 g
s
0 0 .354 r
.60385 .20205 m .60268 .20716 L .60348 .21211 L p F P
0 g
s
0 0 .228 r
.60268 .20716 m .60385 .20205 L .60369 .19689 L p F P
0 g
s
.441 .438 .759 r
.63124 .33316 m .62646 .33912 L .63423 .34206 L p F P
0 g
s
.452 .431 .744 r
.62411 .33003 m .63124 .33316 L .62646 .33912 L p F P
0 g
s
.523 .62 .89 r
.70027 .17746 m .69101 .17753 L .68809 .17266 L p F P
0 g
s
.399 .463 .81 r
.77878 .25455 m .77586 .25344 L .77295 .24665 L p F P
0 g
s
.829 .954 .898 r
.61995 .16584 m .62003 .16102 L p .6113 .17042 L F P
0 g
s
.776 .828 .892 r
.62228 .15934 m .62003 .16102 L .61995 .16584 L p F P
0 g
s
.776 .828 .892 r
.61995 .16584 m .62522 .16232 L .62228 .15934 L p F P
0 g
s
.487 .571 .866 r
.72731 .19918 m .72372 .19883 L .72478 .19443 L closepath p F P
0 g
s
.493 .58 .87 r
.72439 .19373 m .72478 .19443 L .72372 .19883 L p F P
0 g
s
.947 .949 .639 r
.6113 .17042 m .6112 .17401 L .60748 .18046 L p F P
0 g
s
.678 .855 .967 r
.75425 .42694 m .7515 .42972 L p .74074 .43053 L F P
0 g
s
.706 .874 .96 r
.7515 .42972 m .75425 .42694 L .75551 .42789 L closepath p F P
0 g
s
.547 .645 .898 r
.67299 .16881 m .68517 .16785 L p .68442 .17287 L F P
0 g
s
.556 .648 .896 r
.68517 .16785 m .67299 .16881 L .67006 .16424 L p F P
0 g
s
.643 .718 .902 r
.65208 .15754 m .64008 .16077 L .63713 .15699 L p F P
0 g
s
.7 .758 .897 r
.62522 .16232 m .63713 .15699 L .64008 .16077 L p F P
0 g
s
.632 .709 .902 r
.64008 .16077 m .65208 .15754 L .65502 .16174 L p F P
0 g
s
.554 .574 .829 r
.67967 .41079 m .67471 .41089 L .67169 .40466 L p F P
0 g
s
.224 .235 .66 r
.6074 .25301 m .60591 .25622 L .60919 .26042 L p F P
0 g
s
.208 .216 .648 r
.60605 .24743 m .60541 .24648 L p .60591 .25622 L F P
0 g
s
.208 .216 .648 r
.60591 .25622 m .6074 .25301 L .60605 .24743 L p F P
0 g
s
.339 .34 .715 r
.61546 .28349 m .61207 .28914 L .61694 .2929 L p F P
0 g
s
.319 .314 .697 r
.61207 .28914 m .61546 .28349 L .61109 .27959 L p F P
0 g
s
.437 .506 .833 r
.76702 .23346 m .75914 .23132 L p .76635 .23884 L F P
0 g
s
.428 .503 .834 r
.75914 .23132 m .76702 .23346 L .76409 .22719 L p F P
0 g
s
.428 .503 .834 r
.76409 .22719 m .76065 .22625 L .75914 .23132 L p F P
0 g
s
.319 .345 .731 r
.80131 .29267 m .79909 .29728 L .80398 .30116 L p F P
0 g
s
.343 .374 .749 r
.80096 .29164 m .79622 .28836 L p .79909 .29728 L F P
0 g
s
.343 .374 .749 r
.79909 .29728 m .80131 .29267 L .80096 .29164 L p F P
0 g
s
.536 .557 .824 r
.67169 .40466 m .66809 .40455 L .67051 .40213 L closepath p F P
0 g
s
.54 .546 .81 r
.66866 .39819 m .67051 .40213 L .66809 .40455 L p F P
0 g
s
.499 .595 .881 r
.71291 .18786 m .70911 .18765 L .7062 .18255 L p F P
0 g
s
.612 .713 .917 r
.71083 .42963 m .72299 .42713 L .72583 .43095 L p F P
0 g
s
.603 .671 .888 r
.72013 .42303 m .72299 .42713 L .71083 .42963 L p F P
0 g
s
.603 .671 .888 r
.71483 .42394 m .72013 .42303 L p .71083 .42963 L F P
0 g
s
.603 .671 .888 r
.71083 .42963 m .71013 .42854 L .71483 .42394 L p F P
0 g
s
.587 .677 .903 r
.66405 .1651 m .67006 .16424 L .66712 .15972 L p F P
0 g
s
.587 .677 .903 r
.66712 .15972 m .66469 .16012 L .66405 .1651 L p F P
0 g
s
.58 .681 .91 r
.65502 .16174 m .66469 .16012 L .66405 .1651 L p F P
0 g
s
.72 .772 .894 r
.63713 .15699 m .62522 .16232 L .62228 .15934 L p F P
0 g
s
0 0 0 r
.80088 .38464 m .79848 .38787 L .79534 .39436 L p F P
0 g
s
.425 .422 .752 r
.62853 .32421 m .62411 .33003 L .63124 .33316 L p F P
0 g
s
.438 .416 .737 r
.6285 .32411 m .62853 .32421 L .62411 .33003 L p F P
0 g
s
.438 .416 .737 r
.62204 .32085 m .6285 .32411 L p .62411 .33003 L F P
0 g
s
.51 .509 .791 r
.6576 .38389 m .65036 .38293 L .6487 .37885 L p F P
0 g
s
.754 .992 .8 r
.77936 .41276 m .78351 .40902 L .7809 .41243 L closepath p F P
0 g
s
.759 .969 .688 r
.79079 .40128 m .78351 .40902 L .7809 .41243 L p F P
0 g
s
.106 .039 .489 r
.80788 .35659 m .80755 .35455 L .80764 .3544 L closepath p F P
0 g
s
.747 .883 .941 r
.75425 .42694 m .75551 .42789 L .76749 .42125 L p F P
0 g
s
.172 .178 .624 r
.60516 .23665 m .60413 .23894 L .60567 .24586 L p F P
0 g
s
.152 .165 .618 r
.60541 .24648 m .60567 .24586 L .60413 .23894 L p F P
0 g
s
.545 .634 .89 r
.68809 .17266 m .68442 .17287 L .68527 .16802 L closepath p F P
0 g
s
.547 .645 .898 r
.68517 .16785 m .68527 .16802 L .68442 .17287 L p F P
0 g
s
.419 .487 .823 r
.76996 .23997 m .76635 .23884 L .76769 .23489 L closepath p F P
0 g
s
.437 .506 .833 r
.76635 .23884 m .76769 .23489 L .76702 .23346 L p F P
0 g
s
.074 .016 .48 r
.80764 .3544 m .8106 .34932 L p .80839 .3598 L F P
0 g
s
.074 .016 .48 r
.80839 .3598 m .80788 .35659 L .80764 .3544 L p F P
0 g
s
.128 .088 .54 r
.80764 .3544 m .8106 .34932 L .8091 .34429 L p F P
0 g
s
.334 .369 .749 r
.80096 .29164 m .79622 .28836 L .79828 .28388 L closepath p F P
0 g
s
.357 .396 .765 r
.79786 .28273 m .79275 .27963 L p .79622 .28836 L F P
0 g
s
.357 .396 .765 r
.79622 .28836 m .79828 .28388 L .79786 .28273 L p F P
0 g
s
.219 .206 .63 r
.81013 .32435 m .80721 .3296 L .80995 .33422 L p F P
0 g
s
.254 .25 .661 r
.80721 .3296 m .81013 .32435 L .80679 .31993 L p F P
0 g
s
.577 .646 .882 r
.69283 .42165 m .70502 .42035 L .70794 .42512 L p F P
0 g
s
.57 .615 .858 r
.70209 .41535 m .70502 .42035 L .69283 .42165 L p F P
0 g
s
.57 .615 .858 r
.69514 .41587 m .70209 .41535 L p .69283 .42165 L F P
0 g
s
.57 .615 .858 r
.69283 .42165 m .6916 .41941 L .69514 .41587 L p F P
0 g
s
.588 .689 .912 r
.66469 .16012 m .65502 .16174 L .65208 .15754 L p F P
0 g
s
0 .011 .526 r
.60479 .21691 m .60313 .22216 L .60498 .22679 L p F P
0 g
s
0 0 .479 r
.60313 .22216 m .60479 .21691 L .60348 .21211 L p F P
0 g
s
.602 .67 .888 r
.71013 .42854 m .70794 .42512 L .71483 .42394 L closepath p F P
0 g
s
.041 0 .411 r
.80848 .36436 m .80825 .36003 L p .80488 .37065 L F P
0 g
s
.041 0 .411 r
.80488 .37065 m .80848 .36528 L .80848 .36436 L p F P
0 g
s
0 0 .298 r
.80848 .36528 m .80488 .37065 L .80408 .37641 L p F P
0 g
s
.51 .509 .791 r
.6487 .37885 m .65138 .37601 L p .6576 .38389 L F P
0 g
s
.498 .501 .791 r
.6487 .37885 m .64727 .37531 L .65138 .37601 L closepath p F P
0 g
s
.399 .463 .81 r
.77295 .24665 m .77298 .24656 L p .77878 .25455 L F P
0 g
s
.41 .479 .82 r
.77295 .24665 m .7729 .24654 L .77298 .24656 L closepath p F P
0 g
s
.408 .48 .822 r
.77298 .24656 m .7729 .24654 L .76996 .23997 L p F P
0 g
s
.349 .392 .764 r
.79786 .28273 m .79275 .27963 L .79491 .27465 L closepath p F P
0 g
s
.371 .417 .779 r
.7948 .27436 m .78868 .27108 L p .79275 .27963 L F P
0 g
s
.371 .417 .779 r
.79275 .27963 m .79491 .27465 L .7948 .27436 L p F P
0 g
s
.399 .463 .81 r
.77298 .24656 m .78051 .24948 L .77878 .25455 L p F P
0 g
s
.397 .466 .814 r
.77454 .24152 m .77298 .24656 L .78051 .24948 L p F P
0 g
s
.408 .48 .822 r
.76996 .23997 m .77454 .24152 L .77298 .24656 L p F P
0 g
s
.309 .314 .702 r
.61338 .27545 m .61109 .27959 L .61546 .28349 L p F P
0 g
s
.3 .303 .695 r
.61255 .27246 m .61014 .27001 L p .61109 .27959 L F P
0 g
s
.3 .303 .695 r
.61109 .27959 m .61338 .27545 L .61255 .27246 L p F P
0 g
s
.407 .405 .745 r
.6285 .32411 m .62204 .32085 L .62572 .31574 L closepath p F P
0 g
s
.422 .401 .73 r
.62534 .31456 m .62572 .31574 L .62204 .32085 L p F P
0 g
s
.422 .401 .73 r
.62019 .31159 m .62534 .31456 L p .62204 .32085 L F P
0 g
s
.947 .949 .639 r
.61056 .17044 m .6113 .17042 L p .60748 .18046 L F P
0 g
s
.947 .949 .639 r
.60748 .18046 m .60798 .17551 L .61056 .17044 L p F P
0 g
s
.473 .554 .858 r
.74271 .2065 m .73431 .20522 L p .74398 .21192 L F P
0 g
s
.465 .553 .861 r
.73431 .20522 m .74271 .2065 L .73979 .20088 L p F P
0 g
s
.465 .553 .861 r
.73979 .20088 m .73538 .20022 L .73431 .20522 L p F P
0 g
s
.472 .561 .864 r
.72731 .19918 m .73538 .20022 L .73431 .20522 L p F P
0 g
s
.179 .196 .64 r
.60605 .24743 m .60541 .24648 L .60567 .24586 L closepath p F P
0 g
s
.628 .748 .934 r
.73796 .42747 m .72583 .43095 L .72299 .42713 L p F P
0 g
s
.641 .775 .945 r
.72583 .43095 m .73796 .42747 L .74074 .43053 L p F P
0 g
s
0 0 .182 r
.60397 .19508 m .60369 .19689 L .60385 .20205 L p F P
0 g
s
.445 .529 .849 r
.75266 .21897 m .74853 .2181 L .74562 .21222 L p F P
0 g
s
.36 .409 .777 r
.78868 .27108 m .7948 .27436 L .79177 .2665 L p F P
0 g
s
.36 .409 .777 r
.79177 .2665 m .79076 .26594 L .78868 .27108 L p F P
0 g
s
.378 .43 .789 r
.78868 .27108 m .79076 .26594 L .78401 .26273 L p F P
0 g
s
.472 .563 .866 r
.73538 .20022 m .72731 .19918 L .72478 .19443 L p F P
0 g
s
.387 .445 .799 r
.77878 .25455 m .78593 .25762 L .78401 .26273 L p F P
0 g
s
.391 .454 .806 r
.78051 .24948 m .77878 .25455 L .78593 .25762 L p F P
0 g
s
.678 .855 .967 r
.74074 .43053 m .75282 .42579 L .75425 .42694 L p F P
0 g
s
.663 .822 .96 r
.75282 .42579 m .74074 .43053 L .73796 .42747 L p F P
0 g
s
.379 .435 .793 r
.78593 .25762 m .78401 .26273 L .79076 .26594 L p F P
0 g
s
.5 .497 .785 r
.65138 .37601 m .64727 .37531 L .64485 .36918 L p F P
0 g
s
.076 .018 .48 r
.80825 .36003 m .80788 .35659 L .80839 .3598 L closepath p F P
0 g
s
.569 .614 .857 r
.6916 .41941 m .68987 .41627 L .69514 .41587 L closepath p F P
0 g
s
.554 .574 .829 r
.67169 .40466 m .68391 .40482 L p .67967 .41079 L F P
0 g
s
.533 .555 .824 r
.6809 .39873 m .68391 .40482 L .67169 .40466 L p F P
0 g
s
.533 .555 .824 r
.67411 .39843 m .6809 .39873 L p .67169 .40466 L F P
0 g
s
.533 .555 .824 r
.67169 .40466 m .67051 .40213 L .67411 .39843 L p F P
0 g
s
.225 .227 .651 r
.60567 .24586 m .60784 .24103 L p .60851 .25074 L F P
0 g
s
.225 .227 .651 r
.60851 .25074 m .60605 .24743 L .60567 .24586 L p F P
0 g
s
.172 .178 .624 r
.60567 .24586 m .60784 .24103 L .60516 .23665 L p F P
0 g
s
.495 .589 .878 r
.71291 .18786 m .72149 .18846 L .71858 .18322 L p F P
0 g
s
.495 .589 .878 r
.71858 .18322 m .71366 .18291 L .71291 .18786 L p F P
0 g
s
.499 .595 .881 r
.7062 .18255 m .71366 .18291 L .71291 .18786 L p F P
0 g
s
.661 .85 .45 r
.79094 .40108 m .79102 .40098 L .79534 .39436 L p F P
0 g
s
.661 .85 .45 r
.79534 .39436 m .79936 .38892 L p .79094 .40108 L F P
0 g
s
0 0 0 r
.8001 .38751 m .80088 .38464 L p .79534 .39436 L F P
0 g
s
0 0 0 r
.79534 .39436 m .79936 .38892 L .8001 .38751 L p F P
0 g
s
.223 .226 .651 r
.6074 .25301 m .60605 .24743 L .60851 .25074 L closepath p F P
0 g
s
.28 .287 .689 r
.80737 .3123 m .80571 .31045 L p .80679 .31993 L F P
0 g
s
.28 .287 .689 r
.80679 .31993 m .80858 .31658 L .80737 .3123 L p F P
0 g
s
.248 .248 .662 r
.80858 .31658 m .80679 .31993 L .81013 .32435 L p F P
0 g
s
.55 .587 .844 r
.6869 .41065 m .67967 .41079 L .6844 .40579 L closepath p F P
0 g
s
.554 .574 .829 r
.68391 .40482 m .6844 .40579 L .67967 .41079 L p F P
0 g
s
.388 .387 .737 r
.62534 .31456 m .62019 .31159 L .62303 .30741 L closepath p F P
0 g
s
.384 .382 .733 r
.62216 .30466 m .6185 .30227 L p .62019 .31159 L F P
0 g
s
.384 .382 .733 r
.62019 .31159 m .62303 .30741 L .62216 .30466 L p F P
0 g
s
.518 .62 .893 r
.69745 .16762 m .70037 .17248 L .68809 .17266 L p F P
0 g
s
.518 .62 .893 r
.68528 .16784 m .69745 .16762 L p .68809 .17266 L F P
0 g
s
.518 .62 .893 r
.68809 .17266 m .68527 .16802 L .68528 .16784 L p F P
0 g
s
.523 .62 .89 r
.68809 .17266 m .70037 .17248 L p .70027 .17746 L F P
0 g
s
.486 .488 .784 r
.64485 .36918 m .64417 .36745 L .64607 .36785 L closepath p F P
0 g
s
.5 .497 .785 r
.64485 .36918 m .64607 .36785 L p .65138 .37601 L F P
0 g
s
.277 .286 .689 r
.61255 .27246 m .61014 .27001 L .61126 .26782 L closepath p F P
0 g
s
.268 .274 .681 r
.60931 .26056 m .60919 .26042 L p .61014 .27001 L F P
0 g
s
.268 .274 .681 r
.61014 .27001 m .61126 .26782 L .60931 .26056 L p F P
0 g
s
.714 .865 .953 r
.75282 .42579 m .75657 .42403 L .75425 .42694 L closepath p F P
0 g
s
.747 .883 .941 r
.76487 .41991 m .75657 .42403 L .75425 .42694 L p F P
0 g
s
.747 .883 .941 r
.76749 .42125 m .76487 .41991 L p .75425 .42694 L F P
0 g
s
0 0 .354 r
.60348 .21211 m .6046 .20702 L .60385 .20205 L p F P
0 g
s
0 0 .447 r
.6046 .20702 m .60348 .21211 L .60479 .21691 L p F P
0 g
s
.532 .554 .823 r
.67051 .40213 m .66866 .39819 L .67411 .39843 L closepath p F P
0 g
s
.131 .092 .543 r
.81212 .33904 m .8091 .34429 L .8106 .34932 L p F P
0 g
s
.181 .155 .591 r
.8091 .34429 m .81212 .33904 L .80995 .33422 L p F P
0 g
s
.489 .484 .779 r
.64607 .36785 m .64417 .36745 L .64123 .35977 L p F P
0 g
s
.556 .648 .896 r
.67006 .16424 m .68224 .16318 L .68517 .16785 L p F P
0 g
s
.559 .653 .898 r
.68224 .16318 m .67006 .16424 L .66712 .15972 L p F P
0 g
s
.457 .538 .852 r
.74562 .21222 m .74398 .21192 L .74449 .20998 L closepath p F P
0 g
s
.473 .554 .858 r
.74398 .21192 m .74449 .20998 L .74271 .2065 L p F P
0 g
s
.72 .971 .93 r
.77251 .41788 m .76749 .42125 L .76487 .41991 L p F P
0 g
s
.089 .108 .585 r
.60516 .23665 m .60717 .23132 L .60498 .22679 L p F P
0 g
s
.097 .131 .607 r
.60717 .23132 m .60516 .23665 L .60784 .24103 L p F P
0 g
s
.5 .598 .883 r
.71366 .18291 m .7062 .18255 L .70329 .17748 L p F P
0 g
s
.918 .973 .777 r
.61056 .17044 m .61157 .1691 L .6113 .17042 L closepath p F P
0 g
s
.829 .954 .898 r
.62003 .16102 m .61157 .1691 L .6113 .17042 L p F P
0 g
s
.236 .242 .663 r
.60851 .25074 m .6074 .25301 L .60925 .26031 L p F P
0 g
s
.224 .235 .66 r
.60919 .26042 m .60925 .26031 L .6074 .25301 L p F P
0 g
s
.405 .479 .823 r
.77454 .24152 m .76996 .23997 L .76769 .23489 L p F P
0 g
s
0 0 .237 r
.60479 .19177 m .60397 .19508 L .60413 .20027 L p F P
0 g
s
0 0 .182 r
.60385 .20205 m .60413 .20027 L .60397 .19508 L p F P
0 g
s
0 0 .013 r
.60397 .19508 m .60479 .19177 L .60552 .18631 L p F P
0 g
s
.603 .658 .877 r
.71483 .42394 m .70794 .42512 L .70502 .42035 L p F P
0 g
s
.571 .605 .849 r
.69514 .41587 m .68987 .41627 L .6869 .41065 L p F P
0 g
s
.367 .368 .728 r
.62216 .30466 m .6185 .30227 L .62045 .29922 L closepath p F P
0 g
s
.363 .362 .724 r
.61897 .2944 m .61694 .2929 L p .6185 .30227 L F P
0 g
s
.363 .362 .724 r
.6185 .30227 m .62045 .29922 L .61897 .2944 L p F P
0 g
s
.643 .718 .902 r
.63713 .15699 m .64913 .15341 L .65208 .15754 L p F P
0 g
s
.655 .728 .902 r
.64913 .15341 m .63713 .15699 L .63417 .15331 L p F P
0 g
s
.72 .772 .894 r
.62228 .15934 m .63417 .15331 L .63713 .15699 L p F P
0 g
s
.27 .281 .688 r
.80737 .3123 m .80571 .31045 L .80645 .309 L closepath p F P
0 g
s
.299 .316 .711 r
.80411 .30129 m .80398 .30116 L p .80571 .31045 L F P
0 g
s
.299 .316 .711 r
.80571 .31045 m .80645 .309 L .80411 .30129 L p F P
0 g
s
0 0 .399 r
.80848 .36436 m .80839 .3598 L .80825 .36003 L closepath p F P
0 g
s
.72 .971 .93 r
.77701 .4126 m .77251 .41788 L p .76487 .41991 L F P
0 g
s
.752 .991 .883 r
.77251 .41788 m .77701 .4126 L .77936 .41276 L closepath p F P
0 g
s
0 0 0 r
.79079 .40128 m .79094 .40108 L .79102 .40098 L closepath p F P
0 g
s
.721 .974 .738 r
.79094 .40108 m .79079 .40128 L .78351 .40902 L p F P
0 g
s
0 0 .148 r
.80088 .38464 m .80232 .38248 L .80408 .37641 L p F P
0 g
s
0 0 .128 r
.80766 .37106 m .80408 .37641 L .80232 .38248 L p F P
0 g
s
0 0 .298 r
.80408 .37641 m .80766 .37106 L .80848 .36528 L p F P
0 g
s
0 0 0 r
.8001 .38751 m .80232 .38248 L .80088 .38464 L closepath p F P
0 g
s
0 0 .369 r
.80839 .3598 m .81144 .35457 L p .80852 .36523 L F P
0 g
s
0 0 .369 r
.80852 .36523 m .80848 .36436 L .80839 .3598 L p F P
0 g
s
.074 .016 .48 r
.8106 .34932 m .81144 .35457 L .80839 .3598 L p F P
0 g
s
.489 .484 .779 r
.64123 .35977 m .64152 .35945 L p .64607 .36785 L F P
0 g
s
.474 .474 .777 r
.64123 .35977 m .64106 .35933 L .64152 .35945 L closepath p F P
0 g
s
.472 .563 .866 r
.72478 .19443 m .72489 .19378 L p .73538 .20022 L F P
0 g
s
.48 .573 .872 r
.72478 .19443 m .72439 .19373 L .72489 .19378 L closepath p F P
0 g
s
.661 .85 .45 r
.79456 .39592 m .79094 .40108 L p .79168 .40001 L F P
0 g
s
.661 .85 .45 r
.79936 .38892 m .79456 .39592 L p .79168 .40001 L F P
0 g
s
0 0 0 r
.79456 .39592 m .79814 .391 L .79985 .38824 L p F P
0 g
s
.808 .988 .729 r
.79456 .39592 m .79814 .391 L p .79732 .392 L F P
0 g
s
0 0 0 r
.79985 .38824 m .79936 .38892 L .79456 .39592 L p F P
0 g
s
.808 .988 .729 r
.78838 .40284 m .79456 .39592 L .79732 .392 L F
.703 .935 .625 r
.78867 .40273 m .79456 .39592 L .79094 .40108 L closepath p F P
0 g
s
.721 .974 .738 r
.78867 .40273 m .79094 .40108 L p .78351 .40902 L F P
0 g
s
.477 .471 .772 r
.64152 .35945 m .64106 .35933 L .63794 .35094 L p F P
0 g
s
.534 .549 .817 r
.67411 .39843 m .66866 .39819 L .66562 .39151 L p F P
0 g
s
.445 .529 .849 r
.74562 .21222 m .75388 .21396 L .75266 .21897 L p F P
0 g
s
.443 .53 .852 r
.75388 .21396 m .74562 .21222 L .74449 .20998 L p F P
0 g
s
.243 .256 .675 r
.60931 .26056 m .60919 .26042 L .60925 .26031 L closepath p F P
0 g
s
.5 .497 .785 r
.64607 .36785 m .65641 .37004 L p .65138 .37601 L F P
0 g
s
.473 .477 .781 r
.64607 .36785 m .65641 .37004 L .65332 .36241 L p F P
0 g
s
.473 .477 .781 r
.65332 .36241 m .65119 .36187 L .64607 .36785 L p F P
0 g
s
.489 .484 .779 r
.64152 .35945 m .65119 .36187 L .64607 .36785 L p F P
0 g
s
.278 .28 .682 r
.60925 .26031 m .61187 .25492 L p .61302 .26447 L F P
0 g
s
.278 .28 .682 r
.61302 .26447 m .60931 .26056 L .60925 .26031 L p F P
0 g
s
.236 .242 .663 r
.60925 .26031 m .61187 .25492 L .60851 .25074 L p F P
0 g
s
.435 .514 .841 r
.75266 .21897 m .76117 .22098 L p .76065 .22625 L F P
0 g
s
.435 .519 .846 r
.75266 .21897 m .76117 .22098 L .75825 .21499 L p F P
0 g
s
.435 .519 .846 r
.75825 .21499 m .75388 .21396 L .75266 .21897 L p F P
0 g
s
.275 .279 .683 r
.61126 .26782 m .60931 .26056 L .61302 .26447 L closepath p F P
0 g
s
.51 .509 .791 r
.65138 .37601 m .65949 .3774 L p .6576 .38389 L F P
0 g
s
.493 .507 .8 r
.65949 .3774 m .65138 .37601 L .65645 .37013 L closepath p F P
0 g
s
.5 .497 .785 r
.65641 .37004 m .65645 .37013 L .65138 .37601 L p F P
0 g
s
.467 .479 .787 r
.64654 .35347 m .64152 .35945 L .65119 .36187 L p F P
0 g
s
.477 .471 .772 r
.63794 .35094 m .64654 .35347 L .64152 .35945 L p F P
0 g
s
.816 .996 .857 r
.77701 .4126 m .77936 .41276 L .78351 .40902 L p F P
0 g
s
.881 .933 .849 r
.61962 .15683 m .62003 .16102 L .61157 .1691 L p F P
0 g
s
.8 .844 .884 r
.62003 .16102 m .61962 .15683 L .62228 .15934 L closepath p F P
0 g
s
.478 .576 .875 r
.72489 .19378 m .72439 .19373 L .72149 .18846 L p F P
0 g
s
.816 .996 .857 r
.78351 .40902 m .78786 .4035 L p .77701 .4126 L F P
0 g
s
.721 .974 .738 r
.78351 .40902 m .78786 .4035 L .78867 .40273 L p F P
0 g
s
.519 .611 .884 r
.70329 .17748 m .70027 .17746 L .70093 .17343 L closepath p F P
0 g
s
.523 .62 .89 r
.70037 .17248 m .70093 .17343 L .70027 .17746 L p F P
0 g
s
.588 .689 .912 r
.65208 .15754 m .66418 .15529 L p .66469 .16012 L F P
0 g
s
.604 .69 .904 r
.66418 .15529 m .65208 .15754 L .64913 .15341 L p F P
0 g
s
.881 .933 .849 r
.61933 .15658 m .61962 .15683 L p .61157 .1691 L F P
0 g
s
.881 .933 .849 r
.61157 .1691 m .6122 .16408 L .61933 .15658 L p F P
0 g
s
.892 .988 .744 r
.61157 .1691 m .6122 .16408 L p .60797 .17118 L F P
0 g
s
.892 .988 .744 r
.60797 .17118 m .61056 .17044 L .61157 .1691 L p F P
0 g
s
.726 .831 .93 r
.61962 .15683 m .62228 .15934 L .63417 .15331 L p F P
0 g
s
.472 .563 .866 r
.72489 .19378 m .73641 .19522 L .73538 .20022 L p F P
0 g
s
.48 .572 .871 r
.72558 .18887 m .72489 .19378 L .73641 .19522 L p F P
0 g
s
.478 .576 .875 r
.72149 .18846 m .72558 .18887 L .72489 .19378 L p F P
0 g
s
0 0 .328 r
.60413 .20027 m .60385 .20205 L .6046 .20702 L p F P
0 g
s
.458 .455 .767 r
.63794 .35094 m .63762 .35084 L .63782 .3506 L closepath p F P
0 g
s
.456 .452 .766 r
.6348 .34227 m .63423 .34206 L p .63762 .35084 L F P
0 g
s
.456 .452 .766 r
.63762 .35084 m .63782 .3506 L .6348 .34227 L p F P
0 g
s
.52 .521 .797 r
.6576 .38389 m .66256 .38456 L p .66493 .39144 L F P
0 g
s
.505 .52 .805 r
.66256 .38456 m .6576 .38389 L .66077 .38038 L closepath p F P
0 g
s
.51 .509 .791 r
.65949 .3774 m .66077 .38038 L .6576 .38389 L p F P
0 g
s
0 .049 .56 r
.60649 .22159 m .60498 .22679 L .60717 .23132 L p F P
0 g
s
0 .011 .526 r
.60498 .22679 m .60649 .22159 L .60479 .21691 L p F P
0 g
s
.344 .348 .719 r
.61897 .2944 m .61694 .2929 L .61798 .29116 L closepath p F P
0 g
s
.339 .34 .715 r
.61577 .28375 m .61546 .28349 L p .61694 .2929 L F P
0 g
s
.339 .34 .715 r
.61694 .2929 m .61798 .29116 L .61577 .28375 L p F P
0 g
s
.29 .31 .71 r
.80411 .30129 m .80398 .30116 L .80404 .30104 L closepath p F P
0 g
s
.319 .345 .731 r
.80398 .30116 m .80404 .30104 L .80131 .29267 L p F P
0 g
s
.176 .152 .591 r
.81197 .33063 m .80995 .33422 L .81212 .33904 L p F P
0 g
s
.219 .206 .63 r
.81081 .3255 m .81013 .32435 L p .80995 .33422 L F P
0 g
s
.219 .206 .63 r
.80995 .33422 m .81197 .33063 L .81081 .3255 L p F P
0 g
s
.965 .939 .671 r
.60798 .17551 m .60797 .17118 L .61056 .17044 L closepath p F P
0 g
s
.27 .297 .706 r
.80404 .30104 m .80619 .29606 L p .80813 .3053 L F P
0 g
s
.27 .297 .706 r
.80813 .3053 m .80411 .30129 L .80404 .30104 L p F P
0 g
s
.291 .327 .727 r
.80157 .29208 m .80131 .29267 L .80404 .30104 L p F P
0 g
s
.291 .327 .727 r
.80404 .30104 m .80619 .29606 L .80157 .29208 L p F P
0 g
s
.417 .495 .832 r
.76769 .23489 m .76702 .23346 L .76801 .23375 L closepath p F P
0 g
s
.405 .479 .823 r
.76769 .23489 m .76801 .23375 L p .77454 .24152 L F P
0 g
s
.271 .297 .706 r
.80645 .309 m .80411 .30129 L .80813 .3053 L closepath p F P
0 g
s
.465 .46 .767 r
.64654 .35347 m .63794 .35094 L .63782 .3506 L p F P
0 g
s
.465 .46 .767 r
.63782 .3506 m .64246 .34489 L p .64654 .35347 L F P
0 g
s
.449 .448 .766 r
.63782 .3506 m .6348 .34227 L .64246 .34489 L closepath p F P
0 g
s
.628 .748 .934 r
.72299 .42713 m .73516 .42408 L .73796 .42747 L p F P
0 g
s
.615 .724 .923 r
.73516 .42408 m .72299 .42713 L .72013 .42303 L p F P
0 g
s
.452 .543 .858 r
.74449 .20998 m .74271 .2065 L .7451 .20693 L closepath p F P
0 g
s
.443 .53 .852 r
.74449 .20998 m .7451 .20693 L p .75388 .21396 L F P
0 g
s
.318 .358 .746 r
.80131 .29267 m .80096 .29164 L .80157 .29208 L closepath p F P
0 g
s
.307 .306 .694 r
.61126 .26782 m .61302 .26447 L p .6142 .274 L F P
0 g
s
.307 .306 .694 r
.6142 .274 m .61255 .27246 L .61126 .26782 L p F P
0 g
s
.318 .358 .746 r
.80157 .29208 m .80096 .29164 L .79828 .28388 L p F P
0 g
s
.697 .844 .953 r
.75657 .42403 m .75282 .42579 L .7501 .42324 L p F P
0 g
s
.663 .822 .96 r
.73796 .42747 m .7501 .42324 L .75282 .42579 L p F P
0 g
s
.249 .267 .684 r
.80645 .309 m .80813 .3053 L p .80946 .31473 L F P
0 g
s
.249 .267 .684 r
.80946 .31473 m .80737 .3123 L .80645 .309 L p F P
0 g
s
.588 .676 .901 r
.66712 .15972 m .66469 .16012 L .66522 .15685 L closepath p F P
0 g
s
.588 .689 .912 r
.66418 .15529 m .66522 .15685 L .66469 .16012 L p F P
0 g
s
.441 .438 .759 r
.63166 .33334 m .63124 .33316 L p .63423 .34206 L F P
0 g
s
.441 .438 .759 r
.63423 .34206 m .63458 .34164 L .63166 .33334 L p F P
0 g
s
.443 .441 .761 r
.6348 .34227 m .63423 .34206 L .63458 .34164 L closepath p F P
0 g
s
.427 .504 .835 r
.76409 .22719 m .76065 .22625 L .76179 .22228 L closepath p F P
0 g
s
.435 .514 .841 r
.76117 .22098 m .76179 .22228 L .76065 .22625 L p F P
0 g
s
.415 .496 .834 r
.76801 .23375 m .76702 .23346 L .76409 .22719 L p F P
0 g
s
.304 .305 .696 r
.61338 .27545 m .61255 .27246 L .6142 .274 L closepath p F P
0 g
s
.516 .532 .811 r
.66562 .39151 m .66493 .39144 L .66538 .39096 L closepath p F P
0 g
s
.52 .521 .797 r
.66256 .38456 m .66538 .39096 L .66493 .39144 L p F P
0 g
s
.25 .267 .683 r
.80858 .31658 m .80737 .3123 L .80946 .31473 L closepath p F P
0 g
s
.318 .358 .746 r
.79828 .28388 m .79856 .28319 L p .80157 .29208 L F P
0 g
s
.334 .381 .762 r
.79828 .28388 m .79786 .28273 L .79856 .28319 L closepath p F P
0 g
s
.53 .631 .896 r
.68527 .16802 m .68517 .16785 L .68528 .16784 L closepath p F P
0 g
s
.171 .203 .653 r
.61075 .24535 m .60851 .25074 L .61187 .25492 L p F P
0 g
s
.225 .227 .651 r
.60784 .24103 m .61075 .24535 L .60851 .25074 L p F P
0 g
s
.292 .33 .73 r
.80364 .28699 m .80157 .29208 L .80619 .29606 L p F P
0 g
s
.318 .358 .746 r
.79856 .28319 m .80364 .28699 L .80157 .29208 L p F P
0 g
s
.649 .79 .95 r
.7501 .42324 m .73796 .42747 L .73516 .42408 L p F P
0 g
s
.452 .446 .761 r
.64246 .34489 m .6348 .34227 L .63458 .34164 L p F P
0 g
s
.333 .381 .762 r
.79856 .28319 m .79786 .28273 L .79491 .27465 L p F P
0 g
s
.435 .434 .759 r
.63458 .34164 m .63166 .33334 L .63884 .33617 L closepath p F P
0 g
s
.452 .446 .761 r
.63458 .34164 m .63884 .33617 L p .64246 .34489 L F P
0 g
s
.312 .315 .702 r
.6142 .274 m .61338 .27545 L .61561 .28322 L p F P
0 g
s
.309 .314 .702 r
.61546 .28349 m .61561 .28322 L .61338 .27545 L p F P
0 g
s
.529 .635 .899 r
.68528 .16784 m .68517 .16785 L .68224 .16318 L p F P
0 g
s
.529 .635 .899 r
.68224 .16318 m .68536 .16306 L .68528 .16784 L p F P
0 g
s
.528 .632 .898 r
.68528 .16784 m .69745 .16762 L .69452 .1628 L p F P
0 g
s
.528 .632 .898 r
.69452 .1628 m .68536 .16306 L .68528 .16784 L p F P
0 g
s
.534 .549 .817 r
.66562 .39151 m .67787 .39245 L p .67411 .39843 L F P
0 g
s
.512 .53 .811 r
.67484 .38593 m .67787 .39245 L .66562 .39151 L p F P
0 g
s
.512 .53 .811 r
.67042 .38543 m .67484 .38593 L p .66562 .39151 L F P
0 g
s
.512 .53 .811 r
.66562 .39151 m .66538 .39096 L .67042 .38543 L p F P
0 g
s
.428 .426 .755 r
.63166 .33334 m .63124 .33316 L .63149 .33284 L closepath p F P
0 g
s
.425 .422 .752 r
.63124 .33316 m .63149 .33284 L .62853 .32421 L p F P
0 g
s
.568 .621 .865 r
.70209 .41535 m .69514 .41587 L .69959 .41092 L closepath p F P
0 g
s
.571 .605 .849 r
.69914 .41012 m .69959 .41092 L .69514 .41587 L p F P
0 g
s
.571 .605 .849 r
.6869 .41065 m .69914 .41012 L p .69514 .41587 L F P
0 g
s
.215 .225 .655 r
.80946 .31473 m .80858 .31658 L .81042 .3238 L p F P
0 g
s
.248 .248 .662 r
.81013 .32435 m .81042 .3238 L .80858 .31658 L p F P
0 g
s
.319 .325 .71 r
.61577 .28375 m .61546 .28349 L .61561 .28322 L closepath p F P
0 g
s
.55 .587 .844 r
.69617 .40463 m .69914 .41012 L .6869 .41065 L p F P
0 g
s
.55 .587 .844 r
.68534 .4048 m .69617 .40463 L p .6869 .41065 L F P
0 g
s
.55 .587 .844 r
.6869 .41065 m .6844 .40579 L .68534 .4048 L p F P
0 g
s
.511 .528 .81 r
.66538 .39096 m .66256 .38456 L .67042 .38543 L closepath p F P
0 g
s
.5 .598 .883 r
.70329 .17748 m .7144 .17795 L .71366 .18291 L p F P
0 g
s
.501 .601 .885 r
.7144 .17795 m .70329 .17748 L .70093 .17343 L p F P
0 g
s
.405 .479 .823 r
.76801 .23375 m .77603 .23649 L .77454 .24152 L p F P
0 g
s
.411 .488 .829 r
.7693 .22876 m .76801 .23375 L .77603 .23649 L p F P
0 g
s
.415 .496 .834 r
.76409 .22719 m .7693 .22876 L .76801 .23375 L p F P
0 g
s
.697 .844 .953 r
.7501 .42324 m .76171 .41829 L .75657 .42403 L p F P
0 g
s
.719 .892 .959 r
.76221 .41807 m .76171 .41829 L .75657 .42403 L p F P
0 g
s
.719 .892 .959 r
.75657 .42403 m .76487 .41991 L .76221 .41807 L p F P
0 g
s
.601 .678 .896 r
.72013 .42303 m .71483 .42394 L .71816 .42006 L closepath p F P
0 g
s
.603 .658 .877 r
.71724 .41866 m .71816 .42006 L .71483 .42394 L p F P
0 g
s
.603 .658 .877 r
.70502 .42035 m .71724 .41866 L p .71483 .42394 L F P
0 g
s
.438 .432 .755 r
.63884 .33617 m .63166 .33334 L .63149 .33284 L p F P
0 g
s
.342 .341 .713 r
.61561 .28322 m .61861 .27789 L p .62033 .28725 L F P
0 g
s
.342 .341 .713 r
.62033 .28725 m .61577 .28375 L .61561 .28322 L p F P
0 g
s
.312 .315 .702 r
.61561 .28322 m .61861 .27789 L .6142 .274 L p F P
0 g
s
.438 .432 .755 r
.63149 .33284 m .6356 .32731 L p .63884 .33617 L F P
0 g
s
.42 .419 .752 r
.62858 .32415 m .62853 .32421 L .63149 .33284 L p F P
0 g
s
.42 .419 .752 r
.63149 .33284 m .6356 .32731 L .62858 .32415 L p F P
0 g
s
.339 .341 .715 r
.61798 .29116 m .61577 .28375 L .62033 .28725 L closepath p F P
0 g
s
0 0 0 r
.80232 .38248 m .80581 .37716 L p .79985 .38824 L F P
0 g
s
0 0 0 r
.79985 .38824 m .8001 .38751 L .80232 .38248 L p F P
0 g
s
0 0 .128 r
.80232 .38248 m .80581 .37716 L .80766 .37106 L p F P
0 g
s
.311 .357 .749 r
.80051 .27811 m .79856 .28319 L .80364 .28699 L p F P
0 g
s
.333 .381 .762 r
.79498 .27447 m .80051 .27811 L .79856 .28319 L p F P
0 g
s
.333 .381 .762 r
.79491 .27465 m .79498 .27447 L p .79856 .28319 L F P
0 g
s
.576 .653 .888 r
.71724 .41866 m .70502 .42035 L .70209 .41535 L p F P
0 g
s
.559 .653 .898 r
.66712 .15972 m .67931 .15856 L .68224 .16318 L p F P
0 g
s
.553 .659 .907 r
.67637 .15398 m .67931 .15856 L .66712 .15972 L p F P
0 g
s
.553 .659 .907 r
.66513 .15518 m .67637 .15398 L p .66712 .15972 L F P
0 g
s
.553 .659 .907 r
.66712 .15972 m .66522 .15685 L .66513 .15518 L p F P
0 g
s
.067 .012 .479 r
.81367 .34406 m .8106 .34932 L .81144 .35457 L p F P
0 g
s
.131 .092 .543 r
.8106 .34932 m .81367 .34406 L .81212 .33904 L p F P
0 g
s
0 0 .514 r
.60576 .2123 m .60479 .21691 L .60649 .22159 L p F P
0 g
s
0 0 .447 r
.60544 .21029 m .6046 .20702 L p .60479 .21691 L F P
0 g
s
0 0 .447 r
.60479 .21691 m .60576 .2123 L .60544 .21029 L p F P
0 g
s
.911 .846 .395 r
.60797 .17118 m .60798 .17551 L .60623 .1813 L p F P
0 g
s
0 0 .375 r
.60494 .19693 m .60413 .20027 L .60476 .20605 L p F P
0 g
s
0 0 .237 r
.60413 .20027 m .60494 .19693 L .60479 .19177 L p F P
0 g
s
0 0 .328 r
.6046 .20702 m .60476 .20605 L .60413 .20027 L p F P
0 g
s
.028 0 .406 r
.80848 .36528 m .80852 .36523 L .80848 .36436 L closepath p F P
0 g
s
.208 .199 .628 r
.81081 .3255 m .81013 .32435 L .81042 .3238 L closepath p F P
0 g
s
.466 .555 .862 r
.73538 .20022 m .73979 .20088 L .73688 .19528 L p F P
0 g
s
.466 .555 .862 r
.73688 .19528 m .73641 .19522 L .73538 .20022 L p F P
0 g
s
.348 .403 .777 r
.79491 .27465 m .7948 .27436 L .79498 .27447 L closepath p F P
0 g
s
.399 .472 .819 r
.77603 .23649 m .77454 .24152 L .7822 .2444 L p F P
0 g
s
.397 .466 .814 r
.78051 .24948 m .7822 .2444 L .77454 .24152 L p F P
0 g
s
.451 .544 .86 r
.7451 .20693 m .74271 .2065 L .73979 .20088 L p F P
0 g
s
.347 .403 .778 r
.79498 .27447 m .7948 .27436 L .79177 .2665 L p F P
0 g
s
.365 .361 .722 r
.61798 .29116 m .62033 .28725 L p .62214 .29657 L F P
0 g
s
.365 .361 .722 r
.62214 .29657 m .61897 .2944 L .61798 .29116 L p F P
0 g
s
.417 .414 .749 r
.62853 .32421 m .6285 .32411 L .62858 .32415 L closepath p F P
0 g
s
.42 .413 .745 r
.62858 .32415 m .6285 .32411 L .62572 .31574 L p F P
0 g
s
0 0 .172 r
.60557 .18674 m .60479 .19177 L .60494 .19693 L p F P
0 g
s
.361 .361 .724 r
.62045 .29922 m .61897 .2944 L .62214 .29657 L closepath p F P
0 g
s
.404 .418 .761 r
.63268 .31836 m .62858 .32415 L .6356 .32731 L p F P
0 g
s
.42 .413 .745 r
.62622 .31503 m .63268 .31836 L .62858 .32415 L p F P
0 g
s
.42 .413 .745 r
.62572 .31574 m .62622 .31503 L p .62858 .32415 L F P
0 g
s
.327 .381 .765 r
.79679 .26941 m .79498 .27447 L .80051 .27811 L p F P
0 g
s
.347 .403 .778 r
.79177 .2665 m .79679 .26941 L .79498 .27447 L p F P
0 g
s
.385 .379 .73 r
.62045 .29922 m .62214 .29657 L p .6241 .30583 L F P
0 g
s
.385 .379 .73 r
.6241 .30583 m .62216 .30466 L .62045 .29922 L p F P
0 g
s
.4 .398 .741 r
.62572 .31574 m .62534 .31456 L .62622 .31503 L closepath p F P
0 g
s
.403 .397 .738 r
.62622 .31503 m .62534 .31456 L .62303 .30741 L p F P
0 g
s
.381 .38 .733 r
.62303 .30741 m .62216 .30466 L .6241 .30583 L closepath p F P
0 g
s
.403 .397 .738 r
.62303 .30741 m .6241 .30583 L p .62622 .31503 L F P
0 g
s
.391 .454 .806 r
.78578 .2517 m .78051 .24948 L p .78593 .25762 L F P
0 g
s
.381 .448 .805 r
.78051 .24948 m .78578 .2517 L .78281 .24466 L p F P
0 g
s
.381 .448 .805 r
.78281 .24466 m .7822 .2444 L .78051 .24948 L p F P
0 g
s
.529 .561 .831 r
.6809 .39873 m .67411 .39843 L .67841 .39357 L closepath p F P
0 g
s
.534 .549 .817 r
.67787 .39245 m .67841 .39357 L .67411 .39843 L p F P
0 g
s
0 0 .292 r
.80852 .36523 m .80848 .36528 L .80766 .37106 L p F P
0 g
s
.379 .435 .793 r
.78877 .25898 m .78593 .25762 L p .79076 .26594 L F P
0 g
s
.379 .435 .793 r
.79076 .26594 m .79116 .26491 L .78877 .25898 L p F P
0 g
s
.356 .41 .779 r
.79177 .2665 m .79076 .26594 L .79116 .26491 L closepath p F P
0 g
s
0 0 .268 r
.81153 .36006 m .80852 .36523 L .80839 .36994 L p F P
0 g
s
0 0 .292 r
.80766 .37106 m .80839 .36994 L .80852 .36523 L p F P
0 g
s
0 0 .369 r
.81144 .35457 m .81153 .36006 L .80852 .36523 L p F P
0 g
s
.37 .431 .793 r
.78877 .25898 m .78593 .25762 L .78701 .25462 L closepath p F P
0 g
s
.391 .454 .806 r
.78593 .25762 m .78701 .25462 L .78578 .2517 L p F P
0 g
s
.183 .182 .622 r
.81042 .3238 m .81263 .31921 L p .81279 .329 L F P
0 g
s
.183 .182 .622 r
.81279 .329 m .81081 .3255 L .81042 .3238 L p F P
0 g
s
.215 .225 .655 r
.81042 .3238 m .81263 .31921 L .80946 .31473 L p F P
0 g
s
.115 .163 .635 r
.60963 .23577 m .60784 .24103 L .61075 .24535 L p F P
0 g
s
.097 .131 .607 r
.60784 .24103 m .60963 .23577 L .60717 .23132 L p F P
0 g
s
.478 .578 .877 r
.72558 .18887 m .72149 .18846 L .71858 .18322 L p F P
0 g
s
.263 .287 .699 r
.61698 .2685 m .6142 .274 L .61861 .27789 L p F P
0 g
s
.307 .306 .694 r
.61302 .26447 m .61698 .2685 L .6142 .274 L p F P
0 g
s
.497 .592 .879 r
.71366 .18291 m .71858 .18322 L .71566 .17803 L p F P
0 g
s
.497 .592 .879 r
.71566 .17803 m .7144 .17795 L .71366 .18291 L p F P
0 g
s
.655 .728 .902 r
.63417 .15331 m .64618 .14935 L .64913 .15341 L p F P
0 g
s
.668 .737 .902 r
.64618 .14935 m .63417 .15331 L .63122 .14974 L p F P
0 g
s
.726 .831 .93 r
.63417 .15331 m .63122 .14974 L p .61962 .15683 L F P
0 g
s
.184 .182 .622 r
.81197 .33063 m .81081 .3255 L .81279 .329 L closepath p F P
0 g
s
.412 .495 .835 r
.7693 .22876 m .76409 .22719 L .76179 .22228 L p F P
0 g
s
.384 .4 .754 r
.63002 .30931 m .62622 .31503 L .63268 .31836 L p F P
0 g
s
.403 .397 .738 r
.6241 .30583 m .63002 .30931 L .62622 .31503 L p F P
0 g
s
.513 .524 .805 r
.67042 .38543 m .66256 .38456 L .66077 .38038 L p F P
0 g
s
.34 .399 .778 r
.79679 .26941 m .79177 .2665 L .79116 .26491 L p F P
0 g
s
0 0 0 r
.79936 .38892 m .79985 .38824 L .8001 .38751 L closepath p F P
0 g
s
.216 .229 .658 r
.81183 .3096 m .80946 .31473 L .81263 .31921 L p F P
0 g
s
.249 .267 .684 r
.80813 .3053 m .81183 .3096 L .80946 .31473 L p F P
0 g
s
.549 .586 .843 r
.6844 .40579 m .68391 .40482 L .68534 .4048 L closepath p F P
0 g
s
.72 .971 .93 r
.76487 .41991 m .77685 .41256 L .77701 .4126 L p F P
0 g
s
.714 .946 .956 r
.77685 .41256 m .76487 .41991 L .76221 .41807 L p F P
0 g
s
0 0 .424 r
.60544 .21029 m .6046 .20702 L .60476 .20605 L closepath p F P
0 g
s
.604 .69 .904 r
.64913 .15341 m .66123 .15096 L .66418 .15529 L p F P
0 g
s
.611 .697 .905 r
.66123 .15096 m .64913 .15341 L .64618 .14935 L p F P
0 g
s
.34 .399 .778 r
.79116 .26491 m .79249 .26089 L p .79679 .26941 L F P
0 g
s
.355 .421 .791 r
.79116 .26491 m .78877 .25898 L .79249 .26089 L closepath p F P
0 g
s
.443 .53 .852 r
.7451 .20693 m .75504 .20896 L .75388 .21396 L p F P
0 g
s
.45 .54 .857 r
.746 .20199 m .7451 .20693 L .75504 .20896 L p F P
0 g
s
.451 .544 .86 r
.73979 .20088 m .746 .20199 L .7451 .20693 L p F P
0 g
s
.615 .724 .923 r
.72013 .42303 m .73234 .42039 L .73516 .42408 L p F P
0 g
s
.606 .681 .894 r
.72949 .41642 m .73234 .42039 L .72013 .42303 L p F P
0 g
s
.606 .681 .894 r
.72 .41816 m .72949 .41642 L p .72013 .42303 L F P
0 g
s
.606 .681 .894 r
.72013 .42303 m .71816 .42006 L .72 .41816 L p F P
0 g
s
.551 .578 .835 r
.68534 .4048 m .68391 .40482 L .6809 .39873 L p F P
0 g
s
.501 .601 .885 r
.70093 .17343 m .70099 .1725 L p .7144 .17795 L F P
0 g
s
.507 .61 .89 r
.70093 .17343 m .70037 .17248 L .70099 .1725 L closepath p F P
0 g
s
.564 .668 .908 r
.66522 .15685 m .66418 .15529 L .66513 .15518 L closepath p F P
0 g
s
.123 .088 .542 r
.81323 .33709 m .81212 .33904 L .81367 .34406 L p F P
0 g
s
.176 .152 .591 r
.81212 .33904 m .81323 .33709 L .81197 .33063 L p F P
0 g
s
.784 .861 .907 r
.61933 .15658 m .61972 .15631 L .61962 .15683 L closepath p F P
0 g
s
.726 .831 .93 r
.63122 .14974 m .61972 .15631 L .61962 .15683 L p F P
0 g
s
.234 .269 .694 r
.61539 .25907 m .61302 .26447 L .61698 .2685 L p F P
0 g
s
.278 .28 .682 r
.61187 .25492 m .61539 .25907 L .61302 .26447 L p F P
0 g
s
.052 .11 .605 r
.60852 .22618 m .60717 .23132 L .60963 .23577 L p F P
0 g
s
0 .049 .56 r
.60717 .23132 m .60852 .22618 L .60649 .22159 L p F P
0 g
s
.513 .524 .805 r
.66077 .38038 m .66294 .3779 L p .67042 .38543 L F P
0 g
s
.5 .516 .804 r
.66077 .38038 m .65949 .3774 L .66294 .3779 L closepath p F P
0 g
s
.363 .381 .746 r
.62756 .30019 m .6241 .30583 L .63002 .30931 L p F P
0 g
s
.385 .379 .73 r
.62214 .29657 m .62756 .30019 L .6241 .30583 L p F P
0 g
s
.136 .125 .58 r
.81279 .329 m .81197 .33063 L .81323 .33709 L p F P
0 g
s
.911 .846 .395 r
.6077 .17156 m .60797 .17118 L p .60623 .1813 L F P
0 g
s
.911 .846 .395 r
.60623 .1813 m .60639 .17646 L .6077 .17156 L p F P
0 g
s
.531 .639 .902 r
.68536 .16306 m .68224 .16318 L .67931 .15856 L p F P
0 g
s
.811 .875 .894 r
.61972 .15631 m .61933 .15658 L .61638 .15428 L p F P
0 g
s
.869 .874 .839 r
.6122 .16408 m .61933 .15658 L .61638 .15428 L p F P
0 g
s
0 0 .478 r
.60476 .20605 m .60576 .20189 L p .60589 .21183 L F P
0 g
s
0 0 .478 r
.60589 .21183 m .60544 .21029 L .60476 .20605 L p F P
0 g
s
0 0 .375 r
.60476 .20605 m .60576 .20189 L .60494 .19693 L p F P
0 g
s
.811 .875 .894 r
.61638 .15428 m .62029 .15128 L .61972 .15631 L p F P
0 g
s
.743 .792 .893 r
.62825 .14627 m .62029 .15128 L .61972 .15631 L p F P
0 g
s
.743 .792 .893 r
.61972 .15631 m .63122 .14974 L .62825 .14627 L p F P
0 g
s
0 0 0 r
.80281 .38363 m .79985 .38824 L .79814 .391 L p F P
0 g
s
0 0 0 r
.80581 .37716 m .80281 .38363 L .79985 .38824 L p F P
0 g
s
.536 .572 .838 r
.68534 .4048 m .69617 .40463 L .69318 .39896 L p F P
0 g
s
.536 .572 .838 r
.69318 .39896 m .69058 .39891 L .68534 .4048 L p F P
0 g
s
.551 .578 .835 r
.6809 .39873 m .69058 .39891 L .68534 .4048 L p F P
0 g
s
.505 .613 .893 r
.70099 .1725 m .70037 .17248 L .69745 .16762 L p F P
0 g
s
.247 .27 .688 r
.8104 .30018 m .80813 .3053 L .81183 .3096 L p F P
0 g
s
.27 .297 .706 r
.80619 .29606 m .8104 .30018 L .80813 .3053 L p F P
0 g
s
.576 .653 .888 r
.70209 .41535 m .71434 .41402 L .71724 .41866 L p F P
0 g
s
.57 .623 .865 r
.71141 .40915 m .71434 .41402 L .70209 .41535 L p F P
0 g
s
.57 .623 .865 r
.70042 .41002 m .71141 .40915 L p .70209 .41535 L F P
0 g
s
.57 .623 .865 r
.70209 .41535 m .69959 .41092 L .70042 .41002 L p F P
0 g
s
.45 .545 .862 r
.746 .20199 m .73979 .20088 L .73688 .19528 L p F P
0 g
s
.502 .512 .799 r
.66294 .3779 m .65949 .3774 L .65645 .37013 L p F P
0 g
s
.354 .421 .792 r
.79249 .26089 m .78877 .25898 L .78701 .25462 L p F P
0 g
s
.412 .495 .835 r
.76179 .22228 m .76204 .22121 L p .7693 .22876 L F P
0 g
s
.423 .51 .843 r
.76179 .22228 m .76117 .22098 L .76204 .22121 L closepath p F P
0 g
s
.434 .52 .847 r
.75388 .21396 m .75825 .21499 L .75532 .20902 L p F P
0 g
s
.434 .52 .847 r
.75532 .20902 m .75504 .20896 L .75388 .21396 L p F P
0 g
s
.675 .841 .963 r
.76171 .41829 m .7501 .42324 L .74734 .42033 L p F P
0 g
s
.649 .79 .95 r
.73516 .42408 m .74734 .42033 L .7501 .42324 L p F P
0 g
s
.502 .609 .891 r
.70099 .1725 m .71274 .17295 L .70983 .16797 L p F P
0 g
s
.502 .609 .891 r
.70983 .16797 m .70117 .16769 L .70099 .1725 L p F P
0 g
s
.505 .613 .893 r
.69745 .16762 m .70117 .16769 L .70099 .1725 L p F P
0 g
s
.501 .601 .885 r
.70099 .1725 m .71274 .17295 L p .7144 .17795 L F P
0 g
s
.634 .762 .94 r
.74734 .42033 m .73516 .42408 L .73234 .42039 L p F P
0 g
s
.869 .874 .839 r
.61638 .15428 m .61219 .15926 L .6122 .16408 L p F P
0 g
s
.892 .988 .744 r
.6122 .16408 m .60804 .17069 L .60797 .17118 L p F P
0 g
s
.949 .956 .698 r
.61219 .15926 m .6122 .16408 L .60804 .17069 L p F P
0 g
s
.816 .996 .857 r
.78786 .4035 m .77727 .41225 L .77701 .4126 L p F P
0 g
s
.778 .98 .909 r
.77685 .41256 m .77727 .41225 L .77701 .4126 L closepath p F P
0 g
s
.48 .572 .871 r
.73397 .18988 m .72558 .18887 L p .73641 .19522 L F P
0 g
s
.472 .571 .874 r
.72558 .18887 m .73397 .18988 L .73106 .18453 L p F P
0 g
s
.472 .571 .874 r
.73106 .18453 m .7262 .18397 L .72558 .18887 L p F P
0 g
s
.478 .578 .877 r
.71858 .18322 m .7262 .18397 L .72558 .18887 L p F P
0 g
s
0 0 .391 r
.81453 .34931 m .81144 .35457 L .81153 .36006 L p F P
0 g
s
.067 .012 .479 r
.81144 .35457 m .81453 .34931 L .81367 .34406 L p F P
0 g
s
.339 .361 .737 r
.62527 .29101 m .62214 .29657 L .62756 .30019 L p F P
0 g
s
.365 .361 .722 r
.62033 .28725 m .62527 .29101 L .62214 .29657 L p F P
0 g
s
.563 .671 .911 r
.66513 .15518 m .66418 .15529 L .66123 .15096 L p F P
0 g
s
.808 .988 .729 r
.78838 .40284 m .78867 .40273 L .79456 .39592 L p F P
0 g
s
0 0 .131 r
.80839 .36994 m .80766 .37106 L .80581 .37716 L p F P
0 g
s
0 0 .314 r
.60572 .19191 m .60494 .19693 L .60576 .20189 L p F P
0 g
s
0 0 .172 r
.60494 .19693 m .60572 .19191 L .60557 .18674 L p F P
0 g
s
.421 .511 .845 r
.76204 .22121 m .76117 .22098 L .75825 .21499 L p F P
0 g
s
.193 .235 .677 r
.61384 .24963 m .61187 .25492 L .61539 .25907 L p F P
0 g
s
.171 .203 .653 r
.61187 .25492 m .61384 .24963 L .61075 .24535 L p F P
0 g
s
.773 .958 .93 r
.77727 .41225 m .77685 .41256 L .77427 .41149 L p F P
0 g
s
.714 .946 .956 r
.76221 .41807 m .77427 .41149 L .77685 .41256 L p F P
0 g
s
.773 .958 .93 r
.77427 .41149 m .78108 .40689 L .77727 .41225 L p F P
0 g
s
.783 .982 .904 r
.78838 .40284 m .78786 .4035 L .77727 .41225 L p F P
0 g
s
.783 .982 .904 r
.78621 .40304 m .78838 .40284 L p .77727 .41225 L F P
0 g
s
.783 .982 .904 r
.77727 .41225 m .78108 .40689 L .78621 .40304 L p F P
0 g
s
0 .033 .555 r
.60706 .21893 m .60649 .22159 L .60852 .22618 L p F P
0 g
s
0 0 .514 r
.60649 .22159 m .60706 .21893 L .60576 .2123 L p F P
0 g
s
.478 .58 .879 r
.7262 .18397 m .71858 .18322 L .71566 .17803 L p F P
0 g
s
.566 .672 .91 r
.66513 .15518 m .67637 .15398 L .67343 .14946 L p F P
0 g
s
.566 .672 .91 r
.67343 .14946 m .66473 .15051 L .66513 .15518 L p F P
0 g
s
.563 .671 .911 r
.66123 .15096 m .66473 .15051 L .66513 .15518 L p F P
0 g
s
.354 .421 .792 r
.78701 .25462 m .78764 .25255 L p .79249 .26089 L F P
0 g
s
.369 .44 .804 r
.78701 .25462 m .78578 .2517 L .78764 .25255 L closepath p F P
0 g
s
.274 .307 .714 r
.80835 .29095 m .80619 .29606 L .8104 .30018 L p F P
0 g
s
.292 .33 .73 r
.80619 .29606 m .80835 .29095 L .80364 .28699 L p F P
0 g
s
.136 .125 .58 r
.81323 .33709 m .81485 .33386 L .81279 .329 L p F P
0 g
s
.133 .126 .583 r
.81528 .32387 m .81279 .329 L .81485 .33386 L p F P
0 g
s
.183 .182 .622 r
.81263 .31921 m .81528 .32387 L .81279 .329 L p F P
0 g
s
0 0 .482 r
.60576 .2123 m .60544 .21029 L .60589 .21183 L closepath p F P
0 g
s
.412 .495 .835 r
.76204 .22121 m .77053 .22377 L .7693 .22876 L p F P
0 g
s
.418 .505 .841 r
.76306 .21627 m .76204 .22121 L .77053 .22377 L p F P
0 g
s
.421 .511 .845 r
.75825 .21499 m .76306 .21627 L .76204 .22121 L p F P
0 g
s
.725 .976 .742 r
.78786 .4035 m .78838 .40284 L .78867 .40273 L closepath p F P
0 g
s
.606 .68 .894 r
.71816 .42006 m .71724 .41866 L .72 .41816 L closepath p F P
0 g
s
.532 .636 .899 r
.68536 .16306 m .69452 .1628 L .69159 .15803 L p F P
0 g
s
.532 .636 .899 r
.69159 .15803 m .68541 .15826 L .68536 .16306 L p F P
0 g
s
.531 .639 .902 r
.67931 .15856 m .68541 .15826 L .68536 .16306 L p F P
0 g
s
.539 .566 .831 r
.69058 .39891 m .6809 .39873 L .67841 .39357 L p F P
0 g
s
.078 .056 .528 r
.81485 .33386 m .81323 .33709 L .81418 .34316 L p F P
0 g
s
.123 .088 .542 r
.81367 .34406 m .81418 .34316 L .81323 .33709 L p F P
0 g
s
.467 .479 .787 r
.65021 .35456 m .64654 .35347 L p .65119 .36187 L F P
0 g
s
.467 .479 .787 r
.65119 .36187 m .65247 .36027 L .65021 .35456 L p F P
0 g
s
.469 .481 .788 r
.65332 .36241 m .65119 .36187 L .65247 .36027 L closepath p F P
0 g
s
.313 .339 .728 r
.6231 .28178 m .62033 .28725 L .62527 .29101 L p F P
0 g
s
.342 .341 .713 r
.61861 .27789 m .6231 .28178 L .62033 .28725 L p F P
0 g
s
.905 .9 .488 r
.6077 .17156 m .60804 .17069 L .60797 .17118 L closepath p F P
0 g
s
.502 .512 .799 r
.65645 .37013 m .65652 .37006 L p .66294 .3779 L F P
0 g
s
.489 .503 .798 r
.65645 .37013 m .65641 .37004 L .65652 .37006 L closepath p F P
0 g
s
.492 .499 .792 r
.65652 .37006 m .65641 .37004 L .65332 .36241 L p F P
0 g
s
.502 .512 .799 r
.65652 .37006 m .6676 .3721 L .66294 .3779 L p F P
0 g
s
.481 .507 .807 r
.66131 .36419 m .65652 .37006 L .6676 .3721 L p F P
0 g
s
.492 .499 .792 r
.65332 .36241 m .66131 .36419 L .65652 .37006 L p F P
0 g
s
.455 .468 .782 r
.65021 .35456 m .64654 .35347 L .64869 .35064 L closepath p F P
0 g
s
.465 .46 .767 r
.64709 .3465 m .64869 .35064 L .64654 .35347 L p F P
0 g
s
.465 .46 .767 r
.64246 .34489 m .64709 .3465 L p .64654 .35347 L F P
0 g
s
.368 .441 .805 r
.78764 .25255 m .78578 .2517 L .78281 .24466 L p F P
0 g
s
0 0 .103 r
.81079 .36582 m .80839 .36994 L .80783 .3741 L p F P
0 g
s
0 0 .268 r
.80839 .36994 m .81079 .36582 L .81153 .36006 L p F P
0 g
s
0 0 .131 r
.80581 .37716 m .80783 .3741 L .80839 .36994 L p F P
0 g
s
.294 .336 .735 r
.80568 .2819 m .80364 .28699 L .80835 .29095 L p F P
0 g
s
.311 .357 .749 r
.80364 .28699 m .80568 .2819 L .80051 .27811 L p F P
0 g
s
0 .029 .542 r
.60589 .21183 m .60576 .2123 L .60706 .21893 L p F P
0 g
s
.441 .453 .776 r
.64709 .3465 m .64246 .34489 L .6451 .34123 L closepath p F P
0 g
s
.452 .446 .761 r
.64396 .33821 m .6451 .34123 L .64246 .34489 L p F P
0 g
s
.452 .446 .761 r
.63884 .33617 m .64396 .33821 L p .64246 .34489 L F P
0 g
s
.144 .194 .656 r
.61226 .24043 m .61075 .24535 L .61384 .24963 L p F P
0 g
s
.115 .163 .635 r
.61209 .23978 m .60963 .23577 L p .61075 .24535 L F P
0 g
s
.115 .163 .635 r
.61075 .24535 m .61226 .24043 L .61209 .23978 L p F P
0 g
s
.411 .488 .829 r
.7769 .23127 m .7693 .22876 L p .77603 .23649 L F P
0 g
s
.4 .484 .83 r
.7693 .22876 m .7769 .23127 L .77396 .22491 L p F P
0 g
s
.4 .484 .83 r
.77396 .22491 m .77053 .22377 L .7693 .22876 L p F P
0 g
s
.837 .865 .417 r
.60804 .17069 m .60845 .16573 L p .6063 .17406 L F P
0 g
s
.837 .865 .417 r
.6063 .17406 m .6077 .17156 L .60804 .17069 L p F P
0 g
s
.949 .956 .698 r
.60804 .17069 m .60845 .16573 L .61219 .15926 L p F P
0 g
s
.789 .999 .826 r
.78621 .40304 m .79152 .39817 L .78838 .40284 L closepath p F P
0 g
s
.808 .988 .729 r
.79792 .39121 m .79152 .39817 L .78838 .40284 L p F P
0 g
s
.808 .988 .729 r
.79814 .391 m .79792 .39121 L p .78838 .40284 L F P
0 g
s
.513 .524 .805 r
.66294 .3779 m .67179 .37922 L p .67042 .38543 L F P
0 g
s
.486 .506 .803 r
.66294 .3779 m .67179 .37922 L .66872 .37231 L p F P
0 g
s
.486 .506 .803 r
.66872 .37231 m .6676 .3721 L .66294 .3779 L p F P
0 g
s
.668 .737 .902 r
.63122 .14974 m .64322 .14536 L .64618 .14935 L p F P
0 g
s
.683 .747 .9 r
.64322 .14536 m .63122 .14974 L .62825 .14627 L p F P
0 g
s
.569 .621 .864 r
.69959 .41092 m .69914 .41012 L .70042 .41002 L closepath p F P
0 g
s
.607 .667 .882 r
.72 .41816 m .71724 .41866 L .71434 .41402 L p F P
0 g
s
0 0 .51 r
.60708 .20669 m .60589 .21183 L .60775 .21646 L p F P
0 g
s
0 0 .478 r
.60576 .20189 m .60708 .20669 L .60589 .21183 L p F P
0 g
s
0 .029 .542 r
.60706 .21893 m .60775 .21646 L .60589 .21183 L p F P
0 g
s
.949 .861 .441 r
.60639 .17646 m .6063 .17406 L .6077 .17156 L closepath p F P
0 g
s
.464 .557 .865 r
.73688 .19528 m .73641 .19522 L .73653 .19461 L closepath p F P
0 g
s
.48 .572 .871 r
.73641 .19522 m .73653 .19461 L .73397 .18988 L p F P
0 g
s
.438 .432 .755 r
.64082 .32969 m .64167 .33202 L .63884 .33617 L p F P
0 g
s
.438 .432 .755 r
.6356 .32731 m .64082 .32969 L p .63884 .33617 L F P
0 g
s
.425 .438 .77 r
.64396 .33821 m .63884 .33617 L .64167 .33202 L closepath p F P
0 g
s
.312 .362 .754 r
.80241 .27304 m .80051 .27811 L .80568 .2819 L p F P
0 g
s
.327 .381 .765 r
.80051 .27811 m .80241 .27304 L .79679 .26941 L p F P
0 g
s
.611 .697 .905 r
.64618 .14935 m .65828 .14667 L .66123 .15096 L p F P
0 g
s
.619 .704 .906 r
.65828 .14667 m .64618 .14935 L .64322 .14536 L p F P
0 g
s
.399 .472 .819 r
.77985 .23792 m .77603 .23649 L p .7822 .2444 L F P
0 g
s
.391 .467 .819 r
.77985 .23792 m .77603 .23649 L .77728 .2321 L closepath p F P
0 g
s
.411 .488 .829 r
.77603 .23649 m .77728 .2321 L .7769 .23127 L p F P
0 g
s
.283 .314 .717 r
.62103 .27251 m .61861 .27789 L .6231 .28178 L p F P
0 g
s
.263 .287 .699 r
.61861 .27789 m .62103 .27251 L .61698 .2685 L p F P
0 g
s
.45 .545 .862 r
.73688 .19528 m .74683 .19705 L .746 .20199 L p F P
0 g
s
.448 .547 .865 r
.74683 .19705 m .73688 .19528 L .73653 .19461 L p F P
0 g
s
.571 .612 .855 r
.70042 .41002 m .69914 .41012 L .69617 .40463 L p F P
0 g
s
.181 .185 .627 r
.81505 .31407 m .81263 .31921 L .81528 .32387 L p F P
0 g
s
.216 .229 .658 r
.81263 .31921 m .81505 .31407 L .81183 .3096 L p F P
0 g
s
.329 .387 .77 r
.79854 .26436 m .79679 .26941 L .80241 .27304 L p F P
0 g
s
.34 .399 .778 r
.79249 .26089 m .79854 .26436 L .79679 .26941 L p F P
0 g
s
.056 .005 .476 r
.81418 .34316 m .81367 .34406 L .81453 .34931 L p F P
0 g
s
.479 .487 .788 r
.66131 .36419 m .65332 .36241 L .65247 .36027 L p F P
0 g
s
0 0 0 r
.80783 .3741 m .80581 .37716 L .80281 .38363 L p F P
0 g
s
.507 .535 .82 r
.67484 .38593 m .67042 .38543 L .67311 .38215 L closepath p F P
0 g
s
.513 .524 .805 r
.67179 .37922 m .67311 .38215 L .67042 .38543 L p F P
0 g
s
.378 .449 .807 r
.78281 .24466 m .7822 .2444 L .78241 .24373 L closepath p F P
0 g
s
.399 .472 .819 r
.7822 .2444 m .78241 .24373 L .77985 .23792 L p F P
0 g
s
.448 .547 .865 r
.73653 .19461 m .73702 .19034 L p .74683 .19705 L F P
0 g
s
.457 .559 .871 r
.73653 .19461 m .73397 .18988 L .73702 .19034 L closepath p F P
0 g
s
.507 .616 .895 r
.70117 .16769 m .69745 .16762 L .69452 .1628 L p F P
0 g
s
.407 .422 .764 r
.64082 .32969 m .6356 .32731 L .6384 .32298 L closepath p F P
0 g
s
.404 .418 .761 r
.63767 .32094 m .63268 .31836 L p .6356 .32731 L F P
0 g
s
.404 .418 .761 r
.6356 .32731 m .6384 .32298 L .63767 .32094 L p F P
0 g
s
.535 .644 .904 r
.68541 .15826 m .67931 .15856 L .67637 .15398 L p F P
0 g
s
.419 .511 .846 r
.76306 .21627 m .75825 .21499 L .75532 .20902 L p F P
0 g
s
.496 .593 .881 r
.71566 .17803 m .7144 .17795 L .71462 .1762 L closepath p F P
0 g
s
.501 .601 .885 r
.71274 .17295 m .71462 .1762 L .7144 .17795 L p F P
0 g
s
.345 .41 .785 r
.7941 .25587 m .79249 .26089 L .79854 .26436 L p F P
0 g
s
.354 .421 .792 r
.78764 .25255 m .7941 .25587 L .79249 .26089 L p F P
0 g
s
.354 .425 .796 r
.78908 .24755 m .78764 .25255 L .7941 .25587 L p F P
0 g
s
.368 .441 .805 r
.78281 .24466 m .78908 .24755 L .78764 .25255 L p F P
0 g
s
.539 .566 .831 r
.67841 .39357 m .67933 .39252 L p .69058 .39891 L F P
0 g
s
.528 .559 .83 r
.67841 .39357 m .67787 .39245 L .67933 .39252 L closepath p F P
0 g
s
.479 .487 .788 r
.65247 .36027 m .65578 .35603 L p .66131 .36419 L F P
0 g
s
.465 .477 .787 r
.65247 .36027 m .65021 .35456 L .65578 .35603 L closepath p F P
0 g
s
.556 .606 .858 r
.70042 .41002 m .71141 .40915 L .70847 .40409 L p F P
0 g
s
.556 .606 .858 r
.70847 .40409 m .70546 .40422 L .70042 .41002 L p F P
0 g
s
.571 .612 .855 r
.69617 .40463 m .70546 .40422 L .70042 .41002 L p F P
0 g
s
.675 .841 .963 r
.76204 .41792 m .76171 .41829 L p .74734 .42033 L F P
0 g
s
.703 .858 .956 r
.76171 .41829 m .76204 .41792 L .76221 .41807 L closepath p F P
0 g
s
.079 .139 .625 r
.61209 .23978 m .60963 .23577 L .61035 .23304 L closepath p F P
0 g
s
.052 .11 .605 r
.60881 .22672 m .60852 .22618 L p .60963 .23577 L F P
0 g
s
.052 .11 .605 r
.60963 .23577 m .61035 .23304 L .60881 .22672 L p F P
0 g
s
.362 .439 .806 r
.78908 .24755 m .78281 .24466 L .78241 .24373 L p F P
0 g
s
.744 .868 .937 r
.76204 .41792 m .76221 .41807 L .77427 .41149 L p F P
0 g
s
.591 .665 .89 r
.72 .41816 m .72949 .41642 L .72662 .41221 L p F P
0 g
s
.591 .665 .89 r
.72662 .41221 m .72471 .41249 L .72 .41816 L p F P
0 g
s
.607 .667 .882 r
.71434 .41402 m .72471 .41249 L .72 .41816 L p F P
0 g
s
0 0 .391 r
.81153 .36006 m .81462 .35481 L .81453 .34931 L p F P
0 g
s
0 0 .264 r
.81462 .35481 m .81153 .36006 L .81079 .36582 L p F P
0 g
s
.53 .553 .823 r
.67933 .39252 m .67787 .39245 L .67484 .38593 L p F P
0 g
s
.026 .075 .577 r
.60775 .21646 m .60706 .21893 L .60859 .22584 L p F P
0 g
s
0 .033 .555 r
.60852 .22618 m .60859 .22584 L .60706 .21893 L p F P
0 g
s
.362 .439 .806 r
.78241 .24373 m .78352 .23942 L p .78908 .24755 L F P
0 g
s
.376 .458 .817 r
.78241 .24373 m .77985 .23792 L .78352 .23942 L closepath p F P
0 g
s
.713 .852 .948 r
.75951 .41571 m .76543 .41295 L .76204 .41792 L closepath p F P
0 g
s
.744 .868 .937 r
.77164 .40991 m .76543 .41295 L .76204 .41792 L p F P
0 g
s
.744 .868 .937 r
.77427 .41149 m .77164 .40991 L p .76204 .41792 L F P
0 g
s
.675 .841 .963 r
.74734 .42033 m .75951 .41571 L .76204 .41792 L p F P
0 g
s
.388 .405 .757 r
.63767 .32094 m .63268 .31836 L .63526 .3141 L closepath p F P
0 g
s
.384 .4 .754 r
.63451 .31194 m .63002 .30931 L p .63268 .31836 L F P
0 g
s
.384 .4 .754 r
.63268 .31836 m .63526 .3141 L .63451 .31194 L p F P
0 g
s
.478 .58 .879 r
.71566 .17803 m .72678 .17906 L .7262 .18397 L p F P
0 g
s
.478 .583 .882 r
.72678 .17906 m .71566 .17803 L .71462 .1762 L p F P
0 g
s
.249 .285 .704 r
.61888 .26371 m .61698 .2685 L .62103 .27251 L p F P
0 g
s
.234 .269 .694 r
.61856 .26264 m .61539 .25907 L p .61698 .2685 L F P
0 g
s
.234 .269 .694 r
.61698 .2685 m .61888 .26371 L .61856 .26264 L p F P
0 g
s
.004 0 .459 r
.81632 .33891 m .81418 .34316 L .81481 .34881 L p F P
0 g
s
.078 .056 .528 r
.81418 .34316 m .81632 .33891 L .81485 .33386 L p F P
0 g
s
.056 .005 .476 r
.81453 .34931 m .81481 .34881 L .81418 .34316 L p F P
0 g
s
.634 .762 .94 r
.73234 .42039 m .74456 .41709 L .74734 .42033 L p F P
0 g
s
.621 .738 .93 r
.74456 .41709 m .73234 .42039 L .72949 .41642 L p F P
0 g
s
.441 .537 .859 r
.746 .20199 m .75241 .20328 L .74949 .19758 L p F P
0 g
s
.441 .537 .859 r
.74949 .19758 m .74683 .19705 L .746 .20199 L p F P
0 g
s
.45 .54 .857 r
.75241 .20328 m .746 .20199 L p .75504 .20896 L F P
0 g
s
.568 .678 .913 r
.66473 .15051 m .66123 .15096 L .65828 .14667 L p F P
0 g
s
0 0 .405 r
.60648 .19689 m .60576 .20189 L .60708 .20669 L p F P
0 g
s
0 0 .314 r
.60576 .20189 m .60648 .19689 L .60572 .19191 L p F P
0 g
s
.467 .475 .782 r
.65578 .35603 m .65021 .35456 L .64869 .35064 L p F P
0 g
s
.213 .229 .66 r
.81417 .30446 m .81183 .3096 L .81505 .31407 L p F P
0 g
s
.247 .27 .688 r
.81183 .3096 m .81417 .30446 L .8104 .30018 L p F P
0 g
s
.659 .809 .955 r
.75951 .41571 m .74734 .42033 L .74456 .41709 L p F P
0 g
s
.539 .566 .831 r
.67933 .39252 m .69018 .39306 L p .69058 .39891 L F P
0 g
s
.514 .546 .826 r
.67933 .39252 m .69018 .39306 L .68717 .38697 L p F P
0 g
s
.514 .546 .826 r
.68717 .38697 m .68416 .38671 L .67933 .39252 L p F P
0 g
s
.53 .553 .823 r
.67484 .38593 m .68416 .38671 L .67933 .39252 L p F P
0 g
s
.834 .871 .872 r
.62029 .15128 m .61638 .15428 L .61343 .15226 L p F P
0 g
s
.893 .886 .818 r
.61219 .15926 m .61638 .15428 L .61343 .15226 L p F P
0 g
s
.368 .387 .749 r
.63451 .31194 m .63002 .30931 L .63225 .30536 L closepath p F P
0 g
s
.363 .381 .746 r
.63134 .30269 m .62756 .30019 L p .63002 .30931 L F P
0 g
s
.363 .381 .746 r
.63002 .30931 m .63225 .30536 L .63134 .30269 L p F P
0 g
s
.847 .724 .198 r
.6063 .17406 m .60639 .17646 L .60581 .18187 L p F P
0 g
s
.012 .084 .592 r
.60881 .22672 m .60852 .22618 L .60859 .22584 L closepath p F P
0 g
s
.467 .475 .782 r
.64869 .35064 m .65091 .34768 L p .65578 .35603 L F P
0 g
s
.451 .463 .781 r
.64869 .35064 m .64709 .3465 L .65091 .34768 L closepath p F P
0 g
s
.478 .583 .882 r
.71462 .1762 m .71477 .1731 L p .72678 .17906 L F P
0 g
s
.485 .593 .886 r
.71462 .1762 m .71274 .17295 L .71477 .1731 L closepath p F P
0 g
s
.834 .871 .872 r
.61343 .15226 m .62005 .14651 L .62029 .15128 L p F P
0 g
s
.761 .803 .887 r
.62528 .1429 m .62005 .14651 L .62029 .15128 L p F P
0 g
s
.761 .803 .887 r
.62029 .15128 m .62825 .14627 L .62528 .1429 L p F P
0 g
s
.077 .057 .53 r
.81739 .32871 m .81485 .33386 L .81632 .33891 L p F P
0 g
s
.133 .126 .583 r
.81485 .33386 m .81739 .32871 L .81528 .32387 L p F P
0 g
s
.639 .837 .434 r
.8063 .3783 m .80281 .38363 L .79846 .3905 L p F P
0 g
s
0 0 0 r
.80701 .3769 m .80783 .3741 L p .80281 .38363 L F P
0 g
s
0 0 0 r
.80281 .38363 m .8063 .3783 L .80701 .3769 L p F P
0 g
s
0 0 0 r
.79814 .391 m .79846 .3905 L .80281 .38363 L p F P
0 g
s
.193 .235 .677 r
.61533 .25153 m .61384 .24963 L p .61539 .25907 L F P
0 g
s
.193 .235 .677 r
.61539 .25907 m .61655 .2558 L .61533 .25153 L p F P
0 g
s
.207 .251 .687 r
.61856 .26264 m .61539 .25907 L .61655 .2558 L closepath p F P
0 g
s
.096 .142 .62 r
.60859 .22584 m .60993 .221 L p .61112 .23059 L F P
0 g
s
.096 .142 .62 r
.61112 .23059 m .60881 .22672 L .60859 .22584 L p F P
0 g
s
.026 .075 .577 r
.60859 .22584 m .60993 .221 L .60775 .21646 L p F P
0 g
s
.505 .612 .892 r
.70117 .16769 m .70983 .16797 L .7069 .16302 L p F P
0 g
s
.505 .612 .892 r
.7069 .16302 m .7013 .16288 L .70117 .16769 L p F P
0 g
s
.507 .616 .895 r
.69452 .1628 m .7013 .16288 L .70117 .16769 L p F P
0 g
s
.102 .144 .62 r
.61035 .23304 m .60881 .22672 L .61112 .23059 L closepath p F P
0 g
s
.965 .937 .69 r
.61169 .15458 m .61219 .15926 L .60845 .16573 L p F P
0 g
s
.893 .886 .818 r
.61343 .15226 m .61169 .15458 L .61219 .15926 L p F P
0 g
s
.454 .461 .777 r
.65091 .34768 m .64709 .3465 L .6451 .34123 L p F P
0 g
s
.558 .599 .85 r
.70546 .40422 m .69617 .40463 L .69318 .39896 L p F P
0 g
s
.432 .522 .849 r
.75532 .20902 m .75504 .20896 L .75511 .2086 L closepath p F P
0 g
s
.45 .54 .857 r
.75504 .20896 m .75511 .2086 L .75241 .20328 L p F P
0 g
s
.473 .574 .875 r
.7262 .18397 m .73106 .18453 L .72814 .17921 L p F P
0 g
s
.473 .574 .875 r
.72814 .17921 m .72678 .17906 L .7262 .18397 L p F P
0 g
s
.375 .458 .818 r
.78352 .23942 m .77985 .23792 L .77728 .2321 L p F P
0 g
s
.345 .368 .741 r
.63134 .30269 m .62756 .30019 L .62936 .29677 L closepath p F P
0 g
s
.339 .361 .737 r
.62816 .29316 m .62527 .29101 L p .62756 .30019 L F P
0 g
s
.339 .361 .737 r
.62756 .30019 m .62936 .29677 L .62816 .29316 L p F P
0 g
s
.241 .268 .689 r
.81209 .29629 m .8104 .30018 L .81417 .30446 L p F P
0 g
s
.274 .307 .714 r
.81131 .29382 m .80835 .29095 L p .8104 .30018 L F P
0 g
s
.274 .307 .714 r
.8104 .30018 m .81209 .29629 L .81131 .29382 L p F P
0 g
s
.593 .651 .876 r
.72471 .41249 m .71434 .41402 L .71141 .40915 L p F P
0 g
s
.456 .561 .873 r
.73702 .19034 m .73397 .18988 L .73106 .18453 L p F P
0 g
s
.419 .511 .846 r
.75532 .20902 m .76401 .21133 L .76306 .21627 L p F P
0 g
s
.416 .512 .849 r
.76401 .21133 m .75532 .20902 L .75511 .2086 L p F P
0 g
s
.518 .541 .819 r
.68416 .38671 m .67484 .38593 L .67311 .38215 L p F P
0 g
s
.573 .676 .91 r
.66473 .15051 m .67343 .14946 L .67048 .14498 L p F P
0 g
s
.573 .676 .91 r
.67048 .14498 m .66436 .14581 L .66473 .15051 L p F P
0 g
s
.568 .678 .913 r
.65828 .14667 m .66436 .14581 L .66473 .15051 L p F P
0 g
s
.416 .512 .849 r
.75511 .2086 m .75579 .20406 L p .76401 .21133 L F P
0 g
s
.427 .526 .856 r
.75511 .2086 m .75241 .20328 L .75579 .20406 L closepath p F P
0 g
s
0 0 .243 r
.60597 .18704 m .60572 .19191 L .60648 .19689 L p F P
0 g
s
.734 .965 .938 r
.78108 .40689 m .77427 .41149 L .77164 .40991 L p F P
0 g
s
.454 .461 .777 r
.6451 .34123 m .64659 .33915 L p .65091 .34768 L F P
0 g
s
.437 .449 .774 r
.6451 .34123 m .64396 .33821 L .64659 .33915 L closepath p F P
0 g
s
.699 .909 .559 r
.79792 .39121 m .79846 .3905 L .79814 .391 L closepath p F P
0 g
s
0 .013 .546 r
.60879 .21138 m .60775 .21646 L .60993 .221 L p F P
0 g
s
0 0 .51 r
.60775 .21646 m .60879 .21138 L .60708 .20669 L p F P
0 g
s
.151 .189 .646 r
.61035 .23304 m .61112 .23059 L p .61235 .24016 L F P
0 g
s
.151 .189 .646 r
.61235 .24016 m .61209 .23978 L .61035 .23304 L p F P
0 g
s
0 0 .386 r
.81481 .34881 m .81453 .34931 L .81462 .35481 L p F P
0 g
s
.163 .215 .67 r
.61533 .25153 m .61384 .24963 L .61434 .24804 L closepath p F P
0 g
s
.144 .194 .656 r
.61384 .24963 m .61434 .24804 L .61226 .24043 L p F P
0 g
s
.619 .704 .906 r
.64322 .14536 m .65533 .14244 L .65828 .14667 L p F P
0 g
s
.627 .711 .907 r
.65533 .14244 m .64322 .14536 L .64026 .14143 L p F P
0 g
s
.683 .747 .9 r
.62825 .14627 m .64026 .14143 L .64322 .14536 L p F P
0 g
s
.509 .62 .897 r
.7013 .16288 m .69452 .1628 L .69159 .15803 L p F P
0 g
s
.536 .64 .9 r
.68541 .15826 m .69159 .15803 L .68866 .1533 L p F P
0 g
s
.536 .64 .9 r
.68866 .1533 m .68545 .15345 L .68541 .15826 L p F P
0 g
s
.535 .644 .904 r
.67637 .15398 m .68545 .15345 L .68541 .15826 L p F P
0 g
s
.698 .757 .897 r
.64026 .14143 m .62825 .14627 L .62528 .1429 L p F P
0 g
s
.44 .447 .771 r
.64659 .33915 m .64396 .33821 L .64167 .33202 L p F P
0 g
s
0 0 .103 r
.80783 .3741 m .80912 .37188 L .81079 .36582 L p F P
0 g
s
0 0 .081 r
.81385 .36059 m .81079 .36582 L .80912 .37188 L p F P
0 g
s
0 0 .264 r
.81079 .36582 m .81385 .36059 L .81462 .35481 L p F P
0 g
s
0 0 0 r
.80701 .3769 m .80912 .37188 L .80783 .3741 L closepath p F P
0 g
s
.418 .505 .841 r
.77102 .21859 m .76306 .21627 L p .77053 .22377 L F P
0 g
s
.408 .501 .842 r
.76306 .21627 m .77102 .21859 L .76809 .21252 L p F P
0 g
s
.408 .501 .842 r
.76809 .21252 m .76401 .21133 L .76306 .21627 L p F P
0 g
s
.32 .346 .732 r
.62816 .29316 m .62527 .29101 L .62658 .28831 L closepath p F P
0 g
s
.313 .339 .728 r
.62497 .28333 m .6231 .28178 L p .62527 .29101 L F P
0 g
s
.313 .339 .728 r
.62527 .29101 m .62658 .28831 L .62497 .28333 L p F P
0 g
s
.538 .649 .906 r
.68545 .15345 m .67637 .15398 L .67343 .14946 L p F P
0 g
s
.263 .3 .713 r
.81131 .29382 m .80835 .29095 L .80952 .28809 L closepath p F P
0 g
s
.294 .336 .735 r
.80813 .28395 m .80568 .2819 L p .80835 .29095 L F P
0 g
s
.294 .336 .735 r
.80835 .29095 m .80952 .28809 L .80813 .28395 L p F P
0 g
s
.534 .578 .845 r
.69318 .39896 m .69058 .39891 L .69216 .39697 L closepath p F P
0 g
s
.539 .566 .831 r
.69018 .39306 m .69216 .39697 L .69058 .39891 L p F P
0 g
s
.756 .961 .662 r
.79846 .3905 m .79792 .39121 L .79556 .39258 L p F P
0 g
s
.756 .961 .662 r
.79556 .39258 m .8017 .38527 L .79846 .3905 L p F P
0 g
s
.639 .837 .434 r
.79846 .3905 m .8017 .38527 L .8063 .3783 L p F P
0 g
s
.518 .541 .819 r
.67311 .38215 m .6752 .37961 L p .68416 .38671 L F P
0 g
s
.505 .533 .818 r
.67311 .38215 m .67179 .37922 L .6752 .37961 L closepath p F P
0 g
s
.72 .955 .672 r
.79152 .39817 m .79792 .39121 L .79556 .39258 L p F P
0 g
s
0 0 .364 r
.81715 .34418 m .81481 .34881 L .81508 .35401 L p F P
0 g
s
.004 0 .459 r
.81481 .34881 m .81715 .34418 L .81632 .33891 L p F P
0 g
s
0 0 .386 r
.81462 .35481 m .81508 .35401 L .81481 .34881 L p F P
0 g
s
.132 .127 .584 r
.81777 .31871 m .81528 .32387 L .81739 .32871 L p F P
0 g
s
.181 .185 .627 r
.81528 .32387 m .81777 .31871 L .81505 .31407 L p F P
0 g
s
.734 .965 .938 r
.7843 .40271 m .78108 .40689 L p .77164 .40991 L F P
0 g
s
.773 .987 .897 r
.78108 .40689 m .7843 .40271 L .78621 .40304 L closepath p F P
0 g
s
.484 .595 .889 r
.71477 .1731 m .71274 .17295 L .70983 .16797 L p F P
0 g
s
.422 .434 .768 r
.64167 .33202 m .64082 .32969 L .64273 .33047 L closepath p F P
0 g
s
.44 .447 .771 r
.64167 .33202 m .64273 .33047 L p .64659 .33915 L F P
0 g
s
.764 .688 .143 r
.6065 .17161 m .6063 .17406 L .6057 .17829 L p F P
0 g
s
.837 .865 .417 r
.60845 .16573 m .6065 .17161 L .6063 .17406 L p F P
0 g
s
.847 .724 .198 r
.60581 .18187 m .6057 .17829 L .6063 .17406 L p F P
0 g
s
.154 .19 .646 r
.61226 .24043 m .61209 .23978 L .61235 .24016 L closepath p F P
0 g
s
.943 .877 .465 r
.60832 .16094 m .60845 .16573 L .6065 .17161 L p F P
0 g
s
.965 .937 .69 r
.60845 .16573 m .60832 .16094 L .61169 .15458 L p F P
0 g
s
.178 .217 .665 r
.61235 .24016 m .61226 .24043 L .61434 .24804 L p F P
0 g
s
.424 .433 .764 r
.64273 .33047 m .64082 .32969 L .6384 .32298 L p F P
0 g
s
.375 .458 .818 r
.77728 .2321 m .77742 .23146 L p .78352 .23942 L F P
0 g
s
.389 .475 .828 r
.77728 .2321 m .7769 .23127 L .77742 .23146 L closepath p F P
0 g
s
.399 .485 .832 r
.77396 .22491 m .77053 .22377 L .7715 .2196 L closepath p F P
0 g
s
.418 .505 .841 r
.77053 .22377 m .7715 .2196 L .77102 .21859 L p F P
0 g
s
.283 .329 .734 r
.80813 .28395 m .80568 .2819 L .80662 .27946 L closepath p F P
0 g
s
.312 .362 .754 r
.80501 .27494 m .80241 .27304 L p .80568 .2819 L F P
0 g
s
.312 .362 .754 r
.80568 .2819 m .80662 .27946 L .80501 .27494 L p F P
0 g
s
.833 .989 .865 r
.7843 .40271 m .78621 .40304 L .79152 .39817 L p F P
0 g
s
.833 .989 .865 r
.79152 .39817 m .79537 .39276 L p .7843 .40271 L F P
0 g
s
.72 .955 .672 r
.79556 .39258 m .79537 .39276 L .79152 .39817 L p F P
0 g
s
.621 .738 .93 r
.72949 .41642 m .74175 .41356 L .74456 .41709 L p F P
0 g
s
.607 .716 .922 r
.74175 .41356 m .72949 .41642 L .72662 .41221 L p F P
0 g
s
.291 .323 .723 r
.62497 .28333 m .6231 .28178 L .6239 .27998 L closepath p F P
0 g
s
.283 .314 .717 r
.62177 .2732 m .62103 .27251 L p .6231 .28178 L F P
0 g
s
.283 .314 .717 r
.6231 .28178 m .6239 .27998 L .62177 .2732 L p F P
0 g
s
.448 .547 .865 r
.73702 .19034 m .74658 .19196 L p .74683 .19705 L F P
0 g
s
.448 .553 .87 r
.73702 .19034 m .74658 .19196 L .74367 .18651 L p F P
0 g
s
.448 .553 .87 r
.74367 .18651 m .7375 .18548 L .73702 .19034 L p F P
0 g
s
.456 .561 .873 r
.73106 .18453 m .7375 .18548 L .73702 .19034 L p F P
0 g
s
.178 .217 .665 r
.61434 .24804 m .61564 .24438 L .61235 .24016 L p F P
0 g
s
.115 .177 .651 r
.61398 .23494 m .61235 .24016 L .61564 .24438 L p F P
0 g
s
.151 .189 .646 r
.61112 .23059 m .61398 .23494 L .61235 .24016 L p F P
0 g
s
.386 .476 .83 r
.77742 .23146 m .7769 .23127 L .77396 .22491 L p F P
0 g
s
.507 .529 .813 r
.6752 .37961 m .67179 .37922 L .66872 .37231 L p F P
0 g
s
.574 .684 .915 r
.66436 .14581 m .65828 .14667 L .65533 .14244 L p F P
0 g
s
0 0 .465 r
.6077 .20173 m .60708 .20669 L .60879 .21138 L p F P
0 g
s
0 0 .405 r
.60708 .20669 m .6077 .20173 L .60648 .19689 L p F P
0 g
s
.424 .433 .764 r
.6384 .32298 m .63925 .32167 L p .64273 .33047 L F P
0 g
s
.405 .419 .761 r
.6384 .32298 m .63767 .32094 L .63925 .32167 L closepath p F P
0 g
s
.302 .356 .753 r
.80501 .27494 m .80241 .27304 L .80337 .27036 L closepath p F P
0 g
s
.329 .387 .77 r
.80193 .26653 m .79854 .26436 L p .80241 .27304 L F P
0 g
s
.329 .387 .77 r
.80241 .27304 m .80337 .27036 L .80193 .26653 L p F P
0 g
s
.558 .599 .85 r
.69318 .39896 m .70551 .39879 L p .70546 .40422 L F P
0 g
s
.537 .58 .845 r
.70254 .39328 m .70551 .39879 L .69318 .39896 L p F P
0 g
s
.537 .58 .845 r
.69535 .39315 m .70254 .39328 L p .69318 .39896 L F P
0 g
s
.537 .58 .845 r
.69318 .39896 m .69216 .39697 L .69535 .39315 L p F P
0 g
s
.375 .458 .818 r
.77742 .23146 m .78473 .23446 L .78352 .23942 L p F P
0 g
s
.374 .461 .821 r
.77845 .22654 m .77742 .23146 L .78473 .23446 L p F P
0 g
s
.386 .476 .83 r
.77396 .22491 m .77845 .22654 L .77742 .23146 L p F P
0 g
s
.219 .252 .683 r
.61434 .24804 m .61564 .24438 L p .61734 .2538 L F P
0 g
s
.219 .252 .683 r
.61734 .2538 m .61533 .25153 L .61434 .24804 L p F P
0 g
s
.408 .417 .758 r
.63925 .32167 m .63767 .32094 L .63526 .3141 L p F P
0 g
s
.69 .861 .964 r
.76543 .41295 m .75951 .41571 L .75678 .41298 L p F P
0 g
s
.659 .809 .955 r
.74456 .41709 m .75678 .41298 L .75951 .41571 L p F P
0 g
s
.479 .487 .788 r
.65578 .35603 m .66256 .35785 L p .66131 .36419 L F P
0 g
s
.456 .483 .798 r
.66256 .35785 m .65578 .35603 L .65953 .35055 L closepath p F P
0 g
s
.467 .475 .782 r
.65946 .35036 m .65953 .35055 L .65578 .35603 L p F P
0 g
s
.467 .475 .782 r
.65091 .34768 m .65946 .35036 L p .65578 .35603 L F P
0 g
s
.432 .453 .781 r
.65091 .34768 m .65946 .35036 L .65635 .34264 L p F P
0 g
s
.432 .453 .781 r
.65635 .34264 m .65469 .34205 L .65091 .34768 L p F P
0 g
s
.454 .461 .777 r
.64659 .33915 m .65469 .34205 L .65091 .34768 L p F P
0 g
s
.479 .59 .887 r
.71477 .1731 m .72523 .17402 L .72231 .16892 L p F P
0 g
s
.479 .59 .887 r
.72231 .16892 m .71489 .16831 L .71477 .1731 L p F P
0 g
s
.484 .595 .889 r
.70983 .16797 m .71489 .16831 L .71477 .1731 L p F P
0 g
s
.478 .583 .882 r
.71477 .1731 m .72523 .17402 L p .72678 .17906 L F P
0 g
s
.426 .527 .858 r
.75579 .20406 m .75241 .20328 L .74949 .19758 L p F P
0 g
s
.47 .496 .803 r
.66565 .36517 m .66131 .36419 L .66378 .36076 L closepath p F P
0 g
s
.479 .487 .788 r
.66256 .35785 m .66378 .36076 L .66131 .36419 L p F P
0 g
s
.481 .507 .807 r
.66565 .36517 m .66131 .36419 L p .6676 .3721 L F P
0 g
s
.22 .252 .683 r
.61655 .2558 m .61533 .25153 L .61734 .2538 L closepath p F P
0 g
s
.319 .381 .769 r
.80193 .26653 m .79854 .26436 L .79975 .26075 L closepath p F P
0 g
s
.345 .41 .785 r
.79889 .25858 m .7941 .25587 L p .79854 .26436 L F P
0 g
s
.345 .41 .785 r
.79854 .26436 m .79975 .26075 L .79889 .25858 L p F P
0 g
s
.362 .439 .806 r
.78352 .23942 m .79046 .24256 L .78908 .24755 L p F P
0 g
s
.368 .45 .813 r
.78473 .23446 m .78352 .23942 L .79046 .24256 L p F P
0 g
s
.644 .781 .946 r
.75678 .41298 m .74456 .41709 L .74175 .41356 L p F P
0 g
s
.424 .453 .786 r
.65026 .33353 m .64659 .33915 L .65469 .34205 L p F P
0 g
s
.44 .447 .771 r
.64273 .33047 m .65026 .33353 L .64659 .33915 L p F P
0 g
s
.455 .562 .875 r
.7375 .18548 m .73106 .18453 L .72814 .17921 L p F P
0 g
s
.408 .417 .758 r
.63526 .3141 m .63608 .31277 L p .63925 .32167 L F P
0 g
s
.387 .402 .754 r
.63526 .3141 m .63451 .31194 L .63608 .31277 L closepath p F P
0 g
s
.26 .297 .712 r
.62177 .2732 m .62103 .27251 L .62133 .27177 L closepath p F P
0 g
s
.249 .285 .704 r
.62103 .27251 m .62133 .27177 L .61888 .26371 L p F P
0 g
s
.173 .182 .627 r
.81628 .31141 m .81505 .31407 L .81777 .31871 L p F P
0 g
s
.213 .229 .66 r
.81461 .30507 m .81417 .30446 L p .81505 .31407 L F P
0 g
s
.213 .229 .66 r
.81505 .31407 m .81628 .31141 L .81461 .30507 L p F P
0 g
s
.354 .429 .8 r
.79046 .24256 m .78908 .24755 L .79564 .25084 L p F P
0 g
s
.354 .425 .796 r
.7941 .25587 m .79564 .25084 L .78908 .24755 L p F P
0 g
s
.332 .401 .783 r
.7941 .25587 m .79889 .25858 L .79587 .25097 L p F P
0 g
s
.332 .401 .783 r
.79587 .25097 m .79564 .25084 L .7941 .25587 L p F P
0 g
s
.593 .651 .876 r
.71141 .40915 m .72373 .40773 L p .72471 .41249 L F P
0 g
s
.565 .646 .889 r
.72373 .40773 m .71141 .40915 L .70847 .40409 L p F P
0 g
s
.256 .283 .698 r
.61655 .2558 m .61734 .2538 L p .6191 .26318 L F P
0 g
s
.256 .283 .698 r
.6191 .26318 m .61856 .26264 L .61655 .2558 L p F P
0 g
s
.39 .401 .751 r
.63608 .31277 m .63451 .31194 L .63225 .30536 L p F P
0 g
s
.004 0 .46 r
.81889 .33376 m .81632 .33891 L .81715 .34418 L p F P
0 g
s
.077 .057 .53 r
.81632 .33891 m .81889 .33376 L .81739 .32871 L p F P
0 g
s
.483 .509 .809 r
.66872 .37231 m .6676 .3721 L .66826 .37123 L closepath p F P
0 g
s
.481 .507 .807 r
.6676 .3721 m .66826 .37123 L .66565 .36517 L p F P
0 g
s
.407 .437 .78 r
.64623 .32488 m .64273 .33047 L .65026 .33353 L p F P
0 g
s
.424 .433 .764 r
.63925 .32167 m .64623 .32488 L .64273 .33047 L p F P
0 g
s
.535 .578 .844 r
.69216 .39697 m .69018 .39306 L .69535 .39315 L closepath p F P
0 g
s
.039 .117 .618 r
.61238 .22547 m .61112 .23059 L .61398 .23494 L p F P
0 g
s
.096 .142 .62 r
.60993 .221 m .61238 .22547 L .61112 .23059 L p F P
0 g
s
.367 .384 .746 r
.63225 .30536 m .63134 .30269 L .63317 .30377 L closepath p F P
0 g
s
.39 .401 .751 r
.63225 .30536 m .63317 .30377 L p .63608 .31277 L F P
0 g
s
0 0 0 r
.80912 .37188 m .81211 .36668 L p .80675 .37761 L F P
0 g
s
0 0 0 r
.80675 .37761 m .80701 .3769 L .80912 .37188 L p F P
0 g
s
0 0 .081 r
.80912 .37188 m .81211 .36668 L .81385 .36059 L p F P
0 g
s
.255 .283 .698 r
.61888 .26371 m .61856 .26264 L .6191 .26318 L closepath p F P
0 g
s
.267 .297 .707 r
.6191 .26318 m .61888 .26371 L .62133 .27177 L p F P
0 g
s
.37 .384 .744 r
.63317 .30377 m .63134 .30269 L .62936 .29677 L p F P
0 g
s
.44 .538 .86 r
.74949 .19758 m .74683 .19705 L .74738 .19348 L closepath p F P
0 g
s
.448 .547 .865 r
.74658 .19196 m .74738 .19348 L .74683 .19705 L p F P
0 g
s
.37 .384 .744 r
.62936 .29677 m .63048 .2947 L p .63317 .30377 L F P
0 g
s
.346 .365 .738 r
.62936 .29677 m .62816 .29316 L .63048 .2947 L closepath p F P
0 g
s
.388 .421 .773 r
.64256 .31611 m .63925 .32167 L .64623 .32488 L p F P
0 g
s
.408 .417 .758 r
.63608 .31277 m .64256 .31611 L .63925 .32167 L p F P
0 g
s
.298 .323 .718 r
.62133 .27177 m .62333 .26714 L p .62559 .27638 L F P
0 g
s
.298 .323 .718 r
.62559 .27638 m .62177 .2732 L .62133 .27177 L p F P
0 g
s
.267 .297 .707 r
.62133 .27177 m .62333 .26714 L .6191 .26318 L p F P
0 g
s
.349 .365 .736 r
.63048 .2947 m .62816 .29316 L .62658 .28831 L p F P
0 g
s
.297 .323 .719 r
.6239 .27998 m .62177 .2732 L .62559 .27638 L closepath p F P
0 g
s
0 0 .344 r
.60669 .19204 m .60648 .19689 L .6077 .20173 L p F P
0 g
s
0 0 .243 r
.60648 .19689 m .60669 .19204 L .60597 .18704 L p F P
0 g
s
.349 .365 .736 r
.62658 .28831 m .62797 .28557 L p .63048 .2947 L F P
0 g
s
.323 .345 .729 r
.62658 .28831 m .62497 .28333 L .62797 .28557 L closepath p F P
0 g
s
.507 .529 .813 r
.66872 .37231 m .67941 .37395 L .6752 .37961 L p F P
0 g
s
.495 .516 .808 r
.67941 .37395 m .66872 .37231 L .66826 .37123 L p F P
0 g
s
.325 .345 .728 r
.6239 .27998 m .62559 .27638 L p .62797 .28557 L F P
0 g
s
.325 .345 .728 r
.62797 .28557 m .62497 .28333 L .6239 .27998 L p F P
0 g
s
0 0 .26 r
.81508 .35401 m .81462 .35481 L .81385 .36059 L p F P
0 g
s
.69 .861 .964 r
.76939 .4082 m .76543 .41295 L p .75678 .41298 L F P
0 g
s
.72 .88 .955 r
.76543 .41295 m .76939 .4082 L .77164 .40991 L closepath p F P
0 g
s
.214 .266 .701 r
.62116 .25787 m .6191 .26318 L .62333 .26714 L p F P
0 g
s
.256 .283 .698 r
.61734 .2538 m .62116 .25787 L .6191 .26318 L p F P
0 g
s
.509 .62 .897 r
.69159 .15803 m .70139 .15807 L .7013 .16288 L p F P
0 g
s
.511 .624 .9 r
.70139 .15807 m .69159 .15803 L .68866 .1533 L p F P
0 g
s
.518 .541 .819 r
.6752 .37961 m .68414 .38068 L p .68416 .38671 L F P
0 g
s
.49 .522 .817 r
.6752 .37961 m .68414 .38068 L .68109 .37421 L p F P
0 g
s
.49 .522 .817 r
.68109 .37421 m .67941 .37395 L .6752 .37961 L p F P
0 g
s
.841 .913 .884 r
.61099 .1508 m .61343 .15226 L .62005 .14651 L p F P
0 g
s
.914 .893 .795 r
.61169 .15458 m .61099 .1508 L .61343 .15226 L closepath p F P
0 g
s
.242 .286 .709 r
.80952 .28809 m .8103 .28588 L p .81255 .29508 L F P
0 g
s
.242 .286 .709 r
.81255 .29508 m .81131 .29382 L .80952 .28809 L p F P
0 g
s
.264 .316 .73 r
.80952 .28809 m .80813 .28395 L .8103 .28588 L closepath p F P
0 g
s
.495 .516 .808 r
.66826 .37123 m .67196 .36636 L p .67941 .37395 L F P
0 g
s
.482 .507 .807 r
.66826 .37123 m .66565 .36517 L .67196 .36636 L closepath p F P
0 g
s
.764 .688 .143 r
.60579 .17707 m .6065 .17161 L p .60576 .17777 L F P
0 g
s
.818 .716 .184 r
.60653 .16677 m .6065 .17161 L .60579 .17707 L p F P
0 g
s
.818 .716 .184 r
.60587 .17222 m .60653 .16677 L p .60605 .17342 L F P
0 g
s
.818 .716 .184 r
.60579 .17707 m .60587 .17222 L p .60605 .17342 L F P
0 g
s
0 0 .055 r
.60587 .17222 m .60579 .17707 L p .60589 .17476 L F P
0 g
s
0 0 .055 r
.60602 .1774 m .60587 .17222 L p .60592 .17808 L F P
0 g
s
0 0 .055 r
.60596 .18224 m .60602 .1774 L p .60592 .17808 L F P
0 g
s
0 0 .143 r
.60602 .1774 m .60677 .1824 L p .60611 .17673 L F P
0 g
s
.762 .595 .025 r
.60587 .17222 m .60602 .1774 L p .60568 .17101 L F P
0 g
s
.762 .595 .025 r
.60564 .17269 m .6055 .1675 L p .60581 .17351 L F P
0 g
s
.762 .595 .025 r
.60602 .1774 m .60564 .17269 L p .60581 .17351 L F P
0 g
s
0 0 .143 r
.60636 .1777 m .60564 .17269 L p .60627 .17805 L F P
0 g
s
0 0 .143 r
.60677 .1824 m .60636 .1777 L p .60627 .17805 L F P
0 g
s
0 0 .191 r
.60636 .1777 m .60751 .18257 L p .60645 .17734 L F P
0 g
s
0 0 .191 r
.60558 .17311 m .60636 .1777 L p .60645 .17734 L F P
0 g
s
.733 .513 0 r
.60564 .17269 m .60636 .1777 L p .60547 .17186 L F P
0 g
s
.733 .513 0 r
.6049 .16808 m .60564 .17269 L p .60547 .17186 L F P
0 g
s
0 0 .143 r
.60564 .17269 m .60602 .1774 L p .60611 .17673 L F P
0 g
s
.762 .595 .025 r
.6055 .1675 m .60587 .17222 L p .60568 .17101 L F P
0 g
s
0 0 .055 r
.60579 .17707 m .60596 .18224 L p .60589 .17476 L F P
0 g
s
.764 .688 .143 r
.6057 .17829 m .60579 .17707 L p .60576 .17777 L F P
0 g
s
.943 .877 .465 r
.6065 .17161 m .60653 .16677 L .60832 .16094 L p F P
0 g
s
.243 .286 .708 r
.81209 .29629 m .81131 .29382 L .81255 .29508 L closepath p F P
0 g
s
.206 .245 .682 r
.81255 .29508 m .81209 .29629 L .81435 .30407 L p F P
0 g
s
.241 .268 .689 r
.81417 .30446 m .81435 .30407 L .81209 .29629 L p F P
0 g
s
.263 .316 .73 r
.8103 .28588 m .80813 .28395 L .80662 .27946 L p F P
0 g
s
.383 .475 .83 r
.77845 .22654 m .77396 .22491 L .7715 .2196 L p F P
0 g
s
.841 .913 .884 r
.62005 .14651 m .61927 .14191 L p .61099 .1508 L F P
0 g
s
.778 .813 .88 r
.6223 .13962 m .61927 .14191 L .62005 .14651 L p F P
0 g
s
.778 .813 .88 r
.62005 .14651 m .62528 .1429 L .6223 .13962 L p F P
0 g
s
.2 .221 .658 r
.81461 .30507 m .81417 .30446 L .81435 .30407 L closepath p F P
0 g
s
.367 .403 .766 r
.63917 .30725 m .63608 .31277 L .64256 .31611 L p F P
0 g
s
.39 .401 .751 r
.63317 .30377 m .63917 .30725 L .63608 .31277 L p F P
0 g
s
.538 .649 .906 r
.67343 .14946 m .68551 .14862 L .68545 .15345 L p F P
0 g
s
.542 .654 .908 r
.68551 .14862 m .67343 .14946 L .67048 .14498 L p F P
0 g
s
.263 .316 .73 r
.80662 .27946 m .80748 .27686 L p .8103 .28588 L F P
0 g
s
.283 .344 .749 r
.80662 .27946 m .80501 .27494 L .80748 .27686 L closepath p F P
0 g
s
.558 .599 .85 r
.70551 .39879 m .70725 .40189 L .70546 .40422 L p F P
0 g
s
.554 .613 .866 r
.70847 .40409 m .70546 .40422 L .70725 .40189 L closepath p F P
0 g
s
.59 .67 .895 r
.72662 .41221 m .72471 .41249 L .72582 .41098 L closepath p F P
0 g
s
.593 .651 .876 r
.72373 .40773 m .72582 .41098 L .72471 .41249 L p F P
0 g
s
.974 .916 .677 r
.61099 .1508 m .61169 .15458 L .60832 .16094 L p F P
0 g
s
.484 .598 .891 r
.71489 .16831 m .70983 .16797 L .7069 .16302 L p F P
0 g
s
.508 .615 .894 r
.7013 .16288 m .7069 .16302 L .70398 .15811 L p F P
0 g
s
.508 .615 .894 r
.70398 .15811 m .70139 .15807 L .7013 .16288 L p F P
0 g
s
.636 .718 .907 r
.65237 .13826 m .64026 .14143 L .63728 .13757 L p F P
0 g
s
.698 .757 .897 r
.62528 .1429 m .63728 .13757 L .64026 .14143 L p F P
0 g
s
.627 .711 .907 r
.64026 .14143 m .65237 .13826 L .65533 .14244 L p F P
0 g
s
0 .042 .573 r
.61081 .21597 m .60993 .221 L .61238 .22547 L p F P
0 g
s
0 .013 .546 r
.60993 .221 m .61081 .21597 L .60879 .21138 L p F P
0 g
s
0 0 .364 r
.81508 .35401 m .81726 .34968 L .81715 .34418 L p F P
0 g
s
0 0 .233 r
.81726 .34968 m .81508 .35401 L .81495 .35869 L p F P
0 g
s
0 0 .26 r
.81385 .36059 m .81495 .35869 L .81508 .35401 L p F P
0 g
s
.174 .204 .652 r
.81435 .30407 m .81611 .29943 L p .81726 .30897 L F P
0 g
s
.174 .204 .652 r
.81726 .30897 m .81461 .30507 L .81435 .30407 L p F P
0 g
s
.206 .245 .682 r
.81435 .30407 m .81611 .29943 L .81255 .29508 L p F P
0 g
s
.537 .573 .838 r
.69535 .39315 m .69018 .39306 L .68717 .38697 L p F P
0 g
s
.282 .344 .749 r
.80748 .27686 m .80501 .27494 L .80337 .27036 L p F P
0 g
s
.176 .204 .652 r
.81628 .31141 m .81461 .30507 L .81726 .30897 L closepath p F P
0 g
s
.424 .523 .855 r
.75644 .19918 m .75579 .20406 L .7649 .20639 L p F P
0 g
s
.426 .527 .858 r
.74949 .19758 m .75644 .19918 L .75579 .20406 L p F P
0 g
s
.416 .512 .849 r
.75579 .20406 m .7649 .20639 L .76401 .21133 L p F P
0 g
s
.58 .681 .91 r
.66436 .14581 m .67048 .14498 L .66753 .14054 L p F P
0 g
s
.58 .681 .91 r
.66753 .14054 m .66406 .14107 L .66436 .14581 L p F P
0 g
s
.574 .684 .915 r
.65533 .14244 m .66406 .14107 L .66436 .14581 L p F P
0 g
s
.713 .766 .894 r
.63728 .13757 m .62528 .1429 L .6223 .13962 L p F P
0 g
s
.472 .575 .877 r
.72814 .17921 m .72678 .17906 L .72697 .1771 L closepath p F P
0 g
s
.478 .583 .882 r
.72523 .17402 m .72697 .1771 L .72678 .17906 L p F P
0 g
s
0 0 0 r
.8063 .3783 m .80675 .37761 L .80701 .3769 L closepath p F P
0 g
s
.344 .384 .759 r
.63602 .29831 m .63317 .30377 L .63917 .30725 L p F P
0 g
s
.37 .384 .744 r
.63048 .2947 m .63602 .29831 L .63317 .30377 L p F P
0 g
s
.132 .127 .584 r
.81817 .31964 m .81777 .31871 L p .81739 .32871 L F P
0 g
s
.132 .127 .584 r
.81739 .32871 m .81923 .32492 L .81817 .31964 L p F P
0 g
s
.073 .055 .53 r
.81923 .32492 m .81739 .32871 L .81889 .33376 L p F P
0 g
s
.165 .229 .684 r
.61906 .24857 m .61734 .2538 L .62116 .25787 L p F P
0 g
s
.219 .252 .683 r
.61564 .24438 m .61906 .24857 L .61734 .2538 L p F P
0 g
s
.282 .344 .749 r
.80337 .27036 m .80409 .26801 L p .80748 .27686 L F P
0 g
s
.302 .37 .766 r
.80337 .27036 m .80193 .26653 L .80409 .26801 L closepath p F P
0 g
s
.607 .716 .922 r
.72662 .41221 m .73892 .40976 L .74175 .41356 L p F P
0 g
s
.599 .674 .893 r
.73606 .40571 m .73892 .40976 L .72662 .41221 L p F P
0 g
s
.599 .674 .893 r
.72947 .40679 m .73606 .40571 L p .72662 .41221 L F P
0 g
s
.599 .674 .893 r
.72662 .41221 m .72582 .41098 L .72947 .40679 L p F P
0 g
s
.424 .528 .86 r
.75644 .19918 m .74949 .19758 L .74738 .19348 L p F P
0 g
s
0 0 .196 r
.60587 .1835 m .60597 .18704 L .60669 .19204 L p F P
0 g
s
0 0 .026 r
.60597 .18704 m .60587 .1835 L .6057 .17829 L p F P
0 g
s
.511 .552 .834 r
.68717 .38697 m .68416 .38671 L .68591 .38438 L closepath p F P
0 g
s
.518 .541 .819 r
.68414 .38068 m .68591 .38438 L .68416 .38671 L p F P
0 g
s
.734 .965 .938 r
.77164 .40991 m .78368 .40251 L .7843 .40271 L p F P
0 g
s
.768 .89 .931 r
.76939 .4082 m .77164 .40991 L .78368 .40251 L p F P
0 g
s
.606 .812 .404 r
.80675 .37761 m .8063 .3783 L .8017 .38527 L p F P
0 g
s
.206 .248 .685 r
.81436 .29006 m .81255 .29508 L .81611 .29943 L p F P
0 g
s
.242 .286 .709 r
.8103 .28588 m .81436 .29006 L .81255 .29508 L p F P
0 g
s
.484 .504 .803 r
.67196 .36636 m .66565 .36517 L .66378 .36076 L p F P
0 g
s
.541 .644 .901 r
.68545 .15345 m .68866 .1533 L .68572 .14861 L p F P
0 g
s
.541 .644 .901 r
.68572 .14861 m .68551 .14862 L .68545 .15345 L p F P
0 g
s
.58 .691 .917 r
.66406 .14107 m .65533 .14244 L .65237 .13826 L p F P
0 g
s
.301 .37 .767 r
.80409 .26801 m .80193 .26653 L .79975 .26075 L p F P
0 g
s
0 0 .112 r
.60579 .17707 m .6057 .17829 L .60587 .1835 L p F P
0 g
s
.455 .562 .875 r
.72814 .17921 m .73791 .18062 L .7375 .18548 L p F P
0 g
s
.454 .565 .877 r
.73791 .18062 m .72814 .17921 L .72697 .1771 L p F P
0 g
s
.131 .153 .616 r
.81726 .30897 m .81628 .31141 L .81792 .31839 L p F P
0 g
s
.173 .182 .627 r
.81777 .31871 m .81792 .31839 L .81628 .31141 L p F P
0 g
s
.565 .646 .889 r
.70847 .40409 m .72081 .40303 L .72373 .40773 L p F P
0 g
s
.559 .616 .866 r
.71788 .39813 m .72081 .40303 L .70847 .40409 L p F P
0 g
s
.559 .616 .866 r
.71 .39854 m .71788 .39813 L p .70847 .40409 L F P
0 g
s
.559 .616 .866 r
.70847 .40409 m .70725 .40189 L .71 .39854 L p F P
0 g
s
.318 .363 .751 r
.63307 .2893 m .63048 .2947 L .63602 .29831 L p F P
0 g
s
.349 .365 .736 r
.62797 .28557 m .63307 .2893 L .63048 .2947 L p F P
0 g
s
0 0 .507 r
.6093 .20645 m .60879 .21138 L .61081 .21597 L p F P
0 g
s
0 0 .465 r
.60879 .21138 m .6093 .20645 L .6077 .20173 L p F P
0 g
s
.406 .501 .844 r
.76401 .21133 m .76809 .21252 L .76516 .20647 L p F P
0 g
s
.406 .501 .844 r
.76516 .20647 m .7649 .20639 L .76401 .21133 L p F P
0 g
s
.383 .475 .83 r
.7715 .2196 m .77165 .21879 L p .77845 .22654 L F P
0 g
s
.396 .492 .84 r
.7715 .2196 m .77102 .21859 L .77165 .21879 L closepath p F P
0 g
s
.833 .989 .865 r
.79537 .39276 m .78511 .40145 L .7843 .40271 L p F P
0 g
s
.793 .972 .911 r
.78368 .40251 m .78511 .40145 L .7843 .40271 L closepath p F P
0 g
s
.598 .673 .893 r
.72582 .41098 m .72373 .40773 L .72947 .40679 L closepath p F P
0 g
s
0 0 0 r
.80925 .37312 m .80675 .37761 L p .80701 .37708 L F P
0 g
s
0 0 0 r
.81211 .36668 m .80925 .37312 L p .80701 .37708 L F P
0 g
s
0 0 0 r
.81435 .36281 m .81211 .36668 L .80925 .37312 L p F P
0 g
s
0 0 0 r
.81385 .36445 m .81435 .36281 L p .80925 .37312 L F P
0 g
s
0 0 0 r
.80925 .37312 m .81221 .36791 L .81385 .36445 L p F P
0 g
s
.71 .878 .481 r
.80925 .37312 m .80511 .37996 L p .81181 .36859 L F P
0 g
s
.71 .878 .481 r
.81221 .36791 m .80925 .37312 L p .81181 .36859 L F P
0 g
s
.664 .837 .42 r
.80925 .37312 m .80675 .37761 L .80495 .38024 L p F P
0 g
s
.606 .812 .404 r
.8017 .38527 m .80495 .38024 L .80675 .37761 L p F P
0 g
s
.107 .184 .662 r
.61702 .23924 m .61564 .24438 L .61906 .24857 L p F P
0 g
s
.115 .177 .651 r
.61564 .24438 m .61702 .23924 L .61398 .23494 L p F P
0 g
s
0 0 .362 r
.81974 .33903 m .81715 .34418 L .81726 .34968 L p F P
0 g
s
.004 0 .46 r
.81715 .34418 m .81974 .33903 L .81889 .33376 L p F P
0 g
s
.234 .285 .711 r
.812 .28087 m .8103 .28588 L .81436 .29006 L p F P
0 g
s
.263 .316 .73 r
.80748 .27686 m .812 .28087 L .8103 .28588 L p F P
0 g
s
.393 .493 .842 r
.77165 .21879 m .77102 .21859 L .76809 .21252 L p F P
0 g
s
.972 .873 .488 r
.60774 .15629 m .60832 .16094 L .60653 .16677 L p F P
0 g
s
.974 .916 .677 r
.61048 .15064 m .61099 .1508 L p .60832 .16094 L F P
0 g
s
.974 .916 .677 r
.60832 .16094 m .60774 .15629 L .61048 .15064 L p F P
0 g
s
.484 .504 .803 r
.66378 .36076 m .66541 .3585 L p .67196 .36636 L F P
0 g
s
.469 .495 .802 r
.66378 .36076 m .66256 .35785 L .66541 .3585 L closepath p F P
0 g
s
.644 .781 .946 r
.74175 .41356 m .75401 .40993 L .75678 .41298 L p F P
0 g
s
.629 .755 .938 r
.75401 .40993 m .74175 .41356 L .73892 .40976 L p F P
0 g
s
.301 .37 .767 r
.79975 .26075 m .80015 .25933 L p .80409 .26801 L F P
0 g
s
.319 .393 .782 r
.79975 .26075 m .79889 .25858 L .80015 .25933 L closepath p F P
0 g
s
0 0 .087 r
.81495 .35869 m .81385 .36059 L .81211 .36668 L p F P
0 g
s
.69 .861 .964 r
.75678 .41298 m .76896 .40785 L .76939 .4082 L p F P
0 g
s
.674 .832 .96 r
.76896 .40785 m .75678 .41298 L .75401 .40993 L p F P
0 g
s
.289 .34 .741 r
.63027 .28023 m .62797 .28557 L .63307 .2893 L p F P
0 g
s
.325 .345 .728 r
.62559 .27638 m .63027 .28023 L .62797 .28557 L p F P
0 g
s
.383 .475 .83 r
.77165 .21879 m .7794 .22162 L .77845 .22654 L p F P
0 g
s
.382 .479 .834 r
.77241 .21391 m .77165 .21879 L .7794 .22162 L p F P
0 g
s
.393 .493 .842 r
.76809 .21252 m .77241 .21391 L .77165 .21879 L p F P
0 g
s
.448 .555 .872 r
.7375 .18548 m .74367 .18651 L .74075 .18109 L p F P
0 g
s
.448 .555 .872 r
.74075 .18109 m .73791 .18062 L .7375 .18548 L p F P
0 g
s
.118 .117 .581 r
.81817 .31964 m .81777 .31871 L .81792 .31839 L closepath p F P
0 g
s
.454 .565 .877 r
.72697 .1771 m .72705 .17424 L p .73791 .18062 L F P
0 g
s
.463 .576 .883 r
.72697 .1771 m .72523 .17402 L .72705 .17424 L closepath p F P
0 g
s
.318 .393 .783 r
.80015 .25933 m .79889 .25858 L .79587 .25097 L p F P
0 g
s
.841 .994 .748 r
.8017 .38527 m .80495 .38024 L p .79549 .3926 L F P
0 g
s
.841 .994 .748 r
.79549 .3926 m .79556 .39258 L .8017 .38527 L p F P
0 g
s
0 0 .112 r
.60587 .1835 m .60596 .18224 L .60579 .17707 L p F P
0 g
s
.558 .614 .865 r
.70725 .40189 m .70551 .39879 L .71 .39854 L closepath p F P
0 g
s
.537 .573 .838 r
.68717 .38697 m .69931 .38761 L .69535 .39315 L p F P
0 g
s
.525 .56 .833 r
.69931 .38761 m .68717 .38697 L .68591 .38438 L p F P
0 g
s
.472 .492 .798 r
.66541 .3585 m .66256 .35785 L .65953 .35055 L p F P
0 g
s
.258 .317 .734 r
.80906 .27187 m .80748 .27686 L .812 .28087 L p F P
0 g
s
.282 .344 .749 r
.80409 .26801 m .80906 .27187 L .80748 .27686 L p F P
0 g
s
.434 .542 .866 r
.74738 .19348 m .74658 .19196 L .74751 .19214 L closepath p F P
0 g
s
.424 .528 .86 r
.74738 .19348 m .74751 .19214 L p .75644 .19918 L F P
0 g
s
.086 .095 .571 r
.81792 .31839 m .81983 .31367 L p .81981 .32359 L F P
0 g
s
.086 .095 .571 r
.81981 .32359 m .81817 .31964 L .81792 .31839 L p F P
0 g
s
.131 .153 .616 r
.81792 .31839 m .81983 .31367 L .81726 .30897 L p F P
0 g
s
.514 .628 .901 r
.70105 .15326 m .68866 .1533 L .68572 .14861 L p F P
0 g
s
.511 .624 .9 r
.68866 .1533 m .70105 .15326 L p .70139 .15807 L F P
0 g
s
0 0 .433 r
.60785 .1969 m .6077 .20173 L .6093 .20645 L p F P
0 g
s
0 0 .344 r
.6077 .20173 m .60785 .1969 L .60669 .19204 L p F P
0 g
s
.782 .951 .928 r
.78511 .40145 m .78368 .40251 L .78109 .40124 L p F P
0 g
s
.768 .89 .931 r
.78368 .40251 m .78109 .40124 L p .76939 .4082 L F P
0 g
s
.48 .593 .888 r
.71489 .16831 m .72231 .16892 L .71939 .16386 L p F P
0 g
s
.48 .593 .888 r
.71939 .16386 m .71495 .16352 L .71489 .16831 L p F P
0 g
s
.484 .598 .891 r
.7069 .16302 m .71495 .16352 L .71489 .16831 L p F P
0 g
s
.036 .13 .633 r
.61503 .22988 m .61398 .23494 L .61702 .23924 L p F P
0 g
s
.039 .117 .618 r
.61398 .23494 m .61503 .22988 L .61238 .22547 L p F P
0 g
s
.519 .569 .846 r
.69535 .39315 m .70254 .39328 L .69955 .38762 L p F P
0 g
s
.519 .569 .846 r
.69955 .38762 m .69931 .38761 L .69535 .39315 L p F P
0 g
s
.374 .461 .821 r
.78473 .23446 m .78587 .2295 L .77845 .22654 L p F P
0 g
s
.377 .468 .827 r
.7794 .22162 m .77845 .22654 L .78587 .2295 L p F P
0 g
s
.782 .951 .928 r
.78109 .40124 m .78844 .39619 L .78511 .40145 L p F P
0 g
s
.797 .977 .905 r
.79549 .3926 m .79537 .39276 L .78511 .40145 L p F P
0 g
s
.797 .977 .905 r
.79309 .39261 m .79549 .3926 L p .78511 .40145 L F P
0 g
s
.797 .977 .905 r
.78511 .40145 m .78844 .39619 L .79309 .39261 L p F P
0 g
s
.485 .601 .893 r
.71495 .16352 m .7069 .16302 L .70398 .15811 L p F P
0 g
s
.088 .096 .571 r
.81923 .32492 m .81817 .31964 L .81981 .32359 L closepath p F P
0 g
s
.257 .314 .731 r
.62761 .27111 m .62559 .27638 L .63027 .28023 L p F P
0 g
s
.298 .323 .718 r
.62333 .26714 m .62761 .27111 L .62559 .27638 L p F P
0 g
s
.278 .346 .753 r
.80554 .26304 m .80409 .26801 L .80906 .27187 L p F P
0 g
s
.301 .37 .767 r
.80015 .25933 m .80554 .26304 L .80409 .26801 L p F P
0 g
s
.542 .654 .908 r
.67048 .14498 m .68278 .14404 L p .68551 .14862 L F P
0 g
s
.548 .657 .907 r
.68278 .14404 m .67048 .14498 L .66753 .14054 L p F P
0 g
s
.766 .99 .771 r
.79537 .39276 m .79549 .3926 L .79556 .39258 L closepath p F P
0 g
s
.368 .45 .813 r
.7899 .23677 m .78473 .23446 L p .79046 .24256 L F P
0 g
s
.356 .442 .812 r
.78473 .23446 m .7899 .23677 L .78693 .22998 L p F P
0 g
s
.356 .442 .812 r
.78693 .22998 m .78587 .2295 L .78473 .23446 L p F P
0 g
s
.525 .56 .833 r
.68591 .38438 m .6885 .38104 L p .69931 .38761 L F P
0 g
s
.513 .552 .833 r
.68591 .38438 m .68414 .38068 L .6885 .38104 L closepath p F P
0 g
s
.432 .543 .869 r
.74751 .19214 m .74658 .19196 L .74367 .18651 L p F P
0 g
s
.296 .371 .77 r
.80145 .25438 m .80015 .25933 L .80554 .26304 L p F P
0 g
s
.318 .393 .783 r
.79587 .25097 m .80145 .25438 L .80015 .25933 L p F P
0 g
s
.815 .999 .836 r
.79309 .39261 m .79842 .38757 L .79549 .3926 L closepath p F P
0 g
s
.841 .994 .748 r
.80483 .38034 m .79842 .38757 L .79549 .3926 L p F P
0 g
s
.841 .994 .748 r
.80495 .38024 m .80483 .38034 L p .79549 .3926 L F P
0 g
s
.354 .429 .8 r
.79288 .24378 m .79046 .24256 L p .79564 .25084 L F P
0 g
s
.344 .424 .8 r
.79288 .24378 m .79046 .24256 L .7912 .23975 L closepath p F P
0 g
s
.368 .45 .813 r
.79046 .24256 m .7912 .23975 L .7899 .23677 L p F P
0 g
s
.354 .429 .8 r
.79564 .25084 m .79572 .25058 L .79288 .24378 L p F P
0 g
s
.328 .401 .786 r
.79587 .25097 m .79564 .25084 L .79572 .25058 L closepath p F P
0 g
s
.926 .932 .79 r
.61048 .15064 m .61098 .14997 L .61099 .1508 L closepath p F P
0 g
s
.841 .913 .884 r
.61927 .14191 m .61098 .14997 L .61099 .1508 L p F P
0 g
s
.713 .766 .894 r
.6223 .13962 m .6343 .13376 L .63728 .13757 L p F P
0 g
s
.636 .718 .907 r
.63728 .13757 m .6494 .13413 L .65237 .13826 L p F P
0 g
s
.645 .725 .907 r
.6494 .13413 m .63728 .13757 L .6343 .13376 L p F P
0 g
s
.309 .389 .783 r
.80145 .25438 m .79587 .25097 L .79572 .25058 L p F P
0 g
s
.131 .155 .619 r
.81922 .30394 m .81726 .30897 L .81983 .31367 L p F P
0 g
s
.174 .204 .652 r
.81611 .29943 m .81922 .30394 L .81726 .30897 L p F P
0 g
s
.599 .662 .883 r
.72947 .40679 m .72373 .40773 L .72081 .40303 L p F P
0 g
s
.309 .389 .783 r
.79572 .25058 m .79682 .24591 L p .80145 .25438 L F P
0 g
s
.327 .413 .797 r
.79572 .25058 m .79288 .24378 L .79682 .24591 L closepath p F P
0 g
s
.456 .481 .796 r
.65953 .35055 m .65946 .35036 L .65963 .35041 L closepath p F P
0 g
s
.472 .492 .798 r
.65953 .35055 m .65963 .35041 L p .66541 .3585 L F P
0 g
s
.459 .479 .792 r
.65963 .35041 m .65946 .35036 L .65635 .34264 L p F P
0 g
s
.221 .285 .718 r
.62506 .26194 m .62333 .26714 L .62761 .27111 L p F P
0 g
s
.214 .266 .701 r
.62333 .26714 m .62506 .26194 L .62116 .25787 L p F P
0 g
s
.424 .528 .86 r
.74751 .19214 m .75702 .19431 L .75644 .19918 L p F P
0 g
s
.432 .539 .865 r
.74784 .18733 m .74751 .19214 L .75702 .19431 L p F P
0 g
s
.432 .543 .869 r
.74367 .18651 m .74784 .18733 L .74751 .19214 L p F P
0 g
s
.56 .607 .857 r
.71 .39854 m .70551 .39879 L .70254 .39328 L p F P
0 g
s
0 .081 .606 r
.61309 .2205 m .61238 .22547 L .61503 .22988 L p F P
0 g
s
0 .042 .573 r
.61238 .22547 m .61309 .2205 L .61081 .21597 L p F P
0 g
s
0 0 .458 r
.82022 .33105 m .81889 .33376 L .81974 .33903 L p F P
0 g
s
.073 .055 .53 r
.81889 .33376 m .82022 .33105 L .81923 .32492 L p F P
0 g
s
.472 .492 .798 r
.65963 .35041 m .66908 .35294 L .66541 .3585 L p F P
0 g
s
.443 .485 .807 r
.66334 .34481 m .65963 .35041 L .66908 .35294 L p F P
0 g
s
.459 .479 .792 r
.65635 .34264 m .66334 .34481 L .65963 .35041 L p F P
0 g
s
.427 .456 .788 r
.65635 .34264 m .65469 .34205 L .65555 .34065 L closepath p F P
0 g
s
.424 .453 .786 r
.65322 .33474 m .65026 .33353 L p .65469 .34205 L F P
0 g
s
.424 .453 .786 r
.65469 .34205 m .65555 .34065 L .65322 .33474 L p F P
0 g
s
0 0 .316 r
.60662 .18946 m .60669 .19204 L .60785 .1969 L p F P
0 g
s
0 0 .196 r
.60669 .19204 m .60662 .18946 L .60587 .1835 L p F P
0 g
s
0 0 .057 r
.81658 .35544 m .81495 .35869 L .81435 .36281 L p F P
0 g
s
0 0 .233 r
.81495 .35869 m .81658 .35544 L .81726 .34968 L p F P
0 g
s
0 0 .087 r
.81211 .36668 m .81435 .36281 L .81495 .35869 L p F P
0 g
s
.461 .578 .885 r
.72705 .17424 m .72523 .17402 L .72231 .16892 L p F P
0 g
s
.873 .892 .845 r
.61808 .13743 m .61927 .14191 L .61098 .14997 L p F P
0 g
s
.795 .821 .872 r
.61932 .13642 m .61808 .13743 L .61927 .14191 L p F P
0 g
s
.795 .821 .872 r
.61927 .14191 m .6223 .13962 L .61932 .13642 L p F P
0 g
s
.391 .492 .843 r
.77241 .21391 m .76809 .21252 L .76516 .20647 L p F P
0 g
s
.41 .441 .782 r
.65322 .33474 m .65026 .33353 L .65175 .33095 L closepath p F P
0 g
s
.407 .437 .78 r
.65009 .32666 m .64623 .32488 L p .65026 .33353 L F P
0 g
s
.407 .437 .78 r
.65026 .33353 m .65175 .33095 L .65009 .32666 L p F P
0 g
s
0 0 .283 r
.60596 .18224 m .60587 .1835 L .60662 .18946 L p F P
0 g
s
.484 .504 .803 r
.66541 .3585 m .67497 .36073 L p .67196 .36636 L F P
0 g
s
.452 .483 .8 r
.66541 .3585 m .67497 .36073 L .67189 .35371 L p F P
0 g
s
.452 .483 .8 r
.67189 .35371 m .66908 .35294 L .66541 .3585 L p F P
0 g
s
.889 .751 .247 r
.60611 .16206 m .60653 .16677 L .60587 .17222 L p F P
0 g
s
.972 .873 .488 r
.60653 .16677 m .60611 .16206 L .60774 .15629 L p F P
0 g
s
.873 .892 .845 r
.61098 .14997 m .61062 .14521 L .61808 .13743 L p F P
0 g
s
.945 .926 .757 r
.61098 .14997 m .61048 .15064 L .60755 .14998 L p F P
0 g
s
.945 .926 .757 r
.60755 .14998 m .61062 .14521 L .61098 .14997 L p F P
0 g
s
.728 .774 .889 r
.6343 .13376 m .6223 .13962 L .61932 .13642 L p F P
0 g
s
.022 .02 .514 r
.81981 .32359 m .81923 .32492 L .82022 .33105 L p F P
0 g
s
.515 .548 .828 r
.6885 .38104 m .68414 .38068 L .68109 .37421 L p F P
0 g
s
.971 .893 .691 r
.60774 .15629 m .61048 .15064 L .60755 .14998 L p F P
0 g
s
.388 .421 .773 r
.64695 .3184 m .64256 .31611 L p .64623 .32488 L F P
0 g
s
.388 .421 .773 r
.64623 .32488 m .64809 .32142 L .64695 .3184 L p F P
0 g
s
.392 .425 .776 r
.65009 .32666 m .64623 .32488 L .64809 .32142 L closepath p F P
0 g
s
.731 .872 .947 r
.76896 .40785 m .7699 .40737 L .76939 .4082 L closepath p F P
0 g
s
.768 .89 .931 r
.78109 .40124 m .7699 .40737 L .76939 .4082 L p F P
0 g
s
.587 .697 .918 r
.66389 .13626 m .65237 .13826 L .6494 .13413 L p F P
0 g
s
.58 .691 .917 r
.65237 .13826 m .66389 .13626 L .66406 .14107 L p F P
0 g
s
.507 .616 .895 r
.70398 .15811 m .70139 .15807 L .70142 .15387 L closepath p F P
0 g
s
.511 .624 .9 r
.70105 .15326 m .70142 .15387 L .70139 .15807 L p F P
0 g
s
.474 .514 .819 r
.67804 .36754 m .67196 .36636 L .67524 .36133 L closepath p F P
0 g
s
.484 .504 .803 r
.67497 .36073 m .67524 .36133 L .67196 .36636 L p F P
0 g
s
.495 .516 .808 r
.67196 .36636 m .67804 .36754 L p .67941 .37395 L F P
0 g
s
0 0 .362 r
.81726 .34968 m .81985 .34454 L .81974 .33903 L p F P
0 g
s
0 0 .224 r
.81985 .34454 m .81726 .34968 L .81658 .35544 L p F P
0 g
s
.179 .253 .703 r
.62259 .25275 m .62116 .25787 L .62506 .26194 L p F P
0 g
s
.165 .229 .684 r
.62116 .25787 m .62259 .25275 L .61906 .24857 L p F P
0 g
s
.587 .686 .909 r
.66406 .14107 m .66753 .14054 L .66457 .13615 L p F P
0 g
s
.587 .686 .909 r
.66457 .13615 m .66389 .13626 L .66406 .14107 L p F P
0 g
s
.371 .408 .77 r
.64695 .3184 m .64256 .31611 L .64458 .31206 L closepath p F P
0 g
s
.367 .403 .766 r
.6438 .30996 m .63917 .30725 L p .64256 .31611 L F P
0 g
s
.367 .403 .766 r
.64256 .31611 m .64458 .31206 L .6438 .30996 L p F P
0 g
s
.206 .248 .685 r
.81611 .29943 m .81798 .29439 L .81436 .29006 L p F P
0 g
s
.173 .208 .657 r
.81798 .29439 m .81611 .29943 L .81922 .30394 L p F P
0 g
s
0 .012 .561 r
.6112 .2111 m .61081 .21597 L .61309 .2205 L p F P
0 g
s
0 0 .507 r
.61081 .21597 m .6112 .2111 L .6093 .20645 L p F P
0 g
s
.454 .571 .883 r
.72705 .17424 m .73783 .17572 L .73492 .17052 L p F P
0 g
s
.454 .571 .883 r
.73492 .17052 m .72708 .16947 L .72705 .17424 L p F P
0 g
s
.461 .578 .885 r
.72231 .16892 m .72708 .16947 L .72705 .17424 L p F P
0 g
s
.454 .565 .877 r
.72705 .17424 m .73783 .17572 L p .73791 .18062 L F P
0 g
s
.445 .467 .788 r
.66334 .34481 m .65635 .34264 L .65555 .34065 L p F P
0 g
s
.424 .523 .855 r
.76224 .20066 m .75644 .19918 L p .7649 .20639 L F P
0 g
s
.414 .519 .856 r
.75644 .19918 m .76224 .20066 L .75932 .19489 L p F P
0 g
s
.414 .519 .856 r
.75932 .19489 m .75702 .19431 L .75644 .19918 L p F P
0 g
s
.715 .847 .945 r
.7699 .40737 m .76896 .40785 L .76625 .40535 L p F P
0 g
s
.674 .832 .96 r
.75401 .40993 m .76625 .40535 L .76896 .40785 L p F P
0 g
s
.326 .413 .798 r
.79682 .24591 m .79288 .24378 L .7912 .23975 L p F P
0 g
s
.615 .732 .929 r
.75122 .40658 m .73892 .40976 L .73606 .40571 L p F P
0 g
s
.629 .755 .938 r
.73892 .40976 m .75122 .40658 L .75401 .40993 L p F P
0 g
s
0 0 .283 r
.60662 .18946 m .60677 .18721 L .60596 .18224 L p F P
0 g
s
0 0 .222 r
.60602 .1774 m .60596 .18224 L .60677 .18721 L p F P
0 g
s
.715 .847 .945 r
.76625 .40535 m .77305 .40217 L .7699 .40737 L p F P
0 g
s
.739 .908 .952 r
.77845 .3995 m .77305 .40217 L .7699 .40737 L p F P
0 g
s
.739 .908 .952 r
.7699 .40737 m .78109 .40124 L .77845 .3995 L p F P
0 g
s
.445 .467 .788 r
.65555 .34065 m .65817 .33649 L p .66334 .34481 L F P
0 g
s
.428 .455 .786 r
.65555 .34065 m .65322 .33474 L .65817 .33649 L closepath p F P
0 g
s
.349 .39 .763 r
.6438 .30996 m .63917 .30725 L .64119 .30285 L closepath p F P
0 g
s
.344 .384 .759 r
.64064 .30133 m .63602 .29831 L p .63917 .30725 L F P
0 g
s
.344 .384 .759 r
.63917 .30725 m .64119 .30285 L .64064 .30133 L p F P
0 g
s
.487 .527 .824 r
.68109 .37421 m .67941 .37395 L .68035 .37259 L closepath p F P
0 g
s
.495 .516 .808 r
.67804 .36754 m .68035 .37259 L .67941 .37395 L p F P
0 g
s
.54 .646 .902 r
.68572 .14861 m .68551 .14862 L .68551 .14827 L closepath p F P
0 g
s
.542 .654 .908 r
.68278 .14404 m .68551 .14827 L .68551 .14862 L p F P
0 g
s
.514 .628 .901 r
.68572 .14861 m .69811 .14854 L .70105 .15326 L p F P
0 g
s
.504 .628 .906 r
.69518 .14385 m .69811 .14854 L .68572 .14861 L p F P
0 g
s
.504 .628 .906 r
.68491 .14399 m .69518 .14385 L p .68572 .14861 L F P
0 g
s
.504 .628 .906 r
.68572 .14861 m .68551 .14827 L .68491 .14399 L p F P
0 g
s
.131 .215 .685 r
.6202 .24352 m .61906 .24857 L .62259 .25275 L p F P
0 g
s
.107 .184 .662 r
.61906 .24857 m .6202 .24352 L .61702 .23924 L p F P
0 g
s
.086 .095 .571 r
.81983 .31367 m .82187 .31855 L .81981 .32359 L p F P
0 g
s
.022 .02 .514 r
.82022 .33105 m .82125 .32866 L .81981 .32359 L p F P
0 g
s
.015 .017 .513 r
.82187 .31855 m .81981 .32359 L .82125 .32866 L p F P
0 g
s
.658 .802 .952 r
.76625 .40535 m .75401 .40993 L .75122 .40658 L p F P
0 g
s
.543 .605 .865 r
.71 .39854 m .71788 .39813 L .71494 .39305 L p F P
0 g
s
.543 .605 .865 r
.71494 .39305 m .71381 .39306 L .71 .39854 L p F P
0 g
s
.56 .607 .857 r
.70254 .39328 m .71381 .39306 L .71 .39854 L p F P
0 g
s
.485 .601 .893 r
.70398 .15811 m .71494 .15873 L .71495 .16352 L p F P
0 g
s
.486 .605 .896 r
.71494 .15873 m .70398 .15811 L .70142 .15387 L p F P
0 g
s
.431 .545 .871 r
.74784 .18733 m .74367 .18651 L .74075 .18109 L p F P
0 g
s
.519 .639 .908 r
.68551 .14827 m .68278 .14404 L .68491 .14399 L closepath p F P
0 g
s
.209 .255 .691 r
.81612 .28504 m .81436 .29006 L .81798 .29439 L p F P
0 g
s
.234 .285 .711 r
.81436 .29006 m .81612 .28504 L .812 .28087 L p F P
0 g
s
.582 .665 .895 r
.72947 .40679 m .73606 .40571 L .73318 .40143 L p F P
0 g
s
.582 .665 .895 r
.73318 .40143 m .73285 .40148 L .72947 .40679 L p F P
0 g
s
.599 .662 .883 r
.72081 .40303 m .73285 .40148 L .72947 .40679 L p F P
0 g
s
.325 .37 .755 r
.64064 .30133 m .63602 .29831 L .63792 .29378 L closepath p F P
0 g
s
.318 .363 .751 r
.63747 .29251 m .63307 .2893 L p .63602 .29831 L F P
0 g
s
.318 .363 .751 r
.63602 .29831 m .63792 .29378 L .63747 .29251 L p F P
0 g
s
0 0 .495 r
.60939 .20295 m .6093 .20645 L .6112 .2111 L p F P
0 g
s
0 0 .433 r
.60848 .19883 m .60785 .1969 L p .6093 .20645 L F P
0 g
s
0 0 .433 r
.6093 .20645 m .60939 .20295 L .60848 .19883 L p F P
0 g
s
.404 .503 .846 r
.76516 .20647 m .7649 .20639 L .76495 .20603 L closepath p F P
0 g
s
.424 .523 .855 r
.7649 .20639 m .76495 .20603 L .76224 .20066 L p F P
0 g
s
.326 .413 .798 r
.7912 .23975 m .79164 .2376 L p .79682 .24591 L F P
0 g
s
.343 .434 .81 r
.7912 .23975 m .7899 .23677 L .79164 .2376 L closepath p F P
0 g
s
.988 .863 .501 r
.6068 .15174 m .60774 .15629 L .60611 .16206 L p F P
0 g
s
.971 .893 .691 r
.60755 .14998 m .6068 .15174 L .60774 .15629 L p F P
0 g
s
.43 .454 .783 r
.65817 .33649 m .65322 .33474 L .65175 .33095 L p F P
0 g
s
.664 .837 .42 r
.80495 .38024 m .80511 .37996 L .80925 .37312 L p F P
0 g
s
.547 .595 .853 r
.71381 .39306 m .70254 .39328 L .69955 .38762 L p F P
0 g
s
.548 .657 .907 r
.66753 .14054 m .67983 .13952 L .68278 .14404 L p F P
0 g
s
.55 .661 .909 r
.67983 .13952 m .66753 .14054 L .66457 .13615 L p F P
0 g
s
.386 .493 .845 r
.7731 .20904 m .76516 .20647 L .76495 .20603 L p F P
0 g
s
.391 .492 .843 r
.76516 .20647 m .7731 .20904 L .77241 .21391 L p F P
0 g
s
.515 .548 .828 r
.68109 .37421 m .6922 .37553 L .6885 .38104 L p F P
0 g
s
.502 .535 .823 r
.6922 .37553 m .68109 .37421 L .68035 .37259 L p F P
0 g
s
0 0 .394 r
.60677 .18721 m .60662 .18946 L .60783 .19598 L p F P
0 g
s
0 0 .316 r
.60785 .1969 m .60783 .19598 L .60662 .18946 L p F P
0 g
s
.386 .493 .845 r
.76495 .20603 m .76541 .20156 L p .7731 .20904 L F P
0 g
s
.399 .509 .853 r
.76495 .20603 m .76224 .20066 L .76541 .20156 L closepath p F P
0 g
s
.585 .647 .878 r
.73285 .40148 m .72081 .40303 L .71788 .39813 L p F P
0 g
s
0 0 .438 r
.82125 .32866 m .82022 .33105 L .82087 .33673 L p F P
0 g
s
0 0 .458 r
.81974 .33903 m .82087 .33673 L .82022 .33105 L p F P
0 g
s
.076 .172 .662 r
.61786 .23426 m .61702 .23924 L .6202 .24352 L p F P
0 g
s
.036 .13 .633 r
.61702 .23924 m .61786 .23426 L .61503 .22988 L p F P
0 g
s
.297 .348 .747 r
.63747 .29251 m .63307 .2893 L .63476 .28483 L closepath p F P
0 g
s
.289 .34 .741 r
.6343 .2835 m .63027 .28023 L p .63307 .2893 L F P
0 g
s
.289 .34 .741 r
.63307 .2893 m .63476 .28483 L .6343 .2835 L p F P
0 g
s
.525 .56 .833 r
.6885 .38104 m .69654 .38172 L p .69931 .38761 L F P
0 g
s
.496 .542 .834 r
.6885 .38104 m .69654 .38172 L .69352 .37569 L p F P
0 g
s
.496 .542 .834 r
.69352 .37569 m .6922 .37553 L .6885 .38104 L p F P
0 g
s
.43 .454 .783 r
.65175 .33095 m .65348 .32803 L p .65817 .33649 L F P
0 g
s
.412 .441 .78 r
.65175 .33095 m .65009 .32666 L .65348 .32803 L closepath p F P
0 g
s
.234 .289 .716 r
.81365 .27586 m .812 .28087 L .81612 .28504 L p F P
0 g
s
.258 .317 .734 r
.812 .28087 m .81365 .27586 L .80906 .27187 L p F P
0 g
s
.461 .58 .887 r
.72708 .16947 m .72231 .16892 L .71939 .16386 L p F P
0 g
s
.502 .535 .823 r
.68035 .37259 m .68335 .36835 L p .6922 .37553 L F P
0 g
s
.489 .527 .822 r
.68035 .37259 m .67804 .36754 L .68335 .36835 L closepath p F P
0 g
s
.447 .556 .873 r
.74075 .18109 m .73791 .18062 L .73821 .1764 L closepath p F P
0 g
s
.454 .565 .877 r
.73783 .17572 m .73821 .1764 L .73791 .18062 L p F P
0 g
s
.889 .751 .247 r
.60587 .17222 m .6055 .1675 L .60611 .16206 L p F P
0 g
s
.382 .479 .834 r
.7794 .22162 m .78029 .2167 L .77241 .21391 L p F P
0 g
s
.386 .487 .84 r
.7731 .20904 m .77241 .21391 L .78029 .2167 L p F P
0 g
s
.341 .434 .812 r
.79164 .2376 m .7899 .23677 L .78693 .22998 L p F P
0 g
s
0 0 .36 r
.82087 .33673 m .81974 .33903 L .81985 .34454 L p F P
0 g
s
.645 .725 .907 r
.6343 .13376 m .64642 .13003 L .6494 .13413 L p F P
0 g
s
.655 .732 .906 r
.64642 .13003 m .6343 .13376 L .63132 .12999 L p F P
0 g
s
.728 .774 .889 r
.61932 .13642 m .63132 .12999 L .6343 .13376 L p F P
0 g
s
.482 .596 .89 r
.71495 .16352 m .71939 .16386 L .71647 .15884 L p F P
0 g
s
.482 .596 .89 r
.71647 .15884 m .71494 .15873 L .71495 .16352 L p F P
0 g
s
0 0 .406 r
.60848 .19883 m .60785 .1969 L .60783 .19598 L closepath p F P
0 g
s
.415 .44 .778 r
.65348 .32803 m .65009 .32666 L .64809 .32142 L p F P
0 g
s
0 0 .057 r
.81435 .36281 m .81502 .36148 L .81658 .35544 L p F P
0 g
s
0 0 .029 r
.81914 .35032 m .81658 .35544 L .81502 .36148 L p F P
0 g
s
0 0 .224 r
.81658 .35544 m .81914 .35032 L .81985 .34454 L p F P
0 g
s
.08 .095 .574 r
.82184 .30863 m .81983 .31367 L .82187 .31855 L p F P
0 g
s
.131 .155 .619 r
.81983 .31367 m .82184 .30863 L .81922 .30394 L p F P
0 g
s
.267 .324 .737 r
.6343 .2835 m .63027 .28023 L .6317 .27601 L closepath p F P
0 g
s
.257 .314 .731 r
.63111 .27427 m .62761 .27111 L p .63027 .28023 L F P
0 g
s
.257 .314 .731 r
.63027 .28023 m .6317 .27601 L .63111 .27427 L p F P
0 g
s
.258 .321 .738 r
.81058 .26687 m .80906 .27187 L .81365 .27586 L p F P
0 g
s
.278 .346 .753 r
.80906 .27187 m .81058 .26687 L .80554 .26304 L p F P
0 g
s
.747 .961 .938 r
.78844 .39619 m .78109 .40124 L .77845 .3995 L p F P
0 g
s
.754 .936 .593 r
.80483 .38034 m .80511 .37996 L .80495 .38024 L closepath p F P
0 g
s
.377 .468 .827 r
.78398 .22344 m .7794 .22162 L p .78587 .2295 L F P
0 g
s
.365 .462 .826 r
.7794 .22162 m .78398 .22344 L .78103 .21699 L p F P
0 g
s
.365 .462 .826 r
.78103 .21699 m .78029 .2167 L .7794 .22162 L p F P
0 g
s
.009 .119 .632 r
.61553 .2257 m .61503 .22988 L .61786 .23426 L p F P
0 g
s
0 .081 .606 r
.61505 .22399 m .61309 .2205 L p .61503 .22988 L F P
0 g
s
0 .081 .606 r
.61503 .22988 m .61553 .2257 L .61505 .22399 L p F P
0 g
s
.8 .975 .683 r
.80511 .37996 m .80483 .38034 L .80246 .38153 L p F P
0 g
s
.8 .975 .683 r
.80246 .38153 m .80784 .37483 L .80511 .37996 L p F P
0 g
s
.71 .878 .481 r
.80511 .37996 m .80784 .37483 L .81221 .36791 L p F P
0 g
s
.279 .351 .758 r
.80692 .25806 m .80554 .26304 L .81058 .26687 L p F P
0 g
s
.296 .371 .77 r
.80554 .26304 m .80692 .25806 L .80145 .25438 L p F P
0 g
s
.76 .971 .693 r
.79842 .38757 m .80483 .38034 L .80246 .38153 L p F P
0 g
s
.395 .425 .774 r
.64809 .32142 m .64695 .3184 L .64921 .31943 L closepath p F P
0 g
s
.415 .44 .778 r
.64809 .32142 m .64921 .31943 L p .65348 .32803 L F P
0 g
s
.587 .697 .918 r
.6494 .13413 m .66161 .13184 L p .66389 .13626 L F P
0 g
s
.599 .697 .912 r
.66161 .13184 m .6494 .13413 L .64642 .13003 L p F P
0 g
s
.353 .443 .815 r
.78693 .22998 m .78587 .2295 L .78614 .22818 L closepath p F P
0 g
s
.377 .468 .827 r
.78587 .2295 m .78614 .22818 L .78398 .22344 L p F P
0 g
s
0 0 .486 r
.60783 .19598 m .60808 .19203 L p .60953 .20161 L F P
0 g
s
0 0 .486 r
.60953 .20161 m .60848 .19883 L .60783 .19598 L p F P
0 g
s
0 0 .394 r
.60783 .19598 m .60808 .19203 L .60677 .18721 L p F P
0 g
s
.232 .298 .726 r
.63111 .27427 m .62761 .27111 L .62874 .2673 L closepath p F P
0 g
s
.221 .285 .718 r
.62792 .26482 m .62506 .26194 L p .62761 .27111 L F P
0 g
s
.221 .285 .718 r
.62761 .27111 m .62874 .2673 L .62792 .26482 L p F P
0 g
s
.299 .378 .776 r
.80269 .24944 m .80145 .25438 L .80692 .25806 L p F P
0 g
s
.309 .389 .783 r
.79682 .24591 m .80269 .24944 L .80145 .25438 L p F P
0 g
s
.491 .524 .819 r
.68335 .36835 m .67804 .36754 L .67524 .36133 L p F P
0 g
s
.881 .881 .829 r
.6169 .13388 m .61808 .13743 L .61062 .14521 L p F P
0 g
s
.811 .827 .863 r
.61808 .13743 m .6169 .13388 L .61932 .13642 L closepath p F P
0 g
s
.326 .413 .798 r
.79164 .2376 m .7979 .24099 L .79682 .24591 L p F P
0 g
s
.324 .416 .802 r
.79257 .23271 m .79164 .2376 L .7979 .24099 L p F P
0 g
s
.341 .434 .812 r
.78693 .22998 m .79257 .23271 L .79164 .2376 L p F P
0 g
s
.397 .425 .772 r
.64921 .31943 m .64695 .3184 L .64458 .31206 L p F P
0 g
s
.734 .813 .913 r
.6169 .13388 m .61932 .13642 L .63132 .12999 L p F P
0 g
s
.317 .402 .792 r
.7979 .24099 m .79682 .24591 L .80269 .24944 L p F P
0 g
s
0 0 0 r
.81385 .36445 m .81502 .36148 L .81435 .36281 L closepath p F P
0 g
s
.747 .961 .938 r
.7912 .39216 m .78844 .39619 L p .77845 .3995 L F P
0 g
s
.789 .984 .9 r
.78844 .39619 m .7912 .39216 L .79309 .39261 L closepath p F P
0 g
s
.432 .539 .865 r
.7564 .18921 m .74784 .18733 L p .75702 .19431 L F P
0 g
s
.422 .536 .868 r
.74784 .18733 m .7564 .18921 L .75349 .1837 L p F P
0 g
s
.422 .536 .868 r
.75349 .1837 m .74809 .18253 L .74784 .18733 L p F P
0 g
s
.431 .545 .871 r
.74075 .18109 m .74809 .18253 L .74784 .18733 L p F P
0 g
s
.486 .605 .896 r
.70142 .15387 m .70137 .15327 L p .71494 .15873 L F P
0 g
s
.492 .613 .899 r
.70142 .15387 m .70105 .15326 L .70137 .15327 L closepath p F P
0 g
s
.615 .732 .929 r
.73606 .40571 m .7484 .40296 L .75122 .40658 L p F P
0 g
s
.602 .712 .922 r
.7484 .40296 m .73606 .40571 L .73318 .40143 L p F P
0 g
s
0 0 .222 r
.60677 .18721 m .60677 .1824 L .60602 .1774 L p F P
0 g
s
0 0 .331 r
.60677 .1824 m .60677 .18721 L .60808 .19203 L p F P
0 g
s
.429 .546 .873 r
.74809 .18253 m .74075 .18109 L .73821 .1764 L p F P
0 g
s
.518 .572 .849 r
.69955 .38762 m .69931 .38761 L .69944 .38741 L closepath p F P
0 g
s
.525 .56 .833 r
.69654 .38172 m .69944 .38741 L .69931 .38761 L p F P
0 g
s
.847 .983 .864 r
.79842 .38757 m .80171 .38229 L p .7912 .39216 L F P
0 g
s
.847 .983 .864 r
.7912 .39216 m .79309 .39261 L .79842 .38757 L p F P
0 g
s
.76 .971 .693 r
.80246 .38153 m .80171 .38229 L .79842 .38757 L p F P
0 g
s
.934 .767 .293 r
.6053 .15747 m .60611 .16206 L .6055 .1675 L p F P
0 g
s
.988 .863 .501 r
.60611 .16206 m .6053 .15747 L .6068 .15174 L p F P
0 g
s
0 .054 .591 r
.61505 .22399 m .61309 .2205 L .61329 .21787 L closepath p F P
0 g
s
0 .012 .561 r
.61179 .21231 m .6112 .2111 L p .61309 .2205 L F P
0 g
s
0 .012 .561 r
.61309 .2205 m .61329 .21787 L .61179 .21231 L p F P
0 g
s
0 0 .495 r
.60939 .20295 m .60848 .19883 L .60953 .20161 L closepath p F P
0 g
s
.547 .595 .853 r
.69955 .38762 m .71197 .38774 L p .71381 .39306 L F P
0 g
s
.525 .575 .848 r
.70899 .38227 m .71197 .38774 L .69955 .38762 L p F P
0 g
s
.525 .575 .848 r
.70337 .38201 m .70899 .38227 L p .69955 .38762 L F P
0 g
s
.525 .575 .848 r
.69955 .38762 m .69944 .38741 L .70337 .38201 L p F P
0 g
s
.13 .158 .622 r
.82115 .29889 m .81922 .30394 L .82184 .30863 L p F P
0 g
s
.173 .208 .657 r
.81922 .30394 m .82115 .29889 L .81798 .29439 L p F P
0 g
s
.398 .509 .855 r
.76541 .20156 m .76224 .20066 L .75932 .19489 L p F P
0 g
s
.523 .573 .847 r
.69944 .38741 m .69654 .38172 L .70337 .38201 L closepath p F P
0 g
s
.945 .941 .751 r
.61062 .14521 m .60981 .14059 L p .6063 .14983 L F P
0 g
s
.945 .941 .751 r
.6063 .14983 m .60755 .14998 L .61062 .14521 L p F P
0 g
s
.881 .881 .829 r
.61632 .13331 m .6169 .13388 L p .61062 .14521 L F P
0 g
s
.881 .881 .829 r
.61062 .14521 m .60981 .14059 L .61632 .13331 L p F P
0 g
s
.335 .432 .813 r
.79257 .23271 m .78693 .22998 L .78614 .22818 L p F P
0 g
s
.518 .642 .91 r
.68491 .14399 m .68278 .14404 L .67983 .13952 L p F P
0 g
s
.491 .615 .902 r
.70137 .15327 m .70105 .15326 L .69811 .14854 L p F P
0 g
s
.397 .425 .772 r
.64458 .31206 m .64529 .31072 L p .64921 .31943 L F P
0 g
s
.377 .409 .767 r
.64458 .31206 m .6438 .30996 L .64529 .31072 L closepath p F P
0 g
s
.193 .267 .712 r
.62792 .26482 m .62506 .26194 L .62588 .25871 L closepath p F P
0 g
s
.179 .253 .703 r
.62472 .25513 m .62259 .25275 L p .62506 .26194 L F P
0 g
s
.179 .253 .703 r
.62506 .26194 m .62588 .25871 L .62472 .25513 L p F P
0 g
s
.486 .605 .896 r
.70137 .15327 m .71354 .15391 L p .71494 .15873 L F P
0 g
s
.487 .612 .901 r
.70137 .15327 m .71354 .15391 L .71061 .14908 L p F P
0 g
s
.487 .612 .901 r
.71061 .14908 m .70085 .14863 L .70137 .15327 L p F P
0 g
s
.491 .615 .902 r
.69811 .14854 m .70085 .14863 L .70137 .15327 L p F P
0 g
s
0 0 .438 r
.82087 .33673 m .82207 .33394 L .82125 .32866 L p F P
0 g
s
0 0 .435 r
.82333 .32362 m .82125 .32866 L .82207 .33394 L p F P
0 g
s
.015 .017 .513 r
.82125 .32866 m .82333 .32362 L .82187 .31855 L p F P
0 g
s
.379 .409 .766 r
.64529 .31072 m .6438 .30996 L .64119 .30285 L p F P
0 g
s
.692 .856 .961 r
.77305 .40217 m .76625 .40535 L .76351 .40251 L p F P
0 g
s
.658 .802 .952 r
.75122 .40658 m .76351 .40251 L .76625 .40535 L p F P
0 g
s
.335 .432 .813 r
.78614 .22818 m .78671 .22461 L p .79257 .23271 L F P
0 g
s
.351 .452 .824 r
.78614 .22818 m .78398 .22344 L .78671 .22461 L closepath p F P
0 g
s
.587 .686 .91 r
.66457 .13615 m .66389 .13626 L .66384 .13508 L closepath p F P
0 g
s
.587 .697 .918 r
.66161 .13184 m .66384 .13508 L .66389 .13626 L p F P
0 g
s
0 0 .335 r
.82207 .33394 m .82087 .33673 L .82114 .34193 L p F P
0 g
s
0 0 .36 r
.81985 .34454 m .82114 .34193 L .82087 .33673 L p F P
0 g
s
.556 .643 .892 r
.73028 .39691 m .71788 .39813 L .71494 .39305 L p F P
0 g
s
.585 .647 .878 r
.71788 .39813 m .73028 .39691 L p .73285 .40148 L F P
0 g
s
.642 .776 .945 r
.76351 .40251 m .75122 .40658 L .7484 .40296 L p F P
0 g
s
0 0 .546 r
.60953 .20161 m .60939 .20295 L .61122 .21026 L p F P
0 g
s
0 0 .495 r
.6112 .2111 m .61122 .21026 L .60939 .20295 L p F P
0 g
s
.455 .574 .885 r
.72708 .16947 m .73492 .17052 L .732 .16537 L p F P
0 g
s
.455 .574 .885 r
.732 .16537 m .72702 .16472 L .72708 .16947 L p F P
0 g
s
.461 .58 .887 r
.71939 .16386 m .72702 .16472 L .72708 .16947 L p F P
0 g
s
.445 .467 .788 r
.65817 .33649 m .6657 .33923 L p .66334 .34481 L F P
0 g
s
.404 .444 .788 r
.65817 .33649 m .6657 .33923 L .66259 .33173 L p F P
0 g
s
.404 .444 .788 r
.66259 .33173 m .66104 .33111 L .65817 .33649 L p F P
0 g
s
.43 .454 .783 r
.65348 .32803 m .66104 .33111 L .65817 .33649 L p F P
0 g
s
.55 .661 .909 r
.66457 .13615 m .67688 .13504 L .67983 .13952 L p F P
0 g
s
.543 .665 .916 r
.67392 .1306 m .67688 .13504 L .66457 .13615 L p F P
0 g
s
.543 .665 .916 r
.66298 .1317 m .67392 .1306 L p .66457 .13615 L F P
0 g
s
.543 .665 .916 r
.66457 .13615 m .66384 .13508 L .66298 .1317 L p F P
0 g
s
.443 .485 .807 r
.6688 .34653 m .66334 .34481 L p .66908 .35294 L F P
0 g
s
.43 .474 .804 r
.6688 .34653 m .66334 .34481 L .666 .33994 L closepath p F P
0 g
s
.445 .467 .788 r
.6657 .33923 m .666 .33994 L .66334 .34481 L p F P
0 g
s
0 0 .542 r
.61179 .21231 m .6112 .2111 L .61122 .21026 L closepath p F P
0 g
s
0 0 0 r
.81502 .36148 m .8175 .35639 L p .81318 .36619 L F P
0 g
s
0 0 0 r
.81318 .36619 m .81385 .36445 L .81502 .36148 L p F P
0 g
s
0 0 .029 r
.81502 .36148 m .8175 .35639 L .81914 .35032 L p F P
0 g
s
.46 .583 .89 r
.72702 .16472 m .71939 .16386 L .71647 .15884 L p F P
0 g
s
.394 .442 .792 r
.65628 .32264 m .65348 .32803 L .66104 .33111 L p F P
0 g
s
.415 .44 .778 r
.64921 .31943 m .65628 .32264 L .65348 .32803 L p F P
0 g
s
.412 .52 .858 r
.75932 .19489 m .75702 .19431 L .75736 .19103 L closepath p F P
0 g
s
.432 .539 .865 r
.75702 .19431 m .75736 .19103 L .7564 .18921 L p F P
0 g
s
.148 .233 .696 r
.62472 .25513 m .62259 .25275 L .62312 .25025 L closepath p F P
0 g
s
.131 .215 .685 r
.62151 .24516 m .6202 .24352 L p .62259 .25275 L F P
0 g
s
.131 .215 .685 r
.62259 .25275 m .62312 .25025 L .62151 .24516 L p F P
0 g
s
.379 .409 .766 r
.64119 .30285 m .64165 .30191 L p .64529 .31072 L F P
0 g
s
.356 .392 .76 r
.64119 .30285 m .64064 .30133 L .64165 .30191 L closepath p F P
0 g
s
.491 .524 .819 r
.67524 .36133 m .67557 .36084 L p .68335 .36835 L F P
0 g
s
.477 .515 .817 r
.67524 .36133 m .67497 .36073 L .67557 .36084 L closepath p F P
0 g
s
.446 .488 .809 r
.67189 .35371 m .66908 .35294 L .6705 .3505 L closepath p F P
0 g
s
.443 .485 .807 r
.66908 .35294 m .6705 .3505 L .6688 .34653 L p F P
0 g
s
.981 .884 .658 r
.6068 .15174 m .6063 .14983 L .60755 .14998 L closepath p F P
0 g
s
0 0 .225 r
.82114 .34193 m .81985 .34454 L .81914 .35032 L p F P
0 g
s
.517 .639 .909 r
.68491 .14399 m .69518 .14385 L .69224 .13921 L p F P
0 g
s
.517 .639 .909 r
.69224 .13921 m .68419 .13938 L .68491 .14399 L p F P
0 g
s
.518 .642 .91 r
.67983 .13952 m .68419 .13938 L .68491 .14399 L p F P
0 g
s
.209 .255 .691 r
.81875 .28815 m .81612 .28504 L p .81798 .29439 L F P
0 g
s
.209 .255 .691 r
.81798 .29439 m .81943 .2904 L .81875 .28815 L p F P
0 g
s
.166 .206 .658 r
.81943 .2904 m .81798 .29439 L .82115 .29889 L p F P
0 g
s
.358 .391 .759 r
.64165 .30191 m .64064 .30133 L .63792 .29378 L p F P
0 g
s
.374 .426 .787 r
.65189 .31405 m .64921 .31943 L .65628 .32264 L p F P
0 g
s
.397 .425 .772 r
.64529 .31072 m .65189 .31405 L .64921 .31943 L p F P
0 g
s
.48 .511 .812 r
.67557 .36084 m .67497 .36073 L .67189 .35371 L p F P
0 g
s
.352 .408 .78 r
.64782 .30537 m .64529 .31072 L .65189 .31405 L p F P
0 g
s
.379 .409 .766 r
.64165 .30191 m .64782 .30537 L .64529 .31072 L p F P
0 g
s
.491 .524 .819 r
.67557 .36084 m .68661 .36293 L .68335 .36835 L p F P
0 g
s
.465 .518 .828 r
.67909 .35532 m .67557 .36084 L .68661 .36293 L p F P
0 g
s
.48 .511 .812 r
.67189 .35371 m .67909 .35532 L .67557 .36084 L p F P
0 g
s
.555 .674 .917 r
.66384 .13508 m .66161 .13184 L .66298 .1317 L closepath p F P
0 g
s
0 0 .546 r
.61122 .21026 m .61165 .20618 L .60953 .20161 L p F P
0 g
s
0 .069 .596 r
.61122 .21026 m .61165 .20618 L p .61362 .21558 L F P
0 g
s
0 .069 .596 r
.61362 .21558 m .61179 .21231 L .61122 .21026 L p F P
0 g
s
.995 .845 .496 r
.6063 .14983 m .6068 .15174 L .6053 .15747 L p F P
0 g
s
.358 .391 .759 r
.63792 .29378 m .63827 .29302 L p .64165 .30191 L F P
0 g
s
.334 .373 .753 r
.63792 .29378 m .63747 .29251 L .63827 .29302 L closepath p F P
0 g
s
.335 .373 .752 r
.63827 .29302 m .63747 .29251 L .63476 .28483 L p F P
0 g
s
.097 .194 .677 r
.62151 .24516 m .6202 .24352 L .62047 .24191 L closepath p F P
0 g
s
.076 .172 .662 r
.61828 .23485 m .61786 .23426 L p .6202 .24352 L F P
0 g
s
.076 .172 .662 r
.6202 .24352 m .62047 .24191 L .61828 .23485 L p F P
0 g
s
0 .078 .599 r
.61329 .21787 m .61179 .21231 L .61362 .21558 L closepath p F P
0 g
s
0 0 0 r
.81221 .36791 m .81318 .36619 L .81385 .36445 L closepath p F P
0 g
s
0 0 .505 r
.60977 .19673 m .60953 .20161 L .61165 .20618 L p F P
0 g
s
0 0 .486 r
.60808 .19203 m .60977 .19673 L .60953 .20161 L p F P
0 g
s
.317 .376 .765 r
.64401 .29659 m .64165 .30191 L .64782 .30537 L p F P
0 g
s
.358 .391 .759 r
.63827 .29302 m .64401 .29659 L .64165 .30191 L p F P
0 g
s
.35 .453 .825 r
.78671 .22461 m .78398 .22344 L .78103 .21699 L p F P
0 g
s
.386 .493 .845 r
.76541 .20156 m .77371 .20417 L .7731 .20904 L p F P
0 g
s
.395 .505 .852 r
.76581 .19674 m .76541 .20156 L .77371 .20417 L p F P
0 g
s
.398 .509 .855 r
.75932 .19489 m .76581 .19674 L .76541 .20156 L p F P
0 g
s
.692 .856 .961 r
.77634 .3978 m .77305 .40217 L p .76351 .40251 L F P
0 g
s
.722 .874 .952 r
.77305 .40217 m .77634 .3978 L .77845 .3995 L closepath p F P
0 g
s
.08 .095 .574 r
.82187 .31855 m .82392 .3135 L .82184 .30863 L p F P
0 g
s
.017 .02 .516 r
.82392 .3135 m .82187 .31855 L .82333 .32362 L p F P
0 g
s
.429 .546 .873 r
.73821 .1764 m .73821 .17578 L p .74809 .18253 L F P
0 g
s
.44 .558 .879 r
.73821 .1764 m .73783 .17572 L .73821 .17578 L closepath p F P
0 g
s
.734 .813 .913 r
.63132 .12999 m .62832 .12627 L p .6169 .13388 L F P
0 g
s
.655 .732 .906 r
.63132 .12999 m .64344 .12597 L .64642 .13003 L p F P
0 g
s
.664 .738 .905 r
.64344 .12597 m .63132 .12999 L .62832 .12627 L p F P
0 g
s
.195 .246 .688 r
.81875 .28815 m .81612 .28504 L .81702 .28239 L closepath p F P
0 g
s
.234 .289 .716 r
.81551 .27774 m .81365 .27586 L p .81612 .28504 L F P
0 g
s
.234 .289 .716 r
.81612 .28504 m .81702 .28239 L .81551 .27774 L p F P
0 g
s
.525 .57 .843 r
.70337 .38201 m .69654 .38172 L .69352 .37569 L p F P
0 g
s
.335 .373 .752 r
.63476 .28483 m .63508 .28406 L p .63827 .29302 L F P
0 g
s
.31 .352 .744 r
.63476 .28483 m .6343 .2835 L .63508 .28406 L closepath p F P
0 g
s
.31 .352 .744 r
.63508 .28406 m .6343 .2835 L .6317 .27601 L p F P
0 g
s
.036 .13 .633 r
.61329 .21787 m .61362 .21558 L p .61567 .22495 L F P
0 g
s
.036 .13 .633 r
.61567 .22495 m .61505 .22399 L .61329 .21787 L p F P
0 g
s
.395 .51 .857 r
.76581 .19674 m .75932 .19489 L .75736 .19103 L p F P
0 g
s
.47 .518 .825 r
.68335 .36835 m .69049 .36946 L .68744 .3631 L p F P
0 g
s
.47 .518 .825 r
.68744 .3631 m .68661 .36293 L .68335 .36835 L p F P
0 g
s
.502 .535 .823 r
.68335 .36835 m .69049 .36946 L p .6922 .37553 L F P
0 g
s
.437 .56 .881 r
.73821 .17578 m .73783 .17572 L .73492 .17052 L p F P
0 g
s
.294 .357 .757 r
.64043 .28773 m .63827 .29302 L .64401 .29659 L p F P
0 g
s
.335 .373 .752 r
.63508 .28406 m .64043 .28773 L .63827 .29302 L p F P
0 g
s
.837 .638 .092 r
.60475 .16289 m .6055 .1675 L .60564 .17269 L p F P
0 g
s
.934 .767 .293 r
.6055 .1675 m .60475 .16289 L .6053 .15747 L p F P
0 g
s
.599 .697 .912 r
.64642 .13003 m .65864 .12759 L .66161 .13184 L p F P
0 g
s
.605 .702 .913 r
.65864 .12759 m .64642 .13003 L .64344 .12597 L p F P
0 g
s
.429 .546 .873 r
.73821 .17578 m .74827 .17773 L .74809 .18253 L p F P
0 g
s
.439 .557 .878 r
.73812 .17106 m .73821 .17578 L .74827 .17773 L p F P
0 g
s
.437 .56 .881 r
.73492 .17052 m .73812 .17106 L .73821 .17578 L p F P
0 g
s
.038 .149 .652 r
.61828 .23485 m .61786 .23426 L .61793 .23372 L closepath p F P
0 g
s
.009 .119 .632 r
.61786 .23426 m .61793 .23372 L .61553 .2257 L p F P
0 g
s
.581 .666 .896 r
.73318 .40143 m .73285 .40148 L .73303 .40119 L closepath p F P
0 g
s
.585 .647 .878 r
.73028 .39691 m .73303 .40119 L .73285 .40148 L p F P
0 g
s
.783 .835 .892 r
.61632 .13331 m .61684 .13295 L .6169 .13388 L closepath p F P
0 g
s
.734 .813 .913 r
.62832 .12627 m .61684 .13295 L .6169 .13388 L p F P
0 g
s
.31 .352 .744 r
.6317 .27601 m .63207 .27503 L p .63508 .28406 L F P
0 g
s
.282 .33 .735 r
.6317 .27601 m .63111 .27427 L .63207 .27503 L closepath p F P
0 g
s
.049 .135 .634 r
.61553 .2257 m .61505 .22399 L .61567 .22495 L closepath p F P
0 g
s
.541 .608 .87 r
.71494 .39305 m .71381 .39306 L .71442 .39213 L closepath p F P
0 g
s
.547 .595 .853 r
.71197 .38774 m .71442 .39213 L .71381 .39306 L p F P
0 g
s
.466 .5 .809 r
.67909 .35532 m .67189 .35371 L .6705 .3505 L p F P
0 g
s
.374 .481 .84 r
.7731 .20904 m .77809 .2108 L .77515 .20468 L p F P
0 g
s
.374 .481 .84 r
.77515 .20468 m .77371 .20417 L .7731 .20904 L p F P
0 g
s
.386 .487 .84 r
.77809 .2108 m .7731 .20904 L p .78029 .2167 L F P
0 g
s
.282 .33 .735 r
.63207 .27503 m .63111 .27427 L .62874 .2673 L p F P
0 g
s
.726 .907 .537 r
.81318 .36619 m .81221 .36791 L .80784 .37483 L p F P
0 g
s
.602 .712 .922 r
.73318 .40143 m .74556 .3991 L .7484 .40296 L p F P
0 g
s
.593 .671 .894 r
.7427 .39502 m .74556 .3991 L .73318 .40143 L p F P
0 g
s
.593 .671 .894 r
.73718 .39586 m .7427 .39502 L p .73318 .40143 L F P
0 g
s
.593 .671 .894 r
.73318 .40143 m .73303 .40119 L .73718 .39586 L p F P
0 g
s
.078 .167 .655 r
.61567 .22495 m .61553 .2257 L .61793 .23372 L p F P
0 g
s
.221 .281 .714 r
.81551 .27774 m .81365 .27586 L .81426 .27391 L closepath p F P
0 g
s
.258 .321 .738 r
.81235 .26842 m .81058 .26687 L p .81365 .27586 L F P
0 g
s
.258 .321 .738 r
.81365 .27586 m .81426 .27391 L .81235 .26842 L p F P
0 g
s
.481 .597 .892 r
.71647 .15884 m .71494 .15873 L .71489 .15616 L closepath p F P
0 g
s
.486 .605 .896 r
.71354 .15391 m .71489 .15616 L .71494 .15873 L p F P
0 g
s
.592 .67 .894 r
.73303 .40119 m .73028 .39691 L .73718 .39586 L closepath p F P
0 g
s
.267 .335 .748 r
.63704 .27882 m .63508 .28406 L .64043 .28773 L p F P
0 g
s
.31 .352 .744 r
.63207 .27503 m .63704 .27882 L .63508 .28406 L p F P
0 g
s
.282 .33 .735 r
.62874 .2673 m .62921 .26596 L p .63207 .27503 L F P
0 g
s
.252 .305 .724 r
.62874 .2673 m .62792 .26482 L .62921 .26596 L closepath p F P
0 g
s
0 0 .404 r
.608 .18724 m .60808 .19203 L .60977 .19673 L p F P
0 g
s
0 0 .331 r
.60808 .19203 m .608 .18724 L .60677 .1824 L p F P
0 g
s
.492 .619 .905 r
.70085 .14863 m .69811 .14854 L .69518 .14385 L p F P
0 g
s
.25 .305 .725 r
.62921 .26596 m .62792 .26482 L .62588 .25871 L p F P
0 g
s
.747 .961 .938 r
.77845 .3995 m .79055 .39191 L .7912 .39216 L p F P
0 g
s
.773 .884 .926 r
.77634 .3978 m .77845 .3995 L .79055 .39191 L p F P
0 g
s
.126 .209 .68 r
.61793 .23372 m .61877 .22924 L p .62125 .23847 L F P
0 g
s
.126 .209 .68 r
.62125 .23847 m .61828 .23485 L .61793 .23372 L p F P
0 g
s
.078 .167 .655 r
.61793 .23372 m .61877 .22924 L .61567 .22495 L p F P
0 g
s
.133 .211 .679 r
.62047 .24191 m .61828 .23485 L .62125 .23847 L closepath p F P
0 g
s
.52 .646 .912 r
.68419 .13938 m .67983 .13952 L .67688 .13504 L p F P
0 g
s
.556 .643 .892 r
.71494 .39305 m .72737 .3922 L .73028 .39691 L p F P
0 g
s
.551 .613 .868 r
.72443 .38731 m .72737 .3922 L .71494 .39305 L p F P
0 g
s
.551 .613 .868 r
.71774 .38753 m .72443 .38731 L p .71494 .39305 L F P
0 g
s
.551 .613 .868 r
.71494 .39305 m .71442 .39213 L .71774 .38753 L p F P
0 g
s
.25 .305 .725 r
.62588 .25871 m .62646 .25683 L p .62921 .26596 L F P
0 g
s
.217 .278 .712 r
.62588 .25871 m .62472 .25513 L .62646 .25683 L closepath p F P
0 g
s
.215 .277 .713 r
.62646 .25683 m .62472 .25513 L .62312 .25025 L p F P
0 g
s
0 0 .335 r
.82114 .34193 m .8222 .33945 L .82207 .33394 L p F P
0 g
s
0 0 .328 r
.82416 .32891 m .82207 .33394 L .8222 .33945 L p F P
0 g
s
0 0 .435 r
.82207 .33394 m .82416 .32891 L .82333 .32362 L p F P
0 g
s
.178 .247 .697 r
.62312 .25025 m .62151 .24516 L .62381 .24767 L closepath p F P
0 g
s
.173 .245 .698 r
.62381 .24767 m .62151 .24516 L .62047 .24191 L p F P
0 g
s
.173 .245 .698 r
.62047 .24191 m .62125 .23847 L p .62381 .24767 L F P
0 g
s
.215 .277 .713 r
.62312 .25025 m .62381 .24767 L p .62646 .25683 L F P
0 g
s
.986 .894 .569 r
.60464 .15091 m .60595 .14713 L .6063 .14983 L closepath p F P
0 g
s
.945 .941 .751 r
.60981 .14059 m .60595 .14713 L .6063 .14983 L p F P
0 g
s
.995 .845 .496 r
.60464 .15091 m .6063 .14983 L p .6053 .15747 L F P
0 g
s
.362 .463 .829 r
.78103 .21699 m .78029 .2167 L .78044 .21573 L closepath p F P
0 g
s
.386 .487 .84 r
.78029 .2167 m .78044 .21573 L .77809 .2108 L p F P
0 g
s
.245 .314 .736 r
.81235 .26842 m .81058 .26687 L .81113 .26494 L closepath p F P
0 g
s
.279 .351 .758 r
.80925 .25984 m .80692 .25806 L p .81058 .26687 L F P
0 g
s
.279 .351 .758 r
.81058 .26687 m .81113 .26494 L .80925 .25984 L p F P
0 g
s
.8 .838 .881 r
.61684 .13295 m .61632 .13331 L .61332 .13038 L p F P
0 g
s
.867 .841 .817 r
.60981 .14059 m .61632 .13331 L .61332 .13038 L p F P
0 g
s
.466 .5 .809 r
.6705 .3505 m .67236 .34747 L p .67909 .35532 L F P
0 g
s
.451 .489 .808 r
.6705 .3505 m .6688 .34653 L .67236 .34747 L closepath p F P
0 g
s
.073 .092 .574 r
.82323 .30505 m .82184 .30863 L .82392 .3135 L p F P
0 g
s
.13 .158 .622 r
.82217 .30072 m .82115 .29889 L p .82184 .30863 L F P
0 g
s
.13 .158 .622 r
.82184 .30863 m .82323 .30505 L .82217 .30072 L p F P
0 g
s
.8 .838 .881 r
.61332 .13038 m .61614 .12827 L .61684 .13295 L p F P
0 g
s
.743 .783 .885 r
.62532 .12257 m .61614 .12827 L .61684 .13295 L p F P
0 g
s
.743 .783 .885 r
.61684 .13295 m .62832 .12627 L .62532 .12257 L p F P
0 g
s
.494 .546 .839 r
.69352 .37569 m .6922 .37553 L .6929 .37441 L closepath p F P
0 g
s
.502 .535 .823 r
.69049 .36946 m .6929 .37441 L .6922 .37553 L p F P
0 g
s
0 .119 .635 r
.61636 .21998 m .61567 .22495 L .61877 .22924 L p F P
0 g
s
.036 .13 .633 r
.61362 .21558 m .61636 .21998 L .61567 .22495 L p F P
0 g
s
.806 .967 .908 r
.79055 .39191 m .79191 .39086 L .7912 .39216 L closepath p F P
0 g
s
.847 .983 .864 r
.80171 .38229 m .79191 .39086 L .7912 .39216 L p F P
0 g
s
.237 .311 .738 r
.6338 .26984 m .63207 .27503 L .63704 .27882 L p F P
0 g
s
.282 .33 .735 r
.62921 .26596 m .6338 .26984 L .63207 .27503 L p F P
0 g
s
0 0 .006 r
.821 .34659 m .81914 .35032 L .8175 .35639 L p F P
0 g
s
0 0 .225 r
.81914 .35032 m .821 .34659 L .82114 .34193 L p F P
0 g
s
.549 .611 .867 r
.71442 .39213 m .71197 .38774 L .71774 .38753 L closepath p F P
0 g
s
0 0 .195 r
.8222 .33945 m .82114 .34193 L .821 .34659 L p F P
0 g
s
.46 .583 .89 r
.71647 .15884 m .72688 .15997 L .72702 .16472 L p F P
0 g
s
.46 .586 .892 r
.72688 .15997 m .71647 .15884 L .71489 .15616 L p F P
0 g
s
.335 .432 .813 r
.78671 .22461 m .79343 .22783 L .79257 .23271 L p F P
0 g
s
.343 .445 .821 r
.7874 .21976 m .78671 .22461 L .79343 .22783 L p F P
0 g
s
.35 .453 .825 r
.78103 .21699 m .7874 .21976 L .78671 .22461 L p F P
0 g
s
.267 .343 .757 r
.80925 .25984 m .80692 .25806 L .80761 .25543 L closepath p F P
0 g
s
.299 .378 .776 r
.80619 .25178 m .80269 .24944 L p .80692 .25806 L F P
0 g
s
.299 .378 .776 r
.80692 .25806 m .80761 .25543 L .80619 .25178 L p F P
0 g
s
.344 .451 .827 r
.7874 .21976 m .78103 .21699 L .78044 .21573 L p F P
0 g
s
.395 .51 .857 r
.75736 .19103 m .75743 .18947 L p .76581 .19674 L F P
0 g
s
.407 .525 .864 r
.75736 .19103 m .7564 .18921 L .75743 .18947 L closepath p F P
0 g
s
.554 .676 .919 r
.66298 .1317 m .66161 .13184 L .65864 .12759 L p F P
0 g
s
.961 .772 .327 r
.60417 .15297 m .6053 .15747 L .60475 .16289 L p F P
0 g
s
.995 .845 .496 r
.6053 .15747 m .60417 .15297 L .60464 .15091 L p F P
0 g
s
.642 .776 .945 r
.7484 .40296 m .76074 .39937 L .76351 .40251 L p F P
0 g
s
.627 .752 .937 r
.76074 .39937 m .7484 .40296 L .74556 .3991 L p F P
0 g
s
.421 .538 .87 r
.74809 .18253 m .75349 .1837 L .75057 .17823 L p F P
0 g
s
.421 .538 .87 r
.75057 .17823 m .74827 .17773 L .74809 .18253 L p F P
0 g
s
.324 .416 .802 r
.7979 .24099 m .79892 .23607 L .79257 .23271 L p F P
0 g
s
.327 .424 .808 r
.79343 .22783 m .79257 .23271 L .79892 .23607 L p F P
0 g
s
.287 .371 .775 r
.80619 .25178 m .80269 .24944 L .80366 .24533 L closepath p F P
0 g
s
.317 .402 .792 r
.80315 .24409 m .7979 .24099 L p .80269 .24944 L F P
0 g
s
.317 .402 .792 r
.80269 .24944 m .80366 .24533 L .80315 .24409 L p F P
0 g
s
.958 .901 .724 r
.60862 .13608 m .60981 .14059 L .60595 .14713 L p F P
0 g
s
.867 .841 .817 r
.61332 .13038 m .60862 .13608 L .60981 .14059 L p F P
0 g
s
.301 .393 .79 r
.7979 .24099 m .80315 .24409 L .80014 .2368 L p F P
0 g
s
.301 .393 .79 r
.80014 .2368 m .79892 .23607 L .7979 .24099 L p F P
0 g
s
0 0 .261 r
.60636 .1777 m .60677 .1824 L .608 .18724 L p F P
0 g
s
.525 .57 .843 r
.69352 .37569 m .706 .37666 L p .70337 .38201 L F P
0 g
s
.502 .551 .839 r
.70299 .37083 m .706 .37666 L .69352 .37569 L p F P
0 g
s
.502 .551 .839 r
.69582 .37003 m .70299 .37083 L p .69352 .37569 L F P
0 g
s
.502 .551 .839 r
.69352 .37569 m .6929 .37441 L .69582 .37003 L p F P
0 g
s
.865 .993 .751 r
.80784 .37483 m .81073 .36964 L p .80214 .3816 L F P
0 g
s
.865 .993 .751 r
.80214 .3816 m .80246 .38153 L .80784 .37483 L p F P
0 g
s
.726 .907 .537 r
.81171 .36822 m .81318 .36619 L p .80784 .37483 L F P
0 g
s
.726 .907 .537 r
.80784 .37483 m .81073 .36964 L .81171 .36822 L p F P
0 g
s
.675 .828 .957 r
.77577 .39732 m .76351 .40251 L .76074 .39937 L p F P
0 g
s
.692 .856 .961 r
.76351 .40251 m .77577 .39732 L .77634 .3978 L p F P
0 g
s
.453 .488 .805 r
.67236 .34747 m .6688 .34653 L .666 .33994 L p F P
0 g
s
.202 .284 .726 r
.6307 .26082 m .62921 .26596 L .6338 .26984 L p F P
0 g
s
.25 .305 .725 r
.62646 .25683 m .6307 .26082 L .62921 .26596 L p F P
0 g
s
.344 .451 .827 r
.78044 .21573 m .78086 .21186 L p .7874 .21976 L F P
0 g
s
.36 .471 .837 r
.78044 .21573 m .77809 .2108 L .78086 .21186 L closepath p F P
0 g
s
.488 .615 .903 r
.70085 .14863 m .71061 .14908 L .70768 .1443 L p F P
0 g
s
.488 .615 .903 r
.70768 .1443 m .70024 .144 L .70085 .14863 L p F P
0 g
s
.492 .619 .905 r
.69518 .14385 m .70024 .144 L .70085 .14863 L p F P
0 g
s
0 .052 .593 r
.61402 .21068 m .61362 .21558 L .61636 .21998 L p F P
0 g
s
0 .069 .596 r
.61165 .20618 m .61402 .21068 L .61362 .21558 L p F P
0 g
s
0 0 0 r
.8148 .3628 m .81318 .36619 L p .81319 .36618 L F P
0 g
s
0 0 0 r
.8175 .35639 m .8148 .3628 L p .81319 .36618 L F P
0 g
s
0 0 0 r
.81723 .35772 m .82005 .35126 L p .81498 .3624 L F P
0 g
s
0 0 0 r
.8148 .3628 m .81723 .35772 L p .81498 .3624 L F P
0 g
s
0 0 0 r
.82005 .35126 m .8175 .35639 L .8148 .3628 L p F P
0 g
s
0 0 0 r
.82036 .35063 m .82005 .35126 L .81723 .35772 L p F P
0 g
s
0 0 0 r
.81723 .35772 m .81909 .35387 L .82036 .35063 L p F P
0 g
s
.78 .924 .551 r
.81723 .35772 m .81311 .36458 L p .81893 .35416 L F P
0 g
s
.78 .924 .551 r
.81909 .35387 m .81723 .35772 L p .81893 .35416 L F P
0 g
s
.823 .927 .546 r
.8148 .3628 m .81723 .35772 L p .81721 .35774 L F P
0 g
s
.823 .927 .546 r
.81128 .36865 m .8148 .3628 L .81721 .35774 L F
.72 .864 .446 r
.81171 .36822 m .8148 .3628 L .81318 .36619 L closepath p F P
0 g
s
.17 .229 .682 r
.81702 .28239 m .81768 .28006 L p .81974 .28938 L F P
0 g
s
.17 .229 .682 r
.81974 .28938 m .81875 .28815 L .81702 .28239 L p F P
0 g
s
.198 .266 .708 r
.81702 .28239 m .81551 .27774 L .81768 .28006 L closepath p F P
0 g
s
.557 .676 .918 r
.66298 .1317 m .67392 .1306 L .67096 .12619 L p F P
0 g
s
.557 .676 .918 r
.67096 .12619 m .66174 .12722 L .66298 .1317 L p F P
0 g
s
.554 .676 .919 r
.65864 .12759 m .66174 .12722 L .66298 .1317 L p F P
0 g
s
.5 .548 .837 r
.6929 .37441 m .69049 .36946 L .69582 .37003 L closepath p F P
0 g
s
.197 .265 .708 r
.81768 .28006 m .81551 .27774 L .81426 .27391 L p F P
0 g
s
.197 .265 .708 r
.81426 .27391 m .81504 .27091 L p .81768 .28006 L F P
0 g
s
.223 .299 .731 r
.81426 .27391 m .81235 .26842 L .81504 .27091 L closepath p F P
0 g
s
.405 .526 .867 r
.75743 .18947 m .7564 .18921 L .75349 .1837 L p F P
0 g
s
.114 .148 .618 r
.82217 .30072 m .82115 .29889 L .8215 .29795 L closepath p F P
0 g
s
.166 .206 .658 r
.82115 .29889 m .8215 .29795 L .81943 .2904 L p F P
0 g
s
.793 .946 .923 r
.79191 .39086 m .79055 .39191 L .78795 .39052 L p F P
0 g
s
.773 .884 .926 r
.79055 .39191 m .78795 .39052 L p .77634 .3978 L F P
0 g
s
.171 .229 .682 r
.81943 .2904 m .81875 .28815 L .81974 .28938 L closepath p F P
0 g
s
.812 .973 .9 r
.80214 .3816 m .80171 .38229 L .79191 .39086 L p F P
0 g
s
.812 .973 .9 r
.79999 .38149 m .80214 .3816 L p .79191 .39086 L F P
0 g
s
.812 .973 .9 r
.79191 .39086 m .79469 .38573 L .79999 .38149 L p F P
0 g
s
.793 .946 .923 r
.78795 .39052 m .79469 .38573 L .79191 .39086 L p F P
0 g
s
.123 .176 .646 r
.81974 .28938 m .81943 .2904 L .8215 .29795 L p F P
0 g
s
.161 .254 .712 r
.6277 .25175 m .62646 .25683 L .6307 .26082 L p F P
0 g
s
.215 .277 .713 r
.62381 .24767 m .6277 .25175 L .62646 .25683 L p F P
0 g
s
.222 .299 .732 r
.81504 .27091 m .81235 .26842 L .81113 .26494 L p F P
0 g
s
.455 .576 .887 r
.72702 .16472 m .732 .16537 L .72908 .16025 L p F P
0 g
s
.455 .576 .887 r
.72908 .16025 m .72688 .15997 L .72702 .16472 L p F P
0 g
s
.436 .562 .884 r
.73812 .17106 m .73492 .17052 L .732 .16537 L p F P
0 g
s
.797 .996 .781 r
.80171 .38229 m .80214 .3816 L .80246 .38153 L closepath p F P
0 g
s
0 0 .438 r
.82542 .31856 m .82333 .32362 L .82416 .32891 L p F P
0 g
s
.017 .02 .516 r
.82333 .32362 m .82542 .31856 L .82392 .3135 L p F P
0 g
s
.46 .586 .892 r
.71489 .15616 m .71468 .15401 L p .72688 .15997 L F P
0 g
s
.468 .595 .896 r
.71489 .15616 m .71354 .15391 L .71468 .15401 L closepath p F P
0 g
s
.52 .643 .91 r
.68419 .13938 m .69224 .13921 L .68929 .13461 L p F P
0 g
s
.52 .643 .91 r
.68929 .13461 m .68339 .13478 L .68419 .13938 L p F P
0 g
s
.52 .646 .912 r
.67688 .13504 m .68339 .13478 L .68419 .13938 L p F P
0 g
s
.222 .299 .732 r
.81113 .26494 m .81185 .26194 L p .81504 .27091 L F P
0 g
s
.246 .33 .752 r
.81113 .26494 m .80925 .25984 L .81185 .26194 L closepath p F P
0 g
s
.395 .51 .857 r
.75743 .18947 m .76613 .19193 L .76581 .19674 L p F P
0 g
s
.404 .522 .863 r
.75754 .18471 m .75743 .18947 L .76613 .19193 L p F P
0 g
s
.405 .526 .867 r
.75349 .1837 m .75754 .18471 L .75743 .18947 L p F P
0 g
s
.517 .583 .86 r
.70899 .38227 m .70337 .38201 L .70625 .37712 L closepath p F P
0 g
s
.525 .57 .843 r
.706 .37666 m .70625 .37712 L .70337 .38201 L p F P
0 g
s
.837 .638 .092 r
.60564 .17269 m .6049 .16808 L .60475 .16289 L p F P
0 g
s
0 0 .536 r
.61176 .20135 m .61165 .20618 L .61402 .21068 L p F P
0 g
s
0 0 .505 r
.61165 .20618 m .61176 .20135 L .60977 .19673 L p F P
0 g
s
.664 .738 .905 r
.62832 .12627 m .64044 .12195 L .64344 .12597 L p F P
0 g
s
.673 .744 .904 r
.64044 .12195 m .62832 .12627 L .62532 .12257 L p F P
0 g
s
.453 .488 .805 r
.666 .33994 m .66631 .33941 L p .67236 .34747 L F P
0 g
s
.436 .476 .803 r
.666 .33994 m .6657 .33923 L .66631 .33941 L closepath p F P
0 g
s
.593 .661 .885 r
.73718 .39586 m .73028 .39691 L .72737 .3922 L p F P
0 g
s
.551 .606 .861 r
.71774 .38753 m .71197 .38774 L .70899 .38227 L p F P
0 g
s
.083 .126 .609 r
.8215 .29795 m .82274 .29393 L p .82371 .3036 L F P
0 g
s
.083 .126 .609 r
.82371 .3036 m .82217 .30072 L .8215 .29795 L p F P
0 g
s
.123 .176 .646 r
.8215 .29795 m .82274 .29393 L .81974 .28938 L p F P
0 g
s
.439 .474 .799 r
.66631 .33941 m .6657 .33923 L .66259 .33173 L p F P
0 g
s
.114 .218 .695 r
.62481 .24265 m .62381 .24767 L .6277 .25175 L p F P
0 g
s
.173 .245 .698 r
.62125 .23847 m .62481 .24265 L .62381 .24767 L p F P
0 g
s
.981 .897 .558 r
.60595 .14713 m .60502 .14254 L p .60376 .1516 L F P
0 g
s
.981 .897 .558 r
.60376 .1516 m .60464 .15091 L .60595 .14713 L p F P
0 g
s
.958 .901 .724 r
.60595 .14713 m .60502 .14254 L .60862 .13608 L p F P
0 g
s
.837 .997 .834 r
.79999 .38149 m .80435 .37719 L .80214 .3816 L closepath p F P
0 g
s
.865 .993 .751 r
.81073 .36964 m .80435 .37719 L .80214 .3816 L p F P
0 g
s
.245 .329 .753 r
.81185 .26194 m .80925 .25984 L .80761 .25543 L p F P
0 g
s
0 0 .006 r
.82056 .3495 m .821 .34659 L p .8175 .35639 L F P
0 g
s
0 0 .006 r
.8175 .35639 m .82005 .35126 L .82056 .3495 L p F P
0 g
s
.605 .702 .913 r
.64344 .12597 m .65566 .12336 L .65864 .12759 L p F P
0 g
s
.61 .707 .913 r
.65566 .12336 m .64344 .12597 L .64044 .12195 L p F P
0 g
s
.17 .229 .682 r
.81768 .28006 m .82116 .28445 L .81974 .28938 L p F P
0 g
s
.12 .178 .649 r
.82116 .28445 m .81974 .28938 L .82274 .29393 L p F P
0 g
s
.358 .471 .839 r
.78086 .21186 m .77809 .2108 L .77515 .20468 L p F P
0 g
s
.397 .447 .795 r
.66259 .33173 m .66104 .33111 L .66173 .32966 L closepath p F P
0 g
s
.394 .442 .792 r
.65946 .32409 m .65628 .32264 L p .66104 .33111 L F P
0 g
s
.394 .442 .792 r
.66104 .33111 m .66173 .32966 L .65946 .32409 L p F P
0 g
s
.493 .622 .907 r
.70024 .144 m .69518 .14385 L .69224 .13921 L p F P
0 g
s
0 0 .328 r
.8222 .33945 m .82429 .33443 L .82416 .32891 L p F P
0 g
s
0 0 .195 r
.821 .34659 m .82159 .34521 L .8222 .33945 L p F P
0 g
s
0 0 .177 r
.82429 .33443 m .8222 .33945 L .82159 .34521 L p F P
0 g
s
.453 .488 .805 r
.66631 .33941 m .67522 .34211 L .67236 .34747 L p F P
0 g
s
.419 .479 .815 r
.66922 .33401 m .66631 .33941 L .67522 .34211 L p F P
0 g
s
.439 .474 .799 r
.66259 .33173 m .66922 .33401 L .66631 .33941 L p F P
0 g
s
.378 .431 .789 r
.65946 .32409 m .65628 .32264 L .65763 .31957 L closepath p F P
0 g
s
.374 .426 .787 r
.65633 .31632 m .65189 .31405 L p .65628 .32264 L F P
0 g
s
.374 .426 .787 r
.65628 .32264 m .65763 .31957 L .65633 .31632 L p F P
0 g
s
.085 .127 .609 r
.82323 .30505 m .82217 .30072 L .82371 .3036 L closepath p F P
0 g
s
.501 .546 .834 r
.69582 .37003 m .69049 .36946 L .68744 .3631 L p F P
0 g
s
.523 .65 .915 r
.68339 .13478 m .67688 .13504 L .67392 .1306 L p F P
0 g
s
.245 .329 .753 r
.80761 .25543 m .8081 .25314 L p .81185 .26194 L F P
0 g
s
.268 .358 .771 r
.80761 .25543 m .80619 .25178 L .8081 .25314 L closepath p F P
0 g
s
.357 .414 .784 r
.65633 .31632 m .65189 .31405 L .65367 .30963 L closepath p F P
0 g
s
.352 .408 .78 r
.6532 .30843 m .64782 .30537 L p .65189 .31405 L F P
0 g
s
.352 .408 .78 r
.65189 .31405 m .65367 .30963 L .6532 .30843 L p F P
0 g
s
.736 .867 .942 r
.77577 .39732 m .7769 .39673 L .77634 .3978 L closepath p F P
0 g
s
.773 .884 .926 r
.78795 .39052 m .7769 .39673 L .77634 .3978 L p F P
0 g
s
.395 .505 .852 r
.77222 .19873 m .76581 .19674 L p .77371 .20417 L F P
0 g
s
.383 .499 .853 r
.76581 .19674 m .77222 .19873 L .7693 .19291 L p F P
0 g
s
.383 .499 .853 r
.7693 .19291 m .76613 .19193 L .76581 .19674 L p F P
0 g
s
0 0 .455 r
.60958 .19199 m .60977 .19673 L .61176 .20135 L p F P
0 g
s
0 0 .404 r
.60977 .19673 m .60958 .19199 L .608 .18724 L p F P
0 g
s
.466 .5 .809 r
.67236 .34747 m .68132 .34989 L p .67909 .35532 L F P
0 g
s
.43 .477 .808 r
.67236 .34747 m .68132 .34989 L .67824 .34305 L p F P
0 g
s
.43 .477 .808 r
.67824 .34305 m .67522 .34211 L .67236 .34747 L p F P
0 g
s
.058 .176 .673 r
.62199 .23351 m .62125 .23847 L .62481 .24265 L p F P
0 g
s
.126 .209 .68 r
.61877 .22924 m .62199 .23351 L .62125 .23847 L p F P
0 g
s
.466 .597 .899 r
.71468 .15401 m .71354 .15391 L .71061 .14908 L p F P
0 g
s
.322 .381 .768 r
.64782 .30537 m .6532 .30843 L .65005 .3004 L p F P
0 g
s
.322 .381 .768 r
.65005 .3004 m .64972 .30019 L .64782 .30537 L p F P
0 g
s
.317 .376 .765 r
.64782 .30537 m .64972 .30019 L .64401 .29659 L p F P
0 g
s
.888 .666 .147 r
.60367 .15838 m .60475 .16289 L .6049 .16808 L p F P
0 g
s
.961 .772 .327 r
.60475 .16289 m .60367 .15838 L .60417 .15297 L p F P
0 g
s
.158 .225 .683 r
.819 .27514 m .81768 .28006 L .82116 .28445 L p F P
0 g
s
.197 .265 .708 r
.81504 .27091 m .819 .27514 L .81768 .28006 L p F P
0 g
s
.073 .092 .574 r
.82392 .3135 m .82462 .31171 L .82323 .30505 L p F P
0 g
s
.005 .013 .514 r
.82462 .31171 m .82392 .3135 L .82542 .31856 L p F P
0 g
s
.439 .557 .878 r
.74765 .17282 m .73812 .17106 L p .74827 .17773 L F P
0 g
s
.428 .555 .881 r
.73812 .17106 m .74765 .17282 L .74473 .16758 L p F P
0 g
s
.428 .555 .881 r
.74473 .16758 m .73794 .16634 L .73812 .17106 L p F P
0 g
s
.436 .562 .884 r
.732 .16537 m .73794 .16634 L .73812 .17106 L p F P
0 g
s
.266 .358 .771 r
.8081 .25314 m .80619 .25178 L .80366 .24533 L p F P
0 g
s
.021 .056 .557 r
.82371 .3036 m .82323 .30505 L .82462 .31171 L p F P
0 g
s
.465 .518 .828 r
.68439 .35654 m .67909 .35532 L p .68661 .36293 L F P
0 g
s
.453 .509 .826 r
.68439 .35654 m .67909 .35532 L .6816 .35051 L closepath p F P
0 g
s
.466 .5 .809 r
.68132 .34989 m .6816 .35051 L .67909 .35532 L p F P
0 g
s
.307 .375 .769 r
.64575 .29144 m .64401 .29659 L .64972 .30019 L p F P
0 g
s
.294 .357 .757 r
.64401 .29659 m .64575 .29144 L .64043 .28773 L p F P
0 g
s
.424 .463 .796 r
.66922 .33401 m .66259 .33173 L .66173 .32966 L p F P
0 g
s
.46 .586 .892 r
.71468 .15401 m .72615 .15519 L p .72688 .15997 L F P
0 g
s
.461 .592 .897 r
.71468 .15401 m .72615 .15519 L .72322 .15028 L p F P
0 g
s
.461 .592 .897 r
.72322 .15028 m .71412 .14938 L .71468 .15401 L p F P
0 g
s
.466 .597 .899 r
.71061 .14908 m .71412 .14938 L .71468 .15401 L p F P
0 g
s
.999 .839 .513 r
.60417 .15297 m .60376 .1516 L .60464 .15091 L closepath p F P
0 g
s
.719 .845 .942 r
.7769 .39673 m .77577 .39732 L .77305 .39473 L p F P
0 g
s
.675 .828 .957 r
.76074 .39937 m .77305 .39473 L .77577 .39732 L p F P
0 g
s
.372 .482 .842 r
.77515 .20468 m .77371 .20417 L .77393 .20215 L closepath p F P
0 g
s
.395 .505 .852 r
.77371 .20417 m .77393 .20215 L .77222 .19873 L p F P
0 g
s
.403 .527 .868 r
.75754 .18471 m .75349 .1837 L .75057 .17823 L p F P
0 g
s
.559 .681 .921 r
.66174 .12722 m .65864 .12759 L .65566 .12336 L p F P
0 g
s
.627 .752 .937 r
.74556 .3991 m .75795 .39597 L .76074 .39937 L p F P
0 g
s
.612 .731 .93 r
.75795 .39597 m .74556 .3991 L .7427 .39502 L p F P
0 g
s
0 0 .021 r
.82056 .3495 m .82159 .34521 L .821 .34659 L closepath p F P
0 g
s
0 .126 .645 r
.61925 .22434 m .61877 .22924 L .62199 .23351 L p F P
0 g
s
0 .119 .635 r
.61877 .22924 m .61925 .22434 L .61636 .21998 L p F P
0 g
s
0 0 .342 r
.60751 .18257 m .608 .18724 L .60958 .19199 L p F P
0 g
s
0 0 .261 r
.608 .18724 m .60751 .18257 L .60636 .1777 L p F P
0 g
s
.812 .834 .867 r
.61614 .12827 m .61332 .13038 L .61032 .1275 L p F P
0 g
s
.88 .842 .803 r
.60862 .13608 m .61332 .13038 L .61032 .1275 L p F P
0 g
s
.719 .845 .942 r
.77305 .39473 m .7795 .39165 L .7769 .39673 L p F P
0 g
s
.745 .905 .948 r
.78531 .3887 m .7795 .39165 L .7769 .39673 L p F P
0 g
s
.745 .905 .948 r
.7769 .39673 m .78795 .39052 L .78531 .3887 L p F P
0 g
s
.424 .463 .796 r
.66173 .32966 m .66374 .32575 L p .66922 .33401 L F P
0 g
s
.406 .45 .793 r
.66173 .32966 m .65946 .32409 L .66374 .32575 L closepath p F P
0 g
s
.278 .353 .761 r
.642 .28262 m .64043 .28773 L .64575 .29144 L p F P
0 g
s
.267 .335 .748 r
.64043 .28773 m .642 .28262 L .63704 .27882 L p F P
0 g
s
.19 .266 .712 r
.81625 .266 m .81504 .27091 L .819 .27514 L p F P
0 g
s
.222 .299 .732 r
.81185 .26194 m .81625 .266 L .81504 .27091 L p F P
0 g
s
.812 .834 .867 r
.61032 .1275 m .61494 .12373 L .61614 .12827 L p F P
0 g
s
.754 .788 .88 r
.6223 .11889 m .61494 .12373 L .61614 .12827 L p F P
0 g
s
.754 .788 .88 r
.61614 .12827 m .62532 .12257 L .6223 .11889 L p F P
0 g
s
.467 .521 .83 r
.68744 .3631 m .68661 .36293 L .68702 .36219 L closepath p F P
0 g
s
.465 .518 .828 r
.68661 .36293 m .68702 .36219 L .68439 .35654 L p F P
0 g
s
.435 .564 .886 r
.73794 .16634 m .732 .16537 L .72908 .16025 L p F P
0 g
s
.823 .927 .546 r
.81128 .36865 m .81171 .36822 L .8148 .3628 L p F P
0 g
s
.659 .801 .951 r
.77305 .39473 m .76074 .39937 L .75795 .39597 L p F P
0 g
s
.344 .451 .827 r
.78086 .21186 m .78801 .21491 L .7874 .21976 L p F P
0 g
s
.353 .465 .835 r
.78129 .20706 m .78086 .21186 L .78801 .21491 L p F P
0 g
s
.358 .471 .839 r
.77515 .20468 m .78129 .20706 L .78086 .21186 L p F P
0 g
s
.266 .358 .771 r
.80366 .24533 m .80382 .2445 L p .8081 .25314 L F P
0 g
s
.288 .384 .787 r
.80366 .24533 m .80315 .24409 L .80382 .2445 L closepath p F P
0 g
s
.246 .329 .752 r
.63841 .27374 m .63704 .27882 L .642 .28262 L p F P
0 g
s
.237 .311 .738 r
.63704 .27882 m .63841 .27374 L .6338 .26984 L p F P
0 g
s
.978 .776 .36 r
.60376 .1516 m .60417 .15297 L .60367 .15838 L p F P
0 g
s
.217 .3 .736 r
.81292 .25705 m .81185 .26194 L .81625 .266 L p F P
0 g
s
.245 .329 .753 r
.8081 .25314 m .81292 .25705 L .81185 .26194 L p F P
0 g
s
.551 .606 .861 r
.70899 .38227 m .72074 .38226 L .71774 .38753 L p F P
0 g
s
.537 .593 .858 r
.72074 .38226 m .70899 .38227 L .70625 .37712 L p F P
0 g
s
0 .066 .608 r
.61658 .21514 m .61636 .21998 L .61925 .22434 L p F P
0 g
s
0 .052 .593 r
.61636 .21998 m .61658 .21514 L .61402 .21068 L p F P
0 g
s
.501 .546 .834 r
.68744 .3631 m .69873 .36472 L .69582 .37003 L p F P
0 g
s
.488 .533 .829 r
.69873 .36472 m .68744 .3631 L .68702 .36219 L p F P
0 g
s
0 0 .328 r
.82627 .32385 m .82416 .32891 L .82429 .33443 L p F P
0 g
s
0 0 .438 r
.82416 .32891 m .82627 .32385 L .82542 .31856 L p F P
0 g
s
.959 .883 .715 r
.60712 .13166 m .60862 .13608 L .60502 .14254 L p F P
0 g
s
.88 .842 .803 r
.61032 .1275 m .60712 .13166 L .60862 .13608 L p F P
0 g
s
.353 .471 .84 r
.78129 .20706 m .77515 .20468 L .77393 .20215 L p F P
0 g
s
.285 .384 .789 r
.80382 .2445 m .80315 .24409 L .80014 .2368 L p F P
0 g
s
.531 .604 .871 r
.71774 .38753 m .72443 .38731 L .72149 .38226 L p F P
0 g
s
.531 .604 .871 r
.72149 .38226 m .72074 .38226 L .71774 .38753 L p F P
0 g
s
.575 .665 .899 r
.73718 .39586 m .7427 .39502 L .73982 .39074 L p F P
0 g
s
.575 .665 .899 r
.73982 .39074 m .73978 .39074 L .73718 .39586 L p F P
0 g
s
.593 .661 .885 r
.72737 .3922 m .73978 .39074 L .73718 .39586 L p F P
0 g
s
.021 .056 .557 r
.82462 .31171 m .82568 .30851 L .82371 .3036 L p F P
0 g
s
.015 .055 .558 r
.82526 .29866 m .82371 .3036 L .82568 .30851 L p F P
0 g
s
.083 .126 .609 r
.82274 .29393 m .82526 .29866 L .82371 .3036 L p F P
0 g
s
.343 .445 .821 r
.79417 .22293 m .7874 .21976 L p .79343 .22783 L F P
0 g
s
.328 .437 .82 r
.7874 .21976 m .79417 .22293 L .79121 .21642 L p F P
0 g
s
.328 .437 .82 r
.79121 .21642 m .78801 .21491 L .7874 .21976 L p F P
0 g
s
.407 .449 .792 r
.66374 .32575 m .65946 .32409 L .65763 .31957 L p F P
0 g
s
.419 .539 .872 r
.75057 .17823 m .74827 .17773 L .74833 .17407 L closepath p F P
0 g
s
.439 .557 .878 r
.74827 .17773 m .74833 .17407 L .74765 .17282 L p F P
0 g
s
.488 .533 .829 r
.68702 .36219 m .68984 .3575 L p .69873 .36472 L F P
0 g
s
.475 .524 .828 r
.68702 .36219 m .68439 .35654 L .68984 .3575 L closepath p F P
0 g
s
0 0 .191 r
.60669 .178 m .60558 .17311 L p .60662 .17821 L F P
0 g
s
0 0 .191 r
.60751 .18257 m .60669 .178 L p .60662 .17821 L F P
0 g
s
0 0 .246 r
.60669 .178 m .60814 .1828 L p .60675 .17781 L F P
0 g
s
.733 .513 0 r
.60636 .1777 m .60558 .17311 L p .60573 .1736 L F P
0 g
s
.715 .453 0 r
.60669 .178 m .60575 .17421 L .60523 .17193 L p F P
0 g
s
0 0 .246 r
.60575 .17421 m .60669 .178 L p .60675 .17781 L F P
0 g
s
.715 .453 0 r
.60558 .17311 m .60669 .178 L p .60543 .17261 L F P
0 g
s
.715 .453 0 r
.60449 .1686 m .60558 .17311 L p .60543 .17261 L F P
0 g
s
.733 .513 0 r
.60558 .17311 m .6049 .16808 L p .60573 .1736 L F P
0 g
s
.239 .331 .756 r
.80905 .24827 m .8081 .25314 L .81292 .25705 L p F P
0 g
s
.266 .358 .771 r
.80382 .2445 m .80905 .24827 L .8081 .25314 L p F P
0 g
s
.579 .647 .881 r
.73978 .39074 m .72737 .3922 L .72443 .38731 L p F P
0 g
s
.21 .302 .741 r
.63498 .26481 m .6338 .26984 L .63841 .27374 L p F P
0 g
s
.202 .284 .726 r
.6338 .26984 m .63498 .26481 L .6307 .26082 L p F P
0 g
s
0 0 .492 r
.82568 .30851 m .82462 .31171 L .82567 .31792 L p F P
0 g
s
.005 .013 .514 r
.82542 .31856 m .82567 .31792 L .82462 .31171 L p F P
0 g
s
.49 .618 .905 r
.70024 .144 m .70768 .1443 L .70474 .13955 L p F P
0 g
s
.49 .618 .905 r
.70474 .13955 m .69954 .13937 L .70024 .144 L p F P
0 g
s
.493 .622 .907 r
.69224 .13921 m .69954 .13937 L .70024 .144 L p F P
0 g
s
.562 .68 .919 r
.66174 .12722 m .67096 .12619 L .66798 .12183 L p F P
0 g
s
.562 .68 .919 r
.66798 .12183 m .66043 .12275 L .66174 .12722 L p F P
0 g
s
.559 .681 .921 r
.65566 .12336 m .66043 .12275 L .66174 .12722 L p F P
0 g
s
.327 .424 .808 r
.79716 .2298 m .79343 .22783 L p .79892 .23607 L F P
0 g
s
.315 .417 .807 r
.79716 .2298 m .79343 .22783 L .7942 .22299 L closepath p F P
0 g
s
.343 .445 .821 r
.79343 .22783 m .7942 .22299 L .79417 .22293 L p F P
0 g
s
0 0 0 r
.82159 .34521 m .82364 .3402 L p .82036 .35063 L F P
0 g
s
0 0 0 r
.82036 .35063 m .82056 .3495 L .82159 .34521 L p F P
0 g
s
0 0 .177 r
.82159 .34521 m .82364 .3402 L .82429 .33443 L p F P
0 g
s
.259 .357 .774 r
.80462 .23966 m .80382 .2445 L .80905 .24827 L p F P
0 g
s
.285 .384 .789 r
.80014 .2368 m .80462 .23966 L .80382 .2445 L p F P
0 g
s
.327 .424 .808 r
.79892 .23607 m .79921 .23454 L .79716 .2298 L p F P
0 g
s
.297 .393 .792 r
.80014 .2368 m .79892 .23607 L .79921 .23454 L closepath p F P
0 g
s
0 0 .558 r
.61398 .20591 m .61402 .21068 L .61658 .21514 L p F P
0 g
s
0 0 .536 r
.61402 .21068 m .61398 .20591 L .61176 .20135 L p F P
0 g
s
.48 .54 .841 r
.69582 .37003 m .70299 .37083 L .69997 .36491 L p F P
0 g
s
.48 .54 .841 r
.69997 .36491 m .69873 .36472 L .69582 .37003 L p F P
0 g
s
.494 .626 .909 r
.69954 .13937 m .69224 .13921 L .68929 .13461 L p F P
0 g
s
.734 .912 .545 r
.81073 .36964 m .81128 .36865 L .81171 .36822 L closepath p F P
0 g
s
.353 .471 .84 r
.77393 .20215 m .77408 .19936 L p .78129 .20706 L F P
0 g
s
.369 .489 .85 r
.77393 .20215 m .77222 .19873 L .77408 .19936 L closepath p F P
0 g
s
.407 .449 .792 r
.65763 .31957 m .65869 .31735 L p .66374 .32575 L F P
0 g
s
.388 .435 .788 r
.65763 .31957 m .65633 .31632 L .65869 .31735 L closepath p F P
0 g
s
.169 .272 .728 r
.63166 .25583 m .6307 .26082 L .63498 .26481 L p F P
0 g
s
.161 .254 .712 r
.6307 .26082 m .63166 .25583 L .6277 .25175 L p F P
0 g
s
.673 .744 .904 r
.62532 .12257 m .63745 .11795 L .64044 .12195 L p F P
0 g
s
.682 .749 .902 r
.63745 .11795 m .62532 .12257 L .6223 .11889 L p F P
0 g
s
.61 .707 .913 r
.64044 .12195 m .65267 .11917 L .65566 .12336 L p F P
0 g
s
.616 .712 .914 r
.65267 .11917 m .64044 .12195 L .63745 .11795 L p F P
0 g
s
.958 .789 .344 r
.60315 .14841 m .60376 .1516 L .60276 .15535 L p F P
0 g
s
.981 .897 .558 r
.60502 .14254 m .60315 .14841 L .60376 .1516 L p F P
0 g
s
.978 .776 .36 r
.60367 .15838 m .60276 .15535 L .60376 .1516 L p F P
0 g
s
.454 .578 .888 r
.72908 .16025 m .72688 .15997 L .72671 .15614 L closepath p F P
0 g
s
.46 .586 .892 r
.72615 .15519 m .72671 .15614 L .72688 .15997 L p F P
0 g
s
.524 .647 .912 r
.68339 .13478 m .68929 .13461 L .68633 .13004 L p F P
0 g
s
.524 .647 .912 r
.68633 .13004 m .68252 .13019 L .68339 .13478 L p F P
0 g
s
.523 .65 .915 r
.67392 .1306 m .68252 .13019 L .68339 .13478 L p F P
0 g
s
.827 .998 .781 r
.81128 .36865 m .81073 .36964 L .80435 .37719 L p F P
0 g
s
.762 .959 .934 r
.79469 .38573 m .78795 .39052 L .78531 .3887 L p F P
0 g
s
.526 .654 .917 r
.68252 .13019 m .67392 .1306 L .67096 .12619 L p F P
0 g
s
.466 .6 .901 r
.71412 .14938 m .71061 .14908 L .70768 .1443 L p F P
0 g
s
.073 .124 .611 r
.82421 .28899 m .82274 .29393 L .82526 .29866 L p F P
0 g
s
.12 .178 .649 r
.82274 .29393 m .82421 .28899 L .82116 .28445 L p F P
0 g
s
.802 .556 0 r
.60383 .16357 m .6049 .16808 L .60558 .17311 L p F P
0 g
s
.888 .666 .147 r
.6049 .16808 m .60383 .16357 L .60367 .15838 L p F P
0 g
s
.39 .435 .787 r
.65869 .31735 m .65633 .31632 L .65367 .30963 L p F P
0 g
s
.276 .38 .788 r
.80462 .23966 m .80014 .2368 L .79921 .23454 L p F P
0 g
s
.404 .522 .863 r
.76637 .18712 m .75754 .18471 L p .76613 .19193 L F P
0 g
s
.392 .518 .865 r
.75754 .18471 m .76637 .18712 L .76345 .18156 L p F P
0 g
s
.392 .518 .865 r
.76345 .18156 m .75756 .17996 L .75754 .18471 L p F P
0 g
s
.403 .527 .868 r
.75057 .17823 m .75756 .17996 L .75754 .18471 L p F P
0 g
s
.122 .237 .711 r
.62845 .24681 m .6277 .25175 L .63166 .25583 L p F P
0 g
s
.114 .218 .695 r
.6277 .25175 m .62845 .24681 L .62481 .24265 L p F P
0 g
s
.4 .528 .87 r
.75756 .17996 m .75057 .17823 L .74833 .17407 L p F P
0 g
s
0 0 .491 r
.61146 .19665 m .61176 .20135 L .61398 .20591 L p F P
0 g
s
0 0 .455 r
.61176 .20135 m .61146 .19665 L .60958 .19199 L p F P
0 g
s
.996 .866 .568 r
.60374 .13805 m .60502 .14254 L .60315 .14841 L p F P
0 g
s
.959 .883 .715 r
.60502 .14254 m .60374 .13805 L .60712 .13166 L p F P
0 g
s
.476 .522 .826 r
.68984 .3575 m .68439 .35654 L .6816 .35051 L p F P
0 g
s
.804 .981 .896 r
.79469 .38573 m .79764 .38084 L .79999 .38149 L closepath p F P
0 g
s
.762 .959 .934 r
.79764 .38084 m .79469 .38573 L p .78531 .3887 L F P
0 g
s
0 0 .432 r
.82567 .31792 m .82542 .31856 L .82627 .32385 L p F P
0 g
s
.276 .38 .788 r
.79921 .23454 m .79967 .23122 L p .80462 .23966 L F P
0 g
s
.297 .405 .803 r
.79921 .23454 m .79716 .2298 L .79967 .23122 L closepath p F P
0 g
s
.861 .978 .857 r
.80435 .37719 m .80705 .37204 L p .79764 .38084 L F P
0 g
s
.861 .978 .857 r
.79764 .38084 m .79999 .38149 L .80435 .37719 L p F P
0 g
s
.827 .998 .781 r
.80936 .36954 m .81128 .36865 L p .80435 .37719 L F P
0 g
s
.827 .998 .781 r
.80435 .37719 m .80705 .37204 L .80936 .36954 L p F P
0 g
s
.537 .593 .858 r
.70625 .37712 m .70654 .37667 L p .72074 .38226 L F P
0 g
s
.527 .586 .858 r
.70625 .37712 m .706 .37666 L .70654 .37667 L closepath p F P
0 g
s
0 0 0 r
.82005 .35126 m .82036 .35063 L .82056 .3495 L closepath p F P
0 g
s
.833 .98 .687 r
.80936 .36954 m .81311 .36458 L .81128 .36865 L closepath p F P
0 g
s
.823 .927 .546 r
.81723 .35772 m .81311 .36458 L .81128 .36865 L p F P
0 g
s
.612 .731 .93 r
.7427 .39502 m .75513 .39232 L .75795 .39597 L p F P
0 g
s
.599 .712 .924 r
.75513 .39232 m .7427 .39502 L .73982 .39074 L p F P
0 g
s
.068 .197 .691 r
.62533 .23776 m .62481 .24265 L .62845 .24681 L p F P
0 g
s
.058 .176 .673 r
.62481 .24265 m .62533 .23776 L .62199 .23351 L p F P
0 g
s
.366 .49 .851 r
.77408 .19936 m .77222 .19873 L .7693 .19291 L p F P
0 g
s
.529 .581 .851 r
.70654 .37667 m .706 .37666 L .70299 .37083 L p F P
0 g
s
.435 .564 .886 r
.72908 .16025 m .73768 .16164 L .73794 .16634 L p F P
0 g
s
.433 .566 .888 r
.73768 .16164 m .72908 .16025 L .72671 .15614 L p F P
0 g
s
.563 .686 .922 r
.66043 .12275 m .65566 .12336 L .65267 .11917 L p F P
0 g
s
.37 .419 .782 r
.65367 .30963 m .6532 .30843 L .65402 .30883 L closepath p F P
0 g
s
.39 .435 .787 r
.65367 .30963 m .65402 .30883 L p .65869 .31735 L F P
0 g
s
.158 .225 .683 r
.82116 .28445 m .82254 .27951 L .819 .27514 L p F P
0 g
s
.12 .181 .653 r
.82254 .27951 m .82116 .28445 L .82421 .28899 L p F P
0 g
s
0 0 .405 r
.82711 .31361 m .82567 .31792 L .82635 .32365 L p F P
0 g
s
0 0 .492 r
.82567 .31792 m .82711 .31361 L .82568 .30851 L p F P
0 g
s
0 0 .432 r
.82627 .32385 m .82635 .32365 L .82567 .31792 L p F P
0 g
s
.537 .593 .858 r
.70654 .37667 m .71852 .37701 L p .72074 .38226 L F P
0 g
s
.511 .571 .852 r
.70654 .37667 m .71852 .37701 L .71554 .37162 L p F P
0 g
s
.511 .571 .852 r
.71554 .37162 m .70989 .37125 L .70654 .37667 L p F P
0 g
s
.529 .581 .851 r
.70299 .37083 m .70989 .37125 L .70654 .37667 L p F P
0 g
s
0 0 .399 r
.60902 .18735 m .60958 .19199 L .61146 .19665 L p F P
0 g
s
0 0 .342 r
.60958 .19199 m .60902 .18735 L .60751 .18257 L p F P
0 g
s
.92 .681 .188 r
.60276 .15535 m .60367 .15838 L .60383 .16357 L p F P
0 g
s
.371 .419 .781 r
.65402 .30883 m .6532 .30843 L .65005 .3004 L p F P
0 g
s
.381 .5 .855 r
.7693 .19291 m .76613 .19193 L .76638 .18714 L closepath p F P
0 g
s
.404 .522 .863 r
.76613 .19193 m .76638 .18714 L .76637 .18712 L p F P
0 g
s
0 0 .328 r
.82429 .33443 m .82641 .32938 L .82627 .32385 L p F P
0 g
s
0 0 .174 r
.82641 .32938 m .82429 .33443 L .82364 .3402 L p F P
0 g
s
.698 .856 .958 r
.7795 .39165 m .77305 .39473 L .77031 .39184 L p F P
0 g
s
.659 .801 .951 r
.75795 .39597 m .77031 .39184 L .77305 .39473 L p F P
0 g
s
.005 .15 .665 r
.62229 .22867 m .62199 .23351 L .62533 .23776 L p F P
0 g
s
0 .126 .645 r
.62199 .23351 m .62229 .22867 L .61925 .22434 L p F P
0 g
s
.427 .557 .883 r
.73794 .16634 m .74473 .16758 L .74181 .16238 L p F P
0 g
s
.427 .557 .883 r
.74181 .16238 m .73768 .16164 L .73794 .16634 L p F P
0 g
s
.579 .647 .881 r
.72443 .38731 m .73692 .38623 L p .73978 .39074 L F P
0 g
s
.549 .644 .896 r
.73692 .38623 m .72443 .38731 L .72149 .38226 L p F P
0 g
s
.424 .463 .796 r
.66374 .32575 m .67144 .32881 L .66922 .33401 L p F P
0 g
s
.384 .451 .806 r
.66596 .32053 m .66374 .32575 L .67144 .32881 L p F P
0 g
s
.407 .449 .792 r
.65869 .31735 m .66596 .32053 L .66374 .32575 L p F P
0 g
s
.363 .435 .801 r
.66087 .31212 m .65869 .31735 L .66596 .32053 L p F P
0 g
s
.39 .435 .787 r
.65402 .30883 m .66087 .31212 L .65869 .31735 L p F P
0 g
s
.461 .595 .899 r
.71412 .14938 m .72322 .15028 L .7203 .1454 L p F P
0 g
s
.461 .595 .899 r
.7203 .1454 m .71346 .14476 L .71412 .14938 L p F P
0 g
s
.466 .6 .901 r
.70768 .1443 m .71346 .14476 L .71412 .14938 L p F P
0 g
s
.643 .777 .945 r
.77031 .39184 m .75795 .39597 L .75513 .39232 L p F P
0 g
s
.33 .405 .788 r
.65611 .3036 m .65402 .30883 L .66087 .31212 L p F P
0 g
s
.371 .419 .781 r
.65005 .3004 m .65611 .3036 L .65402 .30883 L p F P
0 g
s
.296 .405 .804 r
.79967 .23122 m .79716 .2298 L .7942 .22299 L p F P
0 g
s
.419 .479 .815 r
.67515 .3361 m .66922 .33401 L p .67522 .34211 L F P
0 g
s
.393 .453 .804 r
.66922 .33401 m .67515 .3361 L .67205 .32905 L p F P
0 g
s
.393 .453 .804 r
.67205 .32905 m .67144 .32881 L .66922 .33401 L p F P
0 g
s
.823 .83 .854 r
.61494 .12373 m .61032 .1275 L .6073 .12461 L p F P
0 g
s
.891 .841 .789 r
.60712 .13166 m .61032 .1275 L .6073 .12461 L p F P
0 g
s
.163 .234 .69 r
.82026 .27021 m .819 .27514 L .82254 .27951 L p F P
0 g
s
.19 .266 .712 r
.819 .27514 m .82026 .27021 L .81625 .266 L p F P
0 g
s
0 0 0 r
.82211 .34626 m .82036 .35063 L .81909 .35387 L p F P
0 g
s
0 0 0 r
.82364 .3402 m .82211 .34626 L .82036 .35063 L p F P
0 g
s
.313 .382 .773 r
.65005 .3004 m .64972 .30019 L .64983 .29984 L closepath p F P
0 g
s
.307 .375 .769 r
.64689 .29222 m .64575 .29144 L p .64972 .30019 L F P
0 g
s
.307 .375 .769 r
.64972 .30019 m .64983 .29984 L .64689 .29222 L p F P
0 g
s
0 0 .278 r
.60669 .178 m .60751 .18257 L .60902 .18735 L p F P
0 g
s
.366 .49 .851 r
.7693 .19291 m .77425 .19461 L .77408 .19936 L p F P
0 g
s
.353 .471 .84 r
.77408 .19936 m .78164 .20225 L .78129 .20706 L p F P
0 g
s
.355 .476 .844 r
.77425 .19461 m .77408 .19936 L .78164 .20225 L p F P
0 g
s
.422 .482 .817 r
.67824 .34305 m .67522 .34211 L .67653 .33923 L closepath p F P
0 g
s
.419 .479 .815 r
.67522 .34211 m .67653 .33923 L .67515 .3361 L p F P
0 g
s
.476 .522 .826 r
.6816 .35051 m .68189 .35001 L p .68984 .3575 L F P
0 g
s
.462 .512 .824 r
.6816 .35051 m .68132 .34989 L .68189 .35001 L closepath p F P
0 g
s
.015 .055 .558 r
.82568 .30851 m .82726 .30357 L .82526 .29866 L p F P
0 g
s
0 0 .493 r
.82726 .30357 m .82568 .30851 L .82711 .31361 L p F P
0 g
s
.823 .83 .854 r
.6073 .12461 m .61336 .11932 L .61494 .12373 L p F P
0 g
s
.764 .791 .875 r
.61928 .11521 m .61336 .11932 L .61494 .12373 L p F P
0 g
s
.764 .791 .875 r
.61494 .12373 m .6223 .11889 L .61928 .11521 L p F P
0 g
s
.412 .542 .877 r
.74833 .17407 m .74765 .17282 L .74829 .17296 L closepath p F P
0 g
s
.4 .528 .87 r
.74833 .17407 m .74829 .17296 L p .75756 .17996 L F P
0 g
s
.465 .51 .82 r
.68189 .35001 m .68132 .34989 L .67824 .34305 L p F P
0 g
s
0 .095 .632 r
.61931 .21956 m .61925 .22434 L .62229 .22867 L p F P
0 g
s
0 .066 .608 r
.61925 .22434 m .61931 .21956 L .61658 .21514 L p F P
0 g
s
.353 .407 .778 r
.65611 .3036 m .65005 .3004 L .64983 .29984 L p F P
0 g
s
.353 .407 .778 r
.64983 .29984 m .65165 .29499 L p .65611 .3036 L F P
0 g
s
.331 .39 .773 r
.64983 .29984 m .64689 .29222 L .65165 .29499 L closepath p F P
0 g
s
.286 .362 .766 r
.64689 .29222 m .64575 .29144 L .64611 .29019 L closepath p F P
0 g
s
.278 .353 .761 r
.64373 .28392 m .642 .28262 L p .64575 .29144 L F P
0 g
s
.278 .353 .761 r
.64575 .29144 m .64611 .29019 L .64373 .28392 L p F P
0 g
s
.958 .867 .706 r
.60536 .12732 m .60712 .13166 L .60374 .13805 L p F P
0 g
s
.891 .841 .789 r
.6073 .12461 m .60536 .12732 L .60712 .13166 L p F P
0 g
s
.494 .626 .909 r
.68929 .13461 m .69876 .13476 L .69954 .13937 L p F P
0 g
s
.495 .63 .912 r
.69876 .13476 m .68929 .13461 L .68633 .13004 L p F P
0 g
s
.476 .522 .826 r
.68189 .35001 m .69241 .35226 L .68984 .3575 L p F P
0 g
s
.446 .515 .836 r
.68472 .34466 m .68189 .35001 L .69241 .35226 L p F P
0 g
s
.465 .51 .82 r
.67824 .34305 m .68472 .34466 L .68189 .35001 L p F P
0 g
s
.958 .789 .344 r
.60276 .15535 m .60247 .15389 L .60315 .14841 L p F P
0 g
s
.976 .791 .372 r
.60197 .1439 m .60315 .14841 L .60247 .15389 L p F P
0 g
s
.996 .866 .568 r
.60315 .14841 m .60197 .1439 L .60374 .13805 L p F P
0 g
s
.192 .272 .718 r
.81739 .26109 m .81625 .266 L .82026 .27021 L p F P
0 g
s
.217 .3 .736 r
.81625 .266 m .81739 .26109 L .81292 .25705 L p F P
0 g
s
.353 .465 .835 r
.78825 .20996 m .78129 .20706 L p .78801 .21491 L F P
0 g
s
.339 .458 .835 r
.78129 .20706 m .78825 .20996 L .78531 .20379 L p F P
0 g
s
.339 .458 .835 r
.78531 .20379 m .78164 .20225 L .78129 .20706 L p F P
0 g
s
.256 .339 .758 r
.64373 .28392 m .642 .28262 L .64248 .28064 L closepath p F P
0 g
s
.246 .329 .752 r
.64056 .27551 m .63841 .27374 L p .642 .28262 L F P
0 g
s
.246 .329 .752 r
.642 .28262 m .64248 .28064 L .64056 .27551 L p F P
0 g
s
.41 .544 .88 r
.74829 .17296 m .74765 .17282 L .74473 .16758 L p F P
0 g
s
.466 .603 .904 r
.71346 .14476 m .70768 .1443 L .70474 .13955 L p F P
0 g
s
.698 .856 .958 r
.78285 .38667 m .7795 .39165 L p .77031 .39184 L F P
0 g
s
.728 .874 .949 r
.7795 .39165 m .78285 .38667 L .78531 .3887 L closepath p F P
0 g
s
.566 .684 .919 r
.66043 .12275 m .66798 .12183 L .66501 .11749 L p F P
0 g
s
.566 .684 .919 r
.66501 .11749 m .65906 .11829 L .66043 .12275 L p F P
0 g
s
.563 .686 .922 r
.65267 .11917 m .65906 .11829 L .66043 .12275 L p F P
0 g
s
0 .031 .589 r
.61641 .21042 m .61658 .21514 L .61931 .21956 L p F P
0 g
s
0 0 .558 r
.61658 .21514 m .61641 .21042 L .61398 .20591 L p F P
0 g
s
.526 .654 .917 r
.67096 .12619 m .68157 .12561 L .68252 .13019 L p F P
0 g
s
.528 .659 .919 r
.68157 .12561 m .67096 .12619 L .66798 .12183 L p F P
0 g
s
.802 .556 0 r
.60558 .17311 m .60449 .1686 L .60383 .16357 L p F P
0 g
s
.616 .712 .914 r
.63745 .11795 m .64968 .11501 L .65267 .11917 L p F P
0 g
s
.621 .716 .915 r
.64968 .11501 m .63745 .11795 L .63444 .11397 L p F P
0 g
s
.682 .749 .902 r
.6223 .11889 m .63444 .11397 L .63745 .11795 L p F P
0 g
s
.219 .307 .742 r
.81394 .25216 m .81292 .25705 L .81739 .26109 L p F P
0 g
s
.239 .331 .756 r
.81292 .25705 m .81394 .25216 L .80905 .24827 L p F P
0 g
s
.515 .569 .849 r
.70989 .37125 m .70299 .37083 L .69997 .36491 L p F P
0 g
s
.492 .622 .907 r
.69954 .13937 m .70474 .13955 L .7018 .13485 L p F P
0 g
s
.492 .622 .907 r
.7018 .13485 m .69876 .13476 L .69954 .13937 L p F P
0 g
s
.691 .754 .9 r
.63444 .11397 m .6223 .11889 L .61928 .11521 L p F P
0 g
s
.4 .528 .87 r
.74829 .17296 m .75749 .17523 L .75756 .17996 L p F P
0 g
s
.402 .533 .874 r
.748 .16829 m .74829 .17296 L .75749 .17523 L p F P
0 g
s
.41 .544 .88 r
.74473 .16758 m .748 .16829 L .74829 .17296 L p F P
0 g
s
.433 .566 .888 r
.72671 .15614 m .72661 .15526 L p .73768 .16164 L F P
0 g
s
.443 .577 .893 r
.72671 .15614 m .72615 .15519 L .72661 .15526 L closepath p F P
0 g
s
.363 .489 .853 r
.77425 .19461 m .7693 .19291 L .76638 .18714 L p F P
0 g
s
.221 .314 .748 r
.64056 .27551 m .63841 .27374 L .63894 .27119 L closepath p F P
0 g
s
.21 .302 .741 r
.63739 .267 m .63498 .26481 L p .63841 .27374 L F P
0 g
s
.21 .302 .741 r
.63841 .27374 m .63894 .27119 L .63739 .267 L p F P
0 g
s
.325 .438 .822 r
.79121 .21642 m .78801 .21491 L .7885 .21047 L closepath p F P
0 g
s
.353 .465 .835 r
.78801 .21491 m .7885 .21047 L .78825 .20996 L p F P
0 g
s
.331 .39 .772 r
.65165 .29499 m .64689 .29222 L .64611 .29019 L p F P
0 g
s
.488 .533 .829 r
.68984 .3575 m .69694 .3588 L p .69873 .36472 L F P
0 g
s
.453 .515 .832 r
.68984 .3575 m .69694 .3588 L .69389 .35259 L p F P
0 g
s
.453 .515 .832 r
.69389 .35259 m .69241 .35226 L .68984 .3575 L p F P
0 g
s
.244 .34 .763 r
.80992 .2434 m .80905 .24827 L .81394 .25216 L p F P
0 g
s
.259 .357 .774 r
.80905 .24827 m .80992 .2434 L .80462 .23966 L p F P
0 g
s
.015 .057 .561 r
.82677 .29371 m .82526 .29866 L .82726 .30357 L p F P
0 g
s
.073 .124 .611 r
.82526 .29866 m .82677 .29371 L .82421 .28899 L p F P
0 g
s
0 0 .32 r
.82635 .32365 m .82627 .32385 L .82641 .32938 L p F P
0 g
s
.296 .405 .804 r
.7942 .22299 m .79421 .22294 L p .79967 .23122 L F P
0 g
s
.315 .428 .817 r
.7942 .22299 m .79417 .22293 L .79421 .22294 L closepath p F P
0 g
s
.311 .428 .819 r
.79421 .22294 m .79417 .22293 L .79121 .21642 L p F P
0 g
s
.331 .39 .772 r
.64611 .29019 m .64743 .2863 L p .65165 .29499 L F P
0 g
s
.307 .372 .766 r
.64611 .29019 m .64373 .28392 L .64743 .2863 L closepath p F P
0 g
s
.296 .405 .804 r
.79421 .22294 m .80026 .2264 L .79967 .23122 L p F P
0 g
s
.289 .405 .807 r
.79464 .21816 m .79421 .22294 L .80026 .2264 L p F P
0 g
s
.311 .428 .819 r
.79121 .21642 m .79464 .21816 L .79421 .22294 L p F P
0 g
s
.267 .369 .782 r
.80536 .23481 m .80462 .23966 L .80992 .2434 L p F P
0 g
s
.276 .38 .788 r
.79967 .23122 m .80536 .23481 L .80462 .23966 L p F P
0 g
s
.275 .384 .793 r
.80026 .2264 m .79967 .23122 L .80536 .23481 L p F P
0 g
s
0 0 .288 r
.82793 .31891 m .82635 .32365 L .82662 .32884 L p F P
0 g
s
0 0 .405 r
.82635 .32365 m .82793 .31891 L .82711 .31361 L p F P
0 g
s
0 0 .32 r
.82641 .32938 m .82662 .32884 L .82635 .32365 L p F P
0 g
s
.183 .286 .736 r
.63739 .267 m .63498 .26481 L .63546 .26182 L closepath p F P
0 g
s
.169 .272 .728 r
.63421 .25838 m .63166 .25583 L p .63498 .26481 L F P
0 g
s
.169 .272 .728 r
.63498 .26481 m .63546 .26182 L .63421 .25838 L p F P
0 g
s
.441 .579 .896 r
.72661 .15526 m .72615 .15519 L .72322 .15028 L p F P
0 g
s
0 0 .533 r
.61357 .20124 m .61398 .20591 L .61641 .21042 L p F P
0 g
s
0 0 .491 r
.61398 .20591 m .61357 .20124 L .61146 .19665 L p F P
0 g
s
.574 .665 .9 r
.73982 .39074 m .73978 .39074 L .7398 .3907 L closepath p F P
0 g
s
.579 .647 .881 r
.73692 .38623 m .7398 .3907 L .73978 .39074 L p F P
0 g
s
.527 .651 .913 r
.68252 .13019 m .68633 .13004 L .68337 .12552 L p F P
0 g
s
.527 .651 .913 r
.68337 .12552 m .68157 .12561 L .68252 .13019 L p F P
0 g
s
.599 .712 .924 r
.73982 .39074 m .75228 .38845 L .75513 .39232 L p F P
0 g
s
.59 .673 .897 r
.74942 .38438 m .75228 .38845 L .73982 .39074 L p F P
0 g
s
.59 .673 .897 r
.7436 .38523 m .74942 .38438 L p .73982 .39074 L F P
0 g
s
.59 .673 .897 r
.73982 .39074 m .7398 .3907 L .7436 .38523 L p F P
0 g
s
.589 .671 .896 r
.7398 .3907 m .73692 .38623 L .7436 .38523 L closepath p F P
0 g
s
.863 .651 .117 r
.60247 .15389 m .60276 .15535 L .60294 .1606 L p F P
0 g
s
.92 .681 .188 r
.60383 .16357 m .60294 .1606 L .60276 .15535 L p F P
0 g
s
.53 .607 .875 r
.72149 .38226 m .72074 .38226 L .7211 .38158 L closepath p F P
0 g
s
.537 .593 .858 r
.71852 .37701 m .7211 .38158 L .72074 .38226 L p F P
0 g
s
0 0 0 r
.82573 .33516 m .82364 .3402 L .82211 .34626 L p F P
0 g
s
0 0 .174 r
.82364 .3402 m .82573 .33516 L .82641 .32938 L p F P
0 g
s
.449 .498 .818 r
.68472 .34466 m .67824 .34305 L .67653 .33923 L p F P
0 g
s
.445 .578 .893 r
.72597 .15064 m .72661 .15526 L .73732 .15694 L p F P
0 g
s
.441 .579 .896 r
.72322 .15028 m .72597 .15064 L .72661 .15526 L p F P
0 g
s
.433 .566 .888 r
.72661 .15526 m .73732 .15694 L .73768 .16164 L p F P
0 g
s
.841 .577 .033 r
.60294 .1606 m .60383 .16357 L .60449 .1686 L p F P
0 g
s
.762 .959 .934 r
.78531 .3887 m .79745 .38076 L .79764 .38084 L p F P
0 g
s
.781 .884 .92 r
.78285 .38667 m .78531 .3887 L .79745 .38076 L p F P
0 g
s
.139 .254 .722 r
.63421 .25838 m .63166 .25583 L .63206 .25253 L closepath p F P
0 g
s
.122 .237 .711 r
.63102 .24965 m .62845 .24681 L p .63166 .25583 L F P
0 g
s
.122 .237 .711 r
.63166 .25583 m .63206 .25253 L .63102 .24965 L p F P
0 g
s
.549 .644 .896 r
.72149 .38226 m .734 .38155 L .73692 .38623 L p F P
0 g
s
.544 .614 .873 r
.73107 .37671 m .734 .38155 L .72149 .38226 L p F P
0 g
s
.544 .614 .873 r
.72407 .37687 m .73107 .37671 L p .72149 .38226 L F P
0 g
s
.544 .614 .873 r
.72149 .38226 m .7211 .38158 L .72407 .37687 L p F P
0 g
s
.306 .372 .766 r
.64743 .2863 m .64373 .28392 L .64248 .28064 L p F P
0 g
s
.567 .69 .924 r
.65906 .11829 m .65267 .11917 L .64968 .11501 L p F P
0 g
s
.996 .85 .573 r
.60216 .13365 m .60374 .13805 L .60197 .1439 L p F P
0 g
s
.958 .867 .706 r
.60374 .13805 m .60216 .13365 L .60536 .12732 L p F P
0 g
s
.389 .519 .867 r
.75756 .17996 m .76345 .18156 L .76053 .17605 L p F P
0 g
s
.389 .519 .867 r
.76053 .17605 m .75749 .17523 L .75756 .17996 L p F P
0 g
s
0 0 .461 r
.61081 .19204 m .61146 .19665 L .61357 .20124 L p F P
0 g
s
0 0 .399 r
.61146 .19665 m .61081 .19204 L .60902 .18735 L p F P
0 g
s
.543 .612 .872 r
.7211 .38158 m .71852 .37701 L .72407 .37687 L closepath p F P
0 g
s
.477 .544 .846 r
.69997 .36491 m .69873 .36472 L .69931 .36357 L closepath p F P
0 g
s
.488 .533 .829 r
.69694 .3588 m .69931 .36357 L .69873 .36472 L p F P
0 g
s
.306 .372 .766 r
.64248 .28064 m .64342 .27754 L p .64743 .2863 L F P
0 g
s
.281 .351 .758 r
.64248 .28064 m .64056 .27551 L .64342 .27754 L closepath p F P
0 g
s
.071 .126 .614 r
.82563 .28405 m .82421 .28899 L .82677 .29371 L p F P
0 g
s
.12 .181 .653 r
.82421 .28899 m .82563 .28405 L .82254 .27951 L p F P
0 g
s
.885 .99 .743 r
.81311 .36458 m .81543 .35952 L p .80828 .36973 L F P
0 g
s
.885 .99 .743 r
.80828 .36973 m .80936 .36954 L .81311 .36458 L p F P
0 g
s
.78 .924 .551 r
.81855 .35462 m .81909 .35387 L p .81311 .36458 L F P
0 g
s
.78 .924 .551 r
.81311 .36458 m .81543 .35952 L .81855 .35462 L p F P
0 g
s
.089 .218 .704 r
.63102 .24965 m .62845 .24681 L .62872 .24332 L closepath p F P
0 g
s
.068 .197 .691 r
.62783 .24081 m .62533 .23776 L p .62845 .24681 L F P
0 g
s
.068 .197 .691 r
.62845 .24681 m .62872 .24332 L .62783 .24081 L p F P
0 g
s
.449 .498 .818 r
.67653 .33923 m .67773 .33684 L p .68472 .34466 L F P
0 g
s
.434 .487 .815 r
.67653 .33923 m .67515 .3361 L .67773 .33684 L closepath p F P
0 g
s
.643 .777 .945 r
.75513 .39232 m .76754 .38867 L .77031 .39184 L p F P
0 g
s
.627 .754 .938 r
.76754 .38867 m .75513 .39232 L .75228 .38845 L p F P
0 g
s
.279 .351 .759 r
.64342 .27754 m .64056 .27551 L .63894 .27119 L p F P
0 g
s
.863 .651 .117 r
.60294 .1606 m .60264 .15908 L .60247 .15389 L p F P
0 g
s
.903 .675 .167 r
.60131 .14936 m .60247 .15389 L .60264 .15908 L p F P
0 g
s
.976 .791 .372 r
.60247 .15389 m .60131 .14936 L .60197 .1439 L p F P
0 g
s
0 0 .405 r
.82871 .30866 m .82711 .31361 L .82793 .31891 L p F P
0 g
s
0 0 .493 r
.82711 .31361 m .82871 .30866 L .82726 .30357 L p F P
0 g
s
.515 .569 .849 r
.69997 .36491 m .71233 .36609 L .70989 .37125 L p F P
0 g
s
.501 .557 .845 r
.71233 .36609 m .69997 .36491 L .69931 .36357 L p F P
0 g
s
.698 .856 .958 r
.77031 .39184 m .78263 .38648 L .78285 .38667 L p F P
0 g
s
.68 .83 .955 r
.78263 .38648 m .77031 .39184 L .76754 .38867 L p F P
0 g
s
.861 .978 .857 r
.80705 .37204 m .79782 .38047 L .79764 .38084 L p F P
0 g
s
.819 .963 .901 r
.79745 .38076 m .79782 .38047 L .79764 .38084 L closepath p F P
0 g
s
0 0 .367 r
.60814 .1828 m .60902 .18735 L .61081 .19204 L p F P
0 g
s
0 0 .278 r
.60902 .18735 m .60814 .1828 L .60669 .178 L p F P
0 g
s
.031 .176 .682 r
.62783 .24081 m .62533 .23776 L .62545 .23419 L closepath p F P
0 g
s
.005 .15 .665 r
.62463 .23185 m .62229 .22867 L p .62533 .23776 L F P
0 g
s
.005 .15 .665 r
.62533 .23776 m .62545 .23419 L .62463 .23185 L p F P
0 g
s
.408 .545 .882 r
.748 .16829 m .74473 .16758 L .74181 .16238 L p F P
0 g
s
.306 .426 .819 r
.79464 .21816 m .79121 .21642 L .7885 .21047 L p F P
0 g
s
.823 .998 .777 r
.80705 .37204 m .80828 .36973 L .80936 .36954 L closepath p F P
0 g
s
.363 .489 .853 r
.76638 .18714 m .76638 .18712 L p .77425 .19461 L F P
0 g
s
.378 .506 .861 r
.76638 .18714 m .76637 .18712 L .76638 .18712 L closepath p F P
0 g
s
.374 .507 .864 r
.76638 .18712 m .76637 .18712 L .76345 .18156 L p F P
0 g
s
.363 .489 .853 r
.76638 .18712 m .77432 .18986 L .77425 .19461 L p F P
0 g
s
.361 .492 .856 r
.76626 .18242 m .76638 .18712 L .77432 .18986 L p F P
0 g
s
.374 .507 .864 r
.76345 .18156 m .76626 .18242 L .76638 .18712 L p F P
0 g
s
.279 .351 .759 r
.63894 .27119 m .63959 .26871 L p .64342 .27754 L F P
0 g
s
.251 .329 .749 r
.63894 .27119 m .63739 .267 L .63959 .26871 L closepath p F P
0 g
s
.435 .486 .813 r
.67773 .33684 m .67515 .3361 L .67205 .32905 L p F P
0 g
s
.495 .63 .912 r
.68633 .13004 m .69789 .13016 L .69876 .13476 L p F P
0 g
s
.497 .633 .914 r
.69789 .13016 m .68633 .13004 L .68337 .12552 L p F P
0 g
s
.807 .943 .915 r
.79782 .38047 m .79745 .38076 L .79485 .37933 L p F P
0 g
s
.781 .884 .92 r
.79745 .38076 m .79485 .37933 L p .78285 .38667 L F P
0 g
s
.807 .943 .915 r
.79485 .37933 m .80002 .37547 L .79782 .38047 L p F P
0 g
s
.829 .969 .891 r
.80828 .36973 m .80705 .37204 L .79782 .38047 L p F P
0 g
s
.829 .969 .891 r
.80691 .36963 m .80828 .36973 L p .79782 .38047 L F P
0 g
s
.829 .969 .891 r
.79782 .38047 m .80002 .37547 L .80691 .36963 L p F P
0 g
s
.112 .178 .653 r
.82366 .27532 m .82254 .27951 L .82563 .28405 L p F P
0 g
s
.163 .234 .69 r
.82317 .27376 m .82026 .27021 L p .82254 .27951 L F P
0 g
s
.163 .234 .69 r
.82254 .27951 m .82366 .27532 L .82317 .27376 L p F P
0 g
s
.501 .557 .845 r
.69931 .36357 m .70166 .35939 L p .71233 .36609 L F P
0 g
s
.489 .549 .844 r
.69931 .36357 m .69694 .3588 L .70166 .35939 L closepath p F P
0 g
s
.466 .603 .904 r
.70474 .13955 m .7127 .14015 L .71346 .14476 L p F P
0 g
s
.466 .606 .906 r
.7127 .14015 m .70474 .13955 L .7018 .13485 L p F P
0 g
s
.426 .559 .885 r
.73768 .16164 m .74181 .16238 L .73888 .15722 L p F P
0 g
s
.426 .559 .885 r
.73888 .15722 m .73732 .15694 L .73768 .16164 L p F P
0 g
s
.462 .598 .902 r
.71346 .14476 m .7203 .1454 L .71736 .14057 L p F P
0 g
s
.462 .598 .902 r
.71736 .14057 m .7127 .14015 L .71346 .14476 L p F P
0 g
s
.832 .825 .842 r
.61336 .11932 m .6073 .12461 L .60427 .12169 L p F P
0 g
s
.899 .837 .776 r
.60536 .12732 m .6073 .12461 L .60427 .12169 L p F P
0 g
s
.248 .329 .751 r
.63959 .26871 m .63739 .267 L .63546 .26182 L p F P
0 g
s
.832 .825 .842 r
.60427 .12169 m .61148 .11499 L .61336 .11932 L p F P
0 g
s
.773 .793 .869 r
.61625 .11152 m .61148 .11499 L .61336 .11932 L p F P
0 g
s
.773 .793 .869 r
.61336 .11932 m .61928 .11521 L .61625 .11152 L p F P
0 g
s
0 .127 .654 r
.62463 .23185 m .62229 .22867 L .62225 .22515 L closepath p F P
0 g
s
0 .095 .632 r
.62142 .22275 m .61931 .21956 L p .62229 .22867 L F P
0 g
s
0 .095 .632 r
.62229 .22867 m .62225 .22515 L .62142 .22275 L p F P
0 g
s
.528 .659 .919 r
.66798 .12183 m .68041 .12104 L p .68157 .12561 L F P
0 g
s
.534 .662 .918 r
.68041 .12104 m .66798 .12183 L .66501 .11749 L p F P
0 g
s
.715 .453 0 r
.60523 .17193 m .60449 .1686 L p .60669 .178 L F P
0 g
s
0 0 0 r
.81909 .35387 m .81959 .35263 L .82211 .34626 L p F P
0 g
s
.687 .778 .298 r
.82414 .34125 m .82211 .34626 L .81959 .35263 L p F P
0 g
s
0 0 0 r
.82414 .34125 m .82573 .33516 L p .82215 .34613 L F P
0 g
s
0 0 0 r
.82643 .33344 m .82573 .33516 L .82414 .34125 L p F P
0 g
s
0 0 0 r
.82414 .34125 m .82571 .33737 L .82643 .33344 L p F P
0 g
s
.699 .796 .326 r
.82414 .34125 m .82149 .34767 L p .82567 .33746 L F P
0 g
s
.699 .796 .326 r
.82571 .33737 m .82414 .34125 L p .82567 .33746 L F P
0 g
s
0 0 0 r
.82211 .34626 m .82414 .34125 L p .82215 .34613 L F P
0 g
s
0 0 .167 r
.82662 .32884 m .82641 .32938 L .82573 .33516 L p F P
0 g
s
.899 .837 .776 r
.60427 .12169 m .60336 .12304 L .60536 .12732 L p F P
0 g
s
.956 .852 .698 r
.60336 .12304 m .60536 .12732 L .60216 .13365 L p F P
0 g
s
.355 .476 .844 r
.78164 .20225 m .78191 .19746 L .77425 .19461 L p F P
0 g
s
.359 .485 .85 r
.77432 .18986 m .77425 .19461 L .78191 .19746 L p F P
0 g
s
.492 .566 .859 r
.70989 .37125 m .71554 .37162 L .71255 .36611 L p F P
0 g
s
.492 .566 .859 r
.71255 .36611 m .71233 .36609 L .70989 .37125 L p F P
0 g
s
.248 .329 .751 r
.63546 .26182 m .63591 .25983 L p .63959 .26871 L F P
0 g
s
.218 .304 .739 r
.63546 .26182 m .63421 .25838 L .63591 .25983 L closepath p F P
0 g
s
.621 .716 .915 r
.63444 .11397 m .64668 .11087 L .64968 .11501 L p F P
0 g
s
.626 .721 .915 r
.64668 .11087 m .63444 .11397 L .63142 .11001 L p F P
0 g
s
.691 .754 .9 r
.61928 .11521 m .63142 .11001 L .63444 .11397 L p F P
0 g
s
.146 .223 .687 r
.82317 .27376 m .82026 .27021 L .82104 .267 L closepath p F P
0 g
s
.192 .272 .718 r
.81994 .26375 m .81739 .26109 L p .82026 .27021 L F P
0 g
s
.192 .272 .718 r
.82026 .27021 m .82104 .267 L .81994 .26375 L p F P
0 g
s
.44 .582 .898 r
.72597 .15064 m .72322 .15028 L .7203 .1454 L p F P
0 g
s
.989 .789 .401 r
.60047 .13947 m .60197 .1439 L .60131 .14936 L p F P
0 g
s
.996 .85 .573 r
.60197 .1439 m .60047 .13947 L .60216 .13365 L p F P
0 g
s
0 .07 .619 r
.62142 .22275 m .61931 .21956 L .61912 .21619 L closepath p F P
0 g
s
0 .031 .589 r
.61821 .21348 m .61641 .21042 L p .61931 .21956 L F P
0 g
s
0 .031 .589 r
.61931 .21956 m .61912 .21619 L .61821 .21348 L p F P
0 g
s
.363 .435 .801 r
.66582 .31455 m .66087 .31212 L p .66596 .32053 L F P
0 g
s
.333 .409 .79 r
.66087 .31212 m .66582 .31455 L .66269 .30718 L p F P
0 g
s
.333 .409 .79 r
.66269 .30718 m .66245 .30705 L .66087 .31212 L p F P
0 g
s
.33 .405 .788 r
.66087 .31212 m .66245 .30705 L .65611 .3036 L p F P
0 g
s
.384 .451 .806 r
.66894 .32184 m .66596 .32053 L p .67144 .32881 L F P
0 g
s
.368 .44 .804 r
.66894 .32184 m .66596 .32053 L .66704 .31742 L closepath p F P
0 g
s
.363 .435 .801 r
.66596 .32053 m .66704 .31742 L .66582 .31455 L p F P
0 g
s
.744 .508 0 r
.60264 .15908 m .60294 .1606 L .60402 .16699 L p F P
0 g
s
.841 .577 .033 r
.60449 .1686 m .60402 .16699 L .60294 .1606 L p F P
0 g
s
.698 .758 .898 r
.63142 .11001 m .61928 .11521 L .61625 .11152 L p F P
0 g
s
.59 .664 .889 r
.7436 .38523 m .73692 .38623 L .734 .38155 L p F P
0 g
s
.544 .608 .867 r
.72407 .37687 m .71852 .37701 L .71554 .37162 L p F P
0 g
s
.32 .403 .791 r
.65762 .29853 m .65611 .3036 L .66245 .30705 L p F P
0 g
s
.353 .407 .778 r
.65165 .29499 m .65762 .29853 L .65611 .3036 L p F P
0 g
s
0 0 .288 r
.82662 .32884 m .82808 .32444 L .82793 .31891 L p F P
0 g
s
0 0 .131 r
.82808 .32444 m .82662 .32884 L .82643 .33344 L p F P
0 g
s
0 0 .167 r
.82573 .33516 m .82643 .33344 L .82662 .32884 L p F P
0 g
s
.213 .304 .741 r
.63591 .25983 m .63421 .25838 L .63206 .25253 L p F P
0 g
s
.015 .057 .561 r
.82726 .30357 m .82882 .29861 L .82677 .29371 L p F P
0 g
s
0 0 .496 r
.82882 .29861 m .82726 .30357 L .82871 .30866 L p F P
0 g
s
.384 .451 .806 r
.67144 .32881 m .67168 .3282 L .66894 .32184 L p F P
0 g
s
.388 .455 .809 r
.67205 .32905 m .67144 .32881 L .67168 .3282 L closepath p F P
0 g
s
.571 .688 .92 r
.65906 .11829 m .66501 .11749 L .66202 .1132 L p F P
0 g
s
.571 .688 .92 r
.66202 .1132 m .65761 .11383 L .65906 .11829 L p F P
0 g
s
.567 .69 .924 r
.64968 .11501 m .65761 .11383 L .65906 .11829 L p F P
0 g
s
.294 .384 .785 r
.65306 .28993 m .65165 .29499 L .65762 .29853 L p F P
0 g
s
.331 .39 .772 r
.64743 .2863 m .65306 .28993 L .65165 .29499 L p F P
0 g
s
.763 .875 .452 r
.81855 .35462 m .81959 .35263 L .81909 .35387 L closepath p F P
0 g
s
.758 .478 0 r
.60523 .17193 m .60449 .1686 L .60402 .16699 L closepath p F P
0 g
s
.334 .457 .836 r
.78164 .20225 m .78531 .20379 L .78236 .19765 L p F P
0 g
s
.334 .457 .836 r
.78236 .19765 m .78191 .19746 L .78164 .20225 L p F P
0 g
s
.176 .262 .715 r
.81994 .26375 m .81739 .26109 L .81803 .25815 L closepath p F P
0 g
s
.219 .307 .742 r
.81679 .25473 m .81394 .25216 L p .81739 .26109 L F P
0 g
s
.219 .307 .742 r
.81739 .26109 m .81803 .25815 L .81679 .25473 L p F P
0 g
s
.449 .498 .818 r
.67773 .33684 m .68685 .33951 L .68472 .34466 L p F P
0 g
s
.414 .489 .828 r
.68001 .33163 m .67773 .33684 L .68685 .33951 L p F P
0 g
s
.435 .486 .813 r
.67205 .32905 m .68001 .33163 L .67773 .33684 L p F P
0 g
s
.42 .474 .81 r
.68001 .33163 m .67205 .32905 L .67168 .3282 L p F P
0 g
s
.264 .362 .777 r
.64871 .28126 m .64743 .2863 L .65306 .28993 L p F P
0 g
s
.306 .372 .766 r
.64342 .27754 m .64871 .28126 L .64743 .2863 L p F P
0 g
s
.494 .625 .909 r
.69876 .13476 m .7018 .13485 L .69885 .13018 L p F P
0 g
s
.494 .625 .909 r
.69885 .13018 m .69789 .13016 L .69876 .13476 L p F P
0 g
s
.306 .426 .819 r
.7885 .21047 m .78852 .21008 L p .79464 .21816 L F P
0 g
s
.325 .447 .831 r
.7885 .21047 m .78825 .20996 L .78852 .21008 L closepath p F P
0 g
s
.213 .304 .741 r
.63206 .25253 m .63236 .25091 L p .63591 .25983 L F P
0 g
s
.181 .276 .727 r
.63206 .25253 m .63102 .24965 L .63236 .25091 L closepath p F P
0 g
s
0 .003 .572 r
.61821 .21348 m .61641 .21042 L .6161 .20736 L closepath p F P
0 g
s
0 0 .533 r
.61499 .20399 m .61357 .20124 L p .61641 .21042 L F P
0 g
s
0 0 .533 r
.61641 .21042 m .6161 .20736 L .61499 .20399 L p F P
0 g
s
.49 .546 .841 r
.70166 .35939 m .69694 .3588 L .69389 .35259 L p F P
0 g
s
.402 .533 .874 r
.75749 .17523 m .75733 .1705 L .748 .16829 L p F P
0 g
s
.409 .543 .879 r
.74761 .16362 m .748 .16829 L .75733 .1705 L p F P
0 g
s
.408 .545 .882 r
.74181 .16238 m .74761 .16362 L .748 .16829 L p F P
0 g
s
.42 .474 .81 r
.67168 .3282 m .6737 .32357 L p .68001 .33163 L F P
0 g
s
.403 .462 .807 r
.67168 .3282 m .66894 .32184 L .6737 .32357 L closepath p F P
0 g
s
.321 .448 .833 r
.78852 .21008 m .78825 .20996 L .78531 .20379 L p F P
0 g
s
.174 .275 .728 r
.63236 .25091 m .63102 .24965 L .62872 .24332 L p F P
0 g
s
.279 .351 .759 r
.63959 .26871 m .64456 .27252 L .64342 .27754 L p F P
0 g
s
.222 .328 .761 r
.64456 .27252 m .64342 .27754 L .64871 .28126 L p F P
0 g
s
.571 .694 .925 r
.65761 .11383 m .64968 .11501 L .64668 .11087 L p F P
0 g
s
.306 .426 .819 r
.78852 .21008 m .79499 .21338 L .79464 .21816 L p F P
0 g
s
.301 .427 .823 r
.78871 .20533 m .78852 .21008 L .79499 .21338 L p F P
0 g
s
.321 .448 .833 r
.78531 .20379 m .78871 .20533 L .78852 .21008 L p F P
0 g
s
.204 .298 .739 r
.81679 .25473 m .81394 .25216 L .8146 .24872 L closepath p F P
0 g
s
.244 .34 .763 r
.81369 .24637 m .80992 .2434 L p .81394 .25216 L F P
0 g
s
.244 .34 .763 r
.81394 .25216 m .8146 .24872 L .81369 .24637 L p F P
0 g
s
.446 .515 .836 r
.69084 .34623 m .68472 .34466 L p .69241 .35226 L F P
0 g
s
.422 .49 .825 r
.68472 .34466 m .69084 .34623 L .68777 .33978 L p F P
0 g
s
.422 .49 .825 r
.68777 .33978 m .68685 .33951 L .68472 .34466 L p F P
0 g
s
.743 .867 .938 r
.78263 .38648 m .78302 .38626 L .78285 .38667 L closepath p F P
0 g
s
.781 .884 .92 r
.79485 .37933 m .78302 .38626 L .78285 .38667 L p F P
0 g
s
.527 .652 .914 r
.68337 .12552 m .68157 .12561 L .68061 .12135 L closepath p F P
0 g
s
.528 .659 .919 r
.68041 .12104 m .68061 .12135 L .68157 .12561 L p F P
0 g
s
.193 .305 .751 r
.64057 .26372 m .63959 .26871 L .64456 .27252 L p F P
0 g
s
.248 .329 .751 r
.63591 .25983 m .64057 .26372 L .63959 .26871 L p F P
0 g
s
.856 .995 .825 r
.80691 .36963 m .80944 .36697 L .80828 .36973 L closepath p F P
0 g
s
.885 .99 .743 r
.81543 .35952 m .80944 .36697 L .80828 .36973 L p F P
0 g
s
.289 .409 .811 r
.79499 .21338 m .79464 .21816 L .80076 .22159 L p F P
0 g
s
.289 .405 .807 r
.80026 .2264 m .80076 .22159 L .79464 .21816 L p F P
0 g
s
.229 .331 .761 r
.81369 .24637 m .80992 .2434 L .81071 .23866 L closepath p F P
0 g
s
.267 .369 .782 r
.81063 .23846 m .80536 .23481 L p .80992 .2434 L F P
0 g
s
.267 .369 .782 r
.80992 .2434 m .81071 .23866 L .81063 .23846 L p F P
0 g
s
0 0 .512 r
.61499 .20399 m .61357 .20124 L .61319 .19867 L closepath p F P
0 g
s
0 0 .461 r
.61176 .19417 m .61081 .19204 L p .61357 .20124 L F P
0 g
s
0 0 .461 r
.61357 .20124 m .61319 .19867 L .61176 .19417 L p F P
0 g
s
.174 .275 .728 r
.62872 .24332 m .62892 .24194 L p .63236 .25091 L F P
0 g
s
.138 .244 .712 r
.62872 .24332 m .62783 .24081 L .62892 .24194 L closepath p F P
0 g
s
.371 .508 .865 r
.76626 .18242 m .76345 .18156 L .76053 .17605 L p F P
0 g
s
0 0 .217 r
.60468 .16893 m .60564 .17349 L p .60461 .16913 L F P
0 g
s
0 0 .217 r
.60342 .16408 m .60468 .16893 L p .60461 .16913 L F P
0 g
s
0 0 .235 r
.60468 .16893 m .60629 .17367 L p .60474 .16872 L F P
0 g
s
.723 .444 0 r
.60342 .16408 m .60468 .16893 L p .60314 .16311 L F P
0 g
s
.744 .508 0 r
.60402 .16699 m .60342 .16408 L p .60363 .16478 L F P
0 g
s
0 0 .217 r
.60402 .16699 m .60342 .16408 L p .60564 .17349 L F P
0 g
s
0 0 .235 r
.6034 .16445 m .60468 .16893 L p .60474 .16872 L F P
0 g
s
.723 .444 0 r
.6022 .15958 m .60342 .16408 L p .60314 .16311 L F P
0 g
s
.744 .508 0 r
.60342 .16408 m .60264 .15908 L p .60363 .16478 L F P
0 g
s
.81 .551 0 r
.60146 .15457 m .60264 .15908 L .60342 .16408 L p F P
0 g
s
.903 .675 .167 r
.60264 .15908 m .60146 .15457 L .60131 .14936 L p F P
0 g
s
.445 .578 .893 r
.73596 .15215 m .72597 .15064 L p .73732 .15694 L F P
0 g
s
.433 .575 .896 r
.72597 .15064 m .73596 .15215 L .73303 .14719 L p F P
0 g
s
.433 .575 .896 r
.73303 .14719 m .72523 .14605 L .72597 .15064 L p F P
0 g
s
.44 .582 .898 r
.7203 .1454 m .72523 .14605 L .72597 .15064 L p F P
0 g
s
.275 .384 .793 r
.80536 .23481 m .80602 .22997 L .80026 .2264 L p F P
0 g
s
.279 .393 .8 r
.80076 .22159 m .80026 .2264 L .80602 .22997 L p F P
0 g
s
.247 .356 .778 r
.80536 .23481 m .81063 .23846 L .8076 .23109 L p F P
0 g
s
.247 .356 .778 r
.8076 .23109 m .80602 .22997 L .80536 .23481 L p F P
0 g
s
.405 .546 .884 r
.74761 .16362 m .74181 .16238 L .73888 .15722 L p F P
0 g
s
.005 .052 .56 r
.82774 .2904 m .82677 .29371 L .82882 .29861 L p F P
0 g
s
.071 .126 .614 r
.82656 .28575 m .82563 .28405 L p .82677 .29371 L F P
0 g
s
.071 .126 .614 r
.82677 .29371 m .82774 .2904 L .82656 .28575 L p F P
0 g
s
.727 .845 .937 r
.78302 .38626 m .78263 .38648 L .77991 .38386 L p F P
0 g
s
.68 .83 .955 r
.76754 .38867 m .77991 .38386 L .78263 .38648 L p F P
0 g
s
.851 .926 .539 r
.81959 .35263 m .82149 .34767 L p .81703 .3561 L F P
0 g
s
.851 .926 .539 r
.81703 .3561 m .81855 .35462 L .81959 .35263 L p F P
0 g
s
.687 .778 .298 r
.81959 .35263 m .82149 .34767 L .82414 .34125 L p F P
0 g
s
.128 .242 .713 r
.62892 .24194 m .62783 .24081 L .62545 .23419 L p F P
0 g
s
.994 .835 .576 r
.60032 .12932 m .60216 .13365 L .60047 .13947 L p F P
0 g
s
.956 .852 .698 r
.60216 .13365 m .60032 .12932 L .60336 .12304 L p F P
0 g
s
0 0 .283 r
.82954 .31397 m .82793 .31891 L .82808 .32444 L p F P
0 g
s
0 0 .405 r
.82793 .31891 m .82954 .31397 L .82871 .30866 L p F P
0 g
s
.727 .845 .937 r
.77991 .38386 m .78497 .38134 L .78302 .38626 L p F P
0 g
s
.755 .908 .944 r
.79222 .37748 m .78497 .38134 L .78302 .38626 L p F P
0 g
s
.755 .908 .944 r
.78302 .38626 m .79485 .37933 L .79222 .37748 L p F P
0 g
s
.627 .754 .938 r
.75228 .38845 m .76474 .38526 L .76754 .38867 L p F P
0 g
s
.613 .734 .932 r
.76474 .38526 m .75228 .38845 L .74942 .38438 L p F P
0 g
s
.16 .28 .739 r
.63672 .25488 m .63591 .25983 L .64057 .26372 L p F P
0 g
s
.213 .304 .741 r
.63236 .25091 m .63672 .25488 L .63591 .25983 L p F P
0 g
s
0 0 .217 r
.60564 .17349 m .60523 .17193 L .60402 .16699 L p F P
0 g
s
.449 .519 .838 r
.69389 .35259 m .69241 .35226 L .69304 .35082 L closepath p F P
0 g
s
.446 .515 .836 r
.69241 .35226 m .69304 .35082 L .69084 .34623 L p F P
0 g
s
.128 .242 .713 r
.62545 .23419 m .62558 .23294 L p .62892 .24194 L F P
0 g
s
.088 .207 .694 r
.62545 .23419 m .62463 .23185 L .62558 .23294 L closepath p F P
0 g
s
.387 .52 .869 r
.75749 .17523 m .76053 .17605 L .7576 .17057 L p F P
0 g
s
.387 .52 .869 r
.7576 .17057 m .75733 .1705 L .75749 .17523 L p F P
0 g
s
.772 .919 .543 r
.81543 .35952 m .81703 .3561 L .81855 .35462 L closepath p F P
0 g
s
.497 .633 .914 r
.68337 .12552 m .6959 .1256 L p .69789 .13016 L F P
0 g
s
.484 .63 .917 r
.69294 .12109 m .6959 .1256 L .68337 .12552 L p F P
0 g
s
.484 .63 .917 r
.68051 .12104 m .69294 .12109 L p .68337 .12552 L F P
0 g
s
.484 .63 .917 r
.68337 .12552 m .68061 .12135 L .68051 .12104 L p F P
0 g
s
0 0 .434 r
.61176 .19417 m .61081 .19204 L .61045 .19019 L closepath p F P
0 g
s
0 0 .367 r
.60852 .18381 m .60814 .1828 L p .61081 .19204 L F P
0 g
s
0 0 .367 r
.61081 .19204 m .61045 .19019 L .60852 .18381 L p F P
0 g
s
.404 .462 .806 r
.6737 .32357 m .66894 .32184 L .66704 .31742 L p F P
0 g
s
.466 .606 .906 r
.7018 .13485 m .71185 .13556 L .7127 .14015 L p F P
0 g
s
.467 .609 .909 r
.71185 .13556 m .7018 .13485 L .69885 .13018 L p F P
0 g
s
.123 .252 .726 r
.63299 .24599 m .63236 .25091 L .63672 .25488 L p F P
0 g
s
.174 .275 .728 r
.62892 .24194 m .63299 .24599 L .63236 .25091 L p F P
0 g
s
.075 .203 .694 r
.62558 .23294 m .62463 .23185 L .62225 .22515 L p F P
0 g
s
.663 .805 .951 r
.77991 .38386 m .76754 .38867 L .76474 .38526 L p F P
0 g
s
.524 .605 .876 r
.72407 .37687 m .73107 .37671 L .72812 .37174 L p F P
0 g
s
.524 .605 .876 r
.72812 .37174 m .72652 .37172 L .72407 .37687 L p F P
0 g
s
.544 .608 .867 r
.71554 .37162 m .72652 .37172 L .72407 .37687 L p F P
0 g
s
.938 .692 .218 r
.59984 .14493 m .60131 .14936 L .60146 .15457 L p F P
0 g
s
.989 .789 .401 r
.60131 .14936 m .59984 .14493 L .60047 .13947 L p F P
0 g
s
.53 .596 .864 r
.72652 .37172 m .71554 .37162 L .71255 .36611 L p F P
0 g
s
0 0 .256 r
.60575 .17421 m .60523 .17193 L .60564 .17349 L closepath p F P
0 g
s
.075 .203 .694 r
.62225 .22515 m .62232 .2239 L p .62558 .23294 L F P
0 g
s
.031 .164 .67 r
.62225 .22515 m .62142 .22275 L .62232 .2239 L closepath p F P
0 g
s
.571 .666 .903 r
.7436 .38523 m .74942 .38438 L .74654 .38013 L p F P
0 g
s
.571 .666 .903 r
.74654 .38013 m .74574 .38022 L .7436 .38523 L p F P
0 g
s
.59 .664 .889 r
.734 .38155 m .74574 .38022 L .7436 .38523 L p F P
0 g
s
.079 .22 .71 r
.62936 .23706 m .62892 .24194 L .63299 .24599 L p F P
0 g
s
.128 .242 .713 r
.62558 .23294 m .62936 .23706 L .62892 .24194 L p F P
0 g
s
.052 .113 .608 r
.82656 .28575 m .82563 .28405 L .82589 .28311 L closepath p F P
0 g
s
.112 .178 .653 r
.82563 .28405 m .82589 .28311 L .82366 .27532 L p F P
0 g
s
.013 .157 .67 r
.62232 .2239 m .62142 .22275 L .61912 .21619 L p F P
0 g
s
.49 .546 .841 r
.69389 .35259 m .70402 .35421 L .70166 .35939 L p F P
0 g
s
.476 .534 .838 r
.70402 .35421 m .69389 .35259 L .69304 .35082 L p F P
0 g
s
.534 .662 .918 r
.66501 .11749 m .67744 .11665 L .68041 .12104 L p F P
0 g
s
.535 .665 .92 r
.67744 .11665 m .66501 .11749 L .66202 .1132 L p F P
0 g
s
.439 .584 .9 r
.72523 .14605 m .7203 .1454 L .71736 .14057 L p F P
0 g
s
0 0 .336 r
.60852 .18381 m .60814 .1828 L .60794 .182 L closepath p F P
0 g
s
0 0 .246 r
.60814 .1828 m .60794 .182 L .60575 .17421 L p F P
0 g
s
.118 .204 .679 r
.82104 .267 m .82136 .26532 L p .82381 .27459 L F P
0 g
s
.118 .204 .679 r
.82381 .27459 m .82317 .27376 L .82104 .267 L p F P
0 g
s
.152 .245 .707 r
.82104 .267 m .81994 .26375 L .82136 .26532 L closepath p F P
0 g
s
.576 .65 .886 r
.74574 .38022 m .734 .38155 L .73107 .37671 L p F P
0 g
s
.316 .446 .834 r
.78871 .20533 m .78531 .20379 L .78236 .19765 L p F P
0 g
s
.12 .205 .679 r
.82366 .27532 m .82317 .27376 L .82381 .27459 L closepath p F P
0 g
s
0 0 .366 r
.60564 .17349 m .60575 .17421 L .60794 .182 L p F P
0 g
s
.062 .144 .638 r
.82381 .27459 m .82366 .27532 L .82589 .28311 L p F P
0 g
s
.404 .462 .806 r
.66704 .31742 m .66786 .31538 L p .6737 .32357 L F P
0 g
s
.385 .448 .803 r
.66704 .31742 m .66582 .31455 L .66786 .31538 L closepath p F P
0 g
s
.149 .244 .708 r
.82136 .26532 m .81994 .26375 L .81803 .25815 L p F P
0 g
s
.857 .996 .774 r
.81703 .3561 m .81543 .35952 L .80944 .36697 L p F P
0 g
s
.013 .157 .67 r
.61912 .21619 m .61915 .21483 L p .62232 .2239 L F P
0 g
s
0 .112 .64 r
.61912 .21619 m .61821 .21348 L .61915 .21483 L closepath p F P
0 g
s
.37 .504 .863 r
.76605 .17773 m .76626 .18242 L .77431 .18512 L p F P
0 g
s
.371 .508 .865 r
.76053 .17605 m .76605 .17773 L .76626 .18242 L p F P
0 g
s
.361 .492 .856 r
.77432 .18986 m .77431 .18512 L .76626 .18242 L p F P
0 g
s
.839 .821 .831 r
.61148 .11499 m .60427 .12169 L .60122 .1187 L p F P
0 g
s
.839 .821 .831 r
.60122 .1187 m .60935 .11072 L .61148 .11499 L p F P
0 g
s
.781 .795 .864 r
.6132 .10781 m .60935 .11072 L .61148 .11499 L p F P
0 g
s
.781 .795 .864 r
.61148 .11499 m .61625 .11152 L .6132 .10781 L p F P
0 g
s
0 .102 .637 r
.61915 .21483 m .61821 .21348 L .6161 .20736 L p F P
0 g
s
.501 .557 .845 r
.70166 .35939 m .70954 .36041 L p .71233 .36609 L F P
0 g
s
.468 .539 .847 r
.70166 .35939 m .70954 .36041 L .70652 .35463 L p F P
0 g
s
.468 .539 .847 r
.70652 .35463 m .70402 .35421 L .70166 .35939 L p F P
0 g
s
.029 .183 .69 r
.62583 .2281 m .62558 .23294 L .62936 .23706 L p F P
0 g
s
.075 .203 .694 r
.62232 .2239 m .62583 .2281 L .62558 .23294 L p F P
0 g
s
.905 .832 .764 r
.60336 .12304 m .60427 .12169 L .60122 .1187 L p F P
0 g
s
.462 .601 .904 r
.7127 .14015 m .71736 .14057 L .71442 .13578 L p F P
0 g
s
.462 .601 .904 r
.71442 .13578 m .71185 .13556 L .7127 .14015 L p F P
0 g
s
.149 .244 .708 r
.81803 .25815 m .81836 .25622 L p .82136 .26532 L F P
0 g
s
.181 .282 .733 r
.81803 .25815 m .81679 .25473 L .81836 .25622 L closepath p F P
0 g
s
.626 .721 .915 r
.63142 .11001 m .64367 .10675 L .64668 .11087 L p F P
0 g
s
.63 .724 .915 r
.64367 .10675 m .63142 .11001 L .62839 .10605 L p F P
0 g
s
.698 .758 .898 r
.61625 .11152 m .62839 .10605 L .63142 .11001 L p F P
0 g
s
.476 .534 .838 r
.69304 .35082 m .69493 .34701 L p .70402 .35421 L F P
0 g
s
.463 .525 .836 r
.69304 .35082 m .69084 .34623 L .69493 .34701 L closepath p F P
0 g
s
0 0 .406 r
.8303 .3037 m .82871 .30866 L .82954 .31397 L p F P
0 g
s
0 0 .496 r
.82871 .30866 m .8303 .3037 L .82882 .29861 L p F P
0 g
s
.424 .56 .887 r
.73888 .15722 m .73732 .15694 L .73703 .15398 L closepath p F P
0 g
s
.445 .578 .893 r
.73732 .15694 m .73703 .15398 L .73596 .15215 L p F P
0 g
s
0 .102 .637 r
.6161 .20736 m .61606 .20573 L p .61915 .21483 L F P
0 g
s
0 .049 .6 r
.6161 .20736 m .61499 .20399 L .61606 .20573 L closepath p F P
0 g
s
.954 .839 .691 r
.60116 .11881 m .60336 .12304 L .60032 .12932 L p F P
0 g
s
.905 .832 .764 r
.60122 .1187 m .60116 .11881 L .60336 .12304 L p F P
0 g
s
.79 .932 .926 r
.80002 .37547 m .79485 .37933 L .79222 .37748 L p F P
0 g
s
0 .035 .593 r
.61606 .20573 m .61499 .20399 L .61319 .19867 L p F P
0 g
s
0 0 .451 r
.60794 .182 m .60733 .1782 L p .61014 .18742 L F P
0 g
s
0 0 .451 r
.61014 .18742 m .60852 .18381 L .60794 .182 L p F P
0 g
s
0 0 .366 r
.60794 .182 m .60733 .1782 L .60564 .17349 L p F P
0 g
s
0 0 .472 r
.61045 .19019 m .60852 .18381 L .61014 .18742 L closepath p F P
0 g
s
.016 .089 .596 r
.82589 .28311 m .82674 .27918 L p .82813 .28879 L F P
0 g
s
.016 .089 .596 r
.82813 .28879 m .82656 .28575 L .82589 .28311 L p F P
0 g
s
.062 .144 .638 r
.82589 .28311 m .82674 .27918 L .82381 .27459 L p F P
0 g
s
.386 .448 .802 r
.66786 .31538 m .66582 .31455 L .66269 .30718 L p F P
0 g
s
.179 .281 .733 r
.81836 .25622 m .81679 .25473 L .8146 .24872 L p F P
0 g
s
0 0 .302 r
.60468 .16893 m .60564 .17349 L .60733 .1782 L p F P
0 g
s
.705 .761 .896 r
.62839 .10605 m .61625 .11152 L .6132 .10781 L p F P
0 g
s
.118 .204 .679 r
.82136 .26532 m .82476 .26975 L .82381 .27459 L p F P
0 g
s
.058 .145 .64 r
.82476 .26975 m .82381 .27459 L .82674 .27918 L p F P
0 g
s
0 0 .546 r
.61319 .19867 m .61176 .19417 L .61305 .1966 L closepath p F P
0 g
s
0 0 .533 r
.61305 .1966 m .61176 .19417 L .61045 .19019 L p F P
0 g
s
0 .035 .593 r
.61319 .19867 m .61305 .1966 L p .61606 .20573 L F P
0 g
s
0 0 .533 r
.61045 .19019 m .61014 .18742 L p .61305 .1966 L F P
0 g
s
0 .141 .666 r
.62237 .21911 m .62232 .2239 L .62583 .2281 L p F P
0 g
s
.013 .157 .67 r
.61915 .21483 m .62237 .21911 L .62232 .2239 L p F P
0 g
s
0 0 0 r
.82749 .33021 m .82643 .33344 L .82571 .33737 L p F P
0 g
s
0 0 .131 r
.82643 .33344 m .82749 .33021 L .82808 .32444 L p F P
0 g
s
.996 .782 .422 r
.5987 .13512 m .60047 .13947 L .59984 .14493 L p F P
0 g
s
.994 .835 .576 r
.60047 .13947 m .5987 .13512 L .60032 .12932 L p F P
0 g
s
.367 .508 .867 r
.76605 .17773 m .76053 .17605 L .7576 .17057 L p F P
0 g
s
.79 .932 .926 r
.79222 .37748 m .80255 .37035 L .80002 .37547 L p F P
0 g
s
.819 .983 .885 r
.80438 .36893 m .80255 .37035 L .80002 .37547 L p F P
0 g
s
.819 .983 .885 r
.80002 .37547 m .80691 .36963 L .80438 .36893 L p F P
0 g
s
.019 .09 .596 r
.82774 .2904 m .82656 .28575 L .82813 .28879 L closepath p F P
0 g
s
.849 .988 .854 r
.80944 .36697 m .80691 .36963 L .80438 .36893 L p F P
0 g
s
.849 .988 .854 r
.80438 .36893 m .81155 .36196 L .80944 .36697 L p F P
0 g
s
.857 .996 .774 r
.81625 .35646 m .81703 .3561 L p .80944 .36697 L F P
0 g
s
.857 .996 .774 r
.80944 .36697 m .81155 .36196 L .81625 .35646 L p F P
0 g
s
.359 .485 .85 r
.77943 .19176 m .77432 .18986 L p .78191 .19746 L F P
0 g
s
.345 .478 .85 r
.77432 .18986 m .77943 .19176 L .7765 .18593 L p F P
0 g
s
.345 .478 .85 r
.7765 .18593 m .77431 .18512 L .77432 .18986 L p F P
0 g
s
.575 .692 .921 r
.65761 .11383 m .66202 .1132 L .65903 .10893 L p F P
0 g
s
.575 .692 .921 r
.65903 .10893 m .65609 .10938 L .65761 .11383 L p F P
0 g
s
.571 .694 .925 r
.64668 .11087 m .65609 .10938 L .65761 .11383 L p F P
0 g
s
.179 .281 .733 r
.8146 .24872 m .81481 .24729 L p .81836 .25622 L F P
0 g
s
.208 .316 .755 r
.8146 .24872 m .81369 .24637 L .81481 .24729 L closepath p F P
0 g
s
.405 .546 .884 r
.73888 .15722 m .74712 .15897 L .74761 .16362 L p F P
0 g
s
.403 .548 .886 r
.74712 .15897 m .73888 .15722 L .73703 .15398 L p F P
0 g
s
.575 .698 .926 r
.65609 .10938 m .64668 .11087 L .64367 .10675 L p F P
0 g
s
0 .09 .634 r
.61899 .21009 m .61915 .21483 L .62237 .21911 L p F P
0 g
s
0 .102 .637 r
.61606 .20573 m .61899 .21009 L .61915 .21483 L p F P
0 g
s
0 0 .117 r
.82969 .3195 m .82808 .32444 L .82749 .33021 L p F P
0 g
s
0 0 .283 r
.82808 .32444 m .82969 .3195 L .82954 .31397 L p F P
0 g
s
.101 .197 .678 r
.8222 .26049 m .82136 .26532 L .82476 .26975 L p F P
0 g
s
.149 .244 .708 r
.81836 .25622 m .8222 .26049 L .82136 .26532 L p F P
0 g
s
.81 .551 0 r
.60342 .16408 m .6022 .15958 L .60146 .15457 L p F P
0 g
s
.206 .315 .756 r
.81481 .24729 m .81369 .24637 L .81071 .23866 L p F P
0 g
s
.493 .627 .91 r
.69885 .13018 m .69789 .13016 L .6974 .12792 L closepath p F P
0 g
s
.497 .633 .914 r
.6959 .1256 m .6974 .12792 L .69789 .13016 L p F P
0 g
s
0 .011 .538 r
.82813 .28879 m .82774 .2904 L .82923 .29721 L p F P
0 g
s
.005 .052 .56 r
.82882 .29861 m .82923 .29721 L .82774 .2904 L p F P
0 g
s
.464 .524 .834 r
.69493 .34701 m .69084 .34623 L .68777 .33978 L p F P
0 g
s
.33 .458 .839 r
.78236 .19765 m .78191 .19746 L .78193 .19676 L closepath p F P
0 g
s
.359 .485 .85 r
.78191 .19746 m .78193 .19676 L .77943 .19176 L p F P
0 g
s
.613 .734 .932 r
.74942 .38438 m .76192 .38162 L .76474 .38526 L p F P
0 g
s
.599 .716 .927 r
.76192 .38162 m .74942 .38438 L .74654 .38013 L p F P
0 g
s
.326 .41 .795 r
.66269 .30718 m .66245 .30705 L .66253 .30678 L closepath p F P
0 g
s
.32 .403 .791 r
.65956 .29967 m .65762 .29853 L p .66245 .30705 L F P
0 g
s
.32 .403 .791 r
.66245 .30705 m .66253 .30678 L .65956 .29967 L p F P
0 g
s
0 0 .492 r
.82923 .29721 m .82882 .29861 L .8303 .3037 L p F P
0 g
s
.491 .568 .862 r
.71255 .36611 m .71233 .36609 L .71242 .36588 L closepath p F P
0 g
s
.501 .557 .845 r
.70954 .36041 m .71242 .36588 L .71233 .36609 L p F P
0 g
s
.409 .543 .879 r
.75468 .16528 m .74761 .16362 L p .75733 .1705 L F P
0 g
s
.396 .538 .881 r
.74761 .16362 m .75468 .16528 L .75176 .16005 L p F P
0 g
s
.396 .538 .881 r
.75176 .16005 m .74712 .15897 L .74761 .16362 L p F P
0 g
s
.294 .384 .785 r
.65642 .2921 m .65306 .28993 L p .65762 .29853 L F P
0 g
s
.294 .384 .785 r
.65762 .29853 m .65815 .2963 L .65642 .2921 L p F P
0 g
s
.301 .391 .789 r
.65956 .29967 m .65762 .29853 L .65815 .2963 L closepath p F P
0 g
s
0 .029 .593 r
.61568 .20104 m .61606 .20573 L .61899 .21009 L p F P
0 g
s
0 .035 .593 r
.61305 .1966 m .61568 .20104 L .61606 .20573 L p F P
0 g
s
.404 .462 .806 r
.66786 .31538 m .67544 .31848 L .6737 .32357 L p F P
0 g
s
.357 .447 .816 r
.66961 .31026 m .66786 .31538 L .67544 .31848 L p F P
0 g
s
.386 .448 .802 r
.66269 .30718 m .66961 .31026 L .66786 .31538 L p F P
0 g
s
.53 .596 .864 r
.71255 .36611 m .72516 .3666 L p .72652 .37172 L F P
0 g
s
.508 .578 .861 r
.72218 .36132 m .72516 .3666 L .71255 .36611 L p F P
0 g
s
.508 .578 .861 r
.71512 .3608 m .72218 .36132 L p .71255 .36611 L F P
0 g
s
.508 .578 .861 r
.71255 .36611 m .71242 .36588 L .71512 .3608 L p F P
0 g
s
.502 .642 .918 r
.68061 .12135 m .68041 .12104 L .68051 .12104 L closepath p F P
0 g
s
.369 .436 .799 r
.66961 .31026 m .66269 .30718 L .66253 .30678 L p F P
0 g
s
.137 .241 .709 r
.81907 .25141 m .81836 .25622 L .8222 .26049 L p F P
0 g
s
.179 .281 .733 r
.81481 .24729 m .81907 .25141 L .81836 .25622 L p F P
0 g
s
.506 .575 .859 r
.71242 .36588 m .70954 .36041 L .71512 .3608 L closepath p F P
0 g
s
.273 .371 .782 r
.65642 .2921 m .65306 .28993 L .65385 .2859 L closepath p F P
0 g
s
.264 .362 .777 r
.65327 .28449 m .64871 .28126 L p .65306 .28993 L F P
0 g
s
.264 .362 .777 r
.65306 .28993 m .65385 .2859 L .65327 .28449 L p F P
0 g
s
.316 .446 .834 r
.78236 .19765 m .78881 .20059 L .78871 .20533 L p F P
0 g
s
.309 .445 .836 r
.78881 .20059 m .78236 .19765 L .78193 .19676 L p F P
0 g
s
.369 .436 .799 r
.66253 .30678 m .66415 .30193 L p .66961 .31026 L F P
0 g
s
.349 .421 .795 r
.66253 .30678 m .65956 .29967 L .66415 .30193 L closepath p F P
0 g
s
.467 .609 .909 r
.69885 .13018 m .71089 .13098 L .71185 .13556 L p F P
0 g
s
.467 .613 .911 r
.71089 .13098 m .69885 .13018 L .6974 .12792 L p F P
0 g
s
.42 .474 .81 r
.6737 .32357 m .6816 .32655 L p .68001 .33163 L F P
0 g
s
.374 .449 .809 r
.6737 .32357 m .6816 .32655 L .67851 .31976 L p F P
0 g
s
.374 .449 .809 r
.67851 .31976 m .67544 .31848 L .6737 .32357 L p F P
0 g
s
.5 .645 .921 r
.68051 .12104 m .68041 .12104 L .67744 .11665 L p F P
0 g
s
.498 .642 .92 r
.68051 .12104 m .69294 .12109 L .68998 .11661 L p F P
0 g
s
.498 .642 .92 r
.68998 .11661 m .67894 .11663 L .68051 .12104 L p F P
0 g
s
.5 .645 .921 r
.67744 .11665 m .67894 .11663 L .68051 .12104 L p F P
0 g
s
.301 .427 .823 r
.79499 .21338 m .79525 .20861 L .78871 .20533 L p F P
0 g
s
.301 .431 .826 r
.78881 .20059 m .78871 .20533 L .79525 .20861 L p F P
0 g
s
.229 .335 .765 r
.64871 .28126 m .65327 .28449 L .65012 .2768 L p F P
0 g
s
.229 .335 .765 r
.65012 .2768 m .64952 .27635 L .64871 .28126 L p F P
0 g
s
.222 .328 .761 r
.64871 .28126 m .64952 .27635 L .64456 .27252 L p F P
0 g
s
.99 .821 .578 r
.59824 .12505 m .60032 .12932 L .5987 .13512 L p F P
0 g
s
.954 .839 .691 r
.60032 .12932 m .59824 .12505 L .60116 .11881 L p F P
0 g
s
.71 .835 .942 r
.78497 .38134 m .77991 .38386 L .77717 .38096 L p F P
0 g
s
.663 .805 .951 r
.76474 .38526 m .77717 .38096 L .77991 .38386 L p F P
0 g
s
.309 .445 .836 r
.78193 .19676 m .78188 .19275 L p .78881 .20059 L F P
0 g
s
.328 .466 .847 r
.78193 .19676 m .77943 .19176 L .78188 .19275 L closepath p F P
0 g
s
.864 .585 .055 r
.59998 .15014 m .60146 .15457 L .6022 .15958 L p F P
0 g
s
.938 .692 .218 r
.60146 .15457 m .59998 .15014 L .59984 .14493 L p F P
0 g
s
.432 .578 .898 r
.72523 .14605 m .73303 .14719 L .7301 .14229 L p F P
0 g
s
.432 .578 .898 r
.7301 .14229 m .72439 .14146 L .72523 .14605 L p F P
0 g
s
.439 .584 .9 r
.71736 .14057 m .72439 .14146 L .72523 .14605 L p F P
0 g
s
.167 .278 .735 r
.8154 .2425 m .81481 .24729 L .81907 .25141 L p F P
0 g
s
.206 .315 .756 r
.81073 .23853 m .8154 .2425 L .81481 .24729 L p F P
0 g
s
.206 .315 .756 r
.81071 .23866 m .81073 .23853 L p .81481 .24729 L F P
0 g
s
.4 .48 .827 r
.68469 .33319 m .68001 .33163 L .68166 .32666 L closepath p F P
0 g
s
.42 .474 .81 r
.6816 .32655 m .68166 .32666 L .68001 .33163 L p F P
0 g
s
.414 .489 .828 r
.68469 .33319 m .68001 .33163 L p .68685 .33951 L F P
0 g
s
0 0 .538 r
.61246 .19195 m .61305 .1966 L .61568 .20104 L p F P
0 g
s
0 0 .533 r
.61014 .18742 m .61246 .19195 L .61305 .1966 L p F P
0 g
s
.204 .322 .763 r
.64524 .26763 m .64456 .27252 L .64952 .27635 L p F P
0 g
s
.193 .305 .751 r
.64456 .27252 m .64524 .26763 L .64057 .26372 L p F P
0 g
s
.576 .65 .886 r
.73107 .37671 m .74364 .37568 L p .74574 .38022 L F P
0 g
s
.545 .647 .901 r
.74364 .37568 m .73107 .37671 L .72812 .37174 L p F P
0 g
s
.289 .409 .811 r
.80076 .22159 m .80119 .21678 L .79499 .21338 L p F P
0 g
s
.291 .416 .817 r
.79525 .20861 m .79499 .21338 L .80119 .21678 L p F P
0 g
s
.232 .346 .775 r
.81071 .23866 m .81063 .23846 L .81073 .23853 L closepath p F P
0 g
s
.647 .782 .946 r
.77717 .38096 m .76474 .38526 L .76192 .38162 L p F P
0 g
s
.438 .587 .903 r
.72439 .14146 m .71736 .14057 L .71442 .13578 L p F P
0 g
s
.228 .346 .776 r
.81073 .23853 m .81063 .23846 L .8076 .23109 L p F P
0 g
s
.192 .311 .757 r
.81119 .23376 m .81073 .23853 L .8154 .2425 L p F P
0 g
s
.228 .346 .776 r
.8076 .23109 m .81119 .23376 L .81073 .23853 L p F P
0 g
s
.261 .381 .797 r
.80076 .22159 m .8046 .22396 L .8016 .21704 L p F P
0 g
s
.261 .381 .797 r
.8016 .21704 m .80119 .21678 L .80076 .22159 L p F P
0 g
s
.279 .393 .8 r
.8046 .22396 m .80076 .22159 L p .80602 .22997 L F P
0 g
s
.242 .356 .78 r
.8076 .23109 m .80602 .22997 L .80627 .22784 L closepath p F P
0 g
s
.279 .393 .8 r
.80602 .22997 m .80627 .22784 L .8046 .22396 L p F P
0 g
s
.165 .294 .752 r
.6411 .25886 m .64057 .26372 L .64524 .26763 L p F P
0 g
s
.16 .28 .739 r
.64057 .26372 m .6411 .25886 L .63672 .25488 L p F P
0 g
s
.403 .548 .886 r
.73703 .15398 m .73677 .1523 L p .74712 .15897 L F P
0 g
s
.415 .561 .892 r
.73703 .15398 m .73596 .15215 L .73677 .1523 L closepath p F P
0 g
s
.535 .665 .92 r
.66202 .1132 m .67446 .11229 L .67744 .11665 L p F P
0 g
s
.536 .668 .922 r
.67446 .11229 m .66202 .1132 L .65903 .10893 L p F P
0 g
s
.417 .493 .83 r
.68777 .33978 m .68685 .33951 L .6872 .33857 L closepath p F P
0 g
s
.414 .489 .828 r
.68685 .33951 m .6872 .33857 L .68469 .33319 L p F P
0 g
s
0 .011 .538 r
.82923 .29721 m .83007 .29373 L .82813 .28879 L p F P
0 g
s
0 .009 .538 r
.8292 .28394 m .82813 .28879 L .83007 .29373 L p F P
0 g
s
.016 .089 .596 r
.82674 .27918 m .8292 .28394 L .82813 .28879 L p F P
0 g
s
0 0 .464 r
.83007 .29373 m .82923 .29721 L .83035 .30352 L p F P
0 g
s
0 0 .492 r
.8303 .3037 m .83035 .30352 L .82923 .29721 L p F P
0 g
s
0 0 .451 r
.60733 .1782 m .60932 .18283 L .61014 .18742 L p F P
0 g
s
0 0 .464 r
.60932 .18283 m .61014 .18742 L .61246 .19195 L p F P
0 g
s
.384 .522 .872 r
.7576 .17057 m .75733 .1705 L .75731 .17003 L closepath p F P
0 g
s
.409 .543 .879 r
.75733 .1705 m .75731 .17003 L .75468 .16528 L p F P
0 g
s
0 0 .281 r
.83106 .30929 m .82954 .31397 L .82969 .3195 L p F P
0 g
s
0 0 .406 r
.83063 .30576 m .8303 .3037 L p .82954 .31397 L F P
0 g
s
0 0 .406 r
.82954 .31397 m .83106 .30929 L .83063 .30576 L p F P
0 g
s
.119 .263 .737 r
.6371 .25005 m .63672 .25488 L .6411 .25886 L p F P
0 g
s
.123 .252 .726 r
.63672 .25488 m .6371 .25005 L .63299 .24599 L p F P
0 g
s
.851 .926 .539 r
.82149 .34767 m .81764 .35447 L .81703 .3561 L p F P
0 g
s
.833 .939 .57 r
.82347 .34266 m .82149 .34767 L .81764 .35447 L p F P
0 g
s
.699 .796 .326 r
.82525 .33856 m .82571 .33737 L p .82149 .34767 L F P
0 g
s
.699 .796 .326 r
.82149 .34767 m .82347 .34266 L .82525 .33856 L p F P
0 g
s
.859 .977 .676 r
.81625 .35646 m .81764 .35447 L .81703 .3561 L closepath p F P
0 g
s
.348 .421 .795 r
.66415 .30193 m .65956 .29967 L .65815 .2963 L p F P
0 g
s
.367 .508 .867 r
.7576 .17057 m .76575 .17305 L .76605 .17773 L p F P
0 g
s
.363 .509 .87 r
.76575 .17305 m .7576 .17057 L .75731 .17003 L p F P
0 g
s
.71 .835 .942 r
.77717 .38096 m .78773 .37614 L .78497 .38134 L p F P
0 g
s
.737 .878 .945 r
.78954 .37527 m .78773 .37614 L .78497 .38134 L p F P
0 g
s
.737 .878 .945 r
.78497 .38134 m .79222 .37748 L .78954 .37527 L p F P
0 g
s
.96 .701 .258 r
.59809 .14058 m .59984 .14493 L .59998 .15014 L p F P
0 g
s
.996 .782 .422 r
.59984 .14493 m .59809 .14058 L .5987 .13512 L p F P
0 g
s
.467 .613 .911 r
.6974 .12792 m .69674 .12564 L p .71089 .13098 L F P
0 g
s
.474 .62 .914 r
.6974 .12792 m .6959 .1256 L .69674 .12564 L closepath p F P
0 g
s
.464 .524 .834 r
.68777 .33978 m .69701 .34188 L .69493 .34701 L p F P
0 g
s
.449 .512 .831 r
.69701 .34188 m .68777 .33978 L .6872 .33857 L p F P
0 g
s
.363 .509 .87 r
.75731 .17003 m .75686 .16586 L p .76575 .17305 L F P
0 g
s
.379 .525 .877 r
.75731 .17003 m .75468 .16528 L .75686 .16586 L closepath p F P
0 g
s
.63 .724 .915 r
.62839 .10605 m .64066 .10265 L .64367 .10675 L p F P
0 g
s
.634 .728 .915 r
.64066 .10265 m .62839 .10605 L .62536 .1021 L p F P
0 g
s
.705 .761 .896 r
.6132 .10781 m .62536 .1021 L .62839 .10605 L p F P
0 g
s
.06 .217 .713 r
.6332 .24119 m .63299 .24599 L .6371 .25005 L p F P
0 g
s
.079 .22 .71 r
.63299 .24599 m .6332 .24119 L .62936 .23706 L p F P
0 g
s
.844 .835 .837 r
.60935 .11072 m .60701 .10652 L p .60092 .1184 L F P
0 g
s
.844 .835 .837 r
.60092 .1184 m .60122 .1187 L .60935 .11072 L p F P
0 g
s
.787 .795 .858 r
.61015 .10407 m .60701 .10652 L .60935 .11072 L p F P
0 g
s
.787 .795 .858 r
.60935 .11072 m .6132 .10781 L .61015 .10407 L p F P
0 g
s
0 0 0 r
.82571 .33737 m .82608 .33624 L .82749 .33021 L p F P
0 g
s
0 0 0 r
.82908 .32529 m .82749 .33021 L .82608 .33624 L p F P
0 g
s
0 0 .117 r
.82749 .33021 m .82908 .32529 L .82969 .3195 L p F P
0 g
s
0 0 .365 r
.60629 .17367 m .60733 .1782 L .60932 .18283 L p F P
0 g
s
0 0 .302 r
.60733 .1782 m .60629 .17367 L .60468 .16893 L p F P
0 g
s
.413 .563 .894 r
.73677 .1523 m .73596 .15215 L .73303 .14719 L p F P
0 g
s
.476 .534 .838 r
.69493 .34701 m .70349 .34871 L p .70402 .35421 L F P
0 g
s
.44 .514 .838 r
.69493 .34701 m .70349 .34871 L .70044 .34269 L p F P
0 g
s
.44 .514 .838 r
.70044 .34269 m .69701 .34188 L .69493 .34701 L p F P
0 g
s
.449 .512 .831 r
.6872 .33857 m .68904 .33432 L p .69701 .34188 L F P
0 g
s
.434 .501 .829 r
.6872 .33857 m .68469 .33319 L .68904 .33432 L closepath p F P
0 g
s
.327 .405 .79 r
.65815 .2963 m .65642 .2921 L .65899 .29349 L closepath p F P
0 g
s
.348 .421 .795 r
.65815 .2963 m .65899 .29349 L p .66415 .30193 L F P
0 g
s
.012 .182 .694 r
.6294 .2323 m .62936 .23706 L .6332 .24119 L p F P
0 g
s
.029 .183 .69 r
.62936 .23706 m .6294 .2323 L .62583 .2281 L p F P
0 g
s
.908 .825 .753 r
.60116 .11881 m .60092 .1184 L .60122 .1187 L closepath p F P
0 g
s
.952 .826 .682 r
.60092 .1184 m .60116 .11881 L .59824 .12505 L p F P
0 g
s
.218 .34 .775 r
.81119 .23376 m .8076 .23109 L .80627 .22784 L p F P
0 g
s
.711 .763 .893 r
.62536 .1021 m .6132 .10781 L .61015 .10407 L p F P
0 g
s
.003 .084 .597 r
.82772 .27433 m .82674 .27918 L .8292 .28394 L p F P
0 g
s
.058 .145 .64 r
.82674 .27918 m .82772 .27433 L .82476 .26975 L p F P
0 g
s
.507 .573 .856 r
.71512 .3608 m .70954 .36041 L .70652 .35463 L p F P
0 g
s
.463 .604 .906 r
.71185 .13556 m .71442 .13578 L .71148 .13103 L p F P
0 g
s
.463 .604 .906 r
.71148 .13103 m .71089 .13098 L .71185 .13556 L p F P
0 g
s
.37 .504 .863 r
.77356 .18019 m .76605 .17773 L p .77431 .18512 L F P
0 g
s
.354 .498 .864 r
.76605 .17773 m .77356 .18019 L .77064 .17465 L p F P
0 g
s
.354 .498 .864 r
.77064 .17465 m .76575 .17305 L .76605 .17773 L p F P
0 g
s
.326 .467 .848 r
.78188 .19275 m .77943 .19176 L .7765 .18593 L p F P
0 g
s
.403 .548 .886 r
.73677 .1523 m .74653 .15433 L .74712 .15897 L p F P
0 g
s
.406 .553 .889 r
.73595 .14772 m .73677 .1523 L .74653 .15433 L p F P
0 g
s
.413 .563 .894 r
.73303 .14719 m .73595 .14772 L .73677 .1523 L p F P
0 g
s
.57 .668 .905 r
.74654 .38013 m .74574 .38022 L .74606 .37939 L closepath p F P
0 g
s
.576 .65 .886 r
.74364 .37568 m .74606 .37939 L .74574 .38022 L p F P
0 g
s
.844 .835 .837 r
.60701 .10652 m .5991 .11451 L .60092 .1184 L p F P
0 g
s
.905 .841 .772 r
.59817 .11585 m .5991 .11451 L .60092 .1184 L closepath p F P
0 g
s
.952 .826 .682 r
.59817 .11585 m .60092 .1184 L p .59824 .12505 L F P
0 g
s
.575 .698 .926 r
.64367 .10675 m .65448 .10495 L .65609 .10938 L p F P
0 g
s
.579 .702 .926 r
.65448 .10495 m .64367 .10675 L .64066 .10265 L p F P
0 g
s
.53 .596 .864 r
.72516 .3666 m .72718 .37012 L .72652 .37172 L p F P
0 g
s
.522 .609 .881 r
.72812 .37174 m .72652 .37172 L .72718 .37012 L closepath p F P
0 g
s
0 .141 .67 r
.62568 .22338 m .62583 .2281 L .6294 .2323 L p F P
0 g
s
0 .141 .666 r
.62583 .2281 m .62568 .22338 L .62237 .21911 L p F P
0 g
s
.723 .444 0 r
.60468 .16893 m .6034 .16445 L p .60358 .1648 L F P
0 g
s
.721 .405 0 r
.6034 .16445 m .60495 .16922 L p .60321 .1641 L F P
0 g
s
.721 .405 0 r
.60184 .16006 m .6034 .16445 L p .60321 .1641 L F P
0 g
s
.723 .444 0 r
.6034 .16445 m .6022 .15958 L p .60358 .1648 L F P
0 g
s
.997 .774 .439 r
.59668 .13083 m .5987 .13512 L .59809 .14058 L p F P
0 g
s
.99 .821 .578 r
.5987 .13512 m .59668 .13083 L .59824 .12505 L p F P
0 g
s
.326 .405 .79 r
.65899 .29349 m .65642 .2921 L .65385 .2859 L p F P
0 g
s
.762 .938 .941 r
.80255 .37035 m .79222 .37748 L .78954 .37527 L p F P
0 g
s
.599 .716 .927 r
.74654 .38013 m .75908 .37778 L .76192 .38162 L p F P
0 g
s
.591 .678 .901 r
.75622 .37377 m .75908 .37778 L .74654 .38013 L p F P
0 g
s
.591 .678 .901 r
.74887 .37488 m .75622 .37377 L p .74654 .38013 L F P
0 g
s
.591 .678 .901 r
.74654 .38013 m .74606 .37939 L .74887 .37488 L p F P
0 g
s
.218 .34 .775 r
.80627 .22784 m .80646 .22518 L p .81119 .23376 L F P
0 g
s
.244 .37 .793 r
.80627 .22784 m .8046 .22396 L .80646 .22518 L closepath p F P
0 g
s
.902 .983 .725 r
.81764 .35447 m .81942 .34953 L p .81385 .3569 L F P
0 g
s
.902 .983 .725 r
.81385 .3569 m .81625 .35646 L .81764 .35447 L p F P
0 g
s
.833 .939 .57 r
.81764 .35447 m .81942 .34953 L .82347 .34266 L p F P
0 g
s
0 0 .396 r
.83063 .30576 m .8303 .3037 L .83035 .30352 L closepath p F P
0 g
s
.579 .695 .921 r
.65609 .10938 m .65903 .10893 L .65603 .10469 L p F P
0 g
s
.579 .695 .921 r
.65603 .10469 m .65448 .10495 L .65609 .10938 L p F P
0 g
s
0 .094 .641 r
.62204 .21443 m .62237 .21911 L .62568 .22338 L p F P
0 g
s
0 .09 .634 r
.62237 .21911 m .62204 .21443 L .61899 .21009 L p F P
0 g
s
.7 .762 .267 r
.82525 .33856 m .82608 .33624 L .82571 .33737 L closepath p F P
0 g
s
.056 .147 .643 r
.82564 .26491 m .82476 .26975 L .82772 .27433 L p F P
0 g
s
.101 .197 .678 r
.82476 .26975 m .82564 .26491 L .8222 .26049 L p F P
0 g
s
.472 .622 .916 r
.69674 .12564 m .6959 .1256 L .69294 .12109 L p F P
0 g
s
0 0 .375 r
.83035 .30352 m .83147 .29885 L p .83113 .30901 L F P
0 g
s
0 0 .375 r
.83113 .30901 m .83063 .30576 L .83035 .30352 L p F P
0 g
s
0 0 .464 r
.83035 .30352 m .83147 .29885 L .83007 .29373 L p F P
0 g
s
.463 .544 .855 r
.70652 .35463 m .70402 .35421 L .70499 .35166 L closepath p F P
0 g
s
.476 .534 .838 r
.70349 .34871 m .70499 .35166 L .70402 .35421 L p F P
0 g
s
.846 .996 .762 r
.81155 .36196 m .81385 .3569 L .81625 .35646 L closepath p F P
0 g
s
.341 .479 .852 r
.7765 .18593 m .77431 .18512 L .77423 .18146 L closepath p F P
0 g
s
.37 .504 .863 r
.77431 .18512 m .77423 .18146 L .77356 .18019 L p F P
0 g
s
.541 .619 .879 r
.73779 .36633 m .74072 .37107 L .72812 .37174 L p F P
0 g
s
.541 .619 .879 r
.72914 .3665 m .73779 .36633 L p .72812 .37174 L F P
0 g
s
.541 .619 .879 r
.72812 .37174 m .72718 .37012 L .72914 .3665 L p F P
0 g
s
.545 .647 .901 r
.72812 .37174 m .74072 .37107 L .74364 .37568 L p F P
0 g
s
.59 .676 .901 r
.74606 .37939 m .74364 .37568 L .74887 .37488 L closepath p F P
0 g
s
.502 .648 .923 r
.67894 .11663 m .67744 .11665 L .67446 .11229 L p F P
0 g
s
.788 .487 0 r
.60069 .15517 m .6022 .15958 L .6034 .16445 L p F P
0 g
s
.864 .585 .055 r
.6022 .15958 m .60069 .15517 L .59998 .15014 L p F P
0 g
s
.435 .501 .828 r
.68904 .33432 m .68469 .33319 L .68166 .32666 L p F P
0 g
s
.467 .613 .911 r
.69674 .12564 m .70853 .12638 L p .71089 .13098 L F P
0 g
s
.467 .618 .916 r
.69674 .12564 m .70853 .12638 L .70558 .12179 L p F P
0 g
s
.467 .618 .916 r
.70558 .12179 m .69531 .12119 L .69674 .12564 L p F P
0 g
s
.472 .622 .916 r
.69294 .12109 m .69531 .12119 L .69674 .12564 L p F P
0 g
s
0 .04 .603 r
.61847 .20545 m .61899 .21009 L .62204 .21443 L p F P
0 g
s
0 .029 .593 r
.61899 .21009 m .61847 .20545 L .61568 .20104 L p F P
0 g
s
.438 .587 .903 r
.71442 .13578 m .72344 .1369 L .72439 .14146 L p F P
0 g
s
.437 .589 .905 r
.72344 .1369 m .71442 .13578 L .71148 .13103 L p F P
0 g
s
.242 .37 .794 r
.80646 .22518 m .8046 .22396 L .8016 .21704 L p F P
0 g
s
.326 .405 .79 r
.65385 .2859 m .65409 .28498 L p .65899 .29349 L F P
0 g
s
.303 .387 .784 r
.65385 .2859 m .65327 .28449 L .65409 .28498 L closepath p F P
0 g
s
.864 .958 .866 r
.81155 .36196 m .81385 .3569 L p .80347 .36852 L F P
0 g
s
.864 .958 .866 r
.80347 .36852 m .80438 .36893 L .81155 .36196 L p F P
0 g
s
.1 .199 .681 r
.82297 .25567 m .8222 .26049 L .82564 .26491 L p F P
0 g
s
.137 .241 .709 r
.8222 .26049 m .82297 .25567 L .81907 .25141 L p F P
0 g
s
.762 .938 .941 r
.80347 .36852 m .80255 .37035 L p .78954 .37527 L F P
0 g
s
.81 .961 .909 r
.80255 .37035 m .80347 .36852 L .80438 .36893 L closepath p F P
0 g
s
.394 .54 .883 r
.74712 .15897 m .75176 .16005 L .74883 .15486 L p F P
0 g
s
.394 .54 .883 r
.74883 .15486 m .74653 .15433 L .74712 .15897 L p F P
0 g
s
.309 .445 .836 r
.78188 .19275 m .78882 .19587 L .78881 .20059 L p F P
0 g
s
.311 .451 .841 r
.78172 .18806 m .78188 .19275 L .78882 .19587 L p F P
0 g
s
.326 .467 .848 r
.7765 .18593 m .78172 .18806 L .78188 .19275 L p F P
0 g
s
0 0 .113 r
.83131 .31454 m .82969 .3195 L .82908 .32529 L p F P
0 g
s
0 0 .281 r
.83128 .31362 m .83106 .30929 L p .82969 .3195 L F P
0 g
s
0 0 .281 r
.82969 .3195 m .83131 .31454 L .83128 .31362 L p F P
0 g
s
.647 .782 .946 r
.76192 .38162 m .7744 .37781 L .77717 .38096 L p F P
0 g
s
.631 .761 .94 r
.7744 .37781 m .76192 .38162 L .75908 .37778 L p F P
0 g
s
.376 .526 .879 r
.75686 .16586 m .75468 .16528 L .75176 .16005 L p F P
0 g
s
.499 .646 .922 r
.67894 .11663 m .68998 .11661 L .68701 .11218 L p F P
0 g
s
.499 .646 .922 r
.68701 .11218 m .67726 .11225 L .67894 .11663 L p F P
0 g
s
.502 .648 .923 r
.67446 .11229 m .67726 .11225 L .67894 .11663 L p F P
0 g
s
.302 .387 .784 r
.65409 .28498 m .65327 .28449 L .65012 .2768 L p F P
0 g
s
.986 .808 .58 r
.59594 .12085 m .59824 .12505 L .59668 .13083 L p F P
0 g
s
.952 .826 .682 r
.59824 .12505 m .59594 .12085 L .59817 .11585 L p F P
0 g
s
.539 .617 .878 r
.72718 .37012 m .72516 .3666 L .72914 .3665 L closepath p F P
0 g
s
.69 .836 .954 r
.78773 .37614 m .77717 .38096 L .7744 .37781 L p F P
0 g
s
0 0 .377 r
.83106 .30929 m .83063 .30576 L .83113 .30901 L closepath p F P
0 g
s
0 0 .555 r
.61496 .19644 m .61568 .20104 L .61847 .20545 L p F P
0 g
s
0 0 .538 r
.61568 .20104 m .61496 .19644 L .61246 .19195 L p F P
0 g
s
0 0 0 r
.8276 .33135 m .82908 .32529 L p .82611 .33613 L F P
0 g
s
0 0 0 r
.82608 .33624 m .8276 .33135 L p .82611 .33613 L F P
0 g
s
0 0 0 r
.83067 .32034 m .82908 .32529 L .8276 .33135 L p F P
0 g
s
0 0 0 r
.8276 .33135 m .82914 .32643 L .83067 .32034 L p F P
0 g
s
.775 .831 .365 r
.8276 .33135 m .82515 .33773 L p .8291 .32655 L F P
0 g
s
.775 .831 .365 r
.82914 .32643 m .8276 .33135 L p .8291 .32655 L F P
0 g
s
.798 .827 .354 r
.82608 .33624 m .8276 .33135 L p .82433 .34044 L F P
0 g
s
.798 .827 .354 r
.82433 .34044 m .82525 .33856 L .82608 .33624 L p F P
0 g
s
.536 .668 .922 r
.65903 .10893 m .67148 .10797 L .67446 .11229 L p F P
0 g
s
.537 .671 .924 r
.67148 .10797 m .65903 .10893 L .65603 .10469 L p F P
0 g
s
.901 .608 .108 r
.59822 .14579 m .59998 .15014 L .60069 .15517 L p F P
0 g
s
.96 .701 .258 r
.59998 .15014 m .59822 .14579 L .59809 .14058 L p F P
0 g
s
0 .009 .538 r
.83007 .29373 m .83117 .28887 L .8292 .28394 L p F P
0 g
s
0 0 .464 r
.83117 .28887 m .83007 .29373 L .83147 .29885 L p F P
0 g
s
.136 .244 .712 r
.81972 .2466 m .81907 .25141 L .82297 .25567 L p F P
0 g
s
.167 .278 .735 r
.81907 .25141 m .81972 .2466 L .8154 .2425 L p F P
0 g
s
.507 .573 .856 r
.70652 .35463 m .71715 .35572 L .71512 .3608 L p F P
0 g
s
.493 .561 .854 r
.71715 .35572 m .70652 .35463 L .70499 .35166 L p F P
0 g
s
.431 .58 .901 r
.72439 .14146 m .7301 .14229 L .72717 .13742 L p F P
0 g
s
.431 .58 .901 r
.72717 .13742 m .72344 .1369 L .72439 .14146 L p F P
0 g
s
.301 .431 .826 r
.79525 .20861 m .79543 .20384 L .78881 .20059 L p F P
0 g
s
.304 .439 .832 r
.78882 .19587 m .78881 .20059 L .79543 .20384 L p F P
0 g
s
.326 .405 .79 r
.65409 .28498 m .66013 .2885 L .65899 .29349 L p F P
0 g
s
.348 .421 .795 r
.65899 .29349 m .66534 .29694 L .66415 .30193 L p F P
0 g
s
.286 .397 .801 r
.66013 .2885 m .65899 .29349 L .66534 .29694 L p F P
0 g
s
.369 .436 .799 r
.66415 .30193 m .67083 .30529 L .66961 .31026 L p F P
0 g
s
.313 .416 .807 r
.66534 .29694 m .66415 .30193 L .67083 .30529 L p F P
0 g
s
.257 .37 .788 r
.65516 .27999 m .65409 .28498 L .66013 .2885 L p F P
0 g
s
.302 .387 .784 r
.65012 .2768 m .65516 .27999 L .65409 .28498 L p F P
0 g
s
.321 .466 .85 r
.78172 .18806 m .7765 .18593 L .77423 .18146 L p F P
0 g
s
0 0 .492 r
.61153 .1874 m .61246 .19195 L .61496 .19644 L p F P
0 g
s
0 0 .464 r
.61246 .19195 m .61153 .1874 L .60932 .18283 L p F P
0 g
s
.357 .447 .816 r
.6754 .31293 m .66961 .31026 L p .67544 .31848 L F P
0 g
s
.33 .421 .804 r
.66961 .31026 m .6754 .31293 L .67229 .30602 L p F P
0 g
s
.33 .421 .804 r
.67229 .30602 m .67083 .30529 L .66961 .31026 L p F P
0 g
s
.411 .565 .897 r
.73595 .14772 m .73303 .14719 L .7301 .14229 L p F P
0 g
s
.215 .333 .769 r
.65012 .2768 m .64952 .27635 L .64961 .27557 L closepath p F P
0 g
s
.204 .322 .763 r
.64696 .26904 m .64524 .26763 L p .64952 .27635 L F P
0 g
s
.204 .322 .763 r
.64952 .27635 m .64961 .27557 L .64696 .26904 L p F P
0 g
s
.166 .281 .738 r
.81592 .23771 m .8154 .2425 L .81972 .2466 L p F P
0 g
s
.192 .311 .757 r
.8154 .2425 m .81592 .23771 L .81119 .23376 L p F P
0 g
s
.704 .8 .331 r
.82347 .34266 m .82433 .34044 L .82525 .33856 L closepath p F P
0 g
s
.291 .416 .817 r
.79863 .21047 m .79525 .20861 L p .80119 .21678 L F P
0 g
s
.274 .406 .814 r
.79525 .20861 m .79863 .21047 L .79566 .20396 L p F P
0 g
s
.274 .406 .814 r
.79566 .20396 m .79543 .20384 L .79525 .20861 L p F P
0 g
s
.484 .567 .864 r
.71512 .3608 m .72218 .36132 L .71918 .35595 L p F P
0 g
s
.484 .567 .864 r
.71918 .35595 m .71715 .35572 L .71512 .3608 L p F P
0 g
s
.357 .447 .816 r
.67544 .31848 m .67635 .31502 L .6754 .31293 L p F P
0 g
s
.362 .452 .819 r
.67851 .31976 m .67544 .31848 L .67635 .31502 L closepath p F P
0 g
s
.634 .728 .915 r
.62536 .1021 m .63763 .09857 L .64066 .10265 L p F P
0 g
s
.638 .731 .915 r
.63763 .09857 m .62536 .1021 L .62231 .09814 L p F P
0 g
s
.711 .763 .893 r
.61015 .10407 m .62231 .09814 L .62536 .1021 L p F P
0 g
s
.178 .308 .759 r
.64696 .26904 m .64524 .26763 L .64542 .26529 L closepath p F P
0 g
s
.165 .294 .752 r
.6438 .26127 m .6411 .25886 L p .64524 .26763 L F P
0 g
s
.165 .294 .752 r
.64524 .26763 m .64542 .26529 L .6438 .26127 L p F P
0 g
s
.191 .314 .76 r
.81157 .22899 m .81119 .23376 L .81592 .23771 L p F P
0 g
s
.218 .34 .775 r
.80646 .22518 m .81157 .22899 L .81119 .23376 L p F P
0 g
s
.255 .381 .799 r
.8016 .21704 m .80119 .21678 L .80123 .21619 L closepath p F P
0 g
s
.291 .416 .817 r
.80119 .21678 m .80123 .21619 L .79863 .21047 L p F P
0 g
s
.212 .343 .779 r
.8067 .22044 m .80646 .22518 L .81157 .22899 L p F P
0 g
s
.242 .37 .794 r
.8016 .21704 m .8067 .22044 L .80646 .22518 L p F P
0 g
s
.435 .501 .828 r
.68166 .32666 m .68169 .32657 L p .68904 .33432 L F P
0 g
s
.419 .49 .826 r
.68166 .32666 m .6816 .32655 L .68169 .32657 L closepath p F P
0 g
s
.421 .488 .823 r
.68169 .32657 m .6816 .32655 L .67851 .31976 L p F P
0 g
s
.973 .704 .291 r
.59609 .13629 m .59809 .14058 L .59822 .14579 L p F P
0 g
s
.997 .774 .439 r
.59809 .14058 m .59609 .13629 L .59668 .13083 L p F P
0 g
s
0 0 .41 r
.60819 .17833 m .60932 .18283 L .61153 .1874 L p F P
0 g
s
0 0 .365 r
.60932 .18283 m .60819 .17833 L .60629 .17367 L p F P
0 g
s
.435 .501 .828 r
.68169 .32657 m .69075 .32926 L .68904 .33432 L p F P
0 g
s
.394 .49 .839 r
.68356 .32144 m .68169 .32657 L .69075 .32926 L p F P
0 g
s
.421 .488 .823 r
.67851 .31976 m .68356 .32144 L .68169 .32657 L p F P
0 g
s
.279 .374 .782 r
.65516 .27999 m .65012 .2768 L .64961 .27557 L p F P
0 g
s
.363 .509 .87 r
.75686 .16586 m .76535 .16838 L .76575 .17305 L p F P
0 g
s
.377 .524 .877 r
.75625 .16124 m .75686 .16586 L .76535 .16838 L p F P
0 g
s
.376 .526 .879 r
.75176 .16005 m .75625 .16124 L .75686 .16586 L p F P
0 g
s
.136 .279 .747 r
.6438 .26127 m .6411 .25886 L .64124 .25502 L closepath p F P
0 g
s
.119 .263 .737 r
.64063 .25349 m .6371 .25005 L p .6411 .25886 L F P
0 g
s
.119 .263 .737 r
.6411 .25886 m .64124 .25502 L .64063 .25349 L p F P
0 g
s
.846 .819 .822 r
.60448 .10236 m .60701 .10652 L .5991 .11451 L p F P
0 g
s
.792 .794 .853 r
.60708 .10028 m .60448 .10236 L .60701 .10652 L p F P
0 g
s
.792 .794 .853 r
.60701 .10652 m .61015 .10407 L .60708 .10028 L p F P
0 g
s
.231 .366 .794 r
.8067 .22044 m .8016 .21704 L .80123 .21619 L p F P
0 g
s
.279 .374 .782 r
.64961 .27557 m .65039 .27141 L p .65516 .27999 L F P
0 g
s
.254 .355 .774 r
.64961 .27557 m .64696 .26904 L .65039 .27141 L closepath p F P
0 g
s
.493 .561 .854 r
.70499 .35166 m .7062 .34907 L p .71715 .35572 L F P
0 g
s
.481 .553 .853 r
.70499 .35166 m .70349 .34871 L .7062 .34907 L closepath p F P
0 g
s
.822 .943 .904 r
.8018 .36759 m .8046 .36535 L .80347 .36852 L closepath p F P
0 g
s
.762 .938 .941 r
.78954 .37527 m .8018 .36759 L .80347 .36852 L p F P
0 g
s
.864 .958 .866 r
.81384 .3569 m .8046 .36535 L .80347 .36852 L p F P
0 g
s
.864 .958 .866 r
.81385 .3569 m .81384 .3569 L p .80347 .36852 L F P
0 g
s
0 .01 .54 r
.83022 .27908 m .8292 .28394 L .83117 .28887 L p F P
0 g
s
.003 .084 .597 r
.8292 .28394 m .83022 .27908 L .82772 .27433 L p F P
0 g
s
0 0 .253 r
.83128 .31362 m .83113 .30901 L .83106 .30929 L closepath p F P
0 g
s
.715 .765 .892 r
.62231 .09814 m .61015 .10407 L .60708 .10028 L p F P
0 g
s
.076 .232 .723 r
.6371 .25005 m .64063 .25349 L .63746 .24569 L p F P
0 g
s
.076 .232 .723 r
.63746 .24569 m .63709 .24532 L .6371 .25005 L p F P
0 g
s
.06 .217 .713 r
.6371 .25005 m .63709 .24532 L .6332 .24119 L p F P
0 g
s
.256 .394 .81 r
.80123 .21619 m .79863 .21047 L .80132 .21206 L closepath p F P
0 g
s
.231 .366 .794 r
.80123 .21619 m .80132 .21206 L p .8067 .22044 L F P
0 g
s
.591 .669 .894 r
.74887 .37488 m .74364 .37568 L .74072 .37107 L p F P
0 g
s
.579 .702 .926 r
.64066 .10265 m .65276 .10053 L .65448 .10495 L p F P
0 g
s
.582 .705 .927 r
.65276 .10053 m .64066 .10265 L .63763 .09857 L p F P
0 g
s
.541 .613 .874 r
.72914 .3665 m .72516 .3666 L .72218 .36132 L p F P
0 g
s
.905 .829 .761 r
.5991 .11451 m .59817 .11585 L .5951 .11283 L p F P
0 g
s
.905 .829 .761 r
.5951 .11283 m .59682 .11028 L .5991 .11451 L p F P
0 g
s
.846 .819 .822 r
.5991 .11451 m .59682 .11028 L .60448 .10236 L p F P
0 g
s
0 0 .304 r
.60495 .16922 m .60629 .17367 L .60819 .17833 L p F P
0 g
s
.667 .34 0 r
.60495 .16922 m .60678 .17391 L p .60502 .16928 L F P
0 g
s
.721 .405 0 r
.60334 .16484 m .60184 .16006 L p .60349 .16492 L F P
0 g
s
.721 .405 0 r
.60495 .16922 m .60334 .16484 L p .60349 .16492 L F P
0 g
s
.667 .34 0 r
.60334 .16484 m .60495 .16922 L p .60502 .16928 L F P
0 g
s
.724 .378 0 r
.60334 .16484 m .60511 .16955 L p .60319 .16477 L F P
0 g
s
.724 .378 0 r
.60149 .16053 m .60334 .16484 L p .60319 .16477 L F P
0 g
s
0 0 .235 r
.60495 .16922 m .6034 .16445 L p .60488 .16916 L F P
0 g
s
0 0 .235 r
.60629 .17367 m .60495 .16922 L p .60488 .16916 L F P
0 g
s
0 0 .204 r
.83113 .30901 m .83229 .30417 L p .83132 .31448 L F P
0 g
s
0 0 .204 r
.83132 .31448 m .83128 .31362 L .83113 .30901 L p F P
0 g
s
0 0 .375 r
.83147 .29885 m .83229 .30417 L .83113 .30901 L p F P
0 g
s
.408 .489 .831 r
.68904 .33432 m .69739 .33658 L .69433 .33036 L p F P
0 g
s
.408 .489 .831 r
.69433 .33036 m .69075 .32926 L .68904 .33432 L p F P
0 g
s
.449 .512 .831 r
.68904 .33432 m .69739 .33658 L p .69701 .34188 L F P
0 g
s
.032 .206 .711 r
.63304 .23649 m .6332 .24119 L .63709 .24532 L p F P
0 g
s
.012 .182 .694 r
.6332 .24119 m .63304 .23649 L .6294 .2323 L p F P
0 g
s
.841 .955 .611 r
.82433 .34044 m .82347 .34266 L .81942 .34953 L p F P
0 g
s
.944 .811 .683 r
.59594 .12085 m .59817 .11585 L .5951 .11283 L p F P
0 g
s
.472 .625 .919 r
.69531 .12119 m .69294 .12109 L .68998 .11661 L p F P
0 g
s
.461 .606 .908 r
.71148 .13103 m .71089 .13098 L .71055 .12955 L closepath p F P
0 g
s
.467 .613 .911 r
.70853 .12638 m .71055 .12955 L .71089 .13098 L p F P
0 g
s
.996 .765 .452 r
.59443 .12661 m .59668 .13083 L .59609 .13629 L p F P
0 g
s
.986 .808 .58 r
.59668 .13083 m .59443 .12661 L .59594 .12085 L p F P
0 g
s
.414 .564 .895 r
.73501 .14317 m .73595 .14772 L .74585 .14971 L p F P
0 g
s
.411 .565 .897 r
.7301 .14229 m .73501 .14317 L .73595 .14772 L p F P
0 g
s
.406 .553 .889 r
.74653 .15433 m .74585 .14971 L .73595 .14772 L p F P
0 g
s
0 .162 .686 r
.62908 .22763 m .6294 .2323 L .63304 .23649 L p F P
0 g
s
0 .141 .67 r
.6294 .2323 m .62908 .22763 L .62568 .22338 L p F P
0 g
s
.69 .836 .954 r
.78871 .3745 m .78773 .37614 L p .7744 .37781 L F P
0 g
s
.719 .852 .945 r
.78773 .37614 m .78871 .3745 L .78954 .37527 L closepath p F P
0 g
s
.351 .498 .866 r
.76575 .17305 m .77064 .17465 L .76771 .16915 L p F P
0 g
s
.351 .498 .866 r
.76771 .16915 m .76535 .16838 L .76575 .17305 L p F P
0 g
s
.503 .651 .925 r
.67726 .11225 m .67446 .11229 L .67148 .10797 L p F P
0 g
s
.339 .485 .859 r
.77423 .18146 m .77356 .18019 L .77416 .18041 L closepath p F P
0 g
s
.321 .466 .85 r
.77423 .18146 m .77416 .18041 L p .78172 .18806 L F P
0 g
s
0 0 .113 r
.82908 .32529 m .83067 .32034 L .83131 .31454 L p F P
0 g
s
.437 .589 .905 r
.71148 .13103 m .72238 .13235 L .72344 .1369 L p F P
0 g
s
.436 .592 .908 r
.72238 .13235 m .71148 .13103 L .71055 .12955 L p F P
0 g
s
.788 .487 0 r
.6034 .16445 m .60184 .16006 L .60069 .15517 L p F P
0 g
s
.25 .355 .775 r
.65039 .27141 m .64696 .26904 L .64542 .26529 L p F P
0 g
s
.482 .55 .85 r
.7062 .34907 m .70349 .34871 L .70044 .34269 L p F P
0 g
s
.373 .527 .881 r
.75625 .16124 m .75176 .16005 L .74883 .15486 L p F P
0 g
s
.002 .087 .6 r
.82865 .26949 m .82772 .27433 L .83022 .27908 L p F P
0 g
s
.056 .147 .643 r
.82772 .27433 m .82865 .26949 L .82564 .26491 L p F P
0 g
s
.582 .698 .922 r
.65448 .10495 m .65603 .10469 L .65302 .10048 L p F P
0 g
s
.582 .698 .922 r
.65302 .10048 m .65276 .10053 L .65448 .10495 L p F P
0 g
s
.772 .864 .918 r
.78871 .3745 m .78954 .37527 L .8018 .36759 L p F P
0 g
s
.432 .52 .848 r
.70044 .34269 m .69701 .34188 L .69819 .33819 L closepath p F P
0 g
s
.449 .512 .831 r
.69739 .33658 m .69819 .33819 L .69701 .34188 L p F P
0 g
s
0 .111 .655 r
.62519 .21875 m .62568 .22338 L .62908 .22763 L p F P
0 g
s
0 .094 .641 r
.62568 .22338 m .62519 .21875 L .62204 .21443 L p F P
0 g
s
.404 .477 .822 r
.68356 .32144 m .67851 .31976 L .67635 .31502 L p F P
0 g
s
.336 .486 .862 r
.77416 .18041 m .77356 .18019 L .77064 .17465 L p F P
0 g
s
.223 .333 .766 r
.64542 .26529 m .6438 .26127 L .64579 .26277 L closepath p F P
0 g
s
.25 .355 .775 r
.64542 .26529 m .64579 .26277 L p .65039 .27141 L F P
0 g
s
.631 .761 .94 r
.75908 .37778 m .7716 .37443 L .7744 .37781 L p F P
0 g
s
.617 .742 .935 r
.7716 .37443 m .75908 .37778 L .75622 .37377 L p F P
0 g
s
0 .047 .611 r
.62138 .20983 m .62204 .21443 L .62519 .21875 L p F P
0 g
s
0 .04 .603 r
.62204 .21443 m .62138 .20983 L .61847 .20545 L p F P
0 g
s
.837 .519 0 r
.59891 .15083 m .60069 .15517 L .60184 .16006 L p F P
0 g
s
.901 .608 .108 r
.60069 .15517 m .59891 .15083 L .59822 .14579 L p F P
0 g
s
.467 .621 .918 r
.69531 .12119 m .70558 .12179 L .70262 .11725 L p F P
0 g
s
.467 .621 .918 r
.70262 .11725 m .69376 .11677 L .69531 .12119 L p F P
0 g
s
.472 .625 .919 r
.68998 .11661 m .69376 .11677 L .69531 .12119 L p F P
0 g
s
.254 .394 .811 r
.80132 .21206 m .79863 .21047 L .79566 .20396 L p F P
0 g
s
.537 .671 .924 r
.65603 .10469 m .66849 .10368 L .67148 .10797 L p F P
0 g
s
.537 .674 .926 r
.66849 .10368 m .65603 .10469 L .65302 .10048 L p F P
0 g
s
.321 .466 .85 r
.77416 .18041 m .78146 .18338 L .78172 .18806 L p F P
0 g
s
.318 .469 .854 r
.77373 .17577 m .77416 .18041 L .78146 .18338 L p F P
0 g
s
.336 .486 .862 r
.77064 .17465 m .77373 .17577 L .77416 .18041 L p F P
0 g
s
.436 .592 .908 r
.71055 .12955 m .70964 .12649 L p .72238 .13235 L F P
0 g
s
.446 .601 .911 r
.71055 .12955 m .70853 .12638 L .70964 .12649 L closepath p F P
0 g
s
0 0 .363 r
.83259 .29399 m .83147 .29885 L .83229 .30417 L p F P
0 g
s
0 0 .464 r
.83147 .29885 m .83259 .29399 L .83117 .28887 L p F P
0 g
s
.054 .151 .648 r
.82646 .26007 m .82564 .26491 L .82865 .26949 L p F P
0 g
s
.1 .199 .681 r
.82564 .26491 m .82646 .26007 L .82297 .25567 L p F P
0 g
s
.52 .607 .88 r
.72914 .3665 m .73779 .36633 L .73484 .36146 L p F P
0 g
s
.52 .607 .88 r
.73484 .36146 m .73127 .36141 L .72914 .3665 L p F P
0 g
s
.541 .613 .874 r
.72218 .36132 m .73127 .36141 L .72914 .3665 L p F P
0 g
s
.409 .567 .899 r
.73501 .14317 m .7301 .14229 L .72717 .13742 L p F P
0 g
s
.902 .983 .725 r
.81942 .34953 m .81386 .35687 L .81385 .3569 L p F P
0 g
s
.886 .991 .766 r
.82129 .34455 m .81942 .34953 L .81386 .35687 L p F P
0 g
s
.841 .955 .611 r
.82308 .34172 m .82433 .34044 L p .81942 .34953 L F P
0 g
s
.841 .955 .611 r
.81942 .34953 m .82129 .34455 L .82308 .34172 L p F P
0 g
s
.572 .67 .905 r
.74887 .37488 m .75622 .37377 L .75334 .36958 L p F P
0 g
s
.572 .67 .905 r
.75334 .36958 m .75083 .36987 L .74887 .37488 L p F P
0 g
s
.591 .669 .894 r
.74072 .37107 m .75083 .36987 L .74887 .37488 L p F P
0 g
s
.69 .836 .954 r
.7744 .37781 m .78683 .3727 L .78871 .3745 L p F P
0 g
s
.672 .813 .951 r
.78683 .3727 m .7744 .37781 L .7716 .37443 L p F P
0 g
s
.981 .796 .582 r
.59345 .11669 m .59594 .12085 L .59443 .12661 L p F P
0 g
s
.944 .811 .683 r
.5951 .11283 m .59345 .11669 L .59594 .12085 L p F P
0 g
s
0 0 .567 r
.61762 .20089 m .61847 .20545 L .62138 .20983 L p F P
0 g
s
0 0 .555 r
.61847 .20545 m .61762 .20089 L .61496 .19644 L p F P
0 g
s
.5 .649 .924 r
.67726 .11225 m .68701 .11218 L .68403 .10778 L p F P
0 g
s
.5 .649 .924 r
.68403 .10778 m .67545 .10789 L .67726 .11225 L p F P
0 g
s
.503 .651 .925 r
.67148 .10797 m .67545 .10789 L .67726 .11225 L p F P
0 g
s
.217 .332 .768 r
.64579 .26277 m .6438 .26127 L .64124 .25502 L p F P
0 g
s
.392 .542 .886 r
.74653 .15433 m .74883 .15486 L .7459 .14972 L p F P
0 g
s
.392 .542 .886 r
.7459 .14972 m .74585 .14971 L .74653 .15433 L p F P
0 g
s
.738 .85 .933 r
.78683 .3727 m .78972 .37116 L .78871 .3745 L closepath p F P
0 g
s
.772 .864 .918 r
.79916 .36578 m .78972 .37116 L .78871 .3745 L p F P
0 g
s
.772 .864 .918 r
.8018 .36759 m .79916 .36578 L p .78871 .3745 L F P
0 g
s
.493 .561 .854 r
.7062 .34907 m .71618 .35044 L p .71715 .35572 L F P
0 g
s
.46 .54 .852 r
.7062 .34907 m .71618 .35044 L .71316 .34482 L p F P
0 g
s
.46 .54 .852 r
.71316 .34482 m .70819 .34396 L .7062 .34907 L p F P
0 g
s
.482 .55 .85 r
.70044 .34269 m .70819 .34396 L .7062 .34907 L p F P
0 g
s
.927 .622 .151 r
.59622 .14151 m .59822 .14579 L .59891 .15083 L p F P
0 g
s
.973 .704 .291 r
.59822 .14579 m .59622 .14151 L .59609 .13629 L p F P
0 g
s
.311 .451 .841 r
.78882 .19587 m .78874 .19115 L .78172 .18806 L p F P
0 g
s
.317 .461 .847 r
.78146 .18338 m .78172 .18806 L .78874 .19115 L p F P
0 g
s
.843 .92 .526 r
.82308 .34172 m .82515 .33773 L .82433 .34044 L closepath p F P
0 g
s
.798 .827 .354 r
.8276 .33135 m .82515 .33773 L .82433 .34044 L p F P
0 g
s
0 0 .269 r
.83131 .31454 m .83132 .31448 L .83128 .31362 L closepath p F P
0 g
s
.386 .465 .819 r
.67635 .31502 m .6754 .31293 L .67686 .31347 L closepath p F P
0 g
s
.404 .477 .822 r
.67635 .31502 m .67686 .31347 L p .68356 .32144 L F P
0 g
s
0 0 .512 r
.61394 .19193 m .61496 .19644 L .61762 .20089 L p F P
0 g
s
0 0 .492 r
.61496 .19644 m .61394 .19193 L .61153 .1874 L p F P
0 g
s
.095 .201 .685 r
.82367 .25084 m .82297 .25567 L .82646 .26007 L p F P
0 g
s
.136 .244 .712 r
.82297 .25567 m .82367 .25084 L .81972 .2466 L p F P
0 g
s
.526 .601 .872 r
.73127 .36141 m .72218 .36132 L .71918 .35595 L p F P
0 g
s
.431 .583 .903 r
.72344 .1369 m .72717 .13742 L .72423 .1326 L p F P
0 g
s
.431 .583 .903 r
.72423 .1326 m .72238 .13235 L .72344 .1369 L p F P
0 g
s
.638 .731 .915 r
.62231 .09814 m .6346 .0945 L .63763 .09857 L p F P
0 g
s
.641 .733 .916 r
.6346 .0945 m .62231 .09814 L .61926 .09417 L p F P
0 g
s
.715 .765 .892 r
.60708 .10028 m .61926 .09417 L .62231 .09814 L p F P
0 g
s
.807 .929 .915 r
.8046 .36535 m .8018 .36759 L .79916 .36578 L p F P
0 g
s
.576 .656 .891 r
.75083 .36987 m .74072 .37107 L .73779 .36633 L p F P
0 g
s
.875 .991 .808 r
.81384 .3569 m .81386 .35687 L .81385 .3569 L closepath p F P
0 g
s
0 0 .101 r
.83132 .31448 m .83131 .31454 L .83067 .32034 L p F P
0 g
s
.836 .987 .867 r
.81132 .35629 m .80643 .3604 L .8046 .36535 L p F P
0 g
s
.836 .987 .867 r
.8046 .36535 m .81384 .3569 L .81132 .35629 L p F P
0 g
s
.807 .929 .915 r
.79916 .36578 m .80643 .3604 L .8046 .36535 L p F P
0 g
s
.872 .982 .839 r
.81386 .35687 m .81384 .3569 L .81132 .35629 L p F P
0 g
s
.872 .982 .839 r
.81132 .35629 m .8154 .352 L .81386 .35687 L p F P
0 g
s
.886 .991 .766 r
.81386 .35687 m .8154 .352 L .82129 .34455 L p F P
0 g
s
0 0 .062 r
.83246 .30971 m .83132 .31448 L .83108 .31901 L p F P
0 g
s
0 0 .101 r
.83067 .32034 m .83108 .31901 L .83132 .31448 L p F P
0 g
s
0 0 .204 r
.83229 .30417 m .83246 .30971 L .83132 .31448 L p F P
0 g
s
.387 .464 .818 r
.67686 .31347 m .6754 .31293 L .67229 .30602 L p F P
0 g
s
0 0 .442 r
.61032 .18293 m .61153 .1874 L .61394 .19193 L p F P
0 g
s
0 0 .41 r
.61153 .1874 m .61032 .18293 L .60819 .17833 L p F P
0 g
s
.304 .439 .832 r
.7927 .19778 m .78882 .19587 L p .79543 .20384 L F P
0 g
s
.287 .429 .831 r
.78882 .19587 m .7927 .19778 L .78975 .19165 L p F P
0 g
s
.287 .429 .831 r
.78975 .19165 m .78874 .19115 L .78882 .19587 L p F P
0 g
s
.467 .54 .848 r
.70819 .34396 m .70044 .34269 L .69819 .33819 L p F P
0 g
s
.132 .246 .716 r
.8203 .2418 m .81972 .2466 L .82367 .25084 L p F P
0 g
s
.166 .281 .738 r
.81972 .2466 m .8203 .2418 L .81592 .23771 L p F P
0 g
s
.217 .332 .768 r
.64124 .25502 m .64135 .25408 L p .64579 .26277 L F P
0 g
s
.188 .308 .756 r
.64124 .25502 m .64063 .25349 L .64135 .25408 L closepath p F P
0 g
s
0 0 .465 r
.83222 .28401 m .83117 .28887 L .83259 .29399 L p F P
0 g
s
0 .01 .54 r
.83117 .28887 m .83222 .28401 L .83022 .27908 L p F P
0 g
s
.98 .703 .317 r
.59386 .13206 m .59609 .13629 L .59622 .14151 L p F P
0 g
s
.996 .765 .452 r
.59609 .13629 m .59386 .13206 L .59443 .12661 L p F P
0 g
s
.845 .811 .817 r
.60177 .09825 m .60448 .10236 L .59682 .11028 L p F P
0 g
s
.796 .792 .849 r
.60401 .09643 m .60177 .09825 L .60448 .10236 L p F P
0 g
s
.796 .792 .849 r
.60448 .10236 m .60708 .10028 L .60401 .09643 L p F P
0 g
s
.181 .307 .758 r
.64135 .25408 m .64063 .25349 L .63746 .24569 L p F P
0 g
s
.582 .705 .927 r
.63763 .09857 m .65 .09632 L p .65276 .10053 L F P
0 g
s
.588 .706 .925 r
.65 .09632 m .63763 .09857 L .6346 .0945 L p F P
0 g
s
.718 .766 .89 r
.61926 .09417 m .60708 .10028 L .60401 .09643 L p F P
0 g
s
.268 .406 .817 r
.79566 .20396 m .79543 .20384 L .79544 .2035 L closepath p F P
0 g
s
.304 .439 .832 r
.79543 .20384 m .79544 .2035 L .7927 .19778 L p F P
0 g
s
.165 .287 .744 r
.81636 .23293 m .81592 .23771 L .8203 .2418 L p F P
0 g
s
.191 .314 .76 r
.81592 .23771 m .81636 .23293 L .81157 .22899 L p F P
0 g
s
.257 .37 .788 r
.66013 .2885 m .66082 .28364 L .65516 .27999 L p F P
0 g
s
.286 .397 .801 r
.66605 .29206 m .66013 .2885 L p .66534 .29694 L F P
0 g
s
.258 .372 .789 r
.66013 .2885 m .66605 .29206 L .66291 .28498 L p F P
0 g
s
.258 .372 .789 r
.66291 .28498 m .66082 .28364 L .66013 .2885 L p F P
0 g
s
0 0 .354 r
.60678 .17391 m .60819 .17833 L .61032 .18293 L p F P
0 g
s
0 0 .304 r
.60819 .17833 m .60678 .17391 L .60495 .16922 L p F P
0 g
s
.294 .406 .806 r
.66917 .29905 m .66534 .29694 L .66608 .29213 L closepath p F P
0 g
s
.286 .397 .801 r
.66534 .29694 m .66608 .29213 L .66605 .29206 L p F P
0 g
s
.313 .416 .807 r
.66917 .29905 m .66534 .29694 L p .67083 .30529 L F P
0 g
s
.231 .361 .79 r
.65577 .27513 m .65516 .27999 L .66082 .28364 L p F P
0 g
s
.279 .374 .782 r
.65039 .27141 m .65577 .27513 L .65516 .27999 L p F P
0 g
s
.472 .628 .921 r
.69376 .11677 m .68998 .11661 L .68701 .11218 L p F P
0 g
s
.254 .394 .811 r
.79566 .20396 m .80134 .20735 L .80132 .21206 L p F P
0 g
s
.244 .39 .812 r
.80134 .20735 m .79566 .20396 L .79544 .2035 L p F P
0 g
s
.373 .527 .881 r
.74883 .15486 m .75555 .15664 L .75625 .16124 L p F P
0 g
s
.369 .528 .884 r
.75555 .15664 m .74883 .15486 L .7459 .14972 L p F P
0 g
s
.189 .328 .775 r
.65091 .26655 m .65039 .27141 L .65577 .27513 L p F P
0 g
s
.25 .355 .775 r
.64579 .26277 m .65091 .26655 L .65039 .27141 L p F P
0 g
s
.377 .524 .877 r
.76478 .16371 m .75625 .16124 L p .76535 .16838 L F P
0 g
s
.361 .518 .878 r
.75625 .16124 m .76478 .16371 L .76186 .15846 L p F P
0 g
s
.361 .518 .878 r
.76186 .15846 m .75555 .15664 L .75625 .16124 L p F P
0 g
s
.32 .423 .811 r
.67229 .30602 m .67083 .30529 L .67117 .30353 L closepath p F P
0 g
s
.313 .416 .807 r
.67083 .30529 m .67117 .30353 L .66917 .29905 L p F P
0 g
s
.231 .366 .794 r
.80132 .21206 m .80686 .21571 L .8067 .22044 L p F P
0 g
s
.23 .371 .799 r
.80134 .20735 m .80132 .21206 L .80686 .21571 L p F P
0 g
s
.195 .323 .768 r
.81188 .22423 m .81157 .22899 L .81636 .23293 L p F P
0 g
s
.212 .343 .779 r
.81157 .22899 m .81188 .22423 L .8067 .22044 L p F P
0 g
s
.244 .39 .812 r
.79544 .2035 m .79532 .19916 L p .80134 .20735 L F P
0 g
s
.269 .417 .826 r
.79544 .2035 m .7927 .19778 L .79532 .19916 L closepath p F P
0 g
s
.903 .818 .754 r
.59682 .11028 m .5951 .11283 L .59202 .10958 L p F P
0 g
s
.903 .818 .754 r
.59202 .10958 m .59427 .10612 L .59682 .11028 L p F P
0 g
s
.845 .811 .817 r
.59682 .11028 m .59427 .10612 L .60177 .09825 L p F P
0 g
s
.212 .346 .783 r
.80686 .21571 m .8067 .22044 L .81188 .22423 L p F P
0 g
s
.331 .486 .863 r
.77373 .17577 m .77064 .17465 L .76771 .16915 L p F P
0 g
s
.163 .309 .766 r
.64621 .25793 m .64579 .26277 L .65091 .26655 L p F P
0 g
s
.217 .332 .768 r
.64135 .25408 m .64621 .25793 L .64579 .26277 L p F P
0 g
s
.443 .603 .914 r
.70964 .12649 m .70853 .12638 L .70558 .12179 L p F P
0 g
s
.404 .477 .822 r
.67686 .31347 m .68488 .31646 L .68356 .32144 L p F P
0 g
s
.355 .463 .832 r
.67826 .30845 m .67686 .31347 L .68488 .31646 L p F P
0 g
s
.387 .464 .818 r
.67229 .30602 m .67826 .30845 L .67686 .31347 L p F P
0 g
s
.503 .654 .927 r
.67545 .10789 m .67148 .10797 L .66849 .10368 L p F P
0 g
s
.135 .287 .756 r
.64164 .24925 m .64135 .25408 L .64621 .25793 L p F P
0 g
s
.181 .307 .758 r
.63746 .24569 m .64164 .24925 L .64135 .25408 L p F P
0 g
s
.48 .572 .871 r
.71918 .35595 m .71715 .35572 L .71787 .35354 L closepath p F P
0 g
s
.493 .561 .854 r
.71618 .35044 m .71787 .35354 L .71715 .35572 L p F P
0 g
s
.054 .226 .724 r
.63746 .24569 m .63709 .24532 L .63706 .24474 L closepath p F P
0 g
s
.032 .206 .711 r
.63429 .23786 m .63304 .23649 L p .63709 .24532 L F P
0 g
s
.032 .206 .711 r
.63709 .24532 m .63706 .24474 L .63429 .23786 L p F P
0 g
s
.942 .802 .676 r
.59345 .11669 m .5951 .11283 L .59202 .10958 L p F P
0 g
s
.993 .756 .464 r
.59197 .12245 m .59443 .12661 L .59386 .13206 L p F P
0 g
s
.981 .796 .582 r
.59443 .12661 m .59197 .12245 L .59345 .11669 L p F P
0 g
s
0 .006 .54 r
.8312 .27423 m .83022 .27908 L .83222 .28401 L p F P
0 g
s
.002 .087 .6 r
.83022 .27908 m .8312 .27423 L .82865 .26949 L p F P
0 g
s
.436 .592 .908 r
.70964 .12649 m .72122 .12782 L .72238 .13235 L p F P
0 g
s
.451 .605 .912 r
.70818 .12205 m .70964 .12649 L .72122 .12782 L p F P
0 g
s
.443 .603 .914 r
.70558 .12179 m .70818 .12205 L .70964 .12649 L p F P
0 g
s
.394 .49 .839 r
.69125 .3241 m .68356 .32144 L p .69075 .32926 L F P
0 g
s
.373 .464 .825 r
.68356 .32144 m .69125 .3241 L .68817 .31772 L p F P
0 g
s
.373 .464 .825 r
.68817 .31772 m .68488 .31646 L .68356 .32144 L p F P
0 g
s
0 .187 .703 r
.63429 .23786 m .63304 .23649 L .63286 .23441 L closepath p F P
0 g
s
0 .162 .686 r
.63111 .23008 m .62908 .22763 L p .63304 .23649 L F P
0 g
s
0 .162 .686 r
.63304 .23649 m .63286 .23441 L .63111 .23008 L p F P
0 g
s
.467 .54 .848 r
.69819 .33819 m .69872 .33684 L p .70819 .34396 L F P
0 g
s
.454 .53 .846 r
.69819 .33819 m .69739 .33658 L .69872 .33684 L closepath p F P
0 g
s
.151 .292 .754 r
.64164 .24925 m .63746 .24569 L .63706 .24474 L p F P
0 g
s
.414 .564 .895 r
.74297 .14474 m .73501 .14317 L p .74585 .14971 L F P
0 g
s
.4 .559 .897 r
.73501 .14317 m .74297 .14474 L .74004 .13982 L p F P
0 g
s
.4 .559 .897 r
.74004 .13982 m .73397 .13863 L .73501 .14317 L p F P
0 g
s
.409 .567 .899 r
.72717 .13742 m .73397 .13863 L .73501 .14317 L p F P
0 g
s
.617 .742 .935 r
.75622 .37377 m .76879 .37084 L .7716 .37443 L p F P
0 g
s
.602 .724 .931 r
.76879 .37084 m .75622 .37377 L .75334 .36958 L p F P
0 g
s
.369 .453 .816 r
.67826 .30845 m .67229 .30602 L .67117 .30353 L p F P
0 g
s
.776 .442 0 r
.60003 .15573 m .60184 .16006 L .60334 .16484 L p F P
0 g
s
.837 .519 0 r
.60184 .16006 m .60003 .15573 L .59891 .15083 L p F P
0 g
s
0 0 .227 r
.83342 .29932 m .83229 .30417 L .83246 .30971 L p F P
0 g
s
0 0 .363 r
.83229 .30417 m .83342 .29932 L .83259 .29399 L p F P
0 g
s
.407 .569 .901 r
.73397 .13863 m .72717 .13742 L .72423 .1326 L p F P
0 g
s
.151 .292 .754 r
.63706 .24474 m .63718 .24054 L p .64164 .24925 L F P
0 g
s
.119 .265 .74 r
.63706 .24474 m .63429 .23786 L .63718 .24054 L closepath p F P
0 g
s
.348 .499 .868 r
.76771 .16915 m .76535 .16838 L .76487 .16388 L closepath p F P
0 g
s
.377 .524 .877 r
.76535 .16838 m .76487 .16388 L .76478 .16371 L p F P
0 g
s
.582 .7 .923 r
.65302 .10048 m .65276 .10053 L .65234 .09954 L closepath p F P
0 g
s
.582 .705 .927 r
.65 .09632 m .65234 .09954 L .65276 .10053 L p F P
0 g
s
0 .142 .676 r
.63111 .23008 m .62908 .22763 L .62859 .22401 L closepath p F P
0 g
s
0 .111 .655 r
.62793 .22236 m .62519 .21875 L p .62908 .22763 L F P
0 g
s
0 .111 .655 r
.62908 .22763 m .62859 .22401 L .62793 .22236 L p F P
0 g
s
.537 .674 .926 r
.65302 .10048 m .66549 .09942 L .66849 .10368 L p F P
0 g
s
.524 .672 .931 r
.66248 .09519 m .66549 .09942 L .65302 .10048 L p F P
0 g
s
.524 .672 .931 r
.65054 .09627 m .66248 .09519 L p .65302 .10048 L F P
0 g
s
.524 .672 .931 r
.65302 .10048 m .65234 .09954 L .65054 .09627 L p F P
0 g
s
.722 .837 .936 r
.78972 .37116 m .78683 .3727 L .78409 .36983 L p F P
0 g
s
.672 .813 .951 r
.7716 .37443 m .78409 .36983 L .78683 .3727 L p F P
0 g
s
.399 .495 .841 r
.69433 .33036 m .69075 .32926 L .69178 .32517 L closepath p F P
0 g
s
.394 .49 .839 r
.69075 .32926 m .69178 .32517 L .69125 .3241 L p F P
0 g
s
.902 .946 .591 r
.82515 .33773 m .82658 .33285 L p .82209 .3424 L F P
0 g
s
.902 .946 .591 r
.82209 .3424 m .82308 .34172 L .82515 .33773 L p F P
0 g
s
.775 .831 .365 r
.82515 .33773 m .82658 .33285 L .82914 .32643 L p F P
0 g
s
.526 .601 .872 r
.71918 .35595 m .73188 .35648 L p .73127 .36141 L F P
0 g
s
.504 .585 .869 r
.72891 .35135 m .73188 .35648 L .71918 .35595 L p F P
0 g
s
.504 .585 .869 r
.71914 .35063 m .72891 .35135 L p .71918 .35595 L F P
0 g
s
.504 .585 .869 r
.71918 .35595 m .71787 .35354 L .71914 .35063 L p F P
0 g
s
.455 .529 .844 r
.69872 .33684 m .69739 .33658 L .69433 .33036 L p F P
0 g
s
0 .079 .634 r
.62519 .21875 m .62793 .22236 L .62475 .21468 L p F P
0 g
s
0 .079 .634 r
.62475 .21468 m .6244 .2142 L .62519 .21875 L p F P
0 g
s
0 .047 .611 r
.62519 .21875 m .6244 .2142 L .62138 .20983 L p F P
0 g
s
.369 .453 .816 r
.67117 .30353 m .67201 .30032 L p .67826 .30845 L F P
0 g
s
.35 .439 .812 r
.67117 .30353 m .66917 .29905 L .67201 .30032 L closepath p F P
0 g
s
.872 .542 .033 r
.59689 .14655 m .59891 .15083 L .60003 .15573 L p F P
0 g
s
.927 .622 .151 r
.59891 .15083 m .59689 .14655 L .59622 .14151 L p F P
0 g
s
0 .081 .599 r
.82918 .26649 m .82865 .26949 L .8312 .27423 L p F P
0 g
s
.054 .151 .648 r
.8279 .26227 m .82646 .26007 L p .82865 .26949 L F P
0 g
s
.054 .151 .648 r
.82865 .26949 m .82918 .26649 L .8279 .26227 L p F P
0 g
s
.656 .791 .947 r
.78409 .36983 m .7716 .37443 L .76879 .37084 L p F P
0 g
s
0 0 0 r
.83108 .31901 m .83067 .32034 L .82914 .32643 L p F P
0 g
s
.467 .624 .92 r
.69376 .11677 m .70262 .11725 L .69966 .11275 L p F P
0 g
s
.467 .624 .92 r
.69966 .11275 m .69209 .11237 L .69376 .11677 L p F P
0 g
s
.472 .628 .921 r
.68701 .11218 m .69209 .11237 L .69376 .11677 L p F P
0 g
s
.722 .837 .936 r
.78409 .36983 m .79147 .36624 L .78972 .37116 L p F P
0 g
s
.751 .888 .941 r
.7965 .36363 m .79147 .36624 L .78972 .37116 L p F P
0 g
s
.751 .888 .941 r
.78972 .37116 m .79916 .36578 L .7965 .36363 L p F P
0 g
s
.975 .785 .584 r
.59076 .11258 m .59345 .11669 L .59197 .12245 L p F P
0 g
s
.942 .802 .676 r
.59202 .10958 m .59076 .11258 L .59345 .11669 L p F P
0 g
s
.576 .656 .891 r
.73779 .36633 m .75044 .36524 L p .75083 .36987 L F P
0 g
s
.543 .654 .908 r
.75044 .36524 m .73779 .36633 L .73484 .36146 L p F P
0 g
s
0 .024 .595 r
.62042 .20532 m .62138 .20983 L .6244 .2142 L p F P
0 g
s
0 0 .567 r
.62138 .20983 m .62042 .20532 L .61762 .20089 L p F P
0 g
s
.541 .682 .93 r
.65234 .09954 m .65 .09632 L .65054 .09627 L closepath p F P
0 g
s
.266 .417 .828 r
.79532 .19916 m .7927 .19778 L .78975 .19165 L p F P
0 g
s
.318 .469 .854 r
.78146 .18338 m .78112 .17871 L .77373 .17577 L p F P
0 g
s
.318 .473 .857 r
.7732 .17114 m .77373 .17577 L .78112 .17871 L p F P
0 g
s
.331 .486 .863 r
.76771 .16915 m .7732 .17114 L .77373 .17577 L p F P
0 g
s
.503 .654 .927 r
.66849 .10368 m .67352 .10355 L .67545 .10789 L p F P
0 g
s
.501 .652 .926 r
.67545 .10789 m .68403 .10778 L .68105 .10342 L p F P
0 g
s
.501 .652 .926 r
.68105 .10342 m .67352 .10355 L .67545 .10789 L p F P
0 g
s
.106 .262 .741 r
.63718 .24054 m .63429 .23786 L .63286 .23441 L p F P
0 g
s
.431 .532 .86 r
.70049 .33177 m .69872 .33684 L .70957 .33903 L p F P
0 g
s
.455 .529 .844 r
.69433 .33036 m .70049 .33177 L .69872 .33684 L p F P
0 g
s
.467 .54 .848 r
.69872 .33684 m .70957 .33903 L .70819 .34396 L p F P
0 g
s
.842 .956 .612 r
.82129 .34455 m .82209 .3424 L .82308 .34172 L closepath p F P
0 g
s
0 0 .538 r
.61649 .19642 m .61762 .20089 L .62042 .20532 L p F P
0 g
s
0 0 .512 r
.61762 .20089 m .61649 .19642 L .61394 .19193 L p F P
0 g
s
.944 .63 .188 r
.59399 .13729 m .59622 .14151 L .59689 .14655 L p F P
0 g
s
.98 .703 .317 r
.59622 .14151 m .59399 .13729 L .59386 .13206 L p F P
0 g
s
.502 .582 .868 r
.71787 .35354 m .71618 .35044 L .71914 .35063 L closepath p F P
0 g
s
.641 .733 .916 r
.61926 .09417 m .63155 .09043 L .6346 .0945 L p F P
0 g
s
.643 .735 .916 r
.63155 .09043 m .61926 .09417 L .6162 .09019 L p F P
0 g
s
.718 .766 .89 r
.60401 .09643 m .6162 .09019 L .61926 .09417 L p F P
0 g
s
.095 .201 .685 r
.82464 .25208 m .82367 .25084 L p .82646 .26007 L F P
0 g
s
.095 .201 .685 r
.82646 .26007 m .82672 .25836 L .82464 .25208 L p F P
0 g
s
.032 .136 .642 r
.8279 .26227 m .82646 .26007 L .82672 .25836 L closepath p F P
0 g
s
0 0 .363 r
.83367 .28913 m .83259 .29399 L .83342 .29932 L p F P
0 g
s
0 0 .465 r
.83259 .29399 m .83367 .28913 L .83222 .28401 L p F P
0 g
s
.326 .486 .865 r
.7732 .17114 m .76771 .16915 L .76487 .16388 L p F P
0 g
s
.389 .544 .888 r
.7459 .14972 m .74585 .14971 L .74583 .14959 L closepath p F P
0 g
s
.414 .564 .895 r
.74585 .14971 m .74583 .14959 L .74297 .14474 L p F P
0 g
s
.349 .439 .813 r
.67201 .30032 m .66917 .29905 L .66608 .29213 L p F P
0 g
s
.365 .53 .886 r
.75474 .15206 m .7459 .14972 L .74583 .14959 L p F P
0 g
s
.369 .528 .884 r
.7459 .14972 m .75474 .15206 L .75555 .15664 L p F P
0 g
s
.381 .545 .892 r
.74583 .14959 m .74297 .14474 L .74484 .14517 L closepath p F P
0 g
s
.365 .53 .886 r
.74583 .14959 m .74484 .14517 L p .75474 .15206 L F P
0 g
s
.106 .262 .741 r
.63286 .23441 m .63282 .2318 L p .63718 .24054 L F P
0 g
s
.071 .232 .724 r
.63286 .23441 m .63111 .23008 L .63282 .2318 L closepath p F P
0 g
s
0 0 .466 r
.61263 .18749 m .61394 .19193 L .61649 .19642 L p F P
0 g
s
0 0 .442 r
.61394 .19193 m .61263 .18749 L .61032 .18293 L p F P
0 g
s
.317 .461 .847 r
.78681 .18572 m .78146 .18338 L p .78874 .19115 L F P
0 g
s
.299 .452 .846 r
.78146 .18338 m .78681 .18572 L .78387 .17992 L p F P
0 g
s
.299 .452 .846 r
.78387 .17992 m .78112 .17871 L .78146 .18338 L p F P
0 g
s
.879 .992 .792 r
.82209 .3424 m .82129 .34455 L .8154 .352 L p F P
0 g
s
.43 .586 .905 r
.72238 .13235 m .72423 .1326 L .72128 .12783 L p F P
0 g
s
.43 .586 .905 r
.72128 .12783 m .72122 .12782 L .72238 .13235 L p F P
0 g
s
0 0 0 r
.83191 .31549 m .83108 .31901 L .83027 .3228 L p F P
0 g
s
0 0 .062 r
.83108 .31901 m .83191 .31549 L .83246 .30971 L p F P
0 g
s
0 0 0 r
.82914 .32643 m .83027 .3228 L .83108 .31901 L p F P
0 g
s
.472 .631 .923 r
.69209 .11237 m .68701 .11218 L .68403 .10778 L p F P
0 g
s
.516 .616 .889 r
.73484 .36146 m .73127 .36141 L .73247 .35747 L closepath p F P
0 g
s
.526 .601 .872 r
.73188 .35648 m .73247 .35747 L .73127 .36141 L p F P
0 g
s
.57 .676 .911 r
.75334 .36958 m .75083 .36987 L .75161 .36699 L closepath p F P
0 g
s
.576 .656 .891 r
.75044 .36524 m .75161 .36699 L .75083 .36987 L p F P
0 g
s
.588 .706 .925 r
.6346 .0945 m .64698 .09218 L .65 .09632 L p F P
0 g
s
.589 .708 .926 r
.64698 .09218 m .6346 .0945 L .63155 .09043 L p F P
0 g
s
.843 .803 .812 r
.5989 .09418 m .60177 .09825 L .59427 .10612 L p F P
0 g
s
.798 .79 .845 r
.60092 .09252 m .5989 .09418 L .60177 .09825 L p F P
0 g
s
.798 .79 .845 r
.60177 .09825 m .60401 .09643 L .60092 .09252 L p F P
0 g
s
.442 .606 .916 r
.70818 .12205 m .70558 .12179 L .70262 .11725 L p F P
0 g
s
.983 .7 .339 r
.59141 .1279 m .59386 .13206 L .59399 .13729 L p F P
0 g
s
.993 .756 .464 r
.59386 .13206 m .59141 .1279 L .59197 .12245 L p F P
0 g
s
.72 .766 .889 r
.6162 .09019 m .60401 .09643 L .60092 .09252 L p F P
0 g
s
.074 .187 .679 r
.82464 .25208 m .82367 .25084 L .82383 .24963 L closepath p F P
0 g
s
.132 .246 .716 r
.82148 .24307 m .8203 .2418 L p .82367 .25084 L F P
0 g
s
.132 .246 .716 r
.82367 .25084 m .82383 .24963 L .82148 .24307 L p F P
0 g
s
0 0 .391 r
.60884 .17854 m .61032 .18293 L .61263 .18749 L p F P
0 g
s
0 0 .354 r
.61032 .18293 m .60884 .17854 L .60678 .17391 L p F P
0 g
s
.79 .92 .925 r
.80643 .3604 m .79916 .36578 L .7965 .36363 L p F P
0 g
s
.054 .227 .724 r
.63282 .2318 m .63111 .23008 L .62859 .22401 L p F P
0 g
s
.504 .658 .929 r
.67352 .10355 m .66849 .10368 L .66549 .09942 L p F P
0 g
s
.438 .534 .857 r
.70819 .34396 m .71316 .34482 L .71014 .33915 L p F P
0 g
s
.438 .534 .857 r
.71014 .33915 m .70957 .33903 L .70819 .34396 L p F P
0 g
s
.439 .518 .843 r
.70049 .33177 m .69433 .33036 L .69178 .32517 L p F P
0 g
s
.282 .43 .833 r
.78975 .19165 m .78874 .19115 L .78868 .18944 L closepath p F P
0 g
s
.317 .461 .847 r
.78874 .19115 m .78868 .18944 L .78681 .18572 L p F P
0 g
s
.899 .807 .748 r
.59427 .10612 m .59202 .10958 L .58892 .10604 L p F P
0 g
s
.899 .807 .748 r
.58892 .10604 m .59149 .10202 L .59427 .10612 L p F P
0 g
s
.843 .803 .812 r
.59427 .10612 m .59149 .10202 L .5989 .09418 L p F P
0 g
s
0 0 .3 r
.60511 .16955 m .60678 .17391 L .60884 .17854 L p F P
0 g
s
0 0 .3 r
.60711 .1742 m .60511 .16955 L p .60687 .1738 L F P
0 g
s
0 0 .3 r
.60884 .17854 m .60711 .1742 L p .60687 .1738 L F P
0 g
s
0 0 .318 r
.60711 .1742 m .60883 .17779 L .60735 .1746 L p F P
0 g
s
.682 .327 0 r
.60511 .16955 m .60711 .1742 L p .60521 .16984 L F P
0 g
s
0 0 .318 r
.60735 .1746 m .60565 .17094 L p .60711 .1742 L F P
0 g
s
.682 .327 0 r
.60321 .16526 m .60511 .16955 L p .60521 .16984 L F P
0 g
s
.667 .34 0 r
.60511 .16955 m .60334 .16484 L p .60502 .16927 L F P
0 g
s
.667 .34 0 r
.60678 .17391 m .60511 .16955 L p .60502 .16927 L F P
0 g
s
.111 .233 .711 r
.82148 .24307 m .8203 .2418 L .82046 .24024 L closepath p F P
0 g
s
.165 .287 .744 r
.81837 .23481 m .81636 .23293 L p .8203 .2418 L F P
0 g
s
.165 .287 .744 r
.8203 .2418 m .82046 .24024 L .81837 .23481 L p F P
0 g
s
0 0 .227 r
.83246 .30971 m .83358 .30486 L .83342 .29932 L p F P
0 g
s
0 0 .047 r
.83358 .30486 m .83246 .30971 L .83191 .31549 L p F P
0 g
s
.503 .58 .865 r
.71914 .35063 m .71618 .35044 L .71316 .34482 L p F P
0 g
s
.86 .976 .86 r
.8154 .352 m .81132 .35629 L .80876 .35519 L p F P
0 g
s
.86 .976 .86 r
.80876 .35519 m .81705 .34707 L .8154 .352 L p F P
0 g
s
.879 .992 .792 r
.82072 .34274 m .82209 .3424 L p .8154 .352 L F P
0 g
s
.879 .992 .792 r
.8154 .352 m .81705 .34707 L .82072 .34274 L p F P
0 g
s
.244 .39 .812 r
.79532 .19916 m .80126 .20265 L .80134 .20735 L p F P
0 g
s
.244 .396 .817 r
.79509 .19449 m .79532 .19916 L .80126 .20265 L p F P
0 g
s
.266 .417 .828 r
.78975 .19165 m .79509 .19449 L .79532 .19916 L p F P
0 g
s
.407 .569 .901 r
.72423 .1326 m .73283 .13411 L .73397 .13863 L p F P
0 g
s
.404 .571 .904 r
.73283 .13411 m .72423 .1326 L .72128 .12783 L p F P
0 g
s
0 0 .461 r
.83283 .28104 m .83222 .28401 L .83367 .28913 L p F P
0 g
s
0 .006 .54 r
.83135 .2746 m .8312 .27423 L p .83222 .28401 L F P
0 g
s
0 .006 .54 r
.83222 .28401 m .83283 .28104 L .83135 .2746 L p F P
0 g
s
.357 .519 .88 r
.75555 .15664 m .76186 .15846 L .75893 .15326 L p F P
0 g
s
.357 .519 .88 r
.75893 .15326 m .75474 .15206 L .75555 .15664 L p F P
0 g
s
.79 .92 .925 r
.7965 .36363 m .80857 .35534 L .80643 .3604 L p F P
0 g
s
.828 .965 .894 r
.80876 .35519 m .80857 .35534 L .80643 .3604 L p F P
0 g
s
.828 .965 .894 r
.80643 .3604 m .81132 .35629 L .80876 .35519 L p F P
0 g
s
.786 .849 .395 r
.83027 .3228 m .82914 .32643 L .82658 .33285 L p F P
0 g
s
.595 .687 .906 r
.76309 .36314 m .76595 .36708 L .75334 .36958 L p F P
0 g
s
.595 .687 .906 r
.75282 .36484 m .76309 .36314 L p .75334 .36958 L F P
0 g
s
.595 .687 .906 r
.75334 .36958 m .75161 .36699 L .75282 .36484 L p F P
0 g
s
.602 .724 .931 r
.75334 .36958 m .76595 .36708 L .76879 .37084 L p F P
0 g
s
.145 .275 .74 r
.81837 .23481 m .81636 .23293 L .81657 .23014 L closepath p F P
0 g
s
.195 .323 .768 r
.8153 .22703 m .81188 .22423 L p .81636 .23293 L F P
0 g
s
.195 .323 .768 r
.81636 .23293 m .81657 .23014 L .8153 .22703 L p F P
0 g
s
0 .112 .629 r
.82672 .25836 m .82704 .25529 L p .82941 .26467 L F P
0 g
s
0 .112 .629 r
.82941 .26467 m .8279 .26227 L .82672 .25836 L p F P
0 g
s
.043 .165 .668 r
.82672 .25836 m .82464 .25208 L .82704 .25529 L closepath p F P
0 g
s
.989 .747 .473 r
.58931 .11834 m .59197 .12245 L .59141 .1279 L p F P
0 g
s
.975 .785 .584 r
.59197 .12245 m .58931 .11834 L .59076 .11258 L p F P
0 g
s
.23 .371 .799 r
.80686 .21571 m .80694 .21098 L .80134 .20735 L p F P
0 g
s
.237 .383 .807 r
.80126 .20265 m .80134 .20735 L .80694 .21098 L p F P
0 g
s
.258 .415 .829 r
.79509 .19449 m .78975 .19165 L .78868 .18944 L p F P
0 g
s
.776 .442 0 r
.60334 .16484 m .60149 .16053 L .60003 .15573 L p F P
0 g
s
.171 .307 .761 r
.81188 .22423 m .8153 .22703 L .81226 .2196 L p F P
0 g
s
.171 .307 .761 r
.81226 .2196 m .8121 .21947 L .81188 .22423 L p F P
0 g
s
.212 .346 .783 r
.81188 .22423 m .8121 .21947 L .80686 .21571 L p F P
0 g
s
0 .113 .629 r
.82918 .26649 m .8279 .26227 L .82941 .26467 L closepath p F P
0 g
s
.04 .164 .668 r
.82704 .25529 m .82464 .25208 L .82383 .24963 L p F P
0 g
s
.349 .439 .813 r
.66608 .29213 m .66609 .29208 L p .67201 .30032 L F P
0 g
s
.329 .424 .808 r
.66608 .29213 m .66605 .29206 L .66609 .29208 L closepath p F P
0 g
s
.241 .371 .795 r
.66291 .28498 m .66082 .28364 L .66104 .28079 L closepath p F P
0 g
s
.231 .361 .79 r
.65978 .27792 m .65577 .27513 L p .66082 .28364 L F P
0 g
s
.231 .361 .79 r
.66082 .28364 m .66104 .28079 L .65978 .27792 L p F P
0 g
s
.211 .352 .789 r
.80694 .21098 m .80686 .21571 L .8121 .21947 L p F P
0 g
s
.329 .424 .808 r
.66609 .29208 m .66605 .29206 L .66291 .28498 L p F P
0 g
s
.195 .335 .779 r
.65577 .27513 m .65978 .27792 L .65664 .27085 L p F P
0 g
s
.195 .335 .779 r
.65664 .27085 m .65599 .27038 L .65577 .27513 L p F P
0 g
s
.189 .328 .775 r
.65577 .27513 m .65599 .27038 L .65091 .26655 L p F P
0 g
s
.04 .164 .668 r
.82383 .24963 m .82411 .24609 L p .82704 .25529 L F P
0 g
s
.083 .213 .702 r
.82383 .24963 m .82148 .24307 L .82411 .24609 L closepath p F P
0 g
s
.349 .439 .813 r
.66609 .29208 m .67295 .2954 L .67201 .30032 L p F P
0 g
s
.287 .41 .813 r
.66702 .28714 m .66609 .29208 L .67295 .2954 L p F P
0 g
s
.329 .424 .808 r
.66291 .28498 m .66702 .28714 L .66609 .29208 L p F P
0 g
s
.94 .793 .671 r
.59076 .11258 m .59202 .10958 L .58892 .10604 L p F P
0 g
s
.167 .321 .776 r
.65104 .26181 m .65091 .26655 L .65599 .27038 L p F P
0 g
s
.163 .309 .766 r
.65091 .26655 m .65104 .26181 L .64621 .25793 L p F P
0 g
s
0 .081 .599 r
.8312 .27423 m .83122 .27407 L .82918 .26649 L p F P
0 g
s
0 .038 .574 r
.82941 .26467 m .82918 .26649 L .83122 .27407 L p F P
0 g
s
.054 .227 .724 r
.62859 .22401 m .62854 .22302 L p .63282 .2318 L F P
0 g
s
.015 .193 .704 r
.62859 .22401 m .62793 .22236 L .62854 .22302 L closepath p F P
0 g
s
.124 .292 .764 r
.64623 .25319 m .64621 .25793 L .65104 .26181 L p F P
0 g
s
.135 .287 .756 r
.64621 .25793 m .64623 .25319 L .64164 .24925 L p F P
0 g
s
.451 .605 .912 r
.71834 .12318 m .70818 .12205 L p .72122 .12782 L F P
0 g
s
.436 .601 .915 r
.70818 .12205 m .71834 .12318 L .71539 .11858 L p F P
0 g
s
.436 .601 .915 r
.71539 .11858 m .70661 .11763 L .70818 .12205 L p F P
0 g
s
.442 .606 .916 r
.70262 .11725 m .70661 .11763 L .70818 .12205 L p F P
0 g
s
.54 .684 .932 r
.65054 .09627 m .65 .09632 L .64698 .09218 L p F P
0 g
s
.311 .433 .824 r
.67295 .2954 m .67201 .30032 L .67917 .30356 L p F P
0 g
s
.369 .453 .816 r
.67201 .30032 m .67917 .30356 L .67826 .30845 L p F P
0 g
s
.543 .654 .908 r
.73484 .36146 m .74753 .36074 L .75044 .36524 L p F P
0 g
s
.542 .629 .887 r
.7446 .35611 m .74753 .36074 L .73484 .36146 L p F P
0 g
s
.542 .629 .887 r
.73294 .35644 m .7446 .35611 L p .73484 .36146 L F P
0 g
s
.542 .629 .887 r
.73484 .36146 m .73247 .35747 L .73294 .35644 L p F P
0 g
s
.078 .257 .745 r
.64155 .24454 m .64164 .24925 L .64623 .25319 L p F P
0 g
s
.151 .292 .754 r
.63718 .24054 m .64155 .24454 L .64164 .24925 L p F P
0 g
s
0 .186 .703 r
.62854 .22302 m .62793 .22236 L .62475 .21468 L p F P
0 g
s
.819 .47 0 r
.59798 .15147 m .60003 .15573 L .60149 .16053 L p F P
0 g
s
.872 .542 .033 r
.60003 .15573 m .59798 .15147 L .59689 .14655 L p F P
0 g
s
.539 .683 .932 r
.65054 .09627 m .66248 .09519 L .65947 .091 L p F P
0 g
s
.539 .683 .932 r
.65947 .091 m .6481 .09207 L .65054 .09627 L p F P
0 g
s
.54 .684 .932 r
.64698 .09218 m .6481 .09207 L .65054 .09627 L p F P
0 g
s
.398 .562 .899 r
.73397 .13863 m .74004 .13982 L .73711 .13494 L p F P
0 g
s
.398 .562 .899 r
.73711 .13494 m .73283 .13411 L .73397 .13863 L p F P
0 g
s
.043 .231 .732 r
.63696 .23585 m .63718 .24054 L .64155 .24454 L p F P
0 g
s
.106 .262 .741 r
.63282 .2318 m .63696 .23585 L .63718 .24054 L p F P
0 g
s
.08 .212 .702 r
.82411 .24609 m .82148 .24307 L .82046 .24024 L p F P
0 g
s
.355 .463 .832 r
.68508 .31133 m .67826 .30845 L p .68488 .31646 L F P
0 g
s
.332 .438 .819 r
.67826 .30845 m .68508 .31133 L .68199 .30485 L p F P
0 g
s
.332 .438 .819 r
.68199 .30485 m .67917 .30356 L .67826 .30845 L p F P
0 g
s
.897 .982 .71 r
.82072 .34274 m .82285 .33964 L .82209 .3424 L closepath p F P
0 g
s
.902 .946 .591 r
.82658 .33285 m .82285 .33964 L .82209 .3424 L p F P
0 g
s
.258 .415 .829 r
.78868 .18944 m .78844 .18649 L p .79509 .19449 L F P
0 g
s
.282 .44 .841 r
.78868 .18944 m .78681 .18572 L .78844 .18649 L closepath p F P
0 g
s
.704 .846 .951 r
.79147 .36624 m .78409 .36983 L .78132 .36674 L p F P
0 g
s
.656 .791 .947 r
.76879 .37084 m .78132 .36674 L .78409 .36983 L p F P
0 g
s
.326 .486 .865 r
.76487 .16388 m .76485 .16373 L p .7732 .17114 L F P
0 g
s
.345 .504 .873 r
.76487 .16388 m .76478 .16371 L .76485 .16373 L closepath p F P
0 g
s
.64 .771 .943 r
.78132 .36674 m .76879 .37084 L .76595 .36708 L p F P
0 g
s
.003 .203 .716 r
.63246 .22713 m .63282 .2318 L .63696 .23585 L p F P
0 g
s
.054 .227 .724 r
.62854 .22302 m .63246 .22713 L .63282 .2318 L p F P
0 g
s
0 0 .53 r
.83135 .2746 m .8312 .27423 L .83122 .27407 L closepath p F P
0 g
s
.08 .212 .702 r
.82046 .24024 m .82063 .23705 L p .82411 .24609 L F P
0 g
s
.119 .256 .731 r
.82046 .24024 m .81837 .23481 L .82063 .23705 L closepath p F P
0 g
s
.341 .506 .876 r
.76485 .16373 m .76478 .16371 L .76186 .15846 L p F P
0 g
s
.439 .518 .843 r
.69178 .32517 m .69207 .32431 L p .70049 .33177 L F P
0 g
s
.424 .508 .84 r
.69178 .32517 m .69125 .3241 L .69207 .32431 L closepath p F P
0 g
s
.482 .571 .868 r
.71914 .35063 m .72891 .35135 L .72592 .34613 L p F P
0 g
s
.482 .571 .868 r
.72592 .34613 m .72092 .3456 L .71914 .35063 L p F P
0 g
s
.503 .58 .865 r
.71316 .34482 m .72092 .3456 L .71914 .35063 L p F P
0 g
s
.326 .486 .865 r
.76485 .16373 m .77257 .16653 L .7732 .17114 L p F P
0 g
s
.323 .489 .868 r
.76405 .15916 m .76485 .16373 L .77257 .16653 L p F P
0 g
s
.341 .506 .876 r
.76186 .15846 m .76405 .15916 L .76485 .16373 L p F P
0 g
s
0 0 .512 r
.83122 .27407 m .83181 .26946 L p .8331 .27919 L F P
0 g
s
0 0 .512 r
.8331 .27919 m .83135 .2746 L .83122 .27407 L p F P
0 g
s
0 .038 .574 r
.83122 .27407 m .83181 .26946 L .82941 .26467 L p F P
0 g
s
.969 .774 .586 r
.5879 .10852 m .59076 .11258 L .58931 .11834 L p F P
0 g
s
.94 .793 .671 r
.58892 .10604 m .5879 .10852 L .59076 .11258 L p F P
0 g
s
0 .171 .697 r
.62803 .21838 m .62854 .22302 L .63246 .22713 L p F P
0 g
s
0 .186 .703 r
.62475 .21468 m .62803 .21838 L .62854 .22302 L p F P
0 g
s
.944 .63 .188 r
.59689 .14655 m .59464 .14234 L .59399 .13729 L p F P
0 g
s
.898 .558 .075 r
.59464 .14234 m .59689 .14655 L .59798 .15147 L p F P
0 g
s
.361 .469 .835 r
.68817 .31772 m .68488 .31646 L .68562 .31244 L closepath p F P
0 g
s
.355 .463 .832 r
.68488 .31646 m .68562 .31244 L .68508 .31133 L p F P
0 g
s
0 0 .513 r
.83283 .28104 m .83135 .2746 L .8331 .27919 L closepath p F P
0 g
s
.378 .546 .895 r
.74484 .14517 m .74297 .14474 L .74004 .13982 L p F P
0 g
s
.426 .507 .839 r
.69207 .32431 m .69125 .3241 L .68817 .31772 L p F P
0 g
s
0 0 .224 r
.83451 .29445 m .83342 .29932 L .83358 .30486 L p F P
0 g
s
0 0 .363 r
.83342 .29932 m .83451 .29445 L .83367 .28913 L p F P
0 g
s
.467 .628 .922 r
.69209 .11237 m .69966 .11275 L .69669 .10829 L p F P
0 g
s
.467 .628 .922 r
.69669 .10829 m .6903 .108 L .69209 .11237 L p F P
0 g
s
.472 .631 .923 r
.68403 .10778 m .6903 .108 L .69209 .11237 L p F P
0 g
s
0 .064 .626 r
.62475 .21468 m .6244 .2142 L .62423 .21348 L closepath p F P
0 g
s
0 .024 .595 r
.62156 .20702 m .62042 .20532 L p .6244 .2142 L F P
0 g
s
0 .024 .595 r
.6244 .2142 m .62423 .21348 L .62156 .20702 L p F P
0 g
s
.594 .686 .906 r
.75161 .36699 m .75044 .36524 L .75282 .36484 L closepath p F P
0 g
s
.502 .655 .928 r
.67352 .10355 m .68105 .10342 L .67806 .0991 L p F P
0 g
s
.502 .655 .928 r
.67806 .0991 m .67145 .09924 L .67352 .10355 L p F P
0 g
s
.504 .658 .929 r
.66549 .09942 m .67145 .09924 L .67352 .10355 L p F P
0 g
s
.643 .735 .916 r
.6162 .09019 m .6285 .08638 L .63155 .09043 L p F P
0 g
s
.644 .737 .916 r
.6285 .08638 m .6162 .09019 L .61312 .08619 L p F P
0 g
s
.72 .766 .889 r
.60092 .09252 m .61312 .08619 L .6162 .09019 L p F P
0 g
s
.116 .255 .731 r
.82063 .23705 m .81837 .23481 L .81657 .23014 L p F P
0 g
s
.306 .412 .807 r
.66702 .28714 m .66291 .28498 L .66104 .28079 L p F P
0 g
s
.883 .955 .609 r
.82806 .32794 m .82658 .33285 L .82285 .33964 L p F P
0 g
s
.786 .849 .395 r
.82973 .32397 m .83027 .3228 L p .82658 .33285 L F P
0 g
s
.786 .849 .395 r
.82658 .33285 m .82806 .32794 L .82973 .32397 L p F P
0 g
s
.439 .518 .843 r
.69207 .32431 m .70169 .32685 L .70049 .33177 L p F P
0 g
s
.397 .508 .854 r
.69351 .31929 m .69207 .32431 L .70169 .32685 L p F P
0 g
s
.426 .507 .839 r
.68817 .31772 m .69351 .31929 L .69207 .32431 L p F P
0 g
s
0 .001 .578 r
.62156 .20702 m .62042 .20532 L .61972 .20275 L closepath p F P
0 g
s
0 0 .538 r
.61838 .1995 m .61649 .19642 L p .62042 .20532 L F P
0 g
s
0 0 .538 r
.62042 .20532 m .61972 .20275 L .61838 .1995 L p F P
0 g
s
.954 .635 .219 r
.59154 .13312 m .59399 .13729 L .59464 .14234 L p F P
0 g
s
.983 .7 .339 r
.59399 .13729 m .59154 .13312 L .59141 .1279 L p F P
0 g
s
0 .165 .693 r
.62803 .21838 m .62475 .21468 L .62423 .21348 L p F P
0 g
s
0 .036 .575 r
.82991 .25992 m .82941 .26467 L .83181 .26946 L p F P
0 g
s
0 .112 .629 r
.82704 .25529 m .82991 .25992 L .82941 .26467 L p F P
0 g
s
.488 .569 .864 r
.72092 .3456 m .71316 .34482 L .71014 .33915 L p F P
0 g
s
.318 .473 .857 r
.78112 .17871 m .78068 .17406 L .7732 .17114 L p F P
0 g
s
.324 .483 .863 r
.77257 .16653 m .7732 .17114 L .78068 .17406 L p F P
0 g
s
.472 .634 .926 r
.6903 .108 m .68403 .10778 L .68105 .10342 L p F P
0 g
s
.441 .609 .919 r
.70661 .11763 m .70262 .11725 L .69966 .11275 L p F P
0 g
s
0 0 0 r
.83027 .3228 m .83057 .32153 L .83191 .31549 L p F P
0 g
s
.707 .705 .174 r
.83301 .31066 m .83191 .31549 L .83057 .32153 L p F P
0 g
s
0 0 .047 r
.83191 .31549 m .83301 .31066 L .83358 .30486 L p F P
0 g
s
0 .165 .693 r
.62423 .21348 m .62367 .20961 L p .62803 .21838 L F P
0 g
s
0 .126 .667 r
.62423 .21348 m .62156 .20702 L .62367 .20961 L closepath p F P
0 g
s
0 0 .512 r
.61649 .19642 m .61838 .1995 L .6152 .19216 L p F P
0 g
s
0 0 .512 r
.6152 .19216 m .61511 .19201 L .61649 .19642 L p F P
0 g
s
0 0 .466 r
.61649 .19642 m .61511 .19201 L .61263 .18749 L p F P
0 g
s
.589 .708 .926 r
.63155 .09043 m .64395 .08806 L .64698 .09218 L p F P
0 g
s
.59 .711 .927 r
.64395 .08806 m .63155 .09043 L .6285 .08638 L p F P
0 g
s
.278 .44 .843 r
.78844 .18649 m .78681 .18572 L .78387 .17992 L p F P
0 g
s
.704 .846 .951 r
.79394 .36131 m .79147 .36624 L p .78132 .36674 L F P
0 g
s
.733 .862 .941 r
.79147 .36624 m .79394 .36131 L .7965 .36363 L closepath p F P
0 g
s
.84 .795 .808 r
.59587 .09015 m .5989 .09418 L .59149 .10202 L p F P
0 g
s
.798 .787 .842 r
.59782 .08854 m .59587 .09015 L .5989 .09418 L p F P
0 g
s
.798 .787 .842 r
.5989 .09418 m .60092 .09252 L .59782 .08854 L p F P
0 g
s
.378 .546 .895 r
.74004 .13982 m .74372 .14066 L .74484 .14517 L p F P
0 g
s
.365 .53 .886 r
.74484 .14517 m .75383 .14749 L .75474 .15206 L p F P
0 g
s
.369 .536 .89 r
.74372 .14066 m .74484 .14517 L .75383 .14749 L p F P
0 g
s
.116 .255 .731 r
.81657 .23014 m .81663 .22818 L p .82063 .23705 L F P
0 g
s
.152 .295 .756 r
.81657 .23014 m .8153 .22703 L .81663 .22818 L closepath p F P
0 g
s
.721 .766 .888 r
.61312 .08619 m .60092 .09252 L .59782 .08854 L p F P
0 g
s
0 0 .461 r
.83367 .28913 m .83401 .28747 L .83283 .28104 L p F P
0 g
s
0 0 .428 r
.8331 .27919 m .83283 .28104 L .83401 .28747 L p F P
0 g
s
.505 .661 .931 r
.67145 .09924 m .66549 .09942 L .66248 .09519 L p F P
0 g
s
0 0 .437 r
.61108 .18312 m .61263 .18749 L .61511 .19201 L p F P
0 g
s
0 0 .391 r
.61263 .18749 m .61108 .18312 L .60884 .17854 L p F P
0 g
s
.54 .626 .886 r
.73247 .35747 m .73188 .35648 L .73294 .35644 L closepath p F P
0 g
s
.983 .696 .357 r
.58876 .12379 m .59141 .1279 L .59154 .13312 L p F P
0 g
s
.989 .747 .473 r
.59141 .1279 m .58876 .12379 L .58931 .11834 L p F P
0 g
s
.428 .588 .908 r
.72128 .12783 m .72122 .12782 L .72117 .12764 L closepath p F P
0 g
s
.451 .605 .912 r
.72122 .12782 m .72117 .12764 L .71834 .12318 L p F P
0 g
s
.404 .571 .904 r
.72128 .12783 m .73156 .12961 L .73283 .13411 L p F P
0 g
s
.402 .573 .907 r
.73156 .12961 m .72128 .12783 L .72117 .12764 L p F P
0 g
s
0 .104 .627 r
.82744 .25055 m .82704 .25529 L .82991 .25992 L p F P
0 g
s
.04 .164 .668 r
.82411 .24609 m .82744 .25055 L .82704 .25529 L p F P
0 g
s
.285 .395 .8 r
.66104 .28079 m .65978 .27792 L .66134 .27881 L closepath p F P
0 g
s
.306 .412 .807 r
.66104 .28079 m .66134 .27881 L p .66702 .28714 L F P
0 g
s
.431 .532 .86 r
.7071 .33335 m .70049 .33177 L p .70957 .33903 L F P
0 g
s
.41 .508 .848 r
.70049 .33177 m .7071 .33335 L .70405 .3275 L p F P
0 g
s
.41 .508 .848 r
.70405 .3275 m .70169 .32685 L .70049 .33177 L p F P
0 g
s
.293 .452 .848 r
.78112 .17871 m .78387 .17992 L .78092 .17417 L p F P
0 g
s
.293 .452 .848 r
.78092 .17417 m .78068 .17406 L .78112 .17871 L p F P
0 g
s
.595 .679 .899 r
.75282 .36484 m .75044 .36524 L .74753 .36074 L p F P
0 g
s
.402 .573 .907 r
.72117 .12764 m .71973 .12339 L p .73156 .12961 L F P
0 g
s
.415 .585 .911 r
.72117 .12764 m .71834 .12318 L .71973 .12339 L closepath p F P
0 g
s
0 0 .356 r
.83401 .28747 m .83367 .28913 L .83451 .29445 L p F P
0 g
s
.894 .796 .744 r
.59149 .10202 m .58892 .10604 L .5858 .10221 L p F P
0 g
s
.894 .796 .744 r
.5858 .10221 m .58849 .09799 L .59149 .10202 L p F P
0 g
s
.84 .795 .808 r
.59149 .10202 m .58849 .09799 L .59587 .09015 L p F P
0 g
s
0 0 .343 r
.60711 .1742 m .60884 .17854 L .61108 .18312 L p F P
0 g
s
.149 .294 .757 r
.81663 .22818 m .8153 .22703 L .81226 .2196 L p F P
0 g
s
.541 .622 .881 r
.73294 .35644 m .73188 .35648 L .72891 .35135 L p F P
0 g
s
.79 .816 .336 r
.82973 .32397 m .83057 .32153 L .83027 .3228 L closepath p F P
0 g
s
0 .115 .661 r
.62367 .20961 m .62156 .20702 L .61972 .20275 L p F P
0 g
s
.79 .873 .909 r
.79394 .36131 m .7965 .36363 L .80857 .35534 L p F P
0 g
s
.408 .496 .838 r
.69351 .31929 m .68817 .31772 L .68562 .31244 L p F P
0 g
s
.724 .378 0 r
.60511 .16955 m .60321 .16526 L .60149 .16053 L p F P
0 g
s
.922 .976 .742 r
.82285 .33964 m .82414 .33479 L p .8186 .34275 L F P
0 g
s
.922 .976 .742 r
.8186 .34275 m .82072 .34274 L .82285 .33964 L p F P
0 g
s
.883 .955 .609 r
.82285 .33964 m .82414 .33479 L .82806 .32794 L p F P
0 g
s
.028 .162 .67 r
.82439 .24136 m .82411 .24609 L .82744 .25055 L p F P
0 g
s
.08 .212 .702 r
.82063 .23705 m .82439 .24136 L .82411 .24609 L p F P
0 g
s
.281 .396 .802 r
.66134 .27881 m .65978 .27792 L .65664 .27085 L p F P
0 g
s
.258 .415 .829 r
.78844 .18649 m .79477 .18983 L .79509 .19449 L p F P
0 g
s
.256 .419 .833 r
.78796 .18186 m .78844 .18649 L .79477 .18983 L p F P
0 g
s
.278 .44 .843 r
.78387 .17992 m .78796 .18186 L .78844 .18649 L p F P
0 g
s
.984 .738 .482 r
.58645 .11428 m .58931 .11834 L .58876 .12379 L p F P
0 g
s
.969 .774 .586 r
.58931 .11834 m .58645 .11428 L .5879 .10852 L p F P
0 g
s
.541 .622 .881 r
.72891 .35135 m .73496 .35134 L .73294 .35644 L p F P
0 g
s
.523 .612 .883 r
.73294 .35644 m .7446 .35611 L .74166 .35138 L p F P
0 g
s
.523 .612 .883 r
.74166 .35138 m .73496 .35134 L .73294 .35644 L p F P
0 g
s
.336 .506 .878 r
.76405 .15916 m .76186 .15846 L .75893 .15326 L p F P
0 g
s
.577 .674 .906 r
.75282 .36484 m .76309 .36314 L .76022 .35906 L p F P
0 g
s
.577 .674 .906 r
.76022 .35906 m .75495 .35974 L .75282 .36484 L p F P
0 g
s
.595 .679 .899 r
.74753 .36074 m .75495 .35974 L .75282 .36484 L p F P
0 g
s
.541 .686 .933 r
.6481 .09207 m .64698 .09218 L .64395 .08806 L p F P
0 g
s
.354 .52 .883 r
.75474 .15206 m .75893 .15326 L .756 .14811 L p F P
0 g
s
.354 .52 .883 r
.756 .14811 m .75383 .14749 L .75474 .15206 L p F P
0 g
s
.771 .41 0 r
.59941 .15628 m .60149 .16053 L .60321 .16526 L p F P
0 g
s
.819 .47 0 r
.60149 .16053 m .59941 .15628 L .59798 .15147 L p F P
0 g
s
.936 .784 .668 r
.5879 .10852 m .58892 .10604 L .5858 .10221 L p F P
0 g
s
.069 .211 .704 r
.8208 .23234 m .82063 .23705 L .82439 .24136 L p F P
0 g
s
.116 .255 .731 r
.81663 .22818 m .8208 .23234 L .82063 .23705 L p F P
0 g
s
.244 .396 .817 r
.80126 .20265 m .8011 .19796 L .79509 .19449 L p F P
0 g
s
.252 .409 .825 r
.79477 .18983 m .79509 .19449 L .8011 .19796 L p F P
0 g
s
.875 .994 .787 r
.81705 .34707 m .8186 .34275 L .82072 .34274 L closepath p F P
0 g
s
.435 .536 .861 r
.71014 .33915 m .70957 .33903 L .70973 .33837 L closepath p F P
0 g
s
.431 .532 .86 r
.70957 .33903 m .70973 .33837 L .7071 .33335 L p F P
0 g
s
0 0 .038 r
.83468 .30001 m .83358 .30486 L .83301 .31066 L p F P
0 g
s
0 0 .224 r
.83358 .30486 m .83468 .30001 L .83451 .29445 L p F P
0 g
s
0 .115 .661 r
.61972 .20275 m .61935 .20082 L p .62367 .20961 L F P
0 g
s
0 .069 .628 r
.61972 .20275 m .61838 .1995 L .61935 .20082 L closepath p F P
0 g
s
.435 .604 .917 r
.70661 .11763 m .71539 .11858 L .71244 .11402 L p F P
0 g
s
.435 .604 .917 r
.71244 .11402 m .70491 .11323 L .70661 .11763 L p F P
0 g
s
.441 .609 .919 r
.69966 .11275 m .70491 .11323 L .70661 .11763 L p F P
0 g
s
.375 .548 .897 r
.74372 .14066 m .74004 .13982 L .73711 .13494 L p F P
0 g
s
.54 .685 .933 r
.6481 .09207 m .65947 .091 L .65645 .08683 L p F P
0 g
s
.54 .685 .933 r
.65645 .08683 m .64552 .0879 L .6481 .09207 L p F P
0 g
s
.541 .686 .933 r
.64395 .08806 m .64552 .0879 L .6481 .09207 L p F P
0 g
s
.103 .252 .733 r
.81668 .22348 m .81663 .22818 L .8208 .23234 L p F P
0 g
s
.149 .294 .757 r
.81226 .2196 m .81668 .22348 L .81663 .22818 L p F P
0 g
s
.237 .383 .807 r
.80625 .20584 m .80126 .20265 L p .80694 .21098 L F P
0 g
s
.214 .369 .804 r
.80126 .20265 m .80625 .20584 L .80327 .19937 L p F P
0 g
s
.214 .369 .804 r
.80327 .19937 m .8011 .19796 L .80126 .20265 L p F P
0 g
s
.64 .771 .943 r
.76595 .36708 m .77853 .36343 L .78132 .36674 L p F P
0 g
s
.625 .753 .939 r
.77853 .36343 m .76595 .36708 L .76309 .36314 L p F P
0 g
s
0 0 .512 r
.83181 .26946 m .83372 .27443 L .8331 .27919 L p F P
0 g
s
0 0 .428 r
.83401 .28747 m .83448 .28433 L .8331 .27919 L p F P
0 g
s
0 0 .424 r
.83372 .27443 m .8331 .27919 L .83448 .28433 L p F P
0 g
s
.488 .569 .864 r
.71014 .33915 m .72208 .34073 L .72092 .3456 L p F P
0 g
s
.473 .558 .861 r
.72208 .34073 m .71014 .33915 L .70973 .33837 L p F P
0 g
s
.851 .492 0 r
.59571 .14726 m .59798 .15147 L .59941 .15628 L p F P
0 g
s
.898 .558 .075 r
.59798 .15147 m .59571 .14726 L .59464 .14234 L p F P
0 g
s
.211 .352 .789 r
.80925 .21266 m .80694 .21098 L p .8121 .21947 L F P
0 g
s
.192 .341 .785 r
.80925 .21266 m .80694 .21098 L .80693 .20734 L closepath p F P
0 g
s
.237 .383 .807 r
.80694 .21098 m .80693 .20734 L .80625 .20584 L p F P
0 g
s
.162 .305 .763 r
.81226 .2196 m .8121 .21947 L .81211 .21924 L closepath p F P
0 g
s
.211 .352 .789 r
.8121 .21947 m .81211 .21924 L .80925 .21266 L p F P
0 g
s
.867 .942 .865 r
.81705 .34707 m .8186 .34275 L p .80865 .35513 L F P
0 g
s
.867 .942 .865 r
.80865 .35513 m .80876 .35519 L .81705 .34707 L p F P
0 g
s
.865 .86 .408 r
.83057 .32153 m .8316 .31672 L p .82873 .32564 L F P
0 g
s
.865 .86 .408 r
.82873 .32564 m .82973 .32397 L .83057 .32153 L p F P
0 g
s
.707 .705 .174 r
.83057 .32153 m .8316 .31672 L .83301 .31066 L p F P
0 g
s
0 0 .317 r
.83448 .28433 m .83401 .28747 L .83476 .29329 L p F P
0 g
s
0 0 .356 r
.83451 .29445 m .83476 .29329 L .83401 .28747 L p F P
0 g
s
.704 .846 .951 r
.78132 .36674 m .7938 .36117 L .79394 .36131 L p F P
0 g
s
.686 .826 .95 r
.7938 .36117 m .78132 .36674 L .77853 .36343 L p F P
0 g
s
.133 .286 .755 r
.81668 .22348 m .81226 .2196 L .81211 .21924 L p F P
0 g
s
.18 .333 .783 r
.65664 .27085 m .65599 .27038 L .65599 .26941 L closepath p F P
0 g
s
.167 .321 .776 r
.65349 .26375 m .65104 .26181 L p .65599 .27038 L F P
0 g
s
.167 .321 .776 r
.65599 .27038 m .65599 .26941 L .65349 .26375 L p F P
0 g
s
.141 .307 .772 r
.65349 .26375 m .65104 .26181 L .65088 .25795 L closepath p F P
0 g
s
.124 .292 .764 r
.65034 .25672 m .64623 .25319 L p .65104 .26181 L F P
0 g
s
.124 .292 .764 r
.65104 .26181 m .65088 .25795 L .65034 .25672 L p F P
0 g
s
.306 .412 .807 r
.66134 .27881 m .66752 .28232 L .66702 .28714 L p F P
0 g
s
.232 .377 .804 r
.66181 .27398 m .66134 .27881 L .66752 .28232 L p F P
0 g
s
.281 .396 .802 r
.65664 .27085 m .66181 .27398 L .66134 .27881 L p F P
0 g
s
.133 .286 .755 r
.81211 .21924 m .81203 .2148 L p .81668 .22348 L F P
0 g
s
.168 .324 .778 r
.81211 .21924 m .80925 .21266 L .81203 .2148 L closepath p F P
0 g
s
.473 .558 .861 r
.70973 .33837 m .71121 .33399 L p .72208 .34073 L F P
0 g
s
.462 .549 .86 r
.70973 .33837 m .7071 .33335 L .71121 .33399 L closepath p F P
0 g
s
.396 .564 .902 r
.73283 .13411 m .73711 .13494 L .73417 .13011 L p F P
0 g
s
.396 .564 .902 r
.73417 .13011 m .73156 .12961 L .73283 .13411 L p F P
0 g
s
.79 .873 .909 r
.80857 .35534 m .80865 .35513 L p .79394 .36131 L F P
0 g
s
.813 .945 .91 r
.80857 .35534 m .80865 .35513 L .80876 .35519 L closepath p F P
0 g
s
.963 .764 .589 r
.58485 .10451 m .5879 .10852 L .58645 .11428 L p F P
0 g
s
.936 .784 .668 r
.5858 .10221 m .58485 .10451 L .5879 .10852 L p F P
0 g
s
.088 .266 .751 r
.64623 .25319 m .65034 .25672 L .64719 .24969 L p F P
0 g
s
.088 .266 .751 r
.64719 .24969 m .64592 .24855 L .64623 .25319 L p F P
0 g
s
.078 .257 .745 r
.64623 .25319 m .64592 .24855 L .64155 .24454 L p F P
0 g
s
.272 .438 .844 r
.78796 .18186 m .78387 .17992 L .78092 .17417 L p F P
0 g
s
0 .053 .619 r
.61935 .20082 m .61838 .1995 L .6152 .19216 L p F P
0 g
s
.287 .41 .813 r
.67295 .2954 m .67346 .29059 L .66702 .28714 L p F P
0 g
s
.262 .401 .815 r
.66752 .28232 m .66702 .28714 L .67346 .29059 L p F P
0 g
s
.041 .24 .74 r
.64112 .23991 m .64155 .24454 L .64592 .24855 L p F P
0 g
s
.043 .231 .732 r
.64155 .24454 m .64112 .23991 L .63696 .23585 L p F P
0 g
s
.867 .942 .865 r
.81826 .34268 m .80981 .35053 L .80865 .35513 L p F P
0 g
s
.867 .942 .865 r
.8186 .34275 m .81826 .34268 L p .80865 .35513 L F P
0 g
s
.826 .928 .9 r
.80614 .35349 m .80981 .35053 L .80865 .35513 L closepath p F P
0 g
s
.79 .873 .909 r
.80865 .35513 m .80614 .35349 L p .79394 .36131 L F P
0 g
s
.916 .569 .112 r
.59218 .13818 m .59464 .14234 L .59571 .14726 L p F P
0 g
s
.954 .635 .219 r
.59464 .14234 m .59218 .13818 L .59154 .13312 L p F P
0 g
s
0 .197 .716 r
.63642 .23124 m .63696 .23585 L .64112 .23991 L p F P
0 g
s
.003 .203 .716 r
.63696 .23585 m .63642 .23124 L .63246 .22713 L p F P
0 g
s
.408 .496 .838 r
.68562 .31244 m .68585 .31158 L p .69351 .31929 L F P
0 g
s
.392 .485 .835 r
.68562 .31244 m .68508 .31133 L .68585 .31158 L closepath p F P
0 g
s
.311 .433 .824 r
.67888 .29837 m .67295 .2954 L p .67917 .30356 L F P
0 g
s
.286 .409 .813 r
.67295 .2954 m .67888 .29837 L .67577 .29184 L p F P
0 g
s
.286 .409 .813 r
.67577 .29184 m .67346 .29059 L .67295 .2954 L p F P
0 g
s
.323 .489 .868 r
.77257 .16653 m .77185 .16194 L .76405 .15916 L p F P
0 g
s
.322 .493 .872 r
.76314 .15461 m .76405 .15916 L .77185 .16194 L p F P
0 g
s
.336 .506 .878 r
.75893 .15326 m .76314 .15461 L .76405 .15916 L p F P
0 g
s
.257 .383 .8 r
.66181 .27398 m .65664 .27085 L .65599 .26941 L p F P
0 g
s
.644 .737 .916 r
.61312 .08619 m .62544 .08233 L .6285 .08638 L p F P
0 g
s
.644 .738 .917 r
.62544 .08233 m .61312 .08619 L .61004 .08217 L p F P
0 g
s
.721 .766 .888 r
.59782 .08854 m .61004 .08217 L .61312 .08619 L p F P
0 g
s
.467 .631 .924 r
.6903 .108 m .69669 .10829 L .69372 .10387 L p F P
0 g
s
.467 .631 .924 r
.69372 .10387 m .68838 .10365 L .6903 .108 L p F P
0 g
s
.472 .634 .926 r
.68105 .10342 m .68838 .10365 L .6903 .108 L p F P
0 g
s
0 .166 .697 r
.63178 .22254 m .63246 .22713 L .63642 .23124 L p F P
0 g
s
0 .171 .697 r
.63246 .22713 m .63178 .22254 L .62803 .21838 L p F P
0 g
s
.44 .611 .921 r
.70491 .11323 m .69966 .11275 L .69669 .10829 L p F P
0 g
s
.471 .637 .928 r
.68838 .10365 m .68105 .10342 L .67806 .0991 L p F P
0 g
s
.793 .853 .4 r
.82806 .32794 m .82873 .32564 L .82973 .32397 L closepath p F P
0 g
s
.393 .485 .834 r
.68585 .31158 m .68508 .31133 L .68199 .30485 L p F P
0 g
s
.311 .433 .824 r
.67917 .30356 m .67959 .29986 L .67888 .29837 L p F P
0 g
s
.319 .441 .828 r
.68199 .30485 m .67917 .30356 L .67959 .29986 L closepath p F P
0 g
s
.503 .658 .93 r
.67145 .09924 m .67806 .0991 L .67506 .09481 L p F P
0 g
s
.503 .658 .93 r
.67506 .09481 m .66925 .09496 L .67145 .09924 L p F P
0 g
s
.505 .661 .931 r
.66248 .09519 m .66925 .09496 L .67145 .09924 L p F P
0 g
s
0 0 .509 r
.83234 .2647 m .83181 .26946 L .83372 .27443 L p F P
0 g
s
0 .036 .575 r
.83181 .26946 m .83234 .2647 L .82991 .25992 L p F P
0 g
s
0 .132 .675 r
.62721 .21383 m .62803 .21838 L .63178 .22254 L p F P
0 g
s
0 .165 .693 r
.62367 .20961 m .62721 .21383 L .62803 .21838 L p F P
0 g
s
.257 .383 .8 r
.65599 .26941 m .65628 .26558 L p .66181 .27398 L F P
0 g
s
.234 .364 .791 r
.65599 .26941 m .65349 .26375 L .65628 .26558 L closepath p F P
0 g
s
.961 .636 .245 r
.58888 .12901 m .59154 .13312 L .59218 .13818 L p F P
0 g
s
.983 .696 .357 r
.59154 .13312 m .58888 .12901 L .58876 .12379 L p F P
0 g
s
0 .093 .649 r
.6227 .20509 m .62367 .20961 L .62721 .21383 L p F P
0 g
s
0 .115 .661 r
.61935 .20082 m .6227 .20509 L .62367 .20961 L p F P
0 g
s
.59 .711 .927 r
.6285 .08638 m .64091 .08396 L .64395 .08806 L p F P
0 g
s
.59 .713 .929 r
.64091 .08396 m .6285 .08638 L .62544 .08233 L p F P
0 g
s
.527 .611 .88 r
.73496 .35134 m .72891 .35135 L .72592 .34613 L p F P
0 g
s
.581 .667 .897 r
.75495 .35974 m .74753 .36074 L .7446 .35611 L p F P
0 g
s
.412 .586 .913 r
.71973 .12339 m .71834 .12318 L .71539 .11858 L p F P
0 g
s
.408 .496 .838 r
.68585 .31158 m .69445 .31441 L .69351 .31929 L p F P
0 g
s
.359 .482 .848 r
.68694 .30663 m .68585 .31158 L .69445 .31441 L p F P
0 g
s
.393 .485 .834 r
.68199 .30485 m .68694 .30663 L .68585 .31158 L p F P
0 g
s
.461 .565 .874 r
.72092 .3456 m .72592 .34613 L .72292 .34085 L p F P
0 g
s
.461 .565 .874 r
.72292 .34085 m .72208 .34073 L .72092 .3456 L p F P
0 g
s
.505 .663 .933 r
.66925 .09496 m .66248 .09519 L .65947 .091 L p F P
0 g
s
0 .049 .616 r
.61822 .19633 m .61935 .20082 L .6227 .20509 L p F P
0 g
s
0 .053 .619 r
.6152 .19216 m .61822 .19633 L .61935 .20082 L p F P
0 g
s
0 0 .214 r
.83476 .29329 m .83451 .29445 L .83468 .30001 L p F P
0 g
s
.324 .483 .863 r
.77799 .16864 m .77257 .16653 L p .78068 .17406 L F P
0 g
s
.306 .474 .863 r
.77257 .16653 m .77799 .16864 L .77506 .16319 L p F P
0 g
s
.306 .474 .863 r
.77506 .16319 m .77185 .16194 L .77257 .16653 L p F P
0 g
s
0 0 .492 r
.6152 .19216 m .61511 .19201 L .61502 .19176 L closepath p F P
0 g
s
0 0 .437 r
.61201 .18484 m .61108 .18312 L p .61511 .19201 L F P
0 g
s
0 0 .437 r
.61511 .19201 m .61502 .19176 L .61201 .18484 L p F P
0 g
s
.981 .69 .373 r
.58591 .11973 m .58876 .12379 L .58888 .12901 L p F P
0 g
s
.984 .738 .482 r
.58876 .12379 m .58591 .11973 L .58645 .11428 L p F P
0 g
s
0 .028 .6 r
.61822 .19633 m .6152 .19216 L .61502 .19176 L p F P
0 g
s
.165 .323 .778 r
.81203 .2148 m .80925 .21266 L .80693 .20734 L p F P
0 g
s
0 .036 .577 r
.83035 .25517 m .82991 .25992 L .83234 .2647 L p F P
0 g
s
0 .104 .627 r
.82991 .25992 m .83035 .25517 L .82744 .25055 L p F P
0 g
s
.369 .536 .89 r
.75383 .14749 m .75281 .14294 L .74372 .14066 L p F P
0 g
s
.378 .548 .896 r
.74249 .13617 m .74372 .14066 L .75281 .14294 L p F P
0 g
s
.375 .548 .897 r
.73711 .13494 m .74249 .13617 L .74372 .14066 L p F P
0 g
s
0 .028 .6 r
.61502 .19176 m .61379 .18756 L p .61822 .19633 L F P
0 g
s
0 0 .557 r
.61502 .19176 m .61201 .18484 L .61379 .18756 L closepath p F P
0 g
s
.332 .507 .88 r
.76314 .15461 m .75893 .15326 L .756 .14811 L p F P
0 g
s
.887 .966 .643 r
.82873 .32564 m .82806 .32794 L .82414 .33479 L p F P
0 g
s
0 0 .413 r
.61201 .18484 m .61108 .18312 L .60991 .18027 L closepath p F P
0 g
s
0 0 .343 r
.60883 .17779 m .60711 .1742 L p .61108 .18312 L F P
0 g
s
0 0 .343 r
.61108 .18312 m .60991 .18027 L .60883 .17779 L p F P
0 g
s
.402 .573 .907 r
.71973 .12339 m .73019 .12513 L .73156 .12961 L p F P
0 g
s
.418 .588 .912 r
.71811 .11898 m .71973 .12339 L .73019 .12513 L p F P
0 g
s
.412 .586 .913 r
.71539 .11858 m .71811 .11898 L .71973 .12339 L p F P
0 g
s
.397 .508 .854 r
.70099 .32158 m .69351 .31929 L p .70169 .32685 L F P
0 g
s
.377 .484 .841 r
.69351 .31929 m .70099 .32158 L .69793 .3156 L p F P
0 g
s
.377 .484 .841 r
.69793 .3156 m .69445 .31441 L .69351 .31929 L p F P
0 g
s
.462 .549 .859 r
.71121 .33399 m .7071 .33335 L .70405 .3275 L p F P
0 g
s
0 0 .038 r
.83301 .31066 m .83409 .30581 L .83468 .30001 L p F P
0 g
s
.718 .716 .189 r
.83409 .30581 m .83301 .31066 L .8316 .31672 L p F P
0 g
s
.227 .364 .794 r
.65628 .26558 m .65349 .26375 L .65088 .25795 L p F P
0 g
s
.682 .327 0 r
.60711 .1742 m .60516 .16993 L .60321 .16526 L p F P
0 g
s
0 0 .318 r
.60565 .17094 m .60516 .16993 L .60711 .1742 L p F P
0 g
s
.288 .453 .851 r
.78092 .17417 m .78068 .17406 L .78062 .17358 L closepath p F P
0 g
s
.324 .483 .863 r
.78068 .17406 m .78062 .17358 L .77799 .16864 L p F P
0 g
s
0 0 .214 r
.83468 .30001 m .83501 .29847 L .83476 .29329 L p F P
0 g
s
0 0 .172 r
.83529 .28967 m .83476 .29329 L .83501 .29847 L p F P
0 g
s
0 0 .317 r
.83476 .29329 m .83529 .28967 L .83448 .28433 L p F P
0 g
s
.978 .729 .49 r
.58341 .11027 m .58645 .11428 L .58591 .11973 L p F P
0 g
s
.963 .764 .589 r
.58645 .11428 m .58341 .11027 L .58485 .10451 L p F P
0 g
s
.542 .688 .934 r
.64552 .0879 m .64395 .08806 L .64091 .08396 L p F P
0 g
s
.372 .549 .899 r
.74249 .13617 m .73711 .13494 L .73417 .13011 L p F P
0 g
s
0 .105 .63 r
.82777 .24581 m .82744 .25055 L .83035 .25517 L p F P
0 g
s
.028 .162 .67 r
.82744 .25055 m .82777 .24581 L .82439 .24136 L p F P
0 g
s
.272 .438 .844 r
.78092 .17417 m .78738 .17725 L .78796 .18186 L p F P
0 g
s
.264 .437 .846 r
.78738 .17725 m .78092 .17417 L .78062 .17358 L p F P
0 g
s
.754 .859 .927 r
.7938 .36117 m .794 .36105 L .79394 .36131 L closepath p F P
0 g
s
.79 .873 .909 r
.80614 .35349 m .794 .36105 L .79394 .36131 L p F P
0 g
s
.73 .361 0 r
.6011 .16103 m .60321 .16526 L .60516 .16993 L p F P
0 g
s
.771 .41 0 r
.60321 .16526 m .6011 .16103 L .59941 .15628 L p F P
0 g
s
.374 .474 .834 r
.68694 .30663 m .68199 .30485 L .67959 .29986 L p F P
0 g
s
.738 .841 .928 r
.794 .36105 m .7938 .36117 L .79106 .35838 L p F P
0 g
s
.686 .826 .95 r
.77853 .36343 m .79106 .35838 L .7938 .36117 L p F P
0 g
s
.738 .841 .928 r
.79106 .35838 m .7949 .35634 L .794 .36105 L p F P
0 g
s
.77 .901 .933 r
.80349 .35144 m .7949 .35634 L .794 .36105 L p F P
0 g
s
.77 .901 .933 r
.794 .36105 m .80614 .35349 L .80349 .35144 L p F P
0 g
s
.264 .437 .846 r
.78062 .17358 m .77996 .16948 L p .78738 .17725 L F P
0 g
s
.288 .461 .857 r
.78062 .17358 m .77799 .16864 L .77996 .16948 L closepath p F P
0 g
s
0 0 .31 r
.83511 .27957 m .83448 .28433 L .83529 .28967 L p F P
0 g
s
0 0 .424 r
.83448 .28433 m .83511 .27957 L .83372 .27443 L p F P
0 g
s
.625 .753 .939 r
.76309 .36314 m .77572 .35993 L .77853 .36343 L p F P
0 g
s
.611 .736 .935 r
.77572 .35993 m .76309 .36314 L .76022 .35906 L p F P
0 g
s
.402 .513 .856 r
.70405 .3275 m .70169 .32685 L .7022 .32393 L closepath p F P
0 g
s
.397 .508 .854 r
.70169 .32685 m .7022 .32393 L .70099 .32158 L p F P
0 g
s
.256 .419 .833 r
.79477 .18983 m .79435 .18519 L .78796 .18186 L p F P
0 g
s
.254 .422 .837 r
.78738 .17725 m .78796 .18186 L .79435 .18519 L p F P
0 g
s
.807 .434 0 r
.59711 .15209 m .59941 .15628 L .6011 .16103 L p F P
0 g
s
.851 .492 0 r
.59941 .15628 m .59711 .15209 L .59571 .14726 L p F P
0 g
s
.165 .323 .778 r
.80693 .20734 m .80688 .20627 L p .81203 .2148 L F P
0 g
s
.197 .357 .798 r
.80693 .20734 m .80625 .20584 L .80688 .20627 L closepath p F P
0 g
s
.024 .164 .672 r
.82461 .23663 m .82439 .24136 L .82777 .24581 L p F P
0 g
s
.069 .211 .704 r
.82439 .24136 m .82461 .23663 L .8208 .23234 L p F P
0 g
s
.54 .687 .934 r
.64552 .0879 m .65645 .08683 L .65342 .08269 L p F P
0 g
s
.54 .687 .934 r
.65342 .08269 m .64281 .08376 L .64552 .0879 L p F P
0 g
s
.542 .688 .934 r
.64091 .08396 m .64281 .08376 L .64552 .0879 L p F P
0 g
s
0 0 .537 r
.61379 .18756 m .61201 .18484 L .60991 .18027 L p F P
0 g
s
.351 .522 .885 r
.75383 .14749 m .756 .14811 L .75307 .14302 L p F P
0 g
s
.351 .522 .885 r
.75307 .14302 m .75281 .14294 L .75383 .14749 L p F P
0 g
s
.434 .606 .92 r
.70491 .11323 m .71244 .11402 L .70947 .10951 L p F P
0 g
s
.434 .606 .92 r
.70947 .10951 m .70309 .10886 L .70491 .11323 L p F P
0 g
s
.44 .611 .921 r
.69669 .10829 m .70309 .10886 L .70491 .11323 L p F P
0 g
s
.922 .976 .742 r
.82414 .33479 m .81875 .34211 L .8186 .34275 L p F P
0 g
s
.906 .983 .775 r
.8255 .32991 m .82414 .33479 L .81875 .34211 L p F P
0 g
s
.887 .966 .643 r
.82752 .3266 m .82873 .32564 L p .82414 .33479 L F P
0 g
s
.887 .966 .643 r
.82414 .33479 m .8255 .32991 L .82752 .3266 L p F P
0 g
s
.875 .508 .022 r
.59324 .14311 m .59571 .14726 L .59711 .15209 L p F P
0 g
s
.916 .569 .112 r
.59571 .14726 m .59324 .14311 L .59218 .13818 L p F P
0 g
s
.67 .805 .947 r
.79106 .35838 m .77853 .36343 L .77572 .35993 L p F P
0 g
s
.252 .409 .825 r
.80029 .19299 m .79477 .18983 L p .8011 .19796 L F P
0 g
s
.23 .396 .822 r
.79477 .18983 m .80029 .19299 L .79734 .1869 L p F P
0 g
s
.23 .396 .822 r
.79734 .1869 m .79435 .18519 L .79477 .18983 L p F P
0 g
s
.192 .356 .8 r
.80688 .20627 m .80625 .20584 L .80327 .19937 L p F P
0 g
s
.227 .364 .794 r
.65088 .25795 m .65091 .25713 L p .65628 .26558 L F P
0 g
s
.202 .344 .784 r
.65088 .25795 m .65034 .25672 L .65091 .25713 L closepath p F P
0 g
s
.065 .213 .707 r
.82089 .22763 m .8208 .23234 L .82461 .23663 L p F P
0 g
s
.103 .252 .733 r
.8208 .23234 m .82089 .22763 L .81668 .22348 L p F P
0 g
s
.527 .611 .88 r
.72592 .34613 m .73622 .34646 L .73496 .35134 L p F P
0 g
s
.512 .6 .879 r
.73622 .34646 m .72592 .34613 L .72292 .34085 L p F P
0 g
s
.439 .614 .923 r
.70309 .10886 m .69669 .10829 L .69372 .10387 L p F P
0 g
s
.195 .343 .786 r
.65091 .25713 m .65034 .25672 L .64719 .24969 L p F P
0 g
s
.208 .369 .805 r
.80327 .19937 m .8011 .19796 L .80089 .19423 L closepath p F P
0 g
s
.252 .409 .825 r
.8011 .19796 m .80089 .19423 L .80029 .19299 L p F P
0 g
s
.471 .637 .928 r
.67806 .0991 m .68633 .09933 L .68838 .10365 L p F P
0 g
s
.471 .64 .93 r
.68633 .09933 m .67806 .0991 L .67506 .09481 L p F P
0 g
s
.1 .254 .736 r
.81663 .2188 m .81668 .22348 L .82089 .22763 L p F P
0 g
s
.133 .286 .755 r
.81203 .2148 m .81663 .2188 L .81668 .22348 L p F P
0 g
s
.504 .607 .889 r
.73496 .35134 m .74166 .35138 L .7387 .34656 L p F P
0 g
s
.504 .607 .889 r
.7387 .34656 m .73622 .34646 L .73496 .35134 L p F P
0 g
s
.961 .636 .245 r
.59218 .13818 m .58952 .13408 L .58888 .12901 L p F P
0 g
s
.929 .576 .144 r
.58952 .13408 m .59218 .13818 L .59324 .14311 L p F P
0 g
s
.644 .738 .917 r
.61004 .08217 m .62237 .07828 L .62544 .08233 L p F P
0 g
s
.394 .566 .904 r
.73156 .12961 m .73417 .13011 L .73123 .12533 L p F P
0 g
s
.394 .566 .904 r
.73123 .12533 m .73019 .12513 L .73156 .12961 L p F P
0 g
s
.891 .98 .815 r
.81826 .34268 m .81875 .34211 L .8186 .34275 L closepath p F P
0 g
s
.165 .323 .778 r
.80688 .20627 m .81186 .21014 L .81203 .2148 L p F P
0 g
s
.154 .321 .781 r
.80657 .20164 m .80688 .20627 L .81186 .21014 L p F P
0 g
s
.192 .356 .8 r
.80327 .19937 m .80657 .20164 L .80688 .20627 L p F P
0 g
s
.56 .669 .911 r
.75495 .35974 m .76022 .35906 L .75733 .35484 L p F P
0 g
s
.56 .669 .911 r
.75733 .35484 m .75596 .35497 L .75495 .35974 L p F P
0 g
s
.581 .667 .897 r
.7446 .35611 m .75596 .35497 L .75495 .35974 L p F P
0 g
s
.129 .29 .76 r
.81186 .21014 m .81203 .2148 L .81663 .2188 L p F P
0 g
s
.894 .936 .564 r
.82752 .3266 m .82926 .32309 L .82873 .32564 L closepath p F P
0 g
s
.865 .86 .408 r
.8316 .31672 m .82926 .32309 L .82873 .32564 L p F P
0 g
s
0 0 .031 r
.83501 .29847 m .83468 .30001 L .83409 .30581 L p F P
0 g
s
0 0 .509 r
.83372 .27443 m .83428 .26966 L .83234 .2647 L p F P
0 g
s
0 0 .422 r
.83428 .26966 m .83372 .27443 L .83511 .27957 L p F P
0 g
s
.566 .655 .896 r
.75596 .35497 m .7446 .35611 L .74166 .35138 L p F P
0 g
s
.473 .558 .861 r
.71121 .33399 m .71991 .33544 L p .72208 .34073 L F P
0 g
s
.437 .538 .862 r
.71121 .33399 m .71991 .33544 L .71689 .32998 L p F P
0 g
s
.437 .538 .862 r
.71689 .32998 m .7124 .32908 L .71121 .33399 L p F P
0 g
s
.462 .549 .859 r
.70405 .3275 m .7124 .32908 L .71121 .33399 L p F P
0 g
s
.357 .461 .83 r
.67959 .29986 m .67888 .29837 L .6798 .29874 L closepath p F P
0 g
s
.374 .474 .834 r
.67959 .29986 m .6798 .29874 L p .68694 .30663 L F P
0 g
s
.446 .538 .857 r
.7124 .32908 m .70405 .3275 L .7022 .32393 L p F P
0 g
s
.41 .589 .915 r
.71811 .11898 m .71539 .11858 L .71244 .11402 L p F P
0 g
s
.467 .633 .927 r
.68838 .10365 m .69372 .10387 L .69074 .0995 L p F P
0 g
s
.467 .633 .927 r
.69074 .0995 m .68633 .09933 L .68838 .10365 L p F P
0 g
s
.15 .324 .784 r
.65087 .2524 m .65091 .25713 L .65631 .26085 L p F P
0 g
s
.195 .343 .786 r
.64719 .24969 m .65087 .2524 L .65091 .25713 L p F P
0 g
s
.227 .364 .794 r
.65091 .25713 m .65631 .26085 L .65628 .26558 L p F P
0 g
s
.063 .26 .752 r
.64719 .24969 m .64592 .24855 L .64565 .24632 L closepath p F P
0 g
s
.041 .24 .74 r
.64403 .24272 m .64112 .23991 L p .64592 .24855 L F P
0 g
s
.041 .24 .74 r
.64592 .24855 m .64565 .24632 L .64403 .24272 L p F P
0 g
s
.257 .383 .8 r
.65628 .26558 m .66189 .26925 L .66181 .27398 L p F P
0 g
s
.17 .34 .792 r
.65631 .26085 m .65628 .26558 L .66189 .26925 L p F P
0 g
s
.851 .869 .424 r
.83263 .3119 m .8316 .31672 L .82926 .32309 L p F P
0 g
s
.718 .716 .189 r
.8316 .31672 m .83263 .3119 L .83409 .30581 L p F P
0 g
s
0 0 .537 r
.60991 .18027 m .6094 .17877 L p .61379 .18756 L F P
0 g
s
0 0 .482 r
.60991 .18027 m .60883 .17779 L .6094 .17877 L closepath p F P
0 g
s
.503 .661 .932 r
.66925 .09496 m .67506 .09481 L .67206 .09057 L p F P
0 g
s
.503 .661 .932 r
.67206 .09057 m .66691 .09072 L .66925 .09496 L p F P
0 g
s
.505 .663 .933 r
.65947 .091 m .66691 .09072 L .66925 .09496 L p F P
0 g
s
0 .212 .726 r
.64112 .23991 m .64403 .24272 L .64087 .23584 L p F P
0 g
s
0 .212 .726 r
.64087 .23584 m .6404 .23537 L .64112 .23991 L p F P
0 g
s
0 .197 .716 r
.64112 .23991 m .6404 .23537 L .63642 .23124 L p F P
0 g
s
.322 .493 .872 r
.77185 .16194 m .77102 .15736 L .76314 .15461 L p F P
0 g
s
.332 .505 .878 r
.76212 .15008 m .76314 .15461 L .77102 .15736 L p F P
0 g
s
.332 .507 .88 r
.756 .14811 m .76212 .15008 L .76314 .15461 L p F P
0 g
s
.963 .636 .268 r
.58603 .12496 m .58888 .12901 L .58952 .13408 L p F P
0 g
s
.981 .69 .373 r
.58888 .12901 m .58603 .12496 L .58591 .11973 L p F P
0 g
s
.811 .919 .91 r
.80981 .35053 m .80614 .35349 L .80349 .35144 L p F P
0 g
s
.232 .377 .804 r
.66752 .28232 m .66764 .2776 L .66181 .27398 L p F P
0 g
s
.204 .366 .804 r
.66189 .26925 m .66181 .27398 L .66764 .2776 L p F P
0 g
s
.59 .713 .929 r
.62544 .08233 m .63786 .07988 L .64091 .08396 L p F P
0 g
s
.59 .715 .93 r
.63786 .07988 m .62544 .08233 L .62237 .07828 L p F P
0 g
s
.327 .507 .882 r
.76212 .15008 m .756 .14811 L .75307 .14302 L p F P
0 g
s
.883 .97 .839 r
.81875 .34211 m .81826 .34268 L .81572 .34176 L p F P
0 g
s
.883 .97 .839 r
.81572 .34176 m .81981 .33733 L .81875 .34211 L p F P
0 g
s
.906 .983 .775 r
.81875 .34211 m .81981 .33733 L .8255 .32991 L p F P
0 g
s
0 .18 .707 r
.63557 .22672 m .63642 .23124 L .6404 .23537 L p F P
0 g
s
0 .166 .697 r
.63642 .23124 m .63557 .22672 L .63178 .22254 L p F P
0 g
s
.506 .666 .935 r
.66691 .09072 m .65947 .091 L .65645 .08683 L p F P
0 g
s
.848 .975 .872 r
.80981 .35053 m .81826 .34268 L .81572 .34176 L p F P
0 g
s
.356 .461 .83 r
.6798 .29874 m .67888 .29837 L .67577 .29184 L p F P
0 g
s
.262 .401 .815 r
.67266 .28532 m .66752 .28232 L p .67346 .29059 L F P
0 g
s
.233 .378 .804 r
.66752 .28232 m .67266 .28532 L .66953 .27878 L p F P
0 g
s
.233 .378 .804 r
.66953 .27878 m .66764 .2776 L .66752 .28232 L p F P
0 g
s
.811 .919 .91 r
.80349 .35144 m .81115 .34567 L .80981 .35053 L p F P
0 g
s
.848 .975 .872 r
.81572 .34176 m .81115 .34567 L .80981 .35053 L p F P
0 g
s
0 .129 .675 r
.63082 .21804 m .63178 .22254 L .63557 .22672 L p F P
0 g
s
0 .132 .675 r
.63178 .22254 m .63082 .21804 L .62721 .21383 L p F P
0 g
s
.271 .41 .82 r
.67577 .29184 m .67346 .29059 L .67359 .28729 L closepath p F P
0 g
s
.262 .401 .815 r
.67346 .29059 m .67359 .28729 L .67266 .28532 L p F P
0 g
s
0 .092 .649 r
.62611 .20935 m .62721 .21383 L .63082 .21804 L p F P
0 g
s
0 .093 .649 r
.62721 .21383 m .62611 .20935 L .6227 .20509 L p F P
0 g
s
0 0 .455 r
.6094 .17877 m .60883 .17779 L .60565 .17094 L p F P
0 g
s
.284 .461 .859 r
.77996 .16948 m .77799 .16864 L .77506 .16319 L p F P
0 g
s
0 .052 .619 r
.62145 .20063 m .6227 .20509 L .62611 .20935 L p F P
0 g
s
0 .049 .616 r
.6227 .20509 m .62145 .20063 L .61822 .19633 L p F P
0 g
s
.977 .684 .387 r
.58286 .11572 m .58591 .11973 L .58603 .12496 L p F P
0 g
s
.978 .729 .49 r
.58591 .11973 m .58286 .11572 L .58341 .11027 L p F P
0 g
s
0 0 .51 r
.83281 .25995 m .83234 .2647 L .83428 .26966 L p F P
0 g
s
0 .036 .577 r
.83234 .2647 m .83281 .25995 L .83035 .25517 L p F P
0 g
s
.374 .474 .834 r
.6798 .29874 m .68757 .30181 L .68694 .30663 L p F P
0 g
s
.312 .448 .837 r
.68052 .29387 m .6798 .29874 L .68757 .30181 L p F P
0 g
s
.356 .461 .83 r
.67577 .29184 m .68052 .29387 L .6798 .29874 L p F P
0 g
s
0 .006 .582 r
.61682 .19191 m .61822 .19633 L .62145 .20063 L p F P
0 g
s
0 .028 .6 r
.61379 .18756 m .61682 .19191 L .61822 .19633 L p F P
0 g
s
.372 .549 .899 r
.73417 .13011 m .74114 .13169 L .74249 .13617 L p F P
0 g
s
.368 .551 .902 r
.74114 .13169 m .73417 .13011 L .73123 .12533 L p F P
0 g
s
0 0 .536 r
.61223 .18318 m .61379 .18756 L .61682 .19191 L p F P
0 g
s
0 0 .537 r
.6094 .17877 m .61223 .18318 L .61379 .18756 L p F P
0 g
s
0 0 .031 r
.83409 .30581 m .83471 .30292 L .83501 .29847 L p F P
0 g
s
0 0 .172 r
.83501 .29847 m .83548 .29522 L .83529 .28967 L p F P
0 g
s
0 0 0 r
.83548 .29522 m .83501 .29847 L .83471 .30292 L p F P
0 g
s
.165 .328 .783 r
.65087 .2524 m .64719 .24969 L .64565 .24632 L p F P
0 g
s
.301 .475 .865 r
.77185 .16194 m .77506 .16319 L .77213 .15779 L p F P
0 g
s
.301 .475 .865 r
.77213 .15779 m .77102 .15736 L .77185 .16194 L p F P
0 g
s
.182 .352 .799 r
.80657 .20164 m .80327 .19937 L .80089 .19423 L p F P
0 g
s
.446 .538 .857 r
.7022 .32393 m .70274 .32196 L p .7124 .32908 L F P
0 g
s
.434 .529 .855 r
.7022 .32393 m .70099 .32158 L .70274 .32196 L closepath p F P
0 g
s
.378 .548 .896 r
.75013 .13807 m .74249 .13617 L p .75281 .14294 L F P
0 g
s
.36 .541 .897 r
.74249 .13617 m .75013 .13807 L .7472 .13319 L p F P
0 g
s
.36 .541 .897 r
.7472 .13319 m .74114 .13169 L .74249 .13617 L p F P
0 g
s
0 0 .48 r
.60766 .17443 m .6094 .17877 L .61223 .18318 L p F P
0 g
s
0 0 .455 r
.60565 .17094 m .60766 .17443 L .6094 .17877 L p F P
0 g
s
0 0 .159 r
.83593 .28492 m .83529 .28967 L .83548 .29522 L p F P
0 g
s
0 0 .31 r
.83529 .28967 m .83593 .28492 L .83511 .27957 L p F P
0 g
s
.418 .588 .912 r
.72828 .12063 m .71811 .11898 L p .73019 .12513 L F P
0 g
s
.401 .582 .914 r
.71811 .11898 m .72828 .12063 L .72533 .11602 L p F P
0 g
s
.401 .582 .914 r
.72533 .11602 m .71638 .11459 L .71811 .11898 L p F P
0 g
s
.41 .589 .915 r
.71244 .11402 m .71638 .11459 L .71811 .11898 L p F P
0 g
s
.34 .459 .835 r
.68694 .30663 m .69485 .30961 L .69177 .30353 L p F P
0 g
s
.34 .459 .835 r
.69177 .30353 m .68757 .30181 L .68694 .30663 L p F P
0 g
s
.359 .482 .848 r
.69485 .30961 m .68694 .30663 L p .69445 .31441 L F P
0 g
s
.542 .691 .936 r
.64281 .08376 m .64091 .08396 L .63786 .07988 L p F P
0 g
s
.458 .568 .878 r
.72292 .34085 m .72208 .34073 L .72228 .33971 L closepath p F P
0 g
s
.473 .558 .861 r
.71991 .33544 m .72228 .33971 L .72208 .34073 L p F P
0 g
s
.661 .285 0 r
.60565 .17094 m .60516 .16993 L .60416 .16795 L closepath p F P
0 g
s
.73 .361 0 r
.60247 .16434 m .6011 .16103 L p .60516 .16993 L F P
0 g
s
.73 .361 0 r
.60516 .16993 m .60416 .16795 L .60247 .16434 L p F P
0 g
s
.611 .736 .935 r
.76022 .35906 m .77289 .35625 L .77572 .35993 L p F P
0 g
s
.597 .721 .931 r
.77289 .35625 m .76022 .35906 L .75733 .35484 L p F P
0 g
s
0 .045 .585 r
.83072 .25042 m .83035 .25517 L .83281 .25995 L p F P
0 g
s
0 .105 .63 r
.83035 .25517 m .83072 .25042 L .82777 .24581 L p F P
0 g
s
.752 .369 0 r
.6011 .16103 m .60247 .16434 L .59929 .15809 L p F P
0 g
s
.752 .369 0 r
.59929 .15809 m .59877 .15684 L .6011 .16103 L p F P
0 g
s
.807 .434 0 r
.6011 .16103 m .59877 .15684 L .59711 .15209 L p F P
0 g
s
.491 .586 .877 r
.73275 .3366 m .73573 .34163 L .72292 .34085 L p F P
0 g
s
.491 .586 .877 r
.72354 .33575 m .73275 .3366 L p .72292 .34085 L F P
0 g
s
.491 .586 .877 r
.72292 .34085 m .72228 .33971 L .72354 .33575 L p F P
0 g
s
.512 .6 .879 r
.72292 .34085 m .73573 .34163 L p .73622 .34646 L F P
0 g
s
.138 .305 .771 r
.64565 .24632 m .64403 .24272 L .64554 .24391 L closepath p F P
0 g
s
.165 .328 .783 r
.64565 .24632 m .64554 .24391 L p .65087 .2524 L F P
0 g
s
.264 .437 .846 r
.77996 .16948 m .78671 .17266 L .78738 .17725 L p F P
0 g
s
.263 .442 .851 r
.77912 .16492 m .77996 .16948 L .78671 .17266 L p F P
0 g
s
.284 .461 .859 r
.77506 .16319 m .77912 .16492 L .77996 .16948 L p F P
0 g
s
.933 .947 .612 r
.82926 .32309 m .8302 .31831 L p .82624 .32724 L F P
0 g
s
.933 .947 .612 r
.82624 .32724 m .82752 .3266 L .82926 .32309 L p F P
0 g
s
.851 .869 .424 r
.82926 .32309 m .8302 .31831 L .83263 .3119 L p F P
0 g
s
.434 .528 .854 r
.70274 .32196 m .70099 .32158 L .69793 .3156 L p F P
0 g
s
.366 .488 .851 r
.69793 .3156 m .69445 .31441 L .69495 .3098 L closepath p F P
0 g
s
.359 .482 .848 r
.69445 .31441 m .69495 .3098 L .69485 .30961 L p F P
0 g
s
.723 .832 .932 r
.7949 .35634 m .79106 .35838 L .7883 .35537 L p F P
0 g
s
.67 .805 .947 r
.77572 .35993 m .7883 .35537 L .79106 .35838 L p F P
0 g
s
.335 .45 .829 r
.68052 .29387 m .67577 .29184 L .67359 .28729 L p F P
0 g
s
.738 .74 .222 r
.83471 .30292 m .83409 .30581 L .83263 .3119 L p F P
0 g
s
.842 .462 0 r
.59462 .14795 m .59711 .15209 L .59877 .15684 L p F P
0 g
s
.875 .508 .022 r
.59711 .15209 m .59462 .14795 L .59324 .14311 L p F P
0 g
s
.54 .689 .936 r
.64281 .08376 m .65342 .08269 L .65038 .07858 L p F P
0 g
s
.54 .689 .936 r
.65038 .07858 m .63996 .07965 L .64281 .08376 L p F P
0 g
s
.542 .691 .936 r
.63786 .07988 m .63996 .07965 L .64281 .08376 L p F P
0 g
s
0 0 .422 r
.60766 .17443 m .60565 .17094 L .60416 .16795 L p F P
0 g
s
0 .11 .635 r
.82803 .24107 m .82777 .24581 L .83072 .25042 L p F P
0 g
s
.024 .164 .672 r
.82777 .24581 m .82803 .24107 L .82461 .23663 L p F P
0 g
s
.488 .582 .875 r
.72228 .33971 m .71991 .33544 L .72354 .33575 L closepath p F P
0 g
s
.566 .655 .896 r
.74166 .35138 m .75442 .35048 L p .75596 .35497 L F P
0 g
s
.533 .653 .912 r
.75442 .35048 m .74166 .35138 L .7387 .34656 L p F P
0 g
s
.654 .786 .944 r
.7883 .35537 m .77572 .35993 L .77289 .35625 L p F P
0 g
s
.439 .614 .923 r
.69372 .10387 m .70115 .10451 L .70309 .10886 L p F P
0 g
s
.438 .617 .926 r
.70115 .10451 m .69372 .10387 L .69074 .0995 L p F P
0 g
s
.893 .519 .057 r
.59056 .13901 m .59324 .14311 L .59462 .14795 L p F P
0 g
s
.929 .576 .144 r
.59324 .14311 m .59056 .13901 L .58952 .13408 L p F P
0 g
s
.254 .422 .837 r
.79435 .18519 m .79384 .18056 L .78738 .17725 L p F P
0 g
s
.26 .433 .844 r
.78671 .17266 m .78738 .17725 L .79384 .18056 L p F P
0 g
s
.432 .609 .922 r
.70309 .10886 m .70947 .10951 L .70651 .10505 L p F P
0 g
s
.432 .609 .922 r
.70651 .10505 m .70115 .10451 L .70309 .10886 L p F P
0 g
s
.471 .64 .93 r
.67506 .09481 m .68414 .09504 L .68633 .09933 L p F P
0 g
s
.47 .643 .932 r
.68414 .09504 m .67506 .09481 L .67206 .09057 L p F P
0 g
s
.182 .352 .799 r
.80089 .19423 m .80081 .1933 L p .80657 .20164 L F P
0 g
s
.213 .383 .816 r
.80089 .19423 m .80029 .19299 L .80081 .1933 L closepath p F P
0 g
s
0 0 .306 r
.83569 .27481 m .83511 .27957 L .83593 .28492 L p F P
0 g
s
0 0 .422 r
.83511 .27957 m .83569 .27481 L .83428 .26966 L p F P
0 g
s
.347 .523 .888 r
.75307 .14302 m .75281 .14294 L .75264 .14229 L closepath p F P
0 g
s
.378 .548 .896 r
.75281 .14294 m .75264 .14229 L .75013 .13807 L p F P
0 g
s
.125 .303 .773 r
.64554 .24391 m .64403 .24272 L .64087 .23584 L p F P
0 g
s
.723 .832 .932 r
.7883 .35537 m .79622 .35149 L .7949 .35634 L p F P
0 g
s
.752 .877 .936 r
.8008 .3491 m .79622 .35149 L .7949 .35634 L p F P
0 g
s
.752 .877 .936 r
.7949 .35634 m .80349 .35144 L .8008 .3491 L p F P
0 g
s
.887 .967 .644 r
.8255 .32991 m .82624 .32724 L .82752 .3266 L closepath p F P
0 g
s
.327 .507 .882 r
.75307 .14302 m .76099 .14556 L .76212 .15008 L p F P
0 g
s
.322 .508 .885 r
.76099 .14556 m .75307 .14302 L .75264 .14229 L p F P
0 g
s
.408 .591 .918 r
.71638 .11459 m .71244 .11402 L .70947 .10951 L p F P
0 g
s
.022 .168 .678 r
.82474 .23191 m .82461 .23663 L .82803 .24107 L p F P
0 g
s
.065 .213 .707 r
.82461 .23663 m .82474 .23191 L .82089 .22763 L p F P
0 g
s
.963 .636 .268 r
.58952 .13408 m .58666 .13002 L .58603 .12496 L p F P
0 g
s
.937 .58 .172 r
.58666 .13002 m .58952 .13408 L .59056 .13901 L p F P
0 g
s
.446 .538 .857 r
.70274 .32196 m .7131 .3243 L .7124 .32908 L p F P
0 g
s
.405 .529 .869 r
.70378 .31705 m .70274 .32196 L .7131 .3243 L p F P
0 g
s
.434 .528 .854 r
.69793 .3156 m .70378 .31705 L .70274 .32196 L p F P
0 g
s
.207 .383 .818 r
.80081 .1933 m .80029 .19299 L .79734 .1869 L p F P
0 g
s
.222 .394 .823 r
.79435 .18519 m .79734 .1869 L .79437 .18087 L p F P
0 g
s
.222 .394 .823 r
.79437 .18087 m .79384 .18056 L .79435 .18519 L p F P
0 g
s
.278 .461 .861 r
.77912 .16492 m .77506 .16319 L .77213 .15779 L p F P
0 g
s
0 0 .422 r
.60416 .16795 m .60313 .16567 L p .60766 .17443 L F P
0 g
s
0 0 .349 r
.60416 .16795 m .60247 .16434 L .60313 .16567 L closepath p F P
0 g
s
.322 .508 .885 r
.75264 .14229 m .75153 .13846 L p .76099 .14556 L F P
0 g
s
.342 .526 .892 r
.75264 .14229 m .75013 .13807 L .75153 .13846 L closepath p F P
0 g
s
.391 .568 .907 r
.73123 .12533 m .73019 .12513 L .7291 .12192 L closepath p F P
0 g
s
.418 .588 .912 r
.73019 .12513 m .7291 .12192 L .72828 .12063 L p F P
0 g
s
.066 .22 .714 r
.8209 .22293 m .82089 .22763 L .82474 .23191 L p F P
0 g
s
.1 .254 .736 r
.82089 .22763 m .8209 .22293 L .81663 .2188 L p F P
0 g
s
.59 .715 .93 r
.62237 .07828 m .6348 .07582 L .63786 .07988 L p F P
0 g
s
.506 .666 .935 r
.65645 .08683 m .66442 .08651 L .66691 .09072 L p F P
0 g
s
.505 .669 .936 r
.66442 .08651 m .65645 .08683 L .65342 .08269 L p F P
0 g
s
.335 .45 .829 r
.67359 .28729 m .67377 .28583 L p .68052 .29387 L F P
0 g
s
.317 .436 .824 r
.67359 .28729 m .67266 .28532 L .67377 .28583 L closepath p F P
0 g
s
.182 .352 .799 r
.80081 .1933 m .80617 .19701 L .80657 .20164 L p F P
0 g
s
.172 .351 .801 r
.80026 .1887 m .80081 .1933 L .80617 .19701 L p F P
0 g
s
.207 .383 .818 r
.79734 .1869 m .80026 .1887 L .80081 .1933 L p F P
0 g
s
.467 .636 .929 r
.68633 .09933 m .69074 .0995 L .68775 .09517 L p F P
0 g
s
.467 .636 .929 r
.68775 .09517 m .68414 .09504 L .68633 .09933 L p F P
0 g
s
.964 .634 .287 r
.58298 .12095 m .58603 .12496 L .58666 .13002 L p F P
0 g
s
.977 .684 .387 r
.58603 .12496 m .58298 .12095 L .58286 .11572 L p F P
0 g
s
.503 .664 .934 r
.66691 .09072 m .67206 .09057 L .66905 .08636 L p F P
0 g
s
.503 .664 .934 r
.66905 .08636 m .66442 .08651 L .66691 .09072 L p F P
0 g
s
.899 .982 .795 r
.82624 .32724 m .8255 .32991 L .81981 .33733 L p F P
0 g
s
.106 .266 .745 r
.81651 .21412 m .81663 .2188 L .8209 .22293 L p F P
0 g
s
.129 .29 .76 r
.81663 .2188 m .81651 .21412 L .81186 .21014 L p F P
0 g
s
.15 .324 .784 r
.80617 .19701 m .80657 .20164 L .81159 .20548 L p F P
0 g
s
.154 .321 .781 r
.81186 .21014 m .81159 .20548 L .80657 .20164 L p F P
0 g
s
.126 .293 .763 r
.81159 .20548 m .81186 .21014 L .81651 .21412 L p F P
0 g
s
.368 .551 .902 r
.73123 .12533 m .73968 .12724 L .74114 .13169 L p F P
0 g
s
.365 .553 .904 r
.73968 .12724 m .73123 .12533 L .7291 .12192 L p F P
0 g
s
.332 .505 .878 r
.76919 .15251 m .76212 .15008 L p .77102 .15736 L F P
0 g
s
.312 .497 .878 r
.76212 .15008 m .76919 .15251 L .76626 .14737 L p F P
0 g
s
.312 .497 .878 r
.76626 .14737 m .76099 .14556 L .76212 .15008 L p F P
0 g
s
0 0 .51 r
.83428 .26966 m .83479 .2649 L .83281 .25995 L p F P
0 g
s
0 0 .422 r
.83479 .2649 m .83428 .26966 L .83569 .27481 L p F P
0 g
s
0 0 0 r
.83471 .30292 m .83499 .30101 L .83548 .29522 L p F P
0 g
s
0 0 0 r
.83611 .29048 m .83548 .29522 L .83499 .30101 L p F P
0 g
s
0 0 .159 r
.83548 .29522 m .83611 .29048 L .83593 .28492 L p F P
0 g
s
.315 .437 .826 r
.67377 .28583 m .67266 .28532 L .66953 .27878 L p F P
0 g
s
.512 .6 .879 r
.73573 .34163 m .73677 .34336 L .73622 .34646 L p F P
0 g
s
.5 .613 .896 r
.7387 .34656 m .73622 .34646 L .73677 .34336 L closepath p F P
0 g
s
.165 .328 .783 r
.64554 .24391 m .65048 .24777 L .65087 .2524 L p F P
0 g
s
.076 .281 .767 r
.64507 .23929 m .64554 .24391 L .65048 .24777 L p F P
0 g
s
.125 .303 .773 r
.64087 .23584 m .64507 .23929 L .64554 .24391 L p F P
0 g
s
0 .204 .724 r
.64087 .23584 m .6404 .23537 L .6402 .23441 L closepath p F P
0 g
s
0 .18 .707 r
.63771 .22901 m .63557 .22672 L p .6404 .23537 L F P
0 g
s
0 .18 .707 r
.6404 .23537 m .6402 .23441 L .63771 .22901 L p F P
0 g
s
.559 .673 .914 r
.75733 .35484 m .75596 .35497 L .75623 .3532 L closepath p F P
0 g
s
.566 .655 .896 r
.75442 .35048 m .75623 .3532 L .75596 .35497 L p F P
0 g
s
.15 .324 .784 r
.65631 .26085 m .656 .25621 L .65087 .2524 L p F P
0 g
s
.1 .298 .776 r
.65048 .24777 m .65087 .2524 L .656 .25621 L p F P
0 g
s
0 .151 .69 r
.63557 .22672 m .63771 .22901 L .63455 .22235 L p F P
0 g
s
0 .151 .69 r
.63455 .22235 m .63447 .22226 L .63557 .22672 L p F P
0 g
s
0 .129 .675 r
.63557 .22672 m .63447 .22226 L .63082 .21804 L p F P
0 g
s
.796 .91 .919 r
.81115 .34567 m .80349 .35144 L .8008 .3491 L p F P
0 g
s
.138 .326 .79 r
.656 .25621 m .65631 .26085 L .66164 .26462 L p F P
0 g
s
.17 .34 .792 r
.66189 .26925 m .66164 .26462 L .65631 .26085 L p F P
0 g
s
.639 .261 0 r
.60313 .16567 m .60247 .16434 L .59929 .15809 L p F P
0 g
s
.417 .519 .854 r
.70378 .31705 m .69793 .3156 L .69495 .3098 L p F P
0 g
s
0 .109 .661 r
.62959 .2136 m .63082 .21804 L .63447 .22226 L p F P
0 g
s
0 .092 .649 r
.63082 .21804 m .62959 .2136 L .62611 .20935 L p F P
0 g
s
.489 .581 .874 r
.72354 .33575 m .71991 .33544 L .71689 .32998 L p F P
0 g
s
.415 .531 .866 r
.7124 .32908 m .71689 .32998 L .71386 .32447 L p F P
0 g
s
.415 .531 .866 r
.71386 .32447 m .7131 .3243 L .7124 .32908 L p F P
0 g
s
.204 .366 .804 r
.66641 .27227 m .66189 .26925 L p .66764 .2776 L F P
0 g
s
.173 .343 .794 r
.66189 .26925 m .66641 .27227 L .66328 .26577 L p F P
0 g
s
.173 .343 .794 r
.66328 .26577 m .66164 .26462 L .66189 .26925 L p F P
0 g
s
0 .053 .62 r
.62475 .20493 m .62611 .20935 L .62959 .2136 L p F P
0 g
s
0 .052 .619 r
.62611 .20935 m .62475 .20493 L .62145 .20063 L p F P
0 g
s
.857 .878 .441 r
.83367 .30706 m .83263 .3119 L .8302 .31831 L p F P
0 g
s
.738 .74 .222 r
.83398 .30585 m .83471 .30292 L p .83263 .3119 L F P
0 g
s
.738 .74 .222 r
.83263 .3119 m .83367 .30706 L .83398 .30585 L p F P
0 g
s
.216 .377 .81 r
.66953 .27878 m .66764 .2776 L .66754 .27464 L closepath p F P
0 g
s
.204 .366 .804 r
.66764 .2776 m .66754 .27464 L .66641 .27227 L p F P
0 g
s
.092 .287 .768 r
.64507 .23929 m .64087 .23584 L .6402 .23441 L p F P
0 g
s
0 .011 .586 r
.61995 .19625 m .62145 .20063 L .62475 .20493 L p F P
0 g
s
0 .006 .582 r
.62145 .20063 m .61995 .19625 L .61682 .19191 L p F P
0 g
s
.871 .964 .856 r
.81981 .33733 m .81572 .34176 L .81314 .34041 L p F P
0 g
s
.871 .964 .856 r
.81314 .34041 m .82095 .3325 L .81981 .33733 L p F P
0 g
s
.899 .982 .795 r
.82513 .32735 m .82624 .32724 L p .81981 .33733 L F P
0 g
s
.899 .982 .795 r
.81981 .33733 m .82095 .3325 L .82513 .32735 L p F P
0 g
s
.597 .721 .931 r
.75733 .35484 m .77004 .35243 L .77289 .35625 L p F P
0 g
s
.59 .688 .909 r
.76717 .34847 m .77004 .35243 L .75733 .35484 L p F P
0 g
s
.59 .688 .909 r
.7577 .34995 m .76717 .34847 L p .75733 .35484 L F P
0 g
s
.59 .688 .909 r
.75733 .35484 m .75623 .3532 L .7577 .34995 L p F P
0 g
s
0 0 .544 r
.61517 .18756 m .61682 .19191 L .61995 .19625 L p F P
0 g
s
0 0 .536 r
.61682 .19191 m .61517 .18756 L .61223 .18318 L p F P
0 g
s
.542 .692 .937 r
.63996 .07965 m .63786 .07988 L .6348 .07582 L p F P
0 g
s
.335 .45 .829 r
.67377 .28583 m .68083 .28911 L .68052 .29387 L p F P
0 g
s
.269 .421 .83 r
.67412 .28105 m .67377 .28583 L .68083 .28911 L p F P
0 g
s
.315 .437 .826 r
.66953 .27878 m .67412 .28105 L .67377 .28583 L p F P
0 g
s
.796 .91 .919 r
.8008 .3491 m .81274 .34072 L .81115 .34567 L p F P
0 g
s
.837 .953 .891 r
.81314 .34041 m .81274 .34072 L .81115 .34567 L p F P
0 g
s
.837 .953 .891 r
.81115 .34567 m .81572 .34176 L .81314 .34041 L p F P
0 g
s
.763 .73 .203 r
.83398 .30585 m .83499 .30101 L .83471 .30292 L closepath p F P
0 g
s
0 0 .495 r
.61041 .17886 m .61223 .18318 L .61517 .18756 L p F P
0 g
s
0 0 .48 r
.61223 .18318 m .61041 .17886 L .60766 .17443 L p F P
0 g
s
.092 .287 .768 r
.6402 .23441 m .63973 .23079 L p .64507 .23929 L F P
0 g
s
.062 .262 .754 r
.6402 .23441 m .63771 .22901 L .63973 .23079 L closepath p F P
0 g
s
0 0 .507 r
.83321 .25536 m .83281 .25995 L .83479 .2649 L p F P
0 g
s
0 .045 .585 r
.83308 .25493 m .83072 .25042 L p .83281 .25995 L F P
0 g
s
0 .045 .585 r
.83281 .25995 m .83321 .25536 L .83308 .25493 L p F P
0 g
s
.296 .476 .867 r
.77213 .15779 m .77102 .15736 L .77049 .15482 L closepath p F P
0 g
s
.332 .505 .878 r
.77102 .15736 m .77049 .15482 L .76919 .15251 L p F P
0 g
s
.357 .543 .899 r
.74114 .13169 m .7472 .13319 L .74426 .12837 L p F P
0 g
s
.357 .543 .899 r
.74426 .12837 m .73968 .12724 L .74114 .13169 L p F P
0 g
s
.399 .584 .916 r
.71638 .11459 m .72533 .11602 L .72238 .11147 L p F P
0 g
s
.399 .584 .916 r
.72238 .11147 m .71452 .11023 L .71638 .11459 L p F P
0 g
s
.408 .591 .918 r
.70947 .10951 m .71452 .11023 L .71638 .11459 L p F P
0 g
s
0 0 .434 r
.60568 .17015 m .60766 .17443 L .61041 .17886 L p F P
0 g
s
0 0 .422 r
.60313 .16567 m .60568 .17015 L .60766 .17443 L p F P
0 g
s
.533 .653 .912 r
.7387 .34656 m .75149 .346 L .75442 .35048 L p F P
0 g
s
.533 .63 .893 r
.74856 .34142 m .75149 .346 L .7387 .34656 L p F P
0 g
s
.533 .63 .893 r
.73737 .3416 m .74856 .34142 L p .7387 .34656 L F P
0 g
s
.533 .63 .893 r
.7387 .34656 m .73677 .34336 L .73737 .3416 L p F P
0 g
s
0 0 .36 r
.60097 .16143 m .60313 .16567 L .60568 .17015 L p F P
0 g
s
0 0 .36 r
.60346 .16593 m .60097 .16143 L p .6028 .16483 L F P
0 g
s
0 0 .36 r
.60568 .17015 m .60346 .16593 L p .6028 .16483 L F P
0 g
s
.622 .216 0 r
.60346 .16593 m .6061 .1704 L p .60412 .16703 L F P
0 g
s
.639 .261 0 r
.60097 .16143 m .60313 .16567 L p .6008 .16108 L F P
0 g
s
.649 .247 0 r
.60346 .16593 m .60102 .16177 L .59857 .15726 L p F P
0 g
s
.622 .216 0 r
.60102 .16177 m .60346 .16593 L p .60412 .16703 L F P
0 g
s
.649 .247 0 r
.60097 .16143 m .60346 .16593 L p .60116 .16185 L F P
0 g
s
.649 .247 0 r
.59857 .15726 m .60097 .16143 L p .60116 .16185 L F P
0 g
s
.639 .261 0 r
.59929 .15809 m .60097 .16143 L p .6008 .16108 L F P
0 g
s
.312 .448 .837 r
.68757 .30181 m .68781 .2971 L .68052 .29387 L p F P
0 g
s
.295 .442 .839 r
.68083 .28911 m .68052 .29387 L .68781 .2971 L p F P
0 g
s
.198 .379 .818 r
.80026 .1887 m .79734 .1869 L .79437 .18087 L p F P
0 g
s
.781 .386 0 r
.59929 .15809 m .59877 .15684 L .59679 .15359 L closepath p F P
0 g
s
.842 .462 0 r
.59612 .15229 m .59462 .14795 L p .59877 .15684 L F P
0 g
s
.842 .462 0 r
.59877 .15684 m .59679 .15359 L .59612 .15229 L p F P
0 g
s
0 0 .151 r
.83652 .28015 m .83593 .28492 L .83611 .29048 L p F P
0 g
s
0 0 .306 r
.83593 .28492 m .83652 .28015 L .83569 .27481 L p F P
0 g
s
.54 .691 .937 r
.63996 .07965 m .65038 .07858 L .64734 .07449 L p F P
0 g
s
.54 .691 .937 r
.64734 .07449 m .63697 .07558 L .63996 .07965 L p F P
0 g
s
.542 .692 .937 r
.6348 .07582 m .63697 .07558 L .63996 .07965 L p F P
0 g
s
.438 .617 .926 r
.69074 .0995 m .69907 .1002 L .70115 .10451 L p F P
0 g
s
.436 .619 .928 r
.69907 .1002 m .69074 .0995 L .68775 .09517 L p F P
0 g
s
.338 .527 .894 r
.75153 .13846 m .75013 .13807 L .7472 .13319 L p F P
0 g
s
.271 .46 .863 r
.77818 .16037 m .77213 .15779 L .77049 .15482 L p F P
0 g
s
.278 .461 .861 r
.77213 .15779 m .77818 .16037 L .77912 .16492 L p F P
0 g
s
.589 .686 .908 r
.75623 .3532 m .75442 .35048 L .7577 .34995 L closepath p F P
0 g
s
.852 .462 0 r
.59462 .14795 m .59612 .15229 L .59294 .1468 L p F P
0 g
s
.852 .462 0 r
.59294 .1468 m .59193 .14386 L .59462 .14795 L p F P
0 g
s
.893 .519 .057 r
.59462 .14795 m .59193 .14386 L .59056 .13901 L p F P
0 g
s
.707 .84 .946 r
.79622 .35149 m .7883 .35537 L .78552 .35216 L p F P
0 g
s
.654 .786 .944 r
.77289 .35625 m .78552 .35216 L .7883 .35537 L p F P
0 g
s
.639 .768 .941 r
.78552 .35216 m .77289 .35625 L .77004 .35243 L p F P
0 g
s
.312 .448 .837 r
.68757 .30181 m .69177 .30353 L .68868 .29748 L p F P
0 g
s
.312 .448 .837 r
.68868 .29748 m .68781 .2971 L .68757 .30181 L p F P
0 g
s
.263 .442 .851 r
.78671 .17266 m .78593 .16808 L .77912 .16492 L p F P
0 g
s
.261 .446 .854 r
.77818 .16037 m .77912 .16492 L .78593 .16808 L p F P
0 g
s
0 .027 .574 r
.83308 .25493 m .83072 .25042 L .83091 .2474 L closepath p F P
0 g
s
0 .11 .635 r
.82971 .2437 m .82803 .24107 L p .83072 .25042 L F P
0 g
s
0 .11 .635 r
.83072 .25042 m .83091 .2474 L .82971 .2437 L p F P
0 g
s
.47 .643 .932 r
.67206 .09057 m .6818 .09079 L .68414 .09504 L p F P
0 g
s
.47 .646 .935 r
.6818 .09079 m .67206 .09057 L .66905 .08636 L p F P
0 g
s
.292 .425 .825 r
.67412 .28105 m .66953 .27878 L .66754 .27464 L p F P
0 g
s
.406 .593 .92 r
.71452 .11023 m .70947 .10951 L .70651 .10505 L p F P
0 g
s
.921 .976 .719 r
.82513 .32735 m .82662 .32507 L .82624 .32724 L closepath p F P
0 g
s
.933 .947 .612 r
.8302 .31831 m .82662 .32507 L .82624 .32724 L p F P
0 g
s
.365 .553 .904 r
.7291 .12192 m .72864 .1207 L p .73968 .12724 L F P
0 g
s
.381 .566 .909 r
.7291 .12192 m .72828 .12063 L .72864 .1207 L closepath p F P
0 g
s
.466 .572 .878 r
.72354 .33575 m .73275 .3366 L .72976 .33151 L p F P
0 g
s
.466 .572 .878 r
.72976 .33151 m .72461 .33087 L .72354 .33575 L p F P
0 g
s
.489 .581 .874 r
.71689 .32998 m .72461 .33087 L .72354 .33575 L p F P
0 g
s
.906 .527 .088 r
.58769 .13496 m .59056 .13901 L .59193 .14386 L p F P
0 g
s
.937 .58 .172 r
.59056 .13901 m .58769 .13496 L .58666 .13002 L p F P
0 g
s
.043 .257 .754 r
.63973 .23079 m .63771 .22901 L .63455 .22235 L p F P
0 g
s
.431 .612 .925 r
.70115 .10451 m .70651 .10505 L .70354 .10063 L p F P
0 g
s
.431 .612 .925 r
.70354 .10063 m .69907 .1002 L .70115 .10451 L p F P
0 g
s
.417 .519 .854 r
.69495 .3098 m .69498 .30964 L p .70378 .31705 L F P
0 g
s
.403 .508 .851 r
.69495 .3098 m .69485 .30961 L .69498 .30964 L closepath p F P
0 g
s
.681 .285 0 r
.60097 .16143 m .59929 .15809 L .59679 .15359 L p F P
0 g
s
.922 .958 .636 r
.83114 .3135 m .8302 .31831 L .82662 .32507 L p F P
0 g
s
.857 .878 .441 r
.8302 .31831 m .83114 .3135 L .83367 .30706 L p F P
0 g
s
.404 .508 .851 r
.69498 .30964 m .69485 .30961 L .69177 .30353 L p F P
0 g
s
.942 .582 .196 r
.58361 .12602 m .58666 .13002 L .58769 .13496 L p F P
0 g
s
.964 .634 .287 r
.58666 .13002 m .58361 .12602 L .58298 .12095 L p F P
0 g
s
.363 .499 .861 r
.6958 .30477 m .69498 .30964 L .70436 .31226 L p F P
0 g
s
.404 .508 .851 r
.69177 .30353 m .6958 .30477 L .69498 .30964 L p F P
0 g
s
.417 .519 .854 r
.69498 .30964 m .70436 .31226 L .70378 .31705 L p F P
0 g
s
.322 .508 .885 r
.75153 .13846 m .75976 .14106 L .76099 .14556 L p F P
0 g
s
.322 .513 .888 r
.75011 .13401 m .75153 .13846 L .75976 .14106 L p F P
0 g
s
.338 .527 .894 r
.7472 .13319 m .75011 .13401 L .75153 .13846 L p F P
0 g
s
0 0 0 r
.83499 .30101 m .83559 .29627 L .83611 .29048 L p F P
0 g
s
.836 .775 .269 r
.83499 .30101 m .83559 .29627 L p .83377 .30653 L F P
0 g
s
.836 .775 .269 r
.83377 .30653 m .83398 .30585 L .83499 .30101 L p F P
0 g
s
.26 .433 .844 r
.79143 .17507 m .78671 .17266 L p .79384 .18056 L F P
0 g
s
.237 .421 .841 r
.78671 .17266 m .79143 .17507 L .78848 .16939 L p F P
0 g
s
.237 .421 .841 r
.78848 .16939 m .78593 .16808 L .78671 .17266 L p F P
0 g
s
0 .092 .626 r
.82971 .2437 m .82803 .24107 L .82811 .23876 L closepath p F P
0 g
s
.022 .168 .678 r
.82648 .23418 m .82474 .23191 L p .82803 .24107 L F P
0 g
s
.022 .168 .678 r
.82803 .24107 m .82811 .23876 L .82648 .23418 L p F P
0 g
s
.505 .669 .936 r
.65342 .08269 m .66178 .08233 L .66442 .08651 L p F P
0 g
s
.505 .671 .938 r
.66178 .08233 m .65342 .08269 L .65038 .07858 L p F P
0 g
s
.473 .571 .873 r
.72461 .33087 m .71689 .32998 L .71386 .32447 L p F P
0 g
s
.378 .568 .911 r
.72864 .1207 m .72828 .12063 L .72533 .11602 L p F P
0 g
s
.531 .627 .892 r
.73677 .34336 m .73573 .34163 L .73737 .3416 L closepath p F P
0 g
s
0 0 .303 r
.83622 .27004 m .83569 .27481 L .83652 .28015 L p F P
0 g
s
0 0 .422 r
.83569 .27481 m .83622 .27004 L .83479 .2649 L p F P
0 g
s
.502 .666 .936 r
.66442 .08651 m .66905 .08636 L .66603 .08218 L p F P
0 g
s
.502 .666 .936 r
.66603 .08218 m .66178 .08233 L .66442 .08651 L p F P
0 g
s
.466 .639 .931 r
.68414 .09504 m .68775 .09517 L .68476 .09088 L p F P
0 g
s
.466 .639 .931 r
.68476 .09088 m .6818 .09079 L .68414 .09504 L p F P
0 g
s
.365 .553 .904 r
.72864 .1207 m .7381 .12281 L .73968 .12724 L p F P
0 g
s
.365 .557 .907 r
.72686 .11632 m .72864 .1207 L .7381 .12281 L p F P
0 g
s
.378 .568 .911 r
.72533 .11602 m .72686 .11632 L .72864 .1207 L p F P
0 g
s
0 .151 .669 r
.82648 .23418 m .82474 .23191 L .82477 .22937 L closepath p F P
0 g
s
.066 .22 .714 r
.82334 .22564 m .8209 .22293 L p .82474 .23191 L F P
0 g
s
.066 .22 .714 r
.82474 .23191 m .82477 .22937 L .82334 .22564 L p F P
0 g
s
.215 .394 .825 r
.79437 .18087 m .79384 .18056 L .7937 .17951 L closepath p F P
0 g
s
.26 .433 .844 r
.79384 .18056 m .7937 .17951 L .79143 .17507 L p F P
0 g
s
.292 .425 .825 r
.66754 .27464 m .66762 .27291 L p .67412 .28105 L F P
0 g
s
.273 .41 .819 r
.66754 .27464 m .66641 .27227 L .66762 .27291 L closepath p F P
0 g
s
.295 .482 .873 r
.77049 .15482 m .76919 .15251 L .77001 .15282 L closepath p F P
0 g
s
.271 .46 .863 r
.77049 .15482 m .77001 .15282 L p .77818 .16037 L F P
0 g
s
.707 .84 .946 r
.7982 .34661 m .79622 .35149 L p .78552 .35216 L F P
0 g
s
.735 .855 .937 r
.79622 .35149 m .7982 .34661 L .8008 .3491 L closepath p F P
0 g
s
.172 .351 .801 r
.80617 .19701 m .80567 .19239 L .80026 .1887 L p F P
0 g
s
.168 .353 .804 r
.79962 .18411 m .80026 .1887 L .80567 .19239 L p F P
0 g
s
.198 .379 .818 r
.79437 .18087 m .79962 .18411 L .80026 .1887 L p F P
0 g
s
.041 .204 .707 r
.82334 .22564 m .8209 .22293 L .82084 .21916 L closepath p F P
0 g
s
.106 .266 .745 r
.82024 .2177 m .81651 .21412 L p .8209 .22293 L F P
0 g
s
.106 .266 .745 r
.8209 .22293 m .82084 .21916 L .82024 .2177 L p F P
0 g
s
.187 .376 .818 r
.79962 .18411 m .79437 .18087 L .7937 .17951 L p F P
0 g
s
.405 .529 .869 r
.71082 .31888 m .70378 .31705 L p .7131 .3243 L F P
0 g
s
.386 .507 .858 r
.70378 .31705 m .71082 .31888 L .70777 .31326 L p F P
0 g
s
.386 .507 .858 r
.70777 .31326 m .70436 .31226 L .70378 .31705 L p F P
0 g
s
.59 .681 .904 r
.7577 .34995 m .75442 .35048 L .75149 .346 L p F P
0 g
s
.15 .324 .784 r
.81159 .20548 m .81124 .20084 L .80617 .19701 L p F P
0 g
s
.147 .326 .787 r
.80567 .19239 m .80617 .19701 L .81124 .20084 L p F P
0 g
s
.075 .245 .735 r
.81651 .21412 m .82024 .2177 L .81718 .21032 L p F P
0 g
s
.075 .245 .735 r
.81718 .21032 m .8163 .20945 L .81651 .21412 L p F P
0 g
s
.126 .293 .763 r
.81651 .21412 m .8163 .20945 L .81159 .20548 L p F P
0 g
s
.308 .497 .881 r
.76099 .14556 m .76626 .14737 L .76333 .14229 L p F P
0 g
s
.308 .497 .881 r
.76333 .14229 m .75976 .14106 L .76099 .14556 L p F P
0 g
s
.128 .301 .77 r
.81124 .20084 m .81159 .20548 L .8163 .20945 L p F P
0 g
s
.269 .41 .821 r
.66762 .27291 m .66641 .27227 L .66328 .26577 L p F P
0 g
s
.532 .624 .889 r
.73737 .3416 m .73573 .34163 L .73275 .3366 L p F P
0 g
s
.92 .976 .752 r
.82662 .32507 m .82513 .32735 L .82265 .32709 L p F P
0 g
s
.92 .976 .752 r
.82265 .32709 m .82741 .32033 L .82662 .32507 L p F P
0 g
s
.922 .958 .636 r
.82662 .32507 m .82741 .32033 L .83114 .3135 L p F P
0 g
s
.187 .376 .818 r
.7937 .17951 m .7931 .17598 L p .79962 .18411 L F P
0 g
s
.219 .406 .834 r
.7937 .17951 m .79143 .17507 L .7931 .17598 L closepath p F P
0 g
s
0 .141 .685 r
.63455 .22235 m .63447 .22226 L .63441 .22206 L closepath p F P
0 g
s
0 .109 .661 r
.63139 .21574 m .62959 .2136 L p .63447 .22226 L F P
0 g
s
0 .109 .661 r
.63447 .22226 m .63441 .22206 L .63139 .21574 L p F P
0 g
s
.092 .287 .768 r
.63973 .23079 m .64429 .23474 L .64507 .23929 L p F P
0 g
s
0 .233 .744 r
.63885 .22625 m .63973 .23079 L .64429 .23474 L p F P
0 g
s
.043 .257 .754 r
.63455 .22235 m .63885 .22625 L .63973 .23079 L p F P
0 g
s
0 .081 .642 r
.62959 .2136 m .63139 .21574 L .62823 .20936 L p F P
0 g
s
0 .081 .642 r
.62823 .20936 m .62812 .20923 L .62959 .2136 L p F P
0 g
s
0 .053 .62 r
.62959 .2136 m .62812 .20923 L .62475 .20493 L p F P
0 g
s
.076 .281 .767 r
.65048 .24777 m .64979 .24321 L .64507 .23929 L p F P
0 g
s
.022 .253 .755 r
.64429 .23474 m .64507 .23929 L .64979 .24321 L p F P
0 g
s
.006 .239 .746 r
.63885 .22625 m .63455 .22235 L .63441 .22206 L p F P
0 g
s
.793 .867 .903 r
.7982 .34661 m .8008 .3491 L .81274 .34072 L p F P
0 g
s
0 0 .507 r
.83479 .2649 m .83499 .26261 L .83321 .25536 L p F P
0 g
s
0 0 .415 r
.83499 .26261 m .83479 .2649 L .83622 .27004 L p F P
0 g
s
.751 .364 0 r
.59679 .15359 m .59612 .15229 L .59629 .1527 L closepath p F P
0 g
s
.681 .285 0 r
.59679 .15359 m .59629 .1527 L p .60097 .16143 L F P
0 g
s
.061 .28 .77 r
.64979 .24321 m .65048 .24777 L .65538 .25165 L p F P
0 g
s
.1 .298 .776 r
.656 .25621 m .65538 .25165 L .65048 .24777 L p F P
0 g
s
.006 .239 .746 r
.63441 .22206 m .63346 .21775 L p .63885 .22625 L F P
0 g
s
0 .21 .728 r
.63441 .22206 m .63139 .21574 L .63346 .21775 L closepath p F P
0 g
s
0 .027 .598 r
.62315 .20058 m .62475 .20493 L .62812 .20923 L p F P
0 g
s
0 .011 .586 r
.62475 .20493 m .62315 .20058 L .61995 .19625 L p F P
0 g
s
0 0 0 r
.8367 .28572 m .83611 .29048 L .83559 .29627 L p F P
0 g
s
0 0 .151 r
.83611 .29048 m .8367 .28572 L .83652 .28015 L p F P
0 g
s
.138 .326 .79 r
.66014 .25932 m .656 .25621 L p .66164 .26462 L F P
0 g
s
.105 .303 .779 r
.656 .25621 m .66014 .25932 L .65701 .25292 L p F P
0 g
s
.105 .303 .779 r
.65701 .25292 m .65538 .25165 L .656 .25621 L p F P
0 g
s
0 0 .551 r
.61821 .19193 m .61995 .19625 L .62315 .20058 L p F P
0 g
s
0 0 .544 r
.61995 .19625 m .61821 .19193 L .61517 .18756 L p F P
0 g
s
.29 .483 .875 r
.77001 .15282 m .76919 .15251 L .76626 .14737 L p F P
0 g
s
.758 .754 .24 r
.83367 .30706 m .83377 .30653 L .83398 .30585 L closepath p F P
0 g
s
.895 .986 .79 r
.82095 .3325 m .82513 .32735 L .82265 .32709 L p F P
0 g
s
0 0 .506 r
.61328 .18327 m .61517 .18756 L .61821 .19193 L p F P
0 g
s
0 0 .495 r
.61517 .18756 m .61328 .18327 L .61041 .17886 L p F P
0 g
s
.138 .326 .79 r
.66164 .26462 m .66132 .26176 L .66014 .25932 L p F P
0 g
s
.154 .34 .798 r
.66328 .26577 m .66164 .26462 L .66132 .26176 L closepath p F P
0 g
s
.385 .498 .851 r
.6958 .30477 m .69177 .30353 L .68868 .29748 L p F P
0 g
s
0 0 .555 r
.83091 .2474 m .83093 .2457 L p .83321 .25519 L F P
0 g
s
0 0 .555 r
.83321 .25519 m .83308 .25493 L .83091 .2474 L p F P
0 g
s
0 .067 .61 r
.83091 .2474 m .82971 .2437 L .83093 .2457 L closepath p F P
0 g
s
.333 .528 .896 r
.75011 .13401 m .7472 .13319 L .74426 .12837 L p F P
0 g
s
.532 .624 .889 r
.73275 .3366 m .7387 .33665 L .73737 .3416 L p F P
0 g
s
.513 .615 .891 r
.73737 .3416 m .74856 .34142 L .74561 .33677 L p F P
0 g
s
.513 .615 .891 r
.74561 .33677 m .7387 .33665 L .73737 .3416 L p F P
0 g
s
0 .064 .609 r
.83093 .2457 m .82971 .2437 L .82811 .23876 L p F P
0 g
s
0 0 .453 r
.60837 .1746 m .61041 .17886 L .61328 .18327 L p F P
0 g
s
0 0 .434 r
.61041 .17886 m .60837 .1746 L .60568 .17015 L p F P
0 g
s
0 .064 .609 r
.82811 .23876 m .82809 .23638 L p .83093 .2457 L F P
0 g
s
0 .127 .655 r
.82811 .23876 m .82648 .23418 L .82809 .23638 L closepath p F P
0 g
s
.397 .587 .919 r
.71452 .11023 m .72238 .11147 L .71942 .10696 L p F P
0 g
s
.397 .587 .919 r
.71942 .10696 m .71254 .10589 L .71452 .11023 L p F P
0 g
s
.406 .593 .92 r
.70651 .10505 m .71254 .10589 L .71452 .11023 L p F P
0 g
s
.784 .384 0 r
.59629 .1527 m .59612 .15229 L .59294 .1468 L p F P
0 g
s
0 0 .389 r
.60346 .16593 m .60568 .17015 L .60837 .1746 L p F P
0 g
s
.292 .425 .825 r
.66762 .27291 m .67409 .27635 L .67412 .28105 L p F P
0 g
s
.221 .393 .822 r
.6676 .2682 m .66762 .27291 L .67409 .27635 L p F P
0 g
s
.269 .41 .821 r
.66328 .26577 m .6676 .2682 L .66762 .27291 L p F P
0 g
s
.411 .534 .871 r
.71386 .32447 m .7131 .3243 L .7132 .32328 L closepath p F P
0 g
s
.405 .529 .869 r
.7131 .3243 m .7132 .32328 L .71082 .31888 L p F P
0 g
s
.572 .677 .911 r
.7577 .34995 m .76717 .34847 L .76428 .34438 L p F P
0 g
s
.572 .677 .911 r
.76428 .34438 m .75908 .34503 L .7577 .34995 L p F P
0 g
s
.59 .681 .904 r
.75149 .346 m .75908 .34503 L .7577 .34995 L p F P
0 g
s
.354 .544 .902 r
.73968 .12724 m .74426 .12837 L .74132 .1236 L p F P
0 g
s
.354 .544 .902 r
.74132 .1236 m .7381 .12281 L .73968 .12724 L p F P
0 g
s
.856 .877 .44 r
.83377 .30653 m .83367 .30706 L .83114 .3135 L p F P
0 g
s
.436 .619 .928 r
.68775 .09517 m .69685 .09591 L .69907 .1002 L p F P
0 g
s
.435 .622 .931 r
.69685 .09591 m .68775 .09517 L .68476 .09088 L p F P
0 g
s
.681 .285 0 r
.59629 .1527 m .59857 .15726 L .60097 .16143 L p F P
0 g
s
.271 .46 .863 r
.77001 .15282 m .77714 .15585 L .77818 .16037 L p F P
0 g
s
.267 .463 .866 r
.7688 .14833 m .77001 .15282 L .77714 .15585 L p F P
0 g
s
.29 .483 .875 r
.76626 .14737 m .7688 .14833 L .77001 .15282 L p F P
0 g
s
0 .125 .655 r
.82809 .23638 m .82648 .23418 L .82477 .22937 L p F P
0 g
s
.727 .315 0 r
.59369 .14857 m .59629 .1527 L .59857 .15726 L p F P
0 g
s
.784 .384 0 r
.59294 .1468 m .59369 .14857 L .59629 .1527 L p F P
0 g
s
.639 .768 .941 r
.77004 .35243 m .78272 .34878 L .78552 .35216 L p F P
0 g
s
.624 .752 .939 r
.78272 .34878 m .77004 .35243 L .76717 .34847 L p F P
0 g
s
.873 .931 .858 r
.82095 .3325 m .82218 .32762 L p .81289 .34025 L F P
0 g
s
.873 .931 .858 r
.81289 .34025 m .81314 .34041 L .82095 .3325 L p F P
0 g
s
.895 .986 .79 r
.82265 .32709 m .82218 .32762 L .82095 .3325 L p F P
0 g
s
0 0 .557 r
.83321 .25536 m .83308 .25493 L .83321 .25519 L closepath p F P
0 g
s
.403 .595 .923 r
.71254 .10589 m .70651 .10505 L .70354 .10063 L p F P
0 g
s
0 0 .472 r
.83321 .25519 m .83321 .25536 L .83499 .26261 L p F P
0 g
s
.269 .421 .83 r
.68083 .28911 m .68079 .28445 L .67412 .28105 L p F P
0 g
s
.245 .412 .831 r
.67409 .27635 m .67412 .28105 L .68079 .28445 L p F P
0 g
s
.473 .571 .873 r
.71386 .32447 m .72519 .32612 L .72461 .33087 L p F P
0 g
s
.458 .561 .872 r
.72519 .32612 m .71386 .32447 L .7132 .32328 L p F P
0 g
s
.47 .646 .935 r
.66905 .08636 m .67932 .08656 L .6818 .09079 L p F P
0 g
s
.469 .648 .937 r
.67932 .08656 m .66905 .08636 L .66603 .08218 L p F P
0 g
s
.868 .471 .004 r
.59193 .14386 m .59294 .1468 L .58978 .14193 L p F P
0 g
s
.868 .471 .004 r
.58978 .14193 m .58905 .13981 L .59193 .14386 L p F P
0 g
s
.906 .527 .088 r
.59193 .14386 m .58905 .13981 L .58769 .13496 L p F P
0 g
s
0 0 .467 r
.83328 .25052 m .83321 .25519 L .83508 .26018 L p F P
0 g
s
0 0 .555 r
.83093 .2457 m .83328 .25052 L .83321 .25519 L p F P
0 g
s
0 0 .472 r
.83499 .26261 m .83508 .26018 L .83321 .25519 L p F P
0 g
s
.707 .84 .946 r
.78552 .35216 m .79808 .34649 L .7982 .34661 L p F P
0 g
s
.69 .822 .946 r
.79808 .34649 m .78552 .35216 L .78272 .34878 L p F P
0 g
s
.89 .876 .44 r
.83427 .30233 m .83377 .30653 L .83201 .30906 L p F P
0 g
s
.836 .775 .269 r
.83559 .29627 m .83427 .30233 L .83377 .30653 L p F P
0 g
s
.856 .877 .44 r
.83114 .3135 m .83201 .30906 L .83377 .30653 L p F P
0 g
s
0 .125 .655 r
.82477 .22937 m .8247 .22723 L p .82809 .23638 L F P
0 g
s
.011 .182 .694 r
.82477 .22937 m .82334 .22564 L .8247 .22723 L closepath p F P
0 g
s
.821 .934 .905 r
.81274 .34072 m .81289 .34025 L .81314 .34041 L closepath p F P
0 g
s
.793 .867 .903 r
.81274 .34072 m .81289 .34025 L p .7982 .34661 L F P
0 g
s
.915 .532 .115 r
.58464 .13097 m .58769 .13496 L .58905 .13981 L p F P
0 g
s
.942 .582 .196 r
.58769 .13496 m .58464 .13097 L .58361 .12602 L p F P
0 g
s
.295 .442 .839 r
.68559 .29139 m .68083 .28911 L p .68781 .2971 L F P
0 g
s
.269 .421 .83 r
.68083 .28911 m .68559 .29139 L .68249 .28532 L p F P
0 g
s
.269 .421 .83 r
.68249 .28532 m .68079 .28445 L .68083 .28911 L p F P
0 g
s
.458 .561 .872 r
.7132 .32328 m .71403 .31942 L p .72519 .32612 L F P
0 g
s
.447 .553 .87 r
.7132 .32328 m .71082 .31888 L .71403 .31942 L closepath p F P
0 g
s
.261 .446 .854 r
.78593 .16808 m .78506 .16351 L .77818 .16037 L p F P
0 g
s
.269 .457 .861 r
.77714 .15585 m .77818 .16037 L .78506 .16351 L p F P
0 g
s
.243 .398 .819 r
.6676 .2682 m .66328 .26577 L .66132 .26176 L p F P
0 g
s
.834 .919 .892 r
.8105 .33853 m .81353 .33599 L .81289 .34025 L closepath p F P
0 g
s
.793 .867 .903 r
.81289 .34025 m .8105 .33853 L p .7982 .34661 L F P
0 g
s
.873 .931 .858 r
.82218 .32762 m .81353 .33599 L .81289 .34025 L p F P
0 g
s
.214 .406 .836 r
.7931 .17598 m .79143 .17507 L .78848 .16939 L p F P
0 g
s
.007 .18 .694 r
.8247 .22723 m .82334 .22564 L .82084 .21916 L p F P
0 g
s
.375 .57 .914 r
.72686 .11632 m .72533 .11602 L .72238 .11147 L p F P
0 g
s
.43 .614 .927 r
.69907 .1002 m .70354 .10063 L .70056 .09626 L p F P
0 g
s
.43 .614 .927 r
.70056 .09626 m .69685 .09591 L .69907 .1002 L p F P
0 g
s
0 0 .146 r
.83707 .27539 m .83652 .28015 L .8367 .28572 L p F P
0 g
s
0 0 .303 r
.83652 .28015 m .83707 .27539 L .83622 .27004 L p F P
0 g
s
.505 .671 .938 r
.65038 .07858 m .65897 .0782 L .66178 .08233 L p F P
0 g
s
.504 .673 .94 r
.65897 .0782 m .65038 .07858 L .64734 .07449 L p F P
0 g
s
0 .202 .726 r
.63346 .21775 m .63139 .21574 L .62823 .20936 L p F P
0 g
s
0 0 .542 r
.8309 .24104 m .83093 .2457 L .83328 .25052 L p F P
0 g
s
0 .064 .609 r
.82809 .23638 m .8309 .24104 L .83093 .2457 L p F P
0 g
s
.303 .45 .842 r
.68868 .29748 m .68781 .2971 L .68782 .29579 L closepath p F P
0 g
s
.295 .442 .839 r
.68781 .2971 m .68782 .29579 L .68559 .29139 L p F P
0 g
s
0 0 .373 r
.83508 .26018 m .83499 .26261 L .8363 .26922 L p F P
0 g
s
0 0 .415 r
.83622 .27004 m .8363 .26922 L .83499 .26261 L p F P
0 g
s
.322 .513 .888 r
.75976 .14106 m .75841 .13658 L .75011 .13401 L p F P
0 g
s
.321 .517 .891 r
.74858 .12958 m .75011 .13401 L .75841 .13658 L p F P
0 g
s
.333 .528 .896 r
.74426 .12837 m .74858 .12958 L .75011 .13401 L p F P
0 g
s
.23 .42 .842 r
.78593 .16808 m .78848 .16939 L .78554 .16376 L p F P
0 g
s
.23 .42 .842 r
.78554 .16376 m .78506 .16351 L .78593 .16808 L p F P
0 g
s
.576 .67 .903 r
.75908 .34503 m .75149 .346 L .74856 .34142 L p F P
0 g
s
.517 .614 .888 r
.7387 .33665 m .73275 .3366 L .72976 .33151 L p F P
0 g
s
.501 .669 .938 r
.66178 .08233 m .66603 .08218 L .66301 .07805 L p F P
0 g
s
.501 .669 .938 r
.66301 .07805 m .65897 .0782 L .66178 .08233 L p F P
0 g
s
.445 .565 .882 r
.72461 .33087 m .72976 .33151 L .72675 .32636 L p F P
0 g
s
.445 .565 .882 r
.72675 .32636 m .72519 .32612 L .72461 .33087 L p F P
0 g
s
.465 .642 .934 r
.6818 .09079 m .68476 .09088 L .68176 .08664 L p F P
0 g
s
.465 .642 .934 r
.68176 .08664 m .67932 .08656 L .6818 .09079 L p F P
0 g
s
.385 .498 .851 r
.68868 .29748 m .69618 .30001 L .6958 .30477 L p F P
0 g
s
.366 .488 .85 r
.69618 .30001 m .68868 .29748 L .68782 .29579 L p F P
0 g
s
0 .052 .603 r
.82795 .23174 m .82809 .23638 L .8309 .24104 L p F P
0 g
s
0 .125 .655 r
.8247 .22723 m .82795 .23174 L .82809 .23638 L p F P
0 g
s
.365 .557 .907 r
.7381 .12281 m .7364 .1184 L .72686 .11632 L p F P
0 g
s
.363 .56 .91 r
.72496 .11197 m .72686 .11632 L .7364 .1184 L p F P
0 g
s
.375 .57 .914 r
.72238 .11147 m .72496 .11197 L .72686 .11632 L p F P
0 g
s
.923 .963 .653 r
.83201 .30906 m .83114 .3135 L .82741 .32033 L p F P
0 g
s
.007 .18 .694 r
.82084 .21916 m .82078 .21825 L p .8247 .22723 L F P
0 g
s
.055 .231 .728 r
.82084 .21916 m .82024 .2177 L .82078 .21825 L closepath p F P
0 g
s
0 0 0 r
.83559 .29627 m .83615 .29153 L .8367 .28572 L p F P
0 g
s
.814 .771 .262 r
.83615 .29153 m .83559 .29627 L .83427 .30233 L p F P
0 g
s
.363 .499 .861 r
.70436 .31226 m .70455 .30758 L .6958 .30477 L p F P
0 g
s
.35 .494 .862 r
.69618 .30001 m .6958 .30477 L .70455 .30758 L p F P
0 g
s
.243 .398 .819 r
.66132 .26176 m .66126 .26 L p .6676 .2682 L F P
0 g
s
.222 .381 .812 r
.66132 .26176 m .66014 .25932 L .66126 .26 L closepath p F P
0 g
s
.183 .379 .823 r
.79221 .17144 m .7931 .17598 L .79888 .17954 L p F P
0 g
s
.214 .406 .836 r
.78848 .16939 m .79221 .17144 L .7931 .17598 L p F P
0 g
s
.187 .376 .818 r
.7931 .17598 m .79888 .17954 L .79962 .18411 L p F P
0 g
s
.284 .483 .877 r
.7688 .14833 m .76626 .14737 L .76333 .14229 L p F P
0 g
s
.048 .229 .728 r
.82078 .21825 m .82024 .2177 L .81718 .21032 L p F P
0 g
s
.811 .399 0 r
.59369 .14857 m .59294 .1468 L .58978 .14193 L p F P
0 g
s
0 .116 .651 r
.82445 .2226 m .8247 .22723 L .82795 .23174 L p F P
0 g
s
.007 .18 .694 r
.82078 .21825 m .82445 .2226 L .8247 .22723 L p F P
0 g
s
.366 .488 .85 r
.68782 .29579 m .68815 .29233 L p .69618 .30001 L F P
0 g
s
.352 .477 .846 r
.68782 .29579 m .68559 .29139 L .68815 .29233 L closepath p F P
0 g
s
0 0 .291 r
.8363 .26922 m .83622 .27004 L .83707 .27539 L p F P
0 g
s
.168 .353 .804 r
.80567 .19239 m .80508 .18779 L .79962 .18411 L p F P
0 g
s
.165 .356 .808 r
.79888 .17954 m .79962 .18411 L .80508 .18779 L p F P
0 g
s
.329 .529 .898 r
.74858 .12958 m .74426 .12837 L .74132 .1236 L p F P
0 g
s
.448 .553 .87 r
.71403 .31942 m .71082 .31888 L .70777 .31326 L p F P
0 g
s
0 .17 .691 r
.82041 .21364 m .82078 .21825 L .82445 .2226 L p F P
0 g
s
.048 .229 .728 r
.81718 .21032 m .82041 .21364 L .82078 .21825 L p F P
0 g
s
.303 .498 .883 r
.75976 .14106 m .76333 .14229 L .76039 .13726 L p F P
0 g
s
.303 .498 .883 r
.76039 .13726 m .75841 .13658 L .75976 .14106 L p F P
0 g
s
.147 .326 .787 r
.81124 .20084 m .8108 .19621 L .80567 .19239 L p F P
0 g
s
.149 .335 .794 r
.80508 .18779 m .80567 .19239 L .8108 .19621 L p F P
0 g
s
.215 .381 .814 r
.66126 .26 m .66014 .25932 L .65701 .25292 L p F P
0 g
s
.064 .242 .736 r
.81718 .21032 m .8163 .20945 L .8162 .20795 L closepath p F P
0 g
s
.128 .301 .77 r
.81415 .20331 m .81124 .20084 L p .8163 .20945 L F P
0 g
s
.128 .301 .77 r
.8163 .20945 m .8162 .20795 L .81415 .20331 L p F P
0 g
s
.098 .282 .762 r
.81124 .20084 m .81415 .20331 L .81114 .1965 L p F P
0 g
s
.098 .282 .762 r
.81114 .1965 m .8108 .19621 L .81124 .20084 L p F P
0 g
s
.758 .854 .922 r
.79808 .34649 m .79823 .3464 L .7982 .34661 L closepath p F P
0 g
s
.793 .867 .903 r
.8105 .33853 m .79823 .3464 L .7982 .34661 L p F P
0 g
s
.362 .498 .861 r
.70436 .31226 m .70777 .31326 L .70471 .30764 L p F P
0 g
s
.362 .498 .861 r
.70471 .30764 m .70455 .30758 L .70436 .31226 L p F P
0 g
s
0 .068 .631 r
.62823 .20936 m .62812 .20923 L .628 .20891 L closepath p F P
0 g
s
0 .027 .598 r
.62506 .20307 m .62315 .20058 L p .62812 .20923 L F P
0 g
s
0 .027 .598 r
.62812 .20923 m .628 .20891 L .62506 .20307 L p F P
0 g
s
.743 .838 .923 r
.79823 .3464 m .79808 .34649 L .79533 .3436 L p F P
0 g
s
.69 .822 .946 r
.78272 .34878 m .79533 .3436 L .79808 .34649 L p F P
0 g
s
.006 .239 .746 r
.63346 .21775 m .6377 .22179 L .63885 .22625 L p F P
0 g
s
0 .18 .713 r
.6322 .21331 m .63346 .21775 L .6377 .22179 L p F P
0 g
s
0 .202 .726 r
.62823 .20936 m .6322 .21331 L .63346 .21775 L p F P
0 g
s
0 0 .245 r
.83644 .26535 m .8363 .26922 L .83709 .27513 L p F P
0 g
s
0 0 .373 r
.8363 .26922 m .83644 .26535 L .83508 .26018 L p F P
0 g
s
0 0 .291 r
.83707 .27539 m .83709 .27513 L .8363 .26922 L p F P
0 g
s
0 .004 .578 r
.62315 .20058 m .62506 .20307 L .6219 .19704 L p F P
0 g
s
0 .004 .578 r
.6219 .19704 m .62133 .19629 L .62315 .20058 L p F P
0 g
s
0 0 .551 r
.62315 .20058 m .62133 .19629 L .61821 .19193 L p F P
0 g
s
.435 .622 .931 r
.68476 .09088 m .6945 .09165 L .69685 .09591 L p F P
0 g
s
.433 .624 .933 r
.6945 .09165 m .68476 .09088 L .68176 .08664 L p F P
0 g
s
.743 .838 .923 r
.79533 .3436 m .79863 .34179 L .79823 .3464 L p F P
0 g
s
.777 .895 .927 r
.80783 .33634 m .79863 .34179 L .79823 .3464 L p F P
0 g
s
.777 .895 .927 r
.79823 .3464 m .8105 .33853 L .80783 .33634 L p F P
0 g
s
0 .233 .744 r
.64429 .23474 m .64324 .23027 L .63885 .22625 L p F P
0 g
s
0 .203 .727 r
.6377 .22179 m .63885 .22625 L .64324 .23027 L p F P
0 g
s
0 .181 .714 r
.6322 .21331 m .62823 .20936 L .628 .20891 L p F P
0 g
s
0 0 .514 r
.61625 .18766 m .61821 .19193 L .62133 .19629 L p F P
0 g
s
0 0 .506 r
.61821 .19193 m .61625 .18766 L .61328 .18327 L p F P
0 g
s
.624 .752 .939 r
.76717 .34847 m .77989 .34522 L .78272 .34878 L p F P
0 g
s
.61 .738 .936 r
.77989 .34522 m .76717 .34847 L .76428 .34438 L p F P
0 g
s
.022 .253 .755 r
.64979 .24321 m .64883 .23873 L .64429 .23474 L p F P
0 g
s
0 .227 .743 r
.64324 .23027 m .64429 .23474 L .64883 .23873 L p F P
0 g
s
0 0 .467 r
.61117 .17903 m .61328 .18327 L .61625 .18766 L p F P
0 g
s
0 0 .453 r
.61328 .18327 m .61117 .17903 L .60837 .1746 L p F P
0 g
s
.403 .595 .923 r
.70354 .10063 m .71042 .10158 L .71254 .10589 L p F P
0 g
s
.401 .598 .925 r
.71042 .10158 m .70354 .10063 L .70056 .09626 L p F P
0 g
s
0 0 .411 r
.6061 .1704 m .60837 .1746 L .61117 .17903 L p F P
0 g
s
0 0 .389 r
.60837 .1746 m .6061 .1704 L .60346 .16593 L p F P
0 g
s
0 .181 .714 r
.628 .20891 m .6267 .20482 L p .6322 .21331 L F P
0 g
s
0 .149 .691 r
.628 .20891 m .62506 .20307 L .6267 .20482 L closepath p F P
0 g
s
.061 .28 .77 r
.65387 .24661 m .64979 .24321 L p .65538 .25165 L F P
0 g
s
.029 .259 .759 r
.64979 .24321 m .65387 .24661 L .65072 .24036 L p F P
0 g
s
.029 .259 .759 r
.65072 .24036 m .64883 .23873 L .64979 .24321 L p F P
0 g
s
.205 .404 .837 r
.79221 .17144 m .78848 .16939 L .78554 .16376 L p F P
0 g
s
.394 .589 .921 r
.71254 .10589 m .71942 .10696 L .71646 .1025 L p F P
0 g
s
.394 .589 .921 r
.71646 .1025 m .71042 .10158 L .71254 .10589 L p F P
0 g
s
.931 .959 .77 r
.82741 .32033 m .82822 .31555 L p .82233 .32701 L F P
0 g
s
.931 .959 .77 r
.82233 .32701 m .82265 .32709 L .82741 .32033 L p F P
0 g
s
.923 .963 .653 r
.83183 .30918 m .83201 .30906 L p .82741 .32033 L F P
0 g
s
.923 .963 .653 r
.82741 .32033 m .82822 .31555 L .83183 .30918 L p F P
0 g
s
.082 .298 .781 r
.65701 .25292 m .65538 .25165 L .65477 .24845 L closepath p F P
0 g
s
.061 .28 .77 r
.65538 .25165 m .65477 .24845 L .65387 .24661 L p F P
0 g
s
.692 .275 0 r
.59594 .15314 m .59857 .15726 L .60102 .16177 L p F P
0 g
s
.727 .315 0 r
.59857 .15726 m .59594 .15314 L .59369 .14857 L p F P
0 g
s
0 0 .467 r
.83508 .26018 m .83516 .25551 L .83328 .25052 L p F P
0 g
s
0 0 .366 r
.83516 .25551 m .83508 .26018 L .83644 .26535 L p F P
0 g
s
.469 .648 .937 r
.66603 .08218 m .67668 .08238 L .67932 .08656 L p F P
0 g
s
.467 .651 .939 r
.67668 .08238 m .66603 .08218 L .66301 .07805 L p F P
0 g
s
.761 .338 0 r
.59087 .14451 m .59369 .14857 L .59594 .15314 L p F P
0 g
s
.811 .399 0 r
.58978 .14193 m .59087 .14451 L .59369 .14857 L p F P
0 g
s
.35 .546 .904 r
.7381 .12281 m .74132 .1236 L .73838 .11888 L p F P
0 g
s
.35 .546 .904 r
.73838 .11888 m .7364 .1184 L .7381 .12281 L p F P
0 g
s
.03 .218 .723 r
.82041 .21364 m .81718 .21032 L .8162 .20795 L p F P
0 g
s
.215 .381 .814 r
.65701 .25292 m .66088 .25537 L .66126 .26 L p F P
0 g
s
.243 .398 .819 r
.66126 .26 m .66724 .26358 L .6676 .2682 L p F P
0 g
s
.169 .362 .812 r
.66088 .25537 m .66126 .26 L .66724 .26358 L p F P
0 g
s
0 0 0 r
.83725 .28096 m .8367 .28572 L .83615 .29153 L p F P
0 g
s
0 0 .146 r
.8367 .28572 m .83725 .28096 L .83707 .27539 L p F P
0 g
s
.881 .478 .033 r
.58905 .13981 m .58978 .14193 L .58662 .13766 L p F P
0 g
s
.881 .478 .033 r
.58662 .13766 m .58598 .13581 L .58905 .13981 L p F P
0 g
s
.915 .532 .115 r
.58905 .13981 m .58598 .13581 L .58464 .13097 L p F P
0 g
s
.265 .466 .869 r
.76748 .14386 m .7688 .14833 L .77598 .15134 L p F P
0 g
s
.267 .463 .866 r
.77714 .15585 m .77598 .15134 L .7688 .14833 L p F P
0 g
s
.284 .483 .877 r
.76333 .14229 m .76748 .14386 L .7688 .14833 L p F P
0 g
s
.674 .804 .945 r
.79533 .3436 m .78272 .34878 L .77989 .34522 L p F P
0 g
s
.349 .477 .848 r
.68815 .29233 m .68559 .29139 L .68249 .28532 L p F P
0 g
s
.181 .373 .817 r
.66724 .26358 m .6676 .2682 L .67375 .27175 L p F P
0 g
s
.221 .393 .822 r
.67409 .27635 m .67375 .27175 L .6676 .2682 L p F P
0 g
s
.371 .572 .916 r
.72496 .11197 m .72238 .11147 L .71942 .10696 L p F P
0 g
s
.03 .218 .723 r
.8162 .20795 m .81587 .20484 L p .82041 .21364 L F P
0 g
s
.077 .266 .754 r
.8162 .20795 m .81415 .20331 L .81587 .20484 L closepath p F P
0 g
s
.89 .876 .44 r
.83201 .30906 m .83206 .30868 L .83427 .30233 L p F P
0 g
s
.909 .89 .47 r
.83479 .29761 m .83427 .30233 L .83206 .30868 L p F P
0 g
s
.814 .771 .262 r
.83427 .30233 m .83479 .29761 L .83615 .29153 L p F P
0 g
s
.517 .614 .888 r
.72976 .33151 m .7394 .33188 L .7387 .33665 L p F P
0 g
s
.503 .605 .888 r
.7394 .33188 m .72976 .33151 L .72675 .32636 L p F P
0 g
s
.494 .61 .896 r
.7387 .33665 m .74561 .33677 L .74264 .33204 L p F P
0 g
s
.494 .61 .896 r
.74264 .33204 m .7394 .33188 L .7387 .33665 L p F P
0 g
s
.458 .561 .872 r
.71403 .31942 m .72374 .32115 L p .72519 .32612 L F P
0 g
s
.422 .541 .871 r
.71403 .31942 m .72374 .32115 L .72071 .31588 L p F P
0 g
s
.422 .541 .871 r
.72071 .31588 m .71467 .31462 L .71403 .31942 L p F P
0 g
s
.448 .553 .87 r
.70777 .31326 m .71467 .31462 L .71403 .31942 L p F P
0 g
s
.245 .412 .831 r
.67938 .27926 m .67409 .27635 L p .68079 .28445 L F P
0 g
s
.22 .391 .821 r
.67409 .27635 m .67938 .27926 L .67627 .27321 L p F P
0 g
s
.22 .391 .821 r
.67627 .27321 m .67375 .27175 L .67409 .27635 L p F P
0 g
s
.555 .672 .916 r
.75908 .34503 m .76428 .34438 L .76138 .34019 L p F P
0 g
s
.555 .672 .916 r
.76138 .34019 m .75958 .34035 L .75908 .34503 L p F P
0 g
s
.576 .67 .903 r
.74856 .34142 m .75958 .34035 L .75908 .34503 L p F P
0 g
s
.562 .659 .902 r
.75958 .34035 m .74856 .34142 L .74561 .33677 L p F P
0 g
s
.504 .673 .94 r
.64734 .07449 m .65601 .0741 L .65897 .0782 L p F P
0 g
s
0 0 .464 r
.83327 .24586 m .83328 .25052 L .83516 .25551 L p F P
0 g
s
0 0 .542 r
.83328 .25052 m .83327 .24586 L .8309 .24104 L p F P
0 g
s
.428 .617 .93 r
.69685 .09591 m .70056 .09626 L .69757 .09194 L p F P
0 g
s
.428 .617 .93 r
.69757 .09194 m .6945 .09165 L .69685 .09591 L p F P
0 g
s
.889 .978 .822 r
.82218 .32762 m .82233 .32701 L .82265 .32709 L closepath p F P
0 g
s
.85 .934 .881 r
.82233 .32701 m .82218 .32762 L .81353 .33599 L p F P
0 g
s
.269 .457 .861 r
.7826 .15834 m .77714 .15585 L p .78506 .16351 L F P
0 g
s
.246 .446 .859 r
.77714 .15585 m .7826 .15834 L .77966 .15302 L p F P
0 g
s
.246 .446 .859 r
.77966 .15302 m .77598 .15134 L .77714 .15585 L p F P
0 g
s
.82 .91 .901 r
.81353 .33599 m .8105 .33853 L .80783 .33634 L p F P
0 g
s
.82 .91 .901 r
.80783 .33634 m .81432 .33124 L .81353 .33599 L p F P
0 g
s
.85 .934 .881 r
.8201 .32603 m .82233 .32701 L p .81353 .33599 L F P
0 g
s
.85 .934 .881 r
.81353 .33599 m .81432 .33124 L .8201 .32603 L p F P
0 g
s
.186 .368 .812 r
.66088 .25537 m .65701 .25292 L .65477 .24845 L p F P
0 g
s
.255 .421 .835 r
.68249 .28532 m .68079 .28445 L .6806 .28165 L closepath p F P
0 g
s
.245 .412 .831 r
.68079 .28445 m .6806 .28165 L .67938 .27926 L p F P
0 g
s
.278 .483 .879 r
.76748 .14386 m .76333 .14229 L .76039 .13726 L p F P
0 g
s
.431 .544 .87 r
.71467 .31462 m .70777 .31326 L .70471 .30764 L p F P
0 g
s
.5 .671 .94 r
.65897 .0782 m .66301 .07805 L .65997 .07395 L p F P
0 g
s
.5 .671 .94 r
.65997 .07395 m .65601 .0741 L .65897 .0782 L p F P
0 g
s
.321 .517 .891 r
.75841 .13658 m .75695 .13213 L .74858 .12958 L p F P
0 g
s
.332 .53 .898 r
.74693 .12517 m .74858 .12958 L .75695 .13213 L p F P
0 g
s
.329 .529 .898 r
.74132 .1236 m .74693 .12517 L .74858 .12958 L p F P
0 g
s
.833 .412 0 r
.59087 .14451 m .58978 .14193 L .58662 .13766 L p F P
0 g
s
.463 .645 .936 r
.67932 .08656 m .68176 .08664 L .67875 .08243 L p F P
0 g
s
.463 .645 .936 r
.67875 .08243 m .67668 .08238 L .67932 .08656 L p F P
0 g
s
.896 .958 .829 r
.8201 .32603 m .82283 .32291 L .82233 .32701 L closepath p F P
0 g
s
.931 .959 .77 r
.82822 .31555 m .82283 .32291 L .82233 .32701 L p F P
0 g
s
0 .137 .683 r
.6267 .20482 m .62506 .20307 L .6219 .19704 L p F P
0 g
s
0 0 .542 r
.83079 .23639 m .8309 .24104 L .83327 .24586 L p F P
0 g
s
0 .052 .603 r
.8309 .24104 m .83079 .23639 L .82795 .23174 L p F P
0 g
s
0 0 .13 r
.83709 .27513 m .83707 .27539 L .83725 .28096 L p F P
0 g
s
.072 .265 .754 r
.81587 .20484 m .81415 .20331 L .81114 .1965 L p F P
0 g
s
.324 .53 .901 r
.74693 .12517 m .74132 .1236 L .73838 .11888 L p F P
0 g
s
.223 .42 .844 r
.78554 .16376 m .78506 .16351 L .78481 .1624 L closepath p F P
0 g
s
.269 .457 .861 r
.78506 .16351 m .78481 .1624 L .7826 .15834 L p F P
0 g
s
.366 .488 .85 r
.68815 .29233 m .69619 .29535 L .69618 .30001 L p F P
0 g
s
.308 .469 .857 r
.68829 .28761 m .68815 .29233 L .69619 .29535 L p F P
0 g
s
.349 .477 .848 r
.68249 .28532 m .68829 .28761 L .68815 .29233 L p F P
0 g
s
.363 .56 .91 r
.7364 .1184 m .73457 .11402 L .72496 .11197 L p F P
0 g
s
.377 .574 .916 r
.72294 .10764 m .72496 .11197 L .73457 .11402 L p F P
0 g
s
.371 .572 .916 r
.71942 .10696 m .72294 .10764 L .72496 .11197 L p F P
0 g
s
0 0 .085 r
.83725 .27072 m .83709 .27513 L .83732 .28028 L p F P
0 g
s
0 0 .245 r
.83709 .27513 m .83725 .27072 L .83644 .26535 L p F P
0 g
s
0 0 .13 r
.83725 .28096 m .83732 .28028 L .83709 .27513 L p F P
0 g
s
.205 .404 .837 r
.78554 .16376 m .79122 .16691 L .79221 .17144 L p F P
0 g
s
.195 .401 .837 r
.79122 .16691 m .78554 .16376 L .78481 .1624 L p F P
0 g
s
.928 .935 .575 r
.83183 .30918 m .83206 .30868 L .83201 .30906 L closepath p F P
0 g
s
0 .05 .603 r
.82773 .2271 m .82795 .23174 L .83079 .23639 L p F P
0 g
s
0 .116 .651 r
.82795 .23174 m .82773 .2271 L .82445 .2226 L p F P
0 g
s
.441 .569 .887 r
.72675 .32636 m .72519 .32612 L .72533 .32392 L closepath p F P
0 g
s
.458 .561 .872 r
.72374 .32115 m .72533 .32392 L .72519 .32612 L p F P
0 g
s
.329 .467 .847 r
.68829 .28761 m .68249 .28532 L .6806 .28165 L p F P
0 g
s
.183 .379 .823 r
.79888 .17954 m .79804 .17498 L .79221 .17144 L p F P
0 g
s
.179 .382 .826 r
.79122 .16691 m .79221 .17144 L .79804 .17498 L p F P
0 g
s
0 0 0 r
.83615 .29153 m .83669 .28678 L .83725 .28096 L p F P
0 g
s
.825 .781 .277 r
.83669 .28678 m .83615 .29153 L .83479 .29761 L p F P
0 g
s
.941 .948 .622 r
.83206 .30868 m .83183 .30918 L .82946 .31009 L p F P
0 g
s
.941 .948 .622 r
.82946 .31009 m .83249 .304 L .83206 .30868 L p F P
0 g
s
.909 .89 .47 r
.83206 .30868 m .83249 .304 L .83479 .29761 L p F P
0 g
s
.35 .494 .862 r
.70164 .30194 m .69618 .30001 L p .70455 .30758 L F P
0 g
s
.328 .474 .854 r
.69618 .30001 m .70164 .30194 L .69857 .29626 L p F P
0 g
s
.328 .474 .854 r
.69857 .29626 m .69619 .29535 L .69618 .30001 L p F P
0 g
s
.186 .368 .812 r
.65477 .24845 m .65462 .24712 L p .66088 .25537 L F P
0 g
s
.164 .349 .802 r
.65477 .24845 m .65387 .24661 L .65462 .24712 L closepath p F P
0 g
s
.61 .738 .936 r
.76428 .34438 m .77705 .34153 L .77989 .34522 L p F P
0 g
s
.597 .725 .934 r
.77705 .34153 m .76428 .34438 L .76138 .34019 L p F P
0 g
s
.918 .963 .647 r
.82822 .31555 m .83183 .30918 L .82946 .31009 L p F P
0 g
s
.433 .624 .933 r
.68176 .08664 m .692 .08743 L .6945 .09165 L p F P
0 g
s
.431 .627 .936 r
.692 .08743 m .68176 .08664 L .67875 .08243 L p F P
0 g
s
0 .115 .652 r
.82411 .21798 m .82445 .2226 L .82773 .2271 L p F P
0 g
s
0 .17 .691 r
.82445 .2226 m .82411 .21798 L .82041 .21364 L p F P
0 g
s
.195 .401 .837 r
.78481 .1624 m .78396 .159 L p .79122 .16691 L F P
0 g
s
.227 .43 .852 r
.78481 .1624 m .7826 .15834 L .78396 .159 L closepath p F P
0 g
s
.298 .499 .885 r
.75841 .13658 m .76039 .13726 L .75746 .1323 L p F P
0 g
s
.298 .499 .885 r
.75746 .1323 m .75695 .13213 L .75841 .13658 L p F P
0 g
s
.401 .598 .925 r
.70056 .09626 m .70818 .0973 L .71042 .10158 L p F P
0 g
s
.398 .6 .928 r
.70818 .0973 m .70056 .09626 L .69757 .09194 L p F P
0 g
s
.165 .356 .808 r
.80508 .18779 m .80439 .1832 L .79888 .17954 L p F P
0 g
s
.171 .367 .816 r
.79804 .17498 m .79888 .17954 L .80439 .1832 L p F P
0 g
s
0 0 .235 r
.83654 .26069 m .83644 .26535 L .83725 .27072 L p F P
0 g
s
0 0 .366 r
.83644 .26535 m .83654 .26069 L .83516 .25551 L p F P
0 g
s
0 .17 .692 r
.81995 .20904 m .82041 .21364 L .82411 .21798 L p F P
0 g
s
.03 .218 .723 r
.81587 .20484 m .81995 .20904 L .82041 .21364 L p F P
0 g
s
.149 .335 .794 r
.80815 .19009 m .80508 .18779 L p .8108 .19621 L F P
0 g
s
.121 .317 .787 r
.80508 .18779 m .80815 .19009 L .80516 .18378 L p F P
0 g
s
.121 .317 .787 r
.80516 .18378 m .80439 .1832 L .80508 .18779 L p F P
0 g
s
.503 .605 .888 r
.72675 .32636 m .73963 .32724 L .7394 .33188 L p F P
0 g
s
.488 .595 .887 r
.73963 .32724 m .72675 .32636 L .72533 .32392 L p F P
0 g
s
.73 .83 .927 r
.79863 .34179 m .79533 .3436 L .79256 .34052 L p F P
0 g
s
.674 .804 .945 r
.77989 .34522 m .79256 .34052 L .79533 .3436 L p F P
0 g
s
.467 .651 .939 r
.66301 .07805 m .67389 .07823 L .67668 .08238 L p F P
0 g
s
.466 .653 .941 r
.67389 .07823 m .66301 .07805 L .65997 .07395 L p F P
0 g
s
0 0 .56 r
.6219 .19704 m .62133 .19629 L .62033 .19418 L closepath p F P
0 g
s
0 0 .514 r
.61874 .1912 m .61625 .18766 L p .62133 .19629 L F P
0 g
s
0 0 .514 r
.62133 .19629 m .62033 .19418 L .61874 .1912 L p F P
0 g
s
0 0 .496 r
.61625 .18766 m .61874 .1912 L .61557 .18559 L p F P
0 g
s
0 0 .496 r
.61557 .18559 m .61409 .18345 L .61625 .18766 L p F P
0 g
s
0 0 .467 r
.61625 .18766 m .61409 .18345 L .61117 .17903 L p F P
0 g
s
.017 .217 .725 r
.81528 .20026 m .81587 .20484 L .81995 .20904 L p F P
0 g
s
.072 .265 .754 r
.81114 .1965 m .81528 .20026 L .81587 .20484 L p F P
0 g
s
.154 .348 .804 r
.65462 .24712 m .65387 .24661 L .65072 .24036 L p F P
0 g
s
0 .181 .714 r
.6267 .20482 m .63068 .20893 L .6322 .21331 L p F P
0 g
s
0 .124 .674 r
.62506 .20046 m .6267 .20482 L .63068 .20893 L p F P
0 g
s
0 .137 .683 r
.6219 .19704 m .62506 .20046 L .6267 .20482 L p F P
0 g
s
0 0 .428 r
.60886 .17485 m .61117 .17903 L .61409 .18345 L p F P
0 g
s
0 0 .411 r
.61117 .17903 m .60886 .17485 L .6061 .1704 L p F P
0 g
s
.087 .279 .763 r
.81114 .1965 m .8108 .19621 L .81072 .19557 L closepath p F P
0 g
s
.149 .335 .794 r
.8108 .19621 m .81072 .19557 L .80815 .19009 L p F P
0 g
s
0 0 .371 r
.60363 .16626 m .6061 .1704 L .60886 .17485 L p F P
0 g
s
.622 .216 0 r
.6061 .1704 m .60363 .16626 L p .6029 .16497 L F P
0 g
s
.641 .216 0 r
.60363 .16626 m .60635 .17072 L p .60435 .16755 L F P
0 g
s
.641 .216 0 r
.60095 .16216 m .60363 .16626 L p .60435 .16755 L F P
0 g
s
.622 .216 0 r
.60363 .16626 m .60102 .16177 L p .6029 .16497 L F P
0 g
s
.664 .242 0 r
.59837 .15767 m .60102 .16177 L .60363 .16626 L p F P
0 g
s
.692 .275 0 r
.60102 .16177 m .59837 .15767 L .59594 .15314 L p F P
0 g
s
.392 .592 .924 r
.71042 .10158 m .71646 .1025 L .71349 .0981 L p F P
0 g
s
.392 .592 .924 r
.71349 .0981 m .70818 .0973 L .71042 .10158 L p F P
0 g
s
.727 .297 0 r
.59311 .14909 m .59594 .15314 L .59837 .15767 L p F P
0 g
s
.761 .338 0 r
.59594 .15314 m .59311 .14909 L .59087 .14451 L p F P
0 g
s
0 .18 .713 r
.6377 .22179 m .6363 .2174 L .6322 .21331 L p F P
0 g
s
0 .149 .692 r
.63068 .20893 m .6322 .21331 L .6363 .2174 L p F P
0 g
s
.788 .355 0 r
.58783 .14051 m .59087 .14451 L .59311 .14909 L p F P
0 g
s
.833 .412 0 r
.58662 .13766 m .58783 .14051 L .59087 .14451 L p F P
0 g
s
0 .203 .727 r
.64324 .23027 m .64194 .22586 L .6377 .22179 L p F P
0 g
s
0 .172 .709 r
.6363 .2174 m .6377 .22179 L .64194 .22586 L p F P
0 g
s
.368 .574 .919 r
.72294 .10764 m .71942 .10696 L .71646 .1025 L p F P
0 g
s
0 .227 .743 r
.64758 .23426 m .64324 .23027 L p .64883 .23873 L F P
0 g
s
0 .208 .731 r
.64324 .23027 m .64758 .23426 L .64443 .22821 L p F P
0 g
s
0 .208 .731 r
.64443 .22821 m .64194 .22586 L .64324 .23027 L p F P
0 g
s
.054 .256 .751 r
.81528 .20026 m .81114 .1965 L .81072 .19557 L p F P
0 g
s
.659 .787 .943 r
.79256 .34052 m .77989 .34522 L .77705 .34153 L p F P
0 g
s
.357 .5 .865 r
.70471 .30764 m .70455 .30758 L .70455 .30735 L closepath p F P
0 g
s
.35 .494 .862 r
.70455 .30758 m .70455 .30735 L .70164 .30194 L p F P
0 g
s
.562 .659 .902 r
.74561 .33677 m .75847 .33588 L p .75958 .34035 L F P
0 g
s
.529 .658 .918 r
.75847 .33588 m .74561 .33677 L .74264 .33204 L p F P
0 g
s
.347 .548 .907 r
.7364 .1184 m .73838 .11888 L .73543 .11423 L p F P
0 g
s
.347 .548 .907 r
.73543 .11423 m .73457 .11402 L .7364 .1184 L p F P
0 g
s
0 .251 .757 r
.65072 .24036 m .64883 .23873 L .64766 .23442 L closepath p F P
0 g
s
0 .227 .743 r
.64883 .23873 m .64766 .23442 L .64758 .23426 L p F P
0 g
s
.431 .544 .87 r
.70471 .30764 m .71488 .30993 L .71467 .31462 L p F P
0 g
s
.415 .534 .869 r
.71488 .30993 m .70471 .30764 L .70455 .30735 L p F P
0 g
s
.329 .467 .847 r
.6806 .28165 m .68064 .2798 L p .68829 .28761 L F P
0 g
s
.313 .455 .843 r
.6806 .28165 m .67938 .27926 L .68064 .2798 L closepath p F P
0 g
s
.73 .83 .927 r
.79256 .34052 m .7993 .33708 L .79863 .34179 L p F P
0 g
s
.76 .875 .93 r
.80512 .3339 m .7993 .33708 L .79863 .34179 L p F P
0 g
s
.76 .875 .93 r
.79863 .34179 m .80783 .33634 L .80512 .3339 L p F P
0 g
s
.415 .534 .869 r
.70455 .30735 m .70506 .30278 L p .71488 .30993 L F P
0 g
s
.403 .525 .866 r
.70455 .30735 m .70164 .30194 L .70506 .30278 L closepath p F P
0 g
s
.054 .256 .751 r
.81072 .19557 m .8101 .19164 L p .81528 .20026 L F P
0 g
s
.099 .301 .778 r
.81072 .19557 m .80815 .19009 L .8101 .19164 L closepath p F P
0 g
s
0 .114 .666 r
.62506 .20046 m .6219 .19704 L .62033 .19418 L p F P
0 g
s
.186 .368 .812 r
.65462 .24712 m .66019 .25081 L .66088 .25537 L p F P
0 g
s
.111 .33 .801 r
.65388 .24257 m .65462 .24712 L .66019 .25081 L p F P
0 g
s
.154 .348 .804 r
.65072 .24036 m .65388 .24257 L .65462 .24712 L p F P
0 g
s
.265 .466 .869 r
.77598 .15134 m .77472 .14685 L .76748 .14386 L p F P
0 g
s
.262 .469 .872 r
.76605 .13941 m .76748 .14386 L .77472 .14685 L p F P
0 g
s
.278 .483 .879 r
.76039 .13726 m .76605 .13941 L .76748 .14386 L p F P
0 g
s
0 0 .464 r
.83516 .25551 m .83518 .25085 L .83327 .24586 L p F P
0 g
s
0 0 .361 r
.83518 .25085 m .83516 .25551 L .83654 .26069 L p F P
0 g
s
.272 .483 .88 r
.76605 .13941 m .76039 .13726 L .75746 .1323 L p F P
0 g
s
.125 .341 .806 r
.66019 .25081 m .66088 .25537 L .66659 .25903 L p F P
0 g
s
.169 .362 .812 r
.66724 .26358 m .66659 .25903 L .66088 .25537 L p F P
0 g
s
.917 .969 .786 r
.82906 .31075 m .82822 .31555 L .82283 .32291 L p F P
0 g
s
.918 .963 .647 r
.82946 .31009 m .82906 .31075 L .82822 .31555 L p F P
0 g
s
0 0 0 r
.83732 .28028 m .83725 .28096 L .83669 .28678 L p F P
0 g
s
.488 .595 .887 r
.72533 .32392 m .72585 .32133 L p .73963 .32724 L F P
0 g
s
.48 .589 .885 r
.72533 .32392 m .72374 .32115 L .72585 .32133 L closepath p F P
0 g
s
.426 .62 .932 r
.6945 .09165 m .69757 .09194 L .69458 .08766 L p F P
0 g
s
.426 .62 .932 r
.69458 .08766 m .692 .08743 L .6945 .09165 L p F P
0 g
s
.181 .373 .817 r
.67375 .27175 m .67312 .26722 L .66724 .26358 L p F P
0 g
s
.159 .363 .816 r
.66659 .25903 m .66724 .26358 L .67312 .26722 L p F P
0 g
s
.31 .455 .845 r
.68064 .2798 m .67938 .27926 L .67627 .27321 L p F P
0 g
s
.221 .431 .854 r
.78396 .159 m .7826 .15834 L .77966 .15302 L p F P
0 g
s
.324 .53 .901 r
.73838 .11888 m .74517 .12078 L .74693 .12517 L p F P
0 g
s
.319 .532 .903 r
.74517 .12078 m .73838 .11888 L .73543 .11423 L p F P
0 g
s
.917 .897 .488 r
.83528 .29288 m .83479 .29761 L .83249 .304 L p F P
0 g
s
.825 .781 .277 r
.83479 .29761 m .83528 .29288 L .83669 .28678 L p F P
0 g
s
.238 .445 .861 r
.77598 .15134 m .77966 .15302 L .77672 .14776 L p F P
0 g
s
.238 .445 .861 r
.77672 .14776 m .77472 .14685 L .77598 .15134 L p F P
0 g
s
.186 .377 .82 r
.67375 .27175 m .67627 .27321 L .67316 .26724 L p F P
0 g
s
.186 .377 .82 r
.67316 .26724 m .67312 .26722 L .67375 .27175 L p F P
0 g
s
0 0 0 r
.83669 .28678 m .8369 .28457 L .83732 .28028 L p F P
0 g
s
0 0 .085 r
.83732 .28028 m .83745 .27629 L .83725 .27072 L p F P
0 g
s
.758 .656 .1 r
.83745 .27629 m .83732 .28028 L .8369 .28457 L p F P
0 g
s
.475 .603 .9 r
.7394 .33188 m .74264 .33204 L .73967 .32725 L p F P
0 g
s
.475 .603 .9 r
.73967 .32725 m .73963 .32724 L .7394 .33188 L p F P
0 g
s
0 0 .462 r
.83319 .2412 m .83327 .24586 L .83518 .25085 L p F P
0 g
s
0 0 .542 r
.83327 .24586 m .83319 .2412 L .83079 .23639 L p F P
0 g
s
.462 .647 .939 r
.67668 .08238 m .67875 .08243 L .67574 .07828 L p F P
0 g
s
.462 .647 .939 r
.67574 .07828 m .67389 .07823 L .67668 .08238 L p F P
0 g
s
.4 .534 .875 r
.71467 .31462 m .72071 .31588 L .71768 .3106 L p F P
0 g
s
.4 .534 .875 r
.71768 .3106 m .71488 .30993 L .71467 .31462 L p F P
0 g
s
0 .114 .666 r
.62033 .19418 m .61942 .192 L p .62506 .20046 L F P
0 g
s
0 .076 .637 r
.62033 .19418 m .61874 .1912 L .61942 .192 L closepath p F P
0 g
s
.554 .676 .919 r
.76138 .34019 m .75958 .34035 L .75965 .33764 L closepath p F P
0 g
s
.562 .659 .902 r
.75847 .33588 m .75965 .33764 L .75958 .34035 L p F P
0 g
s
.806 .902 .909 r
.81432 .33124 m .80783 .33634 L .80512 .3339 L p F P
0 g
s
.332 .53 .898 r
.75452 .12746 m .74693 .12517 L p .75695 .13213 L F P
0 g
s
.31 .52 .898 r
.74693 .12517 m .75452 .12746 L .75158 .12271 L p F P
0 g
s
.31 .52 .898 r
.75158 .12271 m .74517 .12078 L .74693 .12517 L p F P
0 g
s
.885 .951 .845 r
.82283 .32291 m .8201 .32603 L .8175 .32455 L p F P
0 g
s
.885 .951 .845 r
.8175 .32455 m .82341 .3182 L .82283 .32291 L p F P
0 g
s
.917 .969 .786 r
.82283 .32291 m .82341 .3182 L .82906 .31075 L p F P
0 g
s
.121 .334 .801 r
.65388 .24257 m .65072 .24036 L .64766 .23442 L p F P
0 g
s
.329 .467 .847 r
.68064 .2798 m .68808 .28298 L .68829 .28761 L p F P
0 g
s
.264 .44 .848 r
.68051 .27513 m .68064 .2798 L .68808 .28298 L p F P
0 g
s
.31 .455 .845 r
.67627 .27321 m .68051 .27513 L .68064 .2798 L p F P
0 g
s
.377 .574 .916 r
.73247 .10964 m .72294 .10764 L p .73457 .11402 L F P
0 g
s
.356 .566 .917 r
.72294 .10764 m .73247 .10964 L .72952 .10515 L p F P
0 g
s
.356 .566 .917 r
.72952 .10515 m .7208 .10333 L .72294 .10764 L p F P
0 g
s
.368 .574 .919 r
.71646 .1025 m .7208 .10333 L .72294 .10764 L p F P
0 g
s
.806 .902 .909 r
.80512 .3339 m .81525 .32643 L .81432 .33124 L p F P
0 g
s
.849 .947 .882 r
.8175 .32455 m .81525 .32643 L .81432 .33124 L p F P
0 g
s
.849 .947 .882 r
.81432 .33124 m .8201 .32603 L .8175 .32455 L p F P
0 g
s
.094 .3 .779 r
.8101 .19164 m .80815 .19009 L .80516 .18378 L p F P
0 g
s
.195 .401 .837 r
.78396 .159 m .79013 .1624 L .79122 .16691 L p F P
0 g
s
.19 .405 .841 r
.78272 .15452 m .78396 .159 L .79013 .1624 L p F P
0 g
s
.221 .431 .854 r
.77966 .15302 m .78272 .15452 L .78396 .159 L p F P
0 g
s
0 0 .541 r
.8306 .23175 m .83079 .23639 L .83319 .2412 L p F P
0 g
s
0 .05 .603 r
.83079 .23639 m .8306 .23175 L .82773 .2271 L p F P
0 g
s
.48 .588 .884 r
.72585 .32133 m .72374 .32115 L .72071 .31588 L p F P
0 g
s
.592 .694 .913 r
.77131 .33377 m .77419 .33771 L .76138 .34019 L p F P
0 g
s
.592 .694 .913 r
.7604 .33556 m .77131 .33377 L p .76138 .34019 L F P
0 g
s
.592 .694 .913 r
.76138 .34019 m .75965 .33764 L .7604 .33556 L p F P
0 g
s
.597 .725 .934 r
.76138 .34019 m .77419 .33771 L .77705 .34153 L p F P
0 g
s
0 0 .071 r
.83735 .26605 m .83725 .27072 L .83745 .27629 L p F P
0 g
s
0 0 .235 r
.83725 .27072 m .83735 .26605 L .83654 .26069 L p F P
0 g
s
.431 .627 .936 r
.67875 .08243 m .68936 .08324 L .692 .08743 L p F P
0 g
s
.429 .629 .938 r
.68936 .08324 m .67875 .08243 L .67574 .07828 L p F P
0 g
s
.398 .6 .928 r
.69757 .09194 m .7058 .09304 L .70818 .0973 L p F P
0 g
s
.395 .602 .93 r
.7058 .09304 m .69757 .09194 L .69458 .08766 L p F P
0 g
s
.402 .526 .867 r
.70506 .30278 m .70164 .30194 L .69857 .29626 L p F P
0 g
s
.308 .469 .857 r
.69549 .29059 m .68829 .28761 L p .69619 .29535 L F P
0 g
s
.291 .449 .847 r
.68829 .28761 m .69549 .29059 L .69241 .28489 L p F P
0 g
s
.291 .449 .847 r
.69241 .28489 m .68808 .28298 L .68829 .28761 L p F P
0 g
s
0 .06 .623 r
.61942 .192 m .61874 .1912 L .61557 .18559 L p F P
0 g
s
.179 .382 .826 r
.79804 .17498 m .7971 .17043 L .79122 .16691 L p F P
0 g
s
.175 .384 .829 r
.79013 .1624 m .79122 .16691 L .7971 .17043 L p F P
0 g
s
0 .049 .604 r
.82742 .22247 m .82773 .2271 L .8306 .23175 L p F P
0 g
s
0 .115 .652 r
.82773 .2271 m .82742 .22247 L .82411 .21798 L p F P
0 g
s
.529 .658 .918 r
.74264 .33204 m .75554 .33148 L .75847 .33588 L p F P
0 g
s
.517 .648 .916 r
.75554 .33148 m .74264 .33204 L .73967 .32725 L p F P
0 g
s
.466 .653 .941 r
.65997 .07395 m .67094 .07412 L .67389 .07823 L p F P
0 g
s
.292 .5 .888 r
.75746 .1323 m .75695 .13213 L .75636 .13047 L closepath p F P
0 g
s
.332 .53 .898 r
.75695 .13213 m .75636 .13047 L .75452 .12746 L p F P
0 g
s
.365 .575 .921 r
.7208 .10333 m .71646 .1025 L .71349 .0981 L p F P
0 g
s
.171 .367 .816 r
.80219 .17773 m .79804 .17498 L p .80439 .1832 L F P
0 g
s
.142 .35 .809 r
.79804 .17498 m .80219 .17773 L .79923 .17185 L p F P
0 g
s
.142 .35 .809 r
.79923 .17185 m .7971 .17043 L .79804 .17498 L p F P
0 g
s
.287 .445 .844 r
.68051 .27513 m .67627 .27321 L .67316 .26724 L p F P
0 g
s
.488 .595 .887 r
.72585 .32133 m .73668 .32236 L p .73963 .32724 L F P
0 g
s
.458 .577 .886 r
.72585 .32133 m .73668 .32236 L .73369 .31743 L p F P
0 g
s
.458 .577 .886 r
.73369 .31743 m .72646 .31653 L .72585 .32133 L p F P
0 g
s
.48 .588 .884 r
.72071 .31588 m .72646 .31653 L .72585 .32133 L p F P
0 g
s
.788 .355 0 r
.59311 .14909 m .59005 .14509 L .58783 .14051 L p F P
0 g
s
0 .115 .654 r
.82368 .21337 m .82411 .21798 L .82742 .22247 L p F P
0 g
s
0 .17 .692 r
.82411 .21798 m .82368 .21337 L .81995 .20904 L p F P
0 g
s
.727 .297 0 r
.59837 .15767 m .59552 .15362 L .59311 .14909 L p F P
0 g
s
.755 .315 0 r
.59005 .14509 m .59311 .14909 L .59552 .15362 L p F P
0 g
s
.664 .242 0 r
.60363 .16626 m .60095 .16216 L .59837 .15767 L p F P
0 g
s
.699 .264 0 r
.59552 .15362 m .59837 .15767 L .60095 .16216 L p F P
0 g
s
.716 .823 .932 r
.7993 .33708 m .79256 .34052 L .78977 .33726 L p F P
0 g
s
.659 .787 .943 r
.77705 .34153 m .78977 .33726 L .79256 .34052 L p F P
0 g
s
0 0 .391 r
.60918 .17516 m .60635 .17072 L p .60906 .17503 L F P
0 g
s
0 0 .391 r
.61173 .17928 m .60918 .17516 L p .60906 .17503 L F P
0 g
s
0 0 .391 r
.60635 .17072 m .60886 .17485 L .61173 .17928 L p F P
0 g
s
.635 .207 0 r
.60918 .17516 m .60876 .17452 L .60609 .17048 L p F P
0 g
s
0 0 .408 r
.60918 .17516 m .60876 .17452 L .60919 .17517 L p F P
0 g
s
0 0 .408 r
.60919 .17517 m .60925 .17526 L .60918 .17516 L p F P
0 g
s
.635 .207 0 r
.60635 .17072 m .60918 .17516 L p .60728 .17223 L F P
0 g
s
0 0 .371 r
.60886 .17485 m .60635 .17072 L p .60543 .16921 L F P
0 g
s
.635 .207 0 r
.60365 .16663 m .60635 .17072 L p .60728 .17223 L F P
0 g
s
0 0 .371 r
.60635 .17072 m .60363 .16626 L p .60543 .16921 L F P
0 g
s
.845 .804 .314 r
.8369 .28457 m .83669 .28678 L .83528 .29288 L p F P
0 g
s
0 0 .428 r
.61409 .18345 m .61173 .17928 L .60886 .17485 L p F P
0 g
s
.96 .944 .652 r
.83249 .304 m .8329 .2993 L p .82915 .31014 L F P
0 g
s
.96 .944 .652 r
.82915 .31014 m .82946 .31009 L .83249 .304 L p F P
0 g
s
.917 .897 .488 r
.83249 .304 m .8329 .2993 L .83528 .29288 L p F P
0 g
s
0 0 .466 r
.61409 .18345 m .61557 .18559 L .61241 .18027 L p F P
0 g
s
0 0 .466 r
.61241 .18027 m .61173 .17928 L .61409 .18345 L p F P
0 g
s
.317 .477 .86 r
.69857 .29626 m .69619 .29535 L .69595 .29145 L closepath p F P
0 g
s
.308 .469 .857 r
.69619 .29535 m .69595 .29145 L .69549 .29059 L p F P
0 g
s
.272 .483 .88 r
.75746 .1323 m .76451 .13498 L .76605 .13941 L p F P
0 g
s
.265 .483 .882 r
.76451 .13498 m .75746 .1323 L .75636 .13047 L p F P
0 g
s
.644 .772 .941 r
.78977 .33726 m .77705 .34153 L .77419 .33771 L p F P
0 g
s
.389 .594 .927 r
.70818 .0973 m .71349 .0981 L .71051 .09375 L p F P
0 g
s
.389 .594 .927 r
.71051 .09375 m .7058 .09304 L .70818 .0973 L p F P
0 g
s
0 .114 .666 r
.61942 .192 m .62319 .19617 L .62506 .20046 L p F P
0 g
s
0 .065 .625 r
.61741 .18774 m .61942 .192 L .62319 .19617 L p F P
0 g
s
0 .06 .623 r
.61557 .18559 m .61741 .18774 L .61942 .192 L p F P
0 g
s
0 .124 .674 r
.63068 .20893 m .62894 .20461 L .62506 .20046 L p F P
0 g
s
0 .092 .649 r
.62319 .19617 m .62506 .20046 L .62894 .20461 L p F P
0 g
s
0 .17 .694 r
.8194 .20444 m .81995 .20904 L .82368 .21337 L p F P
0 g
s
.017 .217 .725 r
.81995 .20904 m .8194 .20444 L .81528 .20026 L p F P
0 g
s
.111 .315 .788 r
.80516 .18378 m .80439 .1832 L .80412 .1816 L closepath p F P
0 g
s
.171 .367 .816 r
.80439 .1832 m .80412 .1816 L .80219 .17773 L p F P
0 g
s
0 0 .227 r
.83656 .25602 m .83654 .26069 L .83735 .26605 L p F P
0 g
s
0 0 .361 r
.83654 .26069 m .83656 .25602 L .83518 .25085 L p F P
0 g
s
0 .149 .692 r
.6363 .2174 m .63467 .21306 L .63068 .20893 L p F P
0 g
s
0 .118 .669 r
.62894 .20461 m .63068 .20893 L .63467 .21306 L p F P
0 g
s
.01 .217 .727 r
.81459 .19569 m .81528 .20026 L .8194 .20444 L p F P
0 g
s
.054 .256 .751 r
.8101 .19164 m .81459 .19569 L .81528 .20026 L p F P
0 g
s
.045 .257 .754 r
.80929 .18709 m .8101 .19164 L .81459 .19569 L p F P
0 g
s
.094 .3 .779 r
.80516 .18378 m .80929 .18709 L .8101 .19164 L p F P
0 g
s
0 .172 .709 r
.64194 .22586 m .64042 .2215 L .6363 .2174 L p F P
0 g
s
0 .144 .689 r
.63467 .21306 m .6363 .2174 L .64042 .2215 L p F P
0 g
s
.343 .55 .91 r
.73543 .11423 m .73457 .11402 L .73291 .1103 L closepath p F P
0 g
s
.377 .574 .916 r
.73457 .11402 m .73291 .1103 L .73247 .10964 L p F P
0 g
s
.213 .429 .855 r
.78272 .15452 m .77966 .15302 L .77672 .14776 L p F P
0 g
s
0 .186 .718 r
.64194 .22586 m .64443 .22821 L .64128 .22234 L p F P
0 g
s
0 .186 .718 r
.64128 .22234 m .64042 .2215 L .64194 .22586 L p F P
0 g
s
.121 .334 .801 r
.64766 .23442 m .64763 .2343 L p .65388 .24257 L F P
0 g
s
.097 .313 .79 r
.64766 .23442 m .64758 .23426 L .64763 .2343 L closepath p F P
0 g
s
.083 .311 .791 r
.64763 .2343 m .64758 .23426 L .64443 .22821 L p F P
0 g
s
.121 .334 .801 r
.64763 .2343 m .65287 .23808 L .65388 .24257 L p F P
0 g
s
.049 .297 .786 r
.64655 .22982 m .64763 .2343 L .65287 .23808 L p F P
0 g
s
.083 .311 .791 r
.64443 .22821 m .64655 .22982 L .64763 .2343 L p F P
0 g
s
.59 .692 .913 r
.75965 .33764 m .75847 .33588 L .7604 .33556 L closepath p F P
0 g
s
.262 .469 .872 r
.77472 .14685 m .77335 .14237 L .76605 .13941 L p F P
0 g
s
.272 .482 .88 r
.76451 .13498 m .76605 .13941 L .77335 .14237 L p F P
0 g
s
.078 .293 .777 r
.80929 .18709 m .80516 .18378 L .80412 .1816 L p F P
0 g
s
.319 .532 .903 r
.73543 .11423 m .74328 .11642 L .74517 .12078 L p F P
0 g
s
.314 .533 .905 r
.74328 .11642 m .73543 .11423 L .73291 .1103 L p F P
0 g
s
.111 .33 .801 r
.66019 .25081 m .65924 .24633 L .65388 .24257 L p F P
0 g
s
.066 .308 .792 r
.65287 .23808 m .65388 .24257 L .65924 .24633 L p F P
0 g
s
.423 .622 .935 r
.692 .08743 m .69458 .08766 L .69159 .08343 L p F P
0 g
s
.423 .622 .935 r
.69159 .08343 m .68936 .08324 L .692 .08743 L p F P
0 g
s
.415 .534 .869 r
.70506 .30278 m .71464 .3053 L p .71488 .30993 L F P
0 g
s
.374 .511 .867 r
.70506 .30278 m .71464 .3053 L .71159 .29994 L p F P
0 g
s
.374 .511 .867 r
.71159 .29994 m .7052 .29808 L .70506 .30278 L p F P
0 g
s
.402 .526 .867 r
.69857 .29626 m .7052 .29808 L .70506 .30278 L p F P
0 g
s
.265 .483 .882 r
.75636 .13047 m .75529 .12772 L p .76451 .13498 L F P
0 g
s
.291 .504 .891 r
.75636 .13047 m .75452 .12746 L .75529 .12772 L closepath p F P
0 g
s
.716 .823 .932 r
.78977 .33726 m .80046 .33219 L .7993 .33708 L p F P
0 g
s
.743 .855 .932 r
.80239 .33122 m .80046 .33219 L .7993 .33708 L p F P
0 g
s
.743 .855 .932 r
.7993 .33708 m .80512 .3339 L .80239 .33122 L p F P
0 g
s
0 0 .462 r
.83518 .25085 m .83512 .24619 L .83319 .2412 L p F P
0 g
s
0 0 .357 r
.83512 .24619 m .83518 .25085 L .83656 .25602 L p F P
0 g
s
.125 .341 .806 r
.66659 .25903 m .66568 .25456 L .66019 .25081 L p F P
0 g
s
.091 .325 .8 r
.65924 .24633 m .66019 .25081 L .66568 .25456 L p F P
0 g
s
.465 .579 .885 r
.72646 .31653 m .72071 .31588 L .71768 .3106 L p F P
0 g
s
.384 .517 .868 r
.7052 .29808 m .69857 .29626 L .69595 .29145 L p F P
0 g
s
.927 .971 .697 r
.82906 .31075 m .82915 .31014 L .82946 .31009 L closepath p F P
0 g
s
.46 .65 .941 r
.67389 .07823 m .67574 .07828 L .67271 .07416 L p F P
0 g
s
.46 .65 .941 r
.67271 .07416 m .67094 .07412 L .67389 .07823 L p F P
0 g
s
.078 .293 .777 r
.80412 .1816 m .8035 .17866 L p .80929 .18709 L F P
0 g
s
.122 .334 .801 r
.80412 .1816 m .80219 .17773 L .8035 .17866 L closepath p F P
0 g
s
0 0 .071 r
.83745 .27629 m .83754 .27163 L .83735 .26605 L p F P
0 g
s
.78 .672 .122 r
.83754 .27163 m .83745 .27629 L .83699 .28208 L p F P
0 g
s
.758 .656 .1 r
.8369 .28457 m .83699 .28208 L .83745 .27629 L p F P
0 g
s
.908 .966 .807 r
.82915 .31014 m .82906 .31075 L .82341 .3182 L p F P
0 g
s
.159 .363 .816 r
.67004 .26127 m .66659 .25903 L p .67312 .26722 L F P
0 g
s
.129 .344 .808 r
.66659 .25903 m .67004 .26127 L .66691 .25539 L p F P
0 g
s
.129 .344 .808 r
.66691 .25539 m .66568 .25456 L .66659 .25903 L p F P
0 g
s
0 .035 .598 r
.61741 .18774 m .61557 .18559 L .61241 .18027 L p F P
0 g
s
.231 .445 .862 r
.77472 .14685 m .77672 .14776 L .77378 .14257 L p F P
0 g
s
.231 .445 .862 r
.77378 .14257 m .77335 .14237 L .77472 .14685 L p F P
0 g
s
.591 .688 .909 r
.7604 .33556 m .75847 .33588 L .75554 .33148 L p F P
0 g
s
.863 .787 .29 r
.83587 .28766 m .83699 .28208 L .8369 .28457 L closepath p F P
0 g
s
.845 .804 .314 r
.83587 .28766 m .8369 .28457 L p .83528 .29288 L F P
0 g
s
.305 .522 .9 r
.74517 .12078 m .75158 .12271 L .74864 .11802 L p F P
0 g
s
.305 .522 .9 r
.74864 .11802 m .74328 .11642 L .74517 .12078 L p F P
0 g
s
.174 .376 .822 r
.67316 .26724 m .67312 .26722 L .6731 .26713 L closepath p F P
0 g
s
.159 .363 .816 r
.67312 .26722 m .6731 .26713 L .67004 .26127 L p F P
0 g
s
.287 .445 .844 r
.67316 .26724 m .68005 .27054 L .68051 .27513 L p F P
0 g
s
.265 .434 .843 r
.68005 .27054 m .67316 .26724 L .6731 .26713 L p F P
0 g
s
.265 .434 .843 r
.6731 .26713 m .67268 .26261 L p .68005 .27054 L F P
0 g
s
.248 .421 .837 r
.6731 .26713 m .67004 .26127 L .67268 .26261 L closepath p F P
0 g
s
.353 .568 .919 r
.7208 .10333 m .72952 .10515 L .72656 .10072 L p F P
0 g
s
.353 .568 .919 r
.72656 .10072 m .71853 .09905 L .7208 .10333 L p F P
0 g
s
.365 .575 .921 r
.71349 .0981 m .71853 .09905 L .7208 .10333 L p F P
0 g
s
0 0 .461 r
.83303 .23655 m .83319 .2412 L .83512 .24619 L p F P
0 g
s
0 0 .541 r
.83319 .2412 m .83303 .23655 L .8306 .23175 L p F P
0 g
s
.908 .966 .807 r
.82698 .30981 m .82915 .31014 L p .82341 .3182 L F P
0 g
s
.939 .962 .741 r
.82698 .30981 m .82941 .30608 L .82915 .31014 L closepath p F P
0 g
s
.96 .944 .652 r
.8329 .2993 m .82941 .30608 L .82915 .31014 L p F P
0 g
s
.922 .903 .503 r
.83575 .28814 m .83528 .29288 L .8329 .2993 L p F P
0 g
s
.845 .804 .314 r
.83528 .29288 m .83575 .28814 L .83587 .28766 L p F P
0 g
s
.791 .911 .923 r
.81525 .32643 m .80512 .3339 L .80239 .33122 L p F P
0 g
s
.474 .605 .902 r
.73967 .32725 m .73963 .32724 L .73963 .32719 L closepath p F P
0 g
s
.488 .595 .887 r
.73668 .32236 m .73963 .32719 L .73963 .32724 L p F P
0 g
s
.517 .648 .916 r
.73967 .32725 m .7526 .327 L .75554 .33148 L p F P
0 g
s
.518 .628 .9 r
.74964 .32246 m .7526 .327 L .73967 .32725 L p F P
0 g
s
.518 .628 .9 r
.74056 .32237 m .74964 .32246 L p .73967 .32725 L F P
0 g
s
.518 .628 .9 r
.73967 .32725 m .73963 .32719 L .74056 .32237 L p F P
0 g
s
.395 .602 .93 r
.69458 .08766 m .70328 .08882 L .7058 .09304 L p F P
0 g
s
.393 .605 .933 r
.70328 .08882 m .69458 .08766 L .69159 .08343 L p F P
0 g
s
.515 .625 .899 r
.73963 .32719 m .73668 .32236 L .74056 .32237 L closepath p F P
0 g
s
.392 .538 .883 r
.71768 .3106 m .71488 .30993 L .71476 .30551 L closepath p F P
0 g
s
.415 .534 .869 r
.71464 .3053 m .71476 .30551 L .71488 .30993 L p F P
0 g
s
.429 .629 .938 r
.67574 .07828 m .68656 .07908 L .68936 .08324 L p F P
0 g
s
.426 .632 .94 r
.68656 .07908 m .67574 .07828 L .67271 .07416 L p F P
0 g
s
.186 .407 .844 r
.78137 .15006 m .78272 .15452 L .78893 .1579 L p F P
0 g
s
.213 .429 .855 r
.77672 .14776 m .78137 .15006 L .78272 .15452 L p F P
0 g
s
.19 .405 .841 r
.79013 .1624 m .78893 .1579 L .78272 .15452 L p F P
0 g
s
.574 .682 .914 r
.7604 .33556 m .77131 .33377 L .76842 .32973 L p F P
0 g
s
.574 .682 .914 r
.76842 .32973 m .76153 .33065 L .7604 .33556 L p F P
0 g
s
.591 .688 .909 r
.75554 .33148 m .76153 .33065 L .7604 .33556 L p F P
0 g
s
.264 .44 .848 r
.68808 .28298 m .68758 .27843 L .68051 .27513 L p F P
0 g
s
.238 .429 .848 r
.68005 .27054 m .68051 .27513 L .68758 .27843 L p F P
0 g
s
.884 .924 .845 r
.82341 .3182 m .82403 .31345 L p .81587 .32344 L F P
0 g
s
.884 .924 .845 r
.81587 .32344 m .8175 .32455 L .82341 .3182 L p F P
0 g
s
.908 .966 .807 r
.82341 .3182 m .82403 .31345 L .82698 .30981 L p F P
0 g
s
.047 .295 .785 r
.64655 .22982 m .64443 .22821 L .64128 .22234 L p F P
0 g
s
.361 .577 .924 r
.71853 .09905 m .71349 .0981 L .71051 .09375 L p F P
0 g
s
.286 .505 .893 r
.75529 .12772 m .75452 .12746 L .75158 .12271 L p F P
0 g
s
0 0 .547 r
.83033 .22711 m .8306 .23175 L .83303 .23655 L p F P
0 g
s
0 .049 .604 r
.8306 .23175 m .83033 .22711 L .82742 .22247 L p F P
0 g
s
.115 .333 .802 r
.8035 .17866 m .80219 .17773 L .79923 .17185 L p F P
0 g
s
.791 .911 .923 r
.81587 .32344 m .81525 .32643 L p .80239 .33122 L F P
0 g
s
.834 .929 .894 r
.81525 .32643 m .81587 .32344 L .8175 .32455 L closepath p F P
0 g
s
0 0 .059 r
.83738 .26139 m .83735 .26605 L .83754 .27163 L p F P
0 g
s
0 0 .227 r
.83735 .26605 m .83738 .26139 L .83656 .25602 L p F P
0 g
s
.204 .427 .856 r
.78137 .15006 m .77672 .14776 L .77378 .14257 L p F P
0 g
s
.175 .384 .829 r
.7971 .17043 m .79606 .1659 L .79013 .1624 L p F P
0 g
s
.181 .396 .836 r
.78893 .1579 m .79013 .1624 L .79606 .1659 L p F P
0 g
s
.644 .772 .941 r
.77419 .33771 m .78695 .33385 L .78977 .33726 L p F P
0 g
s
.63 .758 .939 r
.78695 .33385 m .77419 .33771 L .77131 .33377 L p F P
0 g
s
.755 .315 0 r
.59552 .15362 m .59246 .14962 L .59005 .14509 L p F P
0 g
s
.699 .264 0 r
.60095 .16216 m .59808 .15812 L .59552 .15362 L p F P
0 g
s
.727 .282 0 r
.59246 .14962 m .59552 .15362 L .59808 .15812 L p F P
0 g
s
.263 .439 .848 r
.68808 .28298 m .69241 .28489 L .68932 .27925 L p F P
0 g
s
.263 .439 .848 r
.68932 .27925 m .68758 .27843 L .68808 .28298 L p F P
0 g
s
.265 .483 .882 r
.75529 .12772 m .76285 .13056 L .76451 .13498 L p F P
0 g
s
.261 .486 .886 r
.75348 .12334 m .75529 .12772 L .76285 .13056 L p F P
0 g
s
.286 .505 .893 r
.75158 .12271 m .75348 .12334 L .75529 .12772 L p F P
0 g
s
.641 .216 0 r
.60635 .17072 m .60365 .16663 L .60095 .16216 L p F P
0 g
s
.675 .237 0 r
.59808 .15812 m .60095 .16216 L .60365 .16663 L p F P
0 g
s
.7 .825 .942 r
.80046 .33219 m .78977 .33726 L .78695 .33385 L p F P
0 g
s
0 .053 .609 r
.82703 .21785 m .82742 .22247 L .83033 .22711 L p F P
0 g
s
0 .115 .654 r
.82742 .22247 m .82703 .21785 L .82368 .21337 L p F P
0 g
s
.384 .517 .868 r
.69595 .29145 m .69598 .29074 L p .7052 .29808 L F P
0 g
s
.372 .507 .865 r
.69595 .29145 m .69549 .29059 L .69598 .29074 L closepath p F P
0 g
s
.336 .549 .911 r
.73291 .1103 m .73247 .10964 L .73261 .10967 L closepath p F P
0 g
s
.314 .533 .905 r
.73291 .1103 m .73261 .10967 L p .74328 .11642 L F P
0 g
s
.386 .596 .929 r
.7058 .09304 m .71051 .09375 L .70753 .08945 L p F P
0 g
s
.386 .596 .929 r
.70753 .08945 m .70328 .08882 L .7058 .09304 L p F P
0 g
s
0 0 .435 r
.61173 .17928 m .61241 .18027 L .60925 .17526 L p F P
0 g
s
0 0 .435 r
.60925 .17526 m .60918 .17516 L .61173 .17928 L p F P
0 g
s
0 .065 .625 r
.62319 .19617 m .62109 .19193 L .61741 .18774 L p F P
0 g
s
0 .035 .596 r
.61516 .18354 m .61741 .18774 L .62109 .19193 L p F P
0 g
s
0 .035 .598 r
.61241 .18027 m .61516 .18354 L .61741 .18774 L p F P
0 g
s
.131 .347 .809 r
.7971 .17043 m .79923 .17185 L .79626 .16604 L p F P
0 g
s
.131 .347 .809 r
.79626 .16604 m .79606 .1659 L .7971 .17043 L p F P
0 g
s
0 .092 .649 r
.62894 .20461 m .62698 .20035 L .62319 .19617 L p F P
0 g
s
0 .062 .622 r
.62109 .19193 m .62319 .19617 L .62698 .20035 L p F P
0 g
s
.37 .508 .866 r
.69598 .29074 m .69549 .29059 L .69241 .28489 L p F P
0 g
s
0 .123 .661 r
.82316 .20877 m .82368 .21337 L .82703 .21785 L p F P
0 g
s
0 .17 .694 r
.82368 .21337 m .82316 .20877 L .8194 .20444 L p F P
0 g
s
.465 .579 .885 r
.71768 .3106 m .72664 .31186 L .72646 .31653 L p F P
0 g
s
.449 .571 .885 r
.72664 .31186 m .71768 .3106 L .71476 .30551 L p F P
0 g
s
.332 .551 .913 r
.73261 .10967 m .73247 .10964 L .72952 .10515 L p F P
0 g
s
0 .118 .669 r
.63467 .21306 m .63283 .20877 L .62894 .20461 L p F P
0 g
s
0 .088 .644 r
.62698 .20035 m .62894 .20461 L .63283 .20877 L p F P
0 g
s
.314 .533 .905 r
.73261 .10967 m .74128 .11207 L .74328 .11642 L p F P
0 g
s
.311 .536 .908 r
.73043 .10537 m .73261 .10967 L .74128 .11207 L p F P
0 g
s
.332 .551 .913 r
.72952 .10515 m .73043 .10537 L .73261 .10967 L p F P
0 g
s
.078 .293 .777 r
.8035 .17866 m .80838 .18256 L .80929 .18709 L p F P
0 g
s
.068 .293 .779 r
.80246 .17415 m .8035 .17866 L .80838 .18256 L p F P
0 g
s
.115 .333 .802 r
.79923 .17185 m .80246 .17415 L .8035 .17866 L p F P
0 g
s
.384 .517 .868 r
.69598 .29074 m .70499 .29347 L .7052 .29808 L p F P
0 g
s
.329 .497 .873 r
.69596 .28605 m .69598 .29074 L .70499 .29347 L p F P
0 g
s
.37 .508 .866 r
.69241 .28489 m .69596 .28605 L .69598 .29074 L p F P
0 g
s
0 .184 .705 r
.81875 .19986 m .8194 .20444 L .82316 .20877 L p F P
0 g
s
.01 .217 .727 r
.8194 .20444 m .81875 .19986 L .81459 .19569 L p F P
0 g
s
.91 .812 .341 r
.83699 .28208 m .83705 .27744 L p .83577 .2879 L F P
0 g
s
.91 .812 .341 r
.83577 .2879 m .83587 .28766 L .83699 .28208 L p F P
0 g
s
.78 .672 .122 r
.83699 .28208 m .83705 .27744 L .83754 .27163 L p F P
0 g
s
0 .144 .689 r
.63813 .21661 m .63467 .21306 L p .64042 .2215 L F P
0 g
s
0 .129 .677 r
.63467 .21306 m .63813 .21661 L .63498 .21102 L p F P
0 g
s
0 .129 .677 r
.63498 .21102 m .63283 .20877 L .63467 .21306 L p F P
0 g
s
.95 .953 .664 r
.83329 .29459 m .8329 .2993 L .82941 .30608 L p F P
0 g
s
.922 .903 .503 r
.8329 .2993 m .83329 .29459 L .83575 .28814 L p F P
0 g
s
.439 .571 .89 r
.72646 .31653 m .73369 .31743 L .73068 .31247 L p F P
0 g
s
.439 .571 .89 r
.73068 .31247 m .72664 .31186 L .72646 .31653 L p F P
0 g
s
.045 .257 .754 r
.81459 .19569 m .81382 .19113 L .80929 .18709 L p F P
0 g
s
.038 .258 .756 r
.80838 .18256 m .80929 .18709 L .81382 .19113 L p F P
0 g
s
.003 .217 .729 r
.81382 .19113 m .81459 .19569 L .81875 .19986 L p F P
0 g
s
.241 .421 .84 r
.67268 .26261 m .67004 .26127 L .66691 .25539 L p F P
0 g
s
0 0 .22 r
.83652 .25136 m .83656 .25602 L .83738 .26139 L p F P
0 g
s
0 0 .357 r
.83656 .25602 m .83652 .25136 L .83512 .24619 L p F P
0 g
s
0 .176 .712 r
.64128 .22234 m .64042 .2215 L .63938 .2189 L closepath p F P
0 g
s
0 .144 .689 r
.64042 .2215 m .63938 .2189 L .63813 .21661 L p F P
0 g
s
0 .011 .572 r
.61516 .18354 m .61241 .18027 L .60925 .17526 L p F P
0 g
s
.421 .625 .937 r
.68936 .08324 m .69159 .08343 L .68858 .07926 L p F P
0 g
s
.421 .625 .937 r
.68858 .07926 m .68656 .07908 L .68936 .08324 L p F P
0 g
s
.272 .482 .88 r
.77084 .13754 m .76451 .13498 L p .77335 .14237 L F P
0 g
s
.247 .47 .877 r
.76451 .13498 m .77084 .13754 L .76791 .13261 L p F P
0 g
s
.247 .47 .877 r
.76791 .13261 m .76285 .13056 L .76451 .13498 L p F P
0 g
s
.049 .297 .786 r
.65287 .23808 m .6516 .23366 L .64655 .22982 L p F P
0 g
s
.002 .274 .775 r
.6452 .22541 m .64655 .22982 L .6516 .23366 L p F P
0 g
s
.047 .295 .785 r
.64128 .22234 m .6452 .22541 L .64655 .22982 L p F P
0 g
s
.577 .678 .909 r
.76153 .33065 m .75554 .33148 L .7526 .327 L p F P
0 g
s
.066 .308 .792 r
.65924 .24633 m .65804 .24191 L .65287 .23808 L p F P
0 g
s
.02 .285 .781 r
.6516 .23366 m .65287 .23808 L .65804 .24191 L p F P
0 g
s
.515 .624 .897 r
.74056 .32237 m .73668 .32236 L .73369 .31743 L p F P
0 g
s
.011 .279 .778 r
.6452 .22541 m .64128 .22234 L .63938 .2189 L p F P
0 g
s
.091 .325 .8 r
.66379 .24959 m .65924 .24633 L p .66568 .25456 L F P
0 g
s
.066 .308 .792 r
.65924 .24633 m .66379 .24959 L .66066 .24385 L p F P
0 g
s
.066 .308 .792 r
.66066 .24385 m .65804 .24191 L .65924 .24633 L p F P
0 g
s
.35 .503 .87 r
.7052 .29808 m .71159 .29994 L .70854 .2946 L p F P
0 g
s
.35 .503 .87 r
.70854 .2946 m .70499 .29347 L .7052 .29808 L p F P
0 g
s
.102 .328 .801 r
.80246 .17415 m .79923 .17185 L .79626 .16604 L p F P
0 g
s
0 0 .461 r
.83512 .24619 m .83498 .24153 L .83303 .23655 L p F P
0 g
s
0 0 .354 r
.83498 .24153 m .83512 .24619 L .83652 .25136 L p F P
0 g
s
.224 .445 .864 r
.77378 .14257 m .77335 .14237 L .7729 .14105 L closepath p F P
0 g
s
.272 .482 .88 r
.77335 .14237 m .7729 .14105 L .77084 .13754 L p F P
0 g
s
.3 .523 .902 r
.74328 .11642 m .74864 .11802 L .74569 .11339 L p F P
0 g
s
.3 .523 .902 r
.74569 .11339 m .74128 .11207 L .74328 .11642 L p F P
0 g
s
.11 .341 .81 r
.66691 .25539 m .66568 .25456 L .66498 .25182 L closepath p F P
0 g
s
.091 .325 .8 r
.66568 .25456 m .66498 .25182 L .66379 .24959 L p F P
0 g
s
.393 .605 .933 r
.69159 .08343 m .70063 .08462 L .70328 .08882 L p F P
0 g
s
.389 .607 .935 r
.70063 .08462 m .69159 .08343 L .68858 .07926 L p F P
0 g
s
.7 .825 .942 r
.80115 .32992 m .80046 .33219 L p .78695 .33385 L F P
0 g
s
.727 .838 .933 r
.80046 .33219 m .80115 .32992 L .80239 .33122 L closepath p F P
0 g
s
.349 .569 .922 r
.71853 .09905 m .72656 .10072 L .72359 .09634 L p F P
0 g
s
.349 .569 .922 r
.72359 .09634 m .71613 .0948 L .71853 .09905 L p F P
0 g
s
.361 .577 .924 r
.71051 .09375 m .71613 .0948 L .71853 .09905 L p F P
0 g
s
.426 .632 .94 r
.67271 .07416 m .68362 .07496 L .68656 .07908 L p F P
0 g
s
0 0 .059 r
.83754 .27163 m .83757 .26698 L .83738 .26139 L p F P
0 g
s
.795 .683 .138 r
.83757 .26698 m .83754 .27163 L .83705 .27744 L p F P
0 g
s
.884 .924 .845 r
.82403 .31345 m .81598 .32166 L .81587 .32344 L p F P
0 g
s
.847 .914 .879 r
.81486 .32266 m .81598 .32166 L .81587 .32344 L closepath p F P
0 g
s
.791 .911 .923 r
.80239 .33122 m .81486 .32266 L .81587 .32344 L p F P
0 g
s
.28 .506 .895 r
.75348 .12334 m .75158 .12271 L .74864 .11802 L p F P
0 g
s
.204 .427 .856 r
.77378 .14257 m .77991 .14561 L .78137 .15006 L p F P
0 g
s
.195 .426 .857 r
.77991 .14561 m .77378 .14257 L .7729 .14105 L p F P
0 g
s
.943 .947 .753 r
.82941 .30608 m .82966 .30142 L p .82464 .30905 L F P
0 g
s
.943 .947 .753 r
.82464 .30905 m .82698 .30981 L .82941 .30608 L p F P
0 g
s
.95 .953 .664 r
.82941 .30608 m .82966 .30142 L .83329 .29459 L p F P
0 g
s
.787 .852 .9 r
.80115 .32992 m .80239 .33122 L .81486 .32266 L p F P
0 g
s
.357 .579 .926 r
.71613 .0948 m .71051 .09375 L .70753 .08945 L p F P
0 g
s
.19 .401 .839 r
.67195 .25807 m .67268 .26261 L .67931 .26602 L p F P
0 g
s
.241 .421 .84 r
.66691 .25539 m .67195 .25807 L .67268 .26261 L p F P
0 g
s
.265 .434 .843 r
.67268 .26261 m .67931 .26602 L .68005 .27054 L p F P
0 g
s
.351 .499 .866 r
.69596 .28605 m .69241 .28489 L .68932 .27925 L p F P
0 g
s
0 0 .453 r
.83285 .23305 m .83303 .23655 L .83498 .24153 L p F P
0 g
s
0 0 .547 r
.83203 .23046 m .83033 .22711 L p .83303 .23655 L F P
0 g
s
0 0 .547 r
.83303 .23655 m .83285 .23305 L .83203 .23046 L p F P
0 g
s
.862 .814 .331 r
.83575 .28814 m .83577 .2879 L .83587 .28766 L closepath p F P
0 g
s
.186 .407 .844 r
.78893 .1579 m .78763 .15343 L .78137 .15006 L p F P
0 g
s
.181 .409 .847 r
.77991 .14561 m .78137 .15006 L .78763 .15343 L p F P
0 g
s
.449 .571 .885 r
.71476 .30551 m .71478 .30532 L p .72664 .31186 L F P
0 g
s
.44 .564 .883 r
.71476 .30551 m .71464 .3053 L .71478 .30532 L closepath p F P
0 g
s
.63 .758 .939 r
.77131 .33377 m .78412 .3303 L .78695 .33385 L p F P
0 g
s
.617 .746 .938 r
.78412 .3303 m .77131 .33377 L .76842 .32973 L p F P
0 g
s
.924 .904 .504 r
.83577 .2879 m .83575 .28814 L .83329 .29459 L p F P
0 g
s
.441 .564 .883 r
.71478 .30532 m .71464 .3053 L .71159 .29994 L p F P
0 g
s
.449 .571 .885 r
.71478 .30532 m .72644 .30728 L .72664 .31186 L p F P
0 g
s
.408 .562 .896 r
.71504 .30058 m .71478 .30532 L .72644 .30728 L p F P
0 g
s
.441 .564 .883 r
.71159 .29994 m .71504 .30058 L .71478 .30532 L p F P
0 g
s
.215 .41 .839 r
.67195 .25807 m .66691 .25539 L .66498 .25182 L p F P
0 g
s
.907 .968 .806 r
.82403 .31345 m .82464 .30905 L .82698 .30981 L closepath p F P
0 g
s
0 .256 .764 r
.63938 .2189 m .63813 .21661 L .6388 .21716 L closepath p F P
0 g
s
.011 .279 .778 r
.63938 .2189 m .6388 .21716 L p .6452 .22541 L F P
0 g
s
.195 .426 .857 r
.7729 .14105 m .77178 .13795 L p .77991 .14561 L F P
0 g
s
.228 .454 .87 r
.7729 .14105 m .77084 .13754 L .77178 .13795 L closepath p F P
0 g
s
.945 .892 .494 r
.83579 .28351 m .83577 .2879 L .83366 .28994 L p F P
0 g
s
.91 .812 .341 r
.83705 .27744 m .83579 .28351 L .83577 .2879 L p F P
0 g
s
.924 .904 .504 r
.83329 .29459 m .83366 .28994 L .83577 .2879 L p F P
0 g
s
.727 .282 0 r
.59808 .15812 m .59501 .15412 L .59246 .14962 L p F P
0 g
s
.238 .429 .848 r
.68622 .27363 m .68005 .27054 L p .68758 .27843 L F P
0 g
s
.22 .413 .84 r
.68005 .27054 m .68622 .27363 L .68312 .26803 L p F P
0 g
s
.22 .413 .84 r
.68312 .26803 m .67931 .26602 L .68005 .27054 L p F P
0 g
s
.494 .617 .902 r
.74056 .32237 m .74964 .32246 L .74668 .31786 L p F P
0 g
s
.494 .617 .902 r
.74668 .31786 m .74093 .31764 L .74056 .32237 L p F P
0 g
s
.515 .624 .897 r
.73369 .31743 m .74093 .31764 L .74056 .32237 L p F P
0 g
s
.675 .237 0 r
.60365 .16663 m .60076 .16259 L .59808 .15812 L p F P
0 g
s
.703 .254 0 r
.59501 .15412 m .59808 .15812 L .60076 .16259 L p F P
0 g
s
.7 .825 .942 r
.78695 .33385 m .79964 .32831 L .80115 .32992 L p F P
0 g
s
.685 .81 .942 r
.79964 .32831 m .78695 .33385 L .78412 .3303 L p F P
0 g
s
.647 .208 0 r
.60365 .16663 m .60609 .17048 L .60293 .16602 L p F P
0 g
s
0 0 .473 r
.60609 .17048 m .60293 .16602 L p .60549 .1696 L F P
0 g
s
.635 .207 0 r
.60609 .17048 m .60365 .16663 L p .60752 .1726 L F P
0 g
s
0 0 .473 r
.60654 .17106 m .60609 .17048 L p .60549 .1696 L F P
0 g
s
.635 .207 0 r
.60918 .17516 m .60609 .17048 L .60752 .1726 L F
.647 .208 0 r
.60293 .16602 m .60076 .16259 L .60365 .16663 L p F P
0 g
s
0 0 .53 r
.83203 .23046 m .83033 .22711 L .83012 .22445 L closepath p F P
0 g
s
0 .053 .609 r
.82875 .2206 m .82703 .21785 L p .83033 .22711 L F P
0 g
s
0 .053 .609 r
.83033 .22711 m .83012 .22445 L .82875 .2206 L p F P
0 g
s
.383 .598 .931 r
.70328 .08882 m .70753 .08945 L .70455 .0852 L p F P
0 g
s
.383 .598 .931 r
.70455 .0852 m .70063 .08462 L .70328 .08882 L p F P
0 g
s
.866 .925 .864 r
.82464 .30905 m .82403 .31345 L .81598 .32166 L p F P
0 g
s
.181 .396 .836 r
.79331 .1605 m .78893 .1579 L p .79606 .1659 L F P
0 g
s
.152 .38 .831 r
.78893 .1579 m .79331 .1605 L .79037 .15505 L p F P
0 g
s
.152 .38 .831 r
.79037 .15505 m .78763 .15343 L .78893 .1579 L p F P
0 g
s
.261 .486 .886 r
.76285 .13056 m .76108 .12617 L .75348 .12334 L p F P
0 g
s
.258 .489 .888 r
.75155 .11899 m .75348 .12334 L .76108 .12617 L p F P
0 g
s
.28 .506 .895 r
.74864 .11802 m .75155 .11899 L .75348 .12334 L p F P
0 g
s
.327 .552 .915 r
.73043 .10537 m .72952 .10515 L .72656 .10072 L p F P
0 g
s
.558 .678 .919 r
.76153 .33065 m .76842 .32973 L .76551 .3256 L p F P
0 g
s
.558 .678 .919 r
.76551 .3256 m .76179 .32599 L .76153 .33065 L p F P
0 g
s
.577 .678 .909 r
.7526 .327 m .76179 .32599 L .76153 .33065 L p F P
0 g
s
0 .011 .572 r
.60925 .17526 m .61271 .17939 L .61516 .18354 L p F P
0 g
s
0 0 .544 r
.61271 .17939 m .60925 .17526 L .60876 .17452 L p F P
0 g
s
0 0 .048 r
.83735 .25673 m .83738 .26139 L .83757 .26698 L p F P
0 g
s
0 0 .22 r
.83738 .26139 m .83735 .25673 L .83652 .25136 L p F P
0 g
s
0 .035 .596 r
.62109 .19193 m .61879 .18775 L .61516 .18354 L p F P
0 g
s
0 .007 .566 r
.61271 .17939 m .61516 .18354 L .61879 .18775 L p F P
0 g
s
.834 .903 .887 r
.81598 .32166 m .81486 .32266 L .81217 .32041 L p F P
0 g
s
.787 .852 .9 r
.81486 .32266 m .81217 .32041 L p .80115 .32992 L F P
0 g
s
.834 .903 .887 r
.81217 .32041 m .81617 .31704 L .81598 .32166 L p F P
0 g
s
.866 .925 .864 r
.82444 .30895 m .82464 .30905 L p .81598 .32166 L F P
0 g
s
.866 .925 .864 r
.81598 .32166 m .81617 .31704 L .82444 .30895 L p F P
0 g
s
.25 .44 .853 r
.68932 .27925 m .68758 .27843 L .68702 .27509 L closepath p F P
0 g
s
.238 .429 .848 r
.68758 .27843 m .68702 .27509 L .68622 .27363 L p F P
0 g
s
0 .062 .622 r
.62698 .20035 m .62481 .19613 L .62109 .19193 L p F P
0 g
s
0 .034 .594 r
.61879 .18775 m .62109 .19193 L .62481 .19613 L p F P
0 g
s
0 .031 .594 r
.82875 .2206 m .82703 .21785 L .82672 .21493 L closepath p F P
0 g
s
0 .123 .661 r
.82558 .21198 m .82316 .20877 L p .82703 .21785 L F P
0 g
s
0 .123 .661 r
.82703 .21785 m .82672 .21493 L .82558 .21198 L p F P
0 g
s
0 .25 .762 r
.6388 .21716 m .63813 .21661 L .63498 .21102 L p F P
0 g
s
.121 .345 .811 r
.79626 .16604 m .79606 .1659 L .79593 .16539 L closepath p F P
0 g
s
.181 .396 .836 r
.79606 .1659 m .79593 .16539 L .79331 .1605 L p F P
0 g
s
0 0 .544 r
.60876 .17452 m .60654 .17106 L p .61271 .17939 L F P
0 g
s
0 0 .503 r
.60876 .17452 m .60609 .17048 L .60654 .17106 L closepath p F P
0 g
s
.327 .552 .915 r
.72656 .10072 m .72814 .1011 L .73043 .10537 L p F P
0 g
s
.311 .536 .908 r
.74128 .11207 m .73915 .10776 L .73043 .10537 L p F P
0 g
s
.308 .538 .911 r
.72814 .1011 m .73043 .10537 L .73915 .10776 L p F P
0 g
s
0 .088 .644 r
.63283 .20877 m .63079 .20454 L .62698 .20035 L p F P
0 g
s
0 .06 .619 r
.62481 .19613 m .62698 .20035 L .63079 .20454 L p F P
0 g
s
.102 .328 .801 r
.79626 .16604 m .80131 .16966 L .80246 .17415 L p F P
0 g
s
.088 .323 .8 r
.80131 .16966 m .79626 .16604 L .79593 .16539 L p F P
0 g
s
.755 .841 .916 r
.79964 .32831 m .80113 .32744 L .80115 .32992 L closepath p F P
0 g
s
.787 .852 .9 r
.81217 .32041 m .80113 .32744 L .80115 .32992 L p F P
0 g
s
.501 .616 .898 r
.74093 .31764 m .73369 .31743 L .73068 .31247 L p F P
0 g
s
.564 .669 .909 r
.76179 .32599 m .7526 .327 L .74964 .32246 L p F P
0 g
s
0 .106 .658 r
.63283 .20877 m .63498 .21102 L .63183 .20564 L p F P
0 g
s
0 .106 .658 r
.63183 .20564 m .63079 .20454 L .63283 .20877 L p F P
0 g
s
0 .102 .648 r
.82558 .21198 m .82316 .20877 L .82258 .20437 L closepath p F P
0 g
s
0 .184 .705 r
.82246 .20406 m .81875 .19986 L p .82316 .20877 L F P
0 g
s
0 .184 .705 r
.82316 .20877 m .82258 .20437 L .82246 .20406 L p F P
0 g
s
.418 .627 .94 r
.68656 .07908 m .68858 .07926 L .68557 .07513 L p F P
0 g
s
.418 .627 .94 r
.68557 .07513 m .68362 .07496 L .68656 .07908 L p F P
0 g
s
.068 .293 .779 r
.80838 .18256 m .80737 .17804 L .80246 .17415 L p F P
0 g
s
.061 .293 .781 r
.80131 .16966 m .80246 .17415 L .80737 .17804 L p F P
0 g
s
.132 .362 .822 r
.79593 .16539 m .79331 .1605 L .79479 .16143 L closepath p F P
0 g
s
.088 .323 .8 r
.79593 .16539 m .79479 .16143 L p .80131 .16966 L F P
0 g
s
.215 .41 .839 r
.66498 .25182 m .66468 .25009 L p .67195 .25807 L F P
0 g
s
.198 .396 .832 r
.66498 .25182 m .66379 .24959 L .66468 .25009 L closepath p F P
0 g
s
.011 .279 .778 r
.6388 .21716 m .64362 .22106 L .6452 .22541 L p F P
0 g
s
0 .239 .755 r
.63712 .21282 m .6388 .21716 L .64362 .22106 L p F P
0 g
s
0 .25 .762 r
.63498 .21102 m .63712 .21282 L .6388 .21716 L p F P
0 g
s
0 .157 .689 r
.81875 .19986 m .82246 .20406 L .8194 .19688 L p F P
0 g
s
0 .157 .689 r
.8194 .19688 m .81801 .19529 L .81875 .19986 L p F P
0 g
s
.003 .217 .729 r
.81875 .19986 m .81801 .19529 L .81382 .19113 L p F P
0 g
s
.038 .258 .756 r
.81382 .19113 m .81294 .18658 L .80838 .18256 L p F P
0 g
s
.031 .258 .758 r
.80737 .17804 m .80838 .18256 L .81294 .18658 L p F P
0 g
s
.008 .229 .738 r
.81294 .18658 m .81382 .19113 L .81801 .19529 L p F P
0 g
s
.24 .471 .879 r
.76285 .13056 m .76791 .13261 L .76497 .12774 L p F P
0 g
s
.24 .471 .879 r
.76497 .12774 m .76108 .12617 L .76285 .13056 L p F P
0 g
s
.899 .814 .339 r
.83706 .2728 m .83705 .27744 L .83579 .28351 L p F P
0 g
s
.795 .683 .138 r
.83705 .27744 m .83706 .2728 L .83757 .26698 L p F P
0 g
s
.329 .497 .873 r
.70499 .29347 m .70448 .28894 L .69596 .28605 L p F P
0 g
s
.309 .489 .873 r
.69561 .28144 m .69596 .28605 L .70448 .28894 L p F P
0 g
s
.351 .499 .866 r
.68932 .27925 m .69561 .28144 L .69596 .28605 L p F P
0 g
s
0 0 .21 r
.83643 .24764 m .83652 .25136 L .83735 .25673 L p F P
0 g
s
0 0 .354 r
.83561 .24384 m .83498 .24153 L p .83652 .25136 L F P
0 g
s
0 0 .354 r
.83652 .25136 m .83643 .24764 L .83561 .24384 L p F P
0 g
s
.95 .955 .677 r
.83366 .28994 m .83329 .29459 L .82966 .30142 L p F P
0 g
s
.002 .274 .775 r
.6516 .23366 m .65011 .2293 L .6452 .22541 L p F P
0 g
s
0 .25 .762 r
.64362 .22106 m .6452 .22541 L .65011 .2293 L p F P
0 g
s
.419 .564 .893 r
.72664 .31186 m .73068 .31247 L .72767 .3075 L p F P
0 g
s
.419 .564 .893 r
.72767 .3075 m .72644 .30728 L .72664 .31186 L p F P
0 g
s
.331 .49 .866 r
.69561 .28144 m .68932 .27925 L .68702 .27509 L p F P
0 g
s
.222 .454 .872 r
.77178 .13795 m .77084 .13754 L .76791 .13261 L p F P
0 g
s
.02 .285 .781 r
.65804 .24191 m .65661 .23754 L .6516 .23366 L p F P
0 g
s
0 .263 .77 r
.65011 .2293 m .6516 .23366 L .65661 .23754 L p F P
0 g
s
.274 .506 .897 r
.75155 .11899 m .74864 .11802 L .74569 .11339 L p F P
0 g
s
.189 .395 .834 r
.66468 .25009 m .66379 .24959 L .66066 .24385 L p F P
0 g
s
.389 .607 .935 r
.68858 .07926 m .69784 .08046 L .70063 .08462 L p F P
0 g
s
.386 .609 .937 r
.69784 .08046 m .68858 .07926 L .68557 .07513 L p F P
0 g
s
.424 .556 .883 r
.71504 .30058 m .71159 .29994 L .70854 .2946 L p F P
0 g
s
.028 .291 .785 r
.65804 .24191 m .66066 .24385 L .65753 .23824 L p F P
0 g
s
.028 .291 .785 r
.65753 .23824 m .65661 .23754 L .65804 .24191 L p F P
0 g
s
.345 .571 .924 r
.71613 .0948 m .72359 .09634 L .72062 .09201 L p F P
0 g
s
.345 .571 .924 r
.72062 .09201 m .71359 .09058 L .71613 .0948 L p F P
0 g
s
.357 .579 .926 r
.70753 .08945 m .71359 .09058 L .71613 .0948 L p F P
0 g
s
.295 .524 .904 r
.74128 .11207 m .74569 .11339 L .74274 .10882 L p F P
0 g
s
.295 .524 .904 r
.74274 .10882 m .73915 .10776 L .74128 .11207 L p F P
0 g
s
0 0 .505 r
.83012 .22445 m .82989 .2225 L p .83274 .23192 L F P
0 g
s
0 0 .505 r
.83274 .23192 m .83203 .23046 L .83012 .22445 L p F P
0 g
s
0 .003 .574 r
.83012 .22445 m .82875 .2206 L .82989 .2225 L closepath p F P
0 g
s
.195 .426 .857 r
.77178 .13795 m .77834 .14119 L .77991 .14561 L p F P
0 g
s
.189 .428 .86 r
.77006 .13356 m .77178 .13795 L .77834 .14119 L p F P
0 g
s
.222 .454 .872 r
.76791 .13261 m .77006 .13356 L .77178 .13795 L p F P
0 g
s
.353 .581 .928 r
.71359 .09058 m .70753 .08945 L .70455 .0852 L p F P
0 g
s
0 0 .507 r
.83285 .23305 m .83203 .23046 L .83274 .23192 L closepath p F P
0 g
s
0 0 .407 r
.83274 .23192 m .83285 .23305 L .83495 .24077 L p F P
0 g
s
0 0 .453 r
.83498 .24153 m .83495 .24077 L .83285 .23305 L p F P
0 g
s
.326 .495 .872 r
.70499 .29347 m .70854 .2946 L .70548 .28928 L p F P
0 g
s
.326 .495 .872 r
.70548 .28928 m .70448 .28894 L .70499 .29347 L p F P
0 g
s
0 0 .334 r
.83561 .24384 m .83498 .24153 L .83495 .24077 L closepath p F P
0 g
s
.215 .41 .839 r
.66468 .25009 m .67096 .25359 L .67195 .25807 L p F P
0 g
s
.148 .379 .831 r
.66367 .2456 m .66468 .25009 L .67096 .25359 L p F P
0 g
s
.189 .395 .834 r
.66066 .24385 m .66367 .2456 L .66468 .25009 L p F P
0 g
s
0 0 .571 r
.82989 .2225 m .82875 .2206 L .82672 .21493 L p F P
0 g
s
.617 .746 .938 r
.76842 .32973 m .78127 .32663 L .78412 .3303 L p F P
0 g
s
.604 .734 .936 r
.78127 .32663 m .76842 .32973 L .76551 .3256 L p F P
0 g
s
.742 .831 .919 r
.80113 .32744 m .79964 .32831 L .79686 .32521 L p F P
0 g
s
.685 .81 .942 r
.78412 .3303 m .79686 .32521 L .79964 .32831 L p F P
0 g
s
0 0 .048 r
.83757 .26698 m .83755 .26232 L .83735 .25673 L p F P
0 g
s
.809 .693 .152 r
.83755 .26232 m .83757 .26698 L .83706 .2728 L p F P
0 g
s
0 .233 .751 r
.63712 .21282 m .63498 .21102 L .63183 .20564 L p F P
0 g
s
.742 .831 .919 r
.79686 .32521 m .80109 .32289 L .80113 .32744 L p F P
0 g
s
.774 .878 .922 r
.80946 .31793 m .80109 .32289 L .80113 .32744 L p F P
0 g
s
.774 .878 .922 r
.80113 .32744 m .81217 .32041 L .80946 .31793 L p F P
0 g
s
0 0 .571 r
.82672 .21493 m .82648 .21326 L p .82989 .2225 L F P
0 g
s
0 .075 .63 r
.82672 .21493 m .82558 .21198 L .82648 .21326 L closepath p F P
0 g
s
.943 .947 .753 r
.82966 .30142 m .82465 .30868 L .82464 .30905 L p F P
0 g
s
.931 .951 .777 r
.82991 .29674 m .82966 .30142 L .82465 .30868 L p F P
0 g
s
.95 .955 .677 r
.83362 .28996 m .83366 .28994 L p .82966 .30142 L F P
0 g
s
.95 .955 .677 r
.82966 .30142 m .82991 .29674 L .83362 .28996 L p F P
0 g
s
.181 .409 .847 r
.78763 .15343 m .78621 .14896 L .77991 .14561 L p F P
0 g
s
.193 .424 .856 r
.77834 .14119 m .77991 .14561 L .78621 .14896 L p F P
0 g
s
0 0 .407 r
.83495 .24077 m .83458 .23695 L .83274 .23192 L p F P
0 g
s
0 0 .303 r
.83495 .24077 m .83458 .23695 L p .83636 .24672 L F P
0 g
s
0 0 .303 r
.83636 .24672 m .83561 .24384 L .83495 .24077 L p F P
0 g
s
.19 .401 .839 r
.67931 .26602 m .67832 .26157 L .67195 .25807 L p F P
0 g
s
.156 .386 .835 r
.67096 .25359 m .67195 .25807 L .67832 .26157 L p F P
0 g
s
.323 .554 .918 r
.72814 .1011 m .72656 .10072 L .72359 .09634 L p F P
0 g
s
.703 .254 0 r
.60076 .16259 m .59769 .1586 L .59501 .15412 L p F P
0 g
s
.124 .361 .823 r
.79479 .16143 m .79331 .1605 L .79037 .15505 L p F P
0 g
s
0 0 .399 r
.83219 .22736 m .83274 .23192 L .83458 .23695 L p F P
0 g
s
0 0 .505 r
.82989 .2225 m .83219 .22736 L .83274 .23192 L p F P
0 g
s
.671 .795 .941 r
.79686 .32521 m .78412 .3303 L .78127 .32663 L p F P
0 g
s
.676 .225 0 r
.60076 .16259 m .60293 .16602 L .59976 .16188 L p F P
0 g
s
.676 .225 0 r
.59976 .16188 m .59769 .1586 L .60076 .16259 L p F P
0 g
s
.331 .49 .866 r
.68702 .27509 m .68693 .2739 L p .69561 .28144 L F P
0 g
s
.318 .48 .862 r
.68702 .27509 m .68622 .27363 L .68693 .2739 L closepath p F P
0 g
s
.379 .6 .934 r
.70063 .08462 m .70455 .0852 L .70155 .081 L p F P
0 g
s
.379 .6 .934 r
.70155 .081 m .69784 .08046 L .70063 .08462 L p F P
0 g
s
0 .072 .628 r
.82648 .21326 m .82558 .21198 L .82258 .20437 L p F P
0 g
s
.501 .616 .898 r
.73068 .31247 m .74086 .31304 L .74093 .31764 L p F P
0 g
s
.486 .608 .898 r
.74086 .31304 m .73068 .31247 L .72767 .3075 L p F P
0 g
s
0 0 .544 r
.60654 .17106 m .61004 .17529 L .61271 .17939 L p F P
0 g
s
0 0 .504 r
.60369 .167 m .60654 .17106 L .61004 .17529 L p F P
0 g
s
0 0 .473 r
.60293 .16602 m .60369 .167 L .60654 .17106 L p F P
0 g
s
.945 .892 .494 r
.83366 .28994 m .83366 .28986 L .83579 .28351 L p F P
0 g
s
.956 .899 .517 r
.83576 .27888 m .83579 .28351 L .83366 .28986 L p F P
0 g
s
.899 .814 .339 r
.83579 .28351 m .83576 .27888 L .83706 .2728 L p F P
0 g
s
.258 .489 .888 r
.76108 .12617 m .75919 .1218 L .75155 .11899 L p F P
0 g
s
.253 .491 .891 r
.7495 .11466 m .75155 .11899 L .75919 .1218 L p F P
0 g
s
.274 .506 .897 r
.74569 .11339 m .7495 .11466 L .75155 .11899 L p F P
0 g
s
.564 .669 .909 r
.74964 .32246 m .76152 .32148 L .76179 .32599 L p F P
0 g
s
.551 .661 .909 r
.76152 .32148 m .74964 .32246 L .74668 .31786 L p F P
0 g
s
.189 .401 .838 r
.67931 .26602 m .68312 .26803 L .68002 .26251 L p F P
0 g
s
.189 .401 .838 r
.68002 .26251 m .67832 .26157 L .67931 .26602 L p F P
0 g
s
.142 .377 .831 r
.78763 .15343 m .79037 .15505 L .78742 .14968 L p F P
0 g
s
.142 .377 .831 r
.78742 .14968 m .78621 .14896 L .78763 .15343 L p F P
0 g
s
0 .007 .566 r
.61879 .18775 m .61629 .18361 L .61271 .17939 L p F P
0 g
s
0 0 .537 r
.61004 .17529 m .61271 .17939 L .61629 .18361 L p F P
0 g
s
.408 .562 .896 r
.72465 .30248 m .71504 .30058 L p .72644 .30728 L F P
0 g
s
.398 .543 .884 r
.71504 .30058 m .72465 .30248 L .72162 .29744 L p F P
0 g
s
.398 .543 .884 r
.72162 .29744 m .71492 .29594 L .71504 .30058 L p F P
0 g
s
.424 .556 .883 r
.70854 .2946 m .71492 .29594 L .71504 .30058 L p F P
0 g
s
0 0 .307 r
.83643 .24764 m .83561 .24384 L .83636 .24672 L closepath p F P
0 g
s
0 0 .488 r
.82924 .21795 m .82989 .2225 L .83219 .22736 L p F P
0 g
s
0 0 .571 r
.82648 .21326 m .82924 .21795 L .82989 .2225 L p F P
0 g
s
.911 .948 .812 r
.82444 .30895 m .82465 .30868 L .82464 .30905 L closepath p F P
0 g
s
.315 .48 .864 r
.68693 .2739 m .68622 .27363 L .68312 .26803 L p F P
0 g
s
.476 .611 .906 r
.74093 .31764 m .74668 .31786 L .7437 .31322 L p F P
0 g
s
.476 .611 .906 r
.7437 .31322 m .74086 .31304 L .74093 .31764 L p F P
0 g
s
0 .034 .594 r
.62481 .19613 m .62245 .19197 L .61879 .18775 L p F P
0 g
s
0 .009 .566 r
.61629 .18361 m .61879 .18775 L .62245 .19197 L p F P
0 g
s
.308 .538 .911 r
.73915 .10776 m .73689 .10347 L .72814 .1011 L p F P
0 g
s
.304 .54 .913 r
.72572 .09685 m .72814 .1011 L .73689 .10347 L p F P
0 g
s
.323 .554 .918 r
.72359 .09634 m .72572 .09685 L .72814 .1011 L p F P
0 g
s
.16 .384 .832 r
.66367 .2456 m .66066 .24385 L .65753 .23824 L p F P
0 g
s
0 .06 .619 r
.63079 .20454 m .62856 .20035 L .62481 .19613 L p F P
0 g
s
0 .027 .586 r
.62245 .19197 m .62481 .19613 L .62856 .20035 L p F P
0 g
s
.901 .938 .826 r
.82465 .30868 m .82444 .30895 L .82183 .30742 L p F P
0 g
s
.901 .938 .826 r
.82183 .30742 m .82468 .30408 L .82465 .30868 L p F P
0 g
s
.931 .951 .777 r
.82465 .30868 m .82468 .30408 L .82991 .29674 L p F P
0 g
s
0 0 .037 r
.83728 .25366 m .83735 .25673 L .83755 .26232 L p F P
0 g
s
0 0 .21 r
.83735 .25673 m .83728 .25366 L .83643 .24764 L p F P
0 g
s
.543 .672 .922 r
.76179 .32599 m .76551 .3256 L .7626 .3214 L p F P
0 g
s
.543 .672 .922 r
.7626 .3214 m .76152 .32148 L .76179 .32599 L p F P
0 g
s
.867 .945 .865 r
.81617 .31704 m .82444 .30895 L .82183 .30742 L p F P
0 g
s
.088 .323 .8 r
.79479 .16143 m .80006 .16518 L .80131 .16966 L p F P
0 g
s
.08 .325 .802 r
.7934 .15698 m .79479 .16143 L .80006 .16518 L p F P
0 g
s
.124 .361 .823 r
.79037 .15505 m .7934 .15698 L .79479 .16143 L p F P
0 g
s
.331 .49 .866 r
.68693 .2739 m .69496 .27692 L .69561 .28144 L p F P
0 g
s
.274 .468 .868 r
.68638 .26932 m .68693 .2739 L .69496 .27692 L p F P
0 g
s
.315 .48 .864 r
.68312 .26803 m .68638 .26932 L .68693 .2739 L p F P
0 g
s
.822 .896 .894 r
.81617 .31704 m .81217 .32041 L .80946 .31793 L p F P
0 g
s
0 .072 .628 r
.82255 .20418 m .82573 .20872 L .82648 .21326 L p F P
0 g
s
0 .072 .628 r
.82258 .20437 m .82255 .20418 L p .82648 .21326 L F P
0 g
s
0 0 .559 r
.82573 .20872 m .82648 .21326 L .82924 .21795 L p F P
0 g
s
.213 .453 .873 r
.77006 .13356 m .76791 .13261 L .76497 .12774 L p F P
0 g
s
0 .084 .638 r
.63079 .20454 m .63183 .20564 L .62868 .20047 L p F P
0 g
s
0 .084 .638 r
.62868 .20047 m .62856 .20035 L .63079 .20454 L p F P
0 g
s
.407 .548 .884 r
.71492 .29594 m .70854 .2946 L .70548 .28928 L p F P
0 g
s
.822 .896 .894 r
.80946 .31793 m .81642 .31238 L .81617 .31704 L p F P
0 g
s
.867 .945 .865 r
.82183 .30742 m .81642 .31238 L .81617 .31704 L p F P
0 g
s
0 .14 .678 r
.82258 .20437 m .82246 .20406 L .82255 .20418 L closepath p F P
0 g
s
0 0 .163 r
.83636 .24672 m .83643 .24764 L .83728 .25366 L p F P
0 g
s
.061 .293 .781 r
.80737 .17804 m .80625 .17353 L .80131 .16966 L p F P
0 g
s
.054 .294 .783 r
.80006 .16518 m .80131 .16966 L .80625 .17353 L p F P
0 g
s
0 .135 .676 r
.82255 .20418 m .82246 .20406 L .8194 .19688 L p F P
0 g
s
0 .054 .617 r
.82168 .19965 m .82255 .20418 L .82573 .20872 L p F P
0 g
s
0 .135 .676 r
.8194 .19688 m .82168 .19965 L .82255 .20418 L p F P
0 g
s
0 .239 .755 r
.64362 .22106 m .64182 .21676 L .63712 .21282 L p F P
0 g
s
0 .216 .74 r
.63521 .20854 m .63712 .21282 L .64182 .21676 L p F P
0 g
s
0 .233 .751 r
.63183 .20564 m .63521 .20854 L .63712 .21282 L p F P
0 g
s
.267 .507 .899 r
.7495 .11466 m .74569 .11339 L .74274 .10882 L p F P
0 g
s
.233 .471 .881 r
.76108 .12617 m .76497 .12774 L .76203 .12295 L p F P
0 g
s
.233 .471 .881 r
.76203 .12295 m .75919 .1218 L .76108 .12617 L p F P
0 g
s
.031 .258 .758 r
.81294 .18658 m .81197 .18205 L .80737 .17804 L p F P
0 g
s
.039 .272 .768 r
.80625 .17353 m .80737 .17804 L .81197 .18205 L p F P
0 g
s
0 .151 .687 r
.8194 .19688 m .81801 .19529 L .81749 .19246 L closepath p F P
0 g
s
.008 .229 .738 r
.81635 .18996 m .81294 .18658 L p .81801 .19529 L F P
0 g
s
.008 .229 .738 r
.81801 .19529 m .81749 .19246 L .81635 .18996 L p F P
0 g
s
0 .204 .724 r
.81294 .18658 m .81635 .18996 L .81333 .18342 L p F P
0 g
s
0 .204 .724 r
.81333 .18342 m .81197 .18205 L .81294 .18658 L p F P
0 g
s
0 .25 .762 r
.65011 .2293 m .6484 .22499 L .64362 .22106 L p F P
0 g
s
0 .227 .747 r
.64182 .21676 m .64362 .22106 L .6484 .22499 L p F P
0 g
s
.386 .609 .937 r
.68557 .07513 m .6949 .07633 L .69784 .08046 L p F P
0 g
s
.909 .822 .355 r
.83702 .26815 m .83706 .2728 L .83576 .27888 L p F P
0 g
s
.809 .693 .152 r
.83706 .2728 m .83702 .26815 L .83755 .26232 L p F P
0 g
s
.309 .489 .873 r
.70241 .28395 m .69561 .28144 L p .70448 .28894 L F P
0 g
s
.294 .473 .865 r
.69561 .28144 m .70241 .28395 L .69933 .27864 L p F P
0 g
s
.294 .473 .865 r
.69933 .27864 m .69496 .27692 L .69561 .28144 L p F P
0 g
s
0 0 .163 r
.83728 .25366 m .83717 .2521 L .83636 .24672 L p F P
0 g
s
0 0 .146 r
.83592 .24214 m .83636 .24672 L .83717 .2521 L p F P
0 g
s
0 0 .303 r
.83458 .23695 m .83592 .24214 L .83636 .24672 L p F P
0 g
s
.353 .581 .928 r
.70455 .0852 m .71093 .08638 L .71359 .09058 L p F P
0 g
s
.349 .583 .93 r
.71093 .08638 m .70455 .0852 L .70155 .081 L p F P
0 g
s
0 .215 .739 r
.63521 .20854 m .63183 .20564 L .62868 .20047 L p F P
0 g
s
0 .263 .77 r
.65439 .23274 m .65011 .2293 L p .65661 .23754 L F P
0 g
s
0 .251 .762 r
.65011 .2293 m .65439 .23274 L .65125 .22734 L p F P
0 g
s
0 .251 .762 r
.65125 .22734 m .6484 .22499 L .65011 .2293 L p F P
0 g
s
.414 .567 .897 r
.72767 .3075 m .72644 .30728 L .72625 .30515 L closepath p F P
0 g
s
.408 .562 .896 r
.72644 .30728 m .72625 .30515 L .72465 .30248 L p F P
0 g
s
.96 .932 .606 r
.83362 .28996 m .83366 .28986 L .83366 .28994 L closepath p F P
0 g
s
.341 .573 .926 r
.71359 .09058 m .72062 .09201 L .71764 .08774 L p F P
0 g
s
.341 .573 .926 r
.71764 .08774 m .71093 .08638 L .71359 .09058 L p F P
0 g
s
.965 .937 .641 r
.83366 .28986 m .83362 .28996 L .83119 .29027 L p F P
0 g
s
.965 .937 .641 r
.83119 .29027 m .83356 .28527 L .83366 .28986 L p F P
0 g
s
.956 .899 .517 r
.83366 .28986 m .83356 .28527 L .83576 .27888 L p F P
0 g
s
.947 .956 .672 r
.82991 .29674 m .83362 .28996 L .83119 .29027 L p F P
0 g
s
.604 .734 .936 r
.76551 .3256 m .7784 .32285 L .78127 .32663 L p F P
0 g
s
.592 .723 .935 r
.7784 .32285 m .76551 .3256 L .7626 .3214 L p F P
0 g
s
.289 .525 .907 r
.73915 .10776 m .74274 .10882 L .73978 .10432 L p F P
0 g
s
.289 .525 .907 r
.73978 .10432 m .73689 .10347 L .73915 .10776 L p F P
0 g
s
.113 .358 .822 r
.7934 .15698 m .79037 .15505 L .78742 .14968 L p F P
0 g
s
.189 .428 .86 r
.77834 .14119 m .77666 .13678 L .77006 .13356 L p F P
0 g
s
.184 .43 .862 r
.76824 .12918 m .77006 .13356 L .77666 .13678 L p F P
0 g
s
.213 .453 .873 r
.76497 .12774 m .76824 .12918 L .77006 .13356 L p F P
0 g
s
.006 .286 .784 r
.65753 .23824 m .65661 .23754 L .65563 .23492 L closepath p F P
0 g
s
0 .263 .77 r
.65661 .23754 m .65563 .23492 L .65439 .23274 L p F P
0 g
s
0 0 .44 r
.60369 .167 m .60293 .16602 L .59976 .16188 L p F P
0 g
s
.486 .608 .898 r
.72767 .3075 m .74044 .30853 L .74086 .31304 L p F P
0 g
s
.472 .6 .898 r
.74044 .30853 m .72767 .3075 L .72625 .30515 L p F P
0 g
s
0 .122 .668 r
.82168 .19965 m .8194 .19688 L .81749 .19246 L p F P
0 g
s
.318 .555 .92 r
.72572 .09685 m .72359 .09634 L .72062 .09201 L p F P
0 g
s
.73 .824 .923 r
.80109 .32289 m .79686 .32521 L .79405 .32195 L p F P
0 g
s
.671 .795 .941 r
.78127 .32663 m .79405 .32195 L .79686 .32521 L p F P
0 g
s
.293 .471 .865 r
.68638 .26932 m .68312 .26803 L .68002 .26251 L p F P
0 g
s
0 0 .399 r
.83458 .23695 m .83405 .23238 L .83219 .22736 L p F P
0 g
s
0 0 .28 r
.83405 .23238 m .83458 .23695 L .83592 .24214 L p F P
0 g
s
.148 .379 .831 r
.67096 .25359 m .66972 .24918 L .66367 .2456 L p F P
0 g
s
.11 .361 .825 r
.6624 .24118 m .66367 .2456 L .66972 .24918 L p F P
0 g
s
.16 .384 .832 r
.65753 .23824 m .6624 .24118 L .66367 .2456 L p F P
0 g
s
.318 .497 .876 r
.70548 .28928 m .70448 .28894 L .70418 .28704 L closepath p F P
0 g
s
.309 .489 .873 r
.70448 .28894 m .70418 .28704 L .70241 .28395 L p F P
0 g
s
.551 .661 .909 r
.74668 .31786 m .75966 .31712 L p .76152 .32148 L F P
0 g
s
.52 .66 .924 r
.75966 .31712 m .74668 .31786 L .7437 .31322 L p F P
0 g
s
.657 .782 .94 r
.79405 .32195 m .78127 .32663 L .7784 .32285 L p F P
0 g
s
.132 .372 .829 r
.6624 .24118 m .65753 .23824 L .65563 .23492 L p F P
0 g
s
.193 .424 .856 r
.78447 .14441 m .77834 .14119 L p .78621 .14896 L F P
0 g
s
.163 .409 .851 r
.77834 .14119 m .78447 .14441 L .78153 .13935 L p F P
0 g
s
.163 .409 .851 r
.78153 .13935 m .77666 .13678 L .77834 .14119 L p F P
0 g
s
.375 .603 .936 r
.69784 .08046 m .70155 .081 L .69856 .07686 L p F P
0 g
s
.375 .603 .936 r
.69856 .07686 m .6949 .07633 L .69784 .08046 L p F P
0 g
s
0 0 .504 r
.61004 .17529 m .60718 .17124 L .60369 .167 L p F P
0 g
s
0 0 .474 r
.60063 .16301 m .60369 .167 L .60718 .17124 L p F P
0 g
s
0 0 .44 r
.59976 .16188 m .60063 .16301 L .60369 .167 L p F P
0 g
s
.745 .578 .003 r
.83717 .2521 m .83728 .25366 L .83747 .25877 L p F P
0 g
s
0 0 .037 r
.83755 .26232 m .83747 .25877 L .83728 .25366 L p F P
0 g
s
.826 .708 .174 r
.83747 .25877 m .83755 .26232 L .83702 .26815 L p F P
0 g
s
.156 .386 .835 r
.67691 .25706 m .67096 .25359 L p .67832 .26157 L F P
0 g
s
.14 .373 .828 r
.67096 .25359 m .67691 .25706 L .67379 .25164 L p F P
0 g
s
.14 .373 .828 r
.67379 .25164 m .66972 .24918 L .67096 .25359 L p F P
0 g
s
.407 .548 .884 r
.70548 .28928 m .71448 .29138 L .71492 .29594 L p F P
0 g
s
.39 .54 .884 r
.71448 .29138 m .70548 .28928 L .70418 .28704 L p F P
0 g
s
.73 .824 .923 r
.79405 .32195 m .80125 .31825 L .80109 .32289 L p F P
0 g
s
.759 .861 .925 r
.80673 .31524 m .80125 .31825 L .80109 .32289 L p F P
0 g
s
.759 .861 .925 r
.80109 .32289 m .80946 .31793 L .80673 .31524 L p F P
0 g
s
.253 .491 .891 r
.75919 .1218 m .75718 .11746 L .7495 .11466 L p F P
0 g
s
.249 .493 .893 r
.74733 .11035 m .7495 .11466 L .75718 .11746 L p F P
0 g
s
.267 .507 .899 r
.74274 .10882 m .74733 .11035 L .7495 .11466 L p F P
0 g
s
.926 .949 .787 r
.83015 .29205 m .82991 .29674 L .82468 .30408 L p F P
0 g
s
.947 .956 .672 r
.83119 .29027 m .83015 .29205 L .82991 .29674 L p F P
0 g
s
0 0 .392 r
.83156 .2228 m .83219 .22736 L .83405 .23238 L p F P
0 g
s
0 0 .488 r
.83219 .22736 m .83156 .2228 L .82924 .21795 L p F P
0 g
s
0 0 .537 r
.61629 .18361 m .61359 .17953 L .61004 .17529 L p F P
0 g
s
0 0 .508 r
.60718 .17124 m .61004 .17529 L .61359 .17953 L p F P
0 g
s
.205 .453 .874 r
.76824 .12918 m .76497 .12774 L .76203 .12295 L p F P
0 g
s
0 .122 .668 r
.81749 .19246 m .81712 .19076 L p .82168 .19965 L F P
0 g
s
0 .186 .712 r
.81749 .19246 m .81635 .18996 L .81712 .19076 L closepath p F P
0 g
s
.472 .6 .898 r
.72625 .30515 m .72637 .30264 L p .74044 .30853 L F P
0 g
s
.466 .594 .897 r
.72625 .30515 m .72465 .30248 L .72637 .30264 L closepath p F P
0 g
s
.132 .376 .832 r
.78742 .14968 m .78621 .14896 L .78493 .14522 L closepath p F P
0 g
s
.193 .424 .856 r
.78621 .14896 m .78493 .14522 L .78447 .14441 L p F P
0 g
s
0 .009 .566 r
.62245 .19197 m .61991 .18785 L .61629 .18361 L p F P
0 g
s
0 0 .539 r
.61359 .17953 m .61629 .18361 L .61991 .18785 L p F P
0 g
s
.304 .54 .913 r
.73689 .10347 m .7345 .0992 L .72572 .09685 L p F P
0 g
s
.299 .542 .916 r
.72317 .09262 m .72572 .09685 L .7345 .0992 L p F P
0 g
s
.318 .555 .92 r
.72062 .09201 m .72317 .09262 L .72572 .09685 L p F P
0 g
s
.173 .4 .842 r
.68002 .26251 m .67832 .26157 L .67722 .25762 L closepath p F P
0 g
s
.156 .386 .835 r
.67832 .26157 m .67722 .25762 L .67691 .25706 L p F P
0 g
s
.961 .903 .532 r
.83568 .27426 m .83576 .27888 L .83356 .28527 L p F P
0 g
s
.909 .822 .355 r
.83576 .27888 m .83568 .27426 L .83702 .26815 L p F P
0 g
s
0 .027 .586 r
.62552 .19546 m .62245 .19197 L p .62856 .20035 L F P
0 g
s
0 .022 .578 r
.62245 .19197 m .62552 .19546 L .62236 .19066 L p F P
0 g
s
0 .022 .578 r
.62236 .19066 m .61991 .18785 L .62245 .19197 L p F P
0 g
s
0 0 .483 r
.8285 .21341 m .82924 .21795 L .83156 .2228 L p F P
0 g
s
0 0 .559 r
.82924 .21795 m .8285 .21341 L .82573 .20872 L p F P
0 g
s
.261 .508 .901 r
.74733 .11035 m .74274 .10882 L .73978 .10432 L p F P
0 g
s
.377 .536 .887 r
.71492 .29594 m .72162 .29744 L .71858 .2924 L p F P
0 g
s
.377 .536 .887 r
.71858 .2924 m .71448 .29138 L .71492 .29594 L p F P
0 g
s
.08 .325 .802 r
.80006 .16518 m .7987 .16072 L .7934 .15698 L p F P
0 g
s
.072 .325 .804 r
.79191 .15255 m .7934 .15698 L .7987 .16072 L p F P
0 g
s
.113 .358 .822 r
.78742 .14968 m .79191 .15255 L .7934 .15698 L p F P
0 g
s
0 .071 .624 r
.62868 .20047 m .62856 .20035 L .62819 .1997 L closepath p F P
0 g
s
0 .027 .586 r
.62856 .20035 m .62819 .1997 L .62552 .19546 L p F P
0 g
s
.39 .54 .884 r
.70418 .28704 m .70404 .28436 L p .71448 .29138 L F P
0 g
s
.381 .532 .882 r
.70418 .28704 m .70241 .28395 L .70404 .28436 L closepath p F P
0 g
s
0 .182 .711 r
.81712 .19076 m .81635 .18996 L .81333 .18342 L p F P
0 g
s
.458 .605 .909 r
.74086 .31304 m .7437 .31322 L .74072 .30855 L p F P
0 g
s
.458 .605 .909 r
.74072 .30855 m .74044 .30853 L .74086 .31304 L p F P
0 g
s
.114 .357 .821 r
.65563 .23492 m .65439 .23274 L .6551 .23318 L closepath p F P
0 g
s
.132 .372 .829 r
.65563 .23492 m .6551 .23318 L p .6624 .24118 L F P
0 g
s
0 .215 .739 r
.62868 .20047 m .63309 .20432 L .63521 .20854 L p F P
0 g
s
0 .197 .726 r
.63309 .20432 m .62868 .20047 L .62819 .1997 L p F P
0 g
s
0 0 .556 r
.82487 .20419 m .82573 .20872 L .8285 .21341 L p F P
0 g
s
0 .054 .617 r
.82573 .20872 m .82487 .20419 L .82168 .19965 L p F P
0 g
s
.745 .578 .003 r
.83747 .25877 m .83739 .25769 L .83717 .2521 L p F P
0 g
s
0 0 .146 r
.83717 .2521 m .83673 .24753 L .83592 .24214 L p F P
0 g
s
.769 .594 .024 r
.83673 .24753 m .83717 .2521 L .83739 .25769 L p F P
0 g
s
.81 .889 .901 r
.81642 .31238 m .80946 .31793 L .80673 .31524 L p F P
0 g
s
.541 .675 .925 r
.7626 .3214 m .76152 .32148 L .76131 .31952 L closepath p F P
0 g
s
.551 .661 .909 r
.75966 .31712 m .76131 .31952 L .76152 .32148 L p F P
0 g
s
.1 .354 .822 r
.79191 .15255 m .78742 .14968 L .78493 .14522 L p F P
0 g
s
.891 .932 .838 r
.82468 .30408 m .82183 .30742 L .81919 .30558 L p F P
0 g
s
.891 .932 .838 r
.81919 .30558 m .8247 .29947 L .82468 .30408 L p F P
0 g
s
.926 .949 .787 r
.82468 .30408 m .8247 .29947 L .83015 .29205 L p F P
0 g
s
.243 .454 .866 r
.68555 .26482 m .68638 .26932 L .69405 .27246 L p F P
0 g
s
.293 .471 .865 r
.68002 .26251 m .68555 .26482 L .68638 .26932 L p F P
0 g
s
.274 .468 .868 r
.69496 .27692 m .69405 .27246 L .68638 .26932 L p F P
0 g
s
.226 .471 .883 r
.75919 .1218 m .76203 .12295 L .75908 .11822 L p F P
0 g
s
.226 .471 .883 r
.75908 .11822 m .75718 .11746 L .75919 .1218 L p F P
0 g
s
.054 .294 .783 r
.80625 .17353 m .80504 .16904 L .80006 .16518 L p F P
0 g
s
.046 .295 .785 r
.7987 .16072 m .80006 .16518 L .80504 .16904 L p F P
0 g
s
0 .216 .74 r
.64182 .21676 m .63982 .21251 L .63521 .20854 L p F P
0 g
s
0 .193 .723 r
.63309 .20432 m .63521 .20854 L .63982 .21251 L p F P
0 g
s
0 .197 .726 r
.62819 .1997 m .62628 .19615 L p .63309 .20432 L F P
0 g
s
0 .172 .708 r
.62819 .1997 m .62552 .19546 L .62628 .19615 L closepath p F P
0 g
s
0 .05 .615 r
.82071 .19514 m .82168 .19965 L .82487 .20419 L p F P
0 g
s
0 .122 .668 r
.81712 .19076 m .82071 .19514 L .82168 .19965 L p F P
0 g
s
.039 .272 .768 r
.81033 .17707 m .80625 .17353 L p .81197 .18205 L F P
0 g
s
.001 .249 .756 r
.80625 .17353 m .81033 .17707 L .80734 .17106 L p F P
0 g
s
.001 .249 .756 r
.80734 .17106 m .80504 .16904 L .80625 .17353 L p F P
0 g
s
.853 .929 .877 r
.81642 .31238 m .82183 .30742 L .81919 .30558 L p F P
0 g
s
.81 .889 .901 r
.80673 .31524 m .81675 .30768 L .81642 .31238 L p F P
0 g
s
.853 .929 .877 r
.81919 .30558 m .81675 .30768 L .81642 .31238 L p F P
0 g
s
.349 .583 .93 r
.70155 .081 m .70814 .08222 L .71093 .08638 L p F P
0 g
s
.345 .585 .933 r
.70814 .08222 m .70155 .081 L .69856 .07686 L p F P
0 g
s
.592 .723 .935 r
.7626 .3214 m .77552 .31898 L .7784 .32285 L p F P
0 g
s
.588 .697 .918 r
.77263 .31502 m .77552 .31898 L .7626 .3214 L p F P
0 g
s
.588 .697 .918 r
.76191 .31674 m .77263 .31502 L p .7626 .3214 L F P
0 g
s
.588 .697 .918 r
.7626 .3214 m .76131 .31952 L .76191 .31674 L p F P
0 g
s
.271 .463 .865 r
.68555 .26482 m .68002 .26251 L .67722 .25762 L p F P
0 g
s
0 .112 .662 r
.81603 .18626 m .81712 .19076 L .82071 .19514 L p F P
0 g
s
0 .182 .711 r
.81333 .18342 m .81603 .18626 L .81712 .19076 L p F P
0 g
s
.466 .595 .897 r
.72637 .30264 m .72465 .30248 L .72162 .29744 L p F P
0 g
s
0 .199 .722 r
.81333 .18342 m .81197 .18205 L .81121 .17887 L closepath p F P
0 g
s
.039 .272 .768 r
.81197 .18205 m .81121 .17887 L .81033 .17707 L p F P
0 g
s
0 .227 .747 r
.6484 .22499 m .64649 .22073 L .64182 .21676 L p F P
0 g
s
0 .204 .732 r
.63982 .21251 m .64182 .21676 L .64649 .22073 L p F P
0 g
s
.336 .575 .929 r
.71093 .08638 m .71764 .08774 L .71466 .08353 L p F P
0 g
s
.336 .575 .929 r
.71466 .08353 m .70814 .08222 L .71093 .08638 L p F P
0 g
s
.099 .355 .822 r
.6551 .23318 m .65439 .23274 L .65125 .22734 L p F P
0 g
s
.284 .527 .909 r
.73689 .10347 m .73978 .10432 L .73682 .09988 L p F P
0 g
s
.284 .527 .909 r
.73682 .09988 m .7345 .0992 L .73689 .10347 L p F P
0 g
s
0 .233 .752 r
.6484 .22499 m .65125 .22734 L .64812 .22209 L p F P
0 g
s
0 .233 .752 r
.64812 .22209 m .64649 .22073 L .6484 .22499 L p F P
0 g
s
.269 .464 .866 r
.69496 .27692 m .69933 .27864 L .69625 .27337 L p F P
0 g
s
.269 .464 .866 r
.69625 .27337 m .69405 .27246 L .69496 .27692 L p F P
0 g
s
0 0 .132 r
.8354 .23758 m .83592 .24214 L .83673 .24753 L p F P
0 g
s
0 0 .28 r
.83592 .24214 m .8354 .23758 L .83405 .23238 L p F P
0 g
s
.52 .66 .924 r
.7437 .31322 m .75672 .31276 L .75966 .31712 L p F P
0 g
s
.509 .652 .923 r
.75672 .31276 m .7437 .31322 L .74072 .30855 L p F P
0 g
s
.918 .829 .37 r
.83692 .26351 m .83702 .26815 L .83568 .27426 L p F P
0 g
s
.826 .708 .174 r
.83712 .26143 m .83747 .25877 L p .83702 .26815 L F P
0 g
s
.826 .708 .174 r
.83702 .26815 m .83692 .26351 L .83712 .26143 L p F P
0 g
s
.184 .43 .862 r
.77666 .13678 m .77487 .13239 L .76824 .12918 L p F P
0 g
s
.178 .431 .864 r
.76629 .12483 m .76824 .12918 L .77487 .13239 L p F P
0 g
s
.205 .453 .874 r
.76203 .12295 m .76629 .12483 L .76824 .12918 L p F P
0 g
s
.313 .556 .922 r
.72317 .09262 m .72062 .09201 L .71764 .08774 L p F P
0 g
s
.379 .533 .884 r
.70404 .28436 m .70241 .28395 L .69933 .27864 L p F P
0 g
s
.132 .372 .829 r
.6551 .23318 m .66091 .23682 L .6624 .24118 L p F P
0 g
s
.066 .341 .817 r
.65354 .22882 m .6551 .23318 L .66091 .23682 L p F P
0 g
s
.099 .355 .822 r
.65125 .22734 m .65354 .22882 L .6551 .23318 L p F P
0 g
s
.472 .6 .898 r
.72637 .30264 m .73772 .30382 L p .74044 .30853 L F P
0 g
s
.444 .583 .897 r
.72637 .30264 m .73772 .30382 L .73471 .29907 L p F P
0 g
s
.444 .583 .897 r
.73471 .29907 m .72629 .29798 L .72637 .30264 L p F P
0 g
s
.466 .595 .897 r
.72162 .29744 m .72629 .29798 L .72637 .30264 L p F P
0 g
s
.973 .928 .66 r
.83356 .28527 m .83341 .28067 L p .83021 .2902 L F P
0 g
s
.973 .928 .66 r
.83021 .2902 m .83119 .29027 L .83356 .28527 L p F P
0 g
s
.961 .903 .532 r
.83356 .28527 m .83341 .28067 L .83568 .27426 L p F P
0 g
s
.718 .818 .927 r
.80125 .31825 m .79405 .32195 L .79123 .31857 L p F P
0 g
s
.657 .782 .94 r
.7784 .32285 m .79123 .31857 L .79405 .32195 L p F P
0 g
s
.645 .77 .939 r
.79123 .31857 m .7784 .32285 L .77552 .31898 L p F P
0 g
s
.85 .706 .176 r
.83712 .26143 m .83739 .25769 L .83747 .25877 L closepath p F P
0 g
s
0 .172 .705 r
.81603 .18626 m .81333 .18342 L .81121 .17887 L p F P
0 g
s
.586 .695 .917 r
.76131 .31952 m .75966 .31712 L .76191 .31674 L closepath p F P
0 g
s
.11 .361 .825 r
.66972 .24918 m .66827 .24483 L .6624 .24118 L p F P
0 g
s
.073 .344 .818 r
.66091 .23682 m .6624 .24118 L .66827 .24483 L p F P
0 g
s
0 0 .474 r
.60718 .17124 m .60411 .16725 L .60063 .16301 L p F P
0 g
s
.197 .452 .876 r
.76629 .12483 m .76203 .12295 L .75908 .11822 L p F P
0 g
s
0 0 .392 r
.83405 .23238 m .83343 .22782 L .83156 .2228 L p F P
0 g
s
0 0 .27 r
.83343 .22782 m .83405 .23238 L .8354 .23758 L p F P
0 g
s
.154 .407 .851 r
.77666 .13678 m .78153 .13935 L .77859 .13436 L p F P
0 g
s
.154 .407 .851 r
.77859 .13436 m .77487 .13239 L .77666 .13678 L p F P
0 g
s
.39 .54 .884 r
.70404 .28436 m .71375 .2869 L .71448 .29138 L p F P
0 g
s
.339 .524 .891 r
.70354 .27979 m .70404 .28436 L .71375 .2869 L p F P
0 g
s
.379 .533 .884 r
.69933 .27864 m .70354 .27979 L .70404 .28436 L p F P
0 g
s
.1 .354 .822 r
.78493 .14522 m .78467 .14453 L p .79191 .15255 L F P
0 g
s
.144 .391 .841 r
.78493 .14522 m .78447 .14441 L .78467 .14453 L closepath p F P
0 g
s
0 0 .508 r
.61359 .17953 m .61071 .17549 L .60718 .17124 L p F P
0 g
s
0 0 .481 r
.60411 .16725 m .60718 .17124 L .61071 .17549 L p F P
0 g
s
.249 .493 .893 r
.75718 .11746 m .75505 .11314 L .74733 .11035 L p F P
0 g
s
.244 .495 .896 r
.74504 .10607 m .74733 .11035 L .75505 .11314 L p F P
0 g
s
.261 .508 .901 r
.73978 .10432 m .74504 .10607 L .74733 .11035 L p F P
0 g
s
.108 .36 .825 r
.66972 .24918 m .67379 .25164 L .67068 .24633 L p F P
0 g
s
.108 .36 .825 r
.67068 .24633 m .66827 .24483 L .66972 .24918 L p F P
0 g
s
0 .16 .696 r
.62628 .19615 m .62552 .19546 L .62236 .19066 L p F P
0 g
s
.254 .508 .903 r
.74504 .10607 m .73978 .10432 L .73682 .09988 L p F P
0 g
s
0 0 .539 r
.61991 .18785 m .61718 .18377 L .61359 .17953 L p F P
0 g
s
0 0 .512 r
.61071 .17549 m .61359 .17953 L .61718 .18377 L p F P
0 g
s
.949 .957 .709 r
.83015 .29205 m .83021 .2902 L .83119 .29027 L closepath p F P
0 g
s
.299 .542 .916 r
.7345 .0992 m .73199 .09496 L .72317 .09262 L p F P
0 g
s
.295 .544 .918 r
.7205 .08843 m .72317 .09262 L .73199 .09496 L p F P
0 g
s
.313 .556 .922 r
.71764 .08774 m .7205 .08843 L .72317 .09262 L p F P
0 g
s
.891 .729 .221 r
.83739 .25769 m .83694 .25313 L p .83689 .26284 L F P
0 g
s
.891 .729 .221 r
.83689 .26284 m .83712 .26143 L .83739 .25769 L p F P
0 g
s
.769 .594 .024 r
.83739 .25769 m .83694 .25313 L .83673 .24753 L p F P
0 g
s
.135 .39 .842 r
.78467 .14453 m .78447 .14441 L .78153 .13935 L p F P
0 g
s
.258 .452 .86 r
.67722 .25762 m .67691 .25706 L .67714 .25716 L closepath p F P
0 g
s
.271 .463 .865 r
.67722 .25762 m .67714 .25716 L p .68555 .26482 L F P
0 g
s
0 0 .385 r
.83084 .21826 m .83156 .2228 L .83343 .22782 L p F P
0 g
s
0 0 .483 r
.83156 .2228 m .83084 .21826 L .8285 .21341 L p F P
0 g
s
.1 .354 .822 r
.78467 .14453 m .7903 .14813 L .79191 .15255 L p F P
0 g
s
.088 .352 .822 r
.78293 .14014 m .78467 .14453 L .7903 .14813 L p F P
0 g
s
.135 .39 .842 r
.78153 .13935 m .78293 .14014 L .78467 .14453 L p F P
0 g
s
.718 .818 .927 r
.79123 .31857 m .80177 .31349 L .80125 .31825 L p F P
0 g
s
.744 .846 .927 r
.80397 .31237 m .80177 .31349 L .80125 .31825 L p F P
0 g
s
.744 .846 .927 r
.80125 .31825 m .80673 .31524 L .80397 .31237 L p F P
0 g
s
0 .002 .554 r
.61991 .18785 m .62236 .19066 L .61921 .18611 L p F P
0 g
s
0 .002 .554 r
.61921 .18611 m .61718 .18377 L .61991 .18785 L p F P
0 g
s
.252 .452 .862 r
.67714 .25716 m .67691 .25706 L .67379 .25164 L p F P
0 g
s
.919 .946 .801 r
.83021 .2902 m .83015 .29205 L .8247 .29947 L p F P
0 g
s
.271 .463 .865 r
.67714 .25716 m .68446 .26038 L .68555 .26482 L p F P
0 g
s
.216 .44 .862 r
.67608 .25269 m .67714 .25716 L .68446 .26038 L p F P
0 g
s
.252 .452 .862 r
.67379 .25164 m .67608 .25269 L .67714 .25716 L p F P
0 g
s
.451 .587 .898 r
.72629 .29798 m .72162 .29744 L .71858 .2924 L p F P
0 g
s
0 .172 .705 r
.81121 .17887 m .81085 .17755 L p .81603 .18626 L F P
0 g
s
0 .23 .744 r
.81121 .17887 m .81033 .17707 L .81085 .17755 L closepath p F P
0 g
s
0 .197 .726 r
.62628 .19615 m .63077 .20014 L .63309 .20432 L p F P
0 g
s
0 .162 .697 r
.62382 .19201 m .62628 .19615 L .63077 .20014 L p F P
0 g
s
0 .16 .696 r
.62236 .19066 m .62382 .19201 L .62628 .19615 L p F P
0 g
s
.068 .342 .818 r
.65354 .22882 m .65125 .22734 L .64812 .22209 L p F P
0 g
s
.965 .906 .546 r
.83555 .26963 m .83568 .27426 L .83341 .28067 L p F P
0 g
s
.918 .829 .37 r
.83568 .27426 m .83555 .26963 L .83692 .26351 L p F P
0 g
s
0 0 .478 r
.82767 .20887 m .8285 .21341 L .83084 .21826 L p F P
0 g
s
0 0 .556 r
.8285 .21341 m .82767 .20887 L .82487 .20419 L p F P
0 g
s
.072 .325 .804 r
.7987 .16072 m .79724 .15627 L .79191 .15255 L p F P
0 g
s
.065 .325 .806 r
.7903 .14813 m .79191 .15255 L .79724 .15627 L p F P
0 g
s
.587 .693 .915 r
.76191 .31674 m .75966 .31712 L .75672 .31276 L p F P
0 g
s
.356 .529 .889 r
.71448 .29138 m .71858 .2924 L .71553 .28738 L p F P
0 g
s
.356 .529 .889 r
.71553 .28738 m .71375 .2869 L .71448 .29138 L p F P
0 g
s
.218 .471 .885 r
.75718 .11746 m .75908 .11822 L .75613 .11357 L p F P
0 g
s
.218 .471 .885 r
.75613 .11357 m .75505 .11314 L .75718 .11746 L p F P
0 g
s
.345 .585 .933 r
.69856 .07686 m .70521 .07808 L .70814 .08222 L p F P
0 g
s
0 .193 .723 r
.63982 .21251 m .63761 .20831 L .63309 .20432 L p F P
0 g
s
0 .172 .706 r
.63077 .20014 m .63309 .20432 L .63761 .20831 L p F P
0 g
s
.361 .526 .884 r
.70354 .27979 m .69933 .27864 L .69625 .27337 L p F P
0 g
s
.798 .898 .913 r
.81675 .30768 m .80673 .31524 L .80397 .31237 L p F P
0 g
s
.472 .6 .898 r
.73772 .30382 m .74038 .30802 L .74044 .30853 L p F P
0 g
s
.456 .607 .911 r
.74072 .30855 m .74044 .30853 L .74038 .30802 L closepath p F P
0 g
s
0 0 .553 r
.82393 .19967 m .82487 .20419 L .82767 .20887 L p F P
0 g
s
0 .05 .615 r
.82487 .20419 m .82393 .19967 L .82071 .19514 L p F P
0 g
s
.046 .295 .785 r
.80504 .16904 m .80372 .16457 L .7987 .16072 L p F P
0 g
s
.054 .308 .794 r
.79724 .15627 m .7987 .16072 L .80372 .16457 L p F P
0 g
s
0 .227 .743 r
.81085 .17755 m .81033 .17707 L .80734 .17106 L p F P
0 g
s
0 0 .132 r
.83673 .24753 m .8362 .24297 L .8354 .23758 L p F P
0 g
s
.786 .605 .04 r
.8362 .24297 m .83673 .24753 L .83694 .25313 L p F P
0 g
s
.509 .652 .923 r
.74072 .30855 m .75376 .30836 L .75672 .31276 L p F P
0 g
s
.512 .637 .909 r
.75079 .30392 m .75376 .30836 L .74072 .30855 L p F P
0 g
s
.512 .637 .909 r
.74057 .30382 m .75079 .30392 L p .74072 .30855 L F P
0 g
s
.512 .637 .909 r
.74072 .30855 m .74038 .30802 L .74057 .30382 L p F P
0 g
s
.243 .454 .866 r
.69405 .27246 m .69291 .26805 L .68555 .26482 L p F P
0 g
s
.22 .443 .864 r
.68446 .26038 m .68555 .26482 L .69291 .26805 L p F P
0 g
s
.332 .577 .931 r
.70814 .08222 m .71466 .08353 L .71167 .07938 L p F P
0 g
s
.332 .577 .931 r
.71167 .07938 m .70521 .07808 L .70814 .08222 L p F P
0 g
s
0 .046 .612 r
.81964 .19065 m .82071 .19514 L .82393 .19967 L p F P
0 g
s
0 .112 .662 r
.82071 .19514 m .81964 .19065 L .81603 .18626 L p F P
0 g
s
.887 .908 .836 r
.8247 .29947 m .82471 .29484 L p .81707 .30391 L F P
0 g
s
.887 .908 .836 r
.81707 .30391 m .81919 .30558 L .8247 .29947 L p F P
0 g
s
.919 .946 .801 r
.82867 .2897 m .83021 .2902 L p .8247 .29947 L F P
0 g
s
.919 .946 .801 r
.8247 .29947 m .82471 .29484 L .82867 .2897 L p F P
0 g
s
0 .241 .752 r
.80504 .16904 m .80734 .17106 L .80436 .16514 L p F P
0 g
s
0 .241 .752 r
.80436 .16514 m .80372 .16457 L .80504 .16904 L p F P
0 g
s
0 .204 .732 r
.64649 .22073 m .64439 .21651 L .63982 .21251 L p F P
0 g
s
0 .175 .709 r
.63761 .20831 m .63982 .21251 L .64439 .21651 L p F P
0 g
s
.571 .688 .92 r
.76191 .31674 m .77263 .31502 L .76972 .31099 L p F P
0 g
s
.571 .688 .92 r
.76972 .31099 m .76232 .31198 L .76191 .31674 L p F P
0 g
s
.587 .693 .915 r
.75672 .31276 m .76232 .31198 L .76191 .31674 L p F P
0 g
s
.508 .633 .909 r
.74038 .30802 m .73772 .30382 L .74057 .30382 L closepath p F P
0 g
s
0 .109 .661 r
.81484 .18179 m .81603 .18626 L .81964 .19065 L p F P
0 g
s
0 .172 .705 r
.81085 .17755 m .81484 .18179 L .81603 .18626 L p F P
0 g
s
.845 .719 .192 r
.83692 .26351 m .83689 .26284 L .83712 .26143 L closepath p F P
0 g
s
0 .163 .7 r
.80954 .17309 m .81085 .17755 L .81484 .18179 L p F P
0 g
s
0 .227 .743 r
.80734 .17106 m .80954 .17309 L .81085 .17755 L p F P
0 g
s
.278 .528 .911 r
.7345 .0992 m .73682 .09988 L .73386 .09551 L p F P
0 g
s
.278 .528 .911 r
.73386 .09551 m .73199 .09496 L .7345 .0992 L p F P
0 g
s
.308 .558 .924 r
.7205 .08843 m .71764 .08774 L .71466 .08353 L p F P
0 g
s
0 .216 .74 r
.64649 .22073 m .64812 .22209 L .64497 .21701 L p F P
0 g
s
0 .216 .74 r
.64497 .21701 m .64439 .21651 L .64649 .22073 L p F P
0 g
s
.798 .898 .913 r
.81707 .30391 m .81675 .30768 L p .80397 .31237 L F P
0 g
s
.839 .913 .886 r
.81675 .30768 m .81707 .30391 L .81919 .30558 L closepath p F P
0 g
s
.95 .943 .738 r
.82867 .2897 m .83007 .28743 L .83021 .2902 L closepath p F P
0 g
s
.973 .928 .66 r
.83341 .28067 m .83007 .28743 L .83021 .2902 L p F P
0 g
s
.178 .431 .864 r
.77487 .13239 m .77296 .12803 L .76629 .12483 L p F P
0 g
s
.171 .433 .867 r
.76424 .1205 m .76629 .12483 L .77296 .12803 L p F P
0 g
s
.197 .452 .876 r
.75908 .11822 m .76424 .1205 L .76629 .12483 L p F P
0 g
s
.645 .77 .939 r
.77552 .31898 m .7884 .31506 L .79123 .31857 L p F P
0 g
s
.632 .759 .939 r
.7884 .31506 m .77552 .31898 L .77263 .31502 L p F P
0 g
s
.188 .451 .877 r
.76424 .1205 m .75908 .11822 L .75613 .11357 L p F P
0 g
s
.243 .454 .866 r
.69405 .27246 m .69625 .27337 L .69317 .26816 L p F P
0 g
s
.243 .454 .866 r
.69317 .26816 m .69291 .26805 L .69405 .27246 L p F P
0 g
s
0 0 .12 r
.83479 .23302 m .8354 .23758 L .8362 .24297 L p F P
0 g
s
0 0 .27 r
.8354 .23758 m .83479 .23302 L .83343 .22782 L p F P
0 g
s
.705 .82 .936 r
.80177 .31349 m .79123 .31857 L .7884 .31506 L p F P
0 g
s
.068 .342 .818 r
.64812 .22209 m .65177 .22452 L .65354 .22882 L p F P
0 g
s
.066 .341 .817 r
.66091 .23682 m .6592 .23251 L .65354 .22882 L p F P
0 g
s
.029 .323 .809 r
.65177 .22452 m .65354 .22882 L .6592 .23251 L p F P
0 g
s
.925 .832 .378 r
.83689 .26284 m .83692 .26351 L .83555 .26963 L p F P
0 g
s
.967 .936 .676 r
.83321 .27607 m .83341 .28067 L .83007 .28743 L p F P
0 g
s
.965 .906 .546 r
.83341 .28067 m .83321 .27607 L .83555 .26963 L p F P
0 g
s
.426 .578 .901 r
.72629 .29798 m .73471 .29907 L .7317 .29431 L p F P
0 g
s
.426 .578 .901 r
.7317 .29431 m .72586 .29342 L .72629 .29798 L p F P
0 g
s
.451 .587 .898 r
.71858 .2924 m .72586 .29342 L .72629 .29798 L p F P
0 g
s
0 .142 .678 r
.62382 .19201 m .62236 .19066 L .61921 .18611 L p F P
0 g
s
.124 .388 .842 r
.78293 .14014 m .78153 .13935 L .77859 .13436 L p F P
0 g
s
.229 .443 .862 r
.67608 .25269 m .67379 .25164 L .67068 .24633 L p F P
0 g
s
0 0 .481 r
.61071 .17549 m .60764 .1715 L .60411 .16725 L p F P
0 g
s
.073 .344 .818 r
.66827 .24483 m .66661 .24052 L .66091 .23682 L p F P
0 g
s
.033 .323 .808 r
.6592 .23251 m .66091 .23682 L .66661 .24052 L p F P
0 g
s
.143 .405 .852 r
.77487 .13239 m .77859 .13436 L .77564 .12945 L p F P
0 g
s
.143 .405 .852 r
.77564 .12945 m .77296 .12803 L .77487 .13239 L p F P
0 g
s
.944 .824 .378 r
.83649 .25894 m .83689 .26284 L .83538 .26565 L p F P
0 g
s
.891 .729 .221 r
.83694 .25313 m .83649 .25894 L .83689 .26284 L p F P
0 g
s
.925 .832 .378 r
.83555 .26963 m .83538 .26565 L .83689 .26284 L p F P
0 g
s
.254 .508 .903 r
.73682 .09988 m .74263 .10181 L .74504 .10607 L p F P
0 g
s
.248 .509 .905 r
.74263 .10181 m .73682 .09988 L .73386 .09551 L p F P
0 g
s
.436 .58 .899 r
.72586 .29342 m .71858 .2924 L .71553 .28738 L p F P
0 g
s
.244 .495 .896 r
.75505 .11314 m .75279 .10884 L .74504 .10607 L p F P
0 g
s
.258 .51 .903 r
.74263 .10181 m .74504 .10607 L .75279 .10884 L p F P
0 g
s
0 0 .385 r
.83343 .22782 m .83273 .22327 L .83084 .21826 L p F P
0 g
s
0 0 .26 r
.83273 .22327 m .83343 .22782 L .83479 .23302 L p F P
0 g
s
.036 .329 .812 r
.65177 .22452 m .64812 .22209 L .64497 .21701 L p F P
0 g
s
0 0 .512 r
.61718 .18377 m .61428 .17974 L .61071 .17549 L p F P
0 g
s
0 0 .487 r
.60764 .1715 m .61071 .17549 L .61428 .17974 L p F P
0 g
s
.295 .544 .918 r
.73199 .09496 m .72934 .09075 L .7205 .08843 L p F P
0 g
s
.289 .546 .92 r
.7177 .08426 m .7205 .08843 L .72934 .09075 L p F P
0 g
s
.308 .558 .924 r
.71466 .08353 m .7177 .08426 L .7205 .08843 L p F P
0 g
s
0 .219 .739 r
.80954 .17309 m .80734 .17106 L .80436 .16514 L p F P
0 g
s
.339 .524 .891 r
.71248 .28238 m .70354 .27979 L p .71375 .2869 L F P
0 g
s
.331 .511 .883 r
.70354 .27979 m .71248 .28238 L .70942 .27736 L p F P
0 g
s
.331 .511 .883 r
.70942 .27736 m .70276 .27528 L .70354 .27979 L p F P
0 g
s
.361 .526 .884 r
.69625 .27337 m .70276 .27528 L .70354 .27979 L p F P
0 g
s
.076 .347 .82 r
.66827 .24483 m .67068 .24633 L .66756 .24112 L p F P
0 g
s
.076 .347 .82 r
.66756 .24112 m .66661 .24052 L .66827 .24483 L p F P
0 g
s
.343 .518 .885 r
.70276 .27528 m .69625 .27337 L .69317 .26816 L p F P
0 g
s
0 0 .53 r
.61718 .18377 m .61921 .18611 L .61605 .18178 L p F P
0 g
s
0 0 .53 r
.61605 .18178 m .61428 .17974 L .61718 .18377 L p F P
0 g
s
.575 .685 .916 r
.76232 .31198 m .75672 .31276 L .75376 .30836 L p F P
0 g
s
.088 .352 .822 r
.7903 .14813 m .78859 .14373 L .78293 .14014 L p F P
0 g
s
.08 .352 .823 r
.78108 .13577 m .78293 .14014 L .78859 .14373 L p F P
0 g
s
.124 .388 .842 r
.77859 .13436 m .78108 .13577 L .78293 .14014 L p F P
0 g
s
.889 .733 .224 r
.83641 .24857 m .83694 .25313 L .83649 .25894 L p F P
0 g
s
.786 .605 .04 r
.83694 .25313 m .83641 .24857 L .8362 .24297 L p F P
0 g
s
0 0 .378 r
.83004 .21372 m .83084 .21826 L .83273 .22327 L p F P
0 g
s
0 0 .478 r
.83084 .21826 m .83004 .21372 L .82767 .20887 L p F P
0 g
s
.508 .633 .908 r
.74057 .30382 m .73772 .30382 L .73471 .29907 L p F P
0 g
s
0 .162 .697 r
.63077 .20014 m .62825 .19601 L .62382 .19201 L p F P
0 g
s
0 .143 .678 r
.62115 .18791 m .62382 .19201 L .62825 .19601 L p F P
0 g
s
0 .142 .678 r
.61921 .18611 m .62115 .18791 L .62382 .19201 L p F P
0 g
s
.216 .44 .862 r
.68446 .26038 m .68315 .25599 L .67608 .25269 L p F P
0 g
s
.185 .426 .859 r
.67478 .24828 m .67608 .25269 L .68315 .25599 L p F P
0 g
s
.229 .443 .862 r
.67068 .24633 m .67478 .24828 L .67608 .25269 L p F P
0 g
s
.065 .325 .806 r
.79724 .15627 m .79566 .15185 L .7903 .14813 L p F P
0 g
s
.056 .325 .807 r
.78859 .14373 m .7903 .14813 L .79566 .15185 L p F P
0 g
s
.944 .939 .756 r
.83007 .28743 m .82867 .2897 L .8261 .28852 L p F P
0 g
s
.944 .939 .756 r
.8261 .28852 m .82976 .28287 L .83007 .28743 L p F P
0 g
s
.967 .936 .676 r
.83007 .28743 m .82976 .28287 L .83321 .27607 L p F P
0 g
s
.705 .82 .936 r
.80227 .31052 m .80177 .31349 L p .7884 .31506 L F P
0 g
s
.73 .832 .928 r
.80177 .31349 m .80227 .31052 L .80397 .31237 L closepath p F P
0 g
s
.21 .471 .886 r
.75505 .11314 m .75613 .11357 L .75318 .109 L p F P
0 g
s
.21 .471 .886 r
.75318 .109 m .75279 .10884 L .75505 .11314 L p F P
0 g
s
0 0 .473 r
.82675 .20435 m .82767 .20887 L .83004 .21372 L p F P
0 g
s
0 0 .553 r
.82767 .20887 m .82675 .20435 L .82393 .19967 L p F P
0 g
s
0 .172 .706 r
.63761 .20831 m .63523 .20416 L .63077 .20014 L p F P
0 g
s
0 .152 .688 r
.62825 .19601 m .63077 .20014 L .63523 .20416 L p F P
0 g
s
.969 .91 .562 r
.83538 .26565 m .83555 .26963 L .83321 .27607 L p F P
0 g
s
.054 .308 .794 r
.80139 .15946 m .79724 .15627 L p .80372 .16457 L F P
0 g
s
.016 .285 .782 r
.79724 .15627 m .80139 .15946 L .79843 .15398 L p F P
0 g
s
.016 .285 .782 r
.79843 .15398 m .79566 .15185 L .79724 .15627 L p F P
0 g
s
.919 .95 .799 r
.82471 .29484 m .82867 .2897 L .8261 .28852 L p F P
0 g
s
.798 .898 .913 r
.80397 .31237 m .81651 .30344 L .81707 .30391 L p F P
0 g
s
.792 .847 .892 r
.80227 .31052 m .80397 .31237 L .81651 .30344 L p F P
0 g
s
.348 .532 .894 r
.71553 .28738 m .71375 .2869 L .71294 .28313 L closepath p F P
0 g
s
.339 .524 .891 r
.71375 .2869 m .71294 .28313 L .71248 .28238 L p F P
0 g
s
0 .046 .612 r
.82393 .19967 m .82288 .19517 L .81964 .19065 L p F P
0 g
s
0 0 .549 r
.82288 .19517 m .82393 .19967 L .82675 .20435 L p F P
0 g
s
.303 .559 .926 r
.7177 .08426 m .71466 .08353 L .71167 .07938 L p F P
0 g
s
0 .175 .709 r
.64183 .21207 m .63761 .20831 L p .64439 .21651 L F P
0 g
s
0 .171 .705 r
.63761 .20831 m .64183 .21207 L .63868 .20727 L p F P
0 g
s
0 .171 .705 r
.63868 .20727 m .63523 .20416 L .63761 .20831 L p F P
0 g
s
.272 .529 .913 r
.73199 .09496 m .73386 .09551 L .73089 .09121 L p F P
0 g
s
.272 .529 .913 r
.73089 .09121 m .72934 .09075 L .73199 .09496 L p F P
0 g
s
0 .237 .751 r
.80436 .16514 m .80372 .16457 L .80312 .16272 L closepath p F P
0 g
s
.054 .308 .794 r
.80372 .16457 m .80312 .16272 L .80139 .15946 L p F P
0 g
s
0 0 .12 r
.8362 .24297 m .8356 .23842 L .83479 .23302 L p F P
0 g
s
.802 .615 .055 r
.8356 .23842 m .8362 .24297 L .83641 .24857 L p F P
0 g
s
.22 .443 .864 r
.69007 .26297 m .68446 .26038 L p .69291 .26805 L F P
0 g
s
.207 .433 .859 r
.68446 .26038 m .69007 .26297 L .68698 .25783 L p F P
0 g
s
.207 .433 .859 r
.68698 .25783 m .68315 .25599 L .68446 .26038 L p F P
0 g
s
.188 .451 .877 r
.75613 .11357 m .76206 .11619 L .76424 .1205 L p F P
0 g
s
.179 .451 .878 r
.76206 .11619 m .75613 .11357 L .75318 .109 L p F P
0 g
s
.887 .908 .836 r
.82471 .29484 m .81701 .30298 L .81707 .30391 L p F P
0 g
s
.852 .9 .869 r
.81651 .30344 m .81701 .30298 L .81707 .30391 L closepath p F P
0 g
s
0 .042 .61 r
.81848 .18616 m .81964 .19065 L .82288 .19517 L p F P
0 g
s
0 .109 .661 r
.81964 .19065 m .81848 .18616 L .81484 .18179 L p F P
0 g
s
.488 .625 .911 r
.74057 .30382 m .75079 .30392 L .74782 .29945 L p F P
0 g
s
.488 .625 .911 r
.74782 .29945 m .74036 .2992 L .74057 .30382 L p F P
0 g
s
.508 .633 .908 r
.73471 .29907 m .74036 .2992 L .74057 .30382 L p F P
0 g
s
.632 .759 .939 r
.77263 .31502 m .78554 .31144 L .7884 .31506 L p F P
0 g
s
.62 .748 .938 r
.78554 .31144 m .77263 .31502 L .76972 .31099 L p F P
0 g
s
0 .16 .699 r
.80812 .16865 m .80954 .17309 L .81355 .17732 L p F P
0 g
s
0 .219 .739 r
.80436 .16514 m .80812 .16865 L .80954 .17309 L p F P
0 g
s
0 .163 .7 r
.81484 .18179 m .81355 .17732 L .80954 .17309 L p F P
0 g
s
0 .106 .659 r
.81355 .17732 m .81484 .18179 L .81848 .18616 L p F P
0 g
s
.204 .434 .861 r
.67478 .24828 m .67068 .24633 L .66756 .24112 L p F P
0 g
s
0 .207 .733 r
.64497 .21701 m .64439 .21651 L .64288 .21373 L closepath p F P
0 g
s
0 .175 .709 r
.64439 .21651 m .64288 .21373 L .64183 .21207 L p F P
0 g
s
.872 .908 .852 r
.82473 .29018 m .82471 .29484 L .81701 .30298 L p F P
0 g
s
.919 .95 .799 r
.8261 .28852 m .82473 .29018 L .82471 .29484 L p F P
0 g
s
.113 .385 .842 r
.78108 .13577 m .77859 .13436 L .77564 .12945 L p F P
0 g
s
.171 .433 .867 r
.77296 .12803 m .77093 .12368 L .76424 .1205 L p F P
0 g
s
.165 .434 .868 r
.76206 .11619 m .76424 .1205 L .77093 .12368 L p F P
0 g
s
0 .209 .733 r
.80812 .16865 m .80436 .16514 L .80312 .16272 L p F P
0 g
s
.705 .82 .936 r
.7884 .31506 m .80118 .30931 L .80227 .31052 L p F P
0 g
s
.692 .808 .937 r
.80118 .30931 m .7884 .31506 L .78554 .31144 L p F P
0 g
s
0 .124 .658 r
.62115 .18791 m .61921 .18611 L .61605 .18178 L p F P
0 g
s
.557 .684 .924 r
.76232 .31198 m .76972 .31099 L .76679 .30689 L p F P
0 g
s
.557 .684 .924 r
.76679 .30689 m .76206 .30741 L .76232 .31198 L p F P
0 g
s
.575 .685 .916 r
.75376 .30836 m .76206 .30741 L .76232 .31198 L p F P
0 g
s
.42 .574 .9 r
.72513 .28893 m .71553 .28738 L .71294 .28313 L p F P
0 g
s
.436 .58 .899 r
.71553 .28738 m .72513 .28893 L .72586 .29342 L p F P
0 g
s
.036 .329 .812 r
.64497 .21701 m .64978 .22026 L .65177 .22452 L p F P
0 g
s
.005 .317 .806 r
.64978 .22026 m .64497 .21701 L .64288 .21373 L p F P
0 g
s
.841 .891 .875 r
.81701 .30298 m .81651 .30344 L .8138 .30097 L p F P
0 g
s
.841 .891 .875 r
.8138 .30097 m .81664 .29846 L .81701 .30298 L p F P
0 g
s
.872 .908 .852 r
.81701 .30298 m .81664 .29846 L .82473 .29018 L p F P
0 g
s
.792 .847 .892 r
.81651 .30344 m .8138 .30097 L p .80227 .31052 L F P
0 g
s
.029 .323 .809 r
.6592 .23251 m .6573 .22825 L .65177 .22452 L p F P
0 g
s
0 .307 .8 r
.64978 .22026 m .65177 .22452 L .6573 .22825 L p F P
0 g
s
.235 .455 .869 r
.69317 .26816 m .69291 .26805 L .69273 .26743 L closepath p F P
0 g
s
.22 .443 .864 r
.69291 .26805 m .69273 .26743 L .69007 .26297 L p F P
0 g
s
.248 .509 .905 r
.73386 .09551 m .74009 .09758 L .74263 .10181 L p F P
0 g
s
.241 .509 .906 r
.74009 .09758 m .73386 .09551 L .73089 .09121 L p F P
0 g
s
0 0 .107 r
.8341 .22847 m .83479 .23302 L .8356 .23842 L p F P
0 g
s
0 0 .26 r
.83479 .23302 m .8341 .22847 L .83273 .22327 L p F P
0 g
s
.343 .518 .885 r
.69317 .26816 m .70172 .27084 L .70276 .27528 L p F P
0 g
s
.325 .511 .885 r
.70172 .27084 m .69317 .26816 L .69273 .26743 L p F P
0 g
s
.944 .824 .378 r
.83538 .26565 m .83531 .26501 L .83649 .25894 L p F P
0 g
s
.955 .831 .398 r
.83595 .2544 m .83649 .25894 L .83531 .26501 L p F P
0 g
s
.889 .733 .224 r
.83649 .25894 m .83595 .2544 L .83641 .24857 L p F P
0 g
s
.133 .404 .853 r
.77296 .12803 m .77564 .12945 L .7727 .12462 L p F P
0 g
s
.133 .404 .853 r
.7727 .12462 m .77093 .12368 L .77296 .12803 L p F P
0 g
s
.258 .51 .903 r
.75023 .10451 m .74263 .10181 L p .75279 .10884 L F P
0 g
s
.229 .497 .9 r
.74263 .10181 m .75023 .10451 L .74728 .10012 L p F P
0 g
s
.229 .497 .9 r
.74728 .10012 m .74009 .09758 L .74263 .10181 L p F P
0 g
s
.325 .511 .885 r
.69273 .26743 m .69193 .26358 L p .70172 .27084 L F P
0 g
s
.316 .503 .882 r
.69273 .26743 m .69007 .26297 L .69193 .26358 L closepath p F P
0 g
s
0 0 .487 r
.61428 .17974 m .6112 .17575 L .60764 .1715 L p F P
0 g
s
.033 .323 .808 r
.66443 .23602 m .6592 .23251 L p .66661 .24052 L F P
0 g
s
.021 .317 .805 r
.6592 .23251 m .66443 .23602 L .66131 .231 L p F P
0 g
s
.021 .317 .805 r
.66131 .231 m .6573 .22825 L .6592 .23251 L p F P
0 g
s
.966 .935 .686 r
.83296 .27146 m .83321 .27607 L .82976 .28287 L p F P
0 g
s
.969 .91 .562 r
.83506 .26587 m .83538 .26565 L p .83321 .27607 L F P
0 g
s
.969 .91 .562 r
.83321 .27607 m .83296 .27146 L .83506 .26587 L p F P
0 g
s
.289 .546 .92 r
.72934 .09075 m .72656 .08657 L .7177 .08426 L p F P
0 g
s
.284 .547 .922 r
.71478 .08011 m .7177 .08426 L .72656 .08657 L p F P
0 g
s
.303 .559 .926 r
.71167 .07938 m .71478 .08011 L .7177 .08426 L p F P
0 g
s
0 .209 .733 r
.80312 .16272 m .80222 .16014 L p .80812 .16865 L F P
0 g
s
0 .266 .77 r
.80312 .16272 m .80139 .15946 L .80222 .16014 L closepath p F P
0 g
s
.562 .678 .917 r
.76206 .30741 m .75376 .30836 L .75079 .30392 L p F P
0 g
s
.408 .572 .904 r
.72586 .29342 m .7317 .29431 L .72868 .28955 L p F P
0 g
s
.408 .572 .904 r
.72868 .28955 m .72513 .28893 L .72586 .29342 L p F P
0 g
s
.495 .627 .909 r
.74036 .2992 m .73471 .29907 L .7317 .29431 L p F P
0 g
s
0 0 .506 r
.61428 .17974 m .61605 .18178 L .61288 .17769 L p F P
0 g
s
0 0 .506 r
.61288 .17769 m .6112 .17575 L .61428 .17974 L p F P
0 g
s
.761 .836 .909 r
.80118 .30931 m .80206 .30878 L .80227 .31052 L closepath p F P
0 g
s
.792 .847 .892 r
.8138 .30097 m .80206 .30878 L .80227 .31052 L p F P
0 g
s
0 0 .251 r
.83194 .21873 m .83273 .22327 L .8341 .22847 L p F P
0 g
s
0 0 .378 r
.83273 .22327 m .83194 .21873 L .83004 .21372 L p F P
0 g
s
.058 .343 .82 r
.66756 .24112 m .66661 .24052 L .66526 .23738 L closepath p F P
0 g
s
.033 .323 .808 r
.66661 .24052 m .66526 .23738 L .66443 .23602 L p F P
0 g
s
.08 .352 .823 r
.78859 .14373 m .78677 .13936 L .78108 .13577 L p F P
0 g
s
.071 .352 .824 r
.77912 .13142 m .78108 .13577 L .78677 .13936 L p F P
0 g
s
.113 .385 .842 r
.77564 .12945 m .77912 .13142 L .78108 .13577 L p F P
0 g
s
.31 .503 .885 r
.70276 .27528 m .70942 .27736 L .70635 .27239 L p F P
0 g
s
.31 .503 .885 r
.70635 .27239 m .70172 .27084 L .70276 .27528 L p F P
0 g
s
0 .143 .678 r
.62825 .19601 m .62555 .19193 L .62115 .18791 L p F P
0 g
s
0 .127 .66 r
.61828 .18387 m .62115 .18791 L .62555 .19193 L p F P
0 g
s
0 .124 .658 r
.61605 .18178 m .61828 .18387 L .62115 .18791 L p F P
0 g
s
.005 .317 .806 r
.64288 .21373 m .64218 .21231 L p .64978 .22026 L F P
0 g
s
0 .301 .796 r
.64288 .21373 m .64183 .21207 L .64218 .21231 L closepath p F P
0 g
s
0 0 .371 r
.82914 .20919 m .83004 .21372 L .83194 .21873 L p F P
0 g
s
0 0 .473 r
.83004 .21372 m .82914 .20919 L .82675 .20435 L p F P
0 g
s
.901 .741 .24 r
.8358 .24402 m .83641 .24857 L .83595 .2544 L p F P
0 g
s
.802 .615 .055 r
.83641 .24857 m .8358 .24402 L .8356 .23842 L p F P
0 g
s
.202 .471 .888 r
.75318 .109 m .75279 .10884 L .75115 .10589 L closepath p F P
0 g
s
.258 .51 .903 r
.75279 .10884 m .75115 .10589 L .75023 .10451 L p F P
0 g
s
.056 .325 .807 r
.79566 .15185 m .79398 .14744 L .78859 .14373 L p F P
0 g
s
.048 .325 .808 r
.78677 .13936 m .78859 .14373 L .79398 .14744 L p F P
0 g
s
.204 .434 .861 r
.66756 .24112 m .67325 .24393 L .67478 .24828 L p F P
0 g
s
.18 .425 .86 r
.67325 .24393 m .66756 .24112 L .66526 .23738 L p F P
0 g
s
0 .152 .688 r
.63523 .20416 m .63266 .20004 L .62825 .19601 L p F P
0 g
s
0 .134 .67 r
.62555 .19193 m .62825 .19601 L .63266 .20004 L p F P
0 g
s
.185 .426 .859 r
.68315 .25599 m .68162 .25166 L .67478 .24828 L p F P
0 g
s
.154 .413 .856 r
.67325 .24393 m .67478 .24828 L .68162 .25166 L p F P
0 g
s
.42 .574 .9 r
.71294 .28313 m .71287 .28245 L p .72513 .28893 L F P
0 g
s
.414 .568 .898 r
.71294 .28313 m .71248 .28238 L .71287 .28245 L closepath p F P
0 g
s
0 .263 .769 r
.80222 .16014 m .80139 .15946 L .79843 .15398 L p F P
0 g
s
.973 .882 .507 r
.83506 .26587 m .83531 .26501 L .83538 .26565 L closepath p F P
0 g
s
.179 .451 .878 r
.75318 .109 m .75977 .1119 L .76206 .11619 L p F P
0 g
s
.17 .45 .879 r
.75977 .1119 m .75318 .109 L .75115 .10589 L p F P
0 g
s
0 0 .468 r
.82573 .19985 m .82675 .20435 L .82914 .20919 L p F P
0 g
s
0 0 .549 r
.82675 .20435 m .82573 .19985 L .82288 .19517 L p F P
0 g
s
.942 .921 .761 r
.82976 .28287 m .8294 .27831 L p .82471 .28772 L F P
0 g
s
.942 .921 .761 r
.82471 .28772 m .8261 .28852 L .82976 .28287 L p F P
0 g
s
.966 .935 .686 r
.82976 .28287 m .8294 .27831 L .83296 .27146 L p F P
0 g
s
.102 .383 .842 r
.77912 .13142 m .77564 .12945 L .7727 .12462 L p F P
0 g
s
.62 .748 .938 r
.76972 .31099 m .78267 .30773 L .78554 .31144 L p F P
0 g
s
.609 .739 .937 r
.78267 .30773 m .76972 .31099 L .76679 .30689 L p F P
0 g
s
.75 .828 .912 r
.80206 .30878 m .80118 .30931 L .79838 .30609 L p F P
0 g
s
.692 .808 .937 r
.78554 .31144 m .79838 .30609 L .80118 .30931 L p F P
0 g
s
0 .28 .78 r
.79566 .15185 m .79843 .15398 L .79547 .14859 L p F P
0 g
s
0 .28 .78 r
.79547 .14859 m .79398 .14744 L .79566 .15185 L p F P
0 g
s
.265 .53 .915 r
.72934 .09075 m .73089 .09121 L .72792 .08697 L p F P
0 g
s
.265 .53 .915 r
.72792 .08697 m .72656 .08657 L .72934 .09075 L p F P
0 g
s
0 .155 .69 r
.63523 .20416 m .63868 .20727 L .63553 .20265 L p F P
0 g
s
0 .155 .69 r
.63553 .20265 m .63266 .20004 L .63523 .20416 L p F P
0 g
s
.413 .569 .899 r
.71287 .28245 m .71248 .28238 L .70942 .27736 L p F P
0 g
s
.75 .828 .912 r
.79838 .30609 m .80143 .30434 L .80206 .30878 L p F P
0 g
s
.783 .871 .913 r
.81106 .29831 m .80143 .30434 L .80206 .30878 L p F P
0 g
s
.783 .871 .913 r
.80206 .30878 m .8138 .30097 L .81106 .29831 L p F P
0 g
s
.981 .891 .541 r
.83531 .26501 m .83506 .26587 L .83267 .26684 L p F P
0 g
s
.981 .891 .541 r
.83267 .26684 m .83473 .26049 L .83531 .26501 L p F P
0 g
s
.955 .831 .398 r
.83531 .26501 m .83473 .26049 L .83595 .2544 L p F P
0 g
s
0 .296 .793 r
.64218 .21231 m .64183 .21207 L .63868 .20727 L p F P
0 g
s
.42 .574 .9 r
.71287 .28245 m .72415 .28451 L .72513 .28893 L p F P
0 g
s
.375 .562 .908 r
.71221 .2779 m .71287 .28245 L .72415 .28451 L p F P
0 g
s
.413 .569 .899 r
.70942 .27736 m .71221 .2779 L .71287 .28245 L p F P
0 g
s
0 0 .546 r
.82174 .19068 m .82288 .19517 L .82573 .19985 L p F P
0 g
s
0 .042 .61 r
.82288 .19517 m .82174 .19068 L .81848 .18616 L p F P
0 g
s
0 .209 .733 r
.80222 .16014 m .80661 .16423 L .80812 .16865 L p F P
0 g
s
0 .205 .731 r
.80058 .15574 m .80222 .16014 L .80661 .16423 L p F P
0 g
s
0 .263 .769 r
.79843 .15398 m .80058 .15574 L .80222 .16014 L p F P
0 g
s
0 .107 .637 r
.61828 .18387 m .61605 .18178 L .61288 .17769 L p F P
0 g
s
.311 .505 .885 r
.69193 .26358 m .69007 .26297 L .68698 .25783 L p F P
0 g
s
.18 .423 .858 r
.68315 .25599 m .68698 .25783 L .68388 .25278 L p F P
0 g
s
.18 .423 .858 r
.68388 .25278 m .68162 .25166 L .68315 .25599 L p F P
0 g
s
0 .038 .608 r
.81721 .18169 m .81848 .18616 L .82174 .19068 L p F P
0 g
s
0 .106 .659 r
.81848 .18616 m .81721 .18169 L .81355 .17732 L p F P
0 g
s
.005 .317 .806 r
.64218 .21231 m .6476 .21605 L .64978 .22026 L p F P
0 g
s
0 .291 .79 r
.63989 .20813 m .64218 .21231 L .6476 .21605 L p F P
0 g
s
0 .296 .793 r
.63868 .20727 m .63989 .20813 L .64218 .21231 L p F P
0 g
s
.971 .91 .566 r
.83296 .27146 m .83506 .26587 L .83267 .26684 L p F P
0 g
s
0 .16 .699 r
.81355 .17732 m .81216 .17288 L .80812 .16865 L p F P
0 g
s
0 .157 .698 r
.80661 .16423 m .80812 .16865 L .81216 .17288 L p F P
0 g
s
0 .102 .657 r
.81216 .17288 m .81355 .17732 L .81721 .18169 L p F P
0 g
s
.817 .624 .07 r
.83492 .23387 m .8356 .23842 L .8358 .24402 L p F P
0 g
s
0 0 .107 r
.8356 .23842 m .83492 .23387 L .8341 .22847 L p F P
0 g
s
.165 .434 .868 r
.77093 .12368 m .76879 .11936 L .76206 .11619 L p F P
0 g
s
.158 .435 .87 r
.75977 .1119 m .76206 .11619 L .76879 .11936 L p F P
0 g
s
.68 .797 .937 r
.79838 .30609 m .78554 .31144 L .78267 .30773 L p F P
0 g
s
.495 .627 .909 r
.7317 .29431 m .73979 .29468 L .74036 .2992 L p F P
0 g
s
.473 .62 .915 r
.74036 .2992 m .74782 .29945 L .74483 .29496 L p F P
0 g
s
.473 .62 .915 r
.74483 .29496 m .73979 .29468 L .74036 .2992 L p F P
0 g
s
.241 .509 .906 r
.73089 .09121 m .73743 .09337 L .74009 .09758 L p F P
0 g
s
.234 .51 .908 r
.73743 .09337 m .73089 .09121 L .72792 .08697 L p F P
0 g
s
.908 .94 .817 r
.82473 .29018 m .82471 .28772 L .8261 .28852 L closepath p F P
0 g
s
.863 .903 .859 r
.82471 .28772 m .82473 .29018 L .81664 .29846 L p F P
0 g
s
0 .307 .8 r
.6573 .22825 m .6552 .22403 L .64978 .22026 L p F P
0 g
s
0 .29 .79 r
.6476 .21605 m .64978 .22026 L .6552 .22403 L p F P
0 g
s
.481 .62 .911 r
.73979 .29468 m .7317 .29431 L .72868 .28955 L p F P
0 g
s
.562 .678 .917 r
.75079 .30392 m .76136 .30296 L .76206 .30741 L p F P
0 g
s
.55 .671 .917 r
.76136 .30296 m .75079 .30392 L .74782 .29945 L p F P
0 g
s
.543 .679 .927 r
.76206 .30741 m .76679 .30689 L .76386 .30275 L p F P
0 g
s
.543 .679 .927 r
.76386 .30275 m .76136 .30296 L .76206 .30741 L p F P
0 g
s
.831 .884 .881 r
.81664 .29846 m .8138 .30097 L .81106 .29831 L p F P
0 g
s
.18 .425 .86 r
.66526 .23738 m .66484 .23623 L p .67325 .24393 L F P
0 g
s
.168 .415 .854 r
.66526 .23738 m .66443 .23602 L .66484 .23623 L closepath p F P
0 g
s
.325 .511 .885 r
.69193 .26358 m .70045 .26646 L .70172 .27084 L p F P
0 g
s
.271 .492 .887 r
.69076 .25914 m .69193 .26358 L .70045 .26646 L p F P
0 g
s
.311 .505 .885 r
.68698 .25783 m .69076 .25914 L .69193 .26358 L p F P
0 g
s
.863 .903 .859 r
.82347 .28686 m .82471 .28772 L p .81664 .29846 L F P
0 g
s
.863 .903 .859 r
.81664 .29846 m .81626 .29393 L .82347 .28686 L p F P
0 g
s
.831 .884 .881 r
.81106 .29831 m .81626 .29393 L .81664 .29846 L p F P
0 g
s
.284 .547 .922 r
.72656 .08657 m .72365 .08242 L .71478 .08011 L p F P
0 g
s
.222 .497 .901 r
.74009 .09758 m .74728 .10012 L .74432 .0958 L p F P
0 g
s
.222 .497 .901 r
.74432 .0958 m .73743 .09337 L .74009 .09758 L p F P
0 g
s
.122 .402 .853 r
.77093 .12368 m .7727 .12462 L .76975 .11987 L p F P
0 g
s
.122 .402 .853 r
.76975 .11987 m .76879 .11936 L .77093 .12368 L p F P
0 g
s
0 0 .251 r
.8341 .22847 m .83333 .22393 L .83194 .21873 L p F P
0 g
s
.714 .492 0 r
.83333 .22393 m .8341 .22847 L .83492 .23387 L p F P
0 g
s
0 .304 .798 r
.6573 .22825 m .66131 .231 L .65817 .2261 L p F P
0 g
s
0 .304 .798 r
.65817 .2261 m .6552 .22403 L .6573 .22825 L p F P
0 g
s
.963 .835 .414 r
.83532 .24986 m .83595 .2544 L .83473 .26049 L p F P
0 g
s
.901 .741 .24 r
.83595 .2544 m .83532 .24986 L .8358 .24402 L p F P
0 g
s
.209 .478 .891 r
.75115 .10589 m .75023 .10451 L .75039 .10457 L closepath p F P
0 g
s
.17 .45 .879 r
.75115 .10589 m .75039 .10457 L p .75977 .1119 L F P
0 g
s
.157 .414 .856 r
.66484 .23623 m .66443 .23602 L .66131 .231 L p F P
0 g
s
.965 .934 .696 r
.83267 .26685 m .83296 .27146 L .8294 .27831 L p F P
0 g
s
.971 .91 .566 r
.83267 .26684 m .83267 .26685 L .83296 .27146 L p F P
0 g
s
.389 .566 .906 r
.72513 .28893 m .72868 .28955 L .72565 .2848 L p F P
0 g
s
.389 .566 .906 r
.72565 .2848 m .72415 .28451 L .72513 .28893 L p F P
0 g
s
0 .256 .766 r
.80058 .15574 m .79843 .15398 L .79547 .14859 L p F P
0 g
s
0 .127 .66 r
.62555 .19193 m .62266 .18789 L .61828 .18387 L p F P
0 g
s
0 .112 .642 r
.61522 .17987 m .61828 .18387 L .62266 .18789 L p F P
0 g
s
0 .107 .637 r
.61288 .17769 m .61522 .17987 L .61828 .18387 L p F P
0 g
s
.071 .352 .824 r
.78677 .13936 m .78483 .135 L .77912 .13142 L p F P
0 g
s
.062 .352 .825 r
.77705 .12709 m .77912 .13142 L .78483 .135 L p F P
0 g
s
.102 .383 .842 r
.7727 .12462 m .77705 .12709 L .77912 .13142 L p F P
0 g
s
.18 .425 .86 r
.66484 .23623 m .67151 .23963 L .67325 .24393 L p F P
0 g
s
.128 .403 .853 r
.66307 .23192 m .66484 .23623 L .67151 .23963 L p F P
0 g
s
.157 .414 .856 r
.66131 .231 m .66307 .23192 L .66484 .23623 L p F P
0 g
s
0 0 .371 r
.83194 .21873 m .83106 .21421 L .82914 .20919 L p F P
0 g
s
0 0 .246 r
.83106 .21421 m .83194 .21873 L .83333 .22393 L p F P
0 g
s
.288 .496 .886 r
.70172 .27084 m .70635 .27239 L .70328 .26746 L p F P
0 g
s
.288 .496 .886 r
.70328 .26746 m .70045 .26646 L .70172 .27084 L p F P
0 g
s
.397 .563 .901 r
.71221 .2779 m .70942 .27736 L .70635 .27239 L p F P
0 g
s
.201 .478 .893 r
.75039 .10457 m .75023 .10451 L .74728 .10012 L p F P
0 g
s
.09 .38 .842 r
.77705 .12709 m .7727 .12462 L .76975 .11987 L p F P
0 g
s
.17 .45 .879 r
.75039 .10457 m .75736 .10764 L .75977 .1119 L p F P
0 g
s
.161 .45 .88 r
.74784 .10034 m .75039 .10457 L .75736 .10764 L p F P
0 g
s
.201 .478 .893 r
.74728 .10012 m .74784 .10034 L .75039 .10457 L p F P
0 g
s
0 .134 .67 r
.63266 .20004 m .62993 .19597 L .62555 .19193 L p F P
0 g
s
0 .118 .652 r
.62266 .18789 m .62555 .19193 L .62993 .19597 L p F P
0 g
s
.292 .498 .886 r
.69076 .25914 m .68698 .25783 L .68388 .25278 L p F P
0 g
s
.048 .325 .808 r
.79398 .14744 m .79219 .14305 L .78677 .13936 L p F P
0 g
s
.058 .341 .818 r
.78483 .135 m .78677 .13936 L .79219 .14305 L p F P
0 g
s
.609 .739 .937 r
.76679 .30689 m .77979 .30394 L .78267 .30773 L p F P
0 g
s
.598 .731 .937 r
.77979 .30394 m .76679 .30689 L .76386 .30275 L p F P
0 g
s
0 .283 .784 r
.63989 .20813 m .63868 .20727 L .63553 .20265 L p F P
0 g
s
0 0 .362 r
.82814 .20468 m .82914 .20919 L .83106 .21421 L p F P
0 g
s
0 0 .468 r
.82914 .20919 m .82814 .20468 L .82573 .19985 L p F P
0 g
s
.913 .748 .255 r
.83512 .23948 m .8358 .24402 L .83532 .24986 L p F P
0 g
s
.817 .624 .07 r
.8358 .24402 m .83512 .23948 L .83492 .23387 L p F P
0 g
s
.91 .921 .811 r
.82347 .28686 m .82448 .28559 L .82471 .28772 L closepath p F P
0 g
s
.942 .921 .761 r
.8294 .27831 m .82448 .28559 L .82471 .28772 L p F P
0 g
s
.154 .413 .856 r
.68162 .25166 m .6799 .24737 L .67325 .24393 L p F P
0 g
s
.12 .396 .849 r
.67151 .23963 m .67325 .24393 L .6799 .24737 L p F P
0 g
s
.259 .531 .917 r
.72656 .08657 m .72792 .08697 L .72494 .0828 L p F P
0 g
s
.259 .531 .917 r
.72494 .0828 m .72365 .08242 L .72656 .08657 L p F P
0 g
s
0 .14 .674 r
.63266 .20004 m .63553 .20265 L .63238 .19822 L p F P
0 g
s
0 .14 .674 r
.63238 .19822 m .62993 .19597 L .63266 .20004 L p F P
0 g
s
.74 .822 .915 r
.80143 .30434 m .79838 .30609 L .79555 .30275 L p F P
0 g
s
.68 .797 .937 r
.78267 .30773 m .79555 .30275 L .79838 .30609 L p F P
0 g
s
0 .274 .777 r
.79398 .14744 m .79547 .14859 L .79251 .1433 L p F P
0 g
s
0 .274 .777 r
.79251 .1433 m .79219 .14305 L .79398 .14744 L p F P
0 g
s
0 0 .463 r
.82461 .19535 m .82573 .19985 L .82814 .20468 L p F P
0 g
s
0 0 .546 r
.82573 .19985 m .82461 .19535 L .82174 .19068 L p F P
0 g
s
.933 .925 .777 r
.829 .27374 m .8294 .27831 L .82448 .28559 L p F P
0 g
s
.965 .934 .696 r
.8294 .27831 m .829 .27374 L .83267 .26685 L p F P
0 g
s
.668 .786 .937 r
.79555 .30275 m .78267 .30773 L .77979 .30394 L p F P
0 g
s
0 .205 .731 r
.80661 .16423 m .80498 .15982 L .80058 .15574 L p F P
0 g
s
0 .202 .73 r
.79882 .15135 m .80058 .15574 L .80498 .15982 L p F P
0 g
s
0 .256 .766 r
.79547 .14859 m .79882 .15135 L .80058 .15574 L p F P
0 g
s
0 0 .548 r
.8205 .1862 m .82174 .19068 L .82461 .19535 L p F P
0 g
s
0 .038 .608 r
.82174 .19068 m .8205 .1862 L .81721 .18169 L p F P
0 g
s
.481 .62 .911 r
.72868 .28955 m .73892 .29023 L .73979 .29468 L p F P
0 g
s
.468 .614 .912 r
.73892 .29023 m .72868 .28955 L .72565 .2848 L p F P
0 g
s
.74 .822 .915 r
.79555 .30275 m .80087 .29985 L .80143 .30434 L p F P
0 g
s
.769 .858 .916 r
.8083 .29547 m .80087 .29985 L .80143 .30434 L p F P
0 g
s
.769 .858 .916 r
.80143 .30434 m .81106 .29831 L .8083 .29547 L p F P
0 g
s
0 .291 .79 r
.6476 .21605 m .64523 .21189 L .63989 .20813 L p F P
0 g
s
0 .277 .78 r
.63739 .20399 m .63989 .20813 L .64523 .21189 L p F P
0 g
s
0 .283 .784 r
.63553 .20265 m .63739 .20399 L .63989 .20813 L p F P
0 g
s
.158 .435 .87 r
.76879 .11936 m .76652 .11507 L .75977 .1119 L p F P
0 g
s
.172 .451 .879 r
.75736 .10764 m .75977 .1119 L .76652 .11507 L p F P
0 g
s
.989 .886 .562 r
.83473 .26049 m .83407 .25596 L p .83267 .26684 L F P
0 g
s
.989 .886 .562 r
.83267 .26684 m .83267 .26684 L .83473 .26049 L p F P
0 g
s
.963 .835 .414 r
.83473 .26049 m .83407 .25596 L .83532 .24986 L p F P
0 g
s
.55 .671 .917 r
.74782 .29945 m .76034 .29859 L .76136 .30296 L p F P
0 g
s
.538 .665 .918 r
.76034 .29859 m .74782 .29945 L .74483 .29496 L p F P
0 g
s
.234 .51 .908 r
.72792 .08697 m .73465 .08919 L .73743 .09337 L p F P
0 g
s
.227 .511 .909 r
.73465 .08919 m .72792 .08697 L .72494 .0828 L p F P
0 g
s
0 .157 .698 r
.81216 .17288 m .81066 .16845 L .80661 .16423 L p F P
0 g
s
0 .154 .696 r
.80498 .15982 m .80661 .16423 L .81066 .16845 L p F P
0 g
s
.373 .55 .9 r
.71221 .2779 m .72261 .28006 L .71956 .27531 L p F P
0 g
s
.373 .55 .9 r
.71956 .27531 m .71127 .27343 L .71221 .2779 L p F P
0 g
s
.397 .563 .901 r
.70635 .27239 m .71127 .27343 L .71221 .2779 L p F P
0 g
s
.375 .562 .908 r
.72261 .28006 m .71221 .2779 L p .72415 .28451 L F P
0 g
s
.154 .413 .856 r
.68162 .25166 m .68388 .25278 L .68077 .24781 L p F P
0 g
s
.154 .413 .856 r
.68077 .24781 m .6799 .24737 L .68162 .25166 L p F P
0 g
s
0 .052 .619 r
.81584 .17724 m .81721 .18169 L .8205 .1862 L p F P
0 g
s
0 .102 .657 r
.81721 .18169 m .81584 .17724 L .81216 .17288 L p F P
0 g
s
0 .099 .655 r
.81066 .16845 m .81216 .17288 L .81584 .17724 L p F P
0 g
s
.832 .632 .084 r
.83416 .22933 m .83492 .23387 L .83512 .23948 L p F P
0 g
s
.714 .492 0 r
.83492 .23387 m .83416 .22933 L .83333 .22393 L p F P
0 g
s
0 .29 .79 r
.6552 .22403 m .65293 .21985 L .6476 .21605 L p F P
0 g
s
0 .275 .779 r
.64523 .21189 m .6476 .21605 L .65293 .21985 L p F P
0 g
s
0 .249 .762 r
.79882 .15135 m .79547 .14859 L .79251 .1433 L p F P
0 g
s
.457 .616 .918 r
.73979 .29468 m .74483 .29496 L .74183 .29046 L p F P
0 g
s
.457 .616 .918 r
.74183 .29046 m .73892 .29023 L .73979 .29468 L p F P
0 g
s
.131 .405 .854 r
.66307 .23192 m .66131 .231 L .65817 .2261 L p F P
0 g
s
.215 .497 .903 r
.73743 .09337 m .74432 .0958 L .74135 .09155 L p F P
0 g
s
.215 .497 .903 r
.74135 .09155 m .73465 .08919 L .73743 .09337 L p F P
0 g
s
.111 .401 .853 r
.76879 .11936 m .76975 .11987 L .7668 .11522 L p F P
0 g
s
.111 .401 .853 r
.7668 .11522 m .76652 .11507 L .76879 .11936 L p F P
0 g
s
.901 .914 .821 r
.82448 .28559 m .82347 .28686 L .82079 .28481 L p F P
0 g
s
.901 .914 .821 r
.82079 .28481 m .8239 .28109 L .82448 .28559 L p F P
0 g
s
.933 .925 .777 r
.82448 .28559 m .8239 .28109 L .829 .27374 L p F P
0 g
s
.529 .674 .93 r
.76136 .30296 m .76386 .30275 L .76091 .29855 L p F P
0 g
s
.529 .674 .93 r
.76091 .29855 m .76034 .29859 L .76136 .30296 L p F P
0 g
s
.866 .918 .862 r
.81626 .29393 m .82347 .28686 L .82079 .28481 L p F P
0 g
s
.271 .492 .887 r
.70045 .26646 m .69897 .26212 L .69076 .25914 L p F P
0 g
s
.242 .478 .885 r
.68935 .25477 m .69076 .25914 L .69897 .26212 L p F P
0 g
s
.292 .498 .886 r
.68388 .25278 m .68935 .25477 L .69076 .25914 L p F P
0 g
s
.821 .878 .887 r
.81626 .29393 m .81106 .29831 L .8083 .29547 L p F P
0 g
s
0 .291 .79 r
.6552 .22403 m .65817 .2261 L .65504 .22134 L p F P
0 g
s
0 .291 .79 r
.65504 .22134 m .65293 .21985 L .6552 .22403 L p F P
0 g
s
.382 .557 .902 r
.71127 .27343 m .70635 .27239 L .70328 .26746 L p F P
0 g
s
0 0 .246 r
.83201 .21775 m .83106 .21421 L p .83331 .22385 L F P
0 g
s
0 0 .246 r
.83333 .22393 m .83329 .22377 L .83331 .22385 L F
.83329 .22377 m .83201 .21775 L .83331 .22385 L F
.733 .503 0 r
.83416 .22933 m .83359 .22636 L .83261 .22021 L p F P
0 g
s
0 0 .246 r
.83333 .22393 m .8326 .22012 L .83201 .21775 L p F P
0 g
s
.733 .503 0 r
.83261 .22021 m .8326 .22012 L p .83262 .22026 L F P
0 g
s
.733 .503 0 r
.83416 .22933 m .83261 .22021 L .83262 .22026 L F
.8326 .22012 m .83333 .22393 L .83416 .22933 L p F P
0 g
s
.821 .878 .887 r
.8083 .29547 m .81588 .28937 L .81626 .29393 L p F P
0 g
s
.866 .918 .862 r
.82079 .28481 m .81588 .28937 L .81626 .29393 L p F P
0 g
s
.272 .491 .886 r
.68935 .25477 m .68388 .25278 L .68077 .24781 L p F P
0 g
s
0 .112 .642 r
.62266 .18789 m .61959 .18389 L .61522 .17987 L p F P
0 g
s
.969 .839 .428 r
.83462 .24533 m .83532 .24986 L .83407 .25596 L p F P
0 g
s
.913 .748 .255 r
.83532 .24986 m .83462 .24533 L .83512 .23948 L p F P
0 g
s
.09 .38 .842 r
.76975 .11987 m .77486 .12279 L .77705 .12709 L p F P
0 g
s
.078 .377 .841 r
.77486 .12279 m .76975 .11987 L .7668 .11522 L p F P
0 g
s
.062 .352 .825 r
.78483 .135 m .78278 .13066 L .77705 .12709 L p F P
0 g
s
.052 .351 .826 r
.77486 .12279 m .77705 .12709 L .78278 .13066 L p F P
0 g
s
.193 .478 .894 r
.74784 .10034 m .74728 .10012 L .74432 .0958 L p F P
0 g
s
0 .27 .774 r
.63739 .20399 m .63553 .20265 L .63238 .19822 L p F P
0 g
s
.384 .569 .91 r
.72565 .2848 m .72415 .28451 L .72318 .28095 L closepath p F P
0 g
s
.375 .562 .908 r
.72415 .28451 m .72318 .28095 L .72261 .28006 L p F P
0 g
s
.128 .403 .853 r
.67151 .23963 m .66959 .23537 L .66307 .23192 L p F P
0 g
s
.099 .391 .848 r
.66108 .22766 m .66307 .23192 L .66959 .23537 L p F P
0 g
s
.131 .405 .854 r
.65817 .2261 m .66108 .22766 L .66307 .23192 L p F P
0 g
s
.976 .917 .602 r
.83267 .26685 m .83267 .26684 L .83267 .26684 L closepath p F P
0 g
s
.96 .934 .717 r
.83267 .26684 m .83267 .26685 L .829 .27374 L p F P
0 g
s
.598 .731 .937 r
.76386 .30275 m .77689 .30008 L .77979 .30394 L p F P
0 g
s
.588 .723 .937 r
.77689 .30008 m .76386 .30275 L .76091 .29855 L p F P
0 g
s
.978 .915 .656 r
.83015 .26634 m .83196 .26236 L .83267 .26684 L closepath p F P
0 g
s
.989 .886 .562 r
.83407 .25596 m .83196 .26236 L .83267 .26684 L p F P
0 g
s
.96 .934 .717 r
.83015 .26634 m .83267 .26684 L p .829 .27374 L F P
0 g
s
0 0 .219 r
.83201 .21775 m .83106 .21421 L .83072 .21265 L closepath p F P
0 g
s
0 0 .362 r
.8285 .20565 m .82814 .20468 L p .83106 .21421 L F P
0 g
s
0 0 .362 r
.83106 .21421 m .83072 .21265 L .8285 .20565 L p F P
0 g
s
0 .118 .652 r
.62993 .19597 m .62702 .19194 L .62266 .18789 L p F P
0 g
s
0 .105 .635 r
.61959 .18389 m .62266 .18789 L .62702 .19194 L p F P
0 g
s
.161 .45 .88 r
.75736 .10764 m .75482 .1034 L .74784 .10034 L p F P
0 g
s
.153 .45 .881 r
.74517 .09613 m .74784 .10034 L .75482 .1034 L p F P
0 g
s
.193 .478 .894 r
.74432 .0958 m .74517 .09613 L .74784 .10034 L p F P
0 g
s
.266 .488 .886 r
.70045 .26646 m .70328 .26746 L .7002 .26258 L p F P
0 g
s
.266 .488 .886 r
.7002 .26258 m .69897 .26212 L .70045 .26646 L p F P
0 g
s
.058 .341 .818 r
.78956 .13822 m .78483 .135 L p .79219 .14305 L F P
0 g
s
.019 .318 .806 r
.78483 .135 m .78956 .13822 L .78661 .13328 L p F P
0 g
s
.019 .318 .806 r
.78661 .13328 m .78278 .13066 L .78483 .135 L p F P
0 g
s
.468 .614 .912 r
.72565 .2848 m .7378 .28585 L .73892 .29023 L p F P
0 g
s
.455 .609 .913 r
.7378 .28585 m .72565 .2848 L .72318 .28095 L p F P
0 g
s
0 .125 .658 r
.62993 .19597 m .63238 .19822 L .62923 .19397 L p F P
0 g
s
0 .125 .658 r
.62923 .19397 m .62702 .19194 L .62993 .19597 L p F P
0 g
s
0 0 .334 r
.8285 .20565 m .82814 .20468 L .82796 .20396 L closepath p F P
0 g
s
0 0 .463 r
.82527 .19669 m .82461 .19535 L p .82814 .20468 L F P
0 g
s
0 0 .463 r
.82814 .20468 m .82796 .20396 L .82527 .19669 L p F P
0 g
s
.12 .396 .849 r
.67766 .24292 m .67151 .23963 L p .6799 .24737 L F P
0 g
s
.114 .392 .847 r
.67151 .23963 m .67766 .24292 L .67455 .2381 L p F P
0 g
s
.114 .392 .847 r
.67455 .2381 m .66959 .23537 L .67151 .23963 L p F P
0 g
s
.73 .816 .919 r
.80087 .29985 m .79555 .30275 L .79271 .2993 L p F P
0 g
s
.668 .786 .937 r
.77979 .30394 m .79271 .2993 L .79555 .30275 L p F P
0 g
s
.538 .665 .918 r
.74483 .29496 m .75796 .29431 L p .76034 .29859 L F P
0 g
s
.511 .665 .931 r
.75796 .29431 m .74483 .29496 L .74183 .29046 L p F P
0 g
s
.832 .632 .084 r
.83512 .23948 m .83435 .23495 L .83416 .22933 L p F P
0 g
s
.923 .754 .27 r
.83435 .23495 m .83512 .23948 L .83462 .24533 L p F P
0 g
s
.656 .776 .937 r
.79271 .2993 m .77979 .30394 L .77689 .30008 L p F P
0 g
s
0 .27 .776 r
.79251 .1433 m .79219 .14305 L .7916 .1417 L closepath p F P
0 g
s
.058 .341 .818 r
.79219 .14305 m .7916 .1417 L .78956 .13822 L p F P
0 g
s
0 0 .436 r
.82527 .19669 m .82461 .19535 L .82421 .19386 L closepath p F P
0 g
s
0 0 .548 r
.82213 .18887 m .8205 .1862 L p .82461 .19535 L F P
0 g
s
0 0 .548 r
.82461 .19535 m .82421 .19386 L .82213 .18887 L p F P
0 g
s
.227 .511 .909 r
.72494 .0828 m .73173 .08503 L .73465 .08919 L p F P
0 g
s
0 .249 .762 r
.79251 .1433 m .79696 .14699 L .79882 .15135 L p F P
0 g
s
0 .242 .757 r
.79696 .14699 m .79251 .1433 L .7916 .1417 L p F P
0 g
s
.172 .451 .879 r
.76386 .11067 m .75736 .10764 L p .76652 .11507 L F P
0 g
s
.138 .433 .872 r
.75736 .10764 m .76386 .11067 L .76091 .10624 L p F P
0 g
s
.138 .433 .872 r
.76091 .10624 m .75482 .1034 L .75736 .10764 L p F P
0 g
s
0 .277 .78 r
.64523 .21189 m .64268 .20777 L .63739 .20399 L p F P
0 g
s
0 .264 .769 r
.63471 .1999 m .63739 .20399 L .64268 .20777 L p F P
0 g
s
0 .27 .774 r
.63238 .19822 m .63471 .1999 L .63739 .20399 L p F P
0 g
s
0 0 .308 r
.83072 .21265 m .8285 .20565 L .82997 .20973 L closepath p F P
0 g
s
0 0 .3 r
.82997 .20973 m .8285 .20565 L .82796 .20396 L p F P
0 g
s
0 0 .3 r
.82796 .20396 m .82692 .20022 L p .82997 .20973 L F P
0 g
s
0 0 .41 r
.82796 .20396 m .82527 .19669 L .82692 .20022 L closepath p F P
0 g
s
0 .202 .73 r
.80498 .15982 m .80325 .15543 L .79882 .15135 L p F P
0 g
s
0 .199 .728 r
.79696 .14699 m .79882 .15135 L .80325 .15543 L p F P
0 g
s
0 0 .187 r
.83072 .21265 m .82997 .20973 L p .83244 .21941 L F P
0 g
s
0 0 .187 r
.83244 .21941 m .83201 .21775 L .83072 .21265 L p F P
0 g
s
.106 .397 .851 r
.66108 .22766 m .65817 .2261 L .65504 .22134 L p F P
0 g
s
0 0 .523 r
.82213 .18887 m .8205 .1862 L .81927 .18209 L closepath p F P
0 g
s
0 .052 .619 r
.81903 .18157 m .81584 .17724 L p .8205 .1862 L F P
0 g
s
0 .052 .619 r
.8205 .1862 m .81927 .18209 L .81903 .18157 L p F P
0 g
s
.929 .922 .784 r
.82856 .26917 m .829 .27374 L .8239 .28109 L p F P
0 g
s
.96 .934 .717 r
.829 .27374 m .82856 .26917 L .83015 .26634 L p F P
0 g
s
0 .154 .696 r
.81066 .16845 m .80906 .16403 L .80498 .15982 L p F P
0 g
s
0 .151 .694 r
.80325 .15543 m .80498 .15982 L .80906 .16403 L p F P
0 g
s
.141 .412 .857 r
.68077 .24781 m .6799 .24737 L .67856 .24434 L closepath p F P
0 g
s
.12 .396 .849 r
.6799 .24737 m .67856 .24434 L .67766 .24292 L p F P
0 g
s
0 .016 .59 r
.81584 .17724 m .81903 .18157 L .81599 .17502 L p F P
0 g
s
0 .016 .59 r
.81599 .17502 m .81437 .1728 L .81584 .17724 L p F P
0 g
s
0 .099 .655 r
.81584 .17724 m .81437 .1728 L .81066 .16845 L p F P
0 g
s
0 .095 .653 r
.80906 .16403 m .81066 .16845 L .81437 .1728 L p F P
0 g
s
.73 .816 .919 r
.79271 .2993 m .80043 .29531 L .80087 .29985 L p F P
0 g
s
.757 .845 .918 r
.80551 .29249 m .80043 .29531 L .80087 .29985 L p F P
0 g
s
.757 .845 .918 r
.80087 .29985 m .8083 .29547 L .80551 .29249 L p F P
0 g
s
.987 .892 .569 r
.83334 .25145 m .83407 .25596 L .83196 .26236 L p F P
0 g
s
.969 .839 .428 r
.83407 .25596 m .83334 .25145 L .83462 .24533 L p F P
0 g
s
.354 .545 .902 r
.71127 .27343 m .71956 .27531 L .71651 .27059 L p F P
0 g
s
.354 .545 .902 r
.71651 .27059 m .71009 .26901 L .71127 .27343 L p F P
0 g
s
.382 .557 .902 r
.70328 .26746 m .71009 .26901 L .71127 .27343 L p F P
0 g
s
.366 .552 .903 r
.71009 .26901 m .70328 .26746 L .7002 .26258 L p F P
0 g
s
0 .275 .779 r
.65293 .21985 m .65049 .21571 L .64523 .21189 L p F P
0 g
s
0 .261 .769 r
.64268 .20777 m .64523 .21189 L .65049 .21571 L p F P
0 g
s
.207 .498 .904 r
.73465 .08919 m .74135 .09155 L .73838 .08737 L p F P
0 g
s
.207 .498 .904 r
.73838 .08737 m .73173 .08503 L .73465 .08919 L p F P
0 g
s
0 .242 .757 r
.7916 .1417 m .79022 .1387 L p .79696 .14699 L F P
0 g
s
0 .297 .793 r
.7916 .1417 m .78956 .13822 L .79022 .1387 L closepath p F P
0 g
s
.846 .64 .098 r
.83359 .22636 m .83416 .22933 L .83435 .23495 L p F P
0 g
s
0 0 .403 r
.82692 .20022 m .82527 .19669 L .82421 .19386 L p F P
0 g
s
0 0 .195 r
.8326 .22012 m .83201 .21775 L .83244 .21941 L closepath p F P
0 g
s
.272 .491 .886 r
.68077 .24781 m .68774 .25044 L .68935 .25477 L p F P
0 g
s
.253 .484 .886 r
.68774 .25044 m .68077 .24781 L .67856 .24434 L p F P
0 g
s
.101 .399 .854 r
.7668 .11522 m .76652 .11507 L .7653 .11288 L closepath p F P
0 g
s
.172 .451 .879 r
.76652 .11507 m .7653 .11288 L .76386 .11067 L p F P
0 g
s
0 0 .403 r
.82421 .19386 m .82331 .1909 L p .82692 .20022 L F P
0 g
s
0 0 .498 r
.82421 .19386 m .82213 .18887 L .82331 .1909 L closepath p F P
0 g
s
.778 .534 0 r
.83244 .21941 m .8326 .22012 L .83359 .22636 L p F P
0 g
s
.441 .61 .92 r
.73892 .29023 m .74183 .29046 L .73883 .28595 L p F P
0 g
s
.441 .61 .92 r
.73883 .28595 m .7378 .28585 L .73892 .29023 L p F P
0 g
s
.078 .377 .841 r
.7668 .11522 m .77256 .1185 L .77486 .12279 L p F P
0 g
s
.065 .374 .84 r
.77256 .1185 m .7668 .11522 L .7653 .11288 L p F P
0 g
s
0 .279 .782 r
.65293 .21985 m .65504 .22134 L .6519 .21672 L p F P
0 g
s
0 .279 .782 r
.6519 .21672 m .65049 .21571 L .65293 .21985 L p F P
0 g
s
.893 .909 .829 r
.8239 .28109 m .82079 .28481 L .81809 .28253 L p F P
0 g
s
.893 .909 .829 r
.81809 .28253 m .82328 .27658 L .8239 .28109 L p F P
0 g
s
.929 .922 .784 r
.8239 .28109 m .82328 .27658 L .82856 .26917 L p F P
0 g
s
.242 .478 .885 r
.69712 .25775 m .68935 .25477 L p .69897 .26212 L F P
0 g
s
.239 .473 .882 r
.68935 .25477 m .69712 .25775 L .69403 .25296 L p F P
0 g
s
.239 .473 .882 r
.69403 .25296 m .68774 .25044 L .68935 .25477 L p F P
0 g
s
.528 .675 .931 r
.76091 .29855 m .76034 .29859 L .75997 .2972 L closepath p F P
0 g
s
.538 .665 .918 r
.75796 .29431 m .75997 .2972 L .76034 .29859 L p F P
0 g
s
.811 .872 .892 r
.81588 .28937 m .8083 .29547 L .80551 .29249 L p F P
0 g
s
0 .258 .763 r
.63471 .1999 m .63238 .19822 L .62923 .19397 L p F P
0 g
s
.455 .609 .913 r
.72318 .28095 m .72306 .2801 L p .7378 .28585 L F P
0 g
s
.452 .605 .912 r
.72318 .28095 m .72261 .28006 L .72306 .2801 L closepath p F P
0 g
s
.185 .478 .895 r
.74517 .09613 m .74432 .0958 L .74135 .09155 L p F P
0 g
s
.588 .723 .937 r
.76091 .29855 m .77398 .29616 L .77689 .30008 L p F P
0 g
s
.586 .703 .924 r
.77105 .29218 m .77398 .29616 L .76091 .29855 L p F P
0 g
s
.586 .703 .924 r
.76009 .29395 m .77105 .29218 L p .76091 .29855 L F P
0 g
s
.586 .703 .924 r
.76091 .29855 m .75997 .2972 L .76009 .29395 L p F P
0 g
s
.778 .534 0 r
.83359 .22636 m .83323 .22482 L .83244 .21941 L p F P
0 g
s
.798 .545 0 r
.83129 .21495 m .83244 .21941 L .83323 .22482 L p F P
0 g
s
0 0 .187 r
.82997 .20973 m .83129 .21495 L .83244 .21941 L p F P
0 g
s
.853 .904 .87 r
.81588 .28937 m .82079 .28481 L .81809 .28253 L p F P
0 g
s
.052 .351 .826 r
.78278 .13066 m .78061 .12634 L .77486 .12279 L p F P
0 g
s
.042 .35 .826 r
.77256 .1185 m .77486 .12279 L .78061 .12634 L p F P
0 g
s
.811 .872 .892 r
.80551 .29249 m .81552 .28479 L .81588 .28937 L p F P
0 g
s
.853 .904 .87 r
.81809 .28253 m .81552 .28479 L .81588 .28937 L p F P
0 g
s
.975 .842 .441 r
.83385 .24081 m .83462 .24533 L .83334 .25145 L p F P
0 g
s
.923 .754 .27 r
.83462 .24533 m .83385 .24081 L .83435 .23495 L p F P
0 g
s
0 .105 .635 r
.62702 .19194 m .62394 .18794 L .61959 .18389 L p F P
0 g
s
.451 .607 .913 r
.72306 .2801 m .72261 .28006 L .71956 .27531 L p F P
0 g
s
0 0 .493 r
.82331 .1909 m .82213 .18887 L .81927 .18209 L p F P
0 g
s
.153 .45 .881 r
.75482 .1034 m .75217 .09918 L .74517 .09613 L p F P
0 g
s
.145 .45 .881 r
.74238 .09195 m .74517 .09613 L .75217 .09918 L p F P
0 g
s
.185 .478 .895 r
.74135 .09155 m .74238 .09195 L .74517 .09613 L p F P
0 g
s
.099 .391 .848 r
.66959 .23537 m .66747 .23116 L .66108 .22766 L p F P
0 g
s
.071 .38 .843 r
.6589 .22346 m .66108 .22766 L .66747 .23116 L p F P
0 g
s
.106 .397 .851 r
.65504 .22134 m .6589 .22346 L .66108 .22766 L p F P
0 g
s
.455 .609 .913 r
.72306 .2801 m .73582 .28142 L p .7378 .28585 L F P
0 g
s
.432 .595 .912 r
.72306 .2801 m .73582 .28142 L .73279 .27689 L p F P
0 g
s
.432 .595 .912 r
.73279 .27689 m .7222 .2756 L .72306 .2801 L p F P
0 g
s
.451 .607 .913 r
.71956 .27531 m .7222 .2756 L .72306 .2801 L p F P
0 g
s
.511 .665 .931 r
.74183 .29046 m .75499 .29003 L .75796 .29431 L p F P
0 g
s
.502 .659 .931 r
.75499 .29003 m .74183 .29046 L .73883 .28595 L p F P
0 g
s
.979 .904 .666 r
.83196 .26236 m .83117 .25786 L p .82816 .26563 L F P
0 g
s
.979 .904 .666 r
.82816 .26563 m .83015 .26634 L .83196 .26236 L p F P
0 g
s
.987 .892 .569 r
.83196 .26236 m .83117 .25786 L .83334 .25145 L p F P
0 g
s
0 0 .3 r
.82692 .20022 m .82873 .20528 L .82997 .20973 L p F P
0 g
s
.707 .43 0 r
.82873 .20528 m .82997 .20973 L .83129 .21495 L p F P
0 g
s
.004 .314 .804 r
.78278 .13066 m .78661 .13328 L .78366 .12843 L p F P
0 g
s
.004 .314 .804 r
.78366 .12843 m .78061 .12634 L .78278 .13066 L p F P
0 g
s
0 .294 .792 r
.79022 .1387 m .78956 .13822 L .78661 .13328 L p F P
0 g
s
.257 .49 .889 r
.7002 .26258 m .69897 .26212 L .69754 .25842 L closepath p F P
0 g
s
.242 .478 .885 r
.69897 .26212 m .69754 .25842 L .69712 .25775 L p F P
0 g
s
0 .112 .642 r
.62702 .19194 m .62923 .19397 L .62607 .1899 L p F P
0 g
s
0 .112 .642 r
.62607 .1899 m .62394 .18794 L .62702 .19194 L p F P
0 g
s
.584 .701 .923 r
.75997 .2972 m .75796 .29431 L .76009 .29395 L closepath p F P
0 g
s
.065 .374 .84 r
.7653 .11288 m .76411 .1108 L p .77256 .1185 L F P
0 g
s
.117 .414 .861 r
.7653 .11288 m .76386 .11067 L .76411 .1108 L closepath p F P
0 g
s
.656 .776 .937 r
.77689 .30008 m .78985 .29576 L .79271 .2993 L p F P
0 g
s
.646 .767 .937 r
.78985 .29576 m .77689 .30008 L .77398 .29616 L p F P
0 g
s
.253 .484 .886 r
.67856 .24434 m .67809 .24309 L p .68774 .25044 L F P
0 g
s
.246 .478 .883 r
.67856 .24434 m .67766 .24292 L .67809 .24309 L closepath p F P
0 g
s
.72 .812 .922 r
.80043 .29531 m .79271 .2993 L .78985 .29576 L p F P
0 g
s
.08 .388 .848 r
.6589 .22346 m .65504 .22134 L .6519 .21672 L p F P
0 g
s
.088 .383 .844 r
.66959 .23537 m .67455 .2381 L .67143 .23338 L p F P
0 g
s
.088 .383 .844 r
.67143 .23338 m .66747 .23116 L .66959 .23537 L p F P
0 g
s
0 0 .279 r
.82558 .19579 m .82692 .20022 L .82873 .20528 L p F P
0 g
s
0 0 .403 r
.82331 .1909 m .82558 .19579 L .82692 .20022 L p F P
0 g
s
0 .242 .757 r
.79022 .1387 m .79499 .14264 L .79696 .14699 L p F P
0 g
s
0 .238 .755 r
.78813 .13438 m .79022 .1387 L .79499 .14264 L p F P
0 g
s
0 .294 .792 r
.78661 .13328 m .78813 .13438 L .79022 .1387 L p F P
0 g
s
.874 .653 .126 r
.83323 .22482 m .83359 .22636 L .83367 .23134 L p F P
0 g
s
.846 .64 .098 r
.83435 .23495 m .83367 .23134 L .83359 .22636 L p F P
0 g
s
.128 .433 .872 r
.75482 .1034 m .76091 .10624 L .75795 .10188 L p F P
0 g
s
.128 .433 .872 r
.75795 .10188 m .75217 .09918 L .75482 .1034 L p F P
0 g
s
0 .264 .769 r
.64268 .20777 m .63995 .2037 L .63471 .1999 L p F P
0 g
s
0 .253 .759 r
.63183 .19585 m .63471 .1999 L .63995 .2037 L p F P
0 g
s
0 .258 .763 r
.62923 .19397 m .63183 .19585 L .63471 .1999 L p F P
0 g
s
.935 .762 .289 r
.83367 .23134 m .83435 .23495 L .83385 .24081 L p F P
0 g
s
.366 .552 .903 r
.7002 .26258 m .70868 .26465 L .71009 .26901 L p F P
0 g
s
.35 .546 .905 r
.70868 .26465 m .7002 .26258 L .69754 .25842 L p F P
0 g
s
.96 .931 .718 r
.82856 .26917 m .82816 .26563 L .83015 .26634 L closepath p F P
0 g
s
0 0 .383 r
.82185 .18648 m .82331 .1909 L .82558 .19579 L p F P
0 g
s
0 0 .493 r
.81915 .18175 m .82185 .18648 L .82331 .1909 L p F P
0 g
s
0 0 .493 r
.81927 .18209 m .81915 .18175 L p .82331 .1909 L F P
0 g
s
0 0 .574 r
.81927 .18209 m .81903 .18157 L .81915 .18175 L closepath p F P
0 g
s
0 .199 .728 r
.80325 .15543 m .80141 .15106 L .79696 .14699 L p F P
0 g
s
0 .196 .726 r
.79499 .14264 m .79696 .14699 L .80141 .15106 L p F P
0 g
s
.237 .479 .886 r
.67809 .24309 m .67766 .24292 L .67455 .2381 L p F P
0 g
s
0 0 .567 r
.81915 .18175 m .81903 .18157 L .81599 .17502 L p F P
0 g
s
0 .151 .694 r
.80906 .16403 m .80735 .15963 L .80325 .15543 L p F P
0 g
s
0 .147 .691 r
.80141 .15106 m .80325 .15543 L .80735 .15963 L p F P
0 g
s
0 0 .471 r
.81759 .17734 m .81915 .18175 L .82185 .18648 L p F P
0 g
s
0 0 .567 r
.81599 .17502 m .81759 .17734 L .81915 .18175 L p F P
0 g
s
.253 .484 .886 r
.67809 .24309 m .68593 .24616 L .68774 .25044 L p F P
0 g
s
.209 .468 .885 r
.67628 .23879 m .67809 .24309 L .68593 .24616 L p F P
0 g
s
.237 .479 .886 r
.67455 .2381 m .67628 .23879 L .67809 .24309 L p F P
0 g
s
0 .095 .653 r
.81437 .1728 m .8128 .16838 L .80906 .16403 L p F P
0 g
s
0 .105 .66 r
.80735 .15963 m .80906 .16403 L .8128 .16838 L p F P
0 g
s
0 0 .577 r
.81437 .1728 m .81599 .17502 L .81295 .16859 L p F P
0 g
s
0 0 .577 r
.81295 .16859 m .8128 .16838 L .81437 .1728 L p F P
0 g
s
0 .261 .769 r
.65049 .21571 m .64789 .21161 L .64268 .20777 L p F P
0 g
s
0 .249 .758 r
.63995 .2037 m .64268 .20777 L .64789 .21161 L p F P
0 g
s
.924 .919 .791 r
.82816 .26563 m .82856 .26917 L .82328 .27658 L p F P
0 g
s
.108 .413 .861 r
.76411 .1108 m .76386 .11067 L .76091 .10624 L p F P
0 g
s
.336 .539 .904 r
.71009 .26901 m .71651 .27059 L .71345 .2659 L p F P
0 g
s
.336 .539 .904 r
.71345 .2659 m .70868 .26465 L .71009 .26901 L p F P
0 g
s
.989 .892 .58 r
.83254 .24694 m .83334 .25145 L .83117 .25786 L p F P
0 g
s
.975 .842 .441 r
.83334 .25145 m .83254 .24694 L .83385 .24081 L p F P
0 g
s
.72 .812 .922 r
.78985 .29576 m .80018 .29069 L .80043 .29531 L p F P
0 g
s
.744 .834 .92 r
.80271 .28937 m .80018 .29069 L .80043 .29531 L p F P
0 g
s
.744 .834 .92 r
.80043 .29531 m .80551 .29249 L .80271 .28937 L p F P
0 g
s
.065 .374 .84 r
.76411 .1108 m .77014 .11423 L .77256 .1185 L p F P
0 g
s
.054 .373 .84 r
.76156 .10656 m .76411 .1108 L .77014 .11423 L p F P
0 g
s
.108 .413 .861 r
.76091 .10624 m .76156 .10656 L .76411 .1108 L p F P
0 g
s
.874 .653 .126 r
.83367 .23134 m .83346 .23044 L .83323 .22482 L p F P
0 g
s
.89 .662 .145 r
.83209 .22037 m .83323 .22482 L .83346 .23044 L p F P
0 g
s
.798 .545 0 r
.83323 .22482 m .83209 .22037 L .83129 .21495 L p F P
0 g
s
0 .246 .752 r
.63183 .19585 m .62923 .19397 L .62607 .1899 L p F P
0 g
s
.584 .7 .923 r
.76009 .29395 m .75796 .29431 L .75499 .29003 L p F P
0 g
s
.177 .478 .895 r
.74238 .09195 m .74135 .09155 L .73838 .08737 L p F P
0 g
s
0 .268 .773 r
.65049 .21571 m .6519 .21672 L .64876 .21224 L p F P
0 g
s
0 .268 .773 r
.64876 .21224 m .64789 .21161 L .65049 .21571 L p F P
0 g
s
.438 .613 .923 r
.73883 .28595 m .7378 .28585 L .73703 .28324 L closepath p F P
0 g
s
.455 .609 .913 r
.73582 .28142 m .73703 .28324 L .7378 .28585 L p F P
0 g
s
.438 .602 .915 r
.7222 .2756 m .71956 .27531 L .71651 .27059 L p F P
0 g
s
.217 .466 .881 r
.68774 .25044 m .69403 .25296 L .69093 .24823 L p F P
0 g
s
.217 .466 .881 r
.69093 .24823 m .68593 .24616 L .68774 .25044 L p F P
0 g
s
.802 .867 .896 r
.81552 .28479 m .80551 .29249 L .80271 .28937 L p F P
0 g
s
.042 .35 .826 r
.78061 .12634 m .77832 .12205 L .77256 .1185 L p F P
0 g
s
.032 .349 .826 r
.77014 .11423 m .77256 .1185 L .77832 .12205 L p F P
0 g
s
.884 .903 .837 r
.82328 .27658 m .81809 .28253 L .81536 .28003 L p F P
0 g
s
.884 .903 .837 r
.81536 .28003 m .82261 .27207 L .82328 .27658 L p F P
0 g
s
.924 .919 .791 r
.82757 .2653 m .82816 .26563 L p .82328 .27658 L F P
0 g
s
.924 .919 .791 r
.82328 .27658 m .82261 .27207 L .82757 .2653 L p F P
0 g
s
.502 .659 .931 r
.73883 .28595 m .75201 .28573 L .75499 .29003 L p F P
0 g
s
.509 .651 .922 r
.74902 .28142 m .75201 .28573 L .73883 .28595 L p F P
0 g
s
.509 .651 .922 r
.73677 .28141 m .74902 .28142 L p .73883 .28595 L F P
0 g
s
.509 .651 .922 r
.73883 .28595 m .73703 .28324 L .73677 .28141 L p F P
0 g
s
.814 .555 0 r
.83006 .21051 m .83129 .21495 L .83209 .22037 L p F P
0 g
s
.707 .43 0 r
.83129 .21495 m .83006 .21051 L .82873 .20528 L p F P
0 g
s
.145 .45 .881 r
.75217 .09918 m .74939 .09499 L .74238 .09195 L p F P
0 g
s
.135 .45 .882 r
.73947 .08779 m .74238 .09195 L .74939 .09499 L p F P
0 g
s
.177 .478 .895 r
.73838 .08737 m .73947 .08779 L .74238 .09195 L p F P
0 g
s
0 .289 .789 r
.78813 .13438 m .78661 .13328 L .78366 .12843 L p F P
0 g
s
.57 .696 .926 r
.76009 .29395 m .77105 .29218 L .76812 .28816 L p F P
0 g
s
.57 .696 .926 r
.76812 .28816 m .75973 .28934 L .76009 .29395 L p F P
0 g
s
.584 .7 .923 r
.75499 .29003 m .75973 .28934 L .76009 .29395 L p F P
0 g
s
.071 .38 .843 r
.66747 .23116 m .66519 .22698 L .6589 .22346 L p F P
0 g
s
.045 .369 .838 r
.65653 .21929 m .6589 .22346 L .66519 .22698 L p F P
0 g
s
.08 .388 .848 r
.6519 .21672 m .65653 .21929 L .6589 .22346 L p F P
0 g
s
0 0 .553 r
.81759 .17734 m .81599 .17502 L .81295 .16859 L p F P
0 g
s
.802 .867 .896 r
.80271 .28937 m .81518 .28018 L .81552 .28479 L p F P
0 g
s
.841 .892 .876 r
.81536 .28003 m .81518 .28018 L .81552 .28479 L p F P
0 g
s
.841 .892 .876 r
.81552 .28479 m .81809 .28253 L .81536 .28003 L p F P
0 g
s
.35 .546 .905 r
.69754 .25842 m .69736 .25781 L p .70868 .26465 L F P
0 g
s
.346 .542 .903 r
.69754 .25842 m .69712 .25775 L .69736 .25781 L closepath p F P
0 g
s
.98 .844 .453 r
.83299 .23629 m .83385 .24081 L .83254 .24694 L p F P
0 g
s
.935 .762 .289 r
.8333 .23287 m .83367 .23134 L p .83385 .24081 L F P
0 g
s
.935 .762 .289 r
.83385 .24081 m .83299 .23629 L .8333 .23287 L p F P
0 g
s
.055 .38 .844 r
.65653 .21929 m .6519 .21672 L .64876 .21224 L p F P
0 g
s
0 .309 .802 r
.78061 .12634 m .78366 .12843 L .78072 .12369 L p F P
0 g
s
0 .309 .802 r
.78072 .12369 m .77832 .12205 L .78061 .12634 L p F P
0 g
s
.646 .767 .937 r
.77398 .29616 m .78698 .29213 L .78985 .29576 L p F P
0 g
s
.636 .759 .937 r
.78698 .29213 m .77398 .29616 L .77105 .29218 L p F P
0 g
s
.417 .591 .915 r
.7222 .2756 m .73279 .27689 L .72976 .27237 L p F P
0 g
s
.417 .591 .915 r
.72976 .27237 m .72108 .27116 L .7222 .2756 L p F P
0 g
s
.438 .602 .915 r
.71651 .27059 m .72108 .27116 L .7222 .2756 L p F P
0 g
s
0 0 .279 r
.82873 .20528 m .82739 .20084 L .82558 .19579 L p F P
0 g
s
.726 .441 0 r
.82739 .20084 m .82873 .20528 L .83006 .21051 L p F P
0 g
s
.341 .543 .905 r
.69736 .25781 m .69712 .25775 L .69403 .25296 L p F P
0 g
s
.979 .904 .666 r
.83117 .25786 m .82797 .26462 L .82816 .26563 L p F P
0 g
s
.974 .909 .683 r
.83031 .25338 m .83117 .25786 L .82797 .26462 L p F P
0 g
s
.989 .892 .58 r
.83117 .25786 m .83031 .25338 L .83254 .24694 L p F P
0 g
s
.711 .814 .929 r
.80018 .29069 m .78985 .29576 L .78698 .29213 L p F P
0 g
s
.35 .546 .905 r
.69736 .25781 m .70707 .26034 L .70868 .26465 L p F P
0 g
s
.31 .535 .908 r
.69587 .25345 m .69736 .25781 L .70707 .26034 L p F P
0 g
s
.341 .543 .905 r
.69403 .25296 m .69587 .25345 L .69736 .25781 L p F P
0 g
s
.942 .75 .28 r
.8333 .23287 m .83346 .23044 L .83367 .23134 L closepath p F P
0 g
s
.217 .472 .886 r
.67628 .23879 m .67455 .2381 L .67143 .23338 L p F P
0 g
s
.063 .374 .84 r
.66747 .23116 m .67143 .23338 L .66831 .22876 L p F P
0 g
s
.063 .374 .84 r
.66831 .22876 m .66519 .22698 L .66747 .23116 L p F P
0 g
s
0 .238 .755 r
.79499 .14264 m .79291 .13831 L .78813 .13438 L p F P
0 g
s
0 .235 .753 r
.78592 .13008 m .78813 .13438 L .79291 .13831 L p F P
0 g
s
0 .289 .789 r
.78366 .12843 m .78592 .13008 L .78813 .13438 L p F P
0 g
s
.118 .432 .872 r
.75217 .09918 m .75795 .10188 L .755 .0976 L p F P
0 g
s
.118 .432 .872 r
.755 .0976 m .74939 .09499 L .75217 .09918 L p F P
0 g
s
0 .253 .759 r
.63995 .2037 m .63705 .19966 L .63183 .19585 L p F P
0 g
s
0 .243 .749 r
.62876 .19186 m .63183 .19585 L .63705 .19966 L p F P
0 g
s
0 .246 .752 r
.62607 .1899 m .62876 .19186 L .63183 .19585 L p F P
0 g
s
0 0 .265 r
.82413 .19136 m .82558 .19579 L .82739 .20084 L p F P
0 g
s
0 0 .383 r
.82558 .19579 m .82413 .19136 L .82185 .18648 L p F P
0 g
s
0 .196 .726 r
.80141 .15106 m .79946 .1467 L .79499 .14264 L p F P
0 g
s
0 .192 .723 r
.79291 .13831 m .79499 .14264 L .79946 .1467 L p F P
0 g
s
.504 .647 .921 r
.73703 .28324 m .73582 .28142 L .73677 .28141 L closepath p F P
0 g
s
.955 .916 .734 r
.82757 .2653 m .82797 .26462 L .82816 .26563 L closepath p F P
0 g
s
0 0 .372 r
.8203 .18207 m .82185 .18648 L .82413 .19136 L p F P
0 g
s
0 0 .471 r
.82185 .18648 m .8203 .18207 L .81759 .17734 L p F P
0 g
s
.89 .662 .145 r
.83346 .23044 m .83231 .22599 L .83209 .22037 L p F P
0 g
s
.96 .757 .309 r
.83346 .23044 m .83231 .22599 L p .83268 .23486 L F P
0 g
s
.96 .757 .309 r
.83268 .23486 m .8333 .23287 L .83346 .23044 L p F P
0 g
s
.097 .411 .861 r
.76156 .10656 m .76091 .10624 L .75795 .10188 L p F P
0 g
s
0 .147 .691 r
.80735 .15963 m .80553 .15526 L .80141 .15106 L p F P
0 g
s
0 .143 .688 r
.79946 .1467 m .80141 .15106 L .80553 .15526 L p F P
0 g
s
0 0 .461 r
.81592 .17295 m .81759 .17734 L .8203 .18207 L p F P
0 g
s
0 0 .553 r
.81295 .16859 m .81592 .17295 L .81759 .17734 L p F P
0 g
s
0 .249 .758 r
.64789 .21161 m .64512 .20754 L .63995 .2037 L p F P
0 g
s
0 .238 .748 r
.63705 .19966 m .63995 .2037 L .64512 .20754 L p F P
0 g
s
.209 .468 .885 r
.68593 .24616 m .68393 .24192 L .67628 .23879 L p F P
0 g
s
.186 .46 .883 r
.67427 .23454 m .67628 .23879 L .68393 .24192 L p F P
0 g
s
.217 .472 .886 r
.67143 .23338 m .67427 .23454 L .67628 .23879 L p F P
0 g
s
0 .105 .66 r
.80994 .16267 m .80735 .15963 L p .8128 .16838 L F P
0 g
s
0 .07 .632 r
.80735 .15963 m .80994 .16267 L .80695 .15693 L p F P
0 g
s
0 .07 .632 r
.80695 .15693 m .80553 .15526 L .80735 .15963 L p F P
0 g
s
0 0 .567 r
.81295 .16859 m .8128 .16838 L .8126 .16788 L closepath p F P
0 g
s
0 .105 .66 r
.8128 .16838 m .8126 .16788 L .80994 .16267 L p F P
0 g
s
.425 .597 .916 r
.72108 .27116 m .71651 .27059 L .71345 .2659 L p F P
0 g
s
0 0 .537 r
.81592 .17295 m .81295 .16859 L .8126 .16788 L p F P
0 g
s
.573 .695 .924 r
.75973 .28934 m .75499 .29003 L .75201 .28573 L p F P
0 g
s
.054 .373 .84 r
.77014 .11423 m .7676 .10999 L .76156 .10656 L p F P
0 g
s
.043 .371 .839 r
.75889 .10235 m .76156 .10656 L .7676 .10999 L p F P
0 g
s
.097 .411 .861 r
.75795 .10188 m .75889 .10235 L .76156 .10656 L p F P
0 g
s
.319 .534 .905 r
.70868 .26465 m .71345 .2659 L .71039 .26126 L p F P
0 g
s
.319 .534 .905 r
.71039 .26126 m .70707 .26034 L .70868 .26465 L p F P
0 g
s
0 0 .537 r
.8126 .16788 m .81102 .16401 L p .81592 .17295 L F P
0 g
s
0 .048 .615 r
.8126 .16788 m .80994 .16267 L .81102 .16401 L closepath p F P
0 g
s
.949 .911 .746 r
.82797 .26462 m .82757 .2653 L .82493 .26361 L p F P
0 g
s
.949 .911 .746 r
.82493 .26361 m .82703 .26016 L .82797 .26462 L p F P
0 g
s
.974 .909 .683 r
.82797 .26462 m .82703 .26016 L .83031 .25338 L p F P
0 g
s
.99 .891 .59 r
.83165 .24243 m .83254 .24694 L .83031 .25338 L p F P
0 g
s
.98 .844 .453 r
.83254 .24694 m .83165 .24243 L .83299 .23629 L p F P
0 g
s
.925 .925 .791 r
.82261 .27207 m .82757 .2653 L .82493 .26361 L p F P
0 g
s
0 .257 .764 r
.64789 .21161 m .64876 .21224 L .64562 .2079 L p F P
0 g
s
0 .257 .764 r
.64562 .2079 m .64512 .20754 L .64789 .21161 L p F P
0 g
s
.945 .767 .303 r
.83299 .23629 m .83268 .23486 L .8333 .23287 L closepath p F P
0 g
s
.903 .669 .161 r
.83085 .21593 m .83209 .22037 L .83231 .22599 L p F P
0 g
s
.814 .555 0 r
.83209 .22037 m .83085 .21593 L .83006 .21051 L p F P
0 g
s
.711 .814 .929 r
.80018 .28646 m .80018 .29069 L p .78698 .29213 L F P
0 g
s
.732 .824 .921 r
.80018 .29069 m .80018 .28646 L .80271 .28937 L closepath p F P
0 g
s
.503 .647 .922 r
.73677 .28141 m .73582 .28142 L .73279 .27689 L p F P
0 g
s
0 .284 .785 r
.78592 .13008 m .78366 .12843 L .78072 .12369 L p F P
0 g
s
.032 .349 .826 r
.77832 .12205 m .77592 .11778 L .77014 .11423 L p F P
0 g
s
.02 .347 .825 r
.7676 .10999 m .77014 .11423 L .77592 .11778 L p F P
0 g
s
.487 .639 .922 r
.73677 .28141 m .74902 .28142 L .74602 .2771 L p F P
0 g
s
.487 .639 .922 r
.74602 .2771 m .73589 .27691 L .73677 .28141 L p F P
0 g
s
.503 .647 .922 r
.73279 .27689 m .73589 .27691 L .73677 .28141 L p F P
0 g
s
.135 .45 .882 r
.74939 .09499 m .74648 .09082 L .73947 .08779 L p F P
0 g
s
.796 .839 .884 r
.80018 .28646 m .80271 .28937 L .81518 .28018 L p F P
0 g
s
.197 .459 .881 r
.68593 .24616 m .69093 .24823 L .68784 .24359 L p F P
0 g
s
.197 .459 .881 r
.68784 .24359 m .68393 .24192 L .68593 .24616 L p F P
0 g
s
.055 .38 .844 r
.64876 .21224 m .65398 .21517 L .65653 .21929 L p F P
0 g
s
.031 .372 .84 r
.65398 .21517 m .64876 .21224 L .64562 .2079 L p F P
0 g
s
.325 .539 .907 r
.69587 .25345 m .69403 .25296 L .69093 .24823 L p F P
0 g
s
.83 .564 .014 r
.82873 .20607 m .83006 .21051 L .83085 .21593 L p F P
0 g
s
.726 .441 0 r
.83006 .21051 m .82873 .20607 L .82739 .20084 L p F P
0 g
s
.045 .369 .838 r
.66519 .22698 m .66274 .22284 L .65653 .21929 L p F P
0 g
s
.02 .36 .833 r
.65398 .21517 m .65653 .21929 L .66274 .22284 L p F P
0 g
s
.878 .881 .832 r
.82261 .27207 m .82189 .26755 L p .81515 .27983 L F P
0 g
s
.878 .881 .832 r
.81515 .27983 m .81536 .28003 L .82261 .27207 L p F P
0 g
s
.925 .925 .791 r
.82493 .26361 m .82189 .26755 L .82261 .27207 L p F P
0 g
s
.636 .759 .937 r
.77105 .29218 m .78409 .28843 L .78698 .29213 L p F P
0 g
s
.626 .752 .937 r
.78409 .28843 m .77105 .29218 L .76812 .28816 L p F P
0 g
s
.197 .467 .886 r
.67427 .23454 m .67143 .23338 L .66831 .22876 L p F P
0 g
s
.559 .693 .93 r
.75973 .28934 m .76812 .28816 L .76517 .2841 L p F P
0 g
s
.559 .693 .93 r
.76517 .2841 m .75888 .28486 L .75973 .28934 L p F P
0 g
s
.573 .695 .924 r
.75201 .28573 m .75888 .28486 L .75973 .28934 L p F P
0 g
s
0 .305 .799 r
.77832 .12205 m .78072 .12369 L .77777 .11904 L p F P
0 g
s
0 .305 .799 r
.77777 .11904 m .77592 .11778 L .77832 .12205 L p F P
0 g
s
.986 .851 .477 r
.83268 .23486 m .83299 .23629 L .83165 .24243 L p F P
0 g
s
.711 .814 .929 r
.78698 .29213 m .79988 .28612 L .80018 .28646 L p F P
0 g
s
.7 .805 .93 r
.79988 .28612 m .78698 .29213 L .78409 .28843 L p F P
0 g
s
.829 .882 .881 r
.81518 .28018 m .81515 .27983 L .81536 .28003 L closepath p F P
0 g
s
.796 .839 .884 r
.81518 .28018 m .81515 .27983 L p .80018 .28646 L F P
0 g
s
0 0 .265 r
.82739 .20084 m .82596 .19642 L .82413 .19136 L p F P
0 g
s
.743 .45 0 r
.82596 .19642 m .82739 .20084 L .82873 .20607 L p F P
0 g
s
.402 .587 .917 r
.72108 .27116 m .72976 .27237 L .72673 .26787 L p F P
0 g
s
.402 .587 .917 r
.72673 .26787 m .71971 .26678 L .72108 .27116 L p F P
0 g
s
.425 .597 .916 r
.71345 .2659 m .71971 .26678 L .72108 .27116 L p F P
0 g
s
0 .243 .749 r
.63705 .19966 m .63398 .19566 L .62876 .19186 L p F P
0 g
s
.108 .431 .872 r
.74939 .09499 m .755 .0976 L .75204 .0934 L p F P
0 g
s
.108 .431 .872 r
.75204 .0934 m .74648 .09082 L .74939 .09499 L p F P
0 g
s
.31 .535 .908 r
.70707 .26034 m .70528 .25607 L .69587 .25345 L p F P
0 g
s
.291 .528 .908 r
.69416 .24913 m .69587 .25345 L .70528 .25607 L p F P
0 g
s
.325 .539 .907 r
.69093 .24823 m .69416 .24913 L .69587 .25345 L p F P
0 g
s
.847 .875 .861 r
.8126 .27726 m .81423 .27575 L .81515 .27983 L closepath p F P
0 g
s
.796 .839 .884 r
.81515 .27983 m .8126 .27726 L p .80018 .28646 L F P
0 g
s
.878 .881 .832 r
.82189 .26755 m .81423 .27575 L .81515 .27983 L p F P
0 g
s
.04 .366 .836 r
.66519 .22698 m .66831 .22876 L .66518 .22426 L p F P
0 g
s
.04 .366 .836 r
.66518 .22426 m .66274 .22284 L .66519 .22698 L p F P
0 g
s
0 .041 .608 r
.81102 .16401 m .80994 .16267 L .80695 .15693 L p F P
0 g
s
.972 .906 .691 r
.82938 .24889 m .83031 .25338 L .82703 .26016 L p F P
0 g
s
.99 .891 .59 r
.83031 .25338 m .82938 .24889 L .83165 .24243 L p F P
0 g
s
0 .235 .753 r
.79291 .13831 m .79072 .134 L .78592 .13008 L p F P
0 g
s
0 .231 .75 r
.7836 .12579 m .78592 .13008 L .79072 .134 L p F P
0 g
s
0 .284 .785 r
.78072 .12369 m .7836 .12579 L .78592 .13008 L p F P
0 g
s
0 0 .252 r
.82259 .18696 m .82413 .19136 L .82596 .19642 L p F P
0 g
s
0 0 .372 r
.82413 .19136 m .82259 .18696 L .8203 .18207 L p F P
0 g
s
.086 .409 .861 r
.75889 .10235 m .75795 .10188 L .755 .0976 L p F P
0 g
s
0 .192 .723 r
.79946 .1467 m .79739 .14237 L .79291 .13831 L p F P
0 g
s
0 .188 .72 r
.79072 .134 m .79291 .13831 L .79739 .14237 L p F P
0 g
s
.411 .593 .918 r
.71971 .26678 m .71345 .2659 L .71039 .26126 L p F P
0 g
s
0 0 .36 r
.81864 .17768 m .8203 .18207 L .82259 .18696 L p F P
0 g
s
0 0 .461 r
.8203 .18207 m .81864 .17768 L .81592 .17295 L p F P
0 g
s
0 .238 .748 r
.64512 .20754 m .6422 .20351 L .63705 .19966 L p F P
0 g
s
0 .229 .738 r
.63398 .19566 m .63705 .19966 L .6422 .20351 L p F P
0 g
s
.563 .69 .926 r
.75888 .28486 m .75201 .28573 L .74902 .28142 L p F P
0 g
s
.987 .827 .442 r
.8311 .23616 m .83189 .23183 L .83268 .23486 L closepath p F P
0 g
s
.96 .757 .309 r
.83231 .22599 m .83189 .23183 L .83268 .23486 L p F P
0 g
s
.986 .851 .477 r
.8311 .23616 m .83268 .23486 L p .83165 .24243 L F P
0 g
s
0 .143 .688 r
.80553 .15526 m .8036 .1509 L .79946 .1467 L p F P
0 g
s
0 .159 .699 r
.79739 .14237 m .79946 .1467 L .8036 .1509 L p F P
0 g
s
.963 .763 .32 r
.83107 .22155 m .83231 .22599 L .83189 .23183 L p F P
0 g
s
.903 .669 .161 r
.83231 .22599 m .83107 .22155 L .83085 .21593 L p F P
0 g
s
0 0 .451 r
.81415 .16858 m .81592 .17295 L .81864 .17768 L p F P
0 g
s
0 0 .537 r
.81102 .16401 m .81415 .16858 L .81592 .17295 L p F P
0 g
s
0 .057 .621 r
.80553 .15526 m .80695 .15693 L .80396 .15133 L p F P
0 g
s
0 .057 .621 r
.80396 .15133 m .8036 .1509 L .80553 .15526 L p F P
0 g
s
.186 .46 .883 r
.68393 .24192 m .68177 .23772 L .67427 .23454 L p F P
0 g
s
.164 .452 .881 r
.67206 .23034 m .67427 .23454 L .68177 .23772 L p F P
0 g
s
.197 .467 .886 r
.66831 .22876 m .67206 .23034 L .67427 .23454 L p F P
0 g
s
.043 .371 .839 r
.7676 .10999 m .76494 .10577 L .75889 .10235 L p F P
0 g
s
.032 .37 .838 r
.75611 .09816 m .75889 .10235 L .76494 .10577 L p F P
0 g
s
.086 .409 .861 r
.755 .0976 m .75611 .09816 L .75889 .10235 L p F P
0 g
s
0 0 .526 r
.80913 .15965 m .81102 .16401 L .81415 .16858 L p F P
0 g
s
0 .041 .608 r
.80695 .15693 m .80913 .15965 L .81102 .16401 L p F P
0 g
s
.492 .643 .923 r
.73589 .27691 m .73279 .27689 L .72976 .27237 L p F P
0 g
s
0 .278 .782 r
.7836 .12579 m .78072 .12369 L .77777 .11904 L p F P
0 g
s
0 .248 .755 r
.64512 .20754 m .64562 .2079 L .64247 .20371 L p F P
0 g
s
0 .248 .755 r
.64247 .20371 m .6422 .20351 L .64512 .20754 L p F P
0 g
s
.302 .529 .906 r
.70707 .26034 m .71039 .26126 L .70732 .25666 L p F P
0 g
s
.302 .529 .906 r
.70732 .25666 m .70528 .25607 L .70707 .26034 L p F P
0 g
s
.942 .907 .757 r
.82703 .26016 m .82493 .26361 L .82225 .26164 L p F P
0 g
s
.942 .907 .757 r
.82225 .26164 m .82601 .25572 L .82703 .26016 L p F P
0 g
s
.972 .906 .691 r
.82703 .26016 m .82601 .25572 L .82938 .24889 L p F P
0 g
s
.31 .534 .908 r
.69416 .24913 m .69093 .24823 L .68784 .24359 L p F P
0 g
s
.99 .89 .599 r
.83069 .23794 m .83165 .24243 L .82938 .24889 L p F P
0 g
s
.986 .851 .477 r
.83165 .24243 m .83069 .23794 L .8311 .23616 L p F P
0 g
s
.767 .83 .901 r
.79988 .28612 m .80006 .28601 L .80018 .28646 L closepath p F P
0 g
s
.796 .839 .884 r
.8126 .27726 m .80006 .28601 L .80018 .28646 L p F P
0 g
s
.914 .676 .177 r
.82952 .21149 m .83085 .21593 L .83107 .22155 L p F P
0 g
s
.83 .564 .014 r
.83085 .21593 m .82952 .21149 L .82873 .20607 L p F P
0 g
s
.031 .372 .84 r
.64562 .2079 m .65126 .21109 L .65398 .21517 L p F P
0 g
s
.007 .365 .835 r
.65126 .21109 m .64562 .2079 L .64247 .20371 L p F P
0 g
s
.02 .347 .825 r
.77592 .11778 m .7734 .11353 L .7676 .10999 L p F P
0 g
s
.008 .345 .824 r
.76494 .10577 m .7676 .10999 L .7734 .11353 L p F P
0 g
s
.178 .461 .885 r
.67206 .23034 m .66831 .22876 L .66518 .22426 L p F P
0 g
s
.759 .823 .903 r
.80006 .28601 m .79988 .28612 L .79704 .28274 L p F P
0 g
s
.7 .805 .93 r
.78409 .28843 m .79704 .28274 L .79988 .28612 L p F P
0 g
s
.759 .823 .903 r
.79704 .28274 m .7988 .28167 L .80006 .28601 L p F P
0 g
s
.79 .86 .902 r
.80981 .27434 m .7988 .28167 L .80006 .28601 L p F P
0 g
s
.79 .86 .902 r
.80006 .28601 m .8126 .27726 L .80981 .27434 L p F P
0 g
s
.177 .453 .88 r
.68393 .24192 m .68784 .24359 L .68473 .23902 L p F P
0 g
s
.177 .453 .88 r
.68473 .23902 m .68177 .23772 L .68393 .24192 L p F P
0 g
s
.617 .745 .938 r
.78119 .28467 m .76812 .28816 L .76517 .2841 L p F P
0 g
s
.626 .752 .937 r
.76812 .28816 m .78119 .28467 L .78409 .28843 L p F P
0 g
s
.915 .915 .802 r
.82189 .26755 m .82493 .26361 L .82225 .26164 L p F P
0 g
s
0 .027 .596 r
.80913 .15965 m .80695 .15693 L .80396 .15133 L p F P
0 g
s
.492 .643 .923 r
.72976 .27237 m .73472 .27249 L .73589 .27691 L p F P
0 g
s
.474 .636 .925 r
.73589 .27691 m .74602 .2771 L .74302 .27277 L p F P
0 g
s
.474 .636 .925 r
.74302 .27277 m .73472 .27249 L .73589 .27691 L p F P
0 g
s
.02 .36 .833 r
.66274 .22284 m .66012 .21874 L .65398 .21517 L p F P
0 g
s
0 .352 .827 r
.65126 .21109 m .65398 .21517 L .66012 .21874 L p F P
0 g
s
.844 .572 .03 r
.8273 .20165 m .82873 .20607 L .82952 .21149 L p F P
0 g
s
.743 .45 0 r
.82873 .20607 m .8273 .20165 L .82596 .19642 L p F P
0 g
s
0 .301 .796 r
.77592 .11778 m .77777 .11904 L .77482 .1145 L p F P
0 g
s
0 .301 .796 r
.77482 .1145 m .7734 .11353 L .77592 .11778 L p F P
0 g
s
.69 .797 .931 r
.79704 .28274 m .78409 .28843 L .78119 .28467 L p F P
0 g
s
.87 .883 .843 r
.82113 .26303 m .82189 .26755 L .81423 .27575 L p F P
0 g
s
.915 .915 .802 r
.82225 .26164 m .82113 .26303 L .82189 .26755 L p F P
0 g
s
.548 .689 .933 r
.75888 .28486 m .76517 .2841 L .76221 .28 L p F P
0 g
s
.548 .689 .933 r
.76221 .28 m .75768 .28047 L .75888 .28486 L p F P
0 g
s
.563 .69 .926 r
.74902 .28142 m .75768 .28047 L .75888 .28486 L p F P
0 g
s
.994 .825 .461 r
.83189 .23183 m .83063 .2274 L p .83036 .23654 L F P
0 g
s
.994 .825 .461 r
.83036 .23654 m .8311 .23616 L .83189 .23183 L p F P
0 g
s
.963 .763 .32 r
.83189 .23183 m .83063 .2274 L .83107 .22155 L p F P
0 g
s
0 0 .252 r
.82596 .19642 m .82442 .19201 L .82259 .18696 L p F P
0 g
s
.76 .459 0 r
.82442 .19201 m .82596 .19642 L .8273 .20165 L p F P
0 g
s
.411 .593 .918 r
.71039 .26126 m .71814 .26246 L .71971 .26678 L p F P
0 g
s
.398 .589 .92 r
.71814 .26246 m .71039 .26126 L .70732 .25666 L p F P
0 g
s
.017 .358 .831 r
.66274 .22284 m .66518 .22426 L .66205 .21987 L p F P
0 g
s
.017 .358 .831 r
.66205 .21987 m .66012 .21874 L .66274 .22284 L p F P
0 g
s
0 .231 .75 r
.79072 .134 m .78841 .12971 L .7836 .12579 L p F P
0 g
s
0 .227 .747 r
.78117 .12153 m .7836 .12579 L .78841 .12971 L p F P
0 g
s
0 .278 .782 r
.77777 .11904 m .78117 .12153 L .7836 .12579 L p F P
0 g
s
.87 .883 .843 r
.81423 .27575 m .81317 .27133 L .82113 .26303 L p F P
0 g
s
.839 .869 .866 r
.81423 .27575 m .8126 .27726 L .80981 .27434 L p F P
0 g
s
.839 .869 .866 r
.80981 .27434 m .81317 .27133 L .81423 .27575 L p F P
0 g
s
.387 .583 .919 r
.71971 .26678 m .72673 .26787 L .72368 .2634 L p F P
0 g
s
.387 .583 .919 r
.72368 .2634 m .71814 .26246 L .71971 .26678 L p F P
0 g
s
.291 .528 .908 r
.70528 .25607 m .70332 .25183 L .69416 .24913 L p F P
0 g
s
.262 .514 .905 r
.69225 .24486 m .69416 .24913 L .70332 .25183 L p F P
0 g
s
.31 .534 .908 r
.68784 .24359 m .69225 .24486 L .69416 .24913 L p F P
0 g
s
.075 .408 .86 r
.75611 .09816 m .755 .0976 L .75204 .0934 L p F P
0 g
s
.553 .686 .927 r
.75768 .28047 m .74902 .28142 L .74602 .2771 L p F P
0 g
s
.969 .903 .697 r
.82836 .24442 m .82938 .24889 L .82601 .25572 L p F P
0 g
s
.99 .89 .599 r
.82938 .24889 m .82836 .24442 L .83069 .23794 L p F P
0 g
s
0 0 .36 r
.82259 .18696 m .82094 .18256 L .81864 .17768 L p F P
0 g
s
.67 .348 0 r
.82094 .18256 m .82259 .18696 L .82442 .19201 L p F P
0 g
s
0 .188 .72 r
.79739 .14237 m .79521 .13806 L .79072 .134 L p F P
0 g
s
0 .184 .716 r
.78841 .12971 m .79072 .134 L .79521 .13806 L p F P
0 g
s
0 .229 .738 r
.6422 .20351 m .63912 .19951 L .63398 .19566 L p F P
0 g
s
.481 .639 .925 r
.73472 .27249 m .72976 .27237 L .72673 .26787 L p F P
0 g
s
0 .273 .777 r
.78117 .12153 m .77777 .11904 L .77482 .1145 L p F P
0 g
s
0 0 .347 r
.81688 .1733 m .81864 .17768 L .82094 .18256 L p F P
0 g
s
0 0 .451 r
.81864 .17768 m .81688 .1733 L .81415 .16858 L p F P
0 g
s
0 .159 .699 r
.80099 .14601 m .79739 .14237 L p .8036 .1509 L F P
0 g
s
0 .125 .672 r
.79739 .14237 m .80099 .14601 L .79802 .14091 L p F P
0 g
s
0 .125 .672 r
.79802 .14091 m .79521 .13806 L .79739 .14237 L p F P
0 g
s
.032 .37 .838 r
.76494 .10577 m .76217 .10158 L .75611 .09816 L p F P
0 g
s
.02 .367 .837 r
.75321 .09399 m .75611 .09816 L .76217 .10158 L p F P
0 g
s
.075 .408 .86 r
.75204 .0934 m .75321 .09399 L .75611 .09816 L p F P
0 g
s
.97 .766 .334 r
.82973 .21713 m .83107 .22155 L .83063 .2274 L p F P
0 g
s
.914 .676 .177 r
.83107 .22155 m .82973 .21713 L .82952 .21149 L p F P
0 g
s
0 0 .44 r
.81227 .16422 m .81415 .16858 L .81688 .1733 L p F P
0 g
s
0 0 .526 r
.81415 .16858 m .81227 .16422 L .80913 .15965 L p F P
0 g
s
.164 .452 .881 r
.68177 .23772 m .67944 .23356 L .67206 .23034 L p F P
0 g
s
.144 .445 .879 r
.66968 .22618 m .67206 .23034 L .67944 .23356 L p F P
0 g
s
.178 .461 .885 r
.66518 .22426 m .66968 .22618 L .67206 .23034 L p F P
0 g
s
0 .048 .612 r
.80396 .15133 m .8036 .1509 L .80281 .14922 L closepath p F P
0 g
s
0 .159 .699 r
.8036 .1509 m .80281 .14922 L .80099 .14601 L p F P
0 g
s
0 0 .516 r
.80714 .15531 m .80913 .15965 L .81227 .16422 L p F P
0 g
s
0 .027 .596 r
.80396 .15133 m .80714 .15531 L .80913 .15965 L p F P
0 g
s
.294 .53 .909 r
.69225 .24486 m .68784 .24359 L .68473 .23902 L p F P
0 g
s
0 .239 .746 r
.6422 .20351 m .64247 .20371 L .63932 .19966 L p F P
0 g
s
0 .239 .746 r
.63932 .19966 m .63912 .19951 L .6422 .20351 L p F P
0 g
s
0 .013 .582 r
.80714 .15531 m .80396 .15133 L .80281 .14922 L p F P
0 g
s
.99 .85 .486 r
.83069 .23794 m .83036 .23654 L .8311 .23616 L closepath p F P
0 g
s
.007 .365 .835 r
.64247 .20371 m .64836 .20705 L .65126 .21109 L p F P
0 g
s
0 .358 .83 r
.64836 .20705 m .64247 .20371 L .63932 .19966 L p F P
0 g
s
.158 .456 .884 r
.66968 .22618 m .66518 .22426 L .66205 .21987 L p F P
0 g
s
.285 .524 .906 r
.70528 .25607 m .70732 .25666 L .70424 .25211 L p F P
0 g
s
.285 .524 .906 r
.70424 .25211 m .70332 .25183 L .70528 .25607 L p F P
0 g
s
.008 .345 .824 r
.7734 .11353 m .77075 .1093 L .76494 .10577 L p F P
0 g
s
0 .343 .822 r
.76217 .10158 m .76494 .10577 L .77075 .1093 L p F P
0 g
s
.938 .892 .758 r
.82601 .25572 m .82492 .25127 L p .82064 .26034 L F P
0 g
s
.938 .892 .758 r
.82064 .26034 m .82225 .26164 L .82601 .25572 L p F P
0 g
s
.969 .903 .697 r
.82601 .25572 m .82492 .25127 L .82836 .24442 L p F P
0 g
s
.617 .745 .938 r
.76517 .2841 m .77828 .28084 L .78119 .28467 L p F P
0 g
s
.609 .74 .938 r
.77828 .28084 m .76517 .2841 L .76221 .28 L p F P
0 g
s
.925 .681 .193 r
.82809 .20708 m .82952 .21149 L .82973 .21713 L p F P
0 g
s
.844 .572 .03 r
.82952 .21149 m .82809 .20708 L .8273 .20165 L p F P
0 g
s
.989 .89 .615 r
.83036 .23654 m .83069 .23794 L .82836 .24442 L p F P
0 g
s
.751 .819 .905 r
.7988 .28167 m .79704 .28274 L .79418 .27927 L p F P
0 g
s
.69 .797 .931 r
.78119 .28467 m .79418 .27927 L .79704 .28274 L p F P
0 g
s
.157 .447 .878 r
.68177 .23772 m .68473 .23902 L .68162 .23453 L p F P
0 g
s
.157 .447 .878 r
.68162 .23453 m .67944 .23356 L .68177 .23772 L p F P
0 g
s
0 .352 .827 r
.66012 .21874 m .65736 .21467 L .65126 .21109 L p F P
0 g
s
0 .345 .822 r
.64836 .20705 m .65126 .21109 L .65736 .21467 L p F P
0 g
s
0 .013 .582 r
.80281 .14922 m .80151 .14657 L p .80714 .15531 L F P
0 g
s
0 .102 .655 r
.80281 .14922 m .80099 .14601 L .80151 .14657 L closepath p F P
0 g
s
.751 .819 .905 r
.79418 .27927 m .79752 .27732 L .7988 .28167 L p F P
0 g
s
.78 .85 .904 r
.80701 .27128 m .79752 .27732 L .7988 .28167 L p F P
0 g
s
.78 .85 .904 r
.7988 .28167 m .80981 .27434 L .80701 .27128 L p F P
0 g
s
0 .296 .793 r
.7734 .11353 m .77482 .1145 L .77187 .11007 L p F P
0 g
s
0 .296 .793 r
.77187 .11007 m .77075 .1093 L .7734 .11353 L p F P
0 g
s
.681 .789 .931 r
.79418 .27927 m .78119 .28467 L .77828 .28084 L p F P
0 g
s
.462 .633 .928 r
.73472 .27249 m .74302 .27277 L .74 .26845 L p F P
0 g
s
.462 .633 .928 r
.74 .26845 m .73331 .26812 L .73472 .27249 L p F P
0 g
s
.481 .639 .925 r
.72673 .26787 m .73331 .26812 L .73472 .27249 L p F P
0 g
s
.398 .589 .92 r
.70732 .25666 m .71637 .25817 L .71814 .26246 L p F P
0 g
s
.386 .585 .921 r
.71637 .25817 m .70732 .25666 L .70424 .25211 L p F P
0 g
s
.858 .579 .046 r
.82577 .19724 m .8273 .20165 L .82809 .20708 L p F P
0 g
s
.76 .459 0 r
.8273 .20165 m .82577 .19724 L .82442 .19201 L p F P
0 g
s
.906 .906 .812 r
.82113 .26303 m .82064 .26034 L .82225 .26164 L closepath p F P
0 g
s
.996 .867 .565 r
.82862 .23635 m .82947 .2335 L .83036 .23654 L closepath p F P
0 g
s
.994 .825 .461 r
.83063 .2274 m .82947 .2335 L .83036 .23654 L p F P
0 g
s
.989 .89 .615 r
.82862 .23635 m .83036 .23654 L p .82836 .24442 L F P
0 g
s
.863 .879 .847 r
.82064 .26034 m .82113 .26303 L .81317 .27133 L p F P
0 g
s
.553 .686 .927 r
.74602 .2771 m .75621 .27615 L .75768 .28047 L p F P
0 g
s
.544 .682 .929 r
.75621 .27615 m .74602 .2771 L .74302 .27277 L p F P
0 g
s
0 .351 .827 r
.66012 .21874 m .66205 .21987 L .65891 .21559 L p F P
0 g
s
0 .351 .827 r
.65891 .21559 m .65736 .21467 L .66012 .21874 L p F P
0 g
s
0 .227 .747 r
.78841 .12971 m .78599 .12545 L .78117 .12153 L p F P
0 g
s
0 .223 .742 r
.77862 .11729 m .78117 .12153 L .78599 .12545 L p F P
0 g
s
0 .273 .777 r
.77482 .1145 m .77862 .11729 L .78117 .12153 L p F P
0 g
s
.537 .686 .935 r
.75768 .28047 m .76221 .28 L .75924 .27589 L p F P
0 g
s
.537 .686 .935 r
.75924 .27589 m .75621 .27615 L .75768 .28047 L p F P
0 g
s
.995 .829 .472 r
.82928 .22299 m .83063 .2274 L .82947 .2335 L p F P
0 g
s
.97 .766 .334 r
.83063 .2274 m .82928 .22299 L .82973 .21713 L p F P
0 g
s
.67 .348 0 r
.82442 .19201 m .82279 .18762 L .82094 .18256 L p F P
0 g
s
.777 .468 0 r
.82279 .18762 m .82442 .19201 L .82577 .19724 L p F P
0 g
s
.47 .636 .927 r
.73331 .26812 m .72673 .26787 L .72368 .2634 L p F P
0 g
s
.262 .514 .905 r
.70116 .24762 m .69225 .24486 L p .70332 .25183 L F P
0 g
s
.267 .515 .905 r
.69225 .24486 m .70116 .24762 L .69807 .24316 L p F P
0 g
s
.267 .515 .905 r
.69807 .24316 m .69016 .24064 L .69225 .24486 L p F P
0 g
s
.294 .53 .909 r
.68473 .23902 m .69016 .24064 L .69225 .24486 L p F P
0 g
s
.831 .864 .87 r
.81317 .27133 m .80981 .27434 L .80701 .27128 L p F P
0 g
s
.831 .864 .87 r
.80701 .27128 m .81206 .26691 L .81317 .27133 L p F P
0 g
s
.863 .879 .847 r
.81953 .25936 m .82064 .26034 L p .81317 .27133 L F P
0 g
s
.863 .879 .847 r
.81317 .27133 m .81206 .26691 L .81953 .25936 L p F P
0 g
s
.374 .58 .921 r
.71814 .26246 m .72368 .2634 L .72063 .25895 L p F P
0 g
s
.374 .58 .921 r
.72063 .25895 m .71637 .25817 L .71814 .26246 L p F P
0 g
s
0 .267 .773 r
.77862 .11729 m .77482 .1145 L .77187 .11007 L p F P
0 g
s
0 .184 .716 r
.79521 .13806 m .79292 .13376 L .78841 .12971 L p F P
0 g
s
0 .179 .711 r
.78599 .12545 m .78841 .12971 L .79292 .13376 L p F P
0 g
s
0 0 .347 r
.82094 .18256 m .81919 .17819 L .81688 .1733 L p F P
0 g
s
.688 .357 0 r
.81919 .17819 m .82094 .18256 L .82279 .18762 L p F P
0 g
s
0 .095 .648 r
.80151 .14657 m .80099 .14601 L .79802 .14091 L p F P
0 g
s
.967 .9 .703 r
.82727 .23995 m .82836 .24442 L .82492 .25127 L p F P
0 g
s
.989 .89 .615 r
.82836 .24442 m .82727 .23995 L .82862 .23635 L p F P
0 g
s
.279 .527 .91 r
.69016 .24064 m .68473 .23902 L .68162 .23453 L p F P
0 g
s
.02 .367 .837 r
.76217 .10158 m .75927 .0974 L .75321 .09399 L p F P
0 g
s
0 .115 .663 r
.79521 .13806 m .79802 .14091 L .79506 .13594 L p F P
0 g
s
0 .115 .663 r
.79506 .13594 m .79292 .13376 L .79521 .13806 L p F P
0 g
s
0 0 .334 r
.81501 .16894 m .81688 .1733 L .81919 .17819 L p F P
0 g
s
0 0 .44 r
.81688 .1733 m .81501 .16894 L .81227 .16422 L p F P
0 g
s
.144 .445 .879 r
.67944 .23356 m .67696 .22943 L .66968 .22618 L p F P
0 g
s
.125 .439 .876 r
.66711 .22206 m .66968 .22618 L .67696 .22943 L p F P
0 g
s
.158 .456 .884 r
.66205 .21987 m .66711 .22206 L .66968 .22618 L p F P
0 g
s
0 .013 .582 r
.80151 .14657 m .80504 .15099 L .80714 .15531 L p F P
0 g
s
0 .003 .571 r
.79929 .14227 m .80151 .14657 L .80504 .15099 L p F P
0 g
s
0 .095 .648 r
.79802 .14091 m .79929 .14227 L .80151 .14657 L p F P
0 g
s
0 0 .428 r
.81028 .15988 m .81227 .16422 L .81501 .16894 L p F P
0 g
s
0 0 .516 r
.81227 .16422 m .81028 .15988 L .80714 .15531 L p F P
0 g
s
0 0 .506 r
.80504 .15099 m .80714 .15531 L .81028 .15988 L p F P
0 g
s
.925 .681 .193 r
.82973 .21713 m .8283 .21271 L .82809 .20708 L p F P
0 g
s
.976 .768 .347 r
.8283 .21271 m .82973 .21713 L .82928 .22299 L p F P
0 g
s
.14 .452 .883 r
.66711 .22206 m .66205 .21987 L .65891 .21559 L p F P
0 g
s
0 .358 .83 r
.63932 .19966 m .6453 .20304 L .64836 .20705 L p F P
0 g
s
.609 .74 .938 r
.76221 .28 m .77535 .27697 L .77828 .28084 L p F P
0 g
s
.601 .734 .938 r
.77535 .27697 m .76221 .28 L .75924 .27589 L p F P
0 g
s
0 .343 .822 r
.77075 .1093 m .76798 .1051 L .76217 .10158 L p F P
0 g
s
0 .34 .82 r
.75927 .0974 m .76217 .10158 L .76798 .1051 L p F P
0 g
s
.278 .525 .909 r
.70424 .25211 m .70332 .25183 L .70127 .24778 L closepath p F P
0 g
s
.262 .514 .905 r
.70332 .25183 m .70127 .24778 L .70116 .24762 L p F P
0 g
s
.909 .892 .801 r
.81953 .25936 m .82015 .25856 L .82064 .26034 L closepath p F P
0 g
s
.938 .892 .758 r
.82492 .25127 m .82015 .25856 L .82064 .26034 L p F P
0 g
s
.743 .814 .908 r
.79752 .27732 m .79418 .27927 L .7913 .27572 L p F P
0 g
s
.681 .789 .931 r
.77828 .28084 m .7913 .27572 L .79418 .27927 L p F P
0 g
s
.934 .686 .207 r
.82657 .20267 m .82809 .20708 L .8283 .21271 L p F P
0 g
s
.858 .579 .046 r
.82809 .20708 m .82657 .20267 L .82577 .19724 L p F P
0 g
s
0 .345 .822 r
.65736 .21467 m .65444 .21064 L .64836 .20705 L p F P
0 g
s
0 .339 .817 r
.6453 .20304 m .64836 .20705 L .65444 .21064 L p F P
0 g
s
.931 .893 .769 r
.82375 .24684 m .82492 .25127 L .82015 .25856 L p F P
0 g
s
.967 .9 .703 r
.82492 .25127 m .82375 .24684 L .82727 .23995 L p F P
0 g
s
.139 .442 .877 r
.67944 .23356 m .68162 .23453 L .67851 .23013 L p F P
0 g
s
.139 .442 .877 r
.67851 .23013 m .67696 .22943 L .67944 .23356 L p F P
0 g
s
.386 .585 .921 r
.70424 .25211 m .71442 .25393 L .71637 .25817 L p F P
0 g
s
.373 .582 .923 r
.71442 .25393 m .70424 .25211 L .70127 .24778 L p F P
0 g
s
.996 .859 .576 r
.82947 .2335 m .8281 .2291 L p .82613 .23563 L F P
0 g
s
.996 .859 .576 r
.82613 .23563 m .82862 .23635 L .82947 .2335 L p F P
0 g
s
.995 .829 .472 r
.82947 .2335 m .8281 .2291 L .82928 .22299 L p F P
0 g
s
.672 .782 .932 r
.7913 .27572 m .77828 .28084 L .77535 .27697 L p F P
0 g
s
0 .292 .789 r
.77075 .1093 m .77187 .11007 L .76892 .10574 L p F P
0 g
s
0 .292 .789 r
.76892 .10574 m .76798 .1051 L .77075 .1093 L p F P
0 g
s
.743 .814 .908 r
.7913 .27572 m .79623 .27295 L .79752 .27732 L p F P
0 g
s
.77 .841 .906 r
.80418 .26811 m .79623 .27295 L .79752 .27732 L p F P
0 g
s
.77 .841 .906 r
.79752 .27732 m .80701 .27128 L .80418 .26811 L p F P
0 g
s
.544 .682 .929 r
.74302 .27277 m .75453 .27188 L .75621 .27615 L p F P
0 g
s
.534 .678 .93 r
.75453 .27188 m .74302 .27277 L .74 .26845 L p F P
0 g
s
.47 .636 .927 r
.72368 .2634 m .73168 .26381 L .73331 .26812 L p F P
0 g
s
.451 .63 .93 r
.73331 .26812 m .74 .26845 L .73698 .26414 L p F P
0 g
s
.451 .63 .93 r
.73698 .26414 m .73168 .26381 L .73331 .26812 L p F P
0 g
s
.871 .586 .062 r
.82414 .19285 m .82577 .19724 L .82657 .20267 L p F P
0 g
s
.777 .468 0 r
.82577 .19724 m .82414 .19285 L .82279 .18762 L p F P
0 g
s
.46 .633 .929 r
.73168 .26381 m .72368 .2634 L .72063 .25895 L p F P
0 g
s
0 .345 .822 r
.65736 .21467 m .65891 .21559 L .65577 .21143 L p F P
0 g
s
0 .345 .822 r
.65577 .21143 m .65444 .21064 L .65736 .21467 L p F P
0 g
s
.989 .887 .619 r
.82727 .23995 m .82613 .23563 L .82862 .23635 L closepath p F P
0 g
s
0 .223 .742 r
.78599 .12545 m .78346 .1212 L .77862 .11729 L p F P
0 g
s
0 .218 .738 r
.77596 .11306 m .77862 .11729 L .78346 .1212 L p F P
0 g
s
0 .267 .773 r
.77187 .11007 m .77596 .11306 L .77862 .11729 L p F P
0 g
s
0 .084 .638 r
.79929 .14227 m .79802 .14091 L .79506 .13594 L p F P
0 g
s
0 .262 .768 r
.77596 .11306 m .77187 .11007 L .76892 .10574 L p F P
0 g
s
.902 .886 .807 r
.82015 .25856 m .81953 .25936 L .81678 .25677 L p F P
0 g
s
.902 .886 .807 r
.81678 .25677 m .81886 .25417 L .82015 .25856 L p F P
0 g
s
.931 .893 .769 r
.82015 .25856 m .81886 .25417 L .82375 .24684 L p F P
0 g
s
.688 .357 0 r
.82279 .18762 m .82105 .18324 L .81919 .17819 L p F P
0 g
s
.793 .477 0 r
.82105 .18324 m .82279 .18762 L .82414 .19285 L p F P
0 g
s
.279 .527 .91 r
.68162 .23453 m .68789 .23645 L .69016 .24064 L p F P
0 g
s
.264 .524 .911 r
.68789 .23645 m .68162 .23453 L .67851 .23013 L p F P
0 g
s
.527 .682 .937 r
.75621 .27615 m .75924 .27589 L .75626 .27176 L p F P
0 g
s
.527 .682 .937 r
.75626 .27176 m .75453 .27188 L .75621 .27615 L p F P
0 g
s
.866 .89 .85 r
.81206 .26691 m .81953 .25936 L .81678 .25677 L p F P
0 g
s
.997 .829 .482 r
.82784 .21858 m .82928 .22299 L .8281 .2291 L p F P
0 g
s
.976 .768 .347 r
.82928 .22299 m .82784 .21858 L .8283 .21271 L p F P
0 g
s
.252 .512 .906 r
.69016 .24064 m .69807 .24316 L .69498 .23877 L p F P
0 g
s
.252 .512 .906 r
.69498 .23877 m .68789 .23645 L .69016 .24064 L p F P
0 g
s
0 .179 .711 r
.79292 .13376 m .79051 .12949 L .78599 .12545 L p F P
0 g
s
0 .173 .706 r
.78346 .1212 m .78599 .12545 L .79051 .12949 L p F P
0 g
s
.824 .859 .873 r
.81206 .26691 m .80701 .27128 L .80418 .26811 L p F P
0 g
s
.36 .576 .923 r
.71637 .25817 m .72063 .25895 L .71757 .25454 L p F P
0 g
s
.36 .576 .923 r
.71757 .25454 m .71442 .25393 L .71637 .25817 L p F P
0 g
s
.824 .859 .873 r
.80418 .26811 m .81089 .26249 L .81206 .26691 L p F P
0 g
s
.866 .89 .85 r
.81678 .25677 m .81089 .26249 L .81206 .26691 L p F P
0 g
s
0 0 .334 r
.81919 .17819 m .81733 .17383 L .81501 .16894 L p F P
0 g
s
.706 .366 0 r
.81733 .17383 m .81919 .17819 L .82105 .18324 L p F P
0 g
s
0 .105 .654 r
.79292 .13376 m .79506 .13594 L .7921 .13112 L p F P
0 g
s
0 .105 .654 r
.7921 .13112 m .79051 .12949 L .79292 .13376 L p F P
0 g
s
.964 .896 .709 r
.82613 .23563 m .82727 .23995 L .82375 .24684 L p F P
0 g
s
.14 .452 .883 r
.65891 .21559 m .66438 .21797 L .66711 .22206 L p F P
0 g
s
.122 .448 .882 r
.66438 .21797 m .65891 .21559 L .65577 .21143 L p F P
0 g
s
0 0 .32 r
.81304 .1646 m .81501 .16894 L .81733 .17383 L p F P
0 g
s
0 0 .428 r
.81501 .16894 m .81304 .1646 L .81028 .15988 L p F P
0 g
s
.125 .439 .876 r
.67696 .22943 m .67432 .22533 L .66711 .22206 L p F P
0 g
s
.108 .434 .874 r
.66438 .21797 m .66711 .22206 L .67432 .22533 L p F P
0 g
s
0 .003 .571 r
.80504 .15099 m .80282 .14669 L .79929 .14227 L p F P
0 g
s
0 0 .561 r
.79696 .13799 m .79929 .14227 L .80282 .14669 L p F P
0 g
s
0 .084 .638 r
.79506 .13594 m .79696 .13799 L .79929 .14227 L p F P
0 g
s
0 0 .506 r
.81028 .15988 m .80819 .15556 L .80504 .15099 L p F P
0 g
s
0 0 .415 r
.80819 .15556 m .81028 .15988 L .81304 .1646 L p F P
0 g
s
0 0 .495 r
.80282 .14669 m .80504 .15099 L .80819 .15556 L p F P
0 g
s
.601 .734 .938 r
.75924 .27589 m .77241 .27306 L .77535 .27697 L p F P
0 g
s
.593 .729 .939 r
.77241 .27306 m .75924 .27589 L .75626 .27176 L p F P
0 g
s
.934 .686 .207 r
.8283 .21271 m .82677 .20832 L .82657 .20267 L p F P
0 g
s
.981 .77 .36 r
.82677 .20832 m .8283 .21271 L .82784 .21858 L p F P
0 g
s
0 .34 .82 r
.76798 .1051 m .76509 .10093 L .75927 .0974 L p F P
0 g
s
.373 .582 .923 r
.70127 .24778 m .70121 .24763 L p .71442 .25393 L F P
0 g
s
.374 .581 .922 r
.70127 .24778 m .70116 .24762 L .70121 .24763 L closepath p F P
0 g
s
.37 .583 .925 r
.70121 .24763 m .70116 .24762 L .69807 .24316 L p F P
0 g
s
.373 .582 .923 r
.70121 .24763 m .71231 .24972 L .71442 .25393 L p F P
0 g
s
.346 .577 .927 r
.69919 .24337 m .70121 .24763 L .71231 .24972 L p F P
0 g
s
.37 .583 .925 r
.69807 .24316 m .69919 .24337 L .70121 .24763 L p F P
0 g
s
0 .339 .817 r
.65444 .21064 m .65136 .20664 L .6453 .20304 L p F P
0 g
s
.736 .81 .91 r
.79623 .27295 m .7913 .27572 L .78841 .2721 L p F P
0 g
s
.672 .782 .932 r
.77535 .27697 m .78841 .2721 L .7913 .27572 L p F P
0 g
s
.122 .437 .875 r
.67696 .22943 m .67851 .23013 L .67539 .22582 L p F P
0 g
s
.122 .437 .875 r
.67539 .22582 m .67432 .22533 L .67696 .22943 L p F P
0 g
s
.664 .776 .933 r
.78841 .2721 m .77535 .27697 L .77241 .27306 L p F P
0 g
s
.943 .69 .222 r
.82494 .19828 m .82657 .20267 L .82677 .20832 L p F P
0 g
s
.871 .586 .062 r
.82657 .20267 m .82494 .19828 L .82414 .19285 L p F P
0 g
s
0 .287 .785 r
.76798 .1051 m .76892 .10574 L .76597 .10152 L p F P
0 g
s
0 .287 .785 r
.76597 .10152 m .76509 .10093 L .76798 .1051 L p F P
0 g
s
.534 .678 .93 r
.74 .26845 m .75267 .26765 L .75453 .27188 L p F P
0 g
s
.526 .675 .932 r
.75267 .26765 m .74 .26845 L .73698 .26414 L p F P
0 g
s
.927 .889 .773 r
.82249 .24241 m .82375 .24684 L .81886 .25417 L p F P
0 g
s
.964 .896 .709 r
.82604 .23559 m .82613 .23563 L p .82375 .24684 L F P
0 g
s
.964 .896 .709 r
.82375 .24684 m .82249 .24241 L .82604 .23559 L p F P
0 g
s
.994 .863 .592 r
.82663 .22471 m .8281 .2291 L .82608 .23549 L p F P
0 g
s
.997 .829 .482 r
.8281 .2291 m .82663 .22471 L .82784 .21858 L p F P
0 g
s
.996 .859 .576 r
.8281 .2291 m .82608 .23549 L .82613 .23563 L p F P
0 g
s
.46 .633 .929 r
.72063 .25895 m .72986 .25954 L .73168 .26381 L p F P
0 g
s
.45 .63 .931 r
.72986 .25954 m .72063 .25895 L .71757 .25454 L p F P
0 g
s
0 .073 .627 r
.79696 .13799 m .79506 .13594 L .7921 .13112 L p F P
0 g
s
.736 .81 .91 r
.78841 .2721 m .79493 .26857 L .79623 .27295 L p F P
0 g
s
.761 .833 .908 r
.80134 .26483 m .79493 .26857 L .79623 .27295 L p F P
0 g
s
.761 .833 .908 r
.79623 .27295 m .80418 .26811 L .80134 .26483 L p F P
0 g
s
0 .34 .818 r
.65444 .21064 m .65577 .21143 L .65263 .20738 L p F P
0 g
s
0 .34 .818 r
.65263 .20738 m .65136 .20664 L .65444 .21064 L p F P
0 g
s
0 .262 .768 r
.76892 .10574 m .77319 .10886 L .77596 .11306 L p F P
0 g
s
0 .256 .763 r
.77319 .10886 m .76892 .10574 L .76597 .10152 L p F P
0 g
s
0 .218 .738 r
.78346 .1212 m .7808 .11697 L .77596 .11306 L p F P
0 g
s
0 .212 .732 r
.77319 .10886 m .77596 .11306 L .7808 .11697 L p F P
0 g
s
.44 .627 .933 r
.73168 .26381 m .73698 .26414 L .73395 .25985 L p F P
0 g
s
.44 .627 .933 r
.73395 .25985 m .72986 .25954 L .73168 .26381 L p F P
0 g
s
.883 .592 .078 r
.8224 .18847 m .82414 .19285 L .82494 .19828 L p F P
0 g
s
.793 .477 0 r
.82414 .19285 m .8224 .18847 L .82105 .18324 L p F P
0 g
s
.264 .524 .911 r
.67851 .23013 m .68546 .2323 L .68789 .23645 L p F P
0 g
s
.249 .521 .912 r
.68546 .2323 m .67851 .23013 L .67539 .22582 L p F P
0 g
s
0 .173 .706 r
.79051 .12949 m .78799 .12524 L .78346 .1212 L p F P
0 g
s
0 .167 .7 r
.7808 .11697 m .78346 .1212 L .78799 .12524 L p F P
0 g
s
.706 .366 0 r
.82105 .18324 m .8192 .17888 L .81733 .17383 L p F P
0 g
s
.808 .484 0 r
.8192 .17888 m .82105 .18324 L .8224 .18847 L p F P
0 g
s
.237 .509 .906 r
.68789 .23645 m .69498 .23877 L .69187 .23444 L p F P
0 g
s
.237 .509 .906 r
.69187 .23444 m .68546 .2323 L .68789 .23645 L p F P
0 g
s
.895 .881 .812 r
.81886 .25417 m .81678 .25677 L .81401 .25401 L p F P
0 g
s
.895 .881 .812 r
.81401 .25401 m .81748 .24979 L .81886 .25417 L p F P
0 g
s
.927 .889 .773 r
.81886 .25417 m .81748 .24979 L .82249 .24241 L p F P
0 g
s
.517 .679 .939 r
.75453 .27188 m .75626 .27176 L .75327 .26761 L p F P
0 g
s
.517 .679 .939 r
.75327 .26761 m .75267 .26765 L .75453 .27188 L p F P
0 g
s
.999 .827 .492 r
.82629 .21419 m .82784 .21858 L .82663 .22471 L p F P
0 g
s
.981 .77 .36 r
.82784 .21858 m .82629 .21419 L .82677 .20832 L p F P
0 g
s
.348 .573 .924 r
.71442 .25393 m .71757 .25454 L .71451 .25017 L p F P
0 g
s
.348 .573 .924 r
.71451 .25017 m .71231 .24972 L .71442 .25393 L p F P
0 g
s
.817 .854 .876 r
.81089 .26249 m .80418 .26811 L .80134 .26483 L p F P
0 g
s
.122 .448 .882 r
.65577 .21143 m .66149 .21393 L .66438 .21797 L p F P
0 g
s
.105 .445 .88 r
.66149 .21393 m .65577 .21143 L .65263 .20738 L p F P
0 g
s
.857 .88 .855 r
.81089 .26249 m .81678 .25677 L .81401 .25401 L p F P
0 g
s
0 .095 .644 r
.79051 .12949 m .7921 .13112 L .78915 .12643 L p F P
0 g
s
0 .095 .644 r
.78915 .12643 m .78799 .12524 L .79051 .12949 L p F P
0 g
s
0 0 .32 r
.81733 .17383 m .81537 .16948 L .81304 .1646 L p F P
0 g
s
.724 .375 0 r
.81537 .16948 m .81733 .17383 L .8192 .17888 L p F P
0 g
s
.817 .854 .876 r
.80134 .26483 m .80967 .25807 L .81089 .26249 L p F P
0 g
s
.857 .88 .855 r
.81401 .25401 m .80967 .25807 L .81089 .26249 L p F P
0 g
s
.108 .434 .874 r
.67432 .22533 m .67154 .22126 L .66438 .21797 L p F P
0 g
s
.093 .43 .873 r
.66149 .21393 m .66438 .21797 L .67154 .22126 L p F P
0 g
s
.982 .882 .655 r
.82604 .23559 m .82608 .23549 L .82613 .23563 L closepath p F P
0 g
s
0 0 .561 r
.80282 .14669 m .8005 .14241 L .79696 .13799 L p F P
0 g
s
0 0 .551 r
.79452 .13373 m .79696 .13799 L .8005 .14241 L p F P
0 g
s
0 .073 .627 r
.7921 .13112 m .79452 .13373 L .79696 .13799 L p F P
0 g
s
.638 .271 0 r
.81095 .16028 m .81304 .1646 L .81537 .16948 L p F P
0 g
s
0 0 .415 r
.81304 .1646 m .81095 .16028 L .80819 .15556 L p F P
0 g
s
.593 .729 .939 r
.75626 .27176 m .76946 .26912 L .77241 .27306 L p F P
0 g
s
.586 .725 .939 r
.76946 .26912 m .75626 .27176 L .75327 .26761 L p F P
0 g
s
.978 .879 .666 r
.82608 .23549 m .82604 .23559 L .82338 .23389 L p F P
0 g
s
.978 .879 .666 r
.82338 .23389 m .82458 .23112 L .82608 .23549 L p F P
0 g
s
.994 .863 .592 r
.82608 .23549 m .82458 .23112 L .82663 .22471 L p F P
0 g
s
.964 .898 .708 r
.82249 .24241 m .82604 .23559 L .82338 .23389 L p F P
0 g
s
0 0 .495 r
.80819 .15556 m .80599 .15126 L .80282 .14669 L p F P
0 g
s
0 0 .483 r
.8005 .14241 m .80282 .14669 L .80599 .15126 L p F P
0 g
s
0 0 .402 r
.80599 .15126 m .80819 .15556 L .81095 .16028 L p F P
0 g
s
.358 .581 .927 r
.69919 .24337 m .69807 .24316 L .69498 .23877 L p F P
0 g
s
.986 .771 .372 r
.82514 .20393 m .82677 .20832 L .82629 .21419 L p F P
0 g
s
.943 .69 .222 r
.82677 .20832 m .82514 .20393 L .82494 .19828 L p F P
0 g
s
.346 .577 .927 r
.71231 .24972 m .71005 .24554 L .69919 .24337 L p F P
0 g
s
.333 .573 .928 r
.69699 .23916 m .69919 .24337 L .71005 .24554 L p F P
0 g
s
.358 .581 .927 r
.69498 .23877 m .69699 .23916 L .69919 .24337 L p F P
0 g
s
.664 .776 .933 r
.77241 .27306 m .78551 .26841 L .78841 .2721 L p F P
0 g
s
.73 .806 .912 r
.79493 .26857 m .78841 .2721 L .78551 .26841 L p F P
0 g
s
.526 .675 .932 r
.73698 .26414 m .75027 .26346 L p .75267 .26765 L F P
0 g
s
.507 .676 .941 r
.75027 .26346 m .73698 .26414 L .73395 .25985 L p F P
0 g
s
.657 .771 .933 r
.78551 .26841 m .77241 .27306 L .76946 .26912 L p F P
0 g
s
.45 .63 .931 r
.71757 .25454 m .72786 .2553 L .72986 .25954 L p F P
0 g
s
.44 .628 .933 r
.72786 .2553 m .71757 .25454 L .71451 .25017 L p F P
0 g
s
0 .063 .616 r
.79452 .13373 m .7921 .13112 L .78915 .12643 L p F P
0 g
s
.106 .433 .874 r
.67432 .22533 m .67539 .22582 L .67226 .22159 L p F P
0 g
s
.106 .433 .874 r
.67226 .22159 m .67154 .22126 L .67432 .22533 L p F P
0 g
s
.951 .693 .236 r
.82321 .19391 m .82494 .19828 L .82514 .20393 L p F P
0 g
s
.883 .592 .078 r
.82494 .19828 m .82321 .19391 L .8224 .18847 L p F P
0 g
s
.993 .86 .599 r
.82506 .22033 m .82663 .22471 L .82458 .23112 L p F P
0 g
s
.999 .827 .492 r
.82663 .22471 m .82506 .22033 L .82629 .21419 L p F P
0 g
s
.924 .885 .777 r
.82115 .23799 m .82249 .24241 L .81748 .24979 L p F P
0 g
s
.964 .898 .708 r
.82338 .23389 m .82115 .23799 L .82249 .24241 L p F P
0 g
s
.249 .521 .912 r
.67539 .22582 m .68286 .22819 L .68546 .2323 L p F P
0 g
s
.236 .519 .913 r
.68286 .22819 m .67539 .22582 L .67226 .22159 L p F P
0 g
s
0 .256 .763 r
.76597 .10152 m .7703 .10469 L .77319 .10886 L p F P
0 g
s
0 .212 .732 r
.7808 .11697 m .77803 .11277 L .77319 .10886 L p F P
0 g
s
0 .206 .726 r
.7703 .10469 m .77319 .10886 L .77803 .11277 L p F P
0 g
s
.73 .806 .912 r
.78551 .26841 m .79363 .26417 L .79493 .26857 L p F P
0 g
s
.752 .826 .909 r
.79848 .26145 m .79363 .26417 L .79493 .26857 L p F P
0 g
s
.752 .826 .909 r
.79493 .26857 m .80134 .26483 L .79848 .26145 L p F P
0 g
s
.895 .597 .093 r
.82056 .18411 m .8224 .18847 L .82321 .19391 L p F P
0 g
s
.808 .484 0 r
.8224 .18847 m .82056 .18411 L .8192 .17888 L p F P
0 g
s
.429 .624 .934 r
.72986 .25954 m .73395 .25985 L .73091 .25557 L p F P
0 g
s
.429 .624 .934 r
.73091 .25557 m .72786 .2553 L .72986 .25954 L p F P
0 g
s
0 .167 .7 r
.78799 .12524 m .78534 .12101 L .7808 .11697 L p F P
0 g
s
0 .161 .693 r
.77803 .11277 m .7808 .11697 L .78534 .12101 L p F P
0 g
s
.224 .506 .907 r
.68546 .2323 m .69187 .23444 L .68877 .23019 L p F P
0 g
s
.224 .506 .907 r
.68877 .23019 m .68286 .22819 L .68546 .2323 L p F P
0 g
s
.724 .375 0 r
.8192 .17888 m .81724 .17454 L .81537 .16948 L p F P
0 g
s
.822 .492 0 r
.81724 .17454 m .8192 .17888 L .82056 .18411 L p F P
0 g
s
.105 .445 .88 r
.65263 .20738 m .65842 .20992 L .66149 .21393 L p F P
0 g
s
.516 .681 .94 r
.75327 .26761 m .75267 .26765 L .75148 .26514 L closepath p F P
0 g
s
.526 .675 .932 r
.75027 .26346 m .75148 .26514 L .75267 .26765 L p F P
0 g
s
.889 .876 .817 r
.81748 .24979 m .81401 .25401 L .81121 .2511 L p F P
0 g
s
.889 .876 .817 r
.81121 .2511 m .81602 .24541 L .81748 .24979 L p F P
0 g
s
.924 .885 .777 r
.81748 .24979 m .81602 .24541 L .82115 .23799 L p F P
0 g
s
1 .826 .501 r
.82465 .20982 m .82629 .21419 L .82506 .22033 L p F P
0 g
s
.986 .771 .372 r
.82629 .21419 m .82465 .20982 L .82514 .20393 L p F P
0 g
s
.336 .57 .925 r
.71231 .24972 m .71451 .25017 L .71144 .24584 L p F P
0 g
s
.336 .57 .925 r
.71144 .24584 m .71005 .24554 L .71231 .24972 L p F P
0 g
s
0 .086 .633 r
.78799 .12524 m .78915 .12643 L .7862 .12189 L p F P
0 g
s
0 .086 .633 r
.7862 .12189 m .78534 .12101 L .78799 .12524 L p F P
0 g
s
.811 .85 .879 r
.80967 .25807 m .80134 .26483 L .79848 .26145 L p F P
0 g
s
.586 .725 .939 r
.75327 .26761 m .7665 .26514 L .76946 .26912 L p F P
0 g
s
.587 .715 .932 r
.76353 .26114 m .7665 .26514 L .75327 .26761 L p F P
0 g
s
.587 .715 .932 r
.75106 .26331 m .76353 .26114 L p .75327 .26761 L F P
0 g
s
.587 .715 .932 r
.75327 .26761 m .75148 .26514 L .75106 .26331 L p F P
0 g
s
.741 .384 0 r
.81329 .16516 m .81537 .16948 L .81724 .17454 L p F P
0 g
s
.638 .271 0 r
.81537 .16948 m .81329 .16516 L .81095 .16028 L p F P
0 g
s
.093 .43 .873 r
.67154 .22126 m .66861 .21722 L .66149 .21393 L p F P
0 g
s
.079 .428 .871 r
.65842 .20992 m .66149 .21393 L .66861 .21722 L p F P
0 g
s
0 0 .551 r
.8005 .14241 m .79807 .13815 L .79452 .13373 L p F P
0 g
s
0 0 .539 r
.79197 .12949 m .79452 .13373 L .79807 .13815 L p F P
0 g
s
0 .063 .616 r
.78915 .12643 m .79197 .12949 L .79452 .13373 L p F P
0 g
s
.347 .58 .929 r
.69699 .23916 m .69498 .23877 L .69187 .23444 L p F P
0 g
s
.848 .872 .859 r
.80967 .25807 m .81401 .25401 L .81121 .2511 L p F P
0 g
s
0 0 .402 r
.81095 .16028 m .80876 .15597 L .80599 .15126 L p F P
0 g
s
.656 .28 0 r
.80876 .15597 m .81095 .16028 L .81329 .16516 L p F P
0 g
s
.811 .85 .879 r
.79848 .26145 m .80839 .25365 L .80967 .25807 L p F P
0 g
s
.848 .872 .859 r
.81121 .2511 m .80839 .25365 L .80967 .25807 L p F P
0 g
s
0 0 .483 r
.80599 .15126 m .80367 .14697 L .8005 .14241 L p F P
0 g
s
0 0 .47 r
.79807 .13815 m .8005 .14241 L .80367 .14697 L p F P
0 g
s
0 0 .388 r
.80367 .14697 m .80599 .15126 L .80876 .15597 L p F P
0 g
s
.973 .875 .676 r
.82458 .23112 m .82338 .23389 L .82068 .23189 L p F P
0 g
s
.973 .875 .676 r
.82068 .23189 m .82297 .22676 L .82458 .23112 L p F P
0 g
s
.993 .86 .599 r
.82458 .23112 m .82297 .22676 L .82506 .22033 L p F P
0 g
s
0 .052 .604 r
.79197 .12949 m .78915 .12643 L .7862 .12189 L p F P
0 g
s
.507 .676 .941 r
.73395 .25985 m .74727 .25929 L .75027 .26346 L p F P
0 g
s
.5 .674 .942 r
.74727 .25929 m .73395 .25985 L .73091 .25557 L p F P
0 g
s
.989 .771 .383 r
.8234 .19956 m .82514 .20393 L .82465 .20982 L p F P
0 g
s
.951 .693 .236 r
.82514 .20393 m .8234 .19956 L .82321 .19391 L p F P
0 g
s
.44 .628 .933 r
.71451 .25017 m .72571 .2511 L .72786 .2553 L p F P
0 g
s
.43 .626 .935 r
.72571 .2511 m .71451 .25017 L .71144 .24584 L p F P
0 g
s
.657 .771 .933 r
.76946 .26912 m .78259 .26468 L .78551 .26841 L p F P
0 g
s
.65 .766 .934 r
.78259 .26468 m .76946 .26912 L .7665 .26514 L p F P
0 g
s
.723 .803 .914 r
.79363 .26417 m .78551 .26841 L .78259 .26468 L p F P
0 g
s
.333 .573 .928 r
.71005 .24554 m .70765 .24139 L .69699 .23916 L p F P
0 g
s
.322 .571 .929 r
.69461 .23499 m .69699 .23916 L .70765 .24139 L p F P
0 g
s
.347 .58 .929 r
.69187 .23444 m .69461 .23499 L .69699 .23916 L p F P
0 g
s
.958 .891 .72 r
.82115 .23799 m .82338 .23389 L .82068 .23189 L p F P
0 g
s
.092 .43 .872 r
.67154 .22126 m .67226 .22159 L .66913 .21746 L p F P
0 g
s
.092 .43 .872 r
.66913 .21746 m .66861 .21722 L .67154 .22126 L p F P
0 g
s
.236 .519 .913 r
.67226 .22159 m .68011 .22411 L .68286 .22819 L p F P
0 g
s
.223 .517 .914 r
.68011 .22411 m .67226 .22159 L .66913 .21746 L p F P
0 g
s
.584 .713 .932 r
.75148 .26514 m .75027 .26346 L .75106 .26331 L closepath p F P
0 g
s
.957 .695 .25 r
.82137 .18955 m .82321 .19391 L .8234 .19956 L p F P
0 g
s
.895 .597 .093 r
.82321 .19391 m .82137 .18955 L .82056 .18411 L p F P
0 g
s
0 .206 .726 r
.77803 .11277 m .77514 .10859 L .7703 .10469 L p F P
0 g
s
.991 .857 .605 r
.8234 .21597 m .82506 .22033 L .82297 .22676 L p F P
0 g
s
1 .826 .501 r
.82506 .22033 m .8234 .21597 L .82465 .20982 L p F P
0 g
s
.92 .881 .779 r
.81973 .23358 m .82115 .23799 L .81602 .24541 L p F P
0 g
s
.958 .891 .72 r
.82068 .23189 m .81973 .23358 L .82115 .23799 L p F P
0 g
s
.905 .602 .108 r
.81861 .17977 m .82056 .18411 L .82137 .18955 L p F P
0 g
s
.822 .492 0 r
.82056 .18411 m .81861 .17977 L .81724 .17454 L p F P
0 g
s
.419 .622 .936 r
.72786 .2553 m .73091 .25557 L .72787 .25131 L p F P
0 g
s
.419 .622 .936 r
.72787 .25131 m .72571 .2511 L .72786 .2553 L p F P
0 g
s
.723 .803 .914 r
.78259 .26468 m .79234 .25975 L .79363 .26417 L p F P
0 g
s
.744 .819 .911 r
.7956 .25799 m .79234 .25975 L .79363 .26417 L p F P
0 g
s
.744 .819 .911 r
.79363 .26417 m .79848 .26145 L .7956 .25799 L p F P
0 g
s
0 .161 .693 r
.78534 .12101 m .78258 .11681 L .77803 .11277 L p F P
0 g
s
0 .154 .684 r
.77514 .10859 m .77803 .11277 L .78258 .11681 L p F P
0 g
s
.211 .504 .907 r
.68286 .22819 m .68877 .23019 L .68565 .226 L p F P
0 g
s
.211 .504 .907 r
.68565 .226 m .68011 .22411 L .68286 .22819 L p F P
0 g
s
.584 .714 .932 r
.75106 .26331 m .75027 .26346 L .74727 .25929 L p F P
0 g
s
.836 .499 0 r
.81518 .17021 m .81724 .17454 L .81861 .17977 L p F P
0 g
s
.741 .384 0 r
.81724 .17454 m .81518 .17021 L .81329 .16516 L p F P
0 g
s
0 .076 .622 r
.78534 .12101 m .7862 .12189 L .78325 .11749 L p F P
0 g
s
0 .076 .622 r
.78325 .11749 m .78258 .11681 L .78534 .12101 L p F P
0 g
s
.336 .579 .931 r
.69461 .23499 m .69187 .23444 L .68877 .23019 L p F P
0 g
s
.079 .428 .871 r
.66861 .21722 m .66555 .21321 L .65842 .20992 L p F P
0 g
s
.325 .568 .927 r
.71005 .24554 m .71144 .24584 L .70836 .24155 L p F P
0 g
s
.325 .568 .927 r
.70836 .24155 m .70765 .24139 L .71005 .24554 L p F P
0 g
s
.575 .709 .934 r
.75106 .26331 m .76353 .26114 L .76055 .25712 L p F P
0 g
s
.575 .709 .934 r
.76055 .25712 m .74973 .25888 L .75106 .26331 L p F P
0 g
s
.584 .714 .932 r
.74727 .25929 m .74973 .25888 L .75106 .26331 L p F P
0 g
s
1 .823 .509 r
.82291 .20545 m .82465 .20982 L .8234 .21597 L p F P
0 g
s
.989 .771 .383 r
.82465 .20982 m .82291 .20545 L .8234 .19956 L p F P
0 g
s
.804 .845 .881 r
.80839 .25365 m .79848 .26145 L .7956 .25799 L p F P
0 g
s
.883 .871 .821 r
.81602 .24541 m .81121 .2511 L .80839 .24806 L p F P
0 g
s
.883 .871 .821 r
.80839 .24806 m .81448 .24105 L .81602 .24541 L p F P
0 g
s
.92 .881 .779 r
.81602 .24541 m .81448 .24105 L .81973 .23358 L p F P
0 g
s
.757 .392 0 r
.81111 .16085 m .81329 .16516 L .81518 .17021 L p F P
0 g
s
.656 .28 0 r
.81329 .16516 m .81111 .16085 L .80876 .15597 L p F P
0 g
s
0 0 .539 r
.79807 .13815 m .79552 .1339 L .79197 .12949 L p F P
0 g
s
0 0 .527 r
.78931 .12526 m .79197 .12949 L .79552 .1339 L p F P
0 g
s
0 .052 .604 r
.7862 .12189 m .78931 .12526 L .79197 .12949 L p F P
0 g
s
0 0 .388 r
.80876 .15597 m .80645 .15169 L .80367 .14697 L p F P
0 g
s
.674 .29 0 r
.80645 .15169 m .80876 .15597 L .81111 .16085 L p F P
0 g
s
0 0 .47 r
.80367 .14697 m .80125 .14271 L .79807 .13815 L p F P
0 g
s
0 0 .457 r
.79552 .1339 m .79807 .13815 L .80125 .14271 L p F P
0 g
s
0 0 .373 r
.80125 .14271 m .80367 .14697 L .80645 .15169 L p F P
0 g
s
0 .042 .592 r
.78931 .12526 m .7862 .12189 L .78325 .11749 L p F P
0 g
s
.839 .864 .862 r
.80839 .24806 m .80705 .24923 L .80839 .25365 L p F P
0 g
s
.839 .864 .862 r
.80839 .25365 m .81121 .2511 L .80839 .24806 L p F P
0 g
s
.804 .845 .881 r
.7956 .25799 m .80705 .24923 L .80839 .25365 L p F P
0 g
s
.5 .674 .942 r
.73091 .25557 m .74425 .25513 L .74727 .25929 L p F P
0 g
s
.494 .672 .943 r
.74425 .25513 m .73091 .25557 L .72787 .25131 L p F P
0 g
s
.43 .626 .935 r
.71144 .24584 m .72342 .24693 L .72571 .2511 L p F P
0 g
s
.422 .625 .937 r
.72342 .24693 m .71144 .24584 L .70836 .24155 L p F P
0 g
s
.969 .865 .68 r
.82297 .22676 m .82128 .22241 L p .81852 .23011 L F P
0 g
s
.969 .865 .68 r
.81852 .23011 m .82068 .23189 L .82297 .22676 L p F P
0 g
s
.991 .857 .605 r
.82297 .22676 m .82128 .22241 L .8234 .21597 L p F P
0 g
s
.65 .766 .934 r
.7665 .26514 m .77966 .26089 L .78259 .26468 L p F P
0 g
s
.644 .761 .934 r
.77966 .26089 m .7665 .26514 L .76353 .26114 L p F P
0 g
s
.992 .77 .394 r
.82156 .19521 m .8234 .19956 L .82291 .20545 L p F P
0 g
s
.957 .695 .25 r
.8234 .19956 m .82156 .19521 L .82137 .18955 L p F P
0 g
s
.717 .8 .916 r
.79234 .25975 m .78259 .26468 L .77966 .26089 L p F P
0 g
s
.079 .428 .871 r
.66861 .21722 m .66913 .21746 L .666 .21342 L p F P
0 g
s
.079 .428 .871 r
.666 .21342 m .66555 .21321 L .66861 .21722 L p F P
0 g
s
.322 .571 .929 r
.70765 .24139 m .70511 .23727 L .69461 .23499 L p F P
0 g
s
.293 .556 .926 r
.69205 .23086 m .69461 .23499 L .70511 .23727 L p F P
0 g
s
.336 .579 .931 r
.68877 .23019 m .69205 .23086 L .69461 .23499 L p F P
0 g
s
.223 .517 .914 r
.66913 .21746 m .6772 .22006 L .68011 .22411 L p F P
0 g
s
.211 .516 .914 r
.6772 .22006 m .66913 .21746 L .666 .21342 L p F P
0 g
s
.963 .697 .263 r
.81942 .18521 m .82137 .18955 L .82156 .19521 L p F P
0 g
s
.905 .602 .108 r
.82137 .18955 m .81942 .18521 L .81861 .17977 L p F P
0 g
s
.951 .884 .73 r
.81973 .23358 m .81852 .23011 L .82068 .23189 L closepath p F P
0 g
s
.989 .853 .611 r
.82164 .21161 m .8234 .21597 L .82128 .22241 L p F P
0 g
s
1 .823 .509 r
.8234 .21597 m .82164 .21161 L .82291 .20545 L p F P
0 g
s
.916 .876 .783 r
.81852 .23011 m .81973 .23358 L .81448 .24105 L p F P
0 g
s
0 .154 .684 r
.78258 .11681 m .77969 .11262 L .77514 .10859 L p F P
0 g
s
.913 .604 .12 r
.81655 .17545 m .81861 .17977 L .81942 .18521 L p F P
0 g
s
.836 .499 0 r
.81861 .17977 m .81655 .17545 L .81518 .17021 L p F P
0 g
s
.41 .62 .938 r
.72571 .2511 m .72787 .25131 L .72481 .24707 L p F P
0 g
s
.41 .62 .938 r
.72481 .24707 m .72342 .24693 L .72571 .2511 L p F P
0 g
s
.577 .712 .934 r
.74973 .25888 m .74727 .25929 L .74425 .25513 L p F P
0 g
s
.2 .503 .908 r
.68011 .22411 m .68565 .226 L .68253 .22189 L p F P
0 g
s
.2 .503 .908 r
.68253 .22189 m .6772 .22006 L .68011 .22411 L p F P
0 g
s
.717 .8 .916 r
.77966 .26089 m .79107 .2553 L .79234 .25975 L p F P
0 g
s
.736 .812 .912 r
.79271 .25445 m .79107 .2553 L .79234 .25975 L p F P
0 g
s
.736 .812 .912 r
.79234 .25975 m .7956 .25799 L .79271 .25445 L p F P
0 g
s
.326 .578 .933 r
.69205 .23086 m .68877 .23019 L .68565 .226 L p F P
0 g
s
0 .067 .611 r
.78258 .11681 m .78325 .11749 L .7803 .11325 L p F P
0 g
s
0 .067 .611 r
.7803 .11325 m .77969 .11262 L .78258 .11681 L p F P
0 g
s
.757 .392 0 r
.81518 .17021 m .813 .1659 L .81111 .16085 L p F P
0 g
s
.845 .501 0 r
.813 .1659 m .81518 .17021 L .81655 .17545 L p F P
0 g
s
.315 .566 .928 r
.70765 .24139 m .70836 .24155 L .70527 .23731 L p F P
0 g
s
.315 .566 .928 r
.70527 .23731 m .70511 .23727 L .70765 .24139 L p F P
0 g
s
0 0 .527 r
.79552 .1339 m .79287 .12968 L .78931 .12526 L p F P
0 g
s
0 0 .514 r
.78653 .12106 m .78931 .12526 L .79287 .12968 L p F P
0 g
s
0 .042 .592 r
.78325 .11749 m .78653 .12106 L .78931 .12526 L p F P
0 g
s
.8 .847 .886 r
.80705 .24923 m .7956 .25799 L .79271 .25445 L p F P
0 g
s
.761 .387 0 r
.80881 .15657 m .81111 .16085 L .813 .1659 L p F P
0 g
s
.674 .29 0 r
.81111 .16085 m .80881 .15657 L .80645 .15169 L p F P
0 g
s
1 .821 .517 r
.82106 .20111 m .82291 .20545 L .82164 .21161 L p F P
0 g
s
.992 .77 .394 r
.82291 .20545 m .82106 .20111 L .82156 .19521 L p F P
0 g
s
.878 .858 .817 r
.81448 .24105 m .81285 .23669 L p .80571 .24506 L F P
0 g
s
.878 .858 .817 r
.80571 .24506 m .80839 .24806 L .81448 .24105 L p F P
0 g
s
.916 .876 .783 r
.81794 .22957 m .81852 .23011 L p .81448 .24105 L F P
0 g
s
.916 .876 .783 r
.81448 .24105 m .81285 .23669 L .81794 .22957 L p F P
0 g
s
.568 .708 .936 r
.74973 .25888 m .76055 .25712 L .75755 .25309 L p F P
0 g
s
.568 .708 .936 r
.75755 .25309 m .74806 .25453 L .74973 .25888 L p F P
0 g
s
.577 .712 .934 r
.74425 .25513 m .74806 .25453 L .74973 .25888 L p F P
0 g
s
0 0 .457 r
.80125 .14271 m .79871 .13846 L .79552 .1339 L p F P
0 g
s
0 0 .442 r
.79287 .12968 m .79552 .1339 L .79871 .13846 L p F P
0 g
s
.494 .672 .943 r
.72787 .25131 m .74122 .25097 L .74425 .25513 L p F P
0 g
s
.489 .67 .944 r
.74122 .25097 m .72787 .25131 L .72481 .24707 L p F P
0 g
s
0 .032 .579 r
.78653 .12106 m .78325 .11749 L .7803 .11325 L p F P
0 g
s
.422 .625 .937 r
.70836 .24155 m .72099 .24278 L .72342 .24693 L p F P
0 g
s
.413 .624 .939 r
.72099 .24278 m .70836 .24155 L .70527 .23731 L p F P
0 g
s
0 0 .373 r
.80645 .15169 m .80403 .14742 L .80125 .14271 L p F P
0 g
s
.692 .299 0 r
.80403 .14742 m .80645 .15169 L .80881 .15657 L p F P
0 g
s
.612 .205 0 r
.79871 .13846 m .80125 .14271 L .80403 .14742 L p F P
0 g
s
.644 .761 .934 r
.76353 .26114 m .77672 .25706 L .77966 .26089 L p F P
0 g
s
.638 .757 .935 r
.77672 .25706 m .76353 .26114 L .76055 .25712 L p F P
0 g
s
.831 .856 .865 r
.80705 .24923 m .80571 .24506 L .80839 .24806 L closepath p F P
0 g
s
.8 .847 .886 r
.80571 .24506 m .80705 .24923 L p .79271 .25445 L F P
0 g
s
.969 .865 .68 r
.82128 .22241 m .81815 .2292 L .81852 .23011 L p F P
0 g
s
.965 .865 .689 r
.81948 .21808 m .82128 .22241 L .81815 .2292 L p F P
0 g
s
.989 .853 .611 r
.82128 .22241 m .81948 .21808 L .82164 .21161 L p F P
0 g
s
.712 .8 .919 r
.79107 .2553 m .77966 .26089 L .77672 .25706 L p F P
0 g
s
.963 .697 .263 r
.82156 .19521 m .81961 .19087 L .81942 .18521 L p F P
0 g
s
.994 .769 .404 r
.81961 .19087 m .82156 .19521 L .82106 .20111 L p F P
0 g
s
.293 .556 .926 r
.70218 .23311 m .69205 .23086 L p .70511 .23727 L F P
0 g
s
.308 .567 .93 r
.69205 .23086 m .70218 .23311 L .69908 .22896 L p F P
0 g
s
.308 .567 .93 r
.69908 .22896 m .68933 .22677 L .69205 .23086 L p F P
0 g
s
.326 .578 .933 r
.68565 .226 m .68933 .22677 L .69205 .23086 L p F P
0 g
s
.211 .516 .914 r
.666 .21342 m .67414 .21604 L .6772 .22006 L p F P
0 g
s
.946 .873 .732 r
.81794 .22957 m .81815 .2292 L .81852 .23011 L closepath p F P
0 g
s
.969 .698 .276 r
.81737 .1809 m .81942 .18521 L .81961 .19087 L p F P
0 g
s
.913 .604 .12 r
.81736 .18085 m .81655 .17545 L p .81942 .18521 L F P
0 g
s
.913 .604 .12 r
.81942 .18521 m .81737 .1809 L .81736 .18085 L p F P
0 g
s
.987 .849 .616 r
.81977 .20728 m .82164 .21161 L .81948 .21808 L p F P
0 g
s
1 .821 .517 r
.82164 .21161 m .81977 .20728 L .82106 .20111 L p F P
0 g
s
.571 .71 .936 r
.74806 .25453 m .74425 .25513 L .74122 .25097 L p F P
0 g
s
.941 .868 .738 r
.81815 .2292 m .81794 .22957 L .81516 .22687 L p F P
0 g
s
.941 .868 .738 r
.81516 .22687 m .81631 .22488 L .81815 .2292 L p F P
0 g
s
.965 .865 .689 r
.81815 .2292 m .81631 .22488 L .81948 .21808 L p F P
0 g
s
.916 .879 .783 r
.81285 .23669 m .81794 .22957 L .81516 .22687 L p F P
0 g
s
.317 .578 .935 r
.68933 .22677 m .68565 .226 L .68253 .22189 L p F P
0 g
s
.402 .619 .939 r
.72342 .24693 m .72481 .24707 L .72175 .24287 L p F P
0 g
s
.402 .619 .939 r
.72175 .24287 m .72099 .24278 L .72342 .24693 L p F P
0 g
s
.924 .611 .141 r
.81736 .18085 m .81655 .17545 L .81547 .17331 L closepath p F P
0 g
s
.845 .501 0 r
.81385 .16917 m .813 .1659 L p .81655 .17545 L F P
0 g
s
.845 .501 0 r
.81655 .17545 m .81547 .17331 L .81385 .16917 L p F P
0 g
s
.19 .503 .909 r
.6772 .22006 m .68253 .22189 L .67941 .21785 L p F P
0 g
s
.19 .503 .909 r
.67941 .21785 m .67414 .21604 L .6772 .22006 L p F P
0 g
s
.712 .8 .919 r
.78981 .25084 m .79107 .2553 L p .77672 .25706 L F P
0 g
s
.729 .807 .913 r
.79107 .2553 m .78981 .25084 L .79271 .25445 L closepath p F P
0 g
s
.865 .516 .01 r
.81385 .16917 m .813 .1659 L .81083 .16186 L closepath p F P
0 g
s
.761 .387 0 r
.81066 .1615 m .80881 .15657 L p .813 .1659 L F P
0 g
s
.761 .387 0 r
.813 .1659 m .81083 .16186 L .81066 .1615 L p F P
0 g
s
.31 .567 .93 r
.70527 .23731 m .70511 .23727 L .70408 .23569 L closepath p F P
0 g
s
.293 .556 .926 r
.70511 .23727 m .70408 .23569 L .70218 .23311 L p F P
0 g
s
0 0 .514 r
.79287 .12968 m .79009 .12548 L .78653 .12106 L p F P
0 g
s
0 0 .5 r
.78365 .11688 m .78653 .12106 L .79009 .12548 L p F P
0 g
s
0 .032 .579 r
.7803 .11325 m .78365 .11688 L .78653 .12106 L p F P
0 g
s
.489 .67 .944 r
.72481 .24707 m .73819 .24682 L .74122 .25097 L p F P
0 g
s
.484 .669 .945 r
.73819 .24682 m .72481 .24707 L .72175 .24287 L p F P
0 g
s
.413 .624 .939 r
.70527 .23731 m .71842 .23866 L .72099 .24278 L p F P
0 g
s
.406 .623 .941 r
.71842 .23866 m .70527 .23731 L .70408 .23569 L p F P
0 g
s
.8 .847 .886 r
.79271 .25445 m .80555 .24488 L .80571 .24506 L p F P
0 g
s
.794 .824 .875 r
.78981 .25084 m .79271 .25445 L .80555 .24488 L p F P
0 g
s
.793 .414 0 r
.80881 .15657 m .81066 .1615 L .80761 .15557 L p F P
0 g
s
.793 .414 0 r
.80761 .15557 m .8064 .1523 L .80881 .15657 L p F P
0 g
s
.692 .299 0 r
.80881 .15657 m .8064 .1523 L .80403 .14742 L p F P
0 g
s
0 0 .442 r
.79871 .13846 m .79605 .13424 L .79287 .12968 L p F P
0 g
s
0 0 .427 r
.79009 .12548 m .79287 .12968 L .79605 .13424 L p F P
0 g
s
.999 .817 .524 r
.81911 .19678 m .82106 .20111 L .81977 .20728 L p F P
0 g
s
.994 .769 .404 r
.82106 .20111 m .81911 .19678 L .81961 .19087 L p F P
0 g
s
.709 .309 0 r
.8015 .14318 m .80403 .14742 L .8064 .1523 L p F P
0 g
s
.612 .205 0 r
.80403 .14742 m .8015 .14318 L .79871 .13846 L p F P
0 g
s
.63 .215 0 r
.79605 .13424 m .79871 .13846 L .8015 .14318 L p F P
0 g
s
.878 .858 .817 r
.81285 .23669 m .80561 .24482 L .80571 .24506 L p F P
0 g
s
.871 .856 .824 r
.81113 .23235 m .81285 .23669 L .80561 .24482 L p F P
0 g
s
.916 .879 .783 r
.81516 .22687 m .81113 .23235 L .81285 .23669 L p F P
0 g
s
.562 .707 .938 r
.74806 .25453 m .75755 .25309 L .75455 .24905 L p F P
0 g
s
.562 .707 .938 r
.75455 .24905 m .74615 .25024 L .74806 .25453 L p F P
0 g
s
.571 .71 .936 r
.74122 .25097 m .74615 .25024 L .74806 .25453 L p F P
0 g
s
.638 .757 .935 r
.76055 .25712 m .77377 .25319 L .77672 .25706 L p F P
0 g
s
.633 .754 .935 r
.77377 .25319 m .76055 .25712 L .75755 .25309 L p F P
0 g
s
.851 .853 .843 r
.80555 .24488 m .80561 .24482 L .80571 .24506 L closepath p F P
0 g
s
.712 .8 .919 r
.77672 .25706 m .78981 .25083 L .78981 .25084 L p F P
0 g
s
.706 .795 .92 r
.78981 .25083 m .77672 .25706 L .77377 .25319 L p F P
0 g
s
.962 .86 .692 r
.81759 .21376 m .81948 .21808 L .81631 .22488 L p F P
0 g
s
.987 .849 .616 r
.81948 .21808 m .81759 .21376 L .81977 .20728 L p F P
0 g
s
.93 .616 .153 r
.81547 .17331 m .81434 .17115 L p .81737 .18089 L F P
0 g
s
.93 .616 .153 r
.81737 .18089 m .81736 .18085 L .81547 .17331 L p F P
0 g
s
.868 .524 .017 r
.81547 .17331 m .81385 .16917 L .81434 .17115 L closepath p F P
0 g
s
.846 .848 .845 r
.80561 .24482 m .80555 .24488 L .80269 .24153 L p F P
0 g
s
.846 .848 .845 r
.80269 .24153 m .80372 .24054 L .80561 .24482 L p F P
0 g
s
.871 .856 .824 r
.80561 .24482 m .80372 .24054 L .81113 .23235 L p F P
0 g
s
.794 .824 .875 r
.80555 .24488 m .80269 .24153 L p .78981 .25084 L F P
0 g
s
.3 .568 .932 r
.68933 .22677 m .69908 .22896 L .69597 .22486 L p F P
0 g
s
.3 .568 .932 r
.69597 .22486 m .68645 .22271 L .68933 .22677 L p F P
0 g
s
.317 .578 .935 r
.68253 .22189 m .68645 .22271 L .68933 .22677 L p F P
0 g
s
.406 .623 .941 r
.70408 .23569 m .70253 .23314 L p .71842 .23866 L F P
0 g
s
.413 .627 .941 r
.70408 .23569 m .70218 .23311 L .70253 .23314 L closepath p F P
0 g
s
.995 .767 .414 r
.81756 .18655 m .81961 .19087 L .81911 .19678 L p F P
0 g
s
.969 .698 .276 r
.81737 .18094 m .81737 .1809 L p .81961 .19087 L F P
0 g
s
.969 .698 .276 r
.81961 .19087 m .81756 .18655 L .81737 .18094 L p F P
0 g
s
.876 .528 .03 r
.81434 .17115 m .81385 .16917 L .81083 .16186 L p F P
0 g
s
.924 .614 .142 r
.81737 .1809 m .81736 .18085 L .81737 .18089 L closepath p F P
0 g
s
.97 .694 .277 r
.81737 .18094 m .81737 .18089 L .81737 .1809 L closepath p F P
0 g
s
.974 .694 .293 r
.81737 .18089 m .81512 .17661 L p .81675 .18495 L F P
0 g
s
.974 .694 .293 r
.81675 .18495 m .81737 .18094 L .81737 .18089 L p F P
0 g
s
.93 .616 .153 r
.81434 .17115 m .81512 .17661 L .81737 .18089 L p F P
0 g
s
.973 .699 .289 r
.81756 .18655 m .81675 .18495 L .81737 .18094 L closepath p F P
0 g
s
.566 .709 .938 r
.74615 .25024 m .74122 .25097 L .73819 .24682 L p F P
0 g
s
.309 .579 .937 r
.68645 .22271 m .68253 .22189 L .67941 .21785 L p F P
0 g
s
.985 .844 .62 r
.8178 .20296 m .81977 .20728 L .81759 .21376 L p F P
0 g
s
.999 .817 .524 r
.81977 .20728 m .8178 .20296 L .81911 .19678 L p F P
0 g
s
.936 .863 .742 r
.81631 .22488 m .81516 .22687 L .81235 .22398 L p F P
0 g
s
.936 .863 .742 r
.81235 .22398 m .81437 .22058 L .81631 .22488 L p F P
0 g
s
.962 .86 .692 r
.81631 .22488 m .81437 .22058 L .81759 .21376 L p F P
0 g
s
.395 .618 .941 r
.72099 .24278 m .72175 .24287 L .71868 .23869 L p F P
0 g
s
.395 .618 .941 r
.71868 .23869 m .71842 .23866 L .72099 .24278 L p F P
0 g
s
.939 .622 .175 r
.81199 .16689 m .81434 .17115 L .81512 .17661 L p F P
0 g
s
.876 .528 .03 r
.8107 .16162 m .81199 .16689 L .81434 .17115 L p F P
0 g
s
.876 .528 .03 r
.81083 .16186 m .8107 .16162 L p .81434 .17115 L F P
0 g
s
.796 .423 0 r
.81083 .16186 m .81066 .1615 L .8107 .16162 L closepath p F P
0 g
s
.484 .669 .945 r
.72175 .24287 m .73514 .24268 L .73819 .24682 L p F P
0 g
s
.48 .669 .947 r
.73514 .24268 m .72175 .24287 L .71868 .23869 L p F P
0 g
s
.409 .629 .944 r
.70253 .23314 m .70218 .23311 L .69908 .22896 L p F P
0 g
s
.809 .431 0 r
.8107 .16162 m .81066 .1615 L .80761 .15557 L p F P
0 g
s
.91 .871 .788 r
.81113 .23235 m .81516 .22687 L .81235 .22398 L p F P
0 g
s
0 0 .5 r
.79009 .12548 m .78721 .12129 L .78365 .11688 L p F P
0 g
s
.89 .538 .055 r
.80824 .15737 m .8107 .16162 L .81199 .16689 L p F P
0 g
s
.809 .431 0 r
.80761 .15557 m .80824 .15737 L .8107 .16162 L p F P
0 g
s
.406 .623 .941 r
.70253 .23314 m .7156 .23454 L p .71842 .23866 L F P
0 g
s
.396 .621 .943 r
.70253 .23314 m .7156 .23454 L .71252 .23043 L p F P
0 g
s
.396 .621 .943 r
.71252 .23043 m .69984 .22903 L .70253 .23314 L p F P
0 g
s
.409 .629 .944 r
.69908 .22896 m .69984 .22903 L .70253 .23314 L p F P
0 g
s
0 0 .427 r
.79605 .13424 m .79328 .13004 L .79009 .12548 L p F P
0 g
s
0 0 .411 r
.78721 .12129 m .79009 .12548 L .79328 .13004 L p F P
0 g
s
.769 .817 .89 r
.78981 .25083 m .78981 .25083 L .78981 .25084 L closepath p F P
0 g
s
.794 .824 .875 r
.80269 .24153 m .78981 .25083 L .78981 .25084 L p F P
0 g
s
.765 .813 .891 r
.78981 .25083 m .78981 .25083 L .78689 .24714 L p F P
0 g
s
.706 .795 .92 r
.77377 .25319 m .78689 .24714 L .78981 .25083 L p F P
0 g
s
.765 .813 .891 r
.78689 .24714 m .78771 .24662 L .78981 .25083 L p F P
0 g
s
.791 .835 .885 r
.79981 .2381 m .78771 .24662 L .78981 .25083 L p F P
0 g
s
.791 .835 .885 r
.78981 .25083 m .80269 .24153 L .79981 .2381 L p F P
0 g
s
.809 .426 0 r
.8064 .1523 m .80761 .15557 L .80458 .15 L p F P
0 g
s
.809 .426 0 r
.80458 .15 m .80386 .14806 L .8064 .1523 L p F P
0 g
s
.709 .309 0 r
.8064 .1523 m .80386 .14806 L .8015 .14318 L p F P
0 g
s
.63 .215 0 r
.8015 .14318 m .79885 .13895 L .79605 .13424 L p F P
0 g
s
.648 .225 0 r
.79328 .13004 m .79605 .13424 L .79885 .13895 L p F P
0 g
s
.726 .318 0 r
.79885 .13895 m .8015 .14318 L .80386 .14806 L p F P
0 g
s
.633 .754 .935 r
.75755 .25309 m .7708 .24929 L .77377 .25319 L p F P
0 g
s
.628 .751 .936 r
.7708 .24929 m .75755 .25309 L .75455 .24905 L p F P
0 g
s
.998 .814 .531 r
.81704 .19246 m .81911 .19678 L .8178 .20296 L p F P
0 g
s
.995 .767 .414 r
.81911 .19678 m .81704 .19246 L .81756 .18655 L p F P
0 g
s
.868 .852 .825 r
.8093 .22802 m .81113 .23235 L .80372 .24054 L p F P
0 g
s
.91 .871 .788 r
.81235 .22398 m .8093 .22802 L .81113 .23235 L p F P
0 g
s
.557 .707 .94 r
.74615 .25024 m .75455 .24905 L .75154 .24499 L p F P
0 g
s
.557 .707 .94 r
.75154 .24499 m .74402 .246 L .74615 .25024 L p F P
0 g
s
.566 .709 .938 r
.73819 .24682 m .74402 .246 L .74615 .25024 L p F P
0 g
s
.701 .791 .92 r
.78689 .24714 m .77377 .25319 L .7708 .24929 L p F P
0 g
s
.959 .856 .695 r
.81559 .20945 m .81759 .21376 L .81437 .22058 L p F P
0 g
s
.985 .844 .62 r
.81759 .21376 m .81559 .20945 L .8178 .20296 L p F P
0 g
s
.293 .569 .934 r
.68645 .22271 m .69597 .22486 L .69286 .22083 L p F P
0 g
s
.293 .569 .934 r
.69286 .22083 m .6834 .21868 L .68645 .22271 L p F P
0 g
s
.309 .579 .937 r
.67941 .21785 m .6834 .21868 L .68645 .22271 L p F P
0 g
s
.841 .844 .847 r
.80372 .24054 m .80269 .24153 L .79981 .2381 L p F P
0 g
s
.841 .844 .847 r
.79981 .2381 m .80174 .23627 L .80372 .24054 L p F P
0 g
s
.868 .852 .825 r
.80372 .24054 m .80174 .23627 L .8093 .22802 L p F P
0 g
s
.996 .767 .427 r
.81675 .18495 m .81756 .18655 L .81704 .19246 L p F P
0 g
s
.56 .708 .94 r
.74402 .246 m .73819 .24682 L .73514 .24268 L p F P
0 g
s
.824 .441 0 r
.80824 .15737 m .80761 .15557 L .80458 .15 L p F P
0 g
s
.974 .694 .293 r
.81512 .17661 m .81533 .18227 L .81675 .18495 L p F P
0 g
s
.977 .696 .304 r
.81277 .17235 m .81512 .17661 L .81533 .18227 L p F P
0 g
s
.939 .622 .175 r
.81512 .17661 m .81277 .17235 L .81199 .16689 L p F P
0 g
s
.982 .84 .625 r
.81572 .19866 m .8178 .20296 L .81559 .20945 L p F P
0 g
s
.998 .814 .531 r
.8178 .20296 m .81572 .19866 L .81704 .19246 L p F P
0 g
s
.994 .753 .406 r
.81515 .18506 m .81533 .18227 L .81675 .18495 L closepath p F P
0 g
s
.996 .767 .427 r
.81515 .18506 m .81675 .18495 L p .81704 .19246 L F P
0 g
s
.392 .619 .943 r
.71868 .23869 m .71842 .23866 L .71666 .23597 L closepath p F P
0 g
s
.406 .623 .941 r
.7156 .23454 m .71666 .23597 L .71842 .23866 L p F P
0 g
s
.945 .624 .189 r
.80953 .16264 m .81199 .16689 L .81277 .17235 L p F P
0 g
s
.89 .538 .055 r
.81199 .16689 m .80953 .16264 L .80824 .15737 L p F P
0 g
s
.932 .859 .746 r
.81437 .22058 m .81235 .22398 L .80952 .22093 L p F P
0 g
s
.932 .859 .746 r
.80952 .22093 m .81232 .2163 L .81437 .22058 L p F P
0 g
s
.959 .856 .695 r
.81437 .22058 m .81232 .2163 L .81559 .20945 L p F P
0 g
s
.48 .669 .947 r
.71868 .23869 m .73209 .23856 L .73514 .24268 L p F P
0 g
s
.492 .674 .945 r
.72903 .23446 m .73209 .23856 L .71868 .23869 L p F P
0 g
s
.492 .674 .945 r
.7158 .23454 m .72903 .23446 L p .71868 .23869 L F P
0 g
s
.492 .674 .945 r
.71868 .23869 m .71666 .23597 L .7158 .23454 L p F P
0 g
s
.403 .63 .946 r
.69984 .22903 m .69908 .22896 L .69597 .22486 L p F P
0 g
s
.824 .441 0 r
.80458 .15 m .80568 .15314 L .80824 .15737 L p F P
0 g
s
.899 .543 .071 r
.80568 .15314 m .80824 .15737 L .80953 .16264 L p F P
0 g
s
.39 .623 .945 r
.69984 .22903 m .71252 .23043 L .70943 .22635 L p F P
0 g
s
.39 .623 .945 r
.70943 .22635 m .69698 .22496 L .69984 .22903 L p F P
0 g
s
.403 .63 .946 r
.69597 .22486 m .69698 .22496 L .69984 .22903 L p F P
0 g
s
0 0 .411 r
.79328 .13004 m .7904 .12585 L .78721 .12129 L p F P
0 g
s
.76 .81 .892 r
.78771 .24662 m .78689 .24714 L .78395 .24339 L p F P
0 g
s
.701 .791 .92 r
.7708 .24929 m .78395 .24339 L .78689 .24714 L p F P
0 g
s
.824 .435 0 r
.80386 .14806 m .80458 .15 L .80157 .14481 L p F P
0 g
s
.824 .435 0 r
.80157 .14481 m .80122 .14383 L .80386 .14806 L p F P
0 g
s
.726 .318 0 r
.80386 .14806 m .80122 .14383 L .79885 .13895 L p F P
0 g
s
.628 .751 .936 r
.75455 .24905 m .76782 .24536 L .7708 .24929 L p F P
0 g
s
.624 .749 .936 r
.76782 .24536 m .75455 .24905 L .75154 .24499 L p F P
0 g
s
.648 .225 0 r
.79885 .13895 m .79608 .13475 L .79328 .13004 L p F P
0 g
s
.666 .235 0 r
.7904 .12585 m .79328 .13004 L .79608 .13475 L p F P
0 g
s
.903 .865 .791 r
.8093 .22802 m .81235 .22398 L .80952 .22093 L p F P
0 g
s
.76 .81 .892 r
.78395 .24339 m .78553 .24241 L .78771 .24662 L p F P
0 g
s
.786 .83 .886 r
.79692 .23457 m .78553 .24241 L .78771 .24662 L p F P
0 g
s
.786 .83 .886 r
.78771 .24662 m .79981 .2381 L .79692 .23457 L p F P
0 g
s
.741 .327 0 r
.79608 .13475 m .79885 .13895 L .80122 .14383 L p F P
0 g
s
.996 .809 .537 r
.81486 .18817 m .81704 .19246 L .81572 .19866 L p F P
0 g
s
.996 .767 .427 r
.81704 .19246 m .81486 .18817 L .81515 .18506 L p F P
0 g
s
.697 .787 .92 r
.78395 .24339 m .7708 .24929 L .76782 .24536 L p F P
0 g
s
.552 .706 .942 r
.74402 .246 m .75154 .24499 L .74852 .24094 L p F P
0 g
s
.552 .706 .942 r
.74852 .24094 m .74171 .24181 L .74402 .246 L p F P
0 g
s
.56 .708 .94 r
.73514 .24268 m .74171 .24181 L .74402 .246 L p F P
0 g
s
.864 .848 .826 r
.80738 .2237 m .8093 .22802 L .80174 .23627 L p F P
0 g
s
.903 .865 .791 r
.80952 .22093 m .80738 .2237 L .8093 .22802 L p F P
0 g
s
.956 .851 .697 r
.81348 .20516 m .81559 .20945 L .81232 .2163 L p F P
0 g
s
.982 .84 .625 r
.81559 .20945 m .81348 .20516 L .81572 .19866 L p F P
0 g
s
.837 .451 0 r
.80568 .15314 m .80458 .15 L .80157 .14481 L p F P
0 g
s
.837 .84 .848 r
.80174 .23627 m .79981 .2381 L .79692 .23457 L p F P
0 g
s
.837 .84 .848 r
.79692 .23457 m .79967 .23201 L .80174 .23627 L p F P
0 g
s
.864 .848 .826 r
.80174 .23627 m .79967 .23201 L .80738 .2237 L p F P
0 g
s
.994 .749 .417 r
.81533 .18227 m .81297 .17801 L p .81289 .1845 L F P
0 g
s
.994 .749 .417 r
.81289 .1845 m .81515 .18506 L .81533 .18227 L p F P
0 g
s
.977 .696 .304 r
.81533 .18227 m .81297 .17801 L .81277 .17235 L p F P
0 g
s
.485 .67 .945 r
.71666 .23597 m .7156 .23454 L .7158 .23454 L closepath p F P
0 g
s
.556 .707 .941 r
.74171 .24181 m .73514 .24268 L .73209 .23856 L p F P
0 g
s
.979 .695 .314 r
.81031 .16811 m .81277 .17235 L .81297 .17801 L p F P
0 g
s
.945 .624 .189 r
.81277 .17235 m .81031 .16811 L .80953 .16264 L p F P
0 g
s
.996 .764 .435 r
.81486 .18817 m .81289 .1845 L .81515 .18506 L closepath p F P
0 g
s
.483 .672 .947 r
.7158 .23454 m .7156 .23454 L .71252 .23043 L p F P
0 g
s
.98 .835 .628 r
.81353 .19437 m .81572 .19866 L .81348 .20516 L p F P
0 g
s
.996 .809 .537 r
.81572 .19866 m .81353 .19437 L .81486 .18817 L p F P
0 g
s
.474 .667 .947 r
.7158 .23454 m .72903 .23446 L .72596 .23038 L p F P
0 g
s
.474 .667 .947 r
.72596 .23038 m .71313 .23042 L .7158 .23454 L p F P
0 g
s
.483 .672 .947 r
.71252 .23043 m .71313 .23042 L .7158 .23454 L p F P
0 g
s
.397 .631 .948 r
.69698 .22496 m .69597 .22486 L .69286 .22083 L p F P
0 g
s
.949 .626 .202 r
.80697 .15841 m .80953 .16264 L .81031 .16811 L p F P
0 g
s
.899 .543 .071 r
.80953 .16264 m .80697 .15841 L .80568 .15314 L p F P
0 g
s
.927 .854 .749 r
.81232 .2163 m .80952 .22093 L .80667 .21772 L p F P
0 g
s
.927 .854 .749 r
.80667 .21772 m .81018 .21203 L .81232 .2163 L p F P
0 g
s
.956 .851 .697 r
.81232 .2163 m .81018 .21203 L .81348 .20516 L p F P
0 g
s
.837 .451 0 r
.80157 .14481 m .80301 .14892 L .80568 .15314 L p F P
0 g
s
.906 .547 .086 r
.80301 .14892 m .80568 .15314 L .80697 .15841 L p F P
0 g
s
.386 .624 .947 r
.69698 .22496 m .70943 .22635 L .70633 .22231 L p F P
0 g
s
.386 .624 .947 r
.70633 .22231 m .69395 .22093 L .69698 .22496 L p F P
0 g
s
.397 .631 .948 r
.69286 .22083 m .69395 .22093 L .69698 .22496 L p F P
0 g
s
.624 .749 .936 r
.75154 .24499 m .76484 .24141 L .76782 .24536 L p F P
0 g
s
.621 .747 .937 r
.76484 .24141 m .75154 .24499 L .74852 .24094 L p F P
0 g
s
.837 .444 0 r
.80122 .14383 m .80157 .14481 L .79859 .14002 L p F P
0 g
s
.837 .444 0 r
.79859 .14002 m .79845 .13963 L .80122 .14383 L p F P
0 g
s
.741 .327 0 r
.80122 .14383 m .79845 .13963 L .79608 .13475 L p F P
0 g
s
.666 .235 0 r
.79608 .13475 m .79319 .13057 L .7904 .12585 L p F P
0 g
s
.757 .807 .893 r
.78553 .24241 m .78395 .24339 L .781 .2396 L p F P
0 g
s
.697 .787 .92 r
.76782 .24536 m .781 .2396 L .78395 .24339 L p F P
0 g
s
.756 .336 0 r
.79319 .13057 m .79608 .13475 L .79845 .13963 L p F P
0 g
s
.757 .807 .893 r
.781 .2396 m .78327 .2382 L .78553 .24241 L p F P
0 g
s
.78 .825 .887 r
.79401 .23096 m .78327 .2382 L .78553 .24241 L p F P
0 g
s
.78 .825 .887 r
.78553 .24241 m .79692 .23457 L .79401 .23096 L p F P
0 g
s
.897 .858 .795 r
.80738 .2237 m .80952 .22093 L .80667 .21772 L p F P
0 g
s
.994 .805 .543 r
.81289 .1845 m .81486 .18817 L .81353 .19437 L p F P
0 g
s
.693 .784 .921 r
.781 .2396 m .76782 .24536 L .76484 .24141 L p F P
0 g
s
.849 .459 0 r
.80301 .14892 m .80157 .14481 L .79859 .14002 L p F P
0 g
s
.548 .706 .944 r
.74171 .24181 m .74852 .24094 L .74548 .23688 L p F P
0 g
s
.548 .706 .944 r
.74548 .23688 m .73923 .23764 L .74171 .24181 L p F P
0 g
s
.556 .707 .941 r
.73209 .23856 m .73923 .23764 L .74171 .24181 L p F P
0 g
s
.861 .844 .827 r
.80534 .21941 m .80738 .2237 L .79967 .23201 L p F P
0 g
s
.897 .858 .795 r
.80667 .21772 m .80534 .21941 L .80738 .2237 L p F P
0 g
s
.953 .846 .699 r
.81127 .20089 m .81348 .20516 L .81018 .21203 L p F P
0 g
s
.98 .835 .628 r
.81348 .20516 m .81127 .20089 L .81353 .19437 L p F P
0 g
s
.833 .836 .849 r
.79967 .23201 m .79692 .23457 L .79401 .23096 L p F P
0 g
s
.833 .836 .849 r
.79401 .23096 m .79749 .22777 L .79967 .23201 L p F P
0 g
s
.861 .844 .827 r
.79967 .23201 m .79749 .22777 L .80534 .21941 L p F P
0 g
s
.994 .749 .417 r
.81297 .17801 m .81256 .1839 L .81289 .1845 L p F P
0 g
s
.994 .749 .427 r
.81051 .17377 m .81297 .17801 L .81256 .1839 L p F P
0 g
s
.979 .695 .314 r
.81297 .17801 m .81051 .17377 L .81031 .16811 L p F P
0 g
s
.552 .707 .943 r
.73923 .23764 m .73209 .23856 L .72903 .23446 L p F P
0 g
s
.98 .694 .325 r
.80774 .16388 m .81031 .16811 L .81051 .17377 L p F P
0 g
s
.949 .626 .202 r
.81031 .16811 m .80774 .16388 L .80697 .15841 L p F P
0 g
s
.479 .673 .95 r
.71313 .23042 m .71252 .23043 L .70943 .22635 L p F P
0 g
s
.47 .668 .95 r
.71313 .23042 m .72596 .23038 L .72289 .22631 L p F P
0 g
s
.47 .668 .95 r
.72289 .22631 m .71029 .22634 L .71313 .23042 L p F P
0 g
s
.479 .673 .95 r
.70943 .22635 m .71029 .22634 L .71313 .23042 L p F P
0 g
s
.953 .627 .215 r
.80429 .1542 m .80697 .15841 L .80774 .16388 L p F P
0 g
s
.906 .547 .086 r
.80697 .15841 m .80429 .1542 L .80301 .14892 L p F P
0 g
s
.977 .83 .631 r
.81123 .19011 m .81353 .19437 L .81127 .20089 L p F P
0 g
s
.994 .805 .543 r
.81251 .18421 m .81289 .1845 L p .81353 .19437 L F P
0 g
s
.994 .805 .543 r
.81353 .19437 m .81123 .19011 L .81251 .18421 L p F P
0 g
s
.923 .849 .752 r
.81018 .21203 m .80667 .21772 L .80379 .21438 L p F P
0 g
s
.923 .849 .752 r
.80379 .21438 m .80793 .20778 L .81018 .21203 L p F P
0 g
s
.953 .846 .699 r
.81018 .21203 m .80793 .20778 L .81127 .20089 L p F P
0 g
s
.912 .55 .101 r
.80022 .14473 m .80301 .14892 L .80429 .1542 L p F P
0 g
s
.849 .459 0 r
.79859 .14002 m .80022 .14473 L .80301 .14892 L p F P
0 g
s
.621 .747 .937 r
.74852 .24094 m .76184 .23743 L .76484 .24141 L p F P
0 g
s
.618 .745 .937 r
.76184 .23743 m .74852 .24094 L .74548 .23688 L p F P
0 g
s
.848 .45 0 r
.79845 .13963 m .79859 .14002 L .79563 .13564 L p F P
0 g
s
.848 .45 0 r
.79563 .13564 m .79556 .13545 L .79845 .13963 L p F P
0 g
s
.756 .336 0 r
.79845 .13963 m .79556 .13545 L .79319 .13057 L p F P
0 g
s
.754 .805 .894 r
.78327 .2382 m .781 .2396 L .77804 .23575 L p F P
0 g
s
.693 .784 .921 r
.76484 .24141 m .77804 .23575 L .781 .2396 L p F P
0 g
s
.996 .789 .509 r
.81251 .18421 m .81256 .1839 L .81289 .1845 L closepath p F P
0 g
s
.859 .466 0 r
.80022 .14473 m .79859 .14002 L .79563 .13564 L p F P
0 g
s
.754 .805 .894 r
.77804 .23575 m .78092 .23401 L .78327 .2382 L p F P
0 g
s
.776 .82 .887 r
.79108 .22728 m .78092 .23401 L .78327 .2382 L p F P
0 g
s
.776 .82 .887 r
.78327 .2382 m .79401 .23096 L .79108 .22728 L p F P
0 g
s
.689 .781 .921 r
.77804 .23575 m .76484 .24141 L .76184 .23743 L p F P
0 g
s
.994 .786 .517 r
.81256 .1839 m .81251 .18421 L .80972 .18175 L p F P
0 g
s
.994 .786 .517 r
.80972 .18175 m .81009 .17967 L .81256 .1839 L p F P
0 g
s
.994 .749 .427 r
.81256 .1839 m .81009 .17967 L .81051 .17377 L p F P
0 g
s
.992 .801 .546 r
.81123 .19011 m .81251 .18421 L .80972 .18175 L p F P
0 g
s
.892 .852 .797 r
.80534 .21941 m .80667 .21772 L .80379 .21438 L p F P
0 g
s
.544 .706 .945 r
.73923 .23764 m .74548 .23688 L .74244 .23282 L p F P
0 g
s
.544 .706 .945 r
.74244 .23282 m .73661 .23351 L .73923 .23764 L p F P
0 g
s
.552 .707 .943 r
.72903 .23446 m .73661 .23351 L .73923 .23764 L p F P
0 g
s
.858 .84 .827 r
.80319 .21513 m .80534 .21941 L .79749 .22777 L p F P
0 g
s
.892 .852 .797 r
.80379 .21438 m .80319 .21513 L .80534 .21941 L p F P
0 g
s
.95 .841 .701 r
.80894 .19664 m .81127 .20089 L .80793 .20778 L p F P
0 g
s
.977 .83 .631 r
.81127 .20089 m .80894 .19664 L .81123 .19011 L p F P
0 g
s
.993 .747 .434 r
.80794 .16955 m .81051 .17377 L .81009 .17967 L p F P
0 g
s
.98 .694 .325 r
.81051 .17377 m .80794 .16955 L .80774 .16388 L p F P
0 g
s
.548 .708 .945 r
.73661 .23351 m .72903 .23446 L .72596 .23038 L p F P
0 g
s
.829 .833 .85 r
.79749 .22777 m .79401 .23096 L .79108 .22728 L p F P
0 g
s
.829 .833 .85 r
.79108 .22728 m .79522 .22354 L .79749 .22777 L p F P
0 g
s
.858 .84 .827 r
.79749 .22777 m .79522 .22354 L .80319 .21513 L p F P
0 g
s
.981 .693 .335 r
.80506 .15967 m .80774 .16388 L .80794 .16955 L p F P
0 g
s
.953 .627 .215 r
.80774 .16388 m .80506 .15967 L .80429 .1542 L p F P
0 g
s
.476 .675 .952 r
.71029 .22634 m .70943 .22635 L .70633 .22231 L p F P
0 g
s
.476 .675 .952 r
.70633 .22231 m .70727 .22229 L .71029 .22634 L p F P
0 g
s
.468 .67 .952 r
.71029 .22634 m .72289 .22631 L .7198 .22227 L p F P
0 g
s
.468 .67 .952 r
.7198 .22227 m .70727 .22229 L .71029 .22634 L p F P
0 g
s
.956 .627 .227 r
.80151 .15001 m .80429 .1542 L .80506 .15967 L p F P
0 g
s
.912 .55 .101 r
.80429 .1542 m .80151 .15001 L .80022 .14473 L p F P
0 g
s
.974 .824 .634 r
.80881 .18586 m .81123 .19011 L .80894 .19664 L p F P
0 g
s
.992 .801 .546 r
.80972 .18175 m .80881 .18586 L .81123 .19011 L p F P
0 g
s
.918 .552 .116 r
.79733 .14055 m .80022 .14473 L .80151 .15001 L p F P
0 g
s
.859 .466 0 r
.79563 .13564 m .79733 .14055 L .80022 .14473 L p F P
0 g
s
.618 .745 .937 r
.74548 .23688 m .75883 .23344 L .76184 .23743 L p F P
0 g
s
.616 .744 .937 r
.75883 .23344 m .74548 .23688 L .74244 .23282 L p F P
0 g
s
.919 .841 .751 r
.80793 .20778 m .80557 .20354 L p .80101 .21103 L F P
0 g
s
.919 .841 .751 r
.80101 .21103 m .80379 .21438 L .80793 .20778 L p F P
0 g
s
.95 .841 .701 r
.80793 .20778 m .80557 .20354 L .80894 .19664 L p F P
0 g
s
.751 .802 .894 r
.78092 .23401 m .77804 .23575 L .77507 .23187 L p F P
0 g
s
.689 .781 .921 r
.76184 .23743 m .77507 .23187 L .77804 .23575 L p F P
0 g
s
.687 .778 .921 r
.77507 .23187 m .76184 .23743 L .75883 .23344 L p F P
0 g
s
.751 .802 .894 r
.77507 .23187 m .77847 .22983 L .78092 .23401 L p F P
0 g
s
.771 .815 .888 r
.78814 .22352 m .77847 .22983 L .78092 .23401 L p F P
0 g
s
.771 .815 .888 r
.78092 .23401 m .79108 .22728 L .78814 .22352 L p F P
0 g
s
.991 .783 .524 r
.81009 .17967 m .80972 .18175 L .80689 .17889 L p F P
0 g
s
.991 .783 .524 r
.80689 .17889 m .80751 .17545 L .81009 .17967 L p F P
0 g
s
.993 .747 .434 r
.81009 .17967 m .80751 .17545 L .80794 .16955 L p F P
0 g
s
.542 .706 .946 r
.73661 .23351 m .74244 .23282 L .73939 .22877 L p F P
0 g
s
.542 .706 .946 r
.73939 .22877 m .73386 .22941 L .73661 .23351 L p F P
0 g
s
.548 .708 .945 r
.72596 .23038 m .73386 .22941 L .73661 .23351 L p F P
0 g
s
.887 .846 .799 r
.80319 .21513 m .80101 .21103 L .80379 .21438 L closepath p F P
0 g
s
.855 .836 .827 r
.80101 .21103 m .80319 .21513 L .79522 .22354 L p F P
0 g
s
.546 .708 .947 r
.73386 .22941 m .72596 .23038 L .72289 .22631 L p F P
0 g
s
.989 .797 .555 r
.80881 .18586 m .80972 .18175 L .80689 .17889 L p F P
0 g
s
.947 .836 .702 r
.8065 .1924 m .80894 .19664 L .80557 .20354 L p F P
0 g
s
.974 .824 .634 r
.80894 .19664 m .8065 .1924 L .80881 .18586 L p F P
0 g
s
.992 .743 .441 r
.80525 .16535 m .80794 .16955 L .80751 .17545 L p F P
0 g
s
.981 .693 .335 r
.80794 .16955 m .80525 .16535 L .80506 .15967 L p F P
0 g
s
.826 .829 .85 r
.79522 .22354 m .79108 .22728 L .78814 .22352 L p F P
0 g
s
.826 .829 .85 r
.78814 .22352 m .79284 .21932 L .79522 .22354 L p F P
0 g
s
.855 .836 .827 r
.8009 .21089 m .80101 .21103 L p .79522 .22354 L F P
0 g
s
.855 .836 .827 r
.79522 .22354 m .79284 .21932 L .8009 .21089 L p F P
0 g
s
.981 .691 .344 r
.80227 .15548 m .80506 .15967 L .80525 .16535 L p F P
0 g
s
.956 .627 .227 r
.80506 .15967 m .80227 .15548 L .80151 .15001 L p F P
0 g
s
.958 .627 .239 r
.79861 .14583 m .80151 .15001 L .80227 .15548 L p F P
0 g
s
.918 .552 .116 r
.80151 .15001 m .79861 .14583 L .79733 .14055 L p F P
0 g
s
.97 .819 .636 r
.80627 .18164 m .80881 .18586 L .8065 .1924 L p F P
0 g
s
.989 .797 .555 r
.80689 .17889 m .80627 .18164 L .80881 .18586 L p F P
0 g
s
.616 .744 .937 r
.74244 .23282 m .75581 .22942 L .75883 .23344 L p F P
0 g
s
.614 .743 .938 r
.75581 .22942 m .74244 .23282 L .73939 .22877 L p F P
0 g
s
.919 .841 .751 r
.80557 .20354 m .80092 .21087 L .80101 .21103 L p F P
0 g
s
.915 .838 .754 r
.8031 .19932 m .80557 .20354 L .80092 .21087 L p F P
0 g
s
.947 .836 .702 r
.80557 .20354 m .8031 .19932 L .8065 .1924 L p F P
0 g
s
.748 .8 .894 r
.77847 .22983 m .77507 .23187 L .77208 .22794 L p F P
0 g
s
.687 .778 .921 r
.75883 .23344 m .77208 .22794 L .77507 .23187 L p F P
0 g
s
.685 .776 .92 r
.77208 .22794 m .75883 .23344 L .75581 .22942 L p F P
0 g
s
.748 .8 .894 r
.77208 .22794 m .77593 .22567 L .77847 .22983 L p F P
0 g
s
.768 .811 .887 r
.78518 .2197 m .77593 .22567 L .77847 .22983 L p F P
0 g
s
.768 .811 .887 r
.77847 .22983 m .78814 .22352 L .78518 .2197 L p F P
0 g
s
.989 .779 .53 r
.80751 .17545 m .80689 .17889 L .80402 .17564 L p F P
0 g
s
.989 .779 .53 r
.80402 .17564 m .80482 .17125 L .80751 .17545 L p F P
0 g
s
.992 .743 .441 r
.80751 .17545 m .80482 .17125 L .80525 .16535 L p F P
0 g
s
.54 .706 .948 r
.73386 .22941 m .73939 .22877 L .73633 .22472 L p F P
0 g
s
.54 .706 .948 r
.73633 .22472 m .73097 .22533 L .73386 .22941 L p F P
0 g
s
.546 .708 .947 r
.72289 .22631 m .73097 .22533 L .73386 .22941 L p F P
0 g
s
.896 .842 .784 r
.8009 .21089 m .80092 .21087 L .80101 .21103 L closepath p F P
0 g
s
.892 .837 .784 r
.80092 .21087 m .8009 .21089 L .79798 .20724 L p F P
0 g
s
.892 .837 .784 r
.79798 .20724 m .79841 .20667 L .80092 .21087 L p F P
0 g
s
.915 .838 .754 r
.80092 .21087 m .79841 .20667 L .8031 .19932 L p F P
0 g
s
.855 .837 .827 r
.79284 .21932 m .8009 .21089 L .79798 .20724 L p F P
0 g
s
.544 .71 .948 r
.73097 .22533 m .72289 .22631 L .7198 .22227 L p F P
0 g
s
.99 .74 .447 r
.80246 .16116 m .80525 .16535 L .80482 .17125 L p F P
0 g
s
.981 .691 .344 r
.80525 .16535 m .80246 .16116 L .80227 .15548 L p F P
0 g
s
.943 .83 .703 r
.80395 .18819 m .8065 .1924 L .8031 .19932 L p F P
0 g
s
.97 .819 .636 r
.8065 .1924 m .80395 .18819 L .80627 .18164 L p F P
0 g
s
.823 .825 .85 r
.79284 .21932 m .78814 .22352 L .78518 .2197 L p F P
0 g
s
.823 .825 .85 r
.78518 .2197 m .79036 .21513 L .79284 .21932 L p F P
0 g
s
.855 .837 .827 r
.79798 .20724 m .79036 .21513 L .79284 .21932 L p F P
0 g
s
.986 .792 .561 r
.80627 .18164 m .80689 .17889 L .80402 .17564 L p F P
0 g
s
.981 .689 .352 r
.79938 .15131 m .80227 .15548 L .80246 .16116 L p F P
0 g
s
.958 .627 .239 r
.80227 .15548 m .79938 .15131 L .79861 .14583 L p F P
0 g
s
.614 .743 .938 r
.73939 .22877 m .75277 .2254 L .75581 .22942 L p F P
0 g
s
.613 .743 .938 r
.75277 .2254 m .73939 .22877 L .73633 .22472 L p F P
0 g
s
.967 .813 .638 r
.8036 .17743 m .80627 .18164 L .80395 .18819 L p F P
0 g
s
.986 .792 .561 r
.80402 .17564 m .8036 .17743 L .80627 .18164 L p F P
0 g
s
.913 .833 .754 r
.80052 .19512 m .8031 .19932 L .79841 .20667 L p F P
0 g
s
.943 .83 .703 r
.8031 .19932 m .80052 .19512 L .80395 .18819 L p F P
0 g
s
.747 .798 .894 r
.77593 .22567 m .77208 .22794 L .76909 .22398 L p F P
0 g
s
.685 .776 .92 r
.75581 .22942 m .76909 .22398 L .77208 .22794 L p F P
0 g
s
.683 .774 .92 r
.76909 .22398 m .75581 .22942 L .75277 .2254 L p F P
0 g
s
.747 .798 .894 r
.76909 .22398 m .77329 .22152 L .77593 .22567 L p F P
0 g
s
.765 .808 .887 r
.78221 .21581 m .77329 .22152 L .77593 .22567 L p F P
0 g
s
.765 .808 .887 r
.77593 .22567 m .78518 .2197 L .78221 .21581 L p F P
0 g
s
.986 .774 .534 r
.80482 .17125 m .80402 .17564 L .80111 .17202 L p F P
0 g
s
.986 .774 .534 r
.80111 .17202 m .80202 .16708 L .80482 .17125 L p F P
0 g
s
.99 .74 .447 r
.80482 .17125 m .80202 .16708 L .80246 .16116 L p F P
0 g
s
.539 .708 .949 r
.73097 .22533 m .73633 .22472 L .73326 .22067 L p F P
0 g
s
.539 .708 .949 r
.73326 .22067 m .72795 .22127 L .73097 .22533 L p F P
0 g
s
.544 .71 .948 r
.7198 .22227 m .72795 .22127 L .73097 .22533 L p F P
0 g
s
.889 .833 .785 r
.79841 .20667 m .79798 .20724 L .79504 .20348 L p F P
0 g
s
.889 .833 .785 r
.79504 .20348 m .79579 .20249 L .79841 .20667 L p F P
0 g
s
.913 .833 .754 r
.79841 .20667 m .79579 .20249 L .80052 .19512 L p F P
0 g
s
.852 .832 .827 r
.79036 .21513 m .79798 .20724 L .79504 .20348 L p F P
0 g
s
.981 .689 .352 r
.80246 .16116 m .79956 .157 L .79938 .15131 L p F P
0 g
s
.988 .736 .453 r
.79956 .157 m .80246 .16116 L .80202 .16708 L p F P
0 g
s
.94 .825 .703 r
.80127 .18399 m .80395 .18819 L .80052 .19512 L p F P
0 g
s
.967 .813 .638 r
.80395 .18819 m .80127 .18399 L .8036 .17743 L p F P
0 g
s
.821 .822 .85 r
.79036 .21513 m .78518 .2197 L .78221 .21581 L p F P
0 g
s
.852 .832 .827 r
.79504 .20348 m .78776 .21095 L .79036 .21513 L p F P
0 g
s
.821 .822 .85 r
.78221 .21581 m .78776 .21095 L .79036 .21513 L p F P
0 g
s
.982 .787 .567 r
.8036 .17743 m .80402 .17564 L .80111 .17202 L p F P
0 g
s
.613 .743 .938 r
.73633 .22472 m .74973 .22135 L .75277 .2254 L p F P
0 g
s
.613 .743 .938 r
.74973 .22135 m .73633 .22472 L .73326 .22067 L p F P
0 g
s
.964 .808 .64 r
.80082 .17325 m .8036 .17743 L .80127 .18399 L p F P
0 g
s
.982 .787 .567 r
.80111 .17202 m .80082 .17325 L .8036 .17743 L p F P
0 g
s
.91 .829 .754 r
.79783 .19094 m .80052 .19512 L .79579 .20249 L p F P
0 g
s
.94 .825 .703 r
.80052 .19512 m .79783 .19094 L .80127 .18399 L p F P
0 g
s
.745 .796 .894 r
.77329 .22152 m .76909 .22398 L .76608 .21999 L p F P
0 g
s
.683 .774 .92 r
.75277 .2254 m .76608 .21999 L .76909 .22398 L p F P
0 g
s
.682 .773 .92 r
.76608 .21999 m .75277 .2254 L .74973 .22135 L p F P
0 g
s
.745 .796 .894 r
.76608 .21999 m .77053 .21739 L .77329 .22152 L p F P
0 g
s
.762 .804 .887 r
.77923 .21187 m .77053 .21739 L .77329 .22152 L p F P
0 g
s
.762 .804 .887 r
.77329 .22152 m .78221 .21581 L .77923 .21187 L p F P
0 g
s
.983 .77 .538 r
.80202 .16708 m .80111 .17202 L .79816 .16805 L p F P
0 g
s
.983 .77 .538 r
.79816 .16805 m .79911 .16291 L .80202 .16708 L p F P
0 g
s
.988 .736 .453 r
.80202 .16708 m .79911 .16291 L .79956 .157 L p F P
0 g
s
.887 .829 .784 r
.79579 .20249 m .79504 .20348 L .79209 .19961 L p F P
0 g
s
.887 .829 .784 r
.79209 .19961 m .79307 .19832 L .79579 .20249 L p F P
0 g
s
.91 .829 .754 r
.79579 .20249 m .79307 .19832 L .79783 .19094 L p F P
0 g
s
.848 .827 .827 r
.78776 .21095 m .79504 .20348 L .79209 .19961 L p F P
0 g
s
.937 .82 .703 r
.79848 .17982 m .80127 .18399 L .79783 .19094 L p F P
0 g
s
.964 .808 .64 r
.80127 .18399 m .79848 .17982 L .80082 .17325 L p F P
0 g
s
.819 .819 .849 r
.78776 .21095 m .78221 .21581 L .77923 .21187 L p F P
0 g
s
.819 .819 .849 r
.77923 .21187 m .78504 .20679 L .78776 .21095 L p F P
0 g
s
.848 .827 .827 r
.79209 .19961 m .78504 .20679 L .78776 .21095 L p F P
0 g
s
.978 .782 .571 r
.80082 .17325 m .80111 .17202 L .79816 .16805 L p F P
0 g
s
.613 .743 .938 r
.73326 .22067 m .74668 .2173 L .74973 .22135 L p F P
0 g
s
.96 .802 .641 r
.79792 .16909 m .80082 .17325 L .79848 .17982 L p F P
0 g
s
.978 .782 .571 r
.79816 .16805 m .79792 .16909 L .80082 .17325 L p F P
0 g
s
.744 .795 .893 r
.77053 .21739 m .76608 .21999 L .76305 .21596 L p F P
0 g
s
.682 .773 .92 r
.74973 .22135 m .76305 .21596 L .76608 .21999 L p F P
0 g
s
.907 .824 .753 r
.79502 .18678 m .79783 .19094 L .79307 .19832 L p F P
0 g
s
.937 .82 .703 r
.79783 .19094 m .79502 .18678 L .79848 .17982 L p F P
0 g
s
.682 .771 .919 r
.76305 .21596 m .74973 .22135 L .74668 .2173 L p F P
0 g
s
.744 .795 .893 r
.76305 .21596 m .76767 .21327 L .77053 .21739 L p F P
0 g
s
.76 .801 .886 r
.77623 .20786 m .76767 .21327 L .77053 .21739 L p F P
0 g
s
.76 .801 .886 r
.77053 .21739 m .77923 .21187 L .77623 .20786 L p F P
0 g
s
.884 .825 .784 r
.79307 .19832 m .79209 .19961 L .78912 .19564 L p F P
0 g
s
.884 .825 .784 r
.78912 .19564 m .79024 .19418 L .79307 .19832 L p F P
0 g
s
.907 .824 .753 r
.79307 .19832 m .79024 .19418 L .79502 .18678 L p F P
0 g
s
.845 .822 .826 r
.78504 .20679 m .79209 .19961 L .78912 .19564 L p F P
0 g
s
.934 .814 .703 r
.79557 .17567 m .79848 .17982 L .79502 .18678 L p F P
0 g
s
.96 .802 .641 r
.79848 .17982 m .79557 .17567 L .79792 .16909 L p F P
0 g
s
.817 .816 .848 r
.78504 .20679 m .77923 .21187 L .77623 .20786 L p F P
0 g
s
.817 .816 .848 r
.77623 .20786 m .78221 .20265 L .78504 .20679 L p F P
0 g
s
.845 .822 .826 r
.78912 .19564 m .78221 .20265 L .78504 .20679 L p F P
0 g
s
.744 .793 .893 r
.76767 .21327 m .76305 .21596 L .76002 .2119 L p F P
0 g
s
.682 .771 .919 r
.74668 .2173 m .76002 .2119 L .76305 .21596 L p F P
0 g
s
.905 .82 .752 r
.79209 .18264 m .79502 .18678 L .79024 .19418 L p F P
0 g
s
.934 .814 .703 r
.79502 .18678 m .79209 .18264 L .79557 .17567 L p F P
0 g
s
.744 .793 .893 r
.76002 .2119 m .76469 .20918 L .76767 .21327 L p F P
0 g
s
.759 .798 .885 r
.77322 .20379 m .76469 .20918 L .76767 .21327 L p F P
0 g
s
.759 .798 .885 r
.76767 .21327 m .77623 .20786 L .77322 .20379 L p F P
0 g
s
.882 .82 .783 r
.79024 .19418 m .78912 .19564 L .78613 .19157 L p F P
0 g
s
.882 .82 .783 r
.78613 .19157 m .7873 .19005 L .79024 .19418 L p F P
0 g
s
.905 .82 .752 r
.79024 .19418 m .7873 .19005 L .79209 .18264 L p F P
0 g
s
.843 .818 .825 r
.78221 .20265 m .78912 .19564 L .78613 .19157 L p F P
0 g
s
.816 .812 .847 r
.78221 .20265 m .77623 .20786 L .77322 .20379 L p F P
0 g
s
.816 .812 .847 r
.77322 .20379 m .77926 .19854 L .78221 .20265 L p F P
0 g
s
.843 .818 .825 r
.78613 .19157 m .77926 .19854 L .78221 .20265 L p F P
0 g
s
.25 Mabswid
.80488 0 m
.97794 .26024 L
s
.97794 .26024 m
1 .44134 L
s
1 .44134 m
.82069 .18956 L
s
.82069 .18956 m
.80488 0 L
s
.02168 .27949 m
0 .45986 L
s
0 .45986 m
.82069 .18956 L
s
.82069 .18956 m
.80488 0 L
s
.80488 0 m
.02168 .27949 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 379.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Nb000`400?l00000o`00003ooooonf[>
oookJP;o0000LOoonfX00?oooo]ZbooonfX3o`000003oookJ_l0003ooo]Z073ooo]Z003ooookJ/So
oo]Z0ol00004oookJP;o0000L?oonfX00?oooo]ZaOoonfX3o`0000Oooo]Z00?o0000oookJ_l00000
KooonfX00?oooo]Z`_oonfX3o`0000[ooo]Z00?o0000oookJ_l00000KooonfX00?oooo]Z`?oonfX2
o`0000gooo]Z00Co0000oookJ_oonf[o0000K_oonfX00?oooo]Z_OoonfX3o`0000oooo]Z00Go0000
oookJ_oonf[ooo]Zo`00001]oookJP00oooonfZjoookJP?o00004ooonfX01?l0003ooo]ZoookJ_l0
001]oookJP00oooonfZgoookJP?o00005_oonfX01Ol0003ooo]ZoookJ_oonf[o000006cooo]Z003o
oookJ[Cooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0JOoonfX0
0?oooo]Z/OoonfX3o`0001cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP1Yoook
JP00oooonfZ_oookJP;o00007ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z06So
oo]Z003ooookJZcooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
IooonfX00?oooo]ZZOoonfX3o`0002Cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP1WoookJP00oooonfZVoookJP?o00009ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z06Kooo]Z003ooookJZ?ooo]Z0ol0000ZoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX0IOoonfX00?oooo]ZXOoonfX2o`0002gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP1UoookJP00oooonfZNoookJP?o0000;ooonfX00ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z06Cooo]Z003ooookJY_ooo]Z0ol0000boookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX0HooonfX00?oooo]ZV?oonfX3o`0003Kooo]Z00?o0000oookJ_oonfX01ooonfX0
0ol0003ooo]ZoookJP1SoookJP00oooonfZEoookJP?o0000>OoonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z06;ooo]Z003ooookJY?ooo]Z0_l0000loookJP03o`000?oonf[ooo]Z00Wo
oo]Z00?o0000oookJ_oonfX0HOoonfX00?oooo]ZT?oonfX3o`0003kooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP1QoookJP00oooonfZ=oookJP?o0000@OoonfX00ol0003ooo]Zoook
JP0:oookJP03o`000?oonf[ooo]Z063ooo]Z003ooookJX[ooo]Z0ol00014oookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX0GooonfX00?oooo]ZQooonfX3o`0004Oooo]Z00?o0000oook
J_oonfX02ooonfX00ol0003ooo]ZoookJP1OoookJP00oooonfZ4oookJP?o0000B_oonfX00ol0003o
oo]ZoookJP0<oookJP03o`000?oonf[ooo]Z05kooo]Z003ooookJX;ooo]Z0_l0001=oookJP03o`00
0?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0GOoonfX00?oooo]ZOooonfX3o`0004oooo]Z00?o
0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP1MoookJP00oooonfYloookJP?o0000D_oonfX0
0ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z05cooo]Z003ooookJWWooo]Z0ol0001Eoook
JP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0FooonfX00?oooo]ZM_oonfX3o`0005Wo
oo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP1KoookJP00oooonfYdoookJP;o0000
G?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z05[ooo]Z003ooookJW7ooo]Z0ol0
001NoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0FOoonfX00?oooo]ZK_oonfX3
o`00067ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP1IoookJP00oooonfY[oook
JP?o0000I?oonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z05Sooo]Z003ooookJVSo
oo]Z0ol0001WoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0EooonfX00?oooo]Z
I_oonfX2o`0006[ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP1GoookJP00oooo
nfYSoookJP?o0000K?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z05Kooo]Z003o
oookJV3ooo]Z0ol0001_oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0EOoonfX0
0?oooo]ZGOoonfX3o`0007;ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP1Doook
JP00oooonfYJoookJP?o0000MOoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z05Co
oo]Z003ooookJUOooo]Z0ol0000NoookJPoo0000BooonfX00ol0003ooo]ZoookJP0FoookJP03o`00
0?oonf[ooo]Z05?ooo]Z003ooookJUGooo]Z0_l0000DoookJPgo00000_n1[?000ol0003oOj_`o`00
0005ogNWl0;o00000om]XO08o`0004Cooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Zoook
JP1BoookJP00oooonfYBoookJP?o00004ooonfX3o`0000;oUkO^00?o0000ohZakol000001On:/>l0
0ol0003oPJc`oh6/l003oh6/l003o`000?moZo3o000000GoMjO`0_l00005offQl0;o00000omRVnl6
o`0003kooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP1BoookJP00oooonfY?oook
JP?o00004_oonfX4o`0000KoUkO^00?o0000ohZakol000000_n:/>lMo`000005of:Kkol0003oGi[_
o`000?mHUNh01_l0000hoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0DOoonfX0
0?oooo]ZC?oonfX3o`0001;ooo]Z0ol00003ojBljP03o`000?nG]nkoUkO^00GoUkO^1?l00004ohZ`
k`03o`000?n1Zo3oPJ_`00;oPJ_`00?o0000oh2[l?l000001OmgY_000ol0003oMZG`o`000004offQ
l0;o00000omSVnl6o`000004oeREk_l0003oE9?^oeBCkPGo0000=?oonfX00ol0003ooo]ZoookJP0H
oookJP03o`000?oonf[ooo]Z053ooo]Z003ooookJTWooo]Z0ol0000BoookJP?o00001onT_>X4o`00
00CoUkK]0_l00003ohZ`k`Oo000000?oPJ_`o`000?l000001Ol000000omgY_3o0000o`000003o`00
00;oKJ7`0_l00004of>Kk`03o`000?mQVNoo000000;oFIG^1_l00002odR<k0Co0000<?oonfX00ol0
003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z053ooo]Z003ooookJTOooo]Z0_l0000CoookJP;o
00000_nha><00ol0003oY;cZojBljP03o`0000?oY;cZ00?o0000oiNfkOnG]^d01OnG]^d4o`0000?o
RZo_00?o0000oh6[kon1Znl00_n1Znl01?l0003oP:[_oh2Zkol00004ogRUk`03o`000?mfYNoo0000
00?oKZ3_2ol00002oeVEkP03o`000?mFTngoEY?]00Co000000CoB8c/o`000?l0003o>X;X0_l0000^
oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0CooonfX00?oooo]ZA?oonfX3o`00
01Cooo]Z00?o0000okS4honha><00onha><2o`0000OoY;cZ1?l00004oiNfk@;o00001On:[nl00ol0
003oPJ__oh6[k`02oh6[k`03o`000?n0Z^oo000000?o00000_mhYNl00ol0003oMZG_o`000004ofjP
k`03o`000?m/Wnoo000000?oI9[^00?o0000of:Ik_l000002?l000000om9Rn_o0000odR<k002o`00
00;o>X;X0ol0000[oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0C_oonfX00?oo
oo]Z@OoonfX3o`0001Gooo]Z0_l00004okS4h`03o`000?nha>?o000000CoY;cZ0ol000000onT_>[o
0000oiNfk@07oiNfk@go000000?oP:W_o`000?mhYNl00_mhYNl>o`000004ofBJk_l0003oHYW^o`00
00;oFYC]00?o0000oeNBkOmGT^d00ol00003odV;j`Go000000?o=7oWo`000?l000000_l0000Woook
JP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0C_oonfX00?oooo]Z?_oonfX3o`0001Oo
oo]Z00?o0000okS4honha><00_nha><00ol0003o^<CSokS4h`02okS4h`04o`000?nT_>[o0000o`00
00GoY;cZ00?o0000oiNfkOnG]^d00ol00002oiJek@03ohZ_k_l0003oRZo^00GoRZo^00Go0000oh6Z
kon1Z^ooPJ[_o`000002oh2Yk`03o`000?mhYNooN:G_00;oN:G_00?o0000ogNTkol000001Om^Wnh2
o`0000?oII[^1Ol000001_mJU>go0000oeNBkOmGT^go0000oe2>k0?o000000CoBH_[o`000?l0003o
>h;X0ol000000ol]N^Go0000ob9ch@02o`0002Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003o
oo]ZoookJP1=oookJP00oooonfXkoookJP?o00006OoonfX01?l0003oc<WGo`000?nha><2o`0000Ko
^<CS00?o0000ojBlj_nT_>X01_nT_>X2o`0000KoU[G]00?oRZo^o`000?n:[nh00_n:[nhFo`000003
ofjOk_l0003o000000?oII[^00?o0000of:HkOl000000_mKU>d6o`0000?oBh_[1Ol00002ocMoi`04
obejiOl0003o8W?Qob9ch@?o00008_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z
04cooo]Z003ooookJSWooo]Z0_l0000KoookJP05o`000?oGblko0000olc9eol000001?nha><3o`00
00;o]lCS00?o0000ojBlj_nT_>X00ol00002ojBkjP03o`000?nF]NgoU[G]00GoU[G]1Ol00003ohV^
kP05o`000?n1ZNkoPJW^oh6Yk_l000000on0ZNh00ol0003oN:C^ogRTkP02ogRTkP03o`000?mgXnko
000000CoKio^2Ol00002oe^Dk@03o`000?mHT^coF9;/00Go000000?oBh_[o`000?l000000_lmP^L0
0ol0003o=goWocMoi`04o`0000;o6fkO00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0L
oookJP03o`000?oonf[ooo]Z04cooo]Z003ooookJSKooo]Z0ol0000LoookJP08o`000?oGblkoel_>
omO;c_l0003oc<[Ho`000?nha><2o`0000Ko]lCS0_l00006ojBkjPCo00001?nF]>`00ol0003oRJk^
ohV^kP02ohV^kPoo000000?oN:C^o`000?l000000ol00002ofnOkP;o00000omUVNd00ol0003oHiS]
of>Hk@04o`000005oeRBk?l0003o0000oe6>jol000000_m<R^X3o`000003ocf2iol0003o>7oV00?o
000000?o9G?Qo`000?l000000ol0000PoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oo
nfX0BooonfX00?oooo]Z<ooonfX3o`0001kooo]Z00Co0000omO;c_oGblkoel_>0_l000000oo<b]So
0000o`000004okO4h`?o000000Co]l?To`000?nT^n[oY;_Z0ol00003oj>kjP03o`000?nF]>coU[C/
00GoU[C/1?l00003ohJ/kP05o`000?n1ZNkoPJW^oh6Yk_l000000on0Z>h00ol0003oN:?^ogRSkP02
ogRSkP03o`000?mgX^go000000?oKik]1_l000001omUVNgo0000of>HkOmSV>go0000oebCk?l00000
0_mITN`5o`000003odb:j_l0003o000000?o00000_lhOnH2o`000003obEchOl0003o7VkO00Co0000
7ooonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z04[ooo]Z003ooookJS3ooo]Z0ol0
000PoookJP05o`000?oGblkoel_>omO;c_l000000_oGcLl01Ol0003obl[Iol_:fOl0003o]lCS00;o
00001Ong`n@2o`0000OoXk_Z1?l00003oiBdk@03ohJ/k_l0003oQZc^00GoQZc^00Go0000oh6Yk_n1
ZNkoPJW^o`000003oh2XkP03o`000?mhXnkoN:?^00;oN:?^00?o0000ogNRkOl000000om_W^d00ol0
003oKYg]o`000003ofJIk0Oo00000_mITN`01_l0003oDXg[o`000?m=R^Wo0000odb:jP;o000000?o
?h;Wo`000?l000000ol000001?lWLn7o0000o`000?lNK]l2o`000003o`EMe_l0003o000001gooo]Z
00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP1:oookJP00oooonfX]oookJP?o00008ooo
nfX2o`000003omO;c_l0003oelg?00;oelg?00Go0000ol_:fOo;b]Wobl[Io`000004okO3i0;o0000
0_nf`n@00ol0003oXk_Zoj>kjP03o`0000;oX[[Z00?o0000oiBdkOnD]>d01OnD]>d00on6[>ko0000
ohJ/kP02ohJ/kQWo00000omVVN`01?l0003oI9O/ofBGk?l00002oefCj`Co000000?oDXg[o`000?m=
R^T00_m=R^T4o`0000;o>WoV0ol000001OlWLn7o0000o`000?l0003o25kF00?o00007?oonfX00ol0
003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z04Wooo]Z003ooookJR[ooo]Z0ol0000UoookJP04
o`000?oTbkkoi<^no`0000?oelg?00Co0000omS?dOl0003obl[I0_l00003okO3i003o`000?nf`nCo
]/?T00?o]/?T0_l00006oj:jjP03o`000?nD]>goU;C]00;oU;C]0_l000000onD]>go0000o`000002
o`0000CoRJc]00Co0000oh6XkOn1Z>go00000on0Ynd01Ol0003oN:?]ogRSkOmhXngo000000;oMj;]
00Go0000og2MkOm`WNgoL9g]o`000002ofjLk0So000000CoGI?[o`000?mJTN_oFY7[2?l00002od62
i`05o`000?ljOnKo>WoVo`000?lYLn400_l00002ob1^g`03o`000?l8G]Ko25kF00?o00006_oonfX0
0ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z04Sooo]Z003ooookJRSooo]Z0_l0000Woook
JP05o`000?oTbkkoi<^nonC;__l000000_oGcLl01Ol0003of<oAomS?dOoHcm7o000000;ob/_J0ol0
0004okK3i003o`000?nd`^Go000000SoX[[Z1?l00003oiBck@;o00001on9[>dAo`000005og2MkOl0
003oKYc/ofjLk?l000000_mWV>`00ol0003oI9K[ofBFj`04o`000004oeZAjol0003o0000o`0000?o
CXWY0ol000000om1P^Oo0000od:2i`03o`0000;o:G?Q0_l000001OlHJMco0000o`QNe_l0003o05OB
00;o00006OoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z04Sooo]Z003ooookJRGo
oo]Z0ol0000YoookJP;o000000?oi<^no`000?oVc[l00_l00003omS?d@;o000000?ob/_Jo`000?l0
00001?nf`n@00ol0003o]<;UokC2i@02okC2i@03o`000?nR^^[oX[[Z00?o00000onQ^NX00ol0003o
U;?]oiBck@04oiBck@Go00000on9Zn`01?l0003oP:O]oh2WkOl00003oh2Vk@05o`000?mhX^goN:;]
ogRRkOl000000_mgXN`01?l0003oL9g/og2Mk?m`WN`6o`000007ofNHk?l0003oI9K[ofBFjol0003o
GY;[o`000003oe^@jP?o00000_m>RNT00ol0003oBHKXo`000002o`0000?o@X;W0ol000001olSK]oo
0000o`000?l;G]Ko25kFo`000?l0Em800ol0000GoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000
oookJ_oonfX0AooonfX00?oooo]Z8_oonfX3o`0002cooo]Z00?o0000ono8Zol000000_oVc[l01Ol0
003of<oAomS?dOoHcm7o000000;of=7B00Go0000olW;foo9bm_o0000okK3i002o`0000Ko]<;U0_l0
0007oj6ijP?o00000onC/^d2o`0000OoRJ_/00Co0000oh2WkOn0Yngo00000on0Y^d01Ol0003oN:;]
ogRRkOmhX^go000000;oMj7/00Go0000og2Mk?m`WNcoL9g/o`000002ofjKk003o`000?mWUn_oIiO[
00Go000000?oGY;[o`000?mKT>X00_mKT>X01Ol0003oChWXo`000?l0003oCXWY00;o00000_m2P^H4
o`000003ob]chOl0003o000000;o8fkO1_l000000ol0=;Wo0000oookJP0EoookJP03o`000?oonf[o
oo]Z027ooo]Z00?o0000oookJ_oonfX0A_oonfX00?oooo]Z7ooonfX3o`0002kooo]Z00Ko0000ooK3
U_l0003ol<^[o`000?oVc[l2o`000003omS?dOl0003of=7B00;of=7B0_l000000oo9bm_o0000o`00
0004okC2i@?o000000Co//;Uo`000?nQ^N[oXKWZ1?l00002oj2hjP03o`000?nC/^goTk;]00CoTk;]
2?l000000on9Znco0000o`00000Do`000003ofNGjol0003oIIK[00;oIIK[00?o0000oejBj_l00000
0ol000000omKT>[o0000odn9j002odn9j0Go00000_lnO^D2o`0000;o:g?Q2?l000000ol0@lCo03Bi
o`00000EoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0A_oonfX00?oooo]Z7?oo
nfX3o`00037ooo]Z00Ko0000ooK3U_l0003o0000oo3;Zol00002onOA`@05o`000?oHdM;of=7BomSA
d_l000000_oHeMH01Ol0003oal_MolO;gOl0003o]<;U00;o00001Onb`^D2o`0000OoX;SZ1Ol00000
0onC/^go0000o`000007ohV[k003o`000?n0Y^co000000CoOjK/00Co0000ogRQk?mhXNco00000omg
X>`01Ol0003oL9c[og2Ljom`W>_o000000;oKi_[2Ol00003of2BjPGo000000?oChWXo`000?l00000
0_m4PNH2o`000003ociniOl0003o;G?P00;o00000_l/Ln42o`000007o`eOeol0003o0USBo`000?l0
=[_o02N_o`00000DoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0AOoonfX00?oo
oo]Z6_oonfX2o`0003Cooo]Z0ol000001_ohaYKo0000oo7=[Ol0003oim71o`0000;of=7B00?o0000
omSEe_oHeMH00_l00002olO;g@;o00001?nb`^D2o`0000;o/<7V00?o0000oj2hj_nP^>X00ol00002
oijgjP03o`000?nB/NcoT[7/00?oT[7/00?o0000oi>ajol000001?n9Zn`2o`000003ohV[k?l0003o
000000go00000om`W>/01_l0003oKi_[ofnKjol0003oJ9O[o`0000?oIYGZ1_l000000omPT^[o0000
oe28i`02oe28i`?o000000?oA87Vo`000?loO^@00ol00002obech0;o000000[o;7?Qo`000?l@GmOo
0000o`EHdol0003o04C5o`0f^ol09joo00004ooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oo
nf[ooo]Z04Cooo]Z003ooookJQOooo]Z0ol0000foookJP05o`000?oj^Wgo0000ooS6U_l000000_oa
cJd01?l0003oimC2o`000?l00002omSEeP03o`000?oFd]Coe];D00;o00000_o5bmh01?l0003o//;U
o`000?l00005ok31iP;o00001_nN]nX01_l0003oT[7/oi:ak?nB/Nco0000oi:ak0Ko00000on8Z^/0
0ol0003oP:G/o`000004ognUk004o`000?mhX>_oN:3[o`0000?oMio[2Ol000000omXUn_o0000ofJE
jP02ofJEjP03oenAjOl0003oG8oX00;oG8oX1?l00002oe28i`05o`000?m<QNKo0000odB1i_l00000
0oloO^@3o`000003obQ_g_l0003o000000;o45oG00Oo0000o`EHdol0003o04C5o`0f^ol09joo0000
01;ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP14oookJP00oooonfXDoookJP?o
0000>OoonfX01?l0003on[Ymo`000?ohaYH2o`000004oo7=[Ol0003o0000o`0000;of=GF00Go0000
omKBe?oFd]Coe];Do`000003olG;gP;o00000on``NH3o`000003ojjoi_l0003oW[OZ00OoW[OZ0ol0
0002oi6`k004o`000?nB/>_oT[3[o`0000KoR:[[00?o0000oh2Uk?l000001?moYN`01?l0003oN:3[
ogRPjol00003ogNOj`04o`000?m`Vn_oL9_[o`0000?oKi[Z00?o0000ofRFj_l000001?l000000omO
TNWo0000oeb?j003oeb?j005o`000?mAR>Oo0000o`000?m@R>L00_l000000om6PNGo0000o`000003
o`000003oc1ch?l0003o000000;o:6oN00Co0000oa1Oeol0003o25WC1_l0000AoookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0@ooonfX00?oooo]Z4OoonfX3o`0003cooo]Z00Co0000
ooZjOOl0003o00000_oib9D01_l0003olLn^o`000?l0003of=GFo`0000?oe];D0_l000001_o5bmko
0000o`000?o3b]oo0000ok31iP;o00001On^_nH00ol0003oW[OZoijgjP03o`0000?oWKKY00Ko0000
oi6`k?nA/>coTK3/o`000?nB/>/8o`000003ohRZjol0003o000001Go00001?mVU>T00omPTNWo0000
o`000002o`0000;oG8oX00Co0000oe68iomAR>OoDHSW1?l00003od1mi0;o00000_l`Ln03o`000006
oa=Peol0003o0000o`QIdol0003o04G61?l0000@oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX0@_oonfX00?oooo]Z3_oonfX3o`0003oooo]Z0_l000001?ok_7_o0000ooW8UOoib9D2
o`0000;olm>^00Go0000omKBe?oFd]Coe];Do`000002omCCe`04o`000?o3b]oo`l[Ool?:g`;o0000
2?n^_nH2o`0000OoWKKY1Ol00002oi2_j`03o`000?n8ZN_oR:W[00GoR:W[00?o0000ognTjomoY>/0
1?moY>/2o`0000CoMik[00Co0000og6Kj_maVn[o00000om_VNX6o`000003ofJDjOl0003oGHkX00;o
GHkX1ol00002odj5iP?o00000_m0ON@4o`0000;o:VoN00?o0000oa=PeolCH=L00_l000001_l0C/co
03Vmo`0Z/ol0:[?o001oo`00013ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP12
oookJP00oooonfX<oookJP;o0000@_oonfX2o`000006oo^lNol0003o0000o`000?okbiCo00000_oc
djh2o`000004omKBe?l0003oe=?GomCCe`;o00000_o3b]l01?l0003o`LWQol79hOl00002ojjoiP?o
00000on/_^L00ol0003oWKKYoiffj@03o`0000;oW;CY00Co0000oi2_k?n@[nco00001?n@[n/01?l0
003oR:W[ohRYjon8ZN/3o`000003ohRYjol0003o000000[o000000GoMik[o`000?maVn[oLI_Zo`00
0003ofnIjP03ofVFjOl0003oJiKY00;oJiKY1_l000000omMS^So0000o`000002oe:7iPGo000000Go
@WgSo`000?l0003o@7gTo`000002oc9ch0Ko000000Co2UWCo`000?l0AlSo03Vm0_l0:[<00ol007oo
0000oookJP0>oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0@OoonfX00?oooo]Z
2OoonfX3o`0004Cooo]Z1?l000001?om_gWo0000oo_;U?l00002oo?C[P06ooCF/?l0003o0000o`00
0?oDdmOo00000_oBe=X2o`0000?o`LWQ0ol00007ojbni`;o00001_nL]>T00ol0003oT:o/o`000008
o`0000CoQjS[00?o0000og^Qj_mkXNX01?mkXNX00omhWn[o0000ogNNjP02ogNNjPSo000000?oKiWZ
ofVFjOl000001Om[U^T00ol0003oGHgWoef=i`04o`0000;oDXOV00?o0000odn5iOm?QND00_l00003
od9mh`;o000000?o<W?Po`000?l[K]d00_l00002oaMQe`06o`000?l:FM?o0000o`17b?l0>Kgo02Zc
0_l0000?oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0@?oonfX00?oooo]Z1_oo
nfX3o`0004Oooo]Z0_l000001Ook/5oo0000oofoNOl0003onl^D00?o000000Gom=J`o`000?oVe/Ko
i]K6o`000003om;DfP03o`000?o1bN7o`LWQ00;o00000_nnb>800ol0003o[;kWojbni`03o`0000;o
ZKcW00?o0000oibdjOnL]>T01OnL]>T2o`000003ohn^jol0003oSjk[00?oSjk[00?o0000ohNXjon7
Z>/01?n7Z>/00ol0003oNj7Zog^QjP05og^QjP03ogROj_l0003oMikZ00CoMikZ00?oLI[Yo`000?mc
V^T00_mcV^T6o`0000;oJiKY00?o0000oef=iomMSNL00_mMSNL01_l0003oFX_Vo`000?l0003oDXOV
o`0000;oChGU00?oBH7To`000?l000000_l000001?lkN>7o=7?Ooc9ch?l00002ob]^g@04o`000?lG
HMOo3EWCo`eId`?o000000Co03Vmo`0FX_l02YOo00003_oonfX00ol0003ooo]ZoookJP0VoookJP03
o`000?oonf[ooo]Z043ooo]Z003ooookJP?ooo]Z0ol0001:oookJP;o000000?onk1Oo`000?l00000
0_l000001?olcYCo0000ooCF/?ode[02o`000008onKFa_l0003od]CJo`000?o?eMgo0000ol79hOl0
0004okk8hP?o00001_nY_>L4o`0000CoV[?Y00Co0000ohn^jon?[^_o00000_n?[^/7o`000003ohNX
jol0003o000001?o000000?oLi[Yo`000?mVT^P00_mVT^P6o`0000;oGHgW0_l00002oeB7i@?o0000
00CoChGUo`000?m2O>;o@WcR0ol000000oldLmoo0000o`000002o`000004oaYReolGHMOo3EWCo`eI
d`;o04S80ol000000ol006Wo0000oookJP0<oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX0?ooonfX00?oooo]Z0ol0001=oookJPCo000000Conk9Ko`000?l0003oo<jD0ol00002ooCJ
/P03o`000?oTelWo000000?ocmGM00Co0000okk8h_nnb>;o_/SR0_l000001?nkd>Wo0000ojVlionY
_>L3o`0000;oYk_W00?o0000oiZcjOnJ/nT01_nJ/nT5o`0000;oSZg[00?o0000ohJWj_n6YnX00on6
YnX2o`0000OoOj;Y00?o0000ogNLjOmgW>T01?mgW>T00ol0003oKiOXofnGj002ofnGj0?o00001?mV
T^P2o`0000?oGXgV1?l000001?mDQnGo0000oeB7iOmDQnD4o`000003od9lh_l0003o?GSQ00;o0000
0_l]K]d2o`000006oaYReol0003o3EWCo`000?l0B<So03^o0_l0;KH00ol008Ko0000oookJP0<oook
JP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0?_oonfX00?cooo]Z0ol0001AoookJP?o
000000?onk9Ko`000?l000000_l000001_omdY?o0000ooCJ/_odf[;o0000onCGb@;o000000?ocmGM
o`000?l000000_nnb>800ol0003o^m3Yok_@j@02ok_@j@;o00001_nW^nL00ol0003oV[?YoiZcj@03
o`0000;oVK;Y00?o0000ohf]jol000001On>[N/00ol0003oQZOZohJWjP03ohJWjP;o00001_moX^T0
0ol0003oMicYogNLj@05ogNLj@03o`000?m_UnSoKiOX00?oKiOX00Co0000ofNBiomWT^OoIi;W0_mV
T^P2o`0000?oGXgV00?o0000oe^;i_l000001?l000001omDQnGo0000o`000?m3Nn7o0000od9lh_l0
00000_lfLml2o`000009obe^gOl0003o0000o`000?l?F]?o3EWCo`000?l0B<So03^o00;o02ff00?o
001Yo`000?oonfX02ooonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z03kooo]Z003j
oookJP;o0000E?oonfX6o`000008ook3Lol0003ooM:Co`000?odf[;o0000ooGM]?l00002on7Gc@03
o`000?o<e^7o000000;o00001?nkd>T00onja^?o0000ojNki`07ojNki`;o00001_nI/^T00ol0003o
SJg[o`00000Io`000004ogNLjOl0003o0000o`0000CoKiOX00?o0000ofNBiomWT^L00_mWT^L00ol0
003oII3Vo`000006o`000003oeF7iOl0003oDXCT00?o00000om3Nn42o`000005ocIcgol0003o;fkL
o`000?l]K]d00_lLH]L5o`000004o`0k_ol0;KKo0000o`0000cooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP0moookJP00mooonfX3o`0005Kooo]Z0ol000001?ofXSko0000o`000?on
`g<2o`000007ookETol0003o0000ooGM]?l0003ohMO=o`000002omgGd@04o`000?nkd>Wo^m3Yok_@
j@;o00000onja^<00ol0003oYk_WojNki`03o`0000?oYKWX00?o0000oiVbjOnI/^T01OnI/^T2o`00
00KoRj[Z00Go0000ohFVj_n5Y^[oQJKZo`000002ohJUj@03o`000?mnXNWoOZ7Y00?oOZ7Y0_l00005
ogNKj003o`000?m_U^OoKiKW00;oKiKW00?o0000ofnGj?l000000ol00002ofNBi`;o00000omOS>H0
1_l0003oG8[Uoeb:iOl0003oEHOUo`0000?oDXCT00Co0000od=khOm3Nn7o00000_loN>002?lfLmoo
0000obm^g?l_K]co0000oaaReol0003o4U[B0_l000001?l4DLko03c0o`0k_ol0;KH2o`0000_ooo]Z
00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0loookJP00m?oonfX3o`0005Wooo]Z0ol0
00002OofXSko0000o`000?l0003oolI`o`000?oneI?o0000ooGM]003o`0000?ogMOA0_l000000onk
d>Wo0000ok[6h`05ok[6h`;o00001onU^NP4o`0000CoU[;[00?o0000oh^Zj_n;Z^X00_n;Z^X>o`00
0003ogjQjOl0003o000000?o00000omgVnP00ol0003oKiKWofnFi`03ofnFi`;o00000omXTNH5o`00
0004oen<i_l0003oG8[Uoeb:i@;oEXKT0ol000001?mBQ>Co0000odEkhOm5Nn43o`000003ocQdgol0
003o000000;o000000?o9fSIoaaReol000000_lBF]800ol0003o04_:o`0l`004o`0000[ooo]Z00?o
0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0loookJP00lOoonfX3o`0005cooo]Z1ol00000
1OooaW3o0000ookETol0003omMfd00;o00000ooMem42o`000003oloCg?l0003o^/KS00;o^/KS0ol0
0002okK4i003o`000?nU^NSoYKWX00?o00000onR]nP00ol0003oU[;[oiJbj`04oiJbj`Go00000on<
ZNP01?l0003oQJGYohFUjOl00003ohFTj003o`000?mnX>SoOZ3X00;oOZ3X00?o0000ogfOj?l00000
0omgVnL;o`0000?oJ97V00?o0000ofF?i_l000000_mOS>D4o`000004oeJ6i?l0003oDX?Soe:3h`?o
00000_m5Nn401?l0003oAG_Qo`000?l00002oc1]g0Go000000Co4U[Bo`iGdOl0003o03c10_l0<;P0
0ol008go0000o`000009oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0>ooonfX0
0>kooo]Z0ol0001PoookJPKo000000OoolI`o`000?l0003oo]VBo`000?oeh[Oo000000;ogMOA00?o
0000on7Qe?oQhM@00_l000000onja^?o0000o`000006okK4i0;o00001onR]nP3o`0000?oU;3Z0_l0
0007ohbYj004o`000?n5YNWoQJGYo`0000?oQJCX00?o0000ogjPj?mnX>P00_mnX>P00ol0003oOIoX
o`000004ogNKi`;o00001?m`U^L00ol0003oKYCVo`000007o`000003oen<iOl0003oH8cU00;oH8cU
0ol00002oe:3h`06o`000?m=On;o0000o`000?m5Nn7o00000_m5Nn42o`000003oc1]g?l0003o:FSI
00?o000000Ko4U[Bo`iGdOl0003o03c1o`0`^?l05J<3o`0000Sooo]Z00?o0000oookJ_oonfX0;?oo
nfX00ol0003ooo]ZoookJP0joookJP00k?oonfX2o`0006?ooo]Z1ol000000oonb6co0000ookITP02
o`000003ooGV^Ol0003o000000;ohN7D0_l000000oo;d]oo0000okK4i003okK4i0?o00000_nb`ND0
0ol0003oX[OXoj:gj003o`0000;oX;KX00?o0000oiB`j_nD/>X00onD/>X00ol0003oUZoXo`000003
ohbYj0;o000000?oS:WXo`000?l000005?l00004og2Fi`;o00000omXTNH00ol0003oIXoUofJ?i@02
o`000003oen<iOl0003oH8cU00;oH8cU00Go0000oe:2h_l0003o0000oe:3h`02o`0000;oAg_Q0_l0
00001om5Nn7o0000oc5]fol0003o<6gLo`000?lYJ=T00_l000001olDF];o0000o`000?l0003o036i
o`0`^?l05J<00_l00009oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0>_oonfX0
0>Wooo]Z0ol0001UoookJP03o`000?oEJ@3o000000Co000000?oo/Q/o`000?l000000_l000001Ooe
i[Wo0000on7Qe?oQhMCo000000;ognCH00Co0000olO@hOl0003o]/CT0_l00006ok;1i@;o00001_nP
]^P00ol0003oU;3ZoiB`jP08o`0000?oS:SX00Co0000ohBTj?n4Y>So00001?n4XnP01Ol0003oOYoX
ogjOj?mnWnSo000000;oOIkW00Go0000ogNJiomgV^OoMi[Wo`000002ogJIiPOo00000omXTNH01Ol0
003oIXoUofJ?iOl0003oH8_U00Co000000?oH8cUo`000?mBP^800_mBP^83o`000006odMkhOl0003o
@gSOo`000?m5Nn7o00000_laKM/2o`000003ob9SeolFF];o5U[B00;o35?>00Co0000o`0l`Ol0<KWo
032h0ol00008oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0>OoonfX00>Kooo]Z
0ol0001XoookJP03olUJ0?l0003o000000Go000000?ooLUVo`000?l000000_oei[T00ol0003ohN7D
o`000002omoTf0;o000000?oam3Qo`000?l000001?nb`ND3o`000003ojjoi_l0003oX;KX00KoX;KX
0ol00002oi:_jP04o`000?nD[^SoU:kXo`0000KoS:SX00?o0000ohBTj?l000000_n4XnP5o`000003
ogjOj?l0003oOIkW00;oOIkW00Go0000ogNJiomgV^OoMi[Wo`000002ogJIiP04o`000?m`UNKoL9GV
o`0000;oKY?U2Ol00003oej9h`;o00000omBP^800ol0003oCWoQo`000004o`000008od=hgol0003o
0000oc5]fol0003o<FcKo`000?lRHmL2oaIJdP;o35?>0_l000001?l0<KWo0000o`000?l00008oook
JP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0>?oonfX00>?ooo]Z0ol0001/oookJP03
olUJ0?l0003o000000Co000000OooLUVo`000?l0003omNJio`000?oal<3o000000;ognCH00Co0000
omOYh_l0003o00000_o2cN<01?l0003o//7Uo`000?l00005ojjoiPCo00001?nN]>L01_l0003oTZoZ
oi:_j_nB[n[o0000oiB^j0So000000?oS:SXo`000?l000000_l00003oh6Pi`03o`000?mmW^OoOIkW
00go000000?oL9GVo`000?m^TnD00_m^TnD00ol0003oJI3Uo`000003ofV@i@Co00000_mNRN<01Ol0
003oDh7Qoe>1hOmCPN7oDX;R00;o00000_m8Nn001?l0003o@gONo`000?l00002ocA]f`;o000000Oo
<FcKo`000?l0003o5U[Bo`iCc_l<Dlko03o300;o03:i00Co02Rbo`000?l0003o00001ooonfX00ol0
003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z03Sooo]Z003PoookJP?o0000L?oonfX6o`000004
oog9I_l0003onnF>o`0000;olO3000?o0000omoTf?l000000_oGjN801?l0003o`/gSol;=hoo2cN<2
o`0000?o[[oV0ol000000on[_>Ko0000oijdi`07oijdi`Go00000_nB[NP00ol0003oRZOXohZWj005
ohZWj003o`000?n1X>OoPJ3W00CoPJ3W00?o0000ogfNiol000001?mlWNL01?l0003oMiWVogNIi_l0
0003ogJHiP03o`000?m`U>Go000000Go000000?oJI3Uo`000?mYT>D00_mYT>D2o`000005oef7h_l0
003o0000oej9hol000000omCPN401Ol0003oCgoPodmoh?m8Nn3o000000?o@gON00?o0000ocA]fold
KM/00_l^J=P01olaK=_o0000oaUJd_lFF];o3U?>o`aCc_l0?l<00_l0<[T4o`0000Kooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0goookJP00g_oonfX2o`0007Cooo]Z1ol000000ook
iHko0000oo7``003o`0000;oenWR00?oeMkOo`000?o2cN<00_l000000onnb^Co0000ojjoiP02o`00
00GoZkcV00?o0000oijdionN]>L00ol00002oibbi`04o`000?nA[NWoTJgYo`0000CoTZgX00?o0000
ohZWj?n:YnP00_n:YnP2o`000003ohZWj?l0003o000000go000000?oMiWVo`000?mfV>H00omfV>H2
o`0000CoKY?U0_mYT>@4o`000003ofV@iOl0003oGHOR00?oGHOR1?l000001?mCPN7o0000odmoh?m:
Nml2o`0000;o@gON0ol000000oldKM_o;VSHobiXf002o`000006oaUJd_l0003o3U?>o`000?l0?l?o
03:i1?l00006oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0=_oonfX00=_ooo]Z
0ol0001foookJPco000000CoenWRo`000?oEg]ooeMkO0_l00003okk:i0;o00002?n[_>H2o`0000Ko
W;;W00?o0000oi6]jOl000002Ol00003ohVVi`03o`000?n3X>KoPj3V00CoPj3V00?oOIgVo`000?ml
W>H01?mlW>H2ogNHiP_o000000?oKY?UofV@i?l000000omWSN<2o`0000CoGHOR0_l00002oeB1h@Go
000000CoA7KMo`000?l0003o@gON0olfKMX00ol0003o;VSHo`000002o`0000;o45?>00?o0000o`11
a?l0?l<01Ol00005oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0=_oonfX00=So
oo]Z0ol0001ioookJP03okY80?l0003o000000Ko000000Con>B`o`000?l0003o00000ooEg]l01Ol0
003o_/[Tokk:i?nnb^Co000000;o^MC^00?o0000oj^li_n[_>H00ol00003ojNjiP03o`000?nL/^Oo
W;;W00GoW;;W00?o0000oi2[jOl000001?n@[>P00ol0003oRJKWohVVi`04ohVVi`;o00001_n3X>H0
0ommWNKo0000ogbLiP04ogbLiP03ogNHi_l0003oMYOU00?oMYOU0_m`U>D01?l0003oLI?Tog6Ci?ma
Tn@6o`000003ofN=hol0003oGXOR00;oGXOR00CoGHORo`000?l0003o00000_mDPN401Ol0003oE87P
oeB1h?m:Nmoo000000?oA7KM00?o0000ocI]f_lfKMX00_l_J=P01?l^J=So0000oaaKd_lLFm82oa1C
cP03o`000?l0@LCo000000Co00001OoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z
03Gooo]Z003EoookJP?o0000OOoonfX00onjB03o0000o`000005o`000009ooST/?l0003o0000o`00
0?oTh]7o0000oloOi?l0003o_/[T00;o00001?nie>h2o`0000OoYk[V1?l00003oiZ`i`03o`000?n@
ZnWo000000;oT:cX2?l000000on9Y^Oo0000o`00000Co`000003ogJGiOm`U>Go000000GoLI?T00Co
0000ofN<h_mWS>;oIhcR0ol00003oej7hP06o`000?mKQ>7oFhCQo`000?mDPN7o00000omDPN03o`00
0005odAfgOl0003o?W;KocI]f_l000000_l_J=P2o`000003oaaKd_lBDlgo45?>00Oo00001OoonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z03Cooo]Z003BoookJP?o0000POoonfX6o`00
0008oocLP?l0003onNZ]o`000?oTh]7o0000omkOe_o?gn@2o`0000Co^MC^00Co0000okS5i?nhaNCo
00000_nW^^H3o`0000;oY;OV00?o0000oiZ`ionJ/>L01OnJ/>L4o`0000?oSJSX00?o0000ohRTion8
Y>L00on8Y>L2o`0000OoPYoV00?o0000ogbJiOmlV^D01?mlV^D00ol0003oMIKTogFFi002ogFFi0Ko
00000_maTn@00ol0003oIhcRofN<hP03ofN<hPCo000000GoGXORo`000?mKQ>7o0000oeJ1h005o`00
00;oAGGL0ol000003OlhK][o0000o`000?l_J=So0000obIQe?l0003o75_Boa9CcOl@Dlko04?4o`00
0?ok/5X01?l00004oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0=?oonfX00<oo
oo]Z0ol00024oookJP03okY80?l0003o000000?o000000?oo=b0o`000?oijZd00_l00002omkOeP;o
000000?o^MC^o`000?l000001_nhaN@2o`0000KoY;OV1?l00004oiJ`j@03o`000?n=Z>SoSJSX00Co
SJSX00?o0000ohRTion8Y>L00_n8Y>L00ol0003oRJ?Vo`000006oh:OiP;o00001OmlV^D00ol0003o
MIKTogFFi004ogFFi004o`000?m^T>?oKY3Sofj@h`Ko00000_mWS>82o`0000;oGhKQ1_l00003oe9n
g`;o00000_m5MM`02?l0003oA7CLo`000?l0003o<6OGo`000?l_J=So00000_lOG=801Ol0003o4U?=
o`000?l0003onk1J00Co00001?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03?o
oo]Z003=oookJP;o0000R?oonfX5o`000004oocLP?l0003o0000o`0000;og]oF00Co0000on7^fOl0
003o00001?nhaN@3o`000004ok?2iOl0003oY;OVojBgiP?o00000_nQ]NH00ol0003oU[3YoiJ`j@05
oiJ`j@03o`000?n=Z>SoSJSX00;oSJSX6_l00004ogFFi0;o00001?m^T><2o`0000?oIh_R1?l00002
oen6h@03o`000?mLQ>3oG8CP00Co00000_mBO]l2odMfg004o`000?m5MMco0000odAdg0?o000000Co
<6OGo`000?l0003o7ecB0_lDDld00ol=C/_o0000o`000005o`0000?ooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP0boookJP00b_oonfX3o`0008[ooo]Z1ol000001?ogkk3o0000omkO
e_l00002on7^f@04o`000?o6dnCo0000okS5i0;o00001Onc`^D2o`0000KoXKGV00Co0000oiJ`jOnF
/>WoU[3Y0_l000000onF/>Wo0000o`000003o`0000?oSjOU00Go0000ohNSi_n7XnKoQj?Vo`000003
ohRRiP03o`000?n2W^GoPYkU00;oPYkU00?o0000oh:Mi?l000001?mlVN@2o`0000?oMIGS00?o0000
ogFFi?l000001?l00002ofj@h`;o00000omWRn800ol0003oIHWQofF9h@03o`0000;oG8CP0_mGPN00
1Ol0003oDWgNo`000?mBO]oo000000?oAgKL0_l000000om4M=co<FKFoc5VeP02o`000003obiUe_lO
G=;o000000;o55?=00?o0000ooblLol000001Ol00003oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o
0000oookJ_oonfX0<_oonfX00<Oooo]Z0ol0002>oookJPWo00000_oQk]T2o`000003olKCi?l0003o
000000Co/l;U0_l00002ojjniP03o`000?nQ]NKoXKGV00GoXKGV0ol00003oiB^j003o`000?nF[NOo
000000KoSjOU00?o0000ohNSi_l000003_l00002ogbIi003o`000?mkV>?o000000CoMIGS00?o0000
ogBChol000000om_T>85o`000008ofN;h_l0003oIHWQofF9hOl0003oH8KQo`000?mPQ^02o`000003
oeN1h?l0003oDWgN00;oDWgN0_l00002odMfg004o`000?m2L][o0000odAdg0?o<FKF1?l000000olD
Dlgo0000ooblL`06o`0000?ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0aoook
JP00a?oonfX3o`0009;ooo]Z1ol00002on7^f@04o`000?oDm>Go0000o`0000;o`<oU00Co0000ok?2
iOl0003o00001On^_^H4o`0000CoW[?V00Ko0000oiB^j?nD[^SoU:kXo`000?nF[NL8o`000003ohnW
iOl0003o000000GoQj7U00Go0000oh6MiOn1WNGoPIgUo`000002oh6Li003o`000?mkVNCoNiWT00co
00000om_T>800ol0003oKHkRo`000002ofR;h@?o000000CoIHWQo`000?mPQ^7o00000omPQ^05o`00
0004odiig?l0003oAgKLo`0000?o@W;J00?o0000oc5Ve_laI]H00_l/H]@01Ol0003o5U;<oaACcOl0
003oo;ac00;o000000?onk5Eo`000?l000000_l00002oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o
0000oookJ_oonfX0<?oonfX00<7ooo]Z0ol0002FoookJPCo000000Col_Bbo`000?oQk]Wo00000_oD
m>D01?l0003o`<oUol3?iOo0cnD2o`0000?o[[kV0ol000000onY^nKo0000oijciP07oijciPGo0000
0_nD[>L00ol0003oSZGUohjUi@04ohjUi@03ohNRi_l0003oQj7U00GoQj7U00Co0000oh6MiOn1WNGo
00000on1W>@01?l0003oNiWTog^Ii?l00002ogZGh`05o`000?mfU>?oMYCSogJDhol000000_mdT^88
o`000004ofR;hOl0003oJ8_QofR;h@Go00000_mPQ^001?l0003oDgcMoe=lgOmCO=d3o`000009odQf
fol0003o0000o`000?m2L][o0000ocAWe_laI]Ko000000;o;6;D0_l000001OokaHWo0000oofmL_l0
003onk5E00Co00000_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z002o
oookJP;o0000VOoonfX00ol007Wo0000o`000003o`000006on7^fOoDm>Goe?CUomCVhol0003o`<oU
0_l000000onkf_3o0000ojjniP02o`0000GoZK_V00?o0000oijci_nN/nH00ol00002oib`iP04o`00
0?nB[>SoTZcXo`0000CoU:cW00Co0000ohjUiOn>YNGoSZGU0_l000000on>YNGo0000o`00000Do`00
00;oMYCS00Co0000ogBBh_mdT^;o00000om_Sn800ol0003oKHkQoff>h@05o`0000;oJ8_Q0_l00000
0omLP]ko0000of26h002o`0000?oDgcM0_mBNm`2o`0000;o@g7I0ol000002OldImKo0000o`000?l/
H]Co6U?=o`000?okaHWo0000oofmLP07o`000003oookJ_l0003ooo]Z03Kooo]Z00?o0000oookJ_oo
nfX0;ooonfX00;cooo]Z0ol0002LoookJP03o`00Nol0003o000000;o000000?oe?CUo`000?oDi^<0
0ol00004ok_Jl003o`000?nY^nKoZK_V00KoZK_V0_l00006oib`iP_o00000on<YND00ol0003oQ9kT
ohBNi004ohBNi0?oPIcT00?o0000oh2Ki?n0Vn@00_n0Vn@2og^Hh`04o`000?mjUn?oNYOSogZGh`So
00000_m_Sn801_l0003oKHkQoff>hOm]S^7oJ8_Qo`0000;oIXSO0_l000000omXRn7o0000oeb2gP02
oeb2gPCo000000CoDgcMo`000?mBNmcoDW_L0ol000000om3LMWo0000oca[e`02o`000005obeQdol0
003o;6;Do`000?okaHT00ol000000oom_W3o0000o`000003o`000003oookJ_l0003ooo]Z03Oooo]Z
00?o0000oookJ_oonfX0;_oonfX00;Wooo]Z0ol0002OoookJP03o`000?l007_o000000?o00000_oD
i^<00ol0003o^m[`ok_Jl003ok_Jl0;o^LOU00?o0000ojVki_nY^nH00ol00003ojJhiP03o`000?nL
/>KoW;3V00CoW;3V00?o0000oi>[iol000001On@ZNH00ol0003oS:GUohbUi@03ohbUi@;o00001_n4
W^@00on1W>Co0000oh2Ki005oh2Ki003og^Hhol0003oNYOS00?oNYOS0_mfTn801?l0003oM9;RogBB
h_mdT^87o`000003off>hOmXRn7o000000CoIXSO0_l00002oeb2gP03o`000?mIOmgoE7cL00;oE7cL
0_l000001omBNmco0000od=_f?m3KmSo0000od=afOl000000_lfImH00ol0003o;F7CobeQd`03o`00
0003ooc6R?l0003ooKi`00Go000000?ooo]Zo`000?oonfX0=ooonfX00ol0003ooo]ZoookJP0^oook
JP00]_oonfX3o`000:;ooo]Z0ol000001?ogl:_o0000o`000?oQjMP2o`0000;o^m[`00?o0000okW7
iOnianD00onianD2o`0000OoY[SV0ol00004oiR`j0;o00000on@ZNH7o`000003ohbUiOl0003o0000
01?o00000_mjUn<00omfTn;o0000ogBBhP03ogBBhP;oKhoQ00Co0000og2>h?m`S^3oL8kP1_l00000
0omVR=oo0000oef2g@02oef2g@?o00000_mDO=`01Ol0003oDGWKo`000?mBNmco000000?o@foH0_l0
00002_lfImKo;V7BobiQd_l]HM?o0000ooG=Y?l0003oo<J8o`000?om_W02o`000003ooZaD?l0003o
000000;o0000>OoonfX00ol0003ooo]ZoookJP0]oookJP00/ooonfX3o`000:Gooo]Z00?o]g<0o`00
0?l008400_l00002on7Yf0?o00000onianD3o`0000;o/l?U00?o0000ojJhi_nV^>H00ol00002oj:e
i@03o`000?nH/>SoV;3X00GoV;3X1?l00003oi6Vi003o`000?n;XnGoRj?U00;oRj?U00?o0000oh^R
i?l000001_n5W^<00ol0003oP9WRoh2IhP04oh2IhP;o00000omjUN48o`000003ogBBh_m_Sn7o0000
00GoL8kP00Co0000ofJ7g_mVQmkoIXON0ol00003oef2g@05o`000?mJOmgo0000oeAlg?l000000omA
NM/01?l0003o@foHod=_f?m3KmP2od9^f004ocIWe_l0003o;V7Bo`0000;omLfT1_l000000ooj/E3o
0000o`000002o`0003[ooo]Z00?o0000oookJ_oonfX0;?oonfX00;7ooo]Z0_l0002YoookJP07o`00
F_l0003o0000o`000?oQjMSo0000on7gf002o`000003okW7iOl0003o000000Ko/l?U0_l00006oj:e
i@Co00000onF[^L00ol0003oTJKToi6Vi005oi6Vi004o`000?n;XnGoRj?Uo`0000?oRj;T00?o0000
ohFNhon5W^<00on5W^<2o`0000KoP9WR00?o0000ogZEhOmjUN400omjUN42o`0000CoM93P1_l00002
og2>h003o`000?mVQmkoIXON00;oIXON00Oo0000of>4gOl0003o0000oef2gOl0003oFWoM00;oEWcL
0ol000000omANM_o0000odE`f002od=_f003o`000?m2K]So000000?o000000?omLfTo`000?ofcZ<0
0_l000000oomahOo0000o`000005o`0003[ooo]Z00?o0000oookJ_oonfX0;?oonfX00:kooo]Z0ol0
002[oookJP05o`000?l006oo001To`00Pol000000_oQmmP3o`0000Co/l?U0ol000001?n^_^Ko0000
oj:eiOnR]ND3o`0000;oWk;U00?o0000oiJ^ionF[^L00onF[^L00ol0003oV:cUo`000004oi6Vi0;o
000000?oTJKTo`000?l000005Ol00004ogZEh@03o`000?mdT>3oM93P00CoM93P00Co0000off;gom]
RmooKH_O1_l000000omVQmko0000of>4g@03oej2g@?o000000CoEWcLo`000?mAN=[oDGSJ0ol00002
odE`f0;o000000Oo@VkHobmPdOl_H=7o0000ooG=Y?l0003om/jS00;o000000CooLN7o`000?l0003o
o[m]1?l0000koookJP03o`000?oonf[ooo]Z02_ooo]Z002[oookJP?o0000[_oonfX01Ol0003o001J
o`000?l0003o002300?o00000_nnd>P01?l0003o/l?Uo`000?l00005ojjniP;o00001_nO/^D00ol0
003oUZkWoiJ^i`09o`0000?oT:GS0_n:X^@00ol0003oRZ7SohZQh`02ohZQh`03o`000?n5WN?oQIgS
00;oQIgS00?o0000ohBLh_l000001OmoVN82o`0000?oNYCQ00?o0000ogZEhOl000000_l00004ogB@
h0;o00001?m]Rml2o`0000;oIhKN1?l00002oej2g@03o`000?mNPMcoGX7L00?o00000_mAN=X02ol0
003oC7?Ho`000?m5L=So0000od5/e_l0003o@VkHo`000?o_d;?o000000;om/jS1Ol000000oon_fgo
0000o`000002o`0003cooo]Z00?o0000oookJ_oonfX0:_oonfX00:Sooo]Z0ol0002aoookJP05o`00
@_l005[o001no`00Mol008T00_l07:@00ol0003o_]3Xokk@j002o`0000Co[[kV0_l00002ojVjiP03
o`000?nO/^GoWk;U00GoWk;U0_l00002oiB/iP04o`000?nFZnGoUZ_Uo`0000OoT:GS00?oRZ;To`00
0?n:XN<01?n:XN<01Ol0003oQIgSohFMhon5WN?o000000;oQ9cR00?o0000ognIh_moVN800_moVN80
0ol0003oOiOQo`000004ogZDh@;o00000omdSml00ol0003oM93Po`000004o`000004off;gol0003o
JhWNo`0000;oIhKN00Ko0000ofB4gOmTQ=go0000oej2gOl00004oej1g005oe9gfOl0003o0000oe5h
f_l000000_m7L=L2o`0000;o@FcF00?o0000ono@/ol000000_l00002ooO@X`03o`000?omc8ko0000
00Ko0000>ooonfX00ol0003ooo]ZoookJP0ZoookJP00YOoonfX3o`000;Cooo]Z0ol000000ol007ko
001go`00R@02o`0LY0;o00000_nhfo801?l0003o[[kVo`000?l00005ojVjiPCo00001?nM/>@00ol0
003oU:cVo`000002oiJ[i@So000000?oT:GSo`000?l000006ol00004ogB?g`;o00000om^Rmh5o`00
0004ofN6g_l0003oI8CMofB4g@;oGh7M1?l000000omNPMco0000oe9gf@02oe9gf@;o000000?oAg3G
od5[eOm1JmD00_l000001Oo_d;?o0000onoA/oo_dK?o000000;omm2S00?o0000oog<S_l000001_l0
000loookJP03o`000?oonf[ooo]Z02Wooo]Z002RoookJP?o0000]ooonfX7o`000003o`0LY?l0003o
^=_b00?o^=_b00Co0000ojVji_nY^^KoZK[V0ol000000onU]nGo0000oif`i007oif`i0Co00000_nB
Z>D00ol0003oSZCTohjTi005ohjTi003o`000?n7W^;oQikR00CoQikR00Co0000ohBLh_n4W>;o0000
0_n4Vn800ol0003oOiSQognHh@02ognHh@04o`000?mnU^3oOYKPo`0000?oNY?P00?o0000ogRBgomh
T]l01ol00003ofj;gP03o`000?m/RMkoK8WN00;oIhKM1?l000000omOPMgo0000oeamf`02oeamf`?o
00000_mBMmT3oe5ff006odM`eom1JmGo@F_Eo`000?o_d;?o00000_o_dK<00ol0003omm2SooO@X`02
o`0000;ooLf;1_l0000loookJP03o`000?oonf[ooo]Z02Sooo]Z002PoookJP;o0000^_oonfX03ol0
05Co0000o`000?l008Wo001no`08VOl00I3o0000o`0LY?l0003o^=_bo`000?nga^Ko0000ojVjiP02
o`0000GoYKOU00?o0000oif`i?nM/>@00ol00002oiV_i`;o00001OnBZ>D00ol0003oSZCTohjTi004
ohjTi003o`000?n7W^;oQikR00;oQikR2?l000001On4Vn;o0000ognHhOmoV>7o000000CoOYKP00Co
0000ogZCh?mjTn3o00000_mhT]l01?l0003oM8oOogB?gol00002og:=gPOo000000?oK8WNofN6gOl0
00000omWQM`3o`0000?oG7gK0ol000001?mBMmWo0000oe5ff?mAM]P3o`000006onOA`?l0003okm6c
onoA/ol0003ol=>c0_l000001?ohdJ;o0000oog=RoomcH/6o`0003cooo]Z00?o0000oookJ_oonfX0
:?oonfX009gooo]Z0ol0002koookJPCo000000?o001ao`000?l000000_l000000ol09:go0000o`00
0003okO6iP03o`000?nU]nGoYKOU00KoYKOU0_l00006oiV_i`04o`000?nBZ>GoTZSUoi:Xi@ko0000
0on8W^42o`0000?oPYSP3ol000001?mhT]oo0000ogB?gol00003og:=gP;oKX_N00Oo0000ofj9gOm^
RMgoKXWMo`000?mWQ]go000000CoIhGL00Ko0000oeamf_l0003o0000oeamfol00003oe=gf@;o0000
0_mAM]P00ol0003oim70onOA`002o`000006onoA/ol0003ol=>coo3C/ol0003on=6R0ol000000oon
cX_o0000o`000003o`0003gooo]Z00?o0000oookJ_oonfX09ooonfX009[ooo]Z0ol0002noookJP09
o`000?l006Co001Wo`000?l0077o00NIo`00Rol0003o012O00Go00000_n``NH00ol0003oYKOUojFg
i@03o`0000;oX[?U00Go0000oiV_ionI[nOoVJoWo`000002oiV_i`Go00000onBYN800ol0003oSJ?S
ohfSh`02ohfSh`03o`000?n=X^;o000000OoR9kQ00?o0000oh:Hh?n2V>000on2V>02ognGh@03o`00
0?mnU^3oOYKP00;oOYKP0omjTml00ol0003oNY;NogZBgP07o`000003og:=g_m^Rmko000000CoKXWM
1Ol000000omWQMco0000o`000003oeamfP;o00000_mCMmT01?l0003oCg?Go`000?l00002onOA`004
o`000?oXd/3oj=;0o`0000?ol=>c0_l00002ooWBXP03o`000?oncX_o000000Go0000?OoonfX00ol0
003ooo]ZoookJP0VoookJP00UooonfX3o`000<7ooo]Z0_l000002?l006Oo0028o`00R?l0003o00NI
o`00Rol0003o012O1_l000000on``NKo0000o`000006oj:ci@?o00000onG[NH2o`0000OoTZGR00Co
0000ohfShon=Xn?o00000on=X^801_l0003oR9kQohRNhOn8W^7o0000ohRNh@Oo000000?oPYSPognG
hOl000001OmnU^000omjTmoo0000ogZBgP03ogZBgP03o`000?mdSmko000000?oLXcM1_l00002ofj9
g@04o`000?mUP]_oIH;KofF2f`?o00000omLOMX02ol0003oFgcIoe]lfOmCMmWo0000odmceol0003o
hM78o`000?oWdL3o000000;oj=;000Ko0000oo3C/oo`dk?o0000oo7D/ol00002ooWBXPCo000000Co
o/AYo`000?l0003o0000?OoonfX00ol0003ooo]ZoookJP0VoookJP00U?oonfX3o`000<Cooo]Z00co
0000o`00D?l0003o0000o`00R?l0003o00NIo`000?l008?o01fZo`06U_l0:K82o`0RZ`?o000000Co
Zk_Uo`000?nR/nGoX[?U0ol000000onO/>Co0000oiN]iP03oiN]iP04o`000?nH[>CoV:cTo`0000Co
TZGR0_l000000onBYN;o0000o`000008o`0000;oQigQ00?o0000ohNKh?l000001?n3V=l>o`000003
ogZBg_l0003o000000GoLXcM00Co0000ofb7g?m/QmcoK8OL0ol00004ofF2f`06o`000?mROm[o0000
o`000?mLOM[o00000_mKO=T3o`000004omOAdol0003ohM78o`0000;oj=;000Ko0000onSD`Ol0003o
l=>co`000?oae;<3o`000005oo[DXOl0003oo/n9o`000?ona6T01?l0000moookJP03o`000?oonf[o
oo]Z02Gooo]Z002BoookJP;o0000a_oonfX2o`000008o`00F?l007co001do`00R?l008Wo001go`07
VOl008/2o`0MZP03o`06U_l0:K;o02:[00;o04;31Ol00005oin`i003o`000?nG[NKoUjgV00Wo0000
0onBY>42ohbQhP03o`000?n<XN;oS:7R00;oS:7R00?o0000ohNMhOn7WN400_n7WN401?l0003oQi_P
ohNKh?l00005oh>Hg`03o`000?mnU=koOYCN00CoOYCN00?o0000ogR@gOmhT=d00_mhT=d3o`0000Go
LXcM00?o0000ofb7g?m/Qm`00om/Qm`4o`000003ofF2fol0003oHWoJ00?oGGgI0ol000000omKO=Wo
0000omOAd`02omOAd`;o000000?oj=;0o`000?oXe<400_oXe<43o`000006oo;F/ol0003o0000oo[D
XOl0003oo/n90_l000001?ona6Oo0000o`000?l0000noookJP03o`000?oonf[ooo]Z02Cooo]Z002?
oookJP?o0000b?oonfX2o`000004o`00F?l007co0000o`00MPGo000000Ko01fZo`000?l0003o02Vb
o`0RZol0@/<2o`10`P03o`0j_?l0003oWk3T00KoWk3T0_l000000onEZ^Go0000oiJZi003oiJZi003
o`000?nBY>7oTZCQ00CoTZCQ00CoS:7Ro`000?n<XN;oS:7R4_l00005ogjDgP;o00001OmhT=d01?l0
003oLh_Log>;g?mcRm`2og:<g@Co000000?oK8OLo`000?mYQ=/00omUP]X4o`0000;oGGgI00Co0000
oeYif?mJNMSo00000ooGdM<00ol0003of=;Co`000006o`000004oo7D/ol0003ol]Jco`0000;on]BQ
0_l000000oood8Oo0000ook4I`03o`0003oooo]Z00?o0000oookJ_oonfX08ooonfX008cooo]Z0ol0
003;oookJPOo000000_o002>o`00ROl039go00:Fo`0S[_l07J[o00nOo`000?l0:K;o02:[o`12``02
o`10`P03o`0j_?l0003o000000;o00001?nM[^<00onEZ^Go0000oiJZi002oiJZi0So000000?oTZCQ
o`000?l000000_l00003ohZMh005o`000?n7W>3oQicPohNLh?l000000_n6Vml00ol0003oPYSOoh:H
g`02oh:Hg`03o`000?n2U]ko000000[o000000CoN93Mo`000?mgS]co00001?mcRm`2o`0000;oKHKK
1?l00003ofF2fP03o`000?mUPM[oIH7J00?o000000?oFWWHo`000?oGdM<00_oGdM<00ol0003of=;C
omSBd`03o`0000;oj=C100?o0000onWE`Ol000000_obe[<3o`000003oo[EX?l0003oom2700;o0000
00CooLETo`000?l0003o0000?_oonfX00ol0003ooo]ZoookJP0SoookJP00ROoonfX3o`000<gooo]Z
0_l000003?l005oo001Wo`000?l0087o001mo`08Uol0003o002>o`000?l039go00:Fo`0S[PKo0000
00Go0432o`0l_ol0003o05_Do`000006oif^h`Co00000onCYn<00ol0003oSj?RohnShP04ohnShP03
o`000?n:WN3oRYgP00CoRYgP00?o0000ohNLh?l000001?n6Vml01?l0003oPYSOoh:Hgol00002oh:F
gP03o`000?mmTmkoOI?N00?oOI?N00?o0000ogbAgOl000000_mhSmd6o`000005og>;g?l0003oL8WK
og29fol000000_m]Q]/01_l0003oK8GJofb5f_l0003oIH;Jo`0000?oIH7J0_l000001OmJN=Oo0000
om3?f?l0003oem7C00Co000000Gof=;Co`000?l0003oj=C1o`000002onWE`@07o`000?obe[?ol]Jc
o`000?ocek?o0000oo[EX004o`000004oog5I?l0003o0000o`0003oooo]Z00?o0000oookJ_oonfX0
8_oonfX008Kooo]Z0ol0003@oookJP;o000000?o001Oo`00Iol006h01?l000002_l008ko0029o`0<
WOl0003o00JIo`0O[?l05ZCo03Nmo`000?l0;;@2o`000004o`10`_l0?;oo0000o`1Ke0Co00000_nH
[ND00ol0003oTjOSoi>Wh`05oi>Wh`03o`000?n?Xn;oSj?R00;oSj?R00?o0000ohnPgol000000on:
WN0Ao`0000?oOI?N00Go0000ogbAgOmlTMgoO97Mo`000002ogR?g@03o`000?mgSMcoMhgL00?oLh_L
1?l00002off6f`04o`000?m/QM[oK8GJofb5fPGo000000?oIH7Jo`000?l000000_o@cmP3o`0000?o
f=;C00Co0000omWCdol0003o00000_oYeL401?l0003oj]K1o`000?l00002oo?G/`04o`000?ojeJ3o
0000oo_GW`;o000000?ooLETo`000?l000000_l0000ooookJP03o`000?oonf[ooo]Z027ooo]Z0024
oookJP;o0000dooonfX2o`00000Co`00Gol0003o0000o`000?l008Wo0000o`08Uol008ko0029o`0<
WOl0003o00:Fo`000?l07jco01JTo`0g_Ol0003o02bdo`18b002o`000005o`0l_ol0003o0000o`1F
dOl000000onH[ND00ol0003oTjOSoi>Wh`02oi>Wh`ko00000on:WMl00ol0003oQYWNohJIgP04ohJI
gP03o`000?n3Umko000000?oOiCM2_l000000omhSmgo0000ogN=g002ogN=g0;oLh_L00?o0000og>:
fomcR]/01ol000000om/QM[o0000of9nf002of9nf0Oo00000ooHd]<00ol0003ofM?ComWCd`02o`00
0003onWE`Ol0003oj]K100;oj]K100Go0000oo?G/ol0003olmRbo`000002oo_GW`?o000000CooLER
o`000?l0003o0000?ooonfX00ol0003ooo]ZoookJP0QoookJP00POoonfX3o`000=Cooo]Z1?l00000
1?l007[o001go`00Rol008T2o`000005o`07Uol0003o0000o`000?l03Ih01?l00002o`0a^@03o`00
0?l0A/Oo04K700Co000000?o05KAo`000?nH[ND01_l00003oiBTh005o`000?n?X^7oSj;QohnRhOl0
00000on?XN000ol0003oRYgOohZMg`03ohZMg`;o00001_n6VMh2o`0000CoOiCM0ommTmd01?l0003o
O97MogbAgOmlTMd3ogV?g0Go000000?oLh_Lo`000?mcR]/00_mcR]/00ol0003oKHKKo`000003ofZ3
f@;o000000?oHWkHo`000?l000000ol000001oo@cmSo0000om7@fOoAd=Wo0000omSBdol000000_oI
dm<00ol0003of]CCo`000002o`0000?oj]K100So0000oo?G/ol0003olmRbo`000?okeioo0000oocH
WP;o000000?ooLERo`000?l000000_l0000ooookJP03o`000?oonf[ooo]Z023ooo]Z001noookJP?o
0000eooonfX4o`000003o`00N_l007Oo000000;o000000Go0028o`07Uol02Y[o00JHo`0GYP02o`0=
WP04o`000?l07jco01JTo`0k`0;o036i00?o0000o`16aol0A/L02Ol00007oiBTh003o`000?n?X^7o
000000;oSj7P3ol000000on6VMko0000o`000004o`000003ognDgOmmTmgo000000GoO97M0_miSm`0
1_l0003oNHgKogV=fomiSM_o0000og>;f`Co000000?oLh[Ko`000?l000001?mZPmT3o`0000?o`/cR
0_l00004om7@f@04o`000?oIdm?ofM?Co`0000?of]CC00Oo0000on[F`OoZe/7oj]K1o`000?o[el3o
000000;olmRb00Co0000oo_GWol0003oo=RN0ol000001OolaEoo0000o`000?oonf[o000003oooo]Z
00?o0000oookJ_oonfX07ooonfX007_ooo]Z0ol0003JoookJPCo000000Co001jo`000?l0087o016H
0_l000001ol06Z?o0000o`0:V_l0003o01NVo`000?l03Ih00ol000001Ol0>l3o036io`000?l0003o
04K700;o04;400?o0000o`MOeol000000_l00002oaYah@;o00000onDY>02o`000003oiBTh?l0003o
000000;o00000on=W]l01Ol0003oRYcOohZLgon:W=oo000000;oRI_N00?o0000ohFHgOn5V=d00on5
V=d2o`0000CoPI?L1ol000000omlTMgoNHoLo`000005ogV=f`03o`000?maQm[oLHOJ00;oLHOJ0ol0
00000omZPmWo0000o`000002o`0000?o`/cR0_l000002Oo2cN;o0000om7@fOoAd=Wo0000om7AfOl0
003ofM?Co`000003om[Dd`05o`000?oJe]?o0000on[F`Ol000000_o[el001Ol0003olmRbo`000?od
fK;o000000;oo=RN0ol000001_olaEoo0000o`000?l0003ooo]Zo`0003kooo]Z00?o0000oookJ_oo
nfX07ooonfX007Sooo]Z0ol0003LoookJPCo000000_o001bo`000?l0003o0021o`0AV?l0003o002>
o`0JXol0003o00ZJo`06V002o`000007o`0=W_l0<kWo02Jao`000?l08Jgo03Nmo`0a^@02o`000007
o`16aol0@/Co04;4o`000?l7GmOo0000o`1HdP03o`000004oaA]g_l0003o0000o`0000CoTZ?Q00?o
0000ohfNgon=W]l01?n=W]l00ol0003oRYcOo`000004ohVKgP07o`000?n5V=goQISMohFHgOl0003o
QIKLo`000006oh6Cg003o`000?mlSm_oO8oK00;oO8oK1_l00002ogV=f`03o`000?maQm[oLHOJ00?o
LHOJ0ol000001om[P]So0000okk;i?nnbnCo0000ol;<h_l000001?o2cN82o`0000?odM7I00Go0000
om[DdooJe=?of]CCo`000003om[Fd`05o`000?o[el3ojmO0o`000?o/fL000_l000001OodfK;o0000
oocHW_l0003oo=VM00;o000000Koo<EOo`000?l0003o0000oookJ_l0000ooookJP03o`000?oonf[o
oo]Z01kooo]Z001eoookJP?o0000g_oonfX00ol0003o000ao`00CP02o`00000Do`00L_l0003o0000
o`00POl0003o00fGo`00S_l01iKo0000o`0:V_l01YSo0000o`0GY_l03Iko0000o`0c^Ol09[7o0000
o`0o`ol0=kd4o`000007o`12a?l0003o0000o`000?l0F]?o0000oambh@02o`0000;o56gN0_l00002
oi:Sh@;o00000on=W]lBo`0000CoPI?L00?o0000ognAfol000001OmlSm/01?l0003oMh_JogN;f_mg
RmX9o`000003ofn5f?l0003o000000Co_/_T00?o0000ol;=h_o2cN800_o2cN82o`0000?odM7I00Go
0000om;BfOl0003of]CCo`000003om[Fd`?o000000OojmO0o`000?o/fL3o0000ooCI/_l0003omM^a
00;o000000Goo=VMo`000?l0003o0000oo_5G002o`0000;ooo]Z00?o0000oookJ_oonfX0?OoonfX0
0ol0003ooo]ZoookJP0MoookJP00LooonfX2o`000>7ooo]Z00?o0000o`00<Ol004h00_l000000ol0
07;o00N:o`03R`03o`000004o`0=Uol0003o0000o`0GXP;o000000?o02Zao`000?l000000_l00000
0ol09;3o0000o`0m`@02o`0d^`06o`000?l1DLko0000o`14aOl0003o3V7H0ol00002oambh@?o0000
00?o=XCYo`000?l000001Ol00003ohfMgP03o`000?n:Vmko000000CoR9SM00Go0000ohFGgOn5Umgo
QIOMo`000002ohBFg0_o000000CoO8oKo`000?mjSM[o00001?mgRmX3o`0000;oLHOI0ol00002ojk5
j`05o`000?nnbnCo0000okk;i?l000000_o2cN82o`0000;o`lgS00?o0000om7AfOl000000ooBd]T0
1Ol0003of]KCom[FdooJe]?o000000;of]KC0_l00002oncI`005o`000?odfK;o0000ooGK/Ol00000
0_olfId3o`000003oo_5G?l0003o000000?ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]Z
oookJP0MoookJP00L?oonfX3o`000>;ooo]Z0ol000001Ol004ko0000o`00N_l0003o00N:00;o00>;
00?o00>?o`000?l03IL00_l000003?l05j;o01RTo`000?l0;k?o026/o`0KZOl0003o03>io`0V/Ol0
9;3o03o3o`0m`@;o03Bk00?o0000o`5Ac_l000000ol000000ol5G=Go0000o`000002o`000003oaM^
gol0003o000000?o=XCY0ol00005ohfMgP03o`000?n8V=goR9SM00CoR9SM00?o0000ohFGgOl00000
0on4U]`00ol0003oPI?Loh6Cg002oh6Cg003o`000?moTM_o000000?oO8oK3Ol00006ojk5j`04o`00
0?nnbnCo_/_Tokk;i0;o00001?o3cN<2o`0000?od];I0_l00002om[Fd`04o`000?oJe]?of]KCom[F
d`;o000000Cok=W0o`000?o]f[oo00000_oefk43o`000003oogJW?l0003o000000Co00000_oonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01cooo]Z001]oookJP?o0000i?oonfX3o`00
000=o`00F_l0003o0000o`00N_l0003o00N:o`000?l00h_o0000o`TQX_l03IOo0000o`<XZ`02o`00
0006o`0HY?l0003o02nco`0Q[?l0003o03Fj1?l000002Ol0>[oo03Bko`UDcol9E<oo0000o`1:b_l0
003o56?Io`000002o`ELe@05o`000?lSLn;o0000o`000?lGK]l00ol000000olfQ>Wo0000oc20j00B
o`000005ohBFg?l0003oPI?Loh6Cg?l000000omoTM/01?l0003oO8oKogb?fomlSm/4o`0000;oMh_J
1?l00004ojk5j`?o00000_n^aN/01?l0003o_/_Tokk;i?l00003ol?=h`;o00000_o3c^<00ol0003o
d];Io`000002om;Cf@;o00000ooJe]<01?l0003ofmOCo`000?l00002ongJ_`07o`000?oefk7omM^a
o`000?ofg;7o0000oogJW006o`0000?ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Zoook
JP0KoookJP00J_oonfX3o`000>Oooo]Z0ol000002Ol005[o0000o`000?l0003o00:6o`000?l64i?o
0000o`0:TP02o`TQXP0;o`000?l049_o0bR[o`000?l06:Co0000o`0_/ol0003o026/o`000?l1?Kh0
0_l0;;D01?l2AlOo03g1o`0j_ol0=;/2o`UDc`06o`000?l0B/[o0000oaASfOl0003o1EcE1ol00002
ocV4j@Go00000_m;TNl3o`0000KoR9SL00Co0000ohBDfon4U=_oQ9CK4ol00002oibnl003o`000?n^
aN_o000000;o00001_n^aN/01_l0003o_/_Tokk;i?l0003o`lgSo`0000Co`lkS0_l00003om;Cf@05
o`000?oJe]?of]KCom[Fdol000000_oKem<01Ol0003oiM_;o`000?l0003ok]^n00;o00000_ofg;40
0ol0003ooMZLo`000005o`0000Cooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0K
oookJP00IooonfX3o`000>Wooo]Z1Ol000002?l006co1PF3o`000?l00XKo0000o`HCTol0003o00ZB
0_l98J802?l0003o012Ko`<XZol09:[o01RTo`000?l0;k?o00000_l08J`02Ol0003o0Cfno`0/]Ol0
003o0TO7o`000?l0>[oo0000o`UDc`02o`1>c0?o000000?o2ekFo`ELeOl000000_lXM>801?l0003o
6foOoa]_gol00002ocV4j@03o`000?lcP>So<h3X00;o00001?m;TNl5o`000003ohRHg?l0003oQ9CK
017o00001onL__000ol0003o[/G[ojk5j`03ojk5j`?o00000_n^a^/01?l0003o_/_Tokk;i?l00003
ol?>h`;o00000_o4cn<01ol0003od]?Io`000?oCe=Wo0000om[Fdol000000ooKem<2o`00000:onGK
bol0003ok]^nonkK__l0003om]bao`000?oggK3o0000oogKVPGo00001OoonfX00ol0003ooo]Zoook
JP0loookJP03o`000?oonf[ooo]Z01[ooo]Z001UoookJP;o0000jooonfX5o`00000@o`00L_l0003o
1PF3o`000?l00XKo0000o`HCTolH99ko0000o`0DVol0003o01jRo`000?l06:7o0000o`0TZP?o0000
00Oo02^bo`000?l0003o0Cfno`0c^_l0;;Go000000;o03o300?o0000oa5GdOl9E<l00_l0C/`00ol0
003o6fGIo`000003o`000003obQdh_l0003o7g3P00;o000000Wo?8CYo`000?liQ>Wo0000oc>0j?l0
003oDI?_o`000?m;TNl00_l000000om;TNoo0000of:OlP02of:OlPCo00001OmgZo<3o`0000CoRkGb
00Co0000ohVel_n9]O;o00000_nL__03o`0000?oW;k`00?o0000ojk5jol000000_l00006ojk6j`04
o`000?noc>Co0000ol?>h`;o00001?o4cn<2o`0000?odmCI00Go0000om_GdooKem?ofmOCo`000002
omcHd`0:o`000?oWgL[o0000onoL_Ol0003om]bao`000?oggK3o0000oogKVPGo00001OoonfX00ol0
003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Wooo]Z001RoookJP?o0000kOoonfX3o`000003
o`00H_l0003o001b00;o000000Co6aVAo`000?l038oo00000_lH99h01?l059_o0000o`0NX_l07Z82
o`000006o`0TZ_l0003o01bWo`dj^Ol0:k;o02Zb0_l;@L401?l1?Kko03>jo`a;b?l<BlP2o`0o``04
o`000?lAEm7o0000o`1>c0?o000000Ko4V7Go`000?l0003o0000obQdh_l00002oam`h003o`000?ll
Q>Wo?8CY00Co000000CoDI?_o`000?m<TNkoC97^0ol00002of:OlP;o000000CoHYobo`000?l0003o
Mj_c0ol00002ogN[l`06o`000?n;]O;oRkGboh^el_l0003oRkGb1Ol00007oibnl003o`000?n^a^_o
[/K[00Co[/K[0_l000001On_a^_o0000oko<i?noc>Co000000Goa<oS00Oo0000olG@hol0003odmCI
o`000?oDeMWo000000;ofmOC00?o0000omcHdooLf=<00_l000001OoWgL[o0000o`000?o_g;go0000
00;ommf`0_l000000oong9Wo0000o`000003o`0000Gooo]Z00?o0000oookJ_oonfX0??oonfX00ol0
003ooo]ZoookJP0IoookJP00GooonfX3o`000>oooo]Z0ol000002Ol806So0000o`l2NOl0003o20F2
o`000?lK6I7o0000o`0<S`02o`000008oaPTW_l0003o4bZWo`000?l07Z;o0000oa<c/Ol09:X3o`00
0003o`dj^Ol0003o02Zb00;o2d7100[o0000o`0c^_l<BlSo04K6o`0o`ol0003o0433o`000?l7D/oo
04k<0ol00002oa9Qe`Co000000?o7g3Po`000?l000000ol000000olfPNSo0000o`000002o`000003
odbAk_l0003o000000;o00000omSWo4=o`0000;oRkGb00Go0000ohZdl_n:]?;oR[Cbo`000002oibn
l0?o00000_nM__000ol0003o[/K[ojk6j`02ojk6j`;o00001?n_a^/3o`0000?oa<oS0_l00002olG@
h`;o00000ooDeMT2o`0000;og=SC00Co0000omgIdooMfM?o00000_oXg/T2o`000007ooOM/?l0003o
n=f^o`000?ong9Wo0000ookDN003o`0000Kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]Z
oookJP0HoookJP00G?oonfX3o`0001?ooo]Z1ol0003GoookJPCo000000[o201Xo`000?l?0WWo0000
o`P5P_l0003o6aVAo`000?l038oo3AbJ0_l000006Ol97Iko0000oa<ZYol0003o022Uo`000?lC<k7o
0000o`0TZol0003o3CZio`000?l0:[;o02jdo`]1`Ol0>kko03>jo`000?l<BlSo04K6o`0o`ol0003o
6E[Bo`000?l7D/l00_l000001OlQIm[o0000oa9Qeol0003o45oG00Ko000000?o?hGYo`000?l00000
0_l000000omCTnko0000odjAkP02odjAkPOo000000?oHioao`000?mhZo<01_mhZo<00ol0003oRkGb
oh^elP02oh^elP03o`000?n:]?;o000000?o00001_nM__001?l0003o[/K[o`000?l00006ojo6j`06
o`000?noc>Co_lcTo`000?o4cn?o00000oo5d><01?l0003oa]7SolKAhol00002omCEf@04o`000?oL
f=?og=SCo`0000?ogMWC00?o0000onSNbOoXg/T00ol00002ooSM[P?o000000Coo]Aho`000?l0003o
00001_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Oooo]Z001IoookJP?o0000
4_oonfX4o`0000GoTkS`00CoEI_bo`eah?l0003o0000e?oonfX2o`000008o`00B_l0003o201Xo`P0
J?l<07Wo3`9io`000?l81H82o`000003oaHKUOl0003o3AbJ00;o000000go2AfNo`000?lC:ZOo0000
o`0PYOl19Z[o4c>ao`L^/?l09:_o02V_o`dj^Ol0003o02Zb00?o000000Go03^no`000?lECl[o0000
o`16aP02o`0000;o45OA00Oo0000o`EAc_l0003o0000oaUTfOlBHMOo000000;o<WOR00?o0000obAa
hOlTLN400ol000000oloQNWo0000ocV1j003o`000003odjAk_l0003o000000;o00001?mUW_43o`00
0003ogR[lol0003o000000[o00000_n:]?800ol0003oWKk`oifnl006oifnl003o`000?n_a^_o[lK[
00;o[lK[0ol00002ojo7j`04o`000?noc>Co_lcTo`0000;oaM3S0_l00003olKAh`;o000000CoeMKI
o`000?oLf=?o00000ooMfM<2o`000006onSNbOl0003oj^78on[Qb?l0003on=f^1?l000001?one7So
0000o`000?l00007oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX05ooonfX005Oo
oo]Z0_l0000BoookJP?o00000_n]_nL00ol0003oTkS`oi>hl005oi>hl0Co0000d_oonfX3o`00000:
o`00B_l0003o201Xo`000?l<07Wo0000oahDR?l0003o4aB>o`0000;o5Q^E0ol000000ol97Iko2B6R
oa<ZY`03o`000003oa<c/Ol0003o1bj`00Ko000000Co5dW4o`000?l0>[ko03Zn0_l<C<T00ol0003o
04?5oaUJdP02oa1Gd@05o`000?l5DLko0000o`000?lII=T00_l000000olbMn;o0000obUch@03o`00
00;o@hKY2Ol000000omXXO7o0000ofFNl@04ofFNl@03o`000?miZ_;oNJ[b00KoNJ[b00Go0000ohbe
lOn<]O7oS;Gao`000003ohZdlP03o`000?nM__3o000000?o00000onM_^l01?l0003o[lK[o`000?l0
0006ojo7j`05o`000?o0cNCo0000olG@hol000001?o6dN<00ol0003oam?So`000002omGFf@05o`00
0?oMfM?ogMWComgIdol000000_oNf]<01?l0003oj^78on[Qb?oZhLP4o`000004ookLUol0003o0000
ookCMP;o00002?oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z01Kooo]Z001Doook
JP?o00004OoonfX3o`0000Ko[KoW1?l00004oi>hl@Co0000dOoonfX6o`000007oaX8O?l0003o0000
oahDR?l0003o4aB>o`000002oaHKU@;o000000co9S2Uo`000?l98J;o2B6Ro`000?lP=Jko0000o`4V
Z_l0003o1bj`o`000?l0:Jl2oa]3_@;o03:g00?o02jdoaM9a?l0>kh00_l0>[h2o`a<b@0>o`000?l0
@lGo0000oa1GdOl0003o25;>obQYfol0003o86OJo`000?lFH]So0000oc9gh_l00002obUch@;o0000
0_m3Q^T5o`0000CoBhk]00?o0000ofFNlOl000000_l00002ofFNl@03o`000?miZ_;oNJ[b00;oNJ[b
3Ol00008oifnk`03o`000?n_an_o[lO[00;o[lO[0ol00002ok37j`03o`000?o0cNCo000000Coa]7S
00Oo0000olOChoo7dn?oam?So`000?oEe]Wo000000;ogMWC00?o0000omkJdooNf]<00_l00002on[Q
b004o`000?oZh<So0000ooGT^0;o000000?oo]^Co`000?ondgH00_l00009oookJP03o`000?oonf[o
oo]Z03cooo]Z00?o0000oookJ_oonfX05OoonfX0057ooo]Z0ol0000CoookJP04o`000?nh`^;o^<;R
o`0000;o[KoW0ol00002ojfoi`03o`000?nC^?7oTkSa00GoTkSa1?l0003?oookJP;o000000Co301E
o`000?lG06go00000_lJ27`00ol0003o7QB8o`000002o`000007obHVV_lF6iGo0000oaPQVol0003o
9S2Uo`000002o`TQXP08o`000?lP=Jko3Rf/o`4VZ_lP?KKo1bj`o`000?l0:Jl3oa]3_@;o03:g0_lG
BL@01?l0003o03ZnoaiEcOl<C<T2o`E8a`08o`000?lQGmCo45OAo`000?l8D/ko:6WKo`000?lPImX2
o`000003ocMhh_l0003o000000Go000000Go@hKYo`000?llP^Oo0000oeRDk@04o`000003od^>kOl0
003oIio`00;oIio`1ol00004ogf/l@05o`000?n=]?7oSKCaohfdlOl000000on;]?400ol0003oWKk_
oifnk`04o`0000;oW[k_00?o0000ojo7jol000000_l00006ok37j`;o00000oo6dN<00ol0003oam?S
olOCh`02olOCh`;o000000?oe]OIo`000?l000000_oNf]<00ol0003og]_BomkKdP02o`0000;oj^38
00?o0000ooGT^?l000001ol00008oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0
5OoonfX004kooo]Z0ol0000DoookJP;o00001?nh`^82o`0000Ko[KoW1?l00004oiBjl@Go0000booo
nfX4o`000008o``0EOl0003o5`1]o`000?lJ27co0000ob@GR?l00002oc4WU003o`000?lO8YSo0000
00;o626K00?o0000obH`YOlM;JH01Ol000000ol>;Jco0000ob0m]P03o`0000;o6d>m00_o0000o`0b
]olOCLGo5dW4o`E0`Ol0>[ko0000oaiEcOl<C<Wo1DS7o`000002ob5Oe0;o000000?o25;>o`000?l0
00002Ol000000om7Q^So0000o`000004o`0000?oDY;]1?l00004ofNOl0;o00001omm[?400ol0003o
SKCao`000007o`0000OoW[k_00?o0000ok37jon`an/00on`an/3o`000006ok78jol0003o`LkTo`00
0?o6dN?o00000oo7dn<2o`000004olWDh_l0003oe]OIo`0000;og][C00Go0000omkKd_oNfm;og]_B
o`000002on[Pb0?o000000?om^Feo`000?omhih01Ol00009oookJP03o`000?oonf[ooo]Z03cooo]Z
00?o0000oookJ_oonfX05?oonfX004_ooo]Z0ol0000FoookJP03o`000?nh`^;o^<;R00;o^<;R00Co
0000okS1h_nh`N;o00000_n]_nL3o`0000;o[L3W00?o0000oiBjlOnD^_401OnD^_401Ol0003oki13
o`000?n?203o00000<Wooo]Z2?l000001OlW4X3o0000o`000?lT5hSo000000;o<BND00?o0000oalR
V?l/;Il00_l000001?lM:J;o0000oad]Y_lM;JH2o`000005ob8f[Ol0003o3Rf/o`000?lP?KH00_lD
>;D02Ol8=;Ko0000oa]3_Ol0003o03:go`000?lOCLGo0000o`E0`@02o`000003oaiEcOl0003o1DS7
00?o000000Co4USAo`000?l0003o;VcL1_l000000ol_MN;o0000obech@03o`0000;o@8?W1_l00000
0omBT^go0000ofVOl003ofVOl003o`000?mWWo3o000000Wo00000_n>]?000ol0003oS;Caohbdl@02
ohbdl@03o`000?nN_^ooW[k_00?o00000onN_nl00ol0003o/<O[o`000002o`0000Go/LS[0ol00003
olOCh`04o`000?o9e>;obMCRolWDhP?o000000?og][Co`000?oNfm800_oNfm82o`000007on[Pb?l0
003ojn77o`000?ofiKGo0000ooKU]@06o`0000[ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003o
oo]ZoookJP0CoookJP00B?oonfX3o`0001Kooo]Z0ol00003okS2hP;o00001?nh`N82o`0000Ko[L3W
1?l00003oiFkl@Ko0000aooonfX6o`000005obH7L_l0003o:QB1obLBP?l000000_lT5hP01Ola9iCo
0000o`000?l[9iSo7b:H00;o;2fO00go0000oadYX_l0003o0000oad]Y_l0003o4bbYo`000?l/?[;o
3Rf/o`000?lP?KKo000000;o53Re00Co23Bfo`000?l0003o2c^k0_l000001OlCAlCo0000o`000?l7
@/;o7UG=00;o44k:00?o0000obQRe?lXH]@01Ol000001Ol^K=co7VGIoaiUfOl0003o=GOR00Co0000
0_m;QnP01Ol0003o@8?Wo`000?mKU>go000000?oEI;]0ol00006ofVOl003o`000?mjZo;oNZ_b00Go
NZ_b00Go0000ohjdl?n>]?3oS[C`o`000002ohbdl@Co00001onN_nl00ol0003o/LS[ok78j`03ok78
j`;o000000Go//W[o`000?o1c^Co0000olOCh`02o`0000;obMCR0_l00002ol[EhP;o00000ooNfm80
1?l0003oh=_Aon3KdOl00002on_Qa`06o`000?ofiKGo0000ooKU]Ol0003ooN>M1?l0000:oookJP03
o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX04ooonfX004Kooo]Z0_l0000GoookJP;o0000
0onn`md00ol0003o^<;Ro`000004okS1hP04o`000?nh`N7o^<7Qo`0000;o[L3W0ol00002ojk0i`03
o`000?nE^o7oUK_a00CoUK_a1_l00035oookJPCo000000Ko8@1No`000?l0003o9PMbo`000?lZ5842
o`000006ob@GR?l0003o;bFDoc4WU?l0003o:bNH0_l000000ol/;Ioo0000oadYXP03o`000003oa/_
ZOl0003o000000;o;3jb0ol00002oa@h]@;o000000[o9T[1o`/k^ol:?Kgo2Sfmoam=aOlCAlCo1D31
o`000?lWFLgo00000_l@C/X3o`000006oaaLdol0003o0000ocA_g?l0003o;VcL0_lNIMT2o`0000;o
=GOR0_l000000om;QnSo0000odB3i`02odB3i`03oe^DkOl0003oEI;]00?oEI;]3ol000000omjZo;o
0000o`000004o`0000;oSKCa00?o0000oijokonN_nl00_nN_nl3o`000003oinokol0003o/LS[00?o
/LS[00?o0000ok;9jonbbN/00_nbbN/00ol0003o`LkTo`000003olWDhP03o`000?o:eN;ob]GR00;o
b]GR0ol000001?oNfm;o0000on3KdOoPfm42o`000004on_Qaol0003ok>;6o`0000;om^Fe00?o0000
oogSWOomhiT00ol0000;oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX04_oonfX0
04?ooo]Z0ol0000GoookJP;o00001Onn`md2o`0000?o^<7R0_l00004okS1h@;o00001_n^`>L4o`00
00;oUkca0_l000001OobXfco0000o`000?oFG`7o00000<;ooo]Z1Ol000000olQ05ko0000o`000002
o`000005ocHKPolZ587o0000oc<RSOl000000_l_9I@01?l0003o:bNHob/WV?l/;9d2o`000005ocTj
Y_l0003o936WobdgZ_l000000_lK;jT3ob`n/P0;o`000?lA<[3o;4Jjoa@h]Ol0003o3cNfo`Pd]_l0
003o9T[1o`000?l:?Kd00_l000000olCAlCo0000o`000005o`000005obQRe?lLG=?o75cCoaaLdol0
00000_ldKm`00ol0003o7VGIoaiUf@04o`000007oc9ehOl0003o0000o`000?m4PnOo0000odB3i`05
o`000003oeFBkOl0003oK9o_00GoK9o_00?o0000og^[lOmkZo401OmkZo401Ol0003oSkG`ohnel?n?
]O3o000000CoSKCa1?l00005oinok`04o`000?nab>_o0000o`0000Ko//W[0_l000000oo9e>;o0000
o`000004ol[EhP05o`000?o;d]oobm;Ool_Bgol000000_oPfm400ol0003oh]kBon;NdP02o`000007
oncRa_l0003om^Feo`000?ogi[?o0000oogSV@03o`0000cooo]Z00?o0000oookJ_oonfX0??oonfX0
0ol0003ooo]ZoookJP0AoookJP00@?oonfX3o`0001Sooo]Z0_l00005okk3g@07o`000?nn`]go_/;M
okk2gOl0003o^<7Ro`000004okS1h@04o`000?nh`N7o^<7Qo`0000;o[/3W0ol00002ojo0i`03o`00
0?nG_?7oUkca00;oUkca0ol000000oobXfco0000o`000002o`000<3ooo]Z0_l000000ol?03?o0000
o`000002o`000003ocHBMol0003o000000;o=Q^300Co0000ocLTS_lc8Xgo00000_l_9I@00ol0003o
:bNHo`000002ob`/W@03o`000?li>ZKo>CZV00?o00000_lK;jT01OlQ=joo;3jbo`000?lM=k7o0000
00;o;4Jj0_l000001ol?=kKo9T[1obI:`OlC@Kko0000o`Xm_OlZDlP00ol000000olWFLgo75C=oaaD
c@02o`000004oc1UeOl0003o75cCoaaLd`;o000000Go=6oLo`000?lWJM_o7VGIo`000003od1khPCo
00000_m3PnL3o`0000?oF9?]1_l00003ofbOk`03o`000?mkZo7oNj_a00GoNj_a00?o0000ohnel?n?
]O001_l00009oinok`03o`000?nbbN_o//W[00;o//W[0ol00002ok?:j`;o00001?o:eN82o`0000?o
bm;O00Coc=SRo`000?oPfm7o00000ooRg]801?l0003ok>;6o`000?o]hlD2o`000003ooOV/ol0003o
000000?o00003OoonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z017ooo]Z000moook
JP?o00006_oonfX01?l0003o`/?Kol;3fol00003okk3g@03o`000?nn`]go_/;M00;o_/;M0_l00003
okS1h@;o00001?nh`N42o`0000Ko[l3W1?l00002oo>^O`05o`000?obXfco0000o`000?o[S4`00ol0
002loookJP?o000000?o3`0co`000?l000000_l00002ocHBM`;o000000[o=Q^3o`000?l0003o=bB>
o`000?ll;IGo;bFDo`000?lh<9co00000ol/;9d01_l0003o>CZVocTjY_l0003o936WocQ0[P;o0000
00?o8CN_o`000?l000000_lM=k401ol0003o;4Jjoam0^OlO@;Wo3cNfobi>`_lVB/401?l000000olZ
DlSo0000o`m7a@02o`000003oaaDcOlGDlco5e?<00;o000000?o9F7DoaaLdol000000_ljLM`2o`00
0006obMYfol0003o0000o`000?m0Nn;o00000_lgMn42o`0000Co@h?W0ol00002oeRCk@03o`000?m^
X>ooKZ3_00;oKZ3_2_l000001OmkZo7o0000o`000?n@]O3o000000CoS[C`00?o0000oinokonO_nl0
1?l00003oj30k`04o`000?nbbN_o0000o`0000Ko/l[[00?o0000ol[Eh_o:eN800_l00003ol_Bg`03
o`000?o<f>;oc=SR00;o00000ooRg]83o`0000;okN?500?o0000ooOV/ol000001Ol0000=oookJP03
o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX04?oonfX003[ooo]Z0ol0000LoookJP03o`00
0?o2`m_o`/?K00;o`/?K00?o0000okk3gOl000000onn`]d01ol0003o_/;Mokk2gOnn`]go0000okS1
hOl000001?nh`N400ol0003o^<7Qo`000004ojo0i`;o00000_n_`>H00ol0003oVKgao`000002oo>^
O`?o000000?ol:5]o`000?o[S4`00ol0002joookJP08o`000?l4003o0000o`000?l?03?o0000obl0
H?l00002ocHBM`Co000000KoB2n@ocLTS_l0003o0000oc`]UOl00002ocP`W003o`000?l/;9go;2bM
00;o000000Co>CZVo`000?l[<jOo00000_lh@:h02Ol0003o8CN_ob4g[olgA[Ko0000oadg/OlO?;Ko
;4Jjo`000002oam0^@Co000000?o4d6no`000?lZDlP00_lIC<H01?l?AlGo;ek?obmNcolLE<d2oaMC
c0;o000000Ko9F7Do`000?l0003o>W7Lo`000?l_KM/3o`000007odEmh_l0003o@7_Ro`000?lgMn7o
0000oe>9j003o`000003od>3iol0003oGiC/00;oGiC/0ol00006ofjPk`;o00001ommZo401?l0003o
T;G`oi2el?l00002ohjdl0Co00002?nP`>l00ol0003o/l[[ok?:j`02ok?:j`?o000000Co]<_[ol?@
i?l0003o00000oo;d]l2o`0000?oc=SR00Oo0000omKMg?l0003oh]kBo`000?oSh=7o000000?okN?5
00So0000ooOV/ol0003o0000oogTUol0003on=I]o`0000kooo]Z00?o0000oookJ_oonfX0??oonfX0
0ol0003ooo]ZoookJP0?oookJP00>?oonfX2o`0001kooo]Z00?o0000ol;3foo2`m/00oo2`m/2o`00
00?o_/;M00?o0000okk2gOnn`]d00_nn`]d2o`0000?o^<7Q0_l00003okS1h@04o`000?n_`>Oo0000
o`0000Go[l3V1?l00002oo6/P003o`000?o`XFgo000000;o000000CojHY>o`000?l0003o0000]ooo
nfX3o`000004ob00>Ol0003o0000obl0H0;o000000Go=Q9go`000?m298Go@RB5o`000002odP_T00=
o`000?lo;iKo0000oc`]UOm:>igo0000ocP`W?lm=j7o0000ob`/WOl0003o=CNUo`000002ob/cY`0:
oc4l[Ol0003o>42^obXj[ol0003o8CN_o`000?lgA[Ko0000oall]PCo000000So7T>lobi>`_lRBL7o
8TW1oa=1__l0003o<EO9obYCb0;o6Dc600Co0000obmNcol_G/oo00000_lGDl`2ocMXeP05o`000?lS
Gm?o8eoCocYag?l000000_l_KM/2o`0000;oAGgR1Ol00003odZ7j0;o00001?mOU>`@o`000003ogf[
lOl0003o000000?o00000on?]?000ol0003oX<3_oj30k`04o`0000;oX/7_00?o0000ok?:jol00000
0_l00005okC;j`;o00000_o;d]l00ol0003oc=SRolcHhP02olcHhP05olgHhOl0003oe]gLomKMg?l0
00000_oSh=401ol0003okN?5ongSaOl0003ok^C4o`000?ohik800ol000000ooheVgo0000o`00000>
oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX03ooonfX003Gooo]Z0ol0000Ooook
JP04o`000?o3`m[o0000ol;3f`?o00000_o2`mX00ol0003o_/;Mo`000003okk2g@07o`000?nn`]co
_/;Lokk2g?l0003o^<7Qo`000006okS1h@03o`000?n_`>Ko[l3V00;o[l3V0_l00002ok30iP05o`00
0?oa]8co0000o`000?oa[8000ol000001Oo^Wfoo0000o`000?l0003oihQ?00?o0000]?oonfX2o`00
0003ob<0>ol0003o000000?o000000?oA1ejo`000?l000000_m298D2o`0000;oB2n@00CoA36Eo`00
0?ll;IGo00000_m:>id01?l0003o?CNQocdgXOl00002ocDgY@04oc`mZOl0003o0000oc4l[@;o0000
0_lZ>Zl00ol0003o=dJfocM6]P03o`0000;o=Tfm00Co7d2io`000?l^C/;o00000_lRBL42o`000003
oc5GbOl0003o6Dc600;o000000Go;ek?oamGc_lOElko5e?<o`000002ocMXeP;o000000Ko@7?Lo`00
0?l0003o;fgKo`000?l^K=/3o`0000;o?GWQ1?l00002odZ7j0Co00000_mOU>`2o`0000GoL:3^0_l0
0007ogj/l@03o`000?nB]Noo000000?oSkC`1Ol00007oj;1k`03o`000?ndbn_o]<_[00;o]<_[0ol0
00001Onfc>_o0000o`000?o;d]oo000000?oc=SR00Co0000olgHhOo=f>7ocMSQ0ol000000ooSh=7o
0000onGQc`02o`0000;ok^C40_l000001?ohik3o0000o`000?oheVd2o`0000kooo]Z00?o0000oook
J_oonfX0??oonfX00ol0003ooo]ZoookJP0>oookJP00<_oonfX3o`00023ooo]Z0_l00003ol?3fP03
o`000?o2`m[o`/?J00?o`/?J0_l00003okk2g@03o`000?nn`]co_/;L00;o_/;L0_l00004okS1h@;o
00000_ng_n001?l0003o[l3Vo`000?l00004ok30iP04o`000?oa]8co0000onnbS0;o000000GokjZ1
o`000?o^Wfoo0000onbLL002o`000004onN8Col0003o0000o`000;7ooo]Z0ol000001?lS03_o0000
o`000?m23VL2o`0000;oA1ej00So0000od8TQOm298Go0000od/bTOl0003oB2n@o`0000;oA36E00[o
0000odXkWOm:>igoBS^Mo`000?lm=j7o0000odU2Y_l0003o=CNU0_ll?JT00ol0003o<Cb]oc4l[@02
o`000003obXj[ol0003o000000;o000000?o:D6foall]_lfCKd00_lfCKd02?l0003o7T>lo`000?l0
003o8TW1oam:`ol0003o<EO90_lVD/P01?lIC<Ko=f7@ocMQd?l00002oamGcP;o000000?o=fSFobMR
eOlWH]D00_l000000olgL=co0000obm]f`02o`0000;oBWoR0_l00002oeN;i`06o`000?m?R>So0000
o`000?m8Q^Oo00000_mRUN/9o`000003og2Pk_l0003o000000CoOZca0_l000000omn[?7o0000o`00
0003o`0000?oTKG_00?o0000oj;1konR`Nl00_nR`Nl3o`0000;oXl7_00Co0000okC;jol0003o0000
1Onfc>/2o`0000?oc=SR00?o0000olgHhOo=f>400_o=f>400ol0003ofMoKomWOf`02o`000004onGQ
col0003ok^C4onkTa0?o000000?on>N`o`000?l000000ol0000?oookJP03o`000?oonf[ooo]Z03co
oo]Z00?o0000oookJ_oonfX03OoonfX002oooo]Z0ol0000RoookJP09o`000?o6a=Soa/CHo`000?o3
`m[o0000ol?3f_l0003o`/?J00?o00000_o2`]X00ol0003o_/;Mo`000003okk2g006o`000?nn`Mco
_/7Lokk1g?l0003o^<7Q0_l00004okNoh0;o00001?n``>H5o`0000;okk:<00?o0000onnZPOl00000
0_l00002onbLL003o`000?oWR4oo000000;o000000?o03f]oookJ_oonfX0[OoonfX2o`000003odd9
E_l0003o000000;o@PiW0_l00002od@MNP;o000000Co@RB5o`000?m;<Y7oBc:A0_l00003od@aU@06
o`000?m:>igoBS^Mo`000?m1>:3o00000om9@ZH2o`000004oc`mZOl0003o<Cb]oc4l[@Co000000?o
;D2co`000?l000000_lY@KH01Ol0003o=TfmocI=_Ol0003o7T>l00;o=eC400Go8TW1o`000?lOB/?o
<EO9o`000002obIBb005o`000?lgHM3o:ec?ob]LcolOElh00ol000001OlgJ=Ko9f;EobMReOm0Lmco
000000;o=g3L0ol000001_m:On;o0000ocejh_l0003oEh_Wo`0000CoChSX1?l000001?mRUN_o0000
oebCk?l00005og>QkP03o`000?m]Wnoo000000?o00000omo[?400ol0003oTkK_o`000006oi6ek`04
o`000?nR`Noo0000o`0000KoXl7_00?o0000okK<jonfc>/00onfc>/01ol0003o]lcZo`000?nlcnWo
0000olcHh_l000000oo=f>401Ol0003ocmWQo`000?oIgm_o000000;ofn7J0_l000001Oo^i<Co0000
oo3T`_l0003on>N`00;o000000Coo>BAo`000?l0003o00004?oonfX00ol0003ooo]ZoookJP0koook
JP03o`000?oonf[ooo]Z00gooo]Z000/oookJP?o00009?oonfX01?l0003oa/CHolK4f?o6a=P2o`00
00?o`l?J0_l00004ol;2fP;o00000onn`]`00ol0003o_/7Lokk1g003okk1g003o`000?ng_n3o]koP
00;o]koP0_l00002okW0g`06o`000?n``>Ko0000o`000?na`>Go00000_o_]i@00ol0003okk:<onnb
S003o`000004onfXP_l0003o0000onbLL0?o000000?oiHEAo`000?l000000_l0002[oookJP?o0000
0_m=2EH00ol0003o@PiWod8>I`03o`000005od@MN_l0003oDC2:odPYR?l000000om;<Y42o`0000;o
A36E0_l000001_m:>igo0000od4hX?m1>:3oBD:Vo`0000;oBD:V00?o?3fXo`000?l000000ol00003
od58/P04o`000?l]@;?o0000o`0000;o:D6f00Co:dFjocI=_Ol0003o:4Nm0_l00002ocMDa0;o0000
00Oo7d[3o`000?l0003o9U;8ob=Cb_l0003o=f7@00;o:ec?00Go7eO>oce[eolmJmOo?F_Go`000002
obMRe@Co000000Go=6kKo`000?l0003oBWoRo`000002ocejhPCo000000?oChSXo`000?l000000omU
U^/4o`0000GoLj7^0_l00007ogn/l@03o`000?nC]^oo000000?oTKG_1?l00004oj?1k`?o000000?o
Y<;_o`000?nfc>/00_nfc>/2o`0000?o]lcZ00?o_<oYo`000?l000000_o=f>42o`0000?ocmWQ00Co
0000om_Qf_oKhM[ofn7J0ol00002oo3T`P05o`000?ohik3o0000o`000?oli9400ol0000AoookJP03
o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX03?oonfX002[ooo]Z0_l0000VoookJP05o`00
0?o6a=Soa/CHolK4f?l000000_o6`mL00ol0003o`l?Jo`000002ol;2f@04o`000?o2`][o0000o`00
00;o`/;I00?o0000okk2g?l000001?nn`M`01?l0003o_/7Kokk1fol00002okNoh003o`000?ni`=oo
^L3O00;o^L3O0_l00003ok70i@03o`000?o_]iCokkND00?o00000_o][hd01?l0003okJR2o`000?o[
YX<2o`000007onVJL_l0003o0000o`000?oRPU;o0000ol]=1P02o`000:Oooo]Z0_l000001?la01_o
0000odd9E_m=2EH2o`000003od8>Iol0003oE2Qn00?o00000_mA<8X2o`0000;oBc:A0_l000000om=
>9SoA36Eo`000002od/lWP07o`000?m1>:3o@CRPod4hX?m8@ZOo0000odU2YP04o`0000;oAdN^0_l0
0002od58/P04ocI4/ol]@;?o?djiocm>^@;o000000Go:dFjo`000?l0003o0000obQ7_@02o`000004
ocMDa?lYClCo:Do4oam:``;o>Ug;00?o9U;8o`000?lSDlX00_l00002ob]Lc`03o`000?lmJmOo?F_G
00;o<6KF00Co9f;Eo`000?m5M]goAGKM0ol00002odn1hPCo00000omIRnL4o`0000?oIIK[00?o0000
oenDjomOU>/03_l000000omo[?7o0000o`000003o`0000?oTkG_00?o0000oj?1kol000000_l00005
ojC2k`03o`000?nfc>_o000000Go]lcZ00Go0000okkAjOl0003ocMSQo`000003oloIh@03o`000?oA
f^3o000000;ofn7J00_o0000omgSfOl0003o0000oo3T`_l0003olNS1o`000?oij:ko0000oocTT@03
o`00017ooo]Z00?o0000oookJ_oonfX0>_oonfX3o`0000gooo]Z000WoookJP?o00009ooonfX01Ol0
003oa/CHolK4f?o6a=So000000?oa/?G0_l00004ol;2f@03o`000?o2`]Wo`/;I00;o`/;I0_l00003
okk1g0;o00001?nn`M/2o`0000?o^L3O0_l00002ok[0g`03o`000?na`>Go000000?o00000_o^]I@0
0ol0003okJn=onf_S@03o`0000;ojjJ300Co0000onVJL_l0003oiiMc0_l000001OoRPU;o0000o`00
0?o6A`Co00000:Gooo]Z00Go0000oc406ol0003o0000odd9EP02o`000003oe8LK_l0003o000000;o
E2Qn0_l00002oe4`RP;o000000?oDCJBo`000?l000000_mC?9T00om=>9So0000od/lWP02od/lWP05
ode0X_l0003o@CRPo`000?m8@ZL00ol00002oc`mZ007o`000?m7AjkoAdN^oc]4/Ol0003o@DRbo`00
0002ocI4/`03o`000?loC[Wo?dji00;o000000Co:dFjocmD`?loE<3o:4Nm0_lZBl001OlgE<Co0000
obU?a?lYClCo000000;o>Ug;0_l000001?lSDl[o?VGAociUdOl[G<l2obQLd004oce[eol0003o<6KF
oc1VeP;o00000_m5M]d01Ol0003o>77Mo`000?m?PN;o000000;oAGgS0_l00004oeV;i`03o`000?mA
R>Oo000000;o000000CoIIK[o`000?mOU>_o00001?meX^d00ol0003oL:3^o`000008oh6]l003o`00
0?nC]NooTkG_00;oTkG_1?l00009ojC2k`04o`000?ngc>[o]lcZokO<jP;o000000Go^LgYo`000?nn
dNWo_]7Yo`000003oloIh@04o`000?oAf^3odM[Pom7Jh0;o000000?ogN?Io`000?oLhMP00ol00000
1?oaj<7o0000o`000?ojijX4o`0001;ooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0000;ooo]Z00?o
0000oookJ_oonfX02ooonfX002Cooo]Z0ol0000XoookJP;o000000Coa/CGo`000?o6a=So00000oo6
`mL01_l0003oaL;GolG2eol0003o`/;Io`0000;o`/7I00Co0000ol;2fOl0003o00000_o2`MT00ol0
003o_/7Lo`000004okk1f`03o`000?nn`=_o_/3K00;o000000?o^L3Oo`000?nj`=l00onj`=l3o`00
00;ok[VJ00?o0000onjeU?o^]I@00ol00002on^]SP;o000000CojjJ3o`000?l0003o00000_oWUg<3
o`000003ommnDol0003oaTL400;o0000XOoonfX7o`000004oe8LK_l0003o0000o`0000;oE2Qn0ol0
00001_mA<8[o0000oeTkTomI>i?oDCJBo`0000?oDcbI00Go0000oe8oWOl0003oBcbNo`000002ode0
XPGo00000_ll?JP4o`0000;o>dBa0_l00002ocI4/`03o`000?loC[Wo?dji00;o<dRi00Ko:dFjocmD
`?loE<3o?eC0o`000?lZBl03o`000004obU?a?lZD/Ko0000ocYMb`;o:eO:00Ko8e?:ociUdOlnIM7o
?VGAo`000?lXG=03o`000003oc1Ve_l0003o000000;o000000?oAGKMo`000?lhLMd00ol00002odEm
h`Co00000_mIRnL2o`0000;oJIO[3?l00004oh6]l0?o000000?oPJg`o`000?l000000_l00004oiJg
kP03o`000?nT`^ooY<;_00Co00000_nVa>l01?l0003o]lcZo`000?l00004okW=j@;o000000Co`=?X
o`000?o?fN7o00001?oAf^000ol0003ogN?Io`000002omcQf003o`000?oZj/goj^[=00?o000000?o
n^NZo`000?l000000_l0000CoookJP03o`000?oonf[ooo]Z03;ooo]Z0ol00005oookJP03o`000?oo
nf[ooo]Z00_ooo]Z000QoookJP?o0000:_oonfX01_l0003obLCEolW4eOl0003oa/CGo`0000?oa/?G
00Co0000olG2eoo5`]OoaL;G0_l00004ol;1f@03o`000?o2`MWo`/7I00;o`/7I0_l00003okk1f`;o
00001?nn`=/3o`000004ok[0gol0003o0000o`0000;o^[oN00?o0000onjiV_o^^IX00ol00002onbc
U@;o000000?ojjf>o`000?oYZhh00_l000000ooXXhCo0000o`000002o`0000;oi9Ad1_l0002Noook
JPCo00000_m815801Ol0003oDQa^oe8LK_l0003oGS2000;o000000KoE2Qno`000?mN>HcoGSV<oe@a
R_l00003oeTkT`04o`000?mG?YWo0000oe<lV@;o00000_mB?id5o`0000;oB4:W00Ko0000odY5ZOl0
003o?3fXo`000?m4AZh2o`0000;o>dBa0_m4C;@2o`000003ocQ8]oloC[Wo000000?o<dRi00Co0000
ocmD`?loE<3o00000_lZBl02ocmJaP05obU?a?l0003o0000oc]Mb_l000000_l[ElX00ol0003o?VGA
ociUd@02obiOd@06obQLd?l0003o@foGo`000?l`I]Ko00000_m;N=d3o`000003ocQagOl0003oDh;R
00;o000000?oAGgSo`000?l000000_mMSNL4o`0000;oJIO[00Co0000of>EjomSUN_o00001?mhX^d0
0ol0003oLj7^og>QkP04o`0000CoQZc^00?o0000oiJgk_nF]nh01?nF]nh4o`0000OoY/C_00?o0000
okW=jOnicNT01?nicNT00ol0003o`=?Xol3Cj002o`0000?odM[P00Co0000om;Kgol0003o00000ooL
hMP01?l0003oj^[=o`000?o/k<X2o`000003oo[WZ_l0003onnB:00;o00004ooonfX00ol0003ooo]Z
oookJP0_oookJP?o00002?oonfX00ol0003ooo]ZoookJP0;oookJP007_oonfX3o`0002_ooo]Z0_l0
0003olW4e@;o000000Coa/?Go`000?o6`mOo00000oo5`]L01_l0003oaL;GolG2eol0003o`/7Io`00
00;o`/7I00Co0000ol;1fOl0003o00000_o2`MP00ol0003o_/7Ko`000004okk0f`05o`000?nn_m[o
_[oJo`000?ni_]h00_l00004okZogP?o00000_o/]iX2o`000003onbcUOl0003oj[6F00;o00000_oY
Zhh00ol0003oj:>4o`000002onJQQ@;o000000Coi9Ado`000?oQTWGo00000_oKNU<4o`0009Wooo]Z
1?l00002odP4DP?o000000CoDQa^o`000?mN<83oGS200ol00002oehiS0?o00000_mI>i<2o`0000;o
EcjI00?o0000oeQ3W_l000000ol000001?m@@j?o0000oeI9Y_mFBJH3o`0000;oBTFY00Go0000odA6
[_m4AZko0000odi>/@02o`000004ocm8]?m4C;CoA4bdo`0000;o>4Rg0_l00002oc=8^@04ocE=_Olo
E<3o0000oc5>`0;o:T_00oloF/H3o`0000;o@F;<00Go:eO:o`000?m4J=;o?VGAo`000002obiOd@04
o`000?m3KmOo@foGod=_e`;o00000_m;N=d01Ol0003o?WCMo`000?lhLMgo000000?oDh;R1?l00000
1?mMSNOo0000oeJ9iomFRNL7o`0000CoN:;]00Co0000og>Qk_mcXNko00001_n6[>h00ol0003oU[O^
oiJgkP04o`0000?oU[W`00?o0000ojK4konVa>l00ol00003ojS5kP03o`000?nicNWo000000;o0000
00Co^/kYo`000?l0003o00000_o2eNP00ol0003odM[Po`000002om;Kg`07o`000?oLhMSog>7HomcQ
f?l0003og^;Go`000002onc/bP03o`000?oek[Oo000000Co00005?oonfX00ol0003ooo]ZoookJP0[
oookJP?o00002ooonfX00ol0003ooo]ZoookJP0;oookJP006ooonfX3o`0002gooo]Z00?o0000olW4
eOo9a=D00_o9a=D01_l0003obL?EolW3eOl0003oa/?Go`0000?oaL;G00Co0000olG2eoo5`]OoaL;G
0_l00004ol;1f@;o00000oo2`MP2o`0000?o_/3K0_l00004okjofP05o`000?ni_]go^KkMo`000?nj
_mh00ol000001_o/^ioo0000o`000?o/]i[o0000on^eV`;o00000_oZ/IH00ol0003ojJ^>onV[SP03
o`0000;oiZ6500Co0000on>NQ_l0003o00000_oQTWD9o`0009Cooo]Z0ol000001_lT00_o0000o`00
0?m815;o0000oe`TL0?o00000_mN<803o`0000;oGSV<00Co0000ofE3U?l0003oG3bC0_l000000omN
@i[o0000oeLnV@04o`000005oe8oWOl0003oFdRRoe13Xol000000omFBJH02?l0003oC4JZodY5ZOm:
AJWoE4f]o`000?m4AZko00000_m>C[42o`0000;oA4bd00?o0000ocQ8]olhB;L00_m8E;`00olcB;Wo
0000ocE=_@03o`000003oc5>`?l0003o000000;o?e[60_l`DlH2o`0000;o@F;<0_l000001_m4J=;o
0000o`000?l^Gm7o0000odUaf0;o@foG00Go0000ocQYeol0003oBgSMo`000003ocidg@;o00000_mC
P^800ol0003oBGkRo`000002of6>iPCo00000_m/V>X00ol0003oIYKZofJFjP0?o`000003ohJ/k_l0
003o000000SoU[W`0_l00007ojS5kP03o`000?njc^Wo^/kY00;o^/kY00?o0000ol;Ej?o2eNP00_o2
eNP2o`0000;od]_O0_l00002omcQf009o`000?oNh]Oo0000o`000?o/k<[o0000onc[b_l0003omNng
00Co00005OoonfX00ol0003ooo]ZoookJP0VoookJPCo00003ooonfX00ol0003ooo]ZoookJP0:oook
JP006OoonfX2o`0002oooo]Z00Co0000olW4eOo9a=GobLCE0_l00003olW3e@;o000000Coa/;Go`00
0?o5`]Oo00000oo5`]L01_l0003oaL7FolG1e_l0003o`/7Io`0000?o`/3H00?o0000ol;1f?l00000
0_o2`=P00ol0003o_/3Ko`000004okjofP04o`000?nn_m[o_[oJo`0000;o^KkM0_l000001Onk_mgo
0000o`000?l0003ojkVO00;o00000_o[]I/00ol0003oj[6FonZaUP03o`0000;oijV?1?l00002on>N
QP;o000000CohI9eo`000?oNSgKo00000_oPQf<3o`000003olmK:Ol0003o0000093ooo]Z1_l00000
1?mQ6eko0000o`000?mL9703o`0000;oGS2000Ko0000ofLnS?l0003o0000oehiS?l00002ofE3U003
o`000?mL?9?o000000;oGT>J0ol000001?mKA9goF4>No`000?l00002oe]8XP;o00000_mFBJH01Ol0
003oCTJXo`000?m:AJWo000000;oE4f]0_l00002odi>/@;o@dVb00?oA4bdo`000?m<D[L00ol00002
odQD_0;o000000So=DfmodMI`_m7FL;o<Dk0ocAB`ol0003o?e[6o`0000?o<5?600?o0000od5Rc?m1
H/`00_ldGLd01_m4J=;o>6CBocQTd_l0003o;UoAo`0000;oBG7H0_l00002oe1jg@?o000000?o?WCM
o`000?mGQ>800_mGQ>84o`0000;oHHkV00?o0000oeZ;i_mJRnH00_l000000om/V>[o0000ofJFjP02
ofJFjP04o`000?mkXncoNj?/o`0000CoMZ;]00?o0000ohR]k_n8[Nh00on8[Nh2o`0000;oU[W`1?l0
0002oiNjl003o`000?nXaNkoZ<G^00;oZ<G^0ol00002ojW6kP05o`000?njc^Wo0000okc?j?l00000
0_o2eNP2o`000004olGGiol0003od]_Oo`0000;oe=gN0_l000000ooNh]Oo0000on3Qe002o`0000;o
k>_:00Co0000ooG_]ol0003on>R?0_l0000FoookJP03o`000?oonf[ooo]Z02;ooo]Z0ol0000Coook
JP03o`000?oonf[ooo]Z00[ooo]Z000FoookJP?o0000<?oonfX01Ol0003obLCEo`000?o9a=Go0000
00CobL?E00Ko0000olS2e?o8`]Co0000olK2eol00003olG2e`03o`000?o5`MKoaL7F00;oaL7F00?o
0000ol;0f?o2`=P00oo2`=P01?l0003o`/3Hol;0f?o2`=P2o`0000?o_[oJ0_l00004okjofP05o`00
0?nj_]go^[kMokZngOl000000_o[_:@01?l0003ojkVOon^iWol00002on^eV`?o00000_oX[YH2o`00
0004onNYSol0003oi:J@onBVT0;o000000?ohij6o`000?oPVhL00_l000000ooNSgKo0000o`000002
o`0000;og85P1Ol0002<oookJPKo00000_mQ6eh2o`000007oe`TL?l0003o0000ofXiPol0003oGS20
o`000003ofLnS0;o00000omU@i@00omL?9?o0000o`000003o`0000?oFdBM00Wo0000oe]8X_l0003o
FdRRo`000?mHBjOo0000oeI9Y_l000000om>AZP01?l0003oE4f]oeA=[OmDCJd2oda=/@;o00000om3
BK800ol0003oC5:godaB]`02o`0000;oB5Bl0_llCk`01_leCKgo0000odMI`_m7FL;o0000ocAB``?o
00000_l`DlH2odMUc@05od5Rc?l0003o=5g=odAXd_l000000olhI=802?l0003oBG7HodUaf?l0003o
?6gIo`000?m@N]go00000_m6Mmh3o`0000?oEhCR00Ko0000odn0h_m?P>;o0000of6>i_l00002oeZ;
iP03o`000?m`V^[oL9[Z01;o000000CoR:g^o`000?l0003o00001onG^_04o`0000KoZLK^00Co0000
okc?j?nlcnSo_<oX0_l00003olGGi`;o00000ooDgMh00ol0003og^;Go`000002on3Qe003o`000?o/
jl[ok>_:00Co000000?on>R?o`000?l000005_oonfX00ol0003ooo]ZoookJP0OoookJP?o00005_oo
nfX00ol0003ooo]ZoookJP0:oookJP004ooonfX3o`0003;ooo]Z00Co0000olc4dol0003obLCE0_l0
0003olW3e@04o`000?o8`]Cob<;DolS2e0;o000000Coa/7Fo`000?o5`]Oo00001?o5`MH01?l0003o
aL3Fo`000?o2`=P2o`0000;o`/3H00?o0000ol;0f?l000000_o2_mL00ol0003o_[oJo`000004okjo
fP03o`000?nn_]Wo000000?o^[kM0_l000001?o[_:Co0000o`000?o[^Il3o`0000;ojK>K00Go0000
onR^U_oX[YKo0000onJ/U`02o`0000;oi:J@00Co0000on:TTOl0003o00000_oPVhL2o`000004on>E
N?l0003oh9=ion2CN@?o000000Cof7eOo`000?o8DR?ob58S0_l00028oookJPCo000000CoH1QJo`00
0?l0003oHA]N0_l000001_mZ;gCo0000o`000?mX>8;o0000ofXiP`;o00000omW?X`2o`0000?oID>D
0ol00002of54V@;o00000_mKA9d00ol0003oI4jRo`000002o`0000?oF4^W0_l00003odi6Z0;o0000
00CoE4f]o`000?m<CK7oC4fa0_l00003od=9/P03o`000?m<D[OoC5:g00;o@E2k00?oB5Blo`000?ll
Ck`00_llCk`3odMI`P03ocQC`_l0003o000000;oAeo800?o<5?6o`000?laELL00_m7ILd2o`000003
ocAMcOl0003o000000;o>6CB0ol000001?m9LMSo0000oca]fOllKMT2o`0000;oAWON00Ko0000odAf
gOl0003o0000oeN4h_l00002odn0hP03o`000?mUT>Ko000000Co000000?oL9[Zo`000?mZUnX00omZ
UnX01?l0003oOJC/ogfTk?l00004ogVRk003o`000?n;[^goRjk]00?oRjk]00?o0000ohJ^kol00000
1onG^_000ol0003oZLK^ojW6kP03ojW6kP?o000000?o[<S^o`000?nlcnP00_nlcnP00ol0003oaMOW
olGGi`02o`0000;oamWW0_l000000ooFg]go0000o`000003on3Qe006o`000?o/jl[o0000ong/b?l0
003omnnb1?l0000GoookJP03o`000?oonf[ooo]Z01_ooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z
00[ooo]Z000@oookJP?o0000=?oonfX01Ol0003oc<CColc4doo<a=?o000000;obL?D00?o0000olW3
eOl000000oo8`]@01Ol0003ob<;DolS2e?l0003oa/7F00;o00000oo5`MH00ol0003oaL3FolG0eP02
o`0000Go`/3H0_l00003ol:oe`04o`000?nn_m[o_[oJokjofP;o00000onn_]T00ol0003o^[kMo`00
0002onVmY`;o000000GojKZTo`000?oY]ioojKNOo`000002onVcV`?o00000ooV[9L3o`0000?ohZBA
0_l000000ooPVhOo0000o`000002o`0000;oh9=i00Go0000omf@NOl0003o0000omQmG`05o`0008Co
oo]Z1Ol00003of0HFP?o00000_mZ;g@2o`0000;oJ3R20ol00003ofLnS003o`000?m`BYCoID>D00?o
000000CoJDZJo`000?mQA9WoHDBI0_l000000omRBIko0000o`000003ofA>XP03o`000?mHBjOoF4^W
00;oF4^W0_mHCJ/01Ol0003oCTJXo`000?l0003oDTf^00;o00000_m<CK401?l0003oCe2co`000?m3
BK84o`0000?o@E2k0_l00002oca?_003ociD`?m7FL;o000000;o>5?200Co=5;3o`000?m7GlSoAeo8
0ol000002Om7ILgo>f3=oc]PcOldGLgo0000odY/dol0003o>6CBo`000003odmdf0;o000000?o?6gI
o`000?mDOMd00_l000000om6Mmko0000o`000002oeb6hP?o000000?oCh3Ro`000?l000000omOS>H7
o`000004ofZGj_l0003oOJC/o`0000GoNJ;/00?o0000oh^^kOn;[^d00_l000000on;[^go0000o`00
0004o`0000CoVK_`00?o0000ojW6k_l000000_l00005ojc8kP;o000000Co_]3Xo`000?o5enOo0000
0oo7fNL00ol0003ob]cVol[LiP02o`0000?oh>7D00Go0000on;We_l0003o0000ong/b003o`000003
ooOWRol0003o000001Sooo]Z00?o0000oookJ_oonfX05ooonfX3o`0001cooo]Z00?o0000oookJ_oo
nfX02_oonfX000gooo]Z0ol0000foookJP07o`000?o<a=?oc<CColc4dol0003obl?Bo`000002olW3
e005o`000?o8`]Cob<;DolS2e?l000000oo8`]@2o`0000;oaL7F00?o0000olG1e_l000000_o5`=H0
1Ol0003oaL3EolG0eOl0003o`/3H00;o00000oo2_mL01ol0003o`[oGo`000?o2_mOo0000okjof_l0
00001_nn_]T2o`0000;ojKfW00Co0000onRkYol0003o00000_oY]il3o`0000;oik6K0_l00002onJ/
U`04o`000?oSZYOo0000o`0000;ohZBA00?o0000omnQTOl000000_l000000ooRWHOo0000o`000002
o`0000;ogI1i0ol00002omAhG`Go0000OooonfX6o`0000;oH1QJ0ol00002ofX_M0;o000000?oLd24
o`000?mX>8800_l000000omaAHgo0000ofLnS005o`000003ofE3U?l0003oJDZJ00;oJDZJ00CoHDBI
o`000?mTBYgoI4ZM0_l00004ofA>XP05oee=Yol0003oF4^WoeQ;Yol000000omHCJ/01?l0003oE4j^
oeA>[_l00002oeYC/003o`000?m<CK7o000000;oCe2c00Co0000odQ@]ol0003oC5:h0_l00002od5@
^`;oCeZn00?o?4nlo`000?lnE<000ol00002ocQC`P03o`000?m7GlSoAeo800?o>ec:00GoAfG=o`00
0?lkH<go>f3=o`000003odY/d`;o00000_m?M=P00ol0003o@g3Io`000002o`0000?oE7gM0ol00000
1?mLQ^;o0000oeB2h_mDP^86o`000004oen<i_mcVnWoLi_Yo`0000?oKYSY3?l00003ohf_k@03o`00
0?n9[noo000000SoVK_`00?o0000ojc8k_n/b>h00_n/b>h3o`0000;o[/W^00Co0000okk@j?nnd>So
00000oo7fNL01?l0003ob]cVol[Li_o:g>H2o`0000;oh>7D00Go0000on;We_oRimKo0000ong/b004
o`000003ooOWRol0003o000001Sooo]Z00?o0000oookJ_oonfX04ooonfX4o`0001oooo]Z00?o0000
oookJ_oonfX02_oonfX000cooo]Z0_l0000foookJP;o00000oo<a=<01Ol0003obl?Bol_3d_o;`m;o
000000;obL;D00?o0000olS2e?l000000oo8`]@01?l0003ob<7ColS1dol00002olG1eP;o000000?o
aL3Fo`000?o5`=D00oo5`=D00ol0003o`[oGol:oe`04ol:oe`;o000000?o`[oGo`000?l000001Onn
_]T00ol0003o_kkIoknnf@03o`0000?oj;^W0ol00002onRdWP;o000000?oik6Ko`000?oU[i`00_l0
0002on>ZU`04o`000?oQZ9So0000o`0000?ogj6A1?l00002omnKQ`;o000000CogI1io`000?oIS7[o
fHaj0_l000001OoDN5oo0000om1cG_l0003o^SdD00Go0000MooonfX7o`000005of/OFol0003o0000
o`000?m`<g@01?l00003og=0Q0;o000000?oL4F>o`000?maAHd01?l00002og1:U003ofE3U?l0003o
000000?oJDZJ00Co0000ofA:WOmTBYgoI4ZM0_l00004ofA>XP;oGDfW00Go0000oeQ;Yol0003oFe2[
oeQ=Z`02o`0000;oE4j^00Co0000oeYC/?mJDk3oFU>`0_l00002odm@/`04oeMG]_l0003oB52go`00
00;oDeRj00?o@E2ko`000?l000000_m?F[h2o`000003ociD`?m>GlCoCUo400;o>5?20_m=HlP01?m7
GlSo0000oc]Lb_lkG<X3o`000006oc]PcOl0003o0000o`000?m:K=?o00000_lnJM@00om?M=So0000
od=`f@02od=`f@?o000000?oE7gMo`000?m;NMd00_l000001?mLQ^;o0000oeB2h_mDP^82ofVAiP03
o`000?mOSnSoGhoX00;o000000?oLi_Yo`000?m^V>T01?m^V>T2o`0000KoO:?/00?o0000ohf_kOn=
[nd00on=[nd00ol0003oRJo_o`000002oiVkl0?o00000onK_O001?l0003o[<S^o`000?l00006ojk9
kP03o`000?o0dNOo000000;oamWW00Ko0000ol[Li_o:g>Kob]cVo`000?o;e^83o`0000;oh^OF0ol0
00001?o^k<Ko0000o`000?ogkjd3o`0001Wooo]Z00?o0000oookJ_oonfX03ooonfX3o`0002?ooo]Z
00?o0000oookJ_oonfX02_oonfX000cooo]Z00?o0000oookJ_l00000=?oonfX01_l0003oc<CBolc4
d_l0003oc<CCo`0000?obl?B00?o0000ol_2d_l000000_o9`]@01Ol0003ob<;DolS2e?o8`]Co0000
00?ob<7C0_l00003olG0e@;o00000oo5`=D2o`0000?o`[oG0_l00003ol:ne`?o00000onn_]T2o`00
00;o_kkI00Co0000onRnZOoX_ZWo00000ooX^jL3o`0000;oj;BN00Co0000onJcWol0003o00000_oU
[i`2o`000004on>ZUol0003ohJRHon6XV0;o00000_oOXI42o`000006on2RT?l0003o0000omnKQol0
003og9R80_l00002omV<NP03o`000?oER7[o000000;o000000?od7=No`000?l000000_l00002olMH
=`;o0000LooonfX6o`0000?oJamK0_l00002og0cM0?o00001?mc@8@2o`000003og15S_l0003o0000
00;o00001?m`BY@2o`0000;oJTZJ00Co0000ofU:V_l0003o00000_mTBYd01?l0003oK5:Ro`000?l0
0002ofA>XP;oHe6X00?oGDfWo`000?l000000_mKD:/01_l0003oGe>]oemC[Ol0003oE4j^o`0000?o
FU>`00Co0000odm@/om?D;?o00000_mGEkH2o`0000?oDeRj00Co0000odAB_?m?F[koCeZn0_m4EKl0
1?lnE<3o0000odiOa?m>Gl@2o`0000;oCF?80_l00002oc]LbP;oCVW>00?o>f3=o`000?m@Km<00_m@
Km<2o`000003ociYe?l0003o000000;o000000?o@g3Io`000?l000000_mIOmd3o`0000;oHHSR1?l0
00000omYTNKo0000oen?j004oen?j003o`000?m^V>Wo0000013o000000?oSJo]o`000?l000000ol0
0007oi^ml003o`000?n^bNko[/W^00;o[/W^0ol00002ok3<kP04o`000?o0dNOo0000o`0000;ob]cV
0_l00003ol_FhP;o000000Coh^OFo`000?oTj=Co00000_o^k<H2o`000004ooO_[Ol0003o0000o`00
01[ooo]Z00?o0000oookJ_oonfX02ooonfX3o`0002Kooo]Z00?o0000oookJ_oonfX02_oonfX000co
oo]Z00Co0000oookJ_oonf[o0000<_oonfX00ol0003oc/CAo`000002olc4dP05o`000?o;`m;obl?B
ol_3d_l000000oo;`]801_l0003obL;ColW2dol0003ob<;Do`0000?ob<7C00Ko0000olS0doo8`=?o
0000olG0eOl00002olFoe@03o`000?o5`=Go000000;oaKoE00?o0000ol:oeol000000oo2_]L01?l0
003o`[kFol:ne_o2_]H2o`000003okjnfOl0003o_kkI00?o_kkI00?o0000onRnZOoX_ZT00_l00000
1OoX^jOo0000onJiYooV^JOo000000;oj;BN00Co0000onJcWooV/ioo00000_oU[i`01?l0003ohjfL
o`000?l00002on6XV009o`000?oNYISo0000o`000?oMWi;o0000on2RT?l0003ogYn@00;o00000_oL
V8P4o`0000?oeHQj00Co0000om1cG_l0003o00000_oCNfL3o`000004oki<;ol0003o0000o`0006go
oo]Z1ol00004of/OF`;o00000om`<g@00ol0003oNdJ6o`000002og=0Q0Go000000CoL4F>o`000?l0
003o00000_m`BY@2o`000004og9@Vol0003oJTZJofY:VP;o000000CoK4nNo`000?mTBYgo00000om/
DZ800ol0003oI4jRof=AZ002of=AZ006o`000?mOD:WoGe2Yo`000?mKD:_o00000omODjd3o`000003
oeYC/?l0003oDE2b00;o00001?mGEkH02?l0003oDeRjoe=H^_mCF;[oBENmo`000?m?F[ko00000om4
EKl00ol0003oCUo4odiOa002od=LaP04o`000?m=HlSo@Ek9od5Nb@;o>ec:0om>JLh2o`0000;oD6oC
0_m4Jm@00ol0003o?VWDo`000002oeAgf0Co000000?oFGoMo`000?m?OMl00_l000000omQR>;o0000
oeJ6i002oeJ6i0Ko000000?oGhoXo`000?l000001OmdVnT2o`0000KoPZK/00?o0000oi2`kOn@/>d0
0_n@/>d01?l0003oS;3^ohb`k_l00002oi^ml0Co00000onM__001?l0003o[/W^o`000?l00006ok3<
kP;o000000?ob]cVo`000?l000001?o;e^801Oo=gNGoenCPo`000?l0003oi>SD00;o000000?ok^c6
o`000?l000000_ogkjd3o`0001_ooo]Z00?o0000oookJ_oonfX01ooonfX3o`0002Wooo]Z00?o0000
oookJ_oonfX02_oonfX000cooo]Z00Go0000oookJ_oonf[ooo]Zo`00000`oookJP05o`000?o>a=7o
c/CAolk4dOl000000_o<`m800ol0003obl?Bo`000003ol_2dP06o`000?o;`];obl;Bo`000?o9`]?o
00000oo8`M<01?l0003ob<3ColS0doo8`=<2o`0000CoaKoE00Co0000olFoeOo5_mGoaKoE0_l00003
ol:ne`03o`000?o2_]Ko`[kF00?o`[kF0_l00003oknnf@Go00000_oW_:T2o`0000;oi[VW0ol00003
onJcW`?o00000ooS[I`3o`0000?ogZFH1?l00003omjOT0;o000000Cog9R8o`000?oIU8SofIB80_l0
0002omF8NPGo000000?odg]Wo`000?o>MFD00_l00002oki<;`Co0000IooonfX8o`000003og@XGol0
003oJamK00?o000000?oNC]go`000?m`<g@00_l00002og]6QPGo000000CoND^>o`000?l0003o0000
0omdCID2o`0000?oLU2K0ol00002ofe?WP?o00000om/DZ82o`000003ofEAY_l0003oHe6X00;o0000
0omOD:T2o`0000;oGe>]00Ko0000oe]D/OmKE;7o0000oeYC/?l00002oe5@/P;o00000omGEkH01?m@
E[[o0000oe=H^_l00002odUG_@?o00000_m4EKl01?m7F/;o0000odiOa?l00002od=LaP04odeSb?l0
003o@Ek9od5Nb@;o00000_m>JLh2od=Vd003o`000?m@Km?o000000?oA6_D00Go0000oeAgf?mDMmSo
E7OHo`000002odYbf003o`000?mIOmgo000000;oCggO1?l00002oeJ6i003o`000?m[T^KoJi;V00;o
Ji;V1ol00002ogBKj@03o`000?n2Y^coPZK/00GoPZK/00?o0000oi2`kOn@/>d01ol00008oifnl003
o`000?n`c>ko/<c^00;o/<c^0ol000001?ncc^ko`];Wo`000?l00003ol_FhP;o00000_o=gND01Ol0
003of^ONom[Wg_l0003oi^WB00;o000000?olN_2o`000?ogkjd01?l0000KoookJP03o`000?oonf[o
oo]Z00Cooo]Z0ol0000]oookJP03o`000?oonf[ooo]Z00Wooo]Z000<oookJP03o`000?oonf[ooo]Z
00;ooo]Z00?o0000oookJ_oonfX0:ooonfX2o`0000?oc/CA00?o0000olk3d?l000000_o<`m801Ol0
003obl;Bol_2d_o;`];o000000?obl;B0_l000001?o8`M?o0000olS1dol00003olS0d`06o`000?o7
_m?oakoCo`000?o5_mGo00000_o5_m@00ol0003oaKoEo`000002olFne003o`000?o2_]Oo000000Co
`[kF00Wo0000ol:me_o2_MKo`[gFo`000?no_]Wo0000okjlf?l000000_oX_j/01Ol0003oikbYonNl
ZOl0003oiKZY00;o00000_oT]jL4o`0000;oi;6O0_l00002on>]W004o`000?oQZico0000o`0000;o
gZFH00?o0000ombSVOl000000_l00002omjOT004o`000?oKWI7o0000o`0000;ofIB800?o0000omFA
ROl000000ol000000ooGRg_o0000omB8O003o`0000;ocWEU1?l000000ong?bCo0000o`000003o`00
05oooo]Z2Ol00003og@XG`?o00000omi>gL3o`000003ogU5QOl0003oNdJ600?o00000omiBhh2o`00
00CoM4fE0_l00003og9@V`;o00001?m]Cih2o`0000?oK5:R00?o0000ofaFYol000000_mUDJH3o`00
00;oGe2Y00Go0000ofMG[?l0003oGe>]o`000003oe]D/@;o00000omAD;802OmFEkOo0000o`000?mG
EkKo0000oe1F^_l0003oDURjo`000002odUG_@?oEEo000GoA5Foo`000?m7F/;o0000odiOa002o`00
000:od=La_l0003o0000o`000?m1G/Wo0000od9ObOl0003oCVW>o`0000;o@fK@0ol00002odA[e0?o
000000CoE7OHo`000?m:L]SoBW;H0_mNP]d2o`000003odmmgol0003o000000;oHh[R0_l000000omF
Q^Co0000of^BiP04of^BiP;o00001?mgWNT<o`0000;oT[7/00Go0000ohnak_n?/NkoSk7^o`000002
oifnl0Co00000_nP`>l00ol0003o/<c^o`000002o`0000Go/lk^00Go0000ol_Fh_o;e^;obmKRo`00
0003olgMi@05oloOi?l0003of^ONo`000?oMjm`00_l000000ooajl;o0000oo7``@05o`0001cooo]Z
00?o0000oookJ_l000000ol0000`oookJP03o`000?oonf[ooo]Z00Wooo]Z000;oookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0:OoonfX01_l0003oclC@olo4d?l0003oc/CAo`0000?o
c/?@00Ko0000olc2dOo<`]7o0000ol_2d_l00003ol_2dP05o`000?o:`M7ob/7Ao`000?o8`M<00ol0
00000oo8`=?o0000olNod`02olNod`;o00001?o5_m@2o`0000?oaKkD00Co0000ol:ne_o2_]Ko`[kF
0_l00005ol:meP;o000000Co_[cHo`000?oX_j_oj;n[0ol00003onFjZ@04o`000?oT]jOoi;NWo`00
00;oiKBS00Go0000onBaWooT/Ioo0000on:_X002o`0000;ohJ^L00Co0000omjXWOl0003o00000_oL
XiT2o`000003omfSUol0003o000000?ofifA1?l00003omFAR@Co00000ooDR7`4o`0000;obFmT1Ol0
0002okmC?PCo0000E_oonfX;o`000003og/^HOl0003oM2QO00?o000000CoPD9io`000?mi>gOoNC]g
0_l000000on1BhKo0000ogU5Q@03o`000004oh1@Sol0003oND^>ogU;SP;o000000?oOE>Fo`000?md
CID00_mdCID02?l0003oN5>Jog9@Vol0003oLU2Ko`000?meEIoo00000om]Cih01_l0003oLeNRo`00
0?l0003oK5:Ro`0000;oK5JW00?o0000ofEAY_l000000_m/EjT00ol0003oGe2Yo`000003ofMG[0;o
00000omKE;402?l0003oFeJco`000?mAD;;o0000oeIG]ol0003oEUNg0_l00002oe1F^P05o`000?mI
GKco0000o`000?m<FKl00omEGl02o`000005odMJ`_l0003oE6?5oeASaOm3G<H00omCIlX00om1G/Wo
0000od9Ob@02oeA/cP;o00000_m3I]02oeEce003o`000?m4JmCo000000?oFG[I0_l000002?m:L]So
0000oej2gOl0003oE7oOo`000?m?OMoo00001OmSR^84o`0000;oJi;V00?o0000of>@iol000001Omg
WNT00ol0003oP:S^oh2XkP05oh2XkP05o`000?nB/NcoT[7/oi:ak?l000000_n?/Nh4o`0000OoX<3_
00?o0000ok?>k_ncc^h00oncc^h2o`000005okK@kOl0003o0000ol_Fh_l000000_o=gND00ol0003o
cmoToloOi002o`0000?ogN_L0ol000000ooal<7o0000ooW]Z002o`0001cooo]Z0ol0000doookJP03
o`000?oonf[ooo]Z00Wooo]Z000;oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003oclC@olo4d002olo4d007o`000?o>`m3oc/?@olk3d?l0003ocL;@o`000002olc2
d@05o`000?o;`];obl;Bol_2d_l000000oo:`M42o`0000?ob<3B00Go0000olNodoo7_m?oakoCo`00
0002olNodP03o`000?o5_mCo000000?oaKkD00Oo0000olFne?l0003oaKkDo`000?o2_]Ko000000Go
`[gF00?o0000ol:meOo2_MD00_l00002onRoZ`04o`000?oV_J_oi[f[o`0000?oiKZY0ol000000ooR
]:Oo0000onFdX`03o`0000?ohZnP1?l00002omjXW@;o00000_oLXiT00ol0003ogJ>GomfSU`02o`00
00;ofifA00?o0000omRJTOoHVY400_l00002omFAR@;o000000Koei>9o`000?l0003o0000omB8O?l0
0002om24O0Go00000oo<Mf`4o`000003okI5=?l0003o000000?o0000CooonfX6o`000003ofL3;_l0
003o000000;o00000_mk;V44o`0000CoPD9i0ol00002oh5;QPGo00000_n0D8l3o`0000?oOE>F00Co
0000ogA=UOmdCIGo00000_mhDiX2og9@V`;o000000GoMEFOo`000?m]CikoKDnNo`000003og=GXP?o
00000_m/EZL00omUDJKo0000ofaGZ@03ofaGZ@03o`000?mWEjcoIeN/00;oIeN/0_mPE[001?l0003o
FeBao`000?mMEk<2oe]F/`;o00000_mFEkL01Ol0003oGEbhoeeL^?l0003oD5Jj00?oFEfl0_l00003
oeEO`0;oBe_100?oAe[2o`000?mDHlD00_mDHlD01?l0003oDfO:oe=Wb_mCIlX2o`0000;oE6c>0_m9
J=000ol0003o@fK@o`000003oeEce0;o00000_mIN]T01_l0003oCWSKo`000?l0003oGX;Mo`0000?o
E7oO0ol00003of>:hP;o00000om_U>H7o`0000;oMigY0_l00004oh2XkP;o000000?oP:S^o`000?l0
00001?l00002oi6bk@03o`000?nP`>ooX<3_00;oX<3_0ol000000onR`^oo0000ok?>kP03ok?>kP04
o`000?nfd>go]]3]okK@k@?o00000_o=gND01Ol0003ocmoToloOi?o?gnCo000000?ogN_L00?o0000
omcWfol000001_l0000IoookJP?o00000_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z00Wooo]Z000;oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX09OoonfX01Ol0
003oclC@olo4d?o?a=3o000000;oc/??00?o0000olk3d?l000000oo=`]001_l0003obl7Aol_1dOl0
003obl;Bo`0000?ob/7A00[o0000ol[0dOo:`=7o0000olS0d_l0003ob;oBo`000?o7_m?o00001?o7
_m800ol0003oaKkDolFne003olFne0;o000000?oaKkDo`000?l000001?o2_MH00ol0003o`[gEol:m
e@03ol:me@;o000000Coj;n[o`000?oV_J_oi[f[0_l000001_oU^ZWo0000onBhZOoT^:Wo0000on:d
Y`;o00000_oT/Z82o`0000;ohZnP00Co0000on2]X?oP[J3o00000_oNZ9d01Ol0003ofjJMo`000?oL
XiWo000000;ogJ>G00Co0000om^QUol0003o00000ooHVY400ol0003oeINBo`000003o`000004omNC
ROl0003oe929omB@R@?o00000_o@Q7`00ol0003oc81lolb0O005o`0000;oaVmX1Ol000000on/=27o
0000o`000005o`0004;ooo]Z2Ol000000omZ0BGo0000o`000002o`0000;oPS=Q1?l00002ohM7NP04
o`000?n1@WWoPD9ioh52N@?o000000?oPD^6o`000?l000001?l00002ogm@T003o`000?n0D8oo0000
00GoOE>F0_l00004ogQCVP06og9@Vol0003oMEFOogEEWol0003oMEFO0_l00003og=GXP;o00000_m]
EZH00ol0003oK5JWo`000004ofaGZ@;o00001?mWEj`3of1F/0;o000000?oGENco`000?mKE[<00_mQ
FkD00ol0003oEUNgo`000003oeeL^0;o00000_mIGK`2oe5L`0;oEEo000Go0000od]K`Om;Fl7oBe_1
o`000003oeASa@04od]Rb?l0003oDfO:oe=WbP;oBFG=0_l00004odUXd0;o00000_mELm@01Ol0003o
Bg7Fod]ae_mIN]Wo000000?oCWSK1ol00003ofR<hPCo00000om_U>H00ol0003oJ9;Wo`000003og^N
j@So00000on2Z^h01?l0003oUK?/oiFck?l00005oi6bk@04o`000?nP`>oo0000o`0000GoX/;_00Co
0000ok?>k_l0003o00001?nfd>d01Ol0003o_]G[o`000?o=gNGo000000?ocmoT0_l00002omg[g005
o`000?oLim_og>OKo`000?o[ll`00_l000000oobm:co0000o`00000FoookJP?o00001_oonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z00Wooo]Z000;oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX09?oonfX2o`000003olo4d?l0003oc/??00?oc/??00Co0000olg2d?o=
`]3ocL;@0_l00003ol_1d@?o000000?ob/7Ao`000?o:`=400_o:`=42o`0000?ob;oB0_l00003olNo
dP;o00000oo5_]@01?l0003oaKkColFndoo5_]<2o`000003olBmdol0003o`[gF00;o00001?o2_MD2
o`0000;oikn]00Co0000onJmZooV_J_o00000_oU^j/2o`0000;oi;RY0_l000001_oR]:Oo0000onBb
X_oT/Z;o0000on:`X`;o00000ooP[J03o`0000?ofjJM1Ol00002om^QU`?o000000?of9ZAo`000?oE
Ui800_oEUi84o`0000?oe92900?o0000om2<ROl000000_l00002olb0O0;o00000_o=PWh3o`000004
olI_J?l0003o`VUVol9YIPKo00000_naAC`7o`0003Kooo]Z1ol00002ogdG=P03o`000?mZ0BGoJP4U
00Go00000_n2<f44o`0000CoQdMj00?o0000oh52NOl000000_l000001On8D8Oo0000o`000?l0003o
PD^600;o000000?oQUF@o`000?moD9000_moD903o`0000CoOE>F0_l00004ogQCVP;o00000omeEIl3
o`0000?oLeNR00?o0000ogAJY_l000000_m]EZH3o`0000?oK5NY00Co0000ofYJ[_l0003o00000_mW
Ej`2ofAI/007of1F/?l0003oIU^bofIK/_l0003oGENco`000003of5K]@;o00000omMG;P2oeIL_003
oeUM_?l0003oDEc000;oDEc00_l00003od]K`@;o000000CoE6?5o`000?m;H/SoBf;80ol00002odUU
c@?o00000_m9J=001Ol0003oFgKDoe]fe?mELmCo000000;oBg7F1Ol000000om>N=_o0000of:4gP02
of:4gP?o00000omXS>800ol0003oH8WSof29h`07o`0000CoNikY00Co0000ogBMjomdWN_o00001_n2
Z^h00ol0003oUK?/o`000003oi6bk@Co00002?nR`^l01?l0003o]]3]okK@kOnfd>d2o`000003okS?
k?l0003o_]G[00;o00000oo?gn@00ol0003od^3Som;Ph`02o`0000;og>OK00CognSJo`000?l0003o
jo;=1?l0000CoookJP?o00002_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z00Wo
oo]Z000;oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX08OoonfX2o`0000;od<C>
0_l00003olk3c`05o`000?o>`/oo0000olg2d?l000000_o=`/l00ol0003obl7Ao`000003ol_1d005
o`000?o:`=7ob/3Aol[0dOl000000_o:_m000ol0003ob;oBo`000002olRodP03o`000?o7_m;o0000
00;oakkB00?o0000olFne?l000000oo5_]<01_l0003oaKgColFmdol0003oa;gCo`0000Co`[gE0_l0
00001?o1^mGo0000onNo[OoW_jd2o`000006onJmZol0003oiK^[onFkZol0003ohkV[0_l00002on:f
Z@;o00000_oT/Z800ol0003oh[2Son:`X`02o`0000;oh:fP00Co0000omjZXOl0003o00000_oKYYd2
o`0000;og:FL0_l000001?oKXIOo0000omRNUooHWYL3o`0000;oeINB0_l000001_oFV97o0000o`00
0?l0003oe929o`0000?od8b91Ol00003olf2OP03o`000?o8OGko000000;o00000_o2JFH2o`0000;o
`Va[1_l000000onY=2Wo0000o`000009o`0002Kooo]Z3?l00002ogdG=PKo00000on<?VL4o`0000;o
STak00?o0000ohM7N_n7AgX00_n7AgX3o`000005ohQ@Qol0003o0000o`000?n8D8L00ol00003ohIE
T0Co00000_n3F9H2o`000005ogeCU_l0003o0000oh1IVol000000_mhDiX2o`000005ogeJW_l0003o
MEFOogEEWol000000_mgFJ82o`000007og=GX_l0003oM5ZVogAJY_l0003oKEJVo`000002og9KZ0;o
000000?oK5NYo`000?mZFZh00_mZFZh00ol0003oIeN/o`000002ofAI/003o`000?mVFk;oIU^b00;o
IU^b0_l00003of5K]@05oeaL^Ol0003o0000oeeL^?l000000_mFG;`3o`0000;oDEc00_mKI<801?l0
003oBe_1o`000?l00002oeASa@;o000000OoBf;8o`000?mIJl_oFF_;o`000?m9ILgo000000;oFG3@
0ol000000om9J=3oFgKDoe]fe003o`000003od]ae_l0003oGGcI00;oGGcI0ol00003of:4gP06o`00
0?mIP=ko0000o`000?mXS>;o00000_mPRN<01Ol0003oLiKUog>FiOmcU^Go000000;oKI?V3_l00000
0on2Z^ko0000o`000003o`0000?oU[?/00?o0000oj;2konR`^l01?l00002ojG4k`04o`000?nfd>go
0000o`0000Co^<o/00Ko0000ol7Hjoo1f>_o0000oloOi?l00003om;Ph`03o`000?oLim_og>OK00;o
gnSJ00?o0000on_bcOo[l/d00_l000000oo/ih3o0000oookJP0>oookJPCo00003_oonfX00ol0003o
oo]ZoookJP0_oookJP03o`000?oonf[ooo]Z00Wooo]Z000;oookJP03o`000?oonf[ooo]Z00Wooo]Z
00?o0000oookJ_oonfX07ooonfX02_l0003odLC>om74c_l0003od<C>o`000?o@`lko0000olk3col0
0003olk2c`04o`000?o=`/oocL;?olg2c`;o00000oo;`M001Ol0003obl3@o`000?o:`=7o000000Co
b[o@00?o0000olRod_o8_m800_o8_m801?l0003oakkBolNnd_o7_]82o`0000?oaKkC00?o0000olFm
doo5_M<00_o5_M<2o`0000?o`[gE00Co0000ol6keOo1^mGo`K_E0ol00002onJm[0;o00000_oU^j/0
1?l0003ohkV[on>iZol00002on:fZ@04o`000?oO/j[o0000o`0000?oh[2S00Co0000on2^Xol0003o
00000_oNZZ400ol0003ofjRQo`000003o`0000;og:FL00Co0000om^SVol0003o00000ooHWYL02?l0
003oeI^Ho`000?l0003odYFCo`000?oFV97o00000_oCUI43o`0000;od8b900?o0000olb9R_o<RHX0
1?l000000oo=PWko0000olQmOP02olQmOPKo00000_o2K6/01?l0003o_6IXokaVJ?nlIVP7o`000003
oj/n>ol0003o0000017o00000ooonfX5o`0000?ooo]Z4Ol000000oml42[o0000o`000008o`000004
oi0nH_l0003oS3iWoh`nI`Go00001On>C7/00ol0003oQdMjo`000002o`000004ohiER?l0003o0000
o`0000;oR5270ol00004ohIET0;o00001On3F9H4o`0000?oP5VK0_l00004ogeJWP03ogEEWol0003o
MeVR00;oMeVR00Co0000og9GXol0003o00000_mdFZH00om]EZKo0000og9KZ003og9KZ0?o00000omZ
FZh01_l0003oIUV^ofII[_l0003oI5V`o`0000CoIU^b00SoHeffo`000?l0003oHE^eo`000?mLG;Wo
0000oeaL^@;o00000_mFG;`00ol0003oGV:noeiR_P02oe5L`0CoFfC20ol000001_mDHlGoFVS7oeYX
aol0003oBf;8o`0000?oFF_;0_l00002oeU`d0;oCfkB00Co0000oe]fe?mKM]Co00000_m?L]H2o`00
00CoGGcI1?l000001?mRQ=ko0000oeV0g_l00002ofb>hP?o000000GoH8WSo`000?mcU^GoLiKUo`00
0002offCiP03o`000?mnX>SoOZ3X00;oOZ3X00Co0000ogVNj_miW^[o00001_n9Z^/2o`0000CoU[?/
1Ol00007ojG4k`04o`000?nhcnco^<o/okS?k0;o000000Co^]3[o`000?o1f>_o`MS[0_l00002om;P
h`04o`000?oDh^7o0000omcWf`;ognSJ0_l000000oo[l/go0000o`000003o`0000cooo]Z0ol0000B
oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX02OoonfX000_ooo]Z00?o0000oook
J_oonfX02_oonfX2o`0001kooo]Z00?o0000om74c_oAa<h00_oAa<h01Ol0003od<?>om33c_o@`lko
000000?oc/;?00Go0000olg1col0003ocL;?o`000002olg1c`03o`000?o;`M3o000000?obl3@0_l0
0003olZod0;o00000oo8_m801Ol0003oakkAo`000?o7_];o000000;oakgA00?o0000olFndol00000
0oo5_M<01ol0003oaKcBolFld_o5_=;o0000ol:meOl000000oo1^mD01?l0003oikn^onNo[_l00002
onJm[004o`000?oU^jco0000o`0000?ohkV[0ol00003omncZPCo00000ooP[Z<3o`0000CofjRQ1?l0
0003om^SV`Co00000ooEViP5o`0000?odiFA00?o0000om2BT_l000000_l00002olb9RP;o00000_o=
RXX6o`000004olEjOOl0003oagenolMmOPGo00000onlIVP2o`0000;o^fM/00?o]U9=o`000?l00000
2?l000000on/AT[o0000oj4b<`02oj4b<`03o`000?nN;c;o000001;o00001?nC;3d01Ol0003oRAle
o`000?l0003oR1hc00Go00001?nIBV/01?l0003oT41Voi10I_n@@6H6o`0000?oU59l00?o0000ohi<
Non>C7/00_n>C7/4o`000003ohiER?l0003o000000;o000000CoR527o`000?l0003o00000_n<FY00
0ol0003oQUF@ohIET002o`000003ohULU_l0003oPeRF00?oPeRF0_l00003oh1IW004o`000?n0FI_o
0000o`0000CoOEZN0_l00004ogMIXP;o00000_mdFZH00ol0003oM5ZVo`000005og9KZ005o`000?m/
FZcoK5Z/o`000?mZFZh00_l00003ofII[P?o00000_mVFk801?l0003oHeffo`000?mPFkH2o`0000;o
G5bi00Go0000of9Q^_mRHK[o0000oeIL_004oeiR_P;o00000omKI<82oe5P``;o00001?mJJ<L01_l0
003oFF_;oeU[bomIJl_oD6[>o`0000;oFG3@00Co0000odm^d_m?K];oCfkB0_l00003odmbeP;o0000
0omMO=T2o`0000;oIXKM1Ol000001?m/S^;o0000ofF;h_mURn89o`0000?oOZ3X00Go0000ogVNj_mi
W^[oNIkZo`000003ohVZj`So00001?nF^Nl00ol0003oYLC_ojG4k`03o`0000?oYlK_00?o0000okS?
k?l000000onjd>/3o`0000;oa=_Z0_l00002omCRh@05o`000?oOj=[ognSJo`000?oSj=H00_l00000
0oo]l/Wo0000o`000002o`0000Wooo]Z0ol0000FoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000
oookJ_oonfX02OoonfX000_ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0Joook
JP03o`000?oAa<kodLC>00;odLC>00Wo0000om33cOl0003od<?>o`000?o?`/ko0000olk2col00000
0oo=`Ll2o`0000?ocL7?00Go0000ol_0d?o;`=3obl3@o`000002olZod003o`000?o:_m3o000000;o
bKo@00?o0000olRod_l000000oo7_]42o`0000?oakgA00Go0000olFmdoo5_M?oaKgCo`000005olFl
dP05o`000?o1^mGo`K_Eol6keOl000000ooW_jh3o`0000?oiK^/00Co0000on>iZooS^J_o00000_oR
]j/2o`0000;ogk>Z00Co0000on6aYOoQ/JGo00000ooP[Z<01?l0003ogZbSo`000?l00003om^XX@03
o`000?oHYZ;o000000;o00000_oKXi/00ol0003of:6LomRQW002o`0000;oeI^H00Co0000om:HVOl0
003oeI^G1?l00004om2BTPGo00000oo=RXX01?l0003ob8F:olR5R_o8QHX3o`0000;oagen00Co0000
ol=jOoo3NWoo`gYo2ol00003okMQJ0;o00000oncH6`Uo`0000KoVDY[00?o0000oi10I_l000000_l0
0002oiUEO@04o`000?nCDWgoTe9mo`0000?oU59l00?o0000ohi<Nol000000_l00002oiAJR@?o0000
0_n>EHP3o`0000GoS5Z@0ol00003ohULUP03o`000?n3F9Ko000000;o000000?oQEfKo`000?n0FI`0
0_n0FI`4o`0000?oOEZN00?o0000ogmNX_l000000omgFJ800ol0003oO5jUo`000002ogAJYP?o0000
1?mbFjP00ombGZgo0000ofaJ[002ofaJ[0?o00000_mVFJh01_l0003oKEjaofeN/Ol0003oIU^bo`00
00?oHeff00Ko0000ofIP]omVH;Oo0000oeaL^Ol00003of9Q^P;o00000omNH[h2oeQR`P;oFfC200Go
0000oe5P`omAH<?oDF33o`000004oeYXa`04oe5Wb_l0003oFF_;o`0000;oD6[>1?l00002odm^dP;o
GgWE0_l000000om?L]Ko0000of9of@02of9of@Co00000_mVQ]d00ol0003oGh;Moen2g@04o`0000;o
IH_R00Co0000ogNHiOmgV>Go00000omaUND<o`0000CoS:_Z00?o0000oiJikonF^Nl01_nF^Nl2o`00
00OoYlK_00?o0000ok[@jonjd>/00_njd>/02?l0003oa=_ZolCKj_o4fn[o0000olSNjOl0003oe>;Q
0_l000000ooOj=[o0000on?XeP02o`000003ongbbOl0003o000000;o00001ooonfX3o`0001[ooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP08oookJP002ooonfX00ol0003ooo]Zoook
JP0=oookJP03o`000?oonf[ooo]Z01Sooo]Z0_l00003om74cP05o`000?o@`lgod<?=om33cOl00000
0oo?`/h00ol0003ocL7?olg1c`02olg1c`09o`000?o=`Lko0000olg1col0003oc<3?o`000?o;`=3o
000000Cob[o@00Co0000olVod?o9_m3obKo@0_l00003olNnd@0:o`000?o7_M7oakgAo`000?o7_M7o
0000olNmdOl0003oaKgCo`0000CoaKcB00?o0000ol>kd_o3^m800_l000001Oo1^mGo0000o`000?oW
_jko000000;oiKf^00Co0000onFk[?oU^jcoiK^/0_l000001_oS^J_o0000on:gZooR]j_o0000on2d
Z`;o000000?og[6Yo`000?oQ/JD00_l000002OoP[Z?o0000omj/XooN[:?o0000om^ZY?l0003ofjRQ
o`000002omRVXP03o`000?oJYIoofZFO00;o00000ooHXI`01?l0003oeIjLo`000?l00002om:HV@03
o`000?oEViOo000000;odiVG0_l00003om2BTP04o`000?o<Si;o0000olnATP?o000000?ocHZ:o`00
0?o8QHX00oo8QHX8o`000007ol=jOol0003o`7Inol1fO_l0003o`GMno`000003okeeO`Oo00001Onc
H6`00ol0003o/5m_ok1OK`03ok1OK`05o`000?n/F6So[5QXojaHJ?l000000_nYE6L00ol0003oZ5AX
ojQDJ002ojQDJ003o`000?nSCfOoXdmW00;oXdmW00Co0000oj9?IonRCfOo00001_nLBFD01?l0003o
VDY[oiU:JonIBV/5o`0000GoVEEm00?o0000oi=BOOl000001_l00002oiAJR@Co000000KoSUF8o`00
0?l0003o0000oi5NTOl00005ohaJT0;o00001?n9G9H3o`0000GoQEfK0ol00003oh9MW`;o000000Go
OEZNo`000?moGZ;oOejRo`000002ogMIXP06o`000?mlGZGoO5jUo`000?mdFZKo00000_mfG:P2o`00
00;oLU^X0_mbGZd01?l0003oK5Z/ofaJ[?l00002og5O[P03o`000?mVFJko000000?oKEja0ol00003
of=M]P04o`000?mVH;OoIV2gofIP]`;o00000omRHKX01OmLHKko0000oeiR__mNH[ko000000?oF6;2
0_l00003oe5P``;oGV_70_mJJ<L01?l0003oDFO:o`000?mIJl/2o`000003oe1Zc_l0003oFG3?00;o
GW?@00?o0000odm^d_l000001?mONMD2o`0000?oHWoI00Ko0000oeUng?mIO]co0000ofJ6gOl00003
oen2g@;oL93R00?o0000ofR?iOl000000_l000000omgV>Go0000og6Ei@04og6Ei@03o`000?n2X^So
000000CoO9oY00?o0000ohb[j_n<ZnX01?n<ZnX2o`0000;oU[W_0ol00003oiVkk`03o`000?nWa^oo
YlK_00?o00000on[bNl01_l0003o^]3[o`000?nmd^[o0000olCKjP;o00000_o8g^T4o`000004omoX
f_oSj=Ko0000onC^eP?o000000?olo>Yo`000?l000001?oonfX3o`0001gooo]Z00?o0000oookJ_oo
nfX0;_oonfX00ol0003ooo]ZoookJP08oookJP002_oonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z01Kooo]Z0_l000001?oBa<co0000om74c_l00003om33c@04o`000?o@`/go0000olo2
cP;o00000oo=`Ll01Ol0003ocL7>olg1c_o=`Lko000000?oc<3?00Go0000olZod?o:_m3ob[o@o`00
0002olZnc`03o`000?o9_m3o000000;obKk@00?o0000olNndOl000001?o7_M43o`000003olNmdOl0
003oaKcB00;oaKcB0_l00003ol>kdPOo00000_oU_Jh2o`000004onFk[?l0003ohkV/on>i[0;o0000
0_oR]j/01Ol0003oh;B[on2dZol0003og[6Y00;o00000_oO/:D2o`0000;ogZbS00?o0000om^ZY?oK
ZZ@00_l00002omRVXP04o`000?oJYIoofZFOomZUW`;o00000_oHXI`00ol0003oeIjLomFNW005o`00
00?odiVG00?o0000om2FV?l000000_l00002olb?TP03o`000?o?TI;o000000;ocHnB1?l000001?o8
QH[o0000olJ4Rol00002olR5R`04o`000?o4PX_oa8:;olB2R`Co00000_o1Mgh00ol0003o_GEookee
O`02okeeO`03o`000?nkLWko000000;o^W5n3?l000001?n`Gfoo0000ojaHJ?l00004ojUDI`04o`00
0?nXE6SoZ5AXo`0000?oXdmW4?l00003oimKOP04o`000?nIEGgoVEEmoiUEO@Go00000_nHGHT00ol0
003oVEj9oiUNR@04o`000003oiAJROl0003o000000;o00001OnAGY400ol0003oS5Z@o`000002o`00
0004ohmPUol0003oREbFohULUP;o000000?oRf6Ko`000?n5GI/01?n5GI/2o`0000GoPUfO1Ol00000
0omoGZ;o0000ogMIXP04ogaNY@03ogAJY_l0003oMUbX00?oMUbX00?o0000og9KZ?l000000ombGZd0
0om/FZco0000og5O[P03og5O[P;o00000om]G[401Ol0003oIUfdofIM]?l0003oHeff00;o00000omV
H;L01OmRHK_o0000o`000?mRHK[o000000;oG66n0ol00003oeQR`P;oHFS400Co0000oe5P`ol0003o
DV740omNJlL3o`000006oeU[bomNKlcoGVo<o`000?m@J/ko00001?mNLm02o`0000?oGgWE00Go0000
oeMeeOl0003oHWoIo`000003oeUng003o`000?mWQ]go000000?o000000?oGh;Mo`000?mXSnD01?mX
SnDDo`000003ohb[j_l0003o000000;o00001onI^nl2o`0000OoZlW_00?o0000okgBj_nmd^X00_l0
0003olSNj@07o`000?o:f>Cob]STol[Hi?l0003ohnSFo`000002onC^eP03o`000?o^llKo000000Oo
00008OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z00Sooo]Z000:oookJP03o`00
0?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX05?oonfX01_l0003odl?;om?3bol0003od/C<o`00
00?od<?=00Co0000om32cOo@`/god<;=0_l000001?o?`Lgo0000olg1col00003olg1cP09o`000?o=
`<ko0000olc0col0003oc;o>o`000?o:_m3o000000Cob[k?0_l00003olVnd005o`000?o7_M7oakgA
olNmdOl000001?o7_M001Ol0003oa[c@o`000?o5_=;o000000Go`k_B0_o4^m401Ol0003oi<6donC1
]?l0003ohkjb00;o00000_oU_:d2o`0000;ohkV/00Co0000on6h[?l0003o00000ooP]:/2o`000006
omjaZOl0003ogk2Uomn`YOl0003ogZjU0_l00003om^ZY003o`000?oIZ:Co000000;o00000ooJYIl0
1?l0003of:>Oo`000?l00003omFNW003o`000?oAVikodI^N00?o00000_oCVIL01?l0003od9JHom2F
V?o@UYP3o`000003olb?T_l0003ocHnB00?ocHnB00?o0000olV;T_o9Ri801?l00002olR5R`03o`00
0?o4PX_oa8:;00;oa8:;00?o0000ol5oRol000001_l000001?nmMGoo0000ok]bO_l00003okYaOP03
o`000?ngKgoo]fmo00;o]fmo0_l00004ok=/P0oo00000onYHgh2o`0000OoY5im0_l00003oimKOPKo
00000onMHXX01Ol0003oV5f9oiQMROl0003oVEj900?o000000CoU5Z9o`000?l0003o00000_nGHY80
0ol0003oTEjAoi5NT@02oi5NT@Co00001?n?H9L3o`0000?oRf6K00Co0000ohEMVon5GI_oQEfK0_l0
00000on8HIko0000oh9MW`03oh9MW`;o00000omnGZ<3o`0000CoO5jU0_l00005ogILZ005o`000?mc
GZcoLej/o`000?mbGZd00_l00004og5O[P;o000000?oK5jbo`000?m]G[400_l00003ofIM]0Co0000
00CoIV2go`000?mRHK_oHV6k0ol00003oeaQ_P;oHfK000?o0000oeQR`_mHH/801?mQJ<@2o`0000?o
GV_70_mDIlT00omAIl[o0000oei_c003oei_c003o`000?mNLm3oGW?@00;oGW?@00Go0000oeA`dOl0
003oGgWEo`000002oeMee@;oIh;I1?l000000omIO]co0000o`000003ofZ8gPKo00000_mXSnD00ol0
003oN9WUogRIi@04ogRIi@;o00001On3XnP00ol0003oSjgZohn]jP03ohn]jP03o`000?n;[Ngo0000
00;oVK__1?l00002oi^mk`03o`000?n[bNooZlW_00;oZlW_0ol000000on^c>oo0000okgBjP02o`00
00;ob=kY0_l00003ol[Hi005olcUjOl0003o0000o`000?oTk]H01ol0000VoookJP03o`000?oonf[o
oo]Z02cooo]Z00?o0000oookJ_oonfX02?oonfX000[ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0
003ooo]ZoookJP0BoookJP03o`000?oC`l_odl?;00;odl?;00Go0000om73c?l0003od<?=o`000003
om32c@06o`000?o@`Lcod<7<o`000?o?`Lgo00000oo=`Lh01?l0003ocL3>olg0c_o=`<h2o`0000;o
c;o>00Go0000olZncoo:_/oob[k?o`000003olZnc`07o`000?o9_]3o0000olVmcol0003oakgAo`00
0003olNmd006o`000?o6_=3oa[c@o`000?o6_=3o00001Oo3^m82olBkd@04o`000?oT`KCoi<6donC1
]0;o000000Kohkjbo`000?oU_:goiKb]o`000?oS^Zd2o`0000?ohKR/0_l000001?oP]:_o0000omjb
ZooN/Z/4o`0000?ogZjU1?l00004omVXY0;o000000?ofZFOo`000?oHXil00_oHXil4o`0000CodI^N
00?o0000om>LW?l000000_l00003om2FV003o`000?o;TYWobi:I00Co000000?ocHnBo`000?o9Ri80
0oo9Ri800ol0003oaXVCo`000006o`000004olB2Rol0003o`Gn;o`0000;o`X2;00Co0000okimRonn
OH_o_Wf;1_l000000onjLGko0000okM_O`03okM_O`;o00001_ncK802o`0000Go[VMn00?o0000ojeV
O_l000001_nYHgh2o`0000?oY5im2Ol00002oj=VRP03o`000?nMHX[oWF::00CoWF::00?o0000oiQM
ROl000001_l00005oiMRTP03o`000?nAGY7o000000;o00000_nDI9L00ol0003oSf2GohmPU`02ohmP
U`;o00001_n;HI/3o`0000?oR66N00?o0000oh9MWon2GIl00_l000001On4HJ;o0000ogiNXomnGZ?o
000000;oP66U0ol000001?mlGZGo0000ogeQZ?l00004ogILZ003ogYRZ_l0003oLej/00;oLej/0ol0
0003og5O[P03o`000?m`H[;o000000;oK5jb00CoKEjao`000?mZGkCo00000_mVGK@3ofaR]P03o`00
0?mVH;Oo000000?oHV6k0_mWIK`00ol0003oG66noeaQ_P04of=V`0;o00000omQJ<@2oeYXa`;oGV_7
00Go0000oeAWbOmDIlWoE6O9o`000004oei_c0?o000000CoGW?@o`000?mDL=7oE73A0_mTO=D2o`00
00;oEgGE00?oIh;Io`000?mLOm`00_mLOm`2o`0000GoJXSN00?o0000og:Bh_mbT^800_mbT^85o`00
00GoN9WU00?o0000oh>Sj?n3XnP01?n3XnP01_l0003oSjgZohn]j_n?[N[o0000ohn]jPCo00001onK
_Nl4o`0000Go[/c_00Go0000okoCjOl0003ob=kYo`000003ol[Hi003o`000?o<iNWoc>GY00;o0000
00Gof^gPo`000?l0003o0000oo7b`004o`0002Oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003o
oo]ZoookJP08oookJP002_oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z013ooo]Z
0_l00003om?3b`05o`000?oC`l_o0000om73c?l000000oo@`/d01?l0003od<7<om31c?o@`L`4o`00
0003olg1c_l0003ocL3>00;ocL3>00Go0000olfocOo=_lgo0000olbocP02o`000003olZncol0003o
b[k?00Cob[k?0_l000000oo9_Loo0000o`000003olNmd003o`000?o6_=3oa[c@00;oa[c@0_l00004
ol>kdP?oa;_A0_l000001?oT`KCo0000on:o]?oR_k@2o`0000;oiKb]00Co0000on>j[OoS^Zgo0000
0ooQ^:`01?l0003oh;J/o`000?l00002omjbZ`;o000000?og[6Xo`000?l000000_oN[ZD00ol0003o
fjbVom^/YP02o`0000?ofJRT1Ol00002omRSW`03o`000?oEXJ3oeJ6P00?o00000_oAVih01?l0003o
dibLom>LW?oCW9`4o`0000Cobi:I00?o0000olfCV?o=TiP01Ol000001?o9Ri;o0000olJ9Tol00002
olR;TP04o`000?o5Qi;oaHNBolF7TPCo00000_o2P8/00ol0003o_Wf;okimR`02okimR`03o`000?nl
Nh_o000000;o_7^;8ol00004ojQZR`03o`000?nRIH[o000000CoXfJ:00Co0000oieRR_nMHX[oWF::
1Ol000000onKII7o0000oiaVTP02oiaVTP03o`000?nGHY;oUf:B00;oUf:B1?l00005oiATU`03o`00
0?n?H9Oo000000;o000000?oT6BKo`000?n;HI/01?n;HI/2o`0000GoR66N0ol00004ohAQXP;o0000
0on0HJD00ol0003oNenVog]OYP02o`000003ogeQZ?l0003oMUbX00;oMUbX0_mjHZX01?l0003oLej/
og=N[?l00002ogQR[@;o000000?oLEn^o`000?m`H[800_m`H[801?l0003oK5jbog1R/om`H[<2o`00
0003ofIM]?l0003oK6:f00;oK6:f0ol00003of9Q^`CoIfFl0_l00003of=V`0;oGFO40_mQJ<@01?l0
003oFVS7oeYXaomJJ<L2o`0000?oE6O90_mRL/d2oei_c003o`000?mDJlgoHgKA00;oHgKA0_l00000
1OmDL=7o0000ofAleOl0003oFg_I00;o000000?oIh;Io`000?mLOm`00omLOm`3o`0000?oJXSN0_l0
0005og:BhP;o00001?mlVnD00ol0003oN9WUo`00000:o`0000;oTjoZ00Co0000ohj_k?n>[nco0000
1onK_Nl00ol0003o[/c_ojk<k`02ojk<k`?o00000onac^l2o`0000;ob]ST00?o0000olcUjOo<iNT0
0_o<iNT01?l0003of^gPo`000?oMlMd2o`000003oo7b`?l0003o000000;o00009ooonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z00Sooo]Z000:oookJP03o`000?oonf[ooo]Z01?ooo]Z
00?o0000oookJ_oonfX03ooonfX01Ol0003oe<?:o`000?oC`l_o000000?odl?;00Go0000om72c?l0
003od<;=o`000003om31c004o`000?o?`<cocl3<olo0c0;o00000oo=`<h00ol0003ocKo=olfoc@02
olfoc@;o000000?oc;k>o`000?o:_/l00_o:_/l2o`0000?obKg>0_l000001?o9_Loo0000olNmd?l0
0004olJld004o`000?o7^looak_?o`0000;o`k_B0oo4^m401?l0003oi<6eonC1]Ol00003on:o]004
o`000?oQ_KCo0000o`0000?ohkZ]0_l000001_oQ^:co0000on2f[?oP]Zco0000omjd[0;o00000_oK
/:`2o`000003omf_Yol0003o000000?ofjbV00[o0000omVZY_l0003ofJRTo`000?oFYJGo0000omVW
Xol0003of:FR0_l00003omFQX003o`000?oBWZ3odYjP00?o00000ooCW9`00ol0003od9VLom2IW004
o`000003ol^BVOl0003ocI>H00;ocI>H00Co0000olV?V?o9SiSobHnH1?l000000oo8Ri;o0000olF7
TP04olF7TP03o`000?o2QI;o000000Ko000000Co_Wf;o`000?nlNh_o00000onlNh/00ol0003o^GR;
okUhR`02okUhR`;o00001_neMH/2o`0000Ko/G:;0_l00006oja]R`;o00001_nXJX/01?l0003oXVF:
oj9UR_l00002oj=VRPSo000000GoX6VBo`000?nKII7oVfFAo`000003oiaVTP03o`000?nGHY;o0000
00;o00000_nIJ9L00ol0003oU6BGoiATU`02oiATU`Co00001On@I9/00ol0003oRf6Ko`000002o`00
0003oheUW_l0003oR66N00?oR66N0_l00005ohAQXP;o00001On0HJD2o`0000;oO66X0ol000000omf
G:SoNV:ZogYRZP02ogYRZP03og=N[?l0003oN6:]00?oN6:]0ol00003og1R/P;o00000om`H[<2o`00
00CoK6:f00Go0000ofIR^OmVH[Wo0000of9Q^`02o`0000?oIfFl00GoHVK1o`000?mSI/3oHfK0o`00
0003oeeWa0;o00000omJJ<L2of=_b@04o`000?mDIlWo0000oeEXbP?oHW;=0_l000000omDJlgoHgKA
of=fd@02oeYfe0;o000000?oI7cEo`000?mKNmT00omKNmT4o`000003oeaog?l0003o000000?oKX_N
1_l00002og:BhP03o`000?m[T>Co000000GoO9_U00?o0000oh:Vk?n2Y^`01On2Y^`00ol0003oTjoZ
oi>_jP02oi>_jP03o`000?n>[nco000000Go00001?nN_o001?l0003o[/c_o`000?l00004ok7>k`06
o`000?nddNoo]=7_o`000?o:f>Co00000oo<iNT01?l0003ocn?Vo`000?l00002omgag@06o`000?oX
mlko0000o`000?o[mZGo0000:OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00So
oo]Z000:oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX03OoonfX01Ol0003oe<?:
omC3b_oD`l[o000000?odl?;00Go0000om;2b_l0003odL;<o`000003om31c003o`000?o?`<cocl3<
00;ocl3<0ol000000oo=`<ko0000olfoc@02olfoc@04o`000?o;_/kobkk>ol^ncP?o000000?ob[k?
o`000?o9_Lh00oo9_Lh01_l0003ob;c?olRlcol0003obKg?o`0000Coa[c@00Co0000olNkcoo7^loo
ak_?1?l000000oo4^m7o0000o`000002onC1]@;o000000?oh[ndo`000?oQ_K@00_oQ_K@01?l0003o
hkZ]on>j[Ol00002on6h[@;o00000_oP]Z`00ol0003og[B/omjd[002o`0000;ofk2/00?o0000omf_
YooM[jL00_l00002om^/YP03o`000?oIZZKofJZV00;o00000_oFYJD01?l0003of:FRomRUX_oHYJ84
o`0000CodYjP1Ol00003om2IW004o`000?o=UYcocIJLolfFW0Co000000?ocI>Ho`000?o9SiP00oo9
SiP00ol0003oaXfHo`000005o`000005olF7T_l0003o`XFBol:5T_l000000_o2QY801?l0003o_h>B
okn3T_noPi8;o`000003okUhRol0003o000000Ko]GF;00?o0000ok5bRonaLX/01OnaLX/2o`0000Ko
[6f;0_l00003ojQZR`Wo00000_nUKI83o`0000CoX6VB00?o0000oi]UTOl000000_nLIY84o`0000Go
VFRG00?o0000oiATUol000000_l00002oiEXV`03o`000?n@I9_oT6BK00?oT6BK0ol00004oheUWP03
o`000?n8HIko000000;o000000?oRVFRo`000?n4HJ800_n4HJ82o`000003ohMUYOl0003oP66U00?o
P66U0_l00004ogaQZ0?o00001?mjHZX00ol0003oN6:]ogQR[@03ogQR[@05o`000?maHK7oLF6ao`00
0?m`H[800_l00004og1R/`07ofmU]ol0003o0000o`000?m/H[Ko0000ofUS^@03ofIR^@?o00000_mW
IK`00ol0003oHVK1of9V`@03o`0000?oGFO40_mUK<D00ol0003oFVS7oeYXa`04of=_b@?o00000_mR
L/d2oe]bd0;o000000?oHgKAo`000?mJM]@00_mJM]@5o`000003oe]kfOl0003oJXCJ00;oJXCJ1?l0
0003ofj;gP03o`000?mVR=oo000000?oMiCR1ol00002ogbKi@;o00001?n2Y^`2o`000003oh:Vk?l0
003o000000Co00000_nB/>/00ol0003oW[o`oijol006oijol003o`000?nac^oo/Lk_00;o/Lk_00?o
0000okCAkonddNl00_nddNl2o`0000;oc>GY0_l00002oloSiP03o`000?oMlMgogO7M00?o000000Co
j?O>o`000?l0003o0000:_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z00Sooo]Z
000:oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX02ooonfX02Ol0003oe<?:omC3
b_oD`l[o0000om?2b_l0003odl?;o`000003om;2bP05o`000?oA`L_o0000om31c?l000001?o?`<`0
0ol0003ocko;olnob`02o`0000?ocKo=00Go0000ol^nc_o;_/kobkk>o`000002olbmc0;o00001?o9
_Lh00ol0003ob;c?olRlc`02olRlc`;o00000oo6_=001Ol0003oak_?olNkcoo7^loo000000;oa[[>
00Co0000olFjd?l0003o00000_oT`KD00ol0003oh[ndon:o]002o`0000?ohKfd0_l000001_oS^Zgo
0000on6h[OoQ^:go0000on2g[@;o00000ooN]:`01Ol0003og;:]o`000?oK/:co000000;ogJnW00Co
0000omb]Yol0003o00000ooIZZH01Ol0003oejRWo`000?oFYJGo000000?of:FR00?o0000omJSX_oF
Xj800_l00003om:NX0;o00000_oBWYl3o`000003om2IW?l0003ocIJL00?ocIJL00?o0000olfFW?o=
UY`01?l000001oo9SiSo0000olJ=V?o6SISo0000olR>V?l000000oo5S9L5o`000003ol:6T_l0003o
_h>B00Co_h>B00?o0000okf1Tol000000onlPI<01?l0003o^GjBokUnT_niOY8No`0000?oZG6C00Go
0000ojA/T_nTK9;o0000ojE]TP04o`0000?oX6VB2?l00002oii/V003o`000?nIJ9OoVFRG00?oVFRG
0ol00005oiEXV`03o`000?n@I9_oT6BK00?o000000?oTVRNo`000?n=IIh00on=IIh3o`0000GoRVFR
0ol00003ohMUY@03o`000?n0HJGoP66U00;o000000CoPfFWo`000?mlHJSoO66X0_l000000on0IJ[o
0000ogYR[002o`000003ogYRZ_l0003o000000CoN6:]00?oMfFao`000?maHK400_maHK43o`0000?o
L6:c00?o0000ofmU]ol000000_m[H[L01?m/H[Ko0000ofUS^Ol00002ofIR^@?oK6Jj0_mWIK`01?l0
003oHVK1of9V`OmRI/42ofQZ`P03o`000?mMIlCoGFO400CoIFc50_l00003of=_b@?oG6o=00?oHW;=
o`000?mKL]000omKL]03o`0000?oFWKD00Co0000ofQne_mXO]KoJ7kF0ol00003ofZ4fP03o`000?mR
PM_o000000;o000000GoKX_No`000?mVR=ooIXSOo`000003ogNDhP04o`000?m`T^?oL9;So`0000?o
P9gU1ol00003ohFXk005o`000?nF/N[oU[7ZoiJaj_l000001?nB/>/00ol0003oW[o`oijol003o`00
00?oXL;`00Co0000ok7>kol0003o00001?nddNl01Ol0003o_]S]o`000?o<iNWo000000?ocn?V00Ko
d^GTo`000?oMlMgo0000omg/gOl00002onSgcP?o0000:_oonfX00ol0003ooo]ZoookJP0ZoookJP03
o`000?oonf[ooo]Z00Oooo]Z000:oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
2OoonfX01Ol0003oe<?:omC3b_oD`l[o000000?odl;:00So0000om;2b_oB`/[od/;:o`000?oB`L[o
0000om71b`;o00000oo?`<`02Ol0003ocko;olnoboo?_l_o0000olnobol0003ocKo=o`000003ol^n
cP03o`000?o<_Lcoc;g<00;oc;g<00Go0000olVmc_o9_LkobKg>o`000004olRlc`06o`000?o9^lgo
bK_=o`000?o6_=3o00000oo7^ll01?l0003oa[[>olJjc_o6^/h2o`000005olFjd?l0003o0000onC1
]Ol000000_oR_k@01Ol0003ohKjdo`000?oQ_KCo000000;ogk^c0_l000000ooQ^:go0000on2g[@02
on2g[@04o`000?oN]:cog[B/o`0000?og;:]1?l00003omb]Y`Co00000ooGZ:L5o`0000?oeZ>R00?o
0000om>QXol000000_l000001Oo?W:7o0000om:NWooBWYoo000000;odIbO1?l000000oo=UYco0000
o`000003olfFW003o`000?o:TicobY>L00Go000000?ob8jHo`000?o5S9L00oo5S9L00ol0003o`XVH
ol:9V006o`0000;o_h>B00?o0000okf1Tol000000onlPI<00ol0003o^GjBokUnTP02okUnTP;o0000
1_nfNi800ol0003o/WRCok9hT`05ok9hT`;o00001_n^M9<2o`0000OoZG6C2ol00003oj5^U`03o`00
0?nNK9SoWVbH00GoWVbH00?o0000oiUXUol000000_l000000onJK9_o0000oiEXV`05oiEXV`?o0000
0_nBJ9h<o`0000;oRVFR0_l00005ohMUY@03o`000?n0HJGo000000CoPfFW00?oO66Xo`000?n0IJX0
0_n0IJX00ol0003oNV:/ogYR[005o`0000;oN6:]0_mgIK401?l0003oLF6aog5Q/Ol00003ogIU/P03
o`000?m`H[?o000000?oKfFg0_l00002og1V^0;o000000?oIV:io`000?m/I[X00_m/I[X3o`0000?o
HVK11?mXJ/82o`0000?oIFc50_mOKLT00ol0003oHfo9o`000003oea_c@?o00000omKL]002?l0003o
Ig[BofMjd_l0003oFWKDo`000?mLN=Go00000omXO]H02?l0003oH7_Go`000?l0003oJXCJo`000?mR
PM_o00000_mbSMh7o`000003ogNDh_l0003oL9;S00;oL9;S00Go0000oh2MiOn0WNGoP9gUo`000002
ogVLi`03o`000?n5Z>coQJS/00CoQJS/00?o0000oiJaj_l000000onB/>/5o`0000OoXL;`00Co0000
okCAkonddNoo]=7_0_l000000ongdNgo0000okkHk@02o`0000;ocn?V00?o0000om;Ui?oBiN@00_l0
0002omg/g@03o`000?oXmlkoj_S900?o0000:ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z00Oooo]Z000:oookJP03o`000?oonf[ooo]Z01Oooo]Z0_l00009oookJP;o000000?oe<?:
o`000?oC`/X00_oC`/X01Ol0003odl;9o`000?oB`/[o000000?od/7:00Ko0000om30boo@`<_o0000
olo0c?l00003olnob`03o`000?o?_l_ocko;00;o00000oo;_/h00ol0003oc;g<olbmc002olbmc005
o`000?o<_<co0000olVmc_l000001?o8_<l01?l0003obK_=olVkcOo9^ld4o`000003olNkcol0003o
a[[>00;oa[[>00Co0000olJjc_l0003o00000_oT`[D01?l0003oh[ndon:o]?l00003on6n]006o`00
0?oO^k?ogk^comnk/ol0003ohKV_0_l00003on2g[@;o000000?og[B/o`000?oL/Zd00_oL/Zd01?l0
003ofJn]o`000?l00003omb]Y`03o`000?oJ[:SofZbX00;o00000_oGZ:L01?l0003odjFWo`000?oG
YjD2o`0000;oeZ>R00Co0000om>QXooCXJ?odj6S1Ol00004om6LW`03o`000?o=VIoocIVO00Co0000
0_o=UY`01Ol0003obY>LolZCW?o:Tico000000;oaHnL1Ol000000oo5S9Oo0000ol:9V002ol:9V003
o`000?o2RISo000000?o`8NG1ol000000onlPI?o0000okUnTP03okUnTP;o00001_nfNi82o`0000Go
/WRC00?o0000ok5gTol000001_n^M9<2o`0000?oZG6C2?l00003ojMcV003o`000?nQKYOoXFjG00Co
XFjG00?o0000oii/V?nNK9P00_nNK9P5o`0000CoVVbK00?o0000oiEXVonEJ9/00onEJ9/2o`000004
oi9XW_l0003o0000o`0000;oTVVP0_l00004ohmYX`04o`000?n:IZ?oRVJSohYVX`Ko00000_n7IJD2
o`0000GoPfFW0_l00005oh1UZP;o00001?mjHjd00ol0003oN6:]o`000003ogMU/@03og5Q/Ol0003o
MVFb00?oMVFb0ol00003ofmU]`03o`000?m`I[SoL6Jh00;oL6Jh0ol00003ofaV^P?oJfVn00Co0000
of9V`Ol0003o00000omXJ/801OmSJlGo0000o`000?mUK<Go000000?oGfg90ol00003oea_c@;oIgK>
0_l000000omKL]3o0000o`000003ofMjdPCo000000CoJ7kFo`000?mPNmOoH7_G0om_QmX4o`0000;o
LXgN00Go0000ofb:g_m/R]koK8[No`000002ogZFhQ;o000000?oQJS/o`000?l000000ol00003oiJb
j`03o`000?nQ`_3oXL;`00Co00000_nUaO001?l0003o]=7_o`000?l00003okOAk@;o00000_o2g>`2
o`0000?od^GT00?o0000omg/gOoMk=d01ol0000/oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000
oookJ_oonfX01ooonfX000Wooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP05oook
JP04o`000?oF`lOo0000o`0000?odl;:00Go0000om?2bOoC`/Wodl;9o`000003om;1bP03o`000?oA
`<Wo000000;od<3;00Go0000olnoboo?_l_ocko;o`000002olnob`06o`000?o>_/[oc[k:o`000?o;
_/ko00001?o<_L`00ol0003oc;c<olblc003o`0000?ob;c?00Go0000olVkcOo9^lgobK_=o`000002
olVkc@03o`000?o7^/ko000000?oa[[>00Go0000olJjc_o6^/koa[[>o`000002onC2]@;o000000?o
h[ndo`000?oQ_[@00_oQ_[@2o`000003omnk/ol0003og[Vc00;o000000CogkN^o`000?oP]jgo0000
0_oN]Jd3o`000009ombb[Ol0003ofJn]omV_[Ol0003ofjjYo`000?oL[JOo000000?ofZbX00Co0000
omNYZ?l0003o00000ooCYJL2o`000003omJUYOl0003o000000Codj6S00?o0000oljMY?o>WJ@01?l0
00000ooAW9oo0000olfIW`03olfIW`03o`000?o:UZ3o000000;o00001?o:Ti`01_l0003oaHnLolF?
W?l0003oai6Lo`0000;oaY2L1Ol000000oo2RISo0000o`000005ol27U`03o`000?nmQISo000000;o
_HFH9Ol00002ojYeV0;o00001OnWLiP00ol0003oXFjGoj5^U`03oj5^U`Ko00000onOL9`00ol0003o
VVbKoiY/V`04oiY/V`03o`000?nEJ9_o000000Go00001?nBJJ02o`0000KoSfVS0ol00003oh]XY@03
o`000?n6IZKoQVJV00Oo000000CoPfFWo`000?n4Ij[o00001?n0IJX2o`0000GoNV>]00?o0000ogQT
/?mhI;000_l000000omgIK7o0000ogIU/P04ogIU/P03o`000?m`I;GoL6Be00;o000000?oKfFgo`00
0?m`I[P00om`I[P01om]J;_o0000of]V^ol0003oK6Jjo`000?mXIkh00om[JKh3o`0000;oJ6[200?o
0000of=[aOmSJlD01?l00003oem]b@;oJ7;:00Co0000oea_cOmLKlgo00001?mWM/h3o`0000;oIg[B
00?o0000oemfdom]PMH00_m]PMH2o`000005of1keol0003oKhOJofn7f_l000000_mWQmh7o`000004
ofb:g_l0003oNYKRo`0000?oMI?R00Go0000oh>OiOn3WnGoPioUo`000003ogjMiP03o`000?n=ZNSo
SJWX00GoSJWX00?o0000oiJbjonF/^/00_nF/^/5o`0000OoYLG`00?o0000okOAkOngdNd00ongdNd0
2ol0003o`]c/o`000?l0003oa^3/o`000?oBiNCo0000omGWhol0003ogNcM00Co000000Cok_G5o`00
0?l0003o0000;OoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00Oooo]Z0009oook
JP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX00ooonfX01?l0003oe/?7omK3aooF`lL2
o`000003om?2b_l0003odl;900;odl;900Go0000om;1bOl0003od/7:o`000003om70b@06o`000?o@
_l[od;o:o`000?o?_l_o00000_o?_l/00ol0003oc[k:oljnbP02oljnbP;o00000oo<_L`01?l0003o
c;c<olblc?l00002ol^lb`;o000000?ob;c?o`000?o9^ld00_o9^ld01?l0003obK_=olVkcOo9^ld2
o`000004olNjc_l0003oa[[>o`0000?oa[[>00Co0000onC2]OoT`[Go00000_oR`;@2o`0000;ohKjd
00?o0000omnl]?oO_;@00_l00002omji/`04o`000?oO]jkogkN^o`0000?og[F]00?o0000ombc[OoL
/jd00_l00002omV_[@03o`000?oK[ZWofjjY00;o00000_oJ[:P01?l0003oejVXomNYZ?oGZJP3o`00
0003om>UYol0003oeZFU00;oeZFU0ol000000ooCXJ?o0000oljMY002oljMY004o`000?o@WZ?od9jS
om2NX`;o00000oo=VIl01Ol0003obYJPolZFX?l0003oc9RO00?o000000?obY>Lo`000?o5Si`00_o5
Si`00ol0003oai6Lo`000003olJ@W004o`000?o0Rico`8^Lol2;W0Ko000000Go`8NGo`000?nmQISo
_HFHo`000003okf5V003o`000?nhP9So^82H00;o^82H0_l00006okN0V0;o00001OncO9P00ol0003o
/W^Ho`000006ojiiV0Co00001OnZMIP00ol0003oYg>HojMcV004ojMcV003o`000?nQKYOoXFjG00Co
000000?oXg>Lo`000?nOL9`01OnOL9`01?l0003oVVbKoiY/VonJK9/5o`000005oiM[W_l0003o0000
oiM]X?l000000_nBJJ03o`000003oiA/Xol0003oSfVS00CoSfVS0_l00005oh]XY@?o00001?n7J:P0
0ol0003oPfJYo`000004o`0000?oP6FZ00?o0000oh5W[Ol000001?mjHjd00omnIjko0000ogQT/002
ogQT/0?o00001?mfIK82o`0000?oL6Be1?l00002og1V^003o`000?m]J;_o000000;oJfJk00?oK6Jj
o`000?mXIkh00om[JKh3ofM[`P;oJ6[200Go0000of=[aOmSJlGoHf_5o`000002ofY`a`03o`000?mO
KLWoGfg900CoJ7;:0ol00003ofMfcP04o`000?mOL/ooJgcBof]ldP;o00000_mOM]<2off1eP06o`00
0?mUP][o0000o`000?m_Qm[o00001?mWQmh00ol0003oLXgNo`000003ogF?g`Oo000000GoMI?Ro`00
0?n3WnGoPioUo`000004ogjMiP04o`000?n=ZNSoSJWXohfYj0;o000000?oSJWXo`000?l000000ol0
0004oiNik`03o`000?nUaO3oYLG`00?o00000onXb?001Ol0003o]m7]o`000?l0003o^];/00;o0000
0oo6h>`2o`0000;oeNOS0ol000001_oRlmSo0000onkeaOl0003ok?FRo`0002kooo]Z00?o0000oook
J_oonfX09ooonfX00ol0003ooo]ZoookJP07oookJP002OoonfX00ol0003ooo]ZoookJP0LoookJP05
o`000?oonf[ooo]ZoookJ_l000000ooF`lL01?l0003oe/;7o`000?l00003om?2b@04o`000?oB`LWo
d/79om;1b@;o00000ooA`<T2o`0000;od;o:0_l000000oo?_l_o0000oljnbP03oljnbP;o000000Co
cKg;o`000?o<_Lco00000_o<_<`00ol0003obkc;ol^lb`02ol^lb`Co000000?obK_=o`000?o9^ld0
0_o9^ld00ol0003ob;[<o`000002olNjcP;o00000_o6^/h01Ol0003ohl:fo`000?oT`[Go000000;o
h/2d00Go0000on6n]?l0003ohKjdo`000002omnl]005o`000?oN^[Co0000omji/ol000000_oO]jh2
o`000003omje[Ol0003og;>]00;og;>]00co0000om^a[_l0003ofJn]omR^[Ol0003ofjjYo`000?oJ
[JWo0000omZ/Z?l00003omNYZ003o`000?oEYjWoeJNY00;o00000ooFYJD00ol0003odj>Uom>SY@04
o`000003oljMY?l0003od9jS00;od9jS00Ko0000oljKX_l0003o0000olfIWol00002olZFX003o`00
0?o<V9oo000000;obiJO1Ol000000oo5Sico0000olJ@W003olJ@W003o`000?o0Rico`8^L00;o`8^L
0_l00003ol6;W0So00001OnhP9P00ol0003o]h2HokN0V004okN0V003o`000?nfOYSo000000Go/gbH
00?o0000ok9kV?l000001?n^NIP4o`0000OoZWFH00Co0000ojMcV?nWLiSoYg>H1_l00003oj9bV`03
o`000?nSLico000000CoWg2L1_l00003oi]^WP?o00000_nGKJ04o`0000GoU6bS00?o0000ohmYXol0
00000_l000000on@JjGo0000oh]XY@03oh]XY@;o00001_n7J:P2o`0000CoQ6NZ0_l000001On0IJ[o
0000oh5W[On1Ijgo000000?oNV>]0_mnIjh01?l0003oN6B`ogQT/?l00003ogaX/@;o000000CoMVFb
o`000?meIkGo00000_m`I;D01ol0003oMFRfogEX]_meJ;Ko0000og1V^?l000000om]J;/01Ol0003o
JfJkog1Z_?m`J[co000000;oJfVn00Co0000ofM[`_mWJl;oIf_21?l00002of=[a@GoJW370_l00003
ofQbbP;oHW?>0_l000001?mWM/ko0000oembcomOL/l2of]ldP06o`000?mTOMKo0000o`000?m]PMKo
00001?mUP]X5o`0000;oIhON00?o0000ogF?gomeSml01?meSml2o`0000?oO9SS3Ol00003oi2[j0;o
00002?nG^Nl2o`0000OoZ<S`00Go0000ok[Bk?njd^co^];/o`000003olKPk004o`000?o9f^KobM[V
olWJiP?o000000Coh_?Ho`000?o^mLGok_G50ol0000_oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000oookJ_oonfX01ooonfX000Wooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zo`000003
omK3a`04o`000?oF`/Ooe/;7omK2a`;o000000?odl;9o`000?oB`LT00ooB`LT01Ol0003odL39o`00
0?oA`<Wo000000;odKo900Co0000olnnb_o?_/[ockk:0_l00003oljnbP05o`000?o>_L[oc[g:o`00
0?o=_L/00_l000000oo<_<co0000ol^lb`03ol^lb`03o`000?o;^l_o000000;obK_<00Go0000olVk
cOo9^lgobK_=o`000003olRjc006o`000?o7^/ko0000olNicOl0003oa[[>0_l000001OoS`[Ko0000
on;0]?oR`;Co000000?ohKjd00Co0000omnl]?oO_;Co00000ooN^[@01?l0003og;Nco`000?l00002
omjf[P;o00000_oL/jd01?l0003ofk6^om^a[_oK/Jh4o`0000?ofZfY0ol000000ooGZJSo0000omFW
Z@02omFWZ@03o`000?oBYJWo000000;o00001?oCXjD00ol0003odJ6Uom6QY@03o`0000;od9jS00Co
0000oljKX_o>Vj;ocY^R0ol000000oo:UZ3o0000o`000004ol^FW`04o`000?o7Tiooai>OolNCW`Co
000000?oaY2Lo`000?o0Ri`01?o0Ri`00ol0003o`H^Lol6;W003ol6;W004o`000?nmR9co_HRLo`00
00;o_HNL2_l00003okN0V003o`000?nfOYSo000000Co/gbH00?o0000ok9kV?nbNiP05?l00003ojMf
W003o`000?nRLY_oXW:K00;oXW:K00Go0000oj=cW?nSLico0000oim`W003o`0000;oWg:O00?o0000
oi]^W_nKKYh00onKKYh2o`000004oiM]X?l0003o0000o`0000;oV72S00?o0000oiA/XonDK:<00onD
K:<3o`0000CoT6^U00?o0000oh]XYOn;J:D00_l000000on<JZOo0000ohMXZ004ohMXZ0;o00001?n4
IjX6o`0000;oPFN]00?o0000ogYS[OmnIjh00omnIjh00omhI;3o0000ogaX/@03ogaX/@;o000000Ko
MVFbo`000?meIkGoMFNeog1T]Ol00004ogEX]P?o00000om]J;/2o`0000CoL6Zl0_l00003ofM[`PCo
K6k30ol00004ofY`a`;oI77:00?o0000ofQbb_l000000_mRLlh00ol0003oIgK>ofMfcP03o`000003
oembcol0003oI7gF00CoI7gF0ol00003ofF2fP04o`000?mbRM_oLXWKog:9f`?o00001_meSml00ol0
003oO9SSogbHh`04ogbHh`03o`000?n3WnKo000000CoQ:3V00?o0000oi2[j?n@ZnP01?n@ZnP00ol0
003oRjc/o`000002oiNik`?o00000onJ^nl00ol0003oZ<S`ojS8l003o`0000?oZl_`00Go0000ok[B
k?l0003o0000olKPk002o`0000?obM[V00Oob^W/o`000?l0003o0000on;cf?l0003ok_G500Co0000
<?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z00Oooo]Z0009oookJP03o`000?oo
nf[ooo]Z01kooo]Z00Go0000omO3a_l0003oe/?7o`000004omK2a`04o`000?oE`LKo0000o`0000?o
d/7900Go0000om70bOoA`<WodL39o`000003om6ob@09o`000?o?_/[ockk:olnnb_l0003ockk9o`00
0?o>_/[o000000Coc[g:00?o0000olblboo<_</00_l00003ol^lb`05o`000?o;^l_obk_;ol^kbol0
00000_o9^/`00ol0003obK_=o`000004olRjc0;o00000oo7^Ld02?l0003oh<>kon33^ol0003oh/2e
o`000?oR`;Co00000ooQ_[@2o`000003omnl]?l0003og[Zd00;og[Zd0_l000002OoL]k?o0000omjf
[_oN]Zko0000omfd[_l0003og;>]o`000003om^a[P04o`000?oI[jko0000o`0000?ofZfY00?o0000
omR[Z_oHZjX00ol00002omFWZ@04o`000?oBYJWo0000omFVY`?o000000?odj>Uo`000?oAXJD00_oA
XJD00ol0003ocIfVo`000002o`0000CocY^R00?o0000olVHXoo9V:<01Ol000000oo;UYoo0000olNC
W`04olNCW`03o`000?o6TZ3oaY:P00Go00000_o0Ri`00ol0003o`H^Lol6;W002ol6;W005o`000?nm
R9co_HRLokf8W?l000000_nmQi`00ol0003o^hJKok^6V`03ok^6V`04o`000?nhQ9go^8BMokR4WA3o
00000_n_O9`01?l0003o[g^LojmkW?l00006oj]iW0;o00001onWMY`01Ol0003oXW:Koj9bVol0003o
Xg>L00Co00001OnOLYl01?l0003oVfjNoi]^W_nKKYh5o`0000GoV72S00?o0000oiA/XonDK:<00ol0
00000onDKZCo0000oi1[Y@04oi1[Y@?o00000on<JZL01?l0003oQfRXohMXZ?n7J:P2o`000003ohY[
ZOl0003oQ6NZ00;oQ6NZ00?o0000ohMZ[?l000001?n1J:d4o`0000CoOVN^00?o0000ogaX/OmlJ;40
0omlJ;401?l0003oMVNdogIW]?mfIk@3o`0000GoMFRf00?o0000og=Z^_mcJ[X00_l000000om]J;_o
0000og1Z_004og1Z_0;oJf_000Co0000ofM[`_l0003oJ6c31?m/K/<2ofQ_a`04o`000?mZL<OoJW37
o`0000;oI77:00Co0000ofMcbol0003o00000_mRLlh00ol0003oIgK>of]ic`02of]ic`Co00000omT
OMH00ol0003oL8CGog24e`02o`000003ofF2f_l0003oLXWK00CoLXWK0_l00003ogVBg`;oMHoO0ol0
0005ogbHh`;o00001On4X>H01_l0003oT:_Xoi2[j?n@ZnSo0000oi2[j0Go00001onJ^nl2o`0000Oo
Zl_`00Co0000okgDjol0003o00000oo9f^H01?l0003ob^W/ol[Yk?l00002omWbh@?o000000?ojoW0
o`000?l00000<OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z00Oooo]Z0009oook
JP03o`000?oonf[ooo]Z01gooo]Z00Co0000omO3a_oG`lKoel?60_l00003omK2a`03o`000?oE`LKo
eL7600?o000000?od/79o`000?oA`<T00_oA`<T02Ol0003od[o8o`000?oA_lWo0000om2nbOl0003o
ckk:o`000003olnnb@;o00000oo>_LX02Ol0003oc[c9o`000?o<_<_o0000olblbol0003obkc;o`00
0004ol^kb`04o`000?o9^/cobK[<olVjc0;o00000oo8^/`01Ol0003ob;W<olRic?l0003oakW=00?o
000000Coh<>ko`000?oR`;Goh/2e0_l00002on6n]003o`000?oP_;Coh;bd00;o00000_oN^[@00ol0
003ogKRdomfh]002o`0000;og[J^00?o0000omfd[_oM]:h00ol000000ooK/Jko0000omV_[P02omV_
[PCo00001?oHZjX01?l0003oeZVZo`000?l00003om:UZ@;o00000_oCYJL2o`0000?odJ6U00Co0000
olfMY_l0003od9nU0ol000000oo>Vj;o0000olVHX`03olVHX`04o`000?o:V:?obYRSolZHX`Co0000
0_o7Til2o`0000?oaY:P00Co0000ol>?Woo3Sioo`hnO2ol000000onmR9co0000o`000005ok^6V`;o
00001OnhQ9d01?l0003o]X6LokJ1W?l00002ok>0W0?o00000_nbOY`01Ol0003o[gbLojmlW?n_O9co
000000?o[g^L00?o0000oj]iW?n[NI`00on[NI`00ol0003oZgVLo`000003ojMfW0Wo00000_nTMZ00
0ol0003oWg:OoimbW`04oimbW`03o`000?nKKYko000000;o00000_nMLj<00ol0003oV72SoiQ`X`04
oiQ`X`?o00001?nDKZ@00ol0003oT6^Uoi1[Y@02oi1[Y@;o00001_n<JZL00ol0003oQfRXo`000004
ohY[Z@03o`000?n4Ij[oQfZ/00;oQfZ/00?o0000oh5X[On1J:d00_l00002ohAZ[P05o`000?mnJ;3o
0000o`000?mnIjh00_l00004ogaX/@;o00001?mfIk@5o`000003ogEX]_l0003o000000CoLfZj1?l0
0002og1Z_0;oK6c00om[Jl03o`0000;oK6k300Go0000ofQ_aomXKlOo0000ofU`a`02o`0000?oI77:
00Co0000ofafbom/M/_o00000_mRLlh00ol0003oJgW?of]ic`02of]ic`03o`000?m_P=?oKh3C00;o
000000?oI7gFo`000?m`Q=L01?m`Q=L4o`0000;oLXWK00?o0000ofZ7gOl000001?miT]l2o`0000Co
P9[S0_l000000omlV>?o0000o`000008o`0000;oTjgX00Co0000ohj]jon>[N_o00000_nJ^nl4o`00
00;oWKk`00?o0000oj_;l?n[bo000_n[bo03o`0000;o[loa0_l00002olWJiP09o`000?o:jNcob^W/
ol[Yk?o>i^So0000omWbhOl0003ofNoQ00Go0000<_oonfX00ol0003ooo]ZoookJP0ToookJP03o`00
0?oonf[ooo]Z00Oooo]Z0009oookJP03o`000?oonf[ooo]Z01cooo]Z0_l00003omO3aP05o`000?oG
`/Ko0000omK2aol000000_oE`LH00ol0003oeL36omG0aP02o`0000?odL3900Go0000om:ob?oB_lSo
d[o8o`000003om2nb@05o`000?o?_/Wockk9olnnbOl000000_o?_LT00ol0003oc[g:o`000003oljl
b@06o`000?o<_<_oc;c;olblboo;_<_o00000oo;^l/01Ol0003obk[;o`000?o9^/co000000;obK[<
00?o0000olRjc?l000000oo8^L`3o`0000;oh<>k00Wo0000omo1^_l0003oh/2eo`000?oQ_[Go0000
on6n]?l000000_oP_;@01Ol0003og[^do`000?oN^[Co000000;ogKRd00Co0000omZf]?l0003o0000
0ooM]:h00ol0003ofk:_om^b[`02o`0000?ofJn^0_l000000ooI[Zco0000o`000002omR[ZP04o`00
0?oFZJ[oeZVZomJYZP?o000000?odZFYo`000?oCYJL00_oCYJL00ol0003odJ>Wo`000002o`0000?o
cIfV0_l00002oljNY@Co000000?obIRSo`000?l000001?o:V:<00ol0003ob9JRolRFXP07o`0000Go
`hnO0_l00004ol6>X004o`000?nlRIoo_8VOokb9W`Go00000onkQY/00ol0003o^HFLo`000003okR4
W@04o`000?nfPIco]X6LokJ1W0?o000000?o/h2Lo`000?nbOY`00onbOY`01?l0003o[gbLojmlW?l0
0004ojmkW003o`000?n[NIco000000So00001?nWN9l2o`0000GoY7JP00Co0000oimbWonOLYooWg:O
1Ol00005oiecX`03o`000?nHL:?oV72S00?oV72S0_l00006oiA^Y003o`000?n@JjGo000000;o0000
00?oTFjVo`000?n<JZL01?n<JZL2o`0000GoRV^Y0_l00005ohMZ[0;o00001?n4JZh00ol0003oOVR`
ogiX/006o`000004ogaX/Ol0003oNfZdo`0000;oMVNd0_l00002ogYZ]@04o`000?mdJKSoM6VhogEX
]P;o00000omcJ[X01ol0003oLFbmog5/_Ol0003oKf^mog1Z_?l000000_m/K<03of][`0?oL6k10_m/
K/<01Ol0003oJ6o7ofQ_aomXKlOo000000;oKWC80_l000000omTLL[o0000ofafb`03ofafb`?o0000
0_m[NLl00ol0003oIW[Co`000004ofn0d`;o00001?m`Q=L2o`0000?oMXcK1ol000001?miT]oo0000
og6@hOl00006oh2Jh`03o`000?n4YN[oQ:GZ00GoQ:GZ00Ko0000oi>]j?nC[NSoTjgXo`000?n>[N/4
o`0000OoWKk`1?l00003ojo?l@06o`000?ncdo7o/m?ao`000?o9f^Ko00000_o:jN`00ol0003oc^KX
olkVj002o`0000;ofNoQ0ol000000ooSmjCo0000oookJP0boookJP03o`000?oonf[ooo]Z02Cooo]Z
00?o0000oookJ_oonfX01_oonfX000Wooo]Z00?o0000oookJ_oonfX07?oonfX01Ol0003of<?5o`00
0?oG`lKo000000?oel;60_l000000ooE`LKo0000omG0aP02omG0aP?o000000?odL39o`000?oB_lP0
0_oB_lP02Ol0003odKk7o`000?o@_/Wo0000om2nb?l0003ockk9o`000004olnmb@09o`000?o>_<Wo
c[c9oljlbOl0003ocKc9o`000?o<_<_o000000;oc;_:00?o0000ol^kbol000000oo;^//00ol0003o
bK[<olVjc002olVjc0?o000000?ob;W<o`000?o8^L`00_l00002on33^`;o000000?ogl6jo`000?oQ
_[D00_oQ_[D2o`000003on2l]?l0003og[^d00;og[^d0_l000001?oM^;Co0000omZf]?oJ][@3o`00
0003omfd[_l0003ofk:_00;ofk:_00Go0000omV`[ol0003ofJn^o`000002omJ][`;o000000Cof:b/
o`000?oHZj[o00000ooFZJX00ol0003odjN[om>WZ`02o`0000?odjFW00Co0000om6SYooAXjOodJ>W
0ol000000oo=WJKo0000oljNY@03oljNY@03o`000?o<VjGoc9^U00Co00000_o:V:<00ol0003ob9JR
olRFXP02olRFXP03o`000?o5Tj;o000000;oaY>R1?l000001Oo3Sioo0000ol6>X?o1SZ3o000000;o
`HjP00?o0000okb9WonlRIl00onlRIl01?l0003o_8VPokb9X?nlRJ0Po`0000;oZg^O00Co0000oj]k
Won[Nioo00001onWN9l01?l0003oY7JPojAfX?nTMZ07o`0000;oX7BR0_l00007oiecX`03o`000?nH
L:?o000000;o000000?oVG6To`000?nDKZ@01?nDKZ@3o`0000GoTFjV00?o0000ohaZYol000000_l0
00000on>KJWo0000ohY[Z@03ohY[Z@03o`000?n;KJco000000CoQfZ/0_l00006ohAZ[P;o00001?n1
Jk02o`000006ogaX/Ol0003oNfZdog]Z]?mfIkCo00001?mjJ[D00ol0003oM6VhogAY^002ogQ/^0;o
000000?oLfZjo`000?maK;d00omaK;d00ol0003oLfjnog=^_P02o`0000;oJf_000Co0000og1^`Om`
K/7oL6k11?l00002ofQ_a`03o`000?m^M<SoKWC800?oKWC80_l00003ofafb`04o`000?m_O=3oKgc@
ofmld0Co00001?m_P=<00ol0003oJ7gDo`000006o`0000?oMXcK00?o0000ofn9g?m_RM`00ommU=l<
o`0000?oQ:GZ0ol000000on4YN[o0000o`000003o`0000;oTZkY00?o0000oifnl?nM__001_nM__00
0ol0003o[loaojo?l@02ojo?l@03o`000?ncdo7o/m?a00;o/m?a0_l00002ol[Yk005o`000?o>i^So
c^KXolkVj?l000000_oIkn400ooOk]_o0000onKkb`02o`0003Gooo]Z00?o0000oookJ_oonfX08ooo
nfX00ol0003ooo]ZoookJP06oookJP002?oonfX00ol0003ooo]ZoookJP0MoookJP;o000000?of<?5
o`000?oG`/H00_oG`/H01?l0003oe/75omK1aOl00003omG0aP05o`000?oD_lGoe;o5omBoaOl00000
0ooB_lP01?l0003odKk7om6naooA_/L3o`000003om2nb?l0003ockg900;ockg900Ko0000oljlbOo>
_<Wo0000oljlbOl00003olflb@03o`000?o<^l[oc;_:00;oc;_:0ol000001_o;^/_o0000olZjb_l0
003obK[<o`0000CobKW;0_l000001Oo8^Lco0000on33^ooP`k_o000000;ogl6k0ol000001?oQ_[Go
0000omnl]?oO_;@2o`0000?og[^d00Co0000omfi]?l0003o00000_oJ][@00ol0003og;B`ombd/002
o`0000;ofk:_00Co0000omV`[ooI/:oofK2_0_l00002omJ][`04o`000?oH[:cof:b/omR/[0?o0000
00?oeZVZo`000?oCYj/00_oCYj/5o`0000CodJ>W00?o0000olnPYoo?X:L01?l000000oo>WZGo0000
olbKY@03olbKY@03o`000?o7V:Ko000000Go000000Gob9JRo`000?o5Tj;oaI>Ro`000002olJCXP04
o`000?o4TZ7oa9:QolBBX@Ko000000?o`HjPo`000?nlRIl01?nlRIl00ol0003o_8VPokb9X003okb9
X005o`000?niQioo^HNOo`000?nhQYl00ol00003okJ4WP04o`000?ndPYoo]8:Oo`0000Go/X6N00?o
0000ojmnWol000001On_OYh01?l0003oZg^Ooj]kWol00004oj]kW`03o`000?nWN9ooYgRO00?oYgRO
1Ol00003ojAhXP03o`000?nPM:;oX7BR00;oX7BR00?o0000oj5fXol000001?nMLj<5o`0000GoVG6T
00?o0000oiA^Y?l000000_l000000onEL:Ko0000oi5^YP02oi5^YPco000000GoRV^Yo`000?n;KJco
Rff/o`000003ohMZ[003o`000?n7KJko000000GoQ6Z^0_l00005oh5[/004o`000?mkJ[?oNfZcog]Z
/`?o00001_mjJ[D2o`0000?oN6bh0ol00004og5/_@03o`000?mcK[koLfjn00;oLfjn0_l00004og1^
`@04o`000?m`L/GoL7;5og1ba@?o00001Om^M<P2og1ic003o`000?m/M/_o000000;oI7?=0om_O=03
ofUmd`;o000000CoKh3Co`000?mXOMCoJ7gD0omdQmP00ol0003oKXSLofj8g002o`000003ogJ<fol0
003oKhWL00?oKhWL0ommU=l01?l0003oMi;PogNBh?l00005ohBMh`Go00001?n7Z>/01?l0003oUk3X
oiN`j?l00004oi:^j@03o`000?nM__3oWKk`00?o00000onQ`_001?l0003o[loao`000?l00005ok?C
l@;o000000?ob^W/o`000?o>i^P00_o>i^P01_oAj>Ko0000omW_hOoOk]_o0000onKkb`?o0000=Ooo
nfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z00Kooo]Z0008oookJP03o`000?oonf[o
oo]Z01cooo]Z00So0000omW2`ooI`/?o0000omO2a?l0003oel;6o`0000?oe/750_l000000ooE`<Ko
0000omBoa@02omBoa@?o000000?od[o8o`000?oA_/L00ooA_/L02?l0003odKg7om6maol0003od;g8
o`000?o?_LWo00001?o>_<T3o`000003olflbOl0003o000000?oc;_:00Go0000ol^jb_o;^/[obk[:
o`000003olZjbP03o`000?o9^L_obKW;00;obKW;00?o0000olRhboo8^</00ol000001_oP`k_o0000
omo1^ooO`K_o0000omjo^P;o00000ooO_;@01Ol0003ogk^do`000?oN^kCo000000;ogKVd00co0000
om^g]?l0003of[JdomVd]?l0003og;B`o`000?oK/joo0000om^b[ol00003omV`[`05o`000?oG[joo
0000omJ][ol000000ooH[:`00ol0003oeZ^[omJ[Z`02o`0000?odjN[0_l00002om>VZ@?o000000?o
dJ>Wo`000?o?X:L00oo?X:L00ol0003ocYnWoljOY`03o`0000?oc9^U00Go0000olNHY_l0003obYVT
o`000003olVIY@Co000000?oaI>Ro`000?l000001Oo4TZ401Ol0003o`HnRol6?X_l0003o`HnR00So
00001?nlRJ000ol0003o^HNOokV7W`03o`000003okR6Wol0003o]XBN00?o]XBN00?o0000okB2Wol0
00001_nbPIh2o`0000Ko[gjN00Go0000oj]kWon[Nioo0000oj]kW`09o`000003ojQkX_l0003oY7RR
00GoY7RR00Ko0000oj1dX_nPM:;oX7BRo`000?nQMZ<6o`0000?oWGFU00?o0000oiUaY?nILJ@00_nI
LJ@4o`0000?oUG2V1ol000000onBLJWo0000ohi_ZP04ohi_ZPgo000000CoQff^o`000?n4JZkoQ6Z^
0_l000000on4KK3o0000oh5[/003oh5[/003oh5]/ol0003oNfZc00?oNfZc1Ol00002ogYZ]@;o0000
1?mhK;P00ol0003oLfblog=/_002o`000003og5/_Ol0003oLfjn00CoLfjn00?oL732o`000?m_Kl80
0om`K/45og1ba@;oK7?90_l00002ofidb003o`000?mWLLWoL7W<00;oL7W<1?l000000om_O=3o0000
ofUmd`02ofUmd`03o`000?m_P=CoKh3D00?o000000?oJ7gDogB7f?l000001?m^R=`00ol0003oMXcL
o`000005o`000003ogfDgol0003oMi;P00?oMi;P00Go0000ohBMhon4WN?oQ9gSo`000002ogjLi@03
o`000?n7Z>_oQjS[00GoQjS[00?o0000oiN`j?l000000_nB[^T5o`0000OoXL;`00Co0000ok?ClOnc
do7o/m?a0ol000001?ngd^ko0000o`000?l00002olkVj005o`000?oAj>Ko0000omW_hOoOk]/00_l0
00001?oVnl_o0000on;dVol0000foookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0
1_oonfX000Sooo]Z00?o0000oookJ_oonfX06ooonfX02?l0003ofL;3omW2`ol0003ofL72o`000?oG
`/Co00000ooF`LD01?l0003oe/35omK0aOl00003omBoa@03o`000?oD_/Goe;k500?o00000ooA_/L0
1?l0003odKg7om6maooA_LL2o`000003om2mb?l0003oc[c900;oc[c900?o0000olfkbOo=^lT00_o=
^lT01_l0003ocK_9olfkbOl0003oc;_:o`0000?obk[:00Co0000olZib_l0003ob[[:0_l00003olVi
b`05o`000?o8^<_ob;S;olRhbol000000_oP`k/01?l0003ogl6komo1^ol00003omjo^P;o000000?o
gkbdo`000?oO^k@00_oO^k@01?l0003ogKVdomfi]?l00003om^g]0;o000000?ofKBdo`000?oK/jl0
0_oK/jl2o`0000;ofK2_00Co0000omN_[ooG[jooejn_0ol000000ooH[:co0000omJ[Z`02omJ[Z`03
o`000?oDZ:co000000;o00000_o@Y:/00ol0003odjJYo`000002om:TZ@;o00000oo?X:L00ol0003o
c9jXo`000002oljOY`03o`000?o=WJKo000000;o00000oo7V:H00ol0003obIVUolVIY@03olVIY@03
o`000?o3U:Go`iBU00Ko000000?oa9:Qo`000?o1Sj800_o1Sj800ol0003o`HnRo`000005okn=XA7o
00000_nfQ9h2o`0000Ko/X6N3Ol00003ojeoXP05o`000?nXNZ;oZ7ZRojQjX_l000000_nXNj800ol0
003oY7RRojAhXP05ojAhXPGo00000_nQN:D00ol0003oWGFUoieeY@04oieeY@03o`000?nILJCo0000
00;o00000_nILjH00ol0003oUG2Vo`000002o`0000;oUW:X0ol00003oi9aZ@04o`000?n>Kj[oSVnZ
ohi_ZP;o000000?oSfn[o`000?n:KZ`01?n:KZ`2o`0000CoQff^0ol000001On4JZko0000ohA]/?n4
KK3o000000?oPF^`0_n1KK<00ol0003oNfZcog]Z/`02o`000003ogm]]?l0003oNF^g00;oNF^g1?l0
0004ogQ/^003ogM^_?mcK;coLfbl00;oLfbl0ol00003og=^_P03o`000?m`L<;o000000?oKfo20_l0
0003og1ba@04o`000?m/LlWoK7?9o`0000;oKGC90_l000001OmWLLWo0000og1ic?m`NLco000000;o
Jg[@1?l00003ofUmd`03o`000?m_P=Co000000;oLX?D1Ol00003ofj8g0;o00001?miS]`00ol0003o
O9COo`00000Bo`000003ohNXjol0003o000000?o00000onG/NT00ol0003oXL;`oj72l004o`0000;o
Y<G`00Co0000ok?ClOl0003o00000ongd^h2o`0000;o`]o^0_l00002om7XiP04o`000?oOk]_o0000
omkff`Co0000>?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00Kooo]Z0008oook
JP03o`000?oonf[ooo]Z01[ooo]Z0_l000000ooI`/?o0000omW1`P02omW1`P?o000000?oe/75o`00
0?oF`<D00_oF`<D2o`000003omBoaOl0003oe;k500?oe;k500Go0000om:na_l0003odKk7o`000003
om6ma`03o`000?o@_<Ood;c700?o000000?oc[c9o`000?o=^lT01?o=^lT2o`000003olfkbOl0003o
000000?obk[:00Co0000olZib_o:^L[ob[W:0_l000001?o:^L[o0000olVibol00003olRhb`04o`00
0?oP`k_oh<>kon33^`;o000000?ogl6ko`000?oN_kX00_oN_kX3o`0000Cogk^d0_l000000ooM^KCo
0000om^g]002om^g]004o`000?oJ][Co0000o`0000?ofk>_00Go0000omZb/?l0003ofK2_o`000003
omN_[`03o`000?oD[;3oe:b`00;o00000_oFZj/00ol0003oe:R/omBX[002omBX[0?o000000?od:B[
o`000?oBY:T00_oBY:T02_l0003od::Yo`000?l0003ocj2Wo`000?o<WZSo0000oljOYol00004olfM
YP?o000000?oaiRVo`000?o9VJD00oo9VJD00ol0003o`iBUol>DY@02ol>DY@03o`000?o4U:Goa9BU
00;oa9BU1?l000000oo1Sj;o0000o`000005okn=X@04o`000?nmS:;o0000okb;XPCo00000onhQj80
0ol0003o^8NRo`000004okN7XP_o00001on_PJ<2o`0000Ko[GnR00Co0000ojQjX_nXNZ;o00001?nX
Nj801?l0003oY7RRojAhX_nTN:85o`0000GoXGRU00?o0000oieeYOnMMJD00onMMJD3o`0000CoVG>V
0ol00004oiIbZ0;o00001_nBLJT3o`0000?oSfn[00Co0000ohY^[?n:KZcoRVj/0_l000000on<Kjgo
0000ohM][P03ohM][P;o00000on4KK44o`000003oh5[/?n1KK?oPFfc00;oPFfc00?oNfZco`000?mo
KK@00omoKK@01?l0003oNF^gogU[]ol00002oge^]`;o00000_mhK;P2ogM^_004o`000?mcK;coLfbl
o`0000;oMfnl0_l00002og=^_P06o`000?m`L<;oL732o`000?m_Kl;o00000omcL/82og1ba@04o`00
0?m/LlWoK7?9ofacb@;o00000_maMlT2o`000003og1ic?l0003oJg[@00?oJg[@00?o0000og9odOmb
Om400_l00002ofUmd`03o`000?mbPmCoLX?D00?oLX?D00?o0000ogN:fOmgR]T00_l000000om^R=co
0000ogV>g005ogV>g0;o00001OmmU^03ohROh`05o`000?n3WNCoPigToh>Mi?l000001on?Z>H00ol0
003oUk7YoiNaj@02oiNaj@Go00001onTaO000ol0003o]m;^okOBkP02o`000003ok[DkOl0003o`]o^
00;o000000?oa^G]o`000?l000000_l000000ooOk]_og_KKomkff`04o`0003Sooo]Z00?o0000oook
J_oonfX08OoonfX00ol0003ooo]ZoookJP06oookJP002?oonfX00ol0003ooo]ZoookJP0IoookJP04
o`000?oJ`/;of/;2o`0000?ofL7200?o0000omS1`_oH`L800_l00003omK0a@05o`000?oD_lKoe;o6
omBoaOl000000ooD_/D01Ol0003odkk5o`000?oB_/Ko000000?odKg700Ko0000om2laoo@_<Ood;c7
o`000?o@_<H2o`0000GocK_900?o0000olfjb?o=^/P00_l000001?o=^/Wo0000ol^jb_l00003olZi
bP06o`000?o:^<Wob[S9o`000?o:^L[o00000oo8^</01Ol0003oh<>kon33^ooP`k_o000000;ogl6j
00Go0000omjo^_oN_k[og[njo`000002omfn^P05o`000?oO^kCogk^domnk]?l000000_oM^[@2o`00
00;ofkNd00Co0000omZf]?oJ][Cof[Jd0_l000000ooK/joo0000omZb/002omZb/0?o000000?oejn_
o`000?oD[;000_oD[;001Ol0003oeZ^]o`000?oFZj_o000000Coe:R/00?o0000om:V[?oBYZ`00_l0
0003om:TZ@04o`000?o@XZWod::Yom2RZ@Co000000?ocYnWo`000?o=WJH00oo=WJH00ol0003obI^W
olVKY`04o`0000;obIVU00?o0000ol>DYOo3U:D00_o3U:D00ol0003oa9BUolBDY@03olBDY@03o`00
0?noT:Go_i2U00Ko00000_noSJ44o`0000;o_8^R00?o0000okR7X_nhQj800_nhQj800ol0003o^8NR
o`000006okN7XP03o`000?ncQ:?o/hBS00Go/hBS00?o0000ojn1Xon_PJ<01On_PJ<00ol0003o[GnR
ojeoXP05ojeoXP03o`000?nXNZ;o000000;oZ7^R1ol00002ojAiY0;o00001onQN:D00ol0003oWGFU
o`000002o`000004oiefY_l0003oVG>VoiUcYP?o000000CoVWFXo`000?nFLZSoUW:X0ol000000onF
LjWo0000oi9aZ@04oi9aZ@;o00001_n?Kj/00ol0003oRVj/o`000003oha_[@07o`000?n7KJkoQff^
ohM][_l0003oRFn_o`000006ohA]/@Co00000_n1KK<00ol0003oOffdogm]]003ogm]]003o`000?mi
JkOo000000?oOFjg00Co0000ogM]^_mhK;So00000omgK[`00omcK;co0000ogM__002ogM__003o`00
0?mbK[oo000000?o000000?oL732o`000?l000001?mcL/85o`000003ofacbOl0003oLGO900CoLGO9
1Ol000000om[N]3o0000og9od@04og9od@?o00001?mbPm@00ol0003oMh[IogN:f@03ogN:f@?o0000
1OmiS]`00ol0003oOIKPogfFh004ogfFh003ohROhol0003oPigT00CoPigT00Co0000ohnXi_n?Z>Ko
SjSV0_l000000on?Z>Ko0000o`000003o`0000CoV;W_00?o0000ojC5l?nTaO000ol00004ojS9l@04
o`000?nje>go^]C]ok[Dk@;o00000_o6iNd02?l0003obmgWol_Mioo;gNOo0000omkffol0003oh_SF
0_l000000ooVlYOo0000oookJP0hoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0
1_oonfX000Sooo]Z00?o0000oookJ_oonfX06?oonfX01?l0003of/;2om[2`_oJ`/82o`000003omW1
`_l0003of<7200;of<7200Go0000omRo`_l0003oe/35o`000003omBoaP05o`000?oD_/Co0000omBn
aOl000000ooC_/D01Ol0003od[g6o`000?oA_LOo000000?od;c700Co0000om2la_o@_<Kod;c60_l0
0003olfkb@04o`000?o=^/SocK[8o`0000;ocK[700?o0000olfjbOl000000oo:^LX00ol0003ob[S9
olZhb@02olZhb@?o000000Kob;S;o`000?l0003o0000on33^ol00003omo1^P;o000000?og[njo`00
0?oM_[X00_oM_[X2o`000003omnk]?l0003ogKZd00;ogKZd00Go0000ombh]?l0003ofkNdo`000003
omZf]004o`000?oG/kGo0000o`0000?of[:`00?o0000omR`/?oH/;000_l00003omB//003o`000?oF
ZjgoeZ^]00?o00000_oDZ:`01?l0003odZJ/om:V[?oBYZ`5o`0000Cod::Y00?o0000ol^NZ_o;WZX0
1?l00002olfMYP03o`000?o9VjOobI^W00;obI^W00?o0000olRJYoo8VZL01Ol000001?o3U:Go0000
ol>DYOl00003olBDY@03o`000?noT:Go_i2U00;o_i2U00?o0000okn@YOnoT:D00_noT:D<o`0000;o
^8NR00?o0000okN7X_ngQj801?ngQj82o`0000Ko/hBS00?o0000ok:3X_l000001_n_PJ<00ol0003o
[GnRojeoXP02ojeoXPSo00000onYOZD00ol0003oY7VTojAiY002ojAiY003o`000?nUNjGo000000Co
XGRU1Ol00004oiefYP?o00000onJMJP4o`0000CoUW>Y00Co0000oi9aZOnBLJWoTW6Y0_l000000onC
LZ_o0000ohm_Z`04ohm_Z`03o`000?n:KZcoS6n]00GoS6n]0_n7KJh3ohU_[`03o`000?n4KK7oQ6fa
00?oQ6fa00?oQVnaoh5]/on1KK<00_n1KK<6o`0000;oOffd0_l00005oge^]`03o`000?mkKk[oNfnj
00Co00001OmgKk`00ol0003oMg70ogMa`002ogMa`0;o00001OmcL/800ol0003oM7K6ogAfaP02ogAf
aP;o00001OmaMlT00ol0003oLgc>og=lcP02og=lcP;o00001OmbOm42o`0000?oMXKE1?l00004ogN:
f@;o00001?mlTMd00ol0003oNHkLo`00000Ao`0000?oTj_W0_l00008oiRik`;o00000onXbO43o`00
00;o[<ga00Go0000ok[DkOnje>go0000olKUk@02o`0000CobmgW1?l000000oo/nKgo0000o`00000k
oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX01_oonfX000Sooo]Z00?o0000oook
J_oonfX05ooonfX01Ol0003of/;2om[2`_oJ`/;o000000;of/710_l00002omS1`P05o`000?oH_l;o
f;o2omRo`_l000000ooD_lH01Ol0003oe;k4omBna?oD_/Co000000?odkk500Co0000om>maOl0003o
d[g60ol000000oo@_<Oo0000om2laP02om2laP06o`000?o@^lKod;_6o`000?o=^lWo00000_o=^/P0
0ol0003ocK[7olfja`02olfja`?o000000?ob[W:o`000?o:^<T00oo:^<T01?l0003obkS8ol^hb?o;
^<P2o`0000;oh<>k0_l00002omo1^P03o`000?oN`;[og/2j00;o00000_oM_[X00ol0003ofkbjom^l
^P02o`0000;ogKZd00Go0000ombh]?oL^;Cog;Rdo`000003omZf]003o`000?oG/kGoek>e00?o0000
00?of[:`o`000?oH/;000_oH/;002Ol0003oeZj`o`000?oD[;3o0000om:[/?l0003oeZ^]o`000002
omBZ[@?o00000_oBYZ`00ol0003ocZB]o`000002om6UZ`?o000000?od::Yo`000?o;WZX00oo;WZX0
0ol0003oc9nYolbOZ@04o`0000;obI^W0_l00003olRJY`04o`000?o7V:KoaiRVolNHYPKo000000?o
a9BUo`000?noT:D00onoT:D00ol0003o_i2Uo`000002o`000003okn@YOl0003o^hbT00;o^hbT00?o
0000okb=Y?l000001?nkS:DOo`0000?o[82U00?o0000ojUnYOnYOZD01OnYOZD01_l0003oY7VTojAi
Y?nTNJCo0000ojEkY@Ko00000onQNJL00ol0003oWGJVoiefYP02oiefYP04o`000?nNMjOo0000oiYe
Z0?o00000_nJMZT00ol0003oUW>YoiIcZ@04oiIcZ@?o00000onCLZ/01?l0003oSfn[ohm_Zon?Kj/2
o`000003oi1a[?l0003oS6n]00CoS6n]00?o0000ohM][_n9Kjl01?n9Kjl3ohA]/@?oQVna0on1KK<0
1Ol0003oQ6ndohA_]?n4KkCo000000;oOVjf1?l00004oge^]`;o00001?mkKkX4o`0000;oMfnl00?o
0000ogMa`?mgLL001?mgLL000ol0003oLW;4og=b`P03og=b`P03o`000?mdM/KoM7K600?oM7K61?l0
00001?maMlWo0000ofiicOl00004og=lcPCo000000GoLWoAo`000?m/OM?oK7gCo`000003ogJ6e@03
o`000?m`PmKo000000Oo00001OmlTMd00ol0003oPiWQoh>Ih@05oh>Ih@03o`000?n8XNCoR:7T00Co
R:7T00?o0000oi>[ionCZnL00onCZnL00ol0003oSZcZo`000002oiRik`?o00000onL_>l01?l0003o
Z<Wao`000?l00006ojc=l@04o`000?nne^co0000o`0000GobmgW00?obnS[o`000?oInMl01Ol0000l
oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX01_oonfX000Sooo]Z00?o0000oook
J_oonfX05ooonfX2o`000003om[2`_l0003of/7100;of/7100Go0000omW0`Ol0003of<72o`000003
omRo`P;o000000?oe;o6o`000?oD_/@00ooD_/@2o`000003om>naOl0003odkg500;odkg500Go0000
om6laOoA_<GodKc5o`000003om2laP04o`000?o@^lKod;_6om2kaP?o000000?ocK[8o`000?o=^/L0
0oo=^/L01?l0003ocKW7olfiaoo=^LL2o`0000?ob[S900?o0000ol^hb?o;^<P00_o;^<P3o`000006
on33^ol0003ogl6ko`000?oO`K[o00000_oN`;X01Ol0003ogKjjo`000?oM_[[o000000;ofkbj00Go
0000omfj]Ol0003ogKZdo`000003ombh]0;o000000?of[Jdo`000?oG/kD00_oG/kD00ol0003ofK:a
omVb/@02o`0000;of;2`00Co0000omJ^/?oF[[3oeZj`1Ol00004omBZ[@05o`000?oBZ:go0000om:V
[?l000000_o>Y:d2o`0000?od:B[0ol00002ol^NZP;o00000oo<WjT00ol0003obifXol^MZ005o`00
0003olRJYol0003oaiRV00CoaiRV00?o0000ol>EY_l000000_o4UJH4o`000004okn@YOl0003o0000
o`0000?o_i2U00?o0000ok^<Y?nkS:@00_nkS:@2o`0000Oo^hbU00?o0000okN9YOngRJD00ongRJD0
0ol0003o]XNTo`000005ok>6Y004o`000?nbQJCo/XFTo`0000Go[h>T00?o0000ojn2Y?l000001_n/
P:D00ol0003oZGjUojUnY@05ojUnY@03o`000?nTNJCo000000?o00000_nVOJL00ol0003oXGVWoj5i
Y`04oj5iY`03o`000?nMMZKoWGJV00;o000000CoWWNWo`000?l0003o00001OnJMZT00ol0003oUW>Y
oiIcZ@02oiIcZ@?o00001_nCLZ/3o`0000?oT76/00Co0000oha_[On<KjgoS6n]0_l000000on=LJoo
0000ohU_[`03ohU_[`03o`000?n4KK7oQVna00GoQVna00?oPFfco`000?n4Kk@00on4Kk@00ol0003o
OVjfo`000003oh9`]`?o000000CoOFjgo`000?mlL;[o00000omkKkX00ol0003oNW:no`000002ogM`
_PCo00001?mgLL000ol0003oM7?4o`000003og9ba0?o00000omdM/H00ol0003oKW?7ogEjbP02ogEj
bPCo00000omcO<h00ol0003oKW[>ogN2d@02ogN2d@Go00000_mfQ]D01?l0003oL8?Fog23e_l00004
og^<f@03o`000?meR][o000000Oo00001_n3VN400ol0003oR:7TohRQi005ohRQi003o`000?nCZnOo
Tj_W00Oo00001onL_>l00ol0003o[<gaojc=l@02ojc=l@?o000000Co/=;bokkFk?l0003o00000oo;
gNL02Ol0003obnS[ol_Xjol0003ofOWOo`000?oMlMgo0000on7mbP02o`0003cooo]Z00?o0000oook
J_oonfX07ooonfX00ol0003ooo]ZoookJP05oookJP002?oonfX00ol0003ooo]ZoookJP0FoookJP04
o`000?oM`Kko0000o`0000?of/7100Go0000omW0`OoI`<7ofL31o`000003omRo`P03o`000?oG_/7o
ekk100;o00000ooD_/@00ol0003oe;g4omBma002o`0000?odkg50_l000001_oA_<Go0000om6kaOl0
003od;c6o`0000Cod;_60_l000000oo>^/Ko0000o`000003olfja`03o`000?o=^LOocKW700;ocKW7
00Go0000ol^haol0003ob[S9o`000005ol^hb004o`000?oMa<3ogLC0o`0000?ogl6k00Co0000omk0
^_oN`;[o00000ooM_[X01ol0003ofkbjom^l^_oK_;[of[Zjo`000?oM^[D00_l00002ombh]003o`00
0?oJ]kCof[Nd00?o000000[oek>eo`000?oF/[Go0000omVb/Ol0003of;6ao`000?oH/;3o00000ooF
[[000ol0003oe:b`omB//002o`0000?oe:Z]00Co0000om:X[OoBZ:godZR]0ol000000oo>Y:go0000
om2TZ`03om2TZ`03o`000?o>XZ_ocZ:[00Go000000?oc9nYo`000?o;WJP00oo;WJP00ol0003oaYVY
olJIZ@05o`0000;oaiRV00Co0000ol>EY_o3UJKo00000_o4UJH00ol0003o`iBVo`00000;o`0000;o
^hbT0_l00006ok^<Y@;o00001?ngRJD01?l0003o]XNTokJ7Y?l00004ok>6Y005o`000?nbQJCo/XFT
ok:5Y?l000001?n_Pj@01?l0003o[h:Tojn2Y?l00005ojb0Y@03o`000?n/P:Go000000?oZGjU1_l0
0005ojImY`03o`000?nQNJOoXGVW00CoXGVW00?o0000oiefY_l000000ol000000onNNJWo0000oiYf
Z@05oiYfZ@03o`000?nFLjWo000000;o00000_nGM:X00ol0003oTg:[oi=bZ`03oi=bZ`;o00001_n@
LJ`00ol0003oS6n]o`000003ohea[`07o`000?n9KjooRFn_ohU_[ol0003oRW6ao`000005ohI_/@;o
00001On4Kk@2o`0000CoPW2g00Co0000oga_^Ol0003oOFjg0_l000001?mlL;[o0000og]_^_l00003
ogYb_P03o`000?mgL;koMg2n00?oNW:n00Co0000ogMa`?mgLL3o00000_mdLl@01?l0003oLW;4og9b
a?l00002ogMea0;o00000_mdM/H00ol0003oKW?7ofica`03ogEjbP?oLGc>1?l00002ofijcP?oMh;A
00?o0000og:3e_mbPmH02?l00002og^<f@04o`000?meR][oMH[Jo`0000CoP9CM00?o0000og^Bg_mk
T]h04Ol00002oiN^i`04o`000?nB[NWoTZgYo`0000;oW;c_1?l00002oio0l003o`000?n/cO7o0000
00;o00001On`d_800ol0003obmgWol_Mi`02o`0000;obnS[00?ocn_Xo`000?l000000_oMlMd00ooQ
oL[o0000o`00000noookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX01OoonfX000Oo
oo]Z00?o0000oookJ_oonfX05_oonfX01?l0003ogL6nomg1__oM`Kh2o`000003om[1`Ol0003ofL31
00?ofL310_l000000ooH_l;o0000omNn`@02omNn`@05o`000?oF_/;o0000omBna?l000000ooD_L@0
1Ol0003oe;c3o`000?oC_LGo000000;od[c400Co0000om6kaOoA^lGodK_50_l00003om2kaP04o`00
0?o?^/Gock[5o`0000;oc[W600?o0000olfjaol000001Oo=^LL00oo=^<Ko0000ol^ha`02o`0000Co
bkS800Cob[O8o`000?l0003ogLC00_l000001_oO`K_o0000omk0^_l0003og/2jo`0000?ogKjj0_l0
00001OoK_;[o0000omZj^_oJ^[[o000000;og;Re00?o0000ombh]?l000000_oJ]k@00ol0003ofKFd
omVe]002o`0000;oe[:e00Co0000omRa/OoH/K7of;6a0_l00002omJ^/003o`000?oD[;3oe:b`00;o
e:b`0ol000000ooDZZgo0000om:X[@02om:X[@03o`000?o@YZkod:J^00;o00000oo@Y:/00ol0003o
cZ:[oljRZ`02oljRZ`06o`000?o9WZcobIj/o`000?o<WjWo00000oo;WJP01ol0003oaYVYolJIZOo6
VJWo0000olRKZ?l000000_o7VZT5o`000003ol>EY_l0003o000000;o00000oo3U:H00ol0003o_i6V
o`000002oknAYP04o`000?nnT:Ko_Y2Vokj@YPKo00000onkS:D00ol0003o^HZTo`000004okN9Y@05
o`000?nfQjCo]XNTokJ7Y?l000000oncQZ@01Ol0003o/XFTok:5Y?nbQJCo000000?o[h>T00?o0000
ojn2Y?l000003Ol00004ojQnYP03o`000?nVOJOoYWfW00CoYWfW00Co0000oj5iYonQNJOoXGVW1_l0
0004oiiiZ@03o`000?nJMZWoVWJY00?oVWJY0ol00005oiMdZP04o`000?nCLZ_oTg:[oi=bZa[o0000
00CoQVnao`000?n7LKCo00001?n4Kk@2o`0000GoPW2g0_l00004ogma^@Co00000omjL[h00ol0003o
Mg2no`000003ogYb_P03o`000?mfL/7o000000Co000000?oLW;4o`000?mgML@00_mgML@00ol0003o
LgK7o`000004o`0000;oMG[:00Ko0000og5lc_maO<koLGc>o`000?mcOLh2ogMoc`;o00000_mgP]40
0ol0003oLX?Fog:3eP02og:3eP03o`000?mfQ]Ko000000?oNHSF1_l000001OmeR][o0000oh2DgOn0
U=go000000?oNi;N00?o0000ohJLhOn6W>400on6W>42o`0000OoR:OY00Co0000oiN^ionG[^Oo0000
0_nB[NT4o`0000OoWl3`00?o0000ok3Bl_n`d_800_n`d_83o`000004okCGl_l0003o0000o`0000;o
bnS[00Co0000olo[j?l0003o00000_oMlMd2o`000003on;ma?l0003ooo]Z03kooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP05oookJP001ooonfX00ol0003ooo]ZoookJP0EoookJP;o
00000ooM`Kh4o`0000?ofL3100Co0000omVo`?oI_l3o00000ooG_/401Ol0003oekk1o`000?oF_/;o
000000?oe;g400?o0000omBl`ooD_<<00ol000000ooB_<Co0000o`000003om6ka@05o`000?o@^lGo
0000om2ka_l000000oo?^/D01?l0003oc[W6oljia_o>^LH2o`0000CocKW70oo=^<H01?l0003obkO7
ol^gaol00002ol^hb005olZgb?l0003ogLC0omg4`?l000000_oL`/001Ol0003og/2jomk0^_oN`;[o
000000?ogKjj00?o0000ombm^_oL_KX00ol000000ooJ^[[o0000o`000002ombh]@;o000000?of[Nd
o`000?oI]K@00_oI]K@01Ol0003oek>eo`000?oF/[Go000000?of;6a00Go0000omN_/Ol0003oeZj`
o`000003omB//0;o00000_oDZjl3o`000003om:X[Ol0003od:J^00?od:J^0ol000000oo@Y:_o0000
oljRZ`02oljRZ`04o`000?o9WZcobIj/olVN[0Co00000_o;WJP00ol0003oaYVYolJIZ@02olJIZ@03
o`000?o7VZWoaiZY00;oaiZY00?o0000ol:FZOo2UZT01_l00002ol>DYP06o`000?noTJKo_i6Vo`00
0?noTJKo00001_nnT:H01?l0003o^hjWok^>YonkSZLLo`0000;o/HFW00Go0000ojb1Y_n/PJKo[86V
o`000003ojb1YP03o`000?nXOZKoZ7jV00CoZ7jV0_l00003ojImY`Oo000000CoXGZXo`000?nRO:Wo
00001onNNJT00ol0003oVWJYo`000002o`000003oi]gZ_l0003oUgBZ00CoUgBZ1_l00002oiAe[P04
o`000?n@LjkoT7>^oi1c[P;o000000?oTGB_o`000?n=L[001?n=L[02o`0000GoRG6b00?o0000ohI`
/ol000001_l000001?n4KkCo0000ohAa]_l00004oh9`]`03o`000?n1L[Wo000000GoOg6i00?o0000
og]a_?mkLK`00ol000000omjL[ko0000ogYb_P04ogYb_P03o`000?mjML;oNWG200;oNWG20_l00005
ogMea003o`000?mgNLSoMgW800?oMgW80ol00004og5lcP03o`000?mgOlooMgo?00?oMgo?1Ol00002
og:3eP03o`000?miR=KoNHSF00?oNHSF0_l00003ogj?fPSo000000?oNi;No`000?n6W>400_n6W>40
1?l0003oPI_Soh6Khol00004ohRWj@;o000000?oR:OYo`000?l000000ol00003oiN`j003o`000?nO
`?3oWl3`00?o00000onSa?001?l0003o/=;bo`000?l00003okCGlP;o000000Co`>3_o`000?o;j>_o
00000_o?jnP01_l0003ogO7MomgagOl0003ohOg:on;ma0;o0000?ooonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z00Gooo]Z0007oookJP03o`000?oonf[ooo]Z01Gooo]Z00Go0000omk1
_?l0003ogL6no`000002omc0_@05o`000?oK_kko0000omW0`Ol000000ooI_l02o`000003omNn`Ol0
003oekk100;oekk100Go0000omFm`_l0003oe;g4o`000002omBl``04o`000?oC_<?odkc3om>l``;o
000000Cod[_4o`000?oA^lGo00000oo@^lD02Oo@^lKo0000o`000?o?^/Go0000olniaOl0003oc[W6
o`000002oljiaP03o`000?o=^LOocKW700?ocKS60_l00003ol^ga`?o00000ooMa<02o`000009omc2
`?l0003o0000omk0^_l0003ogKjjo`000?oM_[[o000000?og;fj00Co0000om^k^_oK^k[o00000_oH
^KX01?l0003of[NeomZg]OoJ]kD2o`0000;ofKFd00Co0000omNc]OoG/kGoek>e0ol000000ooH/K7o
0000omN_/@02omN_/@?o000000Ooe:b`o`000?oAZ[7odJZao`000?oDZjoo000000;odjZ_0_l00003
om2V[P04o`000?o=Y:oo0000om2U[@?o00000_o>XZ/00ol0003obIj/olVN[002olVN[003o`000?o;
Wj_obin[00Go00000_o6VJT01?l0003oaiZYolNJZOo7VZT4o`0000;o`YJY00Co0000ol>FZOo3UZWo
`iJY1Ol000000onoTJKo0000o`000005okj@YP;o00001OnkSZL01?l0003o^H^VokV;Y_l00003okN:
YP03o`000?ndQjKo]8NV00;o]8NV00Co0000ok>7Y_ncQjKo00001?ncQjL00ol0003o/8BVo`000005
ok65Y`04o`000?n/PJKo[86Vo`0000Go[86V00?o0000ojQnY_nXOZH00_nXOZH6o`0000?oYGfX00?o
0000oj5jZ?nQNZP00_l00002oj9lZ@03o`000?nNNJWoWWVY00?oWWVY1?l00005oi]gZP03o`000?nG
M:[o000000?o000000?oV7R]o`000?nDMJh01OnDMJh3o`0000?oTGB_00Co0000oheb/?n=L[3oSG:`
0_l000000on>Lk3o0000ohUa/P04ohUa/P;o00001On6LK@2o`000005ohA_]?l0003o0000ohAa]_l0
00000_n2L;L01?l0003oPG:ioh5b^Ol00004ogma^@03ogmc_?l0003oNg6l00?oNg6l1?l00003ogYb
_P03o`000?mjML;oNWG200CoNWG20_mjN<D4ogMea003o`000?mgNLSoMgW800CoMgW80_mhOL`2o`00
00;oLGc>00?o0000ogMocomgOll00omgOll00ol0003oNHGCogV5d`02ogV5d`Go00001?miR=H00ol0
003oOXoJogj?fP03ogj?fP03o`000?n0U=ko000000?oPIGN3Ol00003oi2Wi@03o`000?nF[nSo0000
00CoUk3X1?l00007oj?4l003o`000?ndeo;o]=Ob00?o]=Ob00?o0000ol3Pkoo0h>l00_l00002olo[
j0;o000000KogO7Momcig?l0003oh_g4o`000?oIkHU1oookJP03o`000?oonf[ooo]Z01cooo]Z00?o
0000oookJ_oonfX01OoonfX000Oooo]Z00?o0000oookJ_oonfX05?oonfX01Ol0003og/6lomk1_?oN
`Kco000000?og<2m0_l000000ooK_kko0000omVo`002omVo`005o`000?oH_/3of;k0omNn`Ol00000
0ooG_/42o`000005omFm`_l0003o0000omBl`ol000001?oC_<<01Ol0003odk_2o`000?oB^lCo0000
00?od;_500Go0000olnjaOo?^/Gock[5o`000003olnia@03o`000?o>^LKoc[W600;oc[W60ol00000
2Oo=^<Ko0000olbga_o<]lKo0000ol^gaol0003obkO7o`000003omg4`004o`000?oL`/3og<;0o`00
00;ofl6o00Co0000omfn^_oM_[[ogKjj0ol000000ooL_K[o0000om^k^P02om^k^P;o000000?of;Vj
o`000?oJ]kD00_oJ]kD01Ol0003ofKJeo`000?oI]KCo000000?oek>e00?o0000omBa]_oD/KH00_l0
0003omN_/@03o`000?oE[[7oeJja00;o00000ooAZ[401_l0003odjZ_om>Z[ooCZZoo0000om6X[P;o
000000Cod:J^o`000?o=Y:oocJB_0_l00002oljT[@Co00000_o9WZ`2o`0000?obin[00Co0000olVM
Z_o9WJ[obIfZ1ol00004ol:FZ@;o00001?o3UZT01?l0003o_Y:XokjBZ?nnTZP5o`0000?o_Y2V00?o
0000okb>Yol000000onkSZL01Ol0003o^H^VokV;Y_niRjKo000000;o]hZV00?o0000okB7Y_ndQjH0
1?ndQjH2o`0000Ko/hNW00?o0000ok65YonaQJL01OnaQJL2o`0000;o[86V2_l000000onYPJWo0000
ojEmZ006ojEmZ0;o00001OnRO:T2oiiiZ@?o00000_nNNZX00ol0003oVgNZoi]gZP02oi]gZPGo0000
1?nHN:d00ol0003oU7F^oiAe[P02oiAe[P?o00001_nAM:l2oheb/005o`000?n>Lk3oSW>`ohic/?l0
00001?n9LK800on<Lk;o0000ohIa]005ohIa]003o`000?n4LKKoQ76f00;oQ76f0ol000001_n2L;Oo
0000o`000?l0003oPG:io`0000;oOg6i0omoLk`01?l0003oNg6log]a_?l00002ogic_@03o`000?mj
LkooNW>o00Co00001?mjML800ol0003oMG?3ogYha@03ogYha@Co00000omgNLP00omdNlco0000ogQm
c003ogQmc0Go000000CoMgo?o`000?mcP]?o00001OmiQM<01?l0003oOH_Gogf;eommRmL4o`0000Ko
OXoJ00?o0000oh6Eg_n1UMh00on1UMh01Ol0003oRYoQohZOhOn:Wn7o000000CoQIcR00?o0000oi2W
iOn@YnD01?n@YnD00ol0003oUk3XoiN`j003o`0000?oV;S^00?o0000oj?4l?nSa?000ol00003ojO9
l@05o`000?ndeo;o0000o`000?nie>h00ol00002olGVkP?o000000?ogO7Momcig?l000000_l00000
0ooIkHWo0000oookJP11oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX01OoonfX0
00Oooo]Z00?o0000oookJ_oonfX05?oonfX01?l0003og/6lomk1_?oN`K`2o`000009omc0_Ol0003o
fknmom^o_Ol0003of[nno`000?oI_l3o000000?of;k000Go0000omRm_ol0003oekk1o`000002omJm
`@03o`000?oE_<;oeKc200;o00000ooC_<<02Ol0003odk_2om>k`_oC^l;o0000om6ka?l0003od;_5
o`000003olnja@09o`000?o?^LCo0000olniaOl0003ockW5o`000?o>^LKo000000CocKS50_l00003
olbgaP03o`000?o;]lOobkO700;o000000?ogLC0o`000?oL`/000_oL`/02o`000003om_1_ol0003o
gKjj00;ogKjj00Co0000ombm^_oL_K[o00000ooK^kX00ol0003ofKZjomVj^P03o`000003omZg]Ol0
003ofKJe00;ofKJe0_l00002omNc]@04o`000?oD/KKoe;6fomBa]P?o000000?oejnao`000?oE[[40
0_oE[[401_l0003odjbao`000?l0003odJZao`0000;odjZ_00?o0000om6X[_oAZ:h00_oAZ:h3o`00
0003olfT[ol0003ocZB]00?ocZB]00?o0000olbR[?o<XZ`01?l00002ol^OZ`03o`000?o9WJ[obIfZ
00?obIfZ0ol000000oo7Vj[o0000o`000002o`0000;o`YJY00?o0000ol:FZOl000000_o3UZT00ol0
003o_Y:XokjBZ003okjBZ004o`000?nnTZWo_Y:YokjBZ@co00000_niRjH00ol0003o]hZVo`000006
okB7YP03o`000?ncQjOo/hNW00Go/hNW00Co0000ok65YonaQJOo/HFW2?l00004ojb3Z@03o`000?nX
OjSo000000CoZH6Y00?o0000ojEmZ?nUOJP01?nUOJP2o`0000?oXWbY1Ol00005oiijZP03o`000?nK
Mj[o000000;o000000?oVgV/o`000?l000001_nHN:d00ol0003oU7F^o`000002o`0000;oUGJ^00?o
0000oi5d[onAM:l00onAM:l00ol0003oSG:`ohic/005ohic/003o`000?n9LK;oRG6b00?oS7>b00?o
0000ohIa]?n6LK@00_n6LK@00on9LkCo0000ohAa]P04ohAa]P;o00001?n1L[T2o`000003ogma^Ol0
003oOg>l00;oOg>l00?o0000og]a_?l000000omnLkd01?l0003oNW>oogYc_ol00003ogef`004o`00
0?mjML;oNWG2o`0000;oMG?30omjN<D01?l0003oMg[9ogMjbOl00002ogMjb@05ogMib?l0003o0000
ogAkc?l000000omhOL`00ol0003oLg_<ogZ2c`02ogZ2c`Co00001?miQM<00ol0003oLh?Do`000004
ogf;e`03o`000?mgRMSo000000Co000000?oOXoJo`000?l000001?l000001?n1UMko0000ohZOhOl0
0003ohFLhPSo000000CoT:OUo`000?l0003o00001onH^>h2o`0000OoYlWa00Co0000okWDk_nie>ko
00000oo5i^h2o`0000;ob]oX1?l000000ooRoLCo0000o`000014oookJP03o`000?oonf[ooo]Z01[o
oo]Z00?o0000oookJ_oonfX01OoonfX000Oooo]Z00?o0000oookJ_oonfX04ooonfX01Ol0003og/6l
omk1_?oN`Kco000000;ogL2k00Co0000om^o_OoK_kgofknm0_l000000ooJ_kko0000omRn`002omRn
`005o`000?oH_Koof;foomRm_ol000000ooF_L42o`000006omFl`_l0003oe;_1o`000?oC_<?o0000
1?oC^l82o`000003om6ka?l0003ock[500;ock[500Co0000olnia?o?^LCockW40_l00002olnia@03
o`000?o=^<GocKS500;ocKS500Oo0000olbga_o<]lKo0000olbga_l0003oc;O600;o00000_oMa;l0
1Ol0003og<;0omc2`?oL`/3o000000;ofl6o0ol000000ooM_[[o0000ombm^P02ombm^P;o000000?o
fk^jo`000?oI^[X00_oI^[X01?l0003of;Rjo`000?l00004omVf]@05o`000?oH];Go0000omNc]Ol0
00000ooD/KH00ol0003oe[2bomJ`/P02o`0000;oeJja00?o0000om>//OoC[;400_oC[;43o`000003
om>Z[ol0003odJR^00?odJR^00?o0000olnV[oo?YZl01?l000000oo>Y:go0000olbR[003olbR[003
o`000?o8WZgo000000So00000_o4VJ/00ol0003oai^Zo`000003olFJZ`Ko000000?o`iJYo`000?nn
TZP01?nnTZP00ol0003o_Y:YokjBZ@03okjBZ@04o`000?njSZSo^XjXo`0000;o^hnX00Co0000okZ?
ZOnjSjWo^XnY5ol00003ojn6Z0;o00001on/PjT2o`0000KoZH6Y00?o0000ojEmZ?nUOJP02?l00003
oj9mZ`03o`000?nNNZ[oWWZZ00?oWWZZ0ol000001_nKNJco0000o`000?l0003oW7Z]o`0000GoV7R]
0ol00005oiEf[P04o`000?nAM:ooTGB_oi5d[`;o000000?oTWF`o`000?n>Lk001On>Lk02ohUa/PCo
S7>b00Co0000ohIa]?n6LKCoQW6d0_n9Lk@00ol0003oQ76fohAa]P02ohAa]P03o`000?n6LkOo0000
00GoPG:i00?o0000ogmc^omoLk/00ol000000omoLkco0000ogic_@04ogic_@;o00001?mmM/000ol0
003oNGK3o`000003o`0000;oNWS500?o0000ogMjbOmgN/T00_mgN/T00ol0003oMg[9ogYlb@02ogYl
b@;o00000_mhOL`01?l0003oLg_<og=kc?mcNl`3ogZ2c`03o`000?mgQ=?oMhCC00Oo00000ommRmL0
1?l0003oMhWHogN9f?l00005oh6Bf`;o00001?n6VMl7o`0000?oRZ7S00?o0000oiBZiOnDZ^D00onD
Z^D2o`0000;oV;S^1?l00002oiblk`03o`000?nWbO7oYlWa00;oYlWa0ol000000on[c_;o0000okWD
kP02o`0000;oaNK^00So0000ol[Oj?o:gnSob]oXol[[k?oCmnCo0000omKlg@?o0000AOoonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00Gooo]Z0007oookJP03o`000?oonf[ooo]Z01?o
oo]Z0_l000000ooN`Kco0000omg0^`02omg0^`;o000000Wofknmo`000?oK_[gofkjmo`000?oI_[ko
0000omRn`?l000001?oH_Kl2o`000005omJm`Ol0003oe[c1omJl`Ol000000ooD^l42o`0000?odk_2
00?o0000om:j`_oB^/800_l00002olnja@03o`000?o?^LCockW400;ockW400Go0000olnh`ol0003o
ckW5o`000003olfha@03o`000?o<]lKoc;O600;oc;O61?l00003omg4_`;o000000?og<;0o`000?oK
`Kl00_oK`Kl01?l0003of[noomZo_ol00003ombm^P03o`000?oK_;Wofkbi00;o00000_oI^[X01Ol0
003of;RjomRh^_oH^;[o000000?ofKJe00Co0000omRd]OoH];Gof;Be0ol000002_oD/KKo0000om>_
]_l0003oe[2bo`000?oE[k;o0000omF^/Ol00004om>//@03o`000?o?ZK;o000000?o00000_oAZ:h0
0ol0003ocjJ_olnV[`02olnV[`;o000000?ocZF^o`000?l000000oo<XZ`01Ol0003ob9j]olRN[Ol0
003obj2/00Oo00000_o4VJ/2o`0000GoaIZ[00Go0000ol6FZoo1UZ_o0000ol>GZP04o`0000;o_Y:X
00?o0000okjBZOl000000onnTZT00ol0003o^XjXokZ>Z002okZ>Z0;o00001_njSjT00ol0003o]hbY
okN<Z@05okN<Z@;o00001_ncR:P2o`0000Go[hJX00?o0000ojn5Z?l000001on/PjT01?l0003oZH6Y
ojV1ZOnYPJT8o`0000?oYX2[00?o0000oj9mZonROJ/01OnROJ/00ol0003oWWZZo`000006o`0000Co
W7Z]00Co0000oiQh[OnHN:goV7R]0_l000000onHN:ko0000oiEf[P06oiEf[P?o00000onBMK000ol0
003oSW>`ohic/003ohic/003o`000?n9LK;oS7>b00CoS7>b00?o0000ohIa]?n6LK@01?n9Lk@01?l0
003oQ76fohAa]_l00002ohIc]`03o`000?n1L[WoPG:i00;oPG:i00?oQ7Bio`000?moLk/00omoLk/4
o`0000CoOW>m00?o0000ogef`?mmM/000ommM/02o`0000CoOGS31?l00003ogMjb@;o00001?mjO<T0
0ol0003oN7k=o`000003o`000004og=kc?mjP/ooNX;?o`0000?oMhCC00Co0000ogV6domiQ]?o0000
0_mlR=@7o`000003ogN9f?l0003oPI;K00;oPI;K00Co0000og^AgOmkTMgo00001_n6VMl00ol0003o
RZ7SohZQh`05ohZQh`03o`000?nDZ^Go000000Ko00001onL_>l4o`0000GoZlkb00?o0000okcGkOl0
00000_l000001?o:gnSo0000o`000?o:jn`2o`000005omKlgOl0003o0000o`000?o7k8d0A_oonfX0
0ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00Cooo]Z0007oookJP03o`000?oonf[ooo]Z
01;ooo]Z00Co0000omo0^_oO`;[o00000ooM`;/01?l0003ogKnkomfo^ol00003om^n_@;o000000?o
fKjno`000?l000000ooH_Kl00ol0003oekboomNl_`02o`000003omJl`Ol0003o000000?oe;_100Go
0000omBj`Ol0003odk_2o`000003om:j`P03o`000?oB^L7o000000;o00000oo?^L@01?l0003ockS3
olnh`oo?^<<3o`000003olfhaOl0003oc;O600?oc;O600Co0000olbfa?o<]/Co00000ooMa;l00ol0
003og<>oomc3_`03o`000003om_1_ol0003of[no00;of[no0_l000000ooL_K[o0000om^l^@02om^l
^@05o`000?oJ^[[o0000omVj^_l000000ooH^;X3o`000003omVf]Ol0003of;Be00;of;Be00?o0000
omJc]OoF/kD00_l00002om>_]P04o`000?oE[k;oeJnbomF_/P?o00000_oC[;401Ol0003ocjVbolnY
/_o?ZK;o000000;odJV`0ol00003olnV[`06o`000?o;Xk3o0000oljU[_l0003ocJB^0_l000001?o<
XZco0000olRN[Oo8WZd3o`0000CobIn]00Ko0000olNL[?l0003o0000olBIZol00004olFJZ`03o`00
0?o1UZ_o`IJ[00;o`IJ[0_l00003ol6FZ`_o00000_njSZP00ol0003o^XnYokZ?Z@04okZ?Z@03o`00
0?nhSJSo000000Go]hbY00?o0000okF:Z?l000001OncR:P01?l0003o/XNXok:7Z?l00003ojn6Z005
o`000?n_QJSo[hFXojn5Z?l000000_n/PjT8o`0000CoZ8:Z00?o0000ojEnZOl000001?nVP:/00ol0
003oXWf[oj9mZ`03oj9mZ`Go00001?nOOJd00ol0003oW7Z]oiaj[@04oiaj[@?o00000onHN:h00ol0
003oUGJ^oiEf[P04oiEf[P;o00000_nBMK0Eo`0000;oRG>d0_n4LKH5ohIc]`?oPG:i0on4M;T01?l0
003oOg>kogmc^ol00002oh9e_004o`000?mnM;koOWBnogid_P?o00001?mmM/000ol0003oO7S3ogeh
``05ogeh``?oOG_70_l00002ogMjb@03o`000?mjO<WoNWc900?oNWc900?o0000og^1cOmkPLd00_mk
PLd6o`0000;oMhCC0_l00004ogb8e004o`000?mmS=SoOHcHo`0000;oP8kH6Ol00002oiR]iP05o`00
0?nC[>OoTjcWoi>/iol000001onL_>l00ol0003oZlkboj_>lP02oj_>lP?o00000on_do<01?l0003o
b]oXol[Oj?l00003ol[[k003o`000?oFo=go000000;o000000?ofok6oookJ_oonfX0A_oonfX00ol0
003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00Cooo]Z0007oookJP03o`000?oonf[ooo]Z01;o
oo]Z00?o0000omo0^_oO`;X00_l000000ooM`;_o0000omfo^`02omfo^`;o000000Gofkjmo`000?oJ
_[gof[jmo`000002omVm_@03o`000?oH_Koo000000;oekbo00?o0000omNk_ooG^kl00_l000001?oE
^l3o0000omBk`Ol00003omBj`@05o`000?oB^/;od[[2om:j`_l000000ooB^L401Ol0003odKS2o`00
0?o?^LCo000000CockS300Co0000olng`oo?]l?o00001?o<]lH01?l0003oc;K4olbfa?o<]/@2o`00
0003omg4_ol0003og<>o00;og<>o00Co0000omc1_ooL`Koo00000ooJ_kl01?l0003ofKjoomVn_ol0
0003om^l^@04o`000?oJ^[[of[ZjomZj^P;o00000_oH^;X00ol0003oe[JjomJf^P04o`000003omRd
]Ol0003oe[>e00;oe[>e00Go0000omBa]_l0003odjnfo`000003omF_/P03o`000?oD[K;oe:fb00?o
00000oo?ZK802Ol0003odJV`om6Y/?oAZK3o0000om2X/?l0003ocjJ_o`000003ol^S/003o`000?o=
Y:kocJB^00;ocJB^1?l000000oo8WZgo0000olVO[@03olVO[@03o`000?o7W:coaib/00;oaib/1?l0
0002olFJZ`03o`000?o1UZ_o`IJ[00;o`IJ[00?o0000ol6FZoo1UZ/00oo1UZ/01?l0003o_I:ZokfB
Z_l00002okjCZP04o`000?nmTj_o_I>[okfCZ`ko00000_ngS:T01Ol0003o]HZXokF:Z?neRZSo0000
00?o/hRX00?o0000ok:7Z?l000003?l00002ojb4Z@03o`000?n/Q:[o000000OoZ8:Z0_l00006ojJ0
Z`03o`000?nROJ_o000000;o000000?oXWf[o`000?l000001_nOOJd00ol0003oW7Z]oiaj[@02oiaj
[@?o00001_nHN:h00ol0003oUGJ^o`000007o`0000?oTWNa0ol00004ohmf/`03o`000?n<MKCoS7Fd
00;o00000_n=M[@01?l0003oRGBfohUd]_n9M;H7o`0000;oQW>g0_n1L[T4ohAd^@03o`000?moLk_o
000000?oPWFl00Co0000ogid__mnM;ko00000on1Mkl3o`000004ogef`?l0003o0000ogah``GoOGS3
00?oNg_7ogekaommNlL00ommNlL3o`0000CoNWc900?o0000og^1cOmkPLd01?mkPLd01?l0003oOHKA
ogf6dOmmQ]43o`0000KoO8SD0_l00004oh2>f005o`000?n1Tm_oPI?Koh6Cfol000000on2Tm`00ol0
003oRYcOohZLg`02ohZLg`03o`000?n5Vn7o000000KoRjOX00Co0000oiR]i_nH[NKo00000_nC[>L7
o`0000CoWl3`00Co0000oj_>l_l0003o00001?n_do<01Ol0003o]=Sco`000?o:gnSo000000?ob^_/
00Ooc^gZo`000?l0003ogOGMo`000?oKo/Ko000004Sooo]Z00?o0000oookJ_oonfX06OoonfX00ol0
003ooo]ZoookJP04oookJP001_oonfX00ol0003ooo]ZoookJP0BoookJP;o000000Cogl2jo`000?oN
_kWog[ni0_l00002omfo^`03o`000?oL_[_og;jk00;o00000_oJ_[d01?l0003ofKfmomVm_OoI_Kd2
o`000003omNl_ol0003oek^o00;oek^o00Go0000omJk__l0003oeK_0o`000003omBj`@05o`000?oC
^/7o0000om:j`_l000000ooB^L401?l0003odKS1o`000?oA^<82o`0000?ockS300Go0000olng`oo?
]l?o0000olnf`P02o`000003olbga_l0003oc;K400;oc;K400?o0000om[5aOoJaLD00ol000000ooL
`koo0000omc1_`02omc1_`;o000000?of[noo`000?oI_[l00_oI_[l3o`000003om^l^Ol0003of[Zj
00;of[Zj00Go0000omVi^_l0003of;Rjo`000002omJf^P04o`000?oH];Kof;BfomRd]P;o00000_oF
/kD01?l0003oe;6fomBa]_oD/KH3o`000003omF_/_l0003oe:fb00?oe:fb00Co0000om://_l0003o
cjVb0_l00002om6Y/004o`000?o@Z;3od:R`om2X/0?o00000_o;Xk000ol0003ocJB^olfT[P03o`00
00;obj6^1_l000000oo9Wjgo0000olNL[003olNL[0;o00000_o5Vj`8o`0000Co`IJ[00Oo0000okfB
Z_nmTZ[o_I:Zo`000?nnTj[o000000Ko_I>[00?o0000okZ@Z_njT:X00onjT:X01?l0003o^8fYokR=
ZOl00002okN<Z@co00000_nbRZ/00ol0003o[hJYo`000005ok28ZP05o`000?n/Q:Wo[8BYojb4ZOl0
00000_n/Q:X00ol0003oZ8:ZojR2ZP04ojR2ZP;o00001?nVP:/5o`0000;oXWf[0_l000000onSOjgo
0000oimm[@05oimm[@03o`000?nLNZgo000000;o00000_nLNjd01?l0003oV7R^oiQh[_nHN:h5o`00
00GoUWVa00Co0000oi9g/OnBMk7oTWNa0_l000000onCN;;o0000ohmf/`05ohmf/`;o00001?n=M[@0
0ol0003oRGBfohUd]P02o`000003oh]f]ol0003oQWFi00?oQWFi1_l00003ohAd^@03o`000?n2MKco
PWFl00?oPWFl0_l00004oh5g_`03o`000?mmMl;oOGO200?oP7W20_l00003ogeh``;oNg_700Ko0000
ogekaommNlOoOG_7o`000?miN/L4ogeobPCo00001?mkPLd2o`0000GoOHKA0_l00003oh2;e@;oO8SD
00?o0000oh2>f?n0S]P01?n0S]P00ol0003oPI?Ko`000005oh:Cg004o`000?n:W=ooRYcOo`0000?o
QI_Q00?o0000oh^Wj?n;YnP01?n;YnP00ol0003oV:gVo`000002o`0000?oV:oW00?o0000oio0l?nO
`?001_nO`?000ol0003o[m?cojoCl`02o`0000?o]=Sc0ol00002ol[[k005o`000?o>kN[o0000o`00
0?oMmMd01?l00019oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01?oonfX000Ko
oo]Z00?o0000oookJ_oonfX04_oonfX3o`0000?og[ni00Go0000omjn^Ol0003ogKnko`000002ombn
^`08o`000?oL_K[o0000o`000?oJ_Kco0000omVm_Ol00002omRl_@;o00000_oG^kl01?l0003oe[^n
omJk__oF^kh3o`000003omBj`Ol0003odk[100;odk[10ol000000ooB^L7o0000om6h`@02om6h`@06
o`000?o@]l;od;O2o`000?o?^<?o00000_o?]l<01?l0003ockK2olnf`_o?]/84o`000003olbfa?l0
003of/G500;of/G50_l000000ooL`koo0000omc1_`02omc1_`04o`000?oK`;kofl2no`0000?ofKjo
00Go0000omNl_ol0003ofkbko`000003omZj^P04o`000?oI^K[ofKVjomVi^P;o000000Koe[Jjo`00
0?oD];[o0000omRd]_l00002omJc]P03o`000?oF/kGo000000?oe;6f00?o0000om6_]_oA[kH00_l0
0003omB]/P04o`000?oB[;;odZbbom://PCo000000?odJV`o`000?o@Z;000_o@Z;000ol0003ocZJ`
oljV/005o`000003olfT[_l0003obj6^00?obj6^00?o0000olJN[ol000000_o9Wjh3o`0000;oaib/
00?o0000olBJ[?l000000oo5Vj`00ol0003oa9V[olBIZ`02olBIZ`Wo00000_nmTZX2o`0000Go_I>[
0_l00004okZ@ZP05o`000?nhSJWo^8fYokR=ZOl000000_ngS:T00ol0003o]8ZYokB:Z@03okB:Z@03
o`000?ncRJWo000000Go/XZ[0_l00006ok28ZP04o`000?n/Q:Wo[8BYo`0000Co[8BZ00?o0000ojR2
Z_nXPZX02Ol00003ojF1[004o`000?nROJ_oXWf[o`0000CoXgn]00?o0000oimm[OnOOJd01Ol00005
oiak[@Ko000000?oVG^`o`000?nFNK401_nFNK43o`0000?oTgRb00?o0000ohmf/on?M[<00on?M[<2
o`0000KoSGJd0_l00004oh]f]`03o`000?n6MKWoQWFi00;o000000?oR7Nio`000?n4MK/00_n4MK/7
o`0000;oPWFl00?o0000oh5g_on1Mkl01?n1Mkl2o`0000CoP7W200?o0000ogaiaOmmN<<01?l00002
ogeka`04o`000?miN/OoNG[7ogUja`?oOGo:00?o0000og^1c_mkPLh02?l00003ogf6d@03o`000?mh
Q=?o000000GoP8_E0_l00003oh>Af@?oP8kH6?l00006oiR_i`03o`000?nO`?3oWl3`00?o00001?nS
aO400ol0003o]=ScokCHl`02okCHl`;o00000_o0ho02o`0000;oc^gZ00Ko0000omgegOl0003o0000
om_na_l0001;oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX01?oonfX000Kooo]Z
00?o0000oookJ_oonfX04OoonfX00ol0003oh[neon:o]@02o`000003omjo^Ol0003og[ji00;og[ji
0_l000000ooL_[_o0000ombm^P02ombm^P;o000000?of[flo`000?oH_;d00_oH_;d01Ol0003of;^m
o`000?oG^koo000000?oe[^n00Co0000omJj__l0003o00000ooC^/401?l0003od[W1om:i`OoB^L42
o`0000?odKS100Co0000om2g`_o@]l;od;O20_l000000oo?]l?o0000olnf`P03olnf`P05o`000?o=
]/?ocKK3olff`ol000000ooJaLD02?l0003ofL?5omW3aOl0003ofl6oo`000?oL`Koo00000ooK`;h2
o`000003omVn_ol0003oekbo00;oekbo00Go0000omZk^_l0003of[Zjo`000004omVi^P04o`000?oG
^;[o0000o`0000;oe;Bj00?o0000omJc]_oF/kH00_oF/kH2o`0000;oe;6f00Wo0000om6_]_oA[kKo
dJnfo`000?oC[[?o0000omB]/_l000001?oB[;800ol0003ocZRcoljX/`04o`000004om2X/?l0003o
cZJ`oljV/0?o000000?obJ>ao`000?o<Y:l00_l00003ol^Q[P04o`000?o6WZooaYj_o`0000;obIn^
00?o0000olRO[_o8Wjh01?l000001?o4VZco0000olFK[?l00004olBIZ`03o`000?o1Ujco000000?o
`IN/00Co0000ol2FZoo0UZ_o`9J[1_l00002okfCZ`04o`000?nkT:[o^i2Zo`0000;o^Y2Z00?o0000
okR=ZOnhSJT00onhSJT2o`0000Ko]8ZY0_l00006ok::Z`03o`000?n`R:[o/8RZ00Ko/8RZ0_l00002
ojb4ZPKo000000?oZ8:[o`000?nYQ:`00_nYQ:`00ol0003oYH6/ojF1[004ojF1[0?o00000onSOjd5
o`0000?oWgf]00Co0000oiak[OnLNjgoW7^]0ol000001?nLO:oo0000o`000?l00003oiUk/003o`00
0?nFNK7oUWVa00CoUWVa0_l00006oi=h/P03o`000?n?M[?oSgJc00;o000000?oT7Nco`000?n=M[@0
1?n=M[@2o`0000GoRgJg00?o0000ohIe^Ol000000on8MkT00ol0003oQ7FkohAe^`02o`0000;oQWNk
00Co0000oh9f_On2M[goPWJm1?l00004oh5g_`;o00001On0NL82o`0000CoOg_51_l000001?miN/Oo
OGo:ogeob_l00003og^1cP04o`000?mkPLkoNh7>og^1cP?oOXC>1_l000000omhQ=?o0000oh2;e@02
oh2;e@04o`000?mjR]OoNX[Go`0000GoPi7I00?o0000ohNHgOn7V=d01?n7V=d00ol0003oRIgPo`00
0005ohZNh@03o`000?nCYnCoTjOT00GoTjOT00?o0000oiR_ionH[nL00_nH[nL5o`0000?oXlGa0ol0
00000onWb_;o0000okCHl`02o`000003okSFkol0003o`>?`00;o00000_o5gN/2o`000003omgegOl0
003ofOcJ00;o0000COoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z00Cooo]Z0006
oookJP03o`000?oonf[ooo]Z013ooo]Z00Co0000on:o]OoR_kGoh[ne1?l00003omjn^@03o`000?oM
_KWo000000?og;fj00?o0000om^l^_oK_;X00ol000000ooH_;go0000omRk_@02omRk_@05o`000?oF
^kkoe[^nomJk__l000000ooF^[h2o`000003om>j`Ol0003od[W100?od[W100Wo0000om:h`?l0003o
dKS1o`000?oA^<7o0000om2g`_l000000_o@]l82o`0000?ockK200Co0000oljf`_l0003ocKK30ol0
00000ooJaLGo0000omW3a@02omW3a@;o000000?ofl6oo`000?oK`;h00_oK`;h00ol0003of[jnomZn
_P02o`0000?oekbo0_l000000ooJ^k[o0000o`000003omVi^P08o`000?oG^;[oekRjo`000?oF][[o
0000omBd^_l00004omJc]P05o`000?oF/[Ko0000omBa]_l000000ooA[kH00ol0003odjjcom>^/`03
o`0000;odZbb00Go0000oljX/oo>Z;?ocZRco`000003om2X/@Co000000SocZJ`o`000?o9Xk7obJ>a
o`000?o<Y:oo0000ol^S/0;o000000?obj6^o`000?o6WZl00_o6WZl2o`0000Cob9n^00?o0000ol>J
[_o3VZh01Ol00002olBIZ`04o`000?o1Ujco`IN/o`0000;o`IN/00?o0000ol2FZoo0UZ/00oo0UZ/2
o`0000?o_I>/4ol00003okB:Z@04o`000?nbRZ_o/XZ[ok::Za7o00000on/QZ`01?l0003oZ8:[ojR2
Zol00004ojV4[003o`000?nUPJcoYH6/00CoYH6/00?o0000oj=o[OnSOjd00ol00002oj>0[P03o`00
0?nOOJgoWgf]00CoWgf]0ol00002oial[`?o00001_nINk000ol0003oUWVaoiIi/@03o`000003oiIj
/Ol0003oTgRb00GoTgRb00?o0000ohmf/ol000001?n@Mk<00ol0003oSGJdohef]002o`000003ohih
]_l0003oRgJg00CoRgJg0_l00005ohQg^@;o00001?n6Mk/01?l0003oPWJmoh9f_Ol00003ohEh_P03
o`000?n0N<3oP7S000Co00001?n0NL800ol0003oOg_5o`000005ogmka@03o`000?moOlSoOgo800;o
Ogo81Ol00003og^1cP03o`000?mkPLko000000?oOXC>00Co0000ogf6d_mmQ];o00000_n0R=89o`00
00CoPi7I00?o0000ogf@fol000001_n7V=d00ol0003oRYkQohZNh@05ohZNh@03o`000?nCYnCoTjOT
00;o000000?oTjOTo`000?l000001?l00003oiZikP03o`000?nSaO7o000000;o00001OnWb_800ol0
003o^=K_okSFk`03o`0000?oaMg[0_o3l?02o`000004omWlf_l0003o0000o`0004gooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP04oookJP001_oonfX00ol0003ooo]ZoookJP0@oook
JP;o000000Woh[neo`000?oQ_[GohKjeo`000?oO_KKo0000omjn^Ol000000_oM_KT2o`000003ombm
^_l0003ofkbj00;ofkbj00Co0000omZk^_l0003o00000ooH^kd01Ol0003oekZno`000?oF^kko0000
00Coe[Zn0ol00004om:i`@05o`000?oB^<3od[S0om:h`?l000000ooA^<402Ol0003od;O2om2g`_o@
]l;o0000olnf`_l0003ockK2o`000003oljf`P;o00000_oJaL@01Ol0003ofL?5omW3aOoI`lGo0000
00;of<;400Go0000om_0_ol0003ofl2no`000003omZn_P05o`000?oI_Kko0000omNl_ol000000_oF
^kh01_l0003of;VjomRi^_l0003ofKVjo`0000;oekRj00Co0000omJf^_oF][[oe[Jj0ol00002omJc
]P04o`000?oF/[Koe[:fomJb]P?o000000KodJnfo`000?o@[KOo0000om>^/ol00002om:]]0?o0000
0oo>Z;<00oo<YkCo0000o`000002o`000005oljX/_l0003o0000oljV/?l000000oo9Xk400ol0003o
bj>`ol^S/002ol^S/0?o00000_o6WZl00ol0003ob9n^olRO[P02olRO[P03o`000?o3VZko`iZ^00;o
`iZ^00Co0000olBK[_o4Vjkoa9^^1Ol000001?o1Ujco0000ol6G[?l00004ol2FZ`03o`000?nnU:co
000000Co_I>/00Oo0000okV@ZoniT:_o^I2[o`000?njT:_o000000Ko^I2/00?o0000okJ>[?nfSZ`0
0_nfSZ`7o`0000Co/X^/0_l00006ojn8[0;o00001on/QZ`2o`0000GoZHB/00?o0000ojF1[?nUPJ`0
1ol00005oj>0[P03o`000?nOOJgoWgf]00?oWgf]0_l000001?nLO:oo0000o`000?l00002oiem/003
o`000?nINk3oVG^`00CoVG^`00?o0000oiIi/Ol000001?nFN[400ol0003oTgRboi=h/P02oi=h/P;o
000000CoSgJcoi1g/on@Mk?oT7Nc1?l000000on=M[Co0000ohih]P02ohih]P03o`000?n;M[OoRgJg
00;oRgJg00?o0000oh]h^Ol000001?n8MkT2o`0000KoQWNk0_l00004ohEh_P04o`000?n0N<3oP7S0
o`0000?oPg[10ol000001On0NL;o0000o`000?moNlGo000000CoOg_500?o0000ogmob?moOlP01?mo
OlP3oh23c0;o00000_mkPLh00ol0003oOXC>ogj4cP03ogj4cP;o00001?n0R=801?l0003oOhcFogn<
e_l00003oh2=eQWo00000onGZn@00ol0003oTZ_Wo`000007oiZikP03o`000?nWb_;oYl[b00;oYl[b
0ol00002ojc@l`03o`000?nhe^oo000000?oaMg[1?o3l?001Ol0003oe?STomChi?l0003odoo704oo
oo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP04oookJP001_oonfX00ol0003ooo]Z
oookJP0?oookJP04o`000?oS_[;ohkjbo`0000?ohKje0_l000001OoO_KKo0000omfm^OoM_KWo0000
00;ogKbh0_l00002om^l^P04o`000?oJ^k[of[^jomZk^P;o000000?of;^mo`000?oG^[h00_oG^[h2
o`0000?oe[Zn00?o0000omFi_OoE^Kd00ol000000ooB^L7o0000om:h`003om:h`0;o000000KodKS1
o`000?oA]l7o0000om2g`_l00004olnf`P;o000000?oc[K2o`000?l000000ooJaL@2o`000003omW3
aOl0003of<;400;of<;40_l000000ooK`;oo0000o`000002omZn_P04o`000?oI_KkofKfnomVm_P;o
00000_oF^kh01?l0003of;VjomRi^_oH^KX3o`000003omNh^_l0003oe[Jj00;oe[Jj00Go0000omBd
^_l0003oe[>fo`000003omJb]P04o`000?oD/KKoe;6fomBa]P;o00000_o@[KL00ol0003odZfdom:]
]002om:]]003o`000?oA[;?o000000Co000000?od:Rao`000?o>Z;800oo>Z;83o`0000;obJ>a00?o
0000ol^S/?o;Xk000_o;Xk000ol0003obJ6_olVQ[`06o`000003olRO[_l0003o`iZ^00?o`iZ^00?o
0000olBK[_o4Vjh00_o4Vjh01?l0003o`9N]ol2G[Oo0Ujd6o`0000;o`9J[00Co0000okjD[?nnU:co
00000_nmTj`00ol0003o^I2[okV@Z`03okV@Z`03o`000?niT:co^I2/00Co^I2/0_l00006okJ>[0;o
00001_nbRj`00ol0003o/XZ[o`000005ojn8[003o`000?n_R:co000000Ko[8J/0_l00003ojV4[0So
00000onVPjh00ol0003oXh2^oj>0[P05oj>0[P04o`000?nOOJgoWgf]oimm[@Co00001OnMOK000ol0
003oVG^`oiUk/003oiUk/0;o00001onFN[4:o`0000;oT7Ve5Ol00006ohIg^`03o`000?n5N;koQGRn
00CoQGRn0_l00004oh=j`@03o`000?moN/?oOg[300?oPgc40ol00002ogmka@03o`000?mnO/So0000
00CoOgo800?o0000ogj1c?n0Pl`01?n0Pl`4o`0000CoOXC>00?o0000oh28d_n0R=800on0R=82o`00
00GoP8gF1?n7U=T01?l0003oPY;Joh:Bf_l00005oh^Kg@;o00001_n;YNH00ol0003oUj_ToiN[i002
oiN[i006o`000?nBZnOoTZ_Woi:[iol0003oV[W^0ol00003oifmk`04o`000?nWb_;o0000o`0000Ko
[=3c0_l00002olGMj`?o`o3`0_l00002omChi003o`000?oColOo0000053ooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP04oookJP001_oonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oS_[;ohkjb00;o000000WohKjeo`000?oP_KCoh;fdo`000?oO_;Ko0000omfm^Ol000000_oM_;P0
1Ol0003og;^ho`000?oK_;[o000000?of[^j0ol00004omNj_P05o`000?oG^Kco0000omJj__l00000
0_oE^Kd01?l0003oeKRmo`000?oD^;h2o`0000?od[S000?o0000om:g_ooB]kl00ol000000ooA]l7o
0000olnf`P03olnf`P03o`000?o?]L7ockG100;o00000ooJaL@00ol0003of/C4om[4a003o`000005
omS2a?l0003oel34omO0a?l000000_oJ_[h00ol0003of[jno`000003omVm_P08o`000?oG_;ko0000
o`000?oE^Kko0000omRi^_l00003omNh^P;o00000_oF][X01?l0003oe;BjomBd^_oD];X3o`000003
omJb]_l0003oe;6f00?oe;6f00Go0000om:_]ol0003od:fgo`000003om:]]0So000000?od:Rao`00
0?o>Z;800oo>Z;800ol0003oc:JaolbV/@03o`0000?obj>`00?o0000olVQ[oo9XJl00_o9XJl00ol0
003oaIj`o`000002olRO[`?o00000_o3VZh2o`0000?oa9^^00?o0000ol2G[Oo0Ujd00oo0Ujd00ol0
003o`9R^ol2H[P02ol2H[P_o00000oniT:/00ol0003o^I2/okV@[003okV@[003o`000?nhSjco0000
00Go]Xj/00?o0000okF<Zol000001OnbRj`01Ol0003o/XZ[ok::ZonbRZ_o000000?o[hR/00Co0000
ojn8[?n_R:co00000_n/QZ`9o`0000?oZ8B^00?o0000ojF1[Ol000001OnVPjh00ol0003oXh2^oj>0
[P03oj>0[POo000000?oX82`o`000?nMOK001_nMOK000ol0003oVG^`o`000002o`000003oiYl/Ol0
003oUWZa00?oUWZa1?l00005oi=j]004o`000?n@NKGoT7Veoi1i]@;o000000?oTWZfo`000?n=N;L0
1?n=N;L3o`0000CoS7Vi00Co0000ohQh^on8N;_o00000on:NK/7o`0000GoQGRn0_l00006oh=j`@;o
00001?n3O<@01?l0003oOgc6ogmla_moNlD4o`0000;oOgo800Co0000ogj1c?mnPLco00001?n0Pl`2
o`0000?oPHO@1_l00004oh28dP03o`000?n0SMKoP8gF00CoP8gF0_n7U=T00ol0003oPY;Joh:BfP02
oh:BfP05o`000?n;VmgoRi_Moh^KgOl000000_n6V^000ol0003oRjGVoh^UiP04oh^UiP03o`000?nG
ZnCoUj_T00Oo00001onM_Nl00ol0003o[=3cojc@l`02ojc@l`?o00000_n`e_@01?l0003o`o3`ol?`
l?o3l?03o`0000;oe?ST00Cog?[Ko`000?l0003o0000D?oonfX00ol0003ooo]ZoookJP0EoookJP03
o`000?oonf[ooo]Z00?ooo]Z0006oookJP03o`000?oonf[ooo]Z00kooo]Z0_l000001?oS_[;o0000
on:m/_oR_K82o`0000;oh;fd0_l000001OoO_;Ko0000omfl^?oM_;So000000?og;^h00Go0000omZk
^_oJ^k[of[^jo`000002omZj^@;o00000_oG^[h01?l0003oekVlomNi_?oG^K`2o`000003omFi_Ol0
003oeKRm00;oeKRm00Ko0000om>g__oC]kko0000om:h`?l00002om:g_`04o`000?oA][oodKJoom6f
_`;o00000oo?]/802Ol0003ockG1olne`Oo?]L7o0000om[5a?l0003of/G4o`000003om[4a004o`00
0?oI`/CofL;4o`0000?oel3400Go0000omZn__oJ_[kof[jno`000003omVm_P04o`000?oG_;koekbn
omNl_P;o000000?oeKVno`000?oG^;X00ooG^;X01Ol0003oekNjo`000?oF][[o000000?oe;Bj00?o
0000omFc]ooE/kL00_l00003omBa]P04o`000?oB[kOodZngom:_]`Ko00000ooA[;<00ol0003ocZZd
oljZ]004o`0000;ocZRb00?o0000olbV/Oo<Y[400_o<Y[47o`0000;obJ6_00Co0000olFN/?o5W[3o
00000_o8Wjl00ol0003oaYn`olJO/005o`0000;oa9^^00?o0000ol2G[Oo0Ujd00_o0Ujd00ol0003o
`9R^o`000004ol2H[P07o`000?nlU:go_9B]okbD[Ol0003o_IB]o`000003okbD[P_o000000?o^8n/
o`000?nfSZ`00_nfSZ`01Ol0003o]Hb[okF<ZoneS:_o000000?o/X^/00?o0000ok::Zol000003?l0
0002ojb6[@04o`000?n]R:ko[HR^o`0000OoZ8B^00?o0000ojJ3[_nVPjh01OnVPjh00ol0003oXh2^
o`000002o`000004oj>0[_l0003o0000o`0000CoX82`00?o0000oiem/?nMOK000onMOK04o`0000?o
VWba2?l000000onGO;?o0000oi=j]005oi=j]0?o00000onBN[H01?l0003oSGRgoheh]on=N;L2o`00
0003ohii]ol0003oS7Vi00GoS7Vi0_l00004ohYi^`04o`000?n6NKgoQWVmo`0000?oR7Zm1ol00005
oh=j`@;o00001_n3O<@2o`0000CoPWo71ol00003oh23c004o`000?mlPLgoO87=o`0000CoPHO@0_l0
0003oh><db;o000000?oUjgVo`000?nG[NH00onG[NH00ol0003oWKg_oifmk`03o`0000?oXL;`00Co
0000ojc@lol0003o00001?n`e_@01_l0003o_>3ao`000?o3l?3o0000ol[^k@;o000000Goe?STomcj
fol0003ogOk0o`00001BoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX00ooonfX0
00Gooo]Z00?o0000oookJ_oonfX03ooonfX01?l0003oiKf^o`000?l00002on:m/P04o`000?oR_;7o
0000o`0000;ogkbd00Go0000omjk]Ol0003ogKbho`000003ombk^0;o000000?of[^jo`000?oJ^[T0
0_oJ^[T01Ol0003ofKVio`000?oG^[ko000000;oekVl00?o0000omJh_?oF^;`00_l00003omFh_@04
o`000?oC]kkodkNnom>g_P;o000000?od[Noo`000?oA][l00ooA][l01Ol0003odKFno`000?o?]/;o
000000?ockG100Go0000omK5bOl0003of/G4o`000003om[4a00@o`000?oI`/CofL;4o`000?oH`L?o
0000omO0a?l0003oe[o4o`000?oJ_[ko0000omVm__l0003ofKfno`0000Coekbn00Co0000omJk__l0
003o00000ooG^;X01?l0003oekNjomNg^_oG]kX2o`0000;oe;Bj00Wo0000om6b^ol0003oeK>go`00
0?oD/KOo0000omBa]_l000001?oB[kL5o`0000?odJbc00?o0000oljZ]?o>Z[@00_o>Z[@2o`000004
oljX/_l0003ocZRbo`0000?oc:Ja00Ko0000olRS/_o8Xk;o0000ol^T/Ol00002olZS/@?o00000oo5
W[02o`0000CoaYn`00?o0000ol:K[oo2Vjl01_l00002ol2G[@03o`000?o0V:ko000000?o`9R^00?o
0000okbD[OnlU:d00onlU:d00ol0003o_9B^okbD[P04okbD[P;o00001?niTJd00ol0003o]Xj]okJ>
[@0?o`0000?o/Xb^00?o0000ojn8[Ol000001?n_RJh01Ol0003o[8J]ojb6[On/QZgo000000?o[HR^
00?o0000ojR4[_nXQ:h01?nXQ:h2o`0000?oYX>^1_l000001_nSP:ko0000o`000?l0003oXh:`o`00
00KoX82`00?o0000oiem/?l000000_l00002oien/003o`000?nJO;7o000000;o00000_nJOK83o`00
00CoUgbc00?o0000oi=j]?nCN[@00onCN[@2o`0000KoTWZf0_n=N;L01Ol0003oSWVgohii]on>NKOo
000000GoS7Vi0_l00006ohYi^`;o00001?n8N[d01?l0003oQ7ZoohAj_ol00003ohMk_`Oo00001On3
O<@2o`0000GoPWo700?o0000oh:2b_n2P/X00on2P/X8o`0000?oPHO@00Co0000ogf5dOmmQM7o0000
1?n3S=<2o`0000KoQY7G00?o0000ohVGfon9Um/01On9Um/01?l0003oRicOoh^Lgol00003oh^Mg`03
o`000?nCY^;oTjKR00CoTjKR00?o0000oiN]i_l000000onG[NH5o`0000OoXL;`00Co0000ok3Fm?n`
e_Co/=Kd0_l000000oneeO7o0000okcPl@02o`000005ol[^kOl0003o0000omChi?oLn]/00ol0001D
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX00ooonfX000Gooo]Z00?o0000oook
J_oonfX03_oonfX01Ol0003oiKf^onFm[_l0003oi;b^00;o00000ooR_;401?l0003ogkbdomnl]?l0
0002omjk]@;o00000_oL^kP00ol0003ofkZhom^j^002o`0000;of[Zi00?o0000omVi^OoI^KT00ol0
00000ooG^Kco0000omJh_002omJh_009o`000?oF]k_o0000omFh_Ol0003oe;Nmo`000?oC]kko0000
00;odkJm0_l00003om6f_`04o`000?oA]KkodKFnom6e_P?o000000?ockG1o`000?oFaLT00_oFaLT0
1Ol0003of/C4o`000?oJa<Co000000;ofL;400Go0000omS1`ooH`L?of<73o`000003omJoa0;o0000
0_oI_Kh2o`0000?oekbn00So0000omJk__oF^kko0000omFi__l0003oekRjo`0000CoekNj00Go0000
omFf^_l0003oe;Bjo`000002om6b^`04o`000?oD/KOoe;6gomBa]`Ko00000oo>[KL01_l0003od:bd
o`000?l0003odJbco`0000?ocZZd00?o0000ol^W]Ol000000_o>Z;<3o`000003olbV/Ol0003ob:>b
00?ob:>b00?o0000olZS/Oo:Xk400_o:Xk401_l0003ob:6ao`000?l0003oaIj`o`0000CoaYn`00?o
0000ol:K[oo2Vjl00_o2Vjl00ol0003o`i^_ol>K[`02ol>K[`Ko000000?o`9R^o`000?nlU:d01?nl
U:d2o`0000Go_9B^00?o0000okZB[Ol000000oniTJd00ol0003o]Xj]okJ>[@02okJ>[@03o`000?nf
SZgo000000Go]Hj^00?o0000ok:;[Ol000001_nbS:h2o`0000Go[hV^00Co0000ojb6[On/QZgo0000
1On]R:h00ol0003oZ8B^ojR4[P02ojR4[PKo00001?nVPjl3o`0000GoXh:`00?o0000oj20/?nPP;00
1Ol00004oien/0?o00001?nJOK82o`0000OoUgbc00?o0000oi=j]?nCN[@00_l000000onDNkCo0000
oi9j]P04oi9j]P03o`000?n=N;OoSWVg00GoSWVg00?o0000ohai^On<NKT00_l000000on=Nk_o0000
ohYi^`04ohYi^`;o00001_n8N[d2o`0000CoQg^o00Co0000oh=k`_n3Nl;o00000_n6OL88o`0000Go
PWo700?o0000oh:2b_n2P/X01?n2P/X00ol0003oPhK>oh>6cP03oh>6cPWo00000_n3S=<01?l0003o
OX[Eogj:eOl00004ohJAe`03o`000?n4UMco000000OoRIOK0_l00005oh^Mg`04o`000?nCY^;oTjKR
oi>VhP;o000000?oTjKRo`000?l000000ol00003oiVgk@03o`000?nQ`_3oXL;`00Co00000_nUb?80
1?l0003o/=Kdo`000?l00002okGEl@?o000000Ko`NSao`000?l0003oc_7Zo`000?oLn]/4o`0005Go
oo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP03oookJP001OoonfX00ol0003ooo]Z
oookJP0=oookJP;o00000_oU_Jh01?l0003oi;b^onBl[_l00003on:l/@?o000000Sogk^do`000?oN
^kGo0000omfj]Ol0003og;^ho`0000;ofkZh00Go0000om^i]ol0003of[Zio`000002omVi^@;o0000
00?of;Rjo`000?l000000_oF^;`01?l0003oe[NkomJg^ooF]k/2o`0000;oe;Nm00Wo0000om>f_OoC
][godkJmo`000?oB][ko0000om6f_ol000001?oA]Kh01?l0003od;Boom2d_ol00003omK5b@04o`00
0?oFa<Wo0000om[4a0;o000000?ofL;4o`000?oH`L<00ooH`L<2o`00000;omJoa?l0003oeKk3omFn
`ol0003ofKfno`000?oH_;ko0000omNl__l000000_oF^kh01Ol0003oeKVnomFi__oE^Kko000000Co
ekNj00Co0000omFf^_oE][[oeKJj0ol000000ooA/[_o0000omBa]`02omBa]`Ko00000oo>[KL01?l0
003od:bdom2/]?o@[;@3o`000003oljZ]?l0003objNe00;objNe0_l00003olfW/`?o00000_o8Xk82
o`0000?obZ>a00?o0000olRQ/Oo8XK400_o8XK44o`0000;oaYn`00?o0000ol:K[oo2Vjl00_o2Vjl0
0ol0003o`i^_ol>K[`03ol>K[`04o`000?noUjoo_iN_oknG[`[o00001?nlU:h01ol0003o^Y:]okZB
[OnjTZgo0000okVA[Ol000001_nfSZd00ol0003o]Hj^okF>[P05okF>[P03o`000?nbS:ko/Xb^00Go
/Xb^00?o0000ojn9[_n_RJh01On_RJh2o`0000;o[HR^2_l000000onZQjoo0000ojJ3[`06ojJ3[`03
o`000?nSP[3oXh:`00?oXh:`1Ol00003oj20/003o`000?nMO[3oWGj`00?o000000CoWGnbo`000?nJ
OK;oVWfb0ol000000onJO[?o0000oiMl/`06oiMl/`03oi=j]?l0003o000000CoU7^d00Oo0000oi9j
]_nBN[KoTWZfo`000?nBNkOo000000KoSWVg00?o0000ohai^On<NKT01?n=Nk/01ol0003oRWVkohYi
^on:NK_o0000oh]k_Ol000001On8N[d2o`0000KoQg^o0_l00003ohIm`P05o`000?n2OLGoPWg5oh9m
aOl000000_n5OlD8o`0000GoPX;:00?o0000oh>6c_n3Q/h01?n3Q/h00ol0003oQ8[AohB:d@04ohB:
d@03o`000?n3SMGo000001go00000onGZN<2o`0000OoVKO]0_l00007ojG8lP03o`000?neeO7o]MGa
00;o]MGa00Co0000ol7XlOo1j?7o00000oo7h^/5o`0005Kooo]Z00?o0000oookJ_oonfX04_oonfX0
0ol0003ooo]ZoookJP03oookJP001OoonfX00ol0003ooo]ZoookJP0=oookJP04o`000?oV_:_o0000
o`0000?oi;b^0_l000001?oR_;7o0000on6k/OoQ^k42o`000003omnk]?l0003ogKZe00;ogKZe0_l0
00000ooK^[So0000om^i]`02om^i]`;o000000GofKVio`000?oI^;WofKRio`000002omNg^P03o`00
0?oF^;co000000?oe[Nk00Co0000omFg^ol0003oe;Nm0_l000000ooC][go0000om:f_P02om:f_P;o
00000ooA]Kh02?l0003od;Bno`000?l0003oelG9o`000?oFaLWo00000ooFa<T00ol0003ofL;4omW2
a002o`0000?of<7300?o0000omO0`ooG`<<00_l00003omFn``04o`000?oH_;kof;bnomRl_P;o0000
00?oe[^no`000?oE^Kh00ooE^Kh3o`000003omNg^_l0003oeKJj00;oeKJj00Co0000om>d^_oC];[o
dkBj1Ol00004om>a]`07o`000?oA[kOo0000olj]]ol0003ocJbho`000002om2/]003o`000?o?[;Go
cjbe00?o00000_o;YkD00ol0003ocJNcolfW/`02olfW/`03o`000?o;Y[?objJc00Co00000oo:Xk40
0ol0003ob:6aolRQ/@02olRQ/@;o00000_o6Wk04o`0000;o`Y^_00?o0000ol:K/?l000000oo3Vjl0
0ol0003o_iN_oknG[`02oknG[`03o`000?noV:oo_iR_00Co_iR_00?o0000ok^D[ol000003_l00003
okJ>[@03o`000?neSZko]Hj^00Co]Hj^0_l00006ok:<[Pgo00001?n/R:l00ol0003oZHF^o`000004
ojZ7[`03o`000?nVPjooYX>_00CoYX>_0_l00002oj>2/0?o00000_nSP[400ol0003oX82`oj20/003
oj20/0?o00000onMOk84o`0000GoVWjc00?o0000oiMl/onGO;<00onGO;<2o`0000?oU7^d4Ol00000
0on<NKWo0000o`000006o`000003ohYi^ol0003o000000?o00000_n8N[d00ol0003oR7boo`000005
ohMk_`;o00001On6OL800ol0003oPWg5o`000003ohEoa@05o`000?n2P<SoPX38oh:0b?l000000_n5
P/P8o`0000GoPhK>00?o0000ohB:dOn4R]401On4R]42o`0000CoQXoE00Go0000ohFBf?n5T]SoQI;H
o`000002ohJCf@03o`000?n=VmcoSI_L00CoSI_L00?o0000ohbTiOn<Y>D01?n<Y>D00ol0003oUjWS
oiNYh`03oiNYh`05o`000?nBZ^OoTZ[Wo`000?nI]nd00ol00003oibkkP03o`000?nUb?;oYLSb00?o
00001?nYc_<2o`000004ok[Hkol0003o0000o`0000?oan;[00Go0000oloii_o?nNKo0000omOn_`1H
oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX00ooonfX000Gooo]Z00?o0000oook
J_oonfX03?oonfX01Ol0003oi[b[onJlZooV_:_o000000;oi;b^00Co0000on>k[_oS^jko00000ooQ
^k400ol0003oh;Zao`000002o`000004omfj]Ol0003ogKZeomfj]@;o00000ooK^KL01?l0003of[Rg
o`000?l00002omVh^@04o`000?oG]k[oekNjomNg^P;o00000_oF]k/01?l0003oeKNkomFg^ooE]k/4
o`0000Cod[Jn00Go0000om:d_Ol0003odKFno`000002om2d_P04o`000?oGaLWoelG9omO5b@;o0000
0ooFa<T2o`000006omW2a?l0003of<73o`000?oH`L?o00000ooG`<<01?l0003oe[o3o`000?oE_/<2
o`0000?of;bn00Co0000omJj__l0003o00000ooE^Kh00ol0003od[Noom:g_`04o`000003omFf^_l0
003odkBj00;odkBj1Ol00004om>a]`04o`000?oA[kOodJngom6_]`Co000000?od:bdo`000?o?[;D0
0_o?[;D00ol0003ocZZeoljZ]@03o`0000?ocJNc00?o0000ol^V/oo;Y[<00_o;Y[<00ol0003oaj>d
o`000005o`0000;ob:6a00Co0000olBN/_o4W[;o00000_o6Wk000ol0003oaInaolFO/@06o`000003
ol>K[ol0003o_iN_00?o_iN_0_l00005oknH[`04o`000?nkU:oo^iB_o`0000;o_9F^00?o0000ok^E
[onkUJl01?nkUJl00ol0003o^9:_okRB[`02okRB[a?o000000?o/Hb^o`000?n_RZl01?n_RZl2o`00
00So[8R_00?o0000ojZ7[onZQjl01?nZQjl00ol0003oYX>_ojJ3[`02ojJ3[`Go00001OnSP[400ol0
003oX82`oj20/003o`000003oj62/_l0003oWGnb00?o00000_nMP;800ol0003oVWjcoiYn/`04oiYn
/`03o`000?nGO;?oUgbc00So00000_nEOKL3o`0000GoTWbh00?o0000ohmk^On?NkT00_l000000onA
O;Wo0000ohek^`05ohek^`;o00001On<O;d01?l0003oR7boohQl_on8N[d:o`0000GoQWg20_l00005
ohEoa@03o`000?n2P<So000000?oQH;800Go0000oh:3c?n2PlcoPX?<o`000002ohF5c0_o00000on4
R]400ol0003oQXoEohJ?e@04ohJ?e@03o`000?n5T]So000000CoQY?I00?o0000ohfKg?n=Vm`00_n=
Vm`00ol0003oQi[No`000006ohbTi@03o`000?nGZN?oUjWS00Oo00001onL^nh2o`0000?oZLkc0ol0
00000on^e?Co0000ok[Hk`02o`0000;oan;[00?o0000ol?ekol000000_o?nNH00ol0003oeojoo`00
001IoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX00ooonfX000Gooo]Z00?o0000
oookJ_oonfX03?oonfX01?l0003oi[b[onJlZooV_:/2o`000004onBl[_l0003ohk^^on>k[P;o0000
00KohK^ao`000?oP^[7oh;Zao`000?oP^K42o`0000?ogKZe00Go0000om^i]_l0003ofkVgo`000002
omZh]`08o`000?oJ^;Oo0000o`000?oH^;Wo0000omNg^_l00002omNg^@03o`000?oF]k_o000000;o
eKNk00Go0000omFf^ooE][_oeKJko`000003om:f_P04o`000?oB];god[Bmom:d_@Co00001?oGaLT0
1Ol0003oe/C8o`000?oFa<Wo000000;oeL?90_l00002omS1``05o`000?oG`<?oel33omO0`ol00000
0ooF_l<2o`000004omBl`ol0003of;bno`0000;oe[Zn00Go0000omJj__l0003oeKVno`000003om:g
_`04o`000?oE][[oeKJjomFf^PKo00000ooB/k/3o`000003om>a]ol0003odJng00?odJng00?o0000
oln^^?o?[[P00_l00003oln/]@03o`000?o>Z[GocZZe00;ocZZe00Ko0000olVW]_l0003o0000olfW
/ol00003ol^V/`06o`000?o7XkCoaj>do`000?o9Y;;o00000oo8Xk<4o`000004olBN/_l0003oaYn`
o`0000CoaIna00Go0000ol6K/Oo1Vk7o0000ol>L/009o`0000?o_iR_00?o0000ok^D[onkU:l00_nk
U:l2o`0000Ko^iF_0_l00005okRB[`03o`000?ngT:ko000000Co]Hn_00Co0000okB>[_ndSZko0000
1?nbS:h01Ol0003o/Hb^ok6<[_naS:ko000000Co[hZ_00?o0000ojn:[_l000001on/R:l2o`0000?o
ZXN_2Ol00002ojN6/@03o`000?nSP[7oXh:a00CoXh:a0ol00003oj62/P?o00001OnMP;800ol0003o
VWjcoiYn/`03oiYn/`Go00000onHOkH01?l0003oUGfgoiEm]onEOKL2o`000003oiIn]ol0003oTWbh
00KoTWbh0_l00004oi5l^@GoSG^k00?oSGbkohal_On<O;d01_n<O;d2o`0000CoRgfo00Co0000ohIm
`On6OL7o00000_n9O/8:o`0000CoQGo500?o0000ohF2b?n5P/P00on5P/P00ol0003oPX?<o`000003
ohF5c005o`000?n2QlooPXO?oh:7col000000_n3Qll4ohN=dPSo00000_n6SmD6o`000004ohJCfOl0
003oSI_LohfKg0ko00000_nFZnD01Ol0003oUjcUoiN/iOnG[>Go000000;oW;_^0ol00003oj31l004
o`000?nYc_?o0000o`0000Go[]Cd0_l000002_o7h^_o0000o`000?o3mNoobo;/o`000?o?nNKo0000
omOn_ol0001JoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX00ooonfX000Gooo]Z
00?o0000oookJ_oonfX03?oonfX2o`000005onJlZol0003oi[^ZonJkZ_l000000_oS^jh01?l0003o
hkZ^on>j[_l00002on2j/@04o`000?oP^K7oh;Vaon2i/@;o000000?ogKZeo`000?oK^KH00_oK^KH0
1?l0003of[RgomZh]ol00003omZh]`04o`000?oH^;Wof;Rio`0000CoekNi0_l000000ooE]k_o0000
omFf^`03omFf^`;o000000?od[Jno`000?oB];d00_oB];d00ol0003odKBlom6d_002o`0000?oelG9
00Go0000omK4b?oFa<Soe/C8o`000003omG3b@04o`000?oD`/So0000omS1``;o000000?oel33o`00
0?oF_l<00ooF_l<01Ol0003oeKg3o`000?oD_<?o000000;oe[Zn00Co0000omJj__oF^[koe[Zn0_l0
0002om:g_`04o`000?oA][oo0000omFf^PCo000000?odkBjo`000?oB/k/00ooB/k/2o`000003om:a
^?l0003o000000?odJng00Co0000oln^^?o?[[Socjjh1?l000000oo?[;Go0000oljZ]@02oljZ]@05
o`000?o9YkKobJNfo`000?o=Z;@00ol00002ol^V/`05o`000?o7XkCoaj>dolNS]?l000001Oo8Xk<0
0ol0003oaj6bolNQ/P03o`0000CoaIna00?o0000ol6K/Oo1Vk400_o1Vk42o`0000Co`Y^a00?o0000
okjH/?nnV;001ol00002ok^D[`03o`000?nkUJoo^iF_00Co^iF_00?o0000okZC[ol000001?nhTZl0
1?l0003o]i2^okN@[_l00003okF?[`03o`000?ndSZko]8j^00;o]8j^00Co0000ok:<[_nbS:ko0000
1OnaS:h01?l0003o[hZ_ojn:[ol00003ojn:[P03o`000?n/R:oo[8R_00?o[8R_1_l00003ojV6/0?o
00001OnWQ[400ol0003oXh:aoj>2/@03oj>2/@;o00000_nQP[83o`000003oj62/ol0003oWH2b00Ko
WH2b00?o0000oiYn/ol000000_l00002oi^1]@03o`000?nHOkKoV7nf00CoV7nf0ol00004oiIn]`03
o`000?nBO;SoTWbh00?oTWbh0_l00005oi5l^@04o`000?n=Nk_oSG^kohek^`?oSGbk1_n<O;d2o`00
00KoRgfo0_l00003ohUn`P05o`000?n5O/CoQGk4ohEna?l000000_n8P<@01?l0003oQ877ohB1aon4
PLL6o`0000CoQH;800?o0000ohF5c?n5QL`00on5QL`00ol0003oPXO?o`000004oh>7c`CoQhgB00Co
0000oh>;don3Rm?o00001On9T]H2o`0000CoS9SJ1?l000000on<W=go0000ohfLgP02ohfLgP03o`00
0?nDYN7oU:GQ00GoU:GQ00?o0000oiJ[iOl000000_nG[>D5o`0000OoX<7`00Co0000ojkDm?n^e?Co
[]Cd0ol000002OnbfoGo0000o`000?l0003o`oG_o`000?o;l^co0000oloiiP03o`0005cooo]Z00?o
0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP03oookJP001OoonfX00ol0003ooo]ZoookJP0<
oookJP03o`000?oX^ZKo000000?oi[^Z0_l000001?oS^jko0000on>j[_oS^Zh2o`000003on2j/Ol0
003oh;Va00;oh;Va0ol00004om^i]P;o000000?of[Rgo`000?oJ^;L00_oJ^;L2o`000003omRh^Ol0
003oekNi00;oekNi00?o0000omJf^_oF][X00_l00003omFf^`03o`000?oD];[oe;Bj00?o000000?o
d[Bmo`000?oA];`00_oA];`3o`000003omO5bOl0003oe/C800;oe/C800Go0000omK3b?l0003oeL?9
o`000003omC2b003o`000?oG`<?oel3300;o00000ooF_l<01?l0003oeKg3omFm`ooE_L<3o`000003
omJj__l0003oe[Zn00;oe[Zn00Co0000omBi__l0003od[No1?l00004om>d^P;o00000ooB/k/00ol0
003ock2koln`^`02o`000004om6_^?l0003odJngo`0000?ocjjh00?o0000olb[^Ol000000_o?[;H3
o`000003oljZ]Ol0003obJNf00?obJNf00Co0000ol^W]?o;YkCobjNd1?l00002olNS]003o`000?o8
Xk?ob:>c00;ob:>c00?o0000olNQ/_o7XK800_o7XK89o`0000;o`I^a00?o0000ol:K/Oo2Vk400_o2
Vk401Ol0003o_YR`okjH/?nnV;3o000000;o_iR`00Co0000okjH/OnnV;7o_YRa2ol000001OnjTjoo
0000okRB[onhTZoo000000Co]i2^00?o0000okF?[ol000001OndSZh00ol0003o/Xb^o`000006ok6<
[P04o`000?n_RZoo0000ojn:[P[o000000?o[HZao`000?nYQ[001?nYQ[000ol0003oZHNao`000007
ojN6/@03o`000?nSP[7o000000Ko00001OnQP[<00ol0003oWH2boif0/P03oif0/P?o00001OnKPKD0
0ol0003oV7nfoiQo]P03oiQo]P;o00001_nFO[L01?l0003oTWbhoi9l^?nBO;P2o`000003oi=m^?l0
003oTGbi00CoTGbi00?o0000ohek^on=Nk/01?n=O;/01?l0003oS7bmohal_On<O;d2o`000003ohan
_ol0003oRgfo00CoRgfo0_l00005ohUn`P03o`000?n5O/Co000000CoR83400Co0000ohB1aon4PLOo
00000_n5PLL4ohN5bPKo00001?n5QL`00ol0003oPhO?oh>7c`03oh>7c`04o`000?n7SM;oQhgBo`00
00?oPh_C00?o0000ohVBe_n9T]H00_n9T]H00ol0003oQ97Ho`000006ohbHfP03o`000?n<W=go0000
00GoSIcN00?o0000oiBUhOnDYN400_nDYN42o`000003oiBUhOl0003o000000;o00001?nI]^`00ol0
003oX<7`oj31l003o`0000;oY<Ka00Co0000ojkDm?l0003o00000onbfoD2o`000003okkWl_l0003o
000000;obo;/0ol000000ooGo[oo0000oookJP1LoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000
oookJ_oonfX00_oonfX000Gooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003oj;ZVonRjYP02o`00
0004onJkZ_l0003oiKZZonFjZPCo00000_oR^Jh2o`0000;oh;Va00?o0000omnh/?oO^;000_l00002
om^i]P03o`000?oK^;CofkRd00;o00000_oJ^;L00ol0003ofKNfomVg]P03o`000003omNg^Ol0003o
e[Jj00;oe[Jj00Go0000omFe^Ol0003oeKJko`000003omBd^P03o`000?oC];_odkBk00;o00000_oA
];`00ol0003od/K>om;6cP02o`0000?oe/C800Go0000omK3b?oF`lSoe/?8o`000003omC2b009o`00
0?oC`<So0000omO0`ol0003oe[o3o`000?oF_l?o000000?oeKg300?o0000omBl`ooD_<<00_l00003
omJj_P03o`000?oD^Kkoe;Vn00Co000000?odKJoo`000?oC];X00_oC];X01_l0003odkBkom>d^ol0
003od[>ko`0000?ock2k00Co0000om6_^?oA[kSodJnh0ol00002oln^^006o`000?o<ZkWoc:^io`00
0?o?[;Ko00000_o>ZkH3o`0000;obJNf0_l00004ol^W]003o`000?o:Y[CobZJd00Co00000_o8Xk<0
0ol0003oaj6bolNQ/P02olNQ/P03o`000?o3W[?o000000?oaInb00Co0000olBO/oo4Wk?oa9nc0ol0
0004ol:K/@03o`000?nnV;3o_YR`00;o_YR`0_l00005okjH/@;o00001?nkUK001?l0003o^9:`okRB
/?nhT[0No`0000?o[X^a00Co0000ojb8/?l0003o00001?n]R[401?l0003oZHJ`ojV6/?nYQ[02o`00
00?oZHNa00Co0000ojN6/OnWQ[7oYhJa1_l00004ojB5/`03o`000?nQP[?oXH:c00CoXH:c00?o0000
oif0/_nMP;800ol000000onNP[Go0000oi^1]@06oi^1]@03o`000?nHOkKo000000;o000000?oV7nf
o`000?nFO[L01OnFO[L01?l0003oTWbhoi9l^?l00003oi=m^003o`000?nAO;WoTGbi00co000000Co
S7bmo`000?l0003o00000_n<O[l01ol0003oRgfooh]m_on;OKoo0000oh]o`Ol000001On9O/82o`00
00GoR83400?o0000ohB1aol000001?n5PLL4ohN5bP03o`000?n4Pl[oQhS=00CoQhS=00?o0000ohF5
c?l000002ol00002oh>;d`05o`000?n9T]KoRI;FohVBe_l000000_n4TMP00ol0003oS9SJohbHfP04
ohbHfP04o`000?n=W=koSIcNohfLgPSo00000onGZN800ol0003oVKK/oiVfk006oiVfk0;o00001_nT
a_400ol0003o/]_eok;Km@03ok;Km@03o`000?nnio;o000000?oaN;]1Ol0001OoookJP03o`000?oo
nf[ooo]Z00kooo]Z00?o0000oookJ_oonfX00_oonfX000Cooo]Z00?o0000oookJ_oonfX03?oonfX0
1Ol0003oj;ZVonRjY_l0003oikVU00;o00000_oU^ZX01?l0003oi;VZonBiZ_l00002on:i[P05o`00
0?oQ^:go0000on2i/Ol000000_oO^;001Ol0003og[N`o`000?oK^KKo000000;ofkRd00Go0000om^g
]?l0003of[Rgo`000002omVg]P03o`000?oI][KofKJf00;o00000_oF][X01?l0003oeKFiomFe^OoE
]KT2o`0000?oe;Bj00GodkBjo`000?oC];_o0000om:c^P02o`0000?od/K>00Go0000om;5cOl0003o
e/C8o`000003omK3b005o`000?oE`/So0000omC2b?l000000ooC`<P01Ol0003oe[o3omJo`ooF_l?o
000000?oeKg300Co0000omBl`ooD_<?oe;c30ol000000ooF^[ko0000o`000002o`000004omBi__l0
003odkRnom>h_P?o000000?odkBjo`000?oC];/00ooC];/3o`000003oln`^ol0003o000000?odJnh
00?o0000om2_^Oo@[kT00ol00003olb[^@05o`000?o>ZkKocZ^folj[]_l000000_o=Z[H5o`0000;o
bjNd00?o0000olZV]?o:Y[@00_o:Y[@00ol0003oaZ:eo`000004o`0000;oaj6b00Co0000ol>N/oo3
W[?o00000_o5Wk800ol0003oa9ncolBO/`03olBO/`Wo00000_nnV;000ol0003o_YRaokjH/@03okjH
/@04o`000?nlU[3o_9J`o`0000;o^iF`00?o0000okRB/?nhT[000onhT[02o`0000Ko^9>a00?o0000
okB@/OndT;401OndT;42o`0000Ko/Hj`0_l00007ojj;/@03o`000?n]R[7o[HZa00Go[HZa00?o0000
ojV6/?l000000_nYQk47o`0000;oYXFa0_l00006ojB5/`03o`000?nQP[?oXH:c00?oXH:c1Ol00003
oij2]@03o`000?nKPKGoVh6e00?oVh6e1?l00005oiQo]P03o`000?nFO[OoUWjg00?oUWjg2ol00003
oi9o^`03o`000?n>O[goSWjm00?oSWjm0_l00004ohio_`Go000000?oRgfoo`000?l000002_l00004
ohR0a003o`000?n5PLOoQH7700?oQH770on7QLX01?l0003oQ8?:ohB3b_n4PlX4ohN8c@03o`000?n4
Qlko000000KoR8cA00?o0000ohV@e?n9T=@00_n9T=@Do`0000CoSZCT00?o0000oiNYh_nGZN800onG
ZN801?l0003oTj[Vo`000?nI]^`4o`0000;oW;_^00?o0000ojC6lOnTa_400ol00003ojS=l`05o`00
0?nbfoGo0000o`000?nhf?400_l00003olGRk@05okofl?l0003oc?[WomGmgOl00000H?oonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z00;ooo]Z0004oookJP03o`000?oonf[ooo]Z00co
oo]Z0ol00002onNiY@04o`000?oV^:Go0000o`0000?oi;VZ0ol00003on6h[@;o000000CogkR`o`00
0?oN]k3og[N`0ol000000ooK^;Co0000om^g]002om^g]0;o000000?ofKNfo`000?oI][H00_oI][H0
1Ol0003of;Feo`000?oF][[o000000?oeKFi00Go0000omFd^?l0003oe;Bjo`000002om>d^P04o`00
0?oB/k[od[>jo`0000?od/K>00Go0000om;5cOoBaLgod/G=o`000003omK3b004o`000?oE`/SoeL;8
omG2b0?o000000?odl38o`000?l000000ooF_l<2o`000003omFm`ol0003oe;c300;oe;c300?o0000
om:j`ooB^/<00ol00003omBi_P06o`000?oC^;kodkRnom>h__l0003od[No0_l00005om>d^`03o`00
0?oA/k_odK>k00;o000000CocZnko`000?oA[kSo00001?o@[kT01?l0003ocjjio`000?o<ZkT2o`00
00;ocZ^f00?o0000olfZ]_o=Z[H00_o=Z[H00ol0003ob:JgolRV]`03o`0000CobZJd00Ko0000olJR
]Oo6X[Go0000olRS/ol00002olNS]0Go000000?o`ijco`000?l000001Oo4Wk<00ol0003o`9^bo`00
0003ol:L/@04o`000?o1W;;o`Ibbol6L/PGo00000_nnV;401ol0003o_9J`okbF/?nlU[3o0000ok^E
/?l000001_nhT[000ol0003o^9>aokRC/@04okRC/@;o00001_ndT;400ol0003o]8n`o`000005ok6>
/003o`000?naSK3o000000Oo[X^a00?o0000ojf:/On]R[400_n]R[48o`0000?oZHRb00Co0000ojJ5
/OnVQK7oYXFa0_l000000onWQk?o0000ojB5/`06ojB5/`03o`000?nQP[?o000000Go00001_nNP[D0
0ol0003oVh6eo`000002o`0000;oVh6f00?o0000oiQo]_nHOkH00onHOkH7o`000003oiJ0^Ol0003o
Tgnj00CoTgnj0_l00005oi9o^`03o`000?n>O[goSWjm00;oSWjm00?o0000ohmn_On>Okl01_n>Okl2
o`0000CoS83100Co0000ohV0`on9P<?o00000on;P/<01?l0003oQh;6ohN2a_n7P/H8o`000004ohF1
aon7QL[oQhG:o`0000CoQ8?:00Co0000ohN8cOn7R<go00000on4Qlh00ol0003oR8cAohR<d@03ohR<
d@03o`000?n9T=CoRI3D00CoRI3D00?o0000ohRCf?l000001?n9U=P00ol0003oSi_KohnKf`04ohnK
f`03o`000?n>Y>CoSZCT00KoSZCT00?o0000oiNYh_l000001_l00007oibkkP;o00001onXcO<01?l0
003o^=SaokSHlOl00002olGRk@08o`000?nom_3o_oK`o`000?o<n^OoeOgMo`000?o>o;YQoookJP03
o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX00_oonfX000Cooo]Z00?o0000oookJ_oonfX0
2ooonfX00ol0003ojkRNon^hWP03o`0000?oi[RU00Co0000onBiZ_oT^J[o00000_oS^:X01_l0003o
hKR]on6h[OoQ^:go0000on2g[@;o00000_oN]k000ol0003ogKJaomff/@02o`0000?ofkNd00Co0000
omZf]?l0003o00000_oI][H00ol0003of;FeomRe]@03o`0000;oeKFi00Co0000omFd^?oE];SoeKBh
0ol000001?oC];[o0000o`000?l00003om;6cP04o`000?oBaLgod/G=om;5c@?o000000?oe/?8o`00
0?oE`/P00ooE`/P01?l0003oe<77omC1aol00002om:ob003o`000?oF_l?o000000;oeKg20ol00000
0ooD_<?o0000o`000002o`000006om:j`ol0003oe;Vno`000?oD^Kko00000ooC^;h01Ol0003od[No
om:g_ooB]koo000000CodkBk00Wo0000om6c^ooA/k_odK>ko`000?o@/[co0000olj_^ol000001?o@
[kT01?l0003ocjjioln^^Oo?[[T4o`000003olj[]_l0003ocJZf00;ocJZf00?o0000olRV]oo8Y[L0
0_o8Y[L3o`0000;obZJd00?o0000olJR]Oo6X[D00_o6X[D00ol0003oaj>dolNS]002olNS]004o`00
0?o6XK?oaZ6colJQ/`Go00000_o4Wk<01ol0003o`9^bol2K/_o0Vk;o0000ol:L/Ol000001Oo1W;82
o`0000;o_YVa3?l00003okRB/003o`000?nhTk7o^9>a00?o^9>a00Co0000okJA/?nfTK3o00001?nd
T;401Ol0003o]8n`okB?/?ndSk3o000000?o/Hj`00Go0000ok6=/?naSK3o/Hf`o`000005ojj;/@Ko
00000_n/R[42o`0000OoZHRb00Co0000ojJ5/OnVQK7o00001?nWQk<01?l0003oY8FcojB5/onTQK<8
o`0000;oXHBe00?o0000oij2]OnNP[D00onNP[D3o`0000KoVh6f00?o0000oiQo]_l000001Ol00005
oiJ0^@04o`000?nCOk[oTgnjoi=o^P;o000000?oU7njo`000?nBOk/01OnBOk/00ol0003oSWjmo`00
0004ohmn_@GoSWno00?oSX71o`000?n<P<401On<P<42o`0000GoRh;300Co0000ohN2a_n7P/Ko0000
0_n8P/H5ohV5b0ko000000?oQ8O>o`000?n8S=400on8S=400ol0003oQhoDo`000006ohV@e003o`00
0?n9U=SoRICH00CoRICH00?o0000ohnKfon?Vm/00_n?Vm/00ol0003oRi[Mo`000004ohjTi0;o0000
00?oSZCTo`000?l000000_nGZn@01Ol0003oUj_ToiN[i?nGZnCo000000;oW;_^0ol00003oj30k`03
o`000?nXcO?oZ<gc00?o00000on/do@2o`000003olGRkOl0003o000000;o_oK`00Gob??]o`000?oE
oMgo0000olkl^P1SoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX00_oonfX000Co
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ojkRNon^hWP04o`0000;oi[RU0_l000001?oT^J[o
0000on>hZ_oS^:X2o`00000@on6h[Ol0003oh;N]on2g[Ol0003oh;J]o`000?oN]k3ogKJ`o`000?oM
][7o0000ombe/Ol0003ofkNdo`0000;of[Jd00Go0000omZe/ol0003ofKJfo`000002omRe]@06o`00
0?oG];KoekBfo`000?oE]KWo00000_oE];P01?l0003oe;>homBc^?oD/kP2o`0000;odlK=00?o0000
om;6c_l000000ooBaLd00ol0003odLC=om74c@03o`0000?oeL;800Co0000omC1aooD`LOoe<770_l0
00000ooB_lSo0000o`000003omFm`P03o`000?oD_<;o000000;o00000ooB^/<01?l0003od;W3o`00
0?oD^Kh3o`000003om>h__l0003od[No00?od[No0ol000000ooC];_o0000om6c^`02om6c^`04o`00
0?o@/[cod;:lom2b_0Co000000?od:nio`000?o?[[T00oo?[[T00ol0003obj^iol^[^@04o`000003
olfZ]_l0003ob:Jg00Cob:Jg00?o0000olZV]?o:Y[@01?l00002olJR]@;o00000oo7Xk@00ol0003o
aZ6colJQ/`03olJQ/`;o00000_o4Wk<5o`0000;o`9^b00?o0000ol6L/_o1W;800oo1W;801?l0003o
_IRbokfH/_l00002okjI/@03o`000?nmVK;o_IVb00?o_IVb00?o0000okZF/_njU[800_njU[8To`00
0003ojn=/_l0003o[8Za00?o[8Za00?o0000ojb:/_l000001onYR;83o`0000?oYhNc1_l00002oj>5
/`?o00001_nQQ;D00ol0003oWX:eo`000002o`000003oij3]Ol0003oVh6f00?oVh6f1Ol000001OnI
PKSo0000o`000?nIP[So000000OoUX2i0ol00003oiAo^P03o`000?nBOk_oTWnk00?oTWnk0_l00006
ohmn_@CoSWno0_n>PL400ol0003oS831ohb0`@04ohb0`@03o`000?n;P/?oRh;300CoRh;300?o0000
ohN2a_l000001?n8P/H5ohV5b003ohV8c?l0003oRHS<00GoRHS<00?o0000ohZ;con:Rll00_n:RllR
o`0000CoUJGP00?o0000oiN[i?l000000_nGZn@5o`0000OoX<3_0_l00002ojcCm0?o00000_nafoH2
o`000008okofl?l0003ob??]olSckOl0003oeOgMo`000?o>o;YToookJP03o`000?oonf[ooo]Z00co
oo]Z00?o0000oookJ_oonfX00_oonfX000Cooo]Z00?o0000oookJ_oonfX02ooonfX3o`0000;oj[NN
00Co0000onRfWol0003o00000_oV]jD01?l0003ohkRZon>hZ_l00002on>gZ@;o00000_oP]jd01?l0
003oh;J]on2f[Ol00002omff/005o`000?oL]K7og;Faombe/Ol000000_oJ][@01?l0003of[FcomZe
/ooJ]K<2o`0000;of;Fe0_l00002omNd]P;o000000?oeKBho`000?oD/kP00ooD/kP2o`0000?odlK=
0ol000000ooBaLgo0000om74c@02om74c@;o000000CoeL;7o`000?oE`/So00000ooD`LL00ol0003o
dl37om?0a`02o`000003om6naol0003oeKg200?o000000Koe;c2o`000?oD_<;o0000om:j`ol00003
om2i``04o`000?oC^;kodkRnom>h_P;o00000ooB]kl00ol0003ockBoolnd_`04o`000003om6c^ol0
003od;:l00?od;:l00Co0000olb__?l0003od;2j0_l00003oln^^@05o`000?o;ZkWobj^iol^[^Ol0
00000oo=Z[L2o`0000Cob:Jg00?o0000olNV]ol000000_o:Y[@00ol0003obJJfolVV]P05o`0000;o
aj>d00?o0000olJQ/oo6XK<00_o6XK<00ol0003o`Yjdo`000003olBO/`04o`000?o3WkCo`indol>O
]0Go00000_o1W;801ol0003o_IRbokfH/_nmV;;o0000okjI/Ol000001OnmVK82o`0000Go^YJb00Co
0000okNC/OngTk7o00000onhTk401Ol0003o]i>bokNC/_ngTk;o000000;o]92a00?o0000okBA/_nd
TK800ondTK800ol0003o/Hjao`000005ok6?/P04o`000?n_S;7o[hbao`0000Co[hfb00?o0000ojb:
/On/R[400_l00002ojb:/P03o`000?nYR;;oZHRb00GoZHRb00?o0000ojN7/onWQk<00ol00002ojJ7
]003o`000?nSQK?oXhFc00;oXhFc00?o0000ojB7]Ol000001OnQQ;D4o`0000CoWX>e1Ol00003oib3
]`?o00001?nIP[P00ol0003oUX2ioiJ0^@03oiJ0^@;o00001_nDOkX00ol0003oTWnkoi9o^`02o`00
0003oi:1_Ol0003oSgjm00GoSgjm0on>Okl4ohj1`@03o`000?n<P<7oS83100;oS8310_l00007oh^2
``03o`000?n8P/KoR8;600?oR8;600Co0000ohV5b?n9QLSoRHG80on9R<`00ol0003oRHS<ohV8c002
ohV8c0;o00001_n:Rll00ol0003oR8gBo`000004ohR>dPCoSI?E00Co0000ohVBe_n9T]Ko00001_n>
VMT00ol0003oSYgMo`000005ohnMg@03o`000?nEYN3oUJGP00GoUJGP1?l00004oiZfk003o`000?nP
`>ooX<3_00?o00000_nTa_401?l0003o[=?do`000?l00004ok7KmP04o`000?nmj??o0000o`0000;o
b??]00Go0000omGmgOo9om?o0000ojWIL`1UoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oook
J_oonfX00_oonfX000Cooo]Z00?o0000oookJ_oonfX02_oonfX01?l0003okKFFonfeU_l00002onZg
WP04o`000?oX]Yooj;JOo`0000;oi[NU0_l000001_oS^:[o0000on>gZOoS]jWo0000on:fZ@;o0000
0ooP]Zd2o`000003omff/?l0003og;Fa00;og;Fa0_l000000ooJ][Co0000omZe/`02omZe/`04o`00
0?oI];?o0000o`0000;oekBe00Co0000omJc]_oF/kKoe[>f0_l00003omBc^006o`000?o>a];oc/KB
o`000?oCa/go00000ooCaLd01Ol0003odLC=om74cOoAa<go000000;od<?=00?o0000omG2aol00000
0ooD`LL01?l0003odl37om?0aol00002om:oa`?o00000ooD_<801?l0003oe;c2omBl`_oD_<82o`00
00?od;W300Wo0000om>h__oC^;kodkRno`000?oB][ko0000om:g_ol000000oo?];l01?l0003odK>k
om6c^ooA/k/2o`0000?od;:l00Go0000olb__?o<[kcoc:nlo`000002oln^^@03o`000?o?[[Wo0000
00Cobj^i00KobJZjo`000?o=Z[OocJZgo`000?o<Z[P2o`000007olRV]ol0003oajJgolNV]ol0003o
bZJdo`000004olVV]P03o`000?o5X[KoaJ:f00Go00000_o6XK<01ol0003o`Yjdol:N]?o2W[Co0000
olBO/ol000001?o3Wk@00ol0003o_i^do`000002ol6L/`Go00000_nmV;800ol0003o_IVbokfI/P03
okfI/P03o`000?nkU[;o000000Co^YJb00Go0000okNC/OngTk7o]i>ao`000002okRC/@03o`000?ng
Tk;o]i>b00?o]i>b0_l00006okBA/P;o00001onaSk82o`0000Ko[hfb0_l00005ojb:/P03o`000?nY
R;;oZHRb00Oo00001OnVQk@00ol0003oXhFcoj>5/`02o`0000?oY8Ne00?o0000oj64]Ol000000_l0
0002oj65]@03o`000?nNPkGoWX>e00?o000000?oWhFgo`000?nLPkL01?nLPkL2o`0000KoVH:h00Co
0000oiJ0^OnFP;WoUX2i0_l000000onGPKWo0000oiAo^P02oiAo^PGo000000?oTWnko`000?l00000
2Ol000000on>Okoo0000o`00000?o`000003oh^2`ol0003o000000Oo000000KoRHG8o`000?l0003o
0000ohV8c?l00003ohV8c004o`000?n9RlooRH_?o`0000KoRX_?00?o0000ohR>d_n8S]801?n8S]82
ohfCe@03o`000?n9T]KoRI;F00;oRI;F00?o0000ohjIfOn>VMT01?n>VMT00ol0003oSigMohnMg@02
ohnMg@Oo00000onIZN800ol0003oV[K/oiZfk006oiZfk0;o00001_nTa_400ol0003o/M_fok7KmP03
ok7KmP03o`000?nmj??o000000?oa>?^1Ol0001WoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000
oookJ_oonfX00_oonfX000Cooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003okKFFonfeUP03o`00
0003onVfW_l0003oj;JO00?o00000_oU]ZD4o`0000?oh[JY00Co0000on2f[OoP]Zgo00000_oO]Jd3
o`000004ombe/Ol0003ofkFbom^e/P;o00000_oJ]K<01?l0003ofKBcomVd/ooI];<2o`000003omNd
]Ol0003oe[>f00;oe[>f00Co0000omFb]ol0003oe;>h0_l00003olk6dP09o`000?oCaLgodlG=om?5
cOl0003od/C<o`000?oAa<go000000?od<?=0_l000001?oD`LOo0000omC1aol00002om?0a`Co0000
00Kod[o7o`000?l0003o0000omBl`_l00003omBl`P0:o`000?oC^l?odk_3o`000?o@^L?o0000olnh
`ol0003odkRno`0000?od[Jn0_l00002olnd_`03o`000?o>/koo000000;odK>k00Go0000om2c_?l0
003od;:lo`000004olb__004o`000?o?[[Wocjjioln^^@?o00000_o;ZkT01Ol0003obJZjo`000?o=
Z[Oo000000Coc:Zh0ol00002olNV]`03o`000?o9Y[KobJJf00;obJJf00?o0000olFR]_o5X[H00_o5
X[H01?l0003oaZ>eolJS]Oo6XkD5o`000003ol:N]?l0003o000000Co`ind00Co0000oknK]?noVkCo
00000_o1W;<00ol0003o_ibdoknL]002oknL]0[o000000Go^iJbo`000?njU[;o^YJbo`000005okNC
/@;o00001_ngTk800ol0003o]96bokBA/P05okBA/P03o`000?naSk;o/Hnb00Go/Hnb0_l00007ojn=
/Pco00000onZR[@00ol0003oYXNdojJ7]005ojJ7]0;o00000onTQkD4o`0000GoXHFe0ol00005oin5
]`03o`000?nLPkOo000000;o000000?oW8>ho`000?nIP[P01OnIP[P00ol0003oUX2ioiJ0^@08o`00
00;oU8:l0_l00006oi>2_@03o`000?n@PKooT86o00CoT86o1_n@P/43o`0000CoSX?300?o0000oh^3
aOn;PlD00_l00002oh^3a@OoS8K800?o0000ohb8bon<R</00_n<R</Yo`0000?oT:GS00?o0000oiVY
h_nIZN800onIZN800ol0003oU:[Uo`000002oiZfk0?o00000_nM^nd00ol0003oY<KaojC6l@03o`00
00?oZ<gc00Go0000ok7Km_l0003o0000okOHl@02o`0000?oa>?^00Go^oO`o`000?o8nnOo0000okSi
_01YoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX00OoonfX000Cooo]Z00?o0000
oookJ_oonfX02_oonfX3o`0000;ok;BG0_l000001OoY]Yko0000onNdWooW]9oo000000;oiKJU00Co
0000onBeYOoT]JGo00000ooR]ZT2o`000006on2f[Ol0003ogkF]omne[Ol0003og[B/0_l00003om^e
/P05o`000?oK/k7o0000omZe/ol000000ooI];<00ol0003ofK>bo`000002o`000003omJc]_l0003o
eK:g00;oeK:g0_l000002?o?a];o0000olk6d_l0003oc/GBo`000?oCaLgo00000ooBa<`01Ol0003o
d<?=om33cOo@`lgo000000;od<;=00?o0000omC1aol000001?l00003om:oa`03o`000?oA_/OodKk7
00;o00000ooD_<800ol0003odk_3om>k``02om>k``;o000000?ockS3o`000?l000001?oB][h02Ol0
003odKNoo`000?o?];oo0000oljc_ol0003odK>ko`000003om2c_0?o00000_o<[k`00ol0003objjm
o`000002oln^^@03o`000?o>[[[ocZjj00Co000000?obJZjo`000?o<Z[P01?o<Z[P00ol0003obZVh
olZY^005o`000003olVV]_l0003oaJ:f00CoaJ:f00?o0000olJS]Oo6XkD00_o6XkD01?l0003oaJ:e
olFR]Oo5X[D5o`000003ol>O]?l0003o_i^d00?o_i^d0_l00006oknL]0;o00001?nmVK<00ol0003o
_9VdokbI]00?o`0000?o]i>b00?o0000okBA/_ndTK801?ndTK82o`0000?o/Hnb3_l00006ojb;]003
o`000?nYR;?o000000GoZXZd00?o0000ojJ7]?nVQk@01?nVQk@2o`000004ojB7]Ol0003o0000o`00
00;oY8Ne00?o0000oj65]OnQQKD00onQQKD2o`0000GoWhFg1?l00004oib3^003o`000?nIP[SoVH:h
00CoVH:h1?l00003oiN3^`03o`000?nDP[coU8:l00;oU8:l00?o0000oiF2_?nCP[d01onCP[d00ol0
003oT86ooi21_`03oi21_`03o`000?n@P/7oT8;100?oT8;100?oT8C3o`000?n>Pl<01On>Pl<2o`00
00GoRh?51On<Q/P00on<RL_o0000ohb8b`05ohb8b`;o00001On<Rlh01?l0003oRHgAohV=dOl00003
ohV=d@03o`000?n=T]CoSI;D00CoSI;D00?o0000ohbFf?n<U]P01?n<U]P4oi:LfP04o`000?n>Vm_o
SY_Ko`0000OoT:GS00?o0000oiVYh_nIZN801ol00006oifkk@;o00001onXcO<01?l0003o]mSaokOH
lOl00002olCSkP07o`000?nkmo3o^oO`o`000?o8nnOod?kKo`00001ZoookJP03o`000?oonf[ooo]Z
00[ooo]Z00?o0000oookJ_oonfX00OoonfX000Cooo]Z00?o0000oookJ_oonfX02_oonfX01ol0003o
k[6=o`000?l0003ok;BGo`000?o[/iL00ol000001?oW]9oo0000o`000?l00003onBeY@;o000000Co
h[JYo`000?oQ]:WohKBY1?l00003omjd[0;o000000?ofkFbo`000?oK/k400_oK/k43o`000006omVd
/ol0003ofK>bomVc/_l0003of;:b0_l00004omFb]`05o`000?o?a];oclKBolo6d_l000000oo>aM80
2Ol0003od/C<om;4c?oBa<co0000om;3c?l0003od<?=o`000004om32c@Go00000ooB_lL00ol0003o
dKk7om6na`02om6na`;o000000?oe;c2o`000?oC^l<00ooC^l<00ol0003odK[3om6j``03o`0000?o
d[Jn00Co0000om6g_ooA]koodKNo0ol000000oo>/koo0000om2c_003om2c_003o`000?o?/[cock:l
00Go000000?ocjjio`000?o>[[X00oo>[[X00ol0003oc:fjolb]^P02o`0000Coc:Zh00?o0000olZY
^?o:ZKP00_o:ZKP2o`0000;obJNg1?l00002olFR]P03o`000?o5X[Ko000000;oaZ>e00?o0000olFR
]Oo5X[D00_o5X[D01Ol0003o`Info`000?o3WkGo`ind00Co00000_noVk@00ol0003o_ibdoknL]004
oknL]003o`000?nlVK?o000000?o_IVc00?o0000okbI]?nlVK@00onlVK@00ol0003o^INcokVG/`05
okVG/`03o`000?ngU;?o]iBc00;o]iBc3ol000000onaSk?o0000ok:A]002ok:A]003o`000?n^SK?o
[Xfc00?o[Xfc00?o0000ojj=/ol000001_n/Rk@2o`0000OoZXZd00?o0000ojJ7]?l000001_l00006
ojB7]@03o`000?nQQKGo000000;o000000CoXXJgo`000?nOQKOoWhFg0ol00002oin5]`03o`000?nL
PkSoW8>h00CoW8>h00?o0000oiV2^?l000000ol000000onJQ;[o0000oiN3^`05oiN3^`03o`000?nD
P[co000000CoUH:l1_nCP[d2o`0000KoT86o1?n@P/43oi24``03o`000?n>Pl?oSX?300;oSX?30_l0
0006oh^3a@CoS8K80on<RL/00ol0003oS8S;ohb8b`03ohb8b`03o`000?n<RlkoS8_>00GoS8_>0_l0
0004ohV=d@03o`000?n=T]CoSI;D00?oSI;D0_l00007ohbFf0;oTYcJ00?o0000ohjKfon>Vm/00_n>
Vm/01?l0003oT:GSoi2Uhon@YN<3o`000005oi2Uhol0003o0000oiV/i?l000000onI[>@00ol0003o
WK_]oifkk@03o`0000?oXL7`00?o0000ojS=lonXcO<00ol00003ojcDm@;o000000?oa>?^o`000?l0
00000_nkmo001?l0003ob?_Wom3nfol0001/oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oook
J_oonfX00OoonfX000?ooo]Z00?o0000oookJ_oonfX02ooonfX01?l0003ok[6=o`000?o]/8h2o`00
00;ojk>G0ol00002onNcW`;o00000_oT]JD01?l0003ohkBUo`000?l00002on6dZ@04o`000?oP/jWo
h;>Yo`0000?og[B/00Co0000omfc[?l0003o00000ooK/k401?l0003of[>`omZc/?l00002omVc/P04
o`000?oH/[;of;:bomRb/P?o000000?oeK:go`000?o?a]800_o?a]82olo5d@07o`000?o>aM;o0000
olg4d_l0003od/C<o`000003om;3c0;o000000cod<;=o`000?l0003o0000olo1c?l0003odl37o`00
0?oC_lOo0000om:oaol00004om6na`03o`000?o?_<Oo000000;o00000ooC^l<01_l0003odK[3om6j
`ooA^/?o0000om2i``;o000000?od[Jno`000?oA]kl00_oA]kl01?l0003od;Foom2e_oo@]Kl2o`00
00?od;>l00Go0000olnb_?o?/[cock:lo`000003olj`_@;o00001?o>[[X01_l0003oc:fjolb]^_o<
[K[o0000olRZ^`;o000000?oc:Zho`000?o:ZKP00oo:ZKP01_l0003oaZJiolJV^Ol0003obJNgo`00
00?ob:Jg1Ol000000oo6XkGo0000olFR]@03olFR]@04o`000?o1WkKo`Info`0000;o`ine00Co0000
ol:O]_o2WkKo`Ynf1_l00002oknL]007o`000?nlVK?o_9VcokbI/ol0003o_IVco`000005okbI]0;o
00001_niUk<00ol0003o^9Fbo`000003okND/`05o`000?ndT[?o]9:cokBB/ol000000ondTK<01Ol0
003o/i:dok>B]?ncT[Co000000;o/Hnc00?o0000ok:A]?nbTK@00_nbTK@00ol0003o[Xfcojj=/`02
ojj=/`04o`000?n^SK?o[Xfco`0000Go[8^d00?o0000ojb<]?l000001?nZR[@6o`0000CoYhVf00?o
0000ojB7]OnTQkD01?nTQkD3o`0000;oXXJg1Ol00006oin5]`03o`000?nLPkSoW8>h00Go00001OnJ
Q;X00ol0003oUh>koiN3^`03oiN3^`;o00001_nEP[`01?l0003oTh:moi>2_OnCP[d2o`000003oiB3
_ol0003oT86o00GoT86o0on@P/400on@Q<?o0000o`00000>o`0000?oS8K81?n<RL/00ol0003oS8S;
ohb8b`02ohb8b`;o00001on<Rlh00ol0003oRHgAohV=d@04ohV=d@05o`000?n=T]CoSI;DohfBe?l0
00000_n<U]P01?l0003oS9KHohbFf?n<U]P>o`0000CoUjKP00?o0000oiV/i?l000000onI[>@4o`00
00OoXL7`0_l00002ojcDm@?o000000Co/=cfo`000?l0003o00000_nkmo001?l0003oaOG^o`000?o@
o]/2o`0006gooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP01oookJP000ooonfX0
0ol0003ooo]ZoookJP0;oookJP?o00000_o]/8h01_l0003ojk>Gon^cUol0003oj[:Go`0000;oik>O
00Co0000onFcX?l0003o00000_oS]:D01?l0003ohk>To`000?l00003on2cZ@;o000000Wog[B/o`00
0?oM/jcogK>/o`000?oL/Zgo0000om^c/Ol000000ooJ/k02o`000003omVc/_l0003of;:b00;of;:b
0_l000001OoF/K?o0000olo6d_o?a];o000000CoclGA00Go0000olg4d_o=a=;ocLCBo`000004om;3
c0?o000000?od<;=o`000?o?`L`00_o?`L`01?l0003odko7om>oaooC_lL2o`0000?odKk700Wo0000
olnlaoo?_<Oockc7o`000?oC^l?o0000om>k`ol000000ooA^/<00ol0003od;W3om2i``02om2i``05
o`000?oA]koodKNoom6g_ol000001?o@]Kl01Ol0003ocK;0o`000?o@/kco000000?ock:l00?o0000
olj`_Oo>/;d00_o>/;d01_l0003obZjmo`000?l0003ocZjjo`0000?oc:fj00Go0000olRZ^oo8Z[_o
0000ol^[^@03o`0000;obZVh00?o0000olJV^Oo6Y[T00_o6Y[T00ol0003ob:JgolRV]`02olRV]`04
o`000?o3X[Oo`j:gol>R]`Co00000_o5X[D00ol0003o`Infol6O]P02ol6O]P;o00001Oo2WkH00ol0
003o_Ybeo`000002oknL]0Go000000?o_9Vco`000?l000001OnlVK@01?l0003o^YNcokZG/ol00004
okVG/`04o`000?nhUK;o^9Fbo`0000;o]iBc00?o0000okBB/ondT[<00_ndT[<01?l0003o]96cokBA
/ol00005ok>B]0;o00001_nbTK@01?l0003o[Xfcojj=/ol00004ojj=/`03o`000?n/RkCo000000Wo
00000_nYR[@2o`0000KoYhVf00?o0000ojB7]OnTQkD00_nTQkD7o`0000?oXHJg00?o0000oin5]onO
QKL01?nOQKL6o`000003oif5^_l0003oVXBj00KoVXBj00?o0000oiN3^ol000000_l000000onHPk_o
0000oiF2_005oiF2_005o`000?nCP[goTh:moi>2_OnDPkl02_l000000on@P/7o0000o`000003oi65
``04o`000?n>QLGoSXG5o`0000?oT8K500?o0000ohf6aon=Q/L00on=Q/L00ol0003oS8K8o`00000A
o`000003ohb;c_l0003o0000013o00001?nBV]T00ol0003oTIoMoi6Og@03oi6Og@03o`000?nGY^3o
UjKP00KoUjKP00?o0000oiV/i?l000000_l00003oi^gk003o`000?nQ`O3oXL7`00?o00000_nTao80
1?l0003o[=Ceo`000?l00003ok3LmP;o00000onng^l01?l0003oaOG^o`000?o@o]/2o`0006kooo]Z
00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP01oookJP000ooonfX00ol0003ooo]Zoook
JP0:oookJP04o`000?o`[8;ol:b2o`0000;okK2>0ol00002onZbU`?o00000ooU/j001?l0003ohkBU
on>dYOl00002on>cY004o`000?oP/jWoh;>Yo`0000;oh;:X0_l00002omfc[0;o000000?og;:]o`00
0?l000000_oJ/k000ol0003ofK:`omVb/003o`000003omRb/_l0003o000000?o000000?oclKBo`00
0?o?aM400_o?aM401Ol0003oc/CAolk4dOl0003ocLCB00;o000000Cod/?<o`000?l0003o00000ooA
`/`02Ol0003ocl7<olo1c?o?`Lco0000oljoc?l0003odko7o`000002om:na`03o`000?oA_/Oo0000
00?ockc700Co0000oljkaol0003odk_30_l00002om6j``03o`000?o@^L?od;W300;od;W30ol00000
0ooA]koo0000om2e_`03om2e_`04o`000?o=//3ocK;0olfb`0?o000000?ock:lo`000?o>/;d00oo>
/;d01Ol0003obZjmolZ^_Ol0003ocJnk00?o000000?oc:fjo`000?o8Z[/00oo8Z[/01?l0003obZVh
olZY^?o:ZKP4o`0000;oaZJi0_l00003olRV]`03o`000?o3X[Oo`j:g00?o`j:g00?o0000olFR]Oo5
X[D01Ol00002ol6O]P03o`000?o2WkKo`Ynf00?o`Ynf00Co0000okjL]OnnW;Go00000_noW;@00ol0
003o_YbfokjL]P02okjL]Pko000000?o^INco`000?nhUK800_nhUK800ol0003o]iBco`000006okBB
/`;o00001_ncT[@00ol0003o/Y6dok:A]005ok:A]003o`000?n^SK?o000000;o[Xfc1Ol000000on/
S;Co0000oj^=]P03oj^=]P03o`000?nYR[CoZHZd00;oZHZd00?o0000ojZ<]_l000001onWRKH00ol0
003oY8Neo`000002o`0000;oY8Vg00?o0000oj66]onQQ[L01?nQQ[L01?l0003oWhFgoin5]onOQKL6
o`0000GoWHFj00?o0000oiZ4^_nJQ;X00onJQ;X3o`0000CoV8>k2Ol000000onCP[go0000o`000003
oiF5_`03o`000?nAQ<7oTHC100?oTHC12?nAQL<2o`0000CoT8K500?o0000ohf6aon=Q/L00_n=Q/L0
0ol0003oSHK7o`000006ohj9bP;o00001?n<R/d5ohj>c`03o`000?n;SLoo000000KoSY;B00?o0000
ohfDe_l000001?n=U=H00ol0003oTY[Ioi:Jf@04oi:Jf@;o00001_nAWmd01?l0003oUjKPoiNVh?nG
Y^02o`000004oiNVh?l0003o0000o`0000OoVkO/0_l00006ojC7lP03o`000?n`g?Ko/=cf00;o/=cf
00?o0000okkNkonng^l00_nng^l2okKbm0?o000000?o[?>boookJ_oonfX0K_oonfX00ol0003ooo]Z
oookJP07oookJP03o`000?oonf[ooo]Z007ooo]Z0003oookJP03o`000?oonf[ooo]Z00[ooo]Z0_l0
00001?o`[8;o0000o`000?l00002onf_SP05o`000?oZ/YOoj[:Go`000?oY/IL00_l00002onFcX0?o
00000ooS/j@2o`00000@on2cZOl0003oh;:Xon2bZ?l0003ogk:Xo`000?oM/jcogK:/o`000?oL/Zgo
0000om^a[Ol0003of[>`o`0000;ofK:`00?o0000omVa[ooI/Jl00_l00002ol[6e`;obLKH00Go0000
olo5dOo?aM7oclGAo`000004olk4d@Co000000?od/?<o`000?oA`/`00_oA`/`01Ol0003od<7;o`00
0?o?`Lco000000?oc[o<00?o0000om:naooB_/L00_oB_/L01Ol0003ockc7olnlaoo?_<Oo000000?o
c[_700Ko0000om6j`ooA^/?o0000om6j`ol00003om2i``03o`000?o=]/CocKK400Co00000_o@]Kl0
0ol0003ocK;0olfb`002olfb`003o`000?o?/[gock:m00;o00000oo>/;d00ol0003obZjmolZ^_@02
olZ^_@04o`000?o<[K[oc:fjolb]^P;o00001?o8Z[/00ol0003obZVholZY^002olZY^003o`000?o9
ZK[obJVj00Go000000?ob:Jgo`000?o3X[L01Oo3X[L01Oo2X[So0000olFR]Oo5X[Go000000?oa:>h
1Ol00002ol:O]P03o`000?nnW;Go_Ybe00;o_Ybe0_l00006okjL]P03o`000?nlV[Go_9Ze00;o_9Ze
00?o0000okVG]?niUk@00_niUk@00ol0003o^INdo`00000So`0000?o[Xje00?o0000ojb<]?l00000
1On[SKH00ol0003oZHZdojV:]002o`0000?oZXbf00Co0000ojN9]_nWRKKoYhVf1Ol00006ojB9]`03
o`000?nQQ[OoXHJg00CoXHJg1Ol00002oin7^@03o`000?nMQK[oWHFj00CoWHFj00Co0000oiZ4^_nJ
Q;[oVXBj0_l000001?nJQ;[o0000oiR3^onHPk/3o`000003oiR5_Ol0003oUXBn00GoUXBn2?nEQKl0
0ol0003oTHC1oi64`@03oi64`@KoTHG30_l00006oi26a@03o`000?n=Q/Oo000000?oSHK700?o0000
ohj9b_n>RLX01?n>RLX00ol0003oS8[=ohb:c@04ohb:c@?oSXk?00Go0000oh^=con;SLooRhg?o`00
0005ohjBdP;o00001_n=U=H00ol0003oTY[Ioi:Jf@02oi:Jf@go00000_nKZ^401?l0003oUj[SoiNZ
hol00002oi^gk0?o00000_nN_>h00ol0003oY<ObojC7lP03o`0000?oZ<od00Go0000ok3Lm_l0003o
]][bo`000002okkNk`?o]_;d00Co^?S^o`000?l0003o[?>bL_oonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z007ooo]Z0003oookJP03o`000?oonf[ooo]Z00[ooo]Z00Ko0000oo6TL_l0
003o0000onn[P_l00002onf_SP?o00000_oY/IL01?l0003oijnHo`000?l00002onFaW`Co00000_oR
/Z@4o`0000?ogk:X1?l00003om^a[@Co00000ooI/Jl00ol0003ob/KGol[6e`02ol[6e`05o`000?o8
a]Oo0000olo5dOl000000_o>a=43o`0000;oclC@00?o0000olg3dOl000000ooA`/`01?l0003od<7;
om31boo@`L/2o`0000?oc[o<00Wo0000om:naooB_/Ood[k7o`000?oA_LOo0000olnlaol000000oo>
^lL2o`0000?odK[30ol000000oo@^L?o0000olffa003olffa003o`000?o@]Kood;Fo00?o00001?o=
//001Oo;//7o0000olnb_Ol0003oc[2m00;o000000?oc[2mo`000?o:[[d00_o:[[d2o`0000?oc:fj
00So0000ol^]_?l0003o0000olRZ^ol0003oajVko`0000;obZVh00?o0000olVY^_o9ZKX00_o9ZKX0
0ol0003oaJJjolFV^P05o`0000?o`j:g0_o2X[P00ol0003oaJ:eo`000005olBS^0;o00000_o2X;H5
o`0000;o_Ybe00?o0000okjL]_nnW;H01?nnW;H00ol0003o_9Zdo`000002okbJ]@03o`000?niUkCo
^INd00?o^INd0_l00007okVG]@03o`000?nfUKGo]YFe00Co]YFe0_l00005ok>B]003o`000?ncTKCo
000000Go/I2e00?o0000ok2@]?l000001on^S[D2o`0000OoZhff0_l00002ojZ<]POo00000_nVRKH2
o`0000OoY8Vg00?o0000oj66]onQQ[L00_nQQ[L4o`0000GoWhNi00?o0000oif5^_nMQKX01?nMQKX0
1Ol0003oVXBjoiZ4^_l0003oVXBj00Go00001OnHQKd00ol0003oUXBnoiJ4_P04oiJ4_PKoUHFo0_l0
0005oi64`@04o`000?nAQL?oTHG3oi65``;o000000?oTHO5o`000?n@Q/D01On@Q/D00ol0003oSHK7
ohf6a`04ohf6a`03o`000?n>RL[oSXW:00;oSXW:0_l00006ohb:c@;oSXk?00?o0000oh^=con;SLl0
5?l000001OnBV]Wo0000oi6MfonAWM_o000000OoTjOS00Go0000oi^ZhOnKZ^7o0000oiNZh`05o`00
00KoW[c^0_l00007ojS?m0?o00000_nng^l01onfl_Co0000okShk_nhn>ko0000okcmdol00000M?oo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z007ooo]Z0003oookJP03o`000?oonf[o
oo]Z00[ooo]Z00Go0000oo6TL_oaY7;o0000onn[PP03o`0000;ok:j>1Ol000001OoW[iSo0000onFa
WooU/Ioo000000;oi;2O00Co0000on:bY?oR/ZCo00000_oQ/J@2o`0000;ogk:X00Co0000omjaZ?oN
/JSo00000ooK/Jd01?l0003of[6^omZa[_l00002omVa[`03o`000?o:a]Oob/KG00;ob/KG0oo9a]H0
0oo8a]Oo0000o`000003o`0000CoclC@0_l000001?o<`]7o0000om72c?l00003om31b`0:o`000?o?
`<_ocl3;o`000?o>_lco0000olfnc?l0003od[k7o`0000?odKg70ol000001oo>^lOo0000olfjb?o=
^/So0000om6j`ol000000oo@^L<2o`0000?ocKK40_l00003om2e_`03o`000?o?];oo000000;ocK;0
0oo;//400ol0003oc[2molj`_@02olj`_@?o000000OobZjmo`000?o9[KkobJfno`000?o<[K[o0000
00Cobjfl1?l000000oo:ZKSo0000olVY^P03olVY^P05o`000?o5Y[[oaJJjolFV^_l000001?o6Y[T4
o`000004ol:R^?l0003oaJ:eo`0000Coa:>h00Co0000ol2O]oo0WkOo00000_o2X;H01?l0003o`J2g
ol6P]oo1X;L6o`0000;o_Ybf00Ko0000okbJ]?nlV[Co0000okbJ]Ol00006okVG]003o`000?niUkGo
^INe00Go^INe00?o^9Jdo`000?nfUKD01?nfUKD01?l0003o]I>dokFC]?l00003ok>B]005o`000?nc
TKCo/i6dok>A]?l000000onaT;D01Ol0003o/92dok2@]?n`T;Co000000Co[Xje0_l000000on^S[Go
0000oj^=]P06oj^=]PCo00000onYS;L01?l0003oYXVfojJ9]_nVRKH2o`000003ojN;^?l0003oY8Vg
00KoY8Vg00?o0000oj66]ol000000_l00002oj:9^@03o`000?nOQkWoWhNi00GoWhNi00?o0000oif5
^_nMQKX00_nMQKX6o`0000?oVhJl00?o0000oiR5_OnHQKd00onHQKd2o`0000KoUXBn1?nEQKl2o`00
0003oiF6`Ol0003oTHC100;oTHC11?l000000onAQL?o0000o`000008o`000003oi26aOl0003o0000
01Oo00000on@T]401?l0003oSY?DohjCe?l00003ohjDe003o`000?nBVMOoTYWG00CoTYWG00?o0000
oi6Mfol000001OnAWM/00ol0003oTjOSoi>Wh`02oi>Wh`;o000000?oTjOSo`000?l000000_l00003
oi^^i003o`000?nN_>koW[c^00?o00000onR`o000ol0003oZ<odojS?m003o`0000Co[=Of00Co0000
okKbm?l0003o00000_nhn>h00ol0003o_?gCo`00001eoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o
0000oookJ_oonfX00OoonfX000?ooo]Z00?o0000oookJ_oonfX02_oonfX2o`000005oo6TL_l0003o
0000o`000?o^ZX800_l000001?o/[Xko0000on^]S_o[[Hh2o`000004onN_V?l0003o0000o`0000?o
i;2O0ol00003on6aY004o`000?oP/:Co0000o`0000?og[6X0_l000000ooK/Jgo0000omZa[P02omZa
[P?o00000oo:a]L01?l0003obLKFolW6e_o9a]H4o`000003olk4dOl0003oclC@00?oclC@00Ko0000
olg3dOo=`m7o0000olc2dOl00003om31b`03o`000?o?`<_ocl3;00;ocl3;0_l000000oo=_/co0000
o`000003om6ma`04o`000?o@_<Ood;c7om2la`;o00000oo=^/P00ol0003od;W3om2i``02om2i``05
o`000?o@^LCo0000olffa?l000000_o<]L@00ol0003od;Foo`000003olnd_`?o000000?obk;1o`00
0?l000000oo>/;d01Ol0003ocK6nolfa__o=/KkobZjm00;o000000CobJfno`000?o<[K[o00001?o;
[K`00ol0003obZblolZ/_004o`0000;obJVj00?o0000olFV^_o5Y[X00_o5Y[X00ol0003oaZJiolJV
^@02olJV^@04o`000?o6YKSoaZFholJU^0Go00000_o4XkP01ol0003o`9ngol2O]oo0WkOo0000ol:P
]_l000001Oo1X;L00ol0003o_Ibgo`000002okjM]P[o00000oniUk@2o`0000Ko^INe0onhU[@01Ol0
003o]YFeokJE]OnfUKGo000000?o]I>d00Co0000ok>B]?ncT[Co00001?ncTK@01?l0003o/I2eok6@
]Ol00004ok2@]006o`000?n^S[Go[Xjeojj>]Ol0003o[Xje2ol00007ojV<]`?o00001?nWRkP00ol0
003oY8VgojB9]`02ojB9]`Co00001_nRRKT00ol0003oWhNioin7^@04oin7^@03o`000?nMQK[o0000
00?o000000?oWHRlo`000?nKQ[`01_nKQ[`00ol0003oV8Fmo`000002o`000003oiV5_Ol0003oUXBn
00GoUXBn0onEQKl8o`0000;oThO30_l00006oi>8a@03o`000?n@R<OoT8S700;o00000_n@R<L6oi6;
b@?o00001?n>Rl`6oi2?cP03oi2BdOl0003oT9;A00KoT9;A0_l00005ohjDe003o`000?nBVMOoTYWG
00CoTYWG00?o0000oi6MfonAWM/00_nAWM/7o`0000?oVZSP00?o0000oi^^i?nK[^@00onK[^@4o`00
00OoX/?`0_l00003ojcGmP?o000000?o^>Ceo`000?l000000_nhn>h2o`000003okcmdol0003ooo]Z
07Kooo]Z00?o0000oookJ_oonfX01OoonfX1o`00007ooo]Z0OoonfX000?ooo]Z00?o0000oookJ_oo
nfX02_oonfX02Ol0003ol9YMo`000?l0003ol:=co`000?o^ZX;o0000onfYP`02o`0000;ojjf>0ol0
0002onJ_V@Co00000_oS[il2o`0000;ohK6T00Co0000on2`Y?oP/:Co00000_oN/JP00ol0003og[2X
omj`Z002o`0000;of[6^0ol00003ol[6e`03o`000?o9a]Ko000000;o000000GobLKFolW5e_o9aMKo
b<GGo`000003olo4d0;o00000oo=`m44o`000003om31bol0003ocl3;00;ocl3;00Co0000om30boo@
`<_od<3;0_l000001?o<_Lco0000om6maol00004om2la`04o`000?o@_<Oo0000olfjb0;o00000oo@
^L<01?l0003od;W4om2ia?o@^L@3o`000003olbea?l0003o000000CockBo00?o0000oljd`Oo>]<40
0_l000001?o:/L7o0000olj`_Ol00004olfa_P03o`000?o</;koc;2n00?o00001?o;[K`01?l0003o
bZblolZ/_?o:[;`2o`0000;obJZj1?l00002olFV^P03o`000?o5Y[[o000000;oaZJi00?o0000olJU
^?o6YKP00oo6YKP2o`0000;oa:>h1Ol00002ol2O]`03o`000?o1X;Oo`J2g00?o`J2g00Co0000okfL
]onmW;Oo00000_nnWKH00ol0003o_IfgokfM]`03okfM]`04o`000?nkV[Ko^iZfok^J]Pgo000000Go
^9Jdo`000?nfUKGo]YFeo`000004okFC]003o`000?ncT[Co000000;o/i6d4Ol00002ojj@]`04o`00
0?n[SKKoZhffoj^=]P;o00000_n/SkL00ol0003oZHbgojV<]`04ojV<]`;o00001OnWRkP8o`000003
ojF;^Ol0003oXXVi00GoXXVi00?o0000oin7^OnOQkT00onOQkT4o`0000CoWHRl00?o0000oi^6_?nK
Q[`00onKQ[`4o`0000GoVHFm00Co0000oiJ4__nFQ;koUXBn0ol000000onEQKoo0000o`000003oiJ7
`P03o`000?nCQl?oThO300;oThO300?o0000oi>7`ol000001onCR<D2o`0000CoT8S700?o0000oi6;
bOnARlT00_nARlT00ol0003oTHg<o`000006ohj;c0CoT8o>0on@T]400ol0003oT9;Aoi2Bd@04oi2B
d@03o`000?n>U=CoSYCD00CoSYCD00Co0000oi:IeonBVMOoTYWG2?l00003oi>Uh@03o`000?nJZ>3o
VZSP00CoVZSP00?o0000oi^^i?nK[^@00ol00003oifik003o`000?nR`o3oX/?`00?o00000onVb_<0
1Ol0003o[=Ofo`000?l0003o/]Sc00?o00000onoh_02o`000003okcmdol0003ooo]Z07Sooo]Z00?o
0000oookJ_oonfX01?oonfX1o`00007ooo]Z0OoonfX000;ooo]Z00?o0000oookJ_oonfX03?oonfX0
1?l0003ol9YMo`000?o`Xg<3o`0000;okJV30ol00002onZ/SP04o`000?oV[iWoiZnIo`0000;oiZfH
00Go0000on>_WooS[ioo0000on:^W`02o`0000?oh;2T0_l000002OoN/JSo0000omj`Z?oN/:So0000
omb^ZOl0003of[6^o`000002ol?6g003o`000?o:a]Oo000000;o000000?obLKFo`000?l000001?o9
aMH2o`000003olo4d?l0003ocL?A00?ocL?A00Co0000olg3dOo=`m7ocL?A0_l00003olo0b`03o`00
0?o@`<_od<3;00;od<3;00Go0000oljoc?l0003oc;g<o`000004om2la`04o`000?o@_<Ood;c7om2l
a`;o000000Coc;W8o`000?o@^L?o00000oo@^L@01?l0003ockS4olnha?o?^<@3o`0000?ockBo00Co
0000oljd`Oo>]<7o00000_o=/l400ol0003ob[71o`000004olfa_P06o`000?o</;koc;2nolb`__l0
003ob:fo0ol000000oo;[Kco0000olZ/_002olZ/_006o`000?o6ZKcoaZVlo`000?o9Z[[o00000oo8
ZK/00ol0003oaJJjo`000002o`000003olJV^Ol0003oaZFh00CoaZFh00?o0000ol6R^Ol000000_o4
XkP00ol0003o`j>iol>S^@02ol>S^@?o00001?o1X;L00ol0003o_IbgokfL]`02okfL]`;o00001_nm
WKL00ol0003o^iZfok^J]P02ok^J]P05o`000?nhUkKo^9NfokRG]_l000000_niV;H00ol0003o^9Rg
okRH]`02okRH]`ko00001?ncTkL00ol0003o/96gok2A]`05ok2A]`03o`000?n^T;Oo[Y2g00Go[Y2g
0ol00005ojb?]`03o`000?nYS;OoZHbg00;oZHbg00?o0000ojV=]ol000000_nWRkP3o`0000;oYh^h
0ol00004ojF;^@03o`000?nRRKWoXXVi00CoXXVi00?o0000oin7^OnOQkT00ol00002oj29^`03o`00
0?nMR;coWHRl00CoWHRl00?o0000oi^6_?l000000_l00002oi^6_004o`000?nIQKgoVHFmoiV5_@Oo
00000onGQl07oiJ7`P03o`000?nCQl?o000000CoThO300?o0000oi>8aOnCR<D00onCR<D2o`0000Ko
T8S700Co0000oi6;bOnARlWo00000onASL`00ol0003oSX_<ohj;c003ohj;c0?oT8o>0_n@T]4Eo`00
00?oTYcJ00?o0000oi>UhOnCYN401OnCYN401Ol0003oVZSPo`000?l0003oVZSP00Co00001onM^N`2
o`0000OoY/[c00Co0000ok;Hlonbf??o00001Onoh_001?ncm?;o0000o`000?n]l:MjoookJP03o`00
0?oonf[ooo]Z00Cooo]Z0Ol00001oookJP7ooo]Z0002oookJP03o`000?oonf[ooo]Z00cooo]Z1Ol0
00001_o_Xg?o0000o`000?o]ZH?o0000onbXP`;o000000CojZb>o`000?l0003o00000ooV[IP3o`00
00?ohZjO0_l000001?oP/:Co0000omn_Y?oO[j@4o`000004omf_Z?l0003o0000o`0000;o`lKL0ol0
0003olW6eP03o`000?o9aMKobLGF00?obLGF0oo:aMD2o`0000?ocL?A00Go0000olg3dOo=`m7ocL?A
o`000002olc2d@03o`000?o?`<_o000000Cod<3;00Co0000oljoc?o>_lcoc[o<0_l00003om2la`05
o`000?o@_<Ood;c7om2laol000000_o>^lP00ol0003oc;W8o`000003om2ia003o`000?o?^<CockS4
00;ockS400Ko0000olfga?l0003o0000olnd_ol00002oljd`@03o`000?o=/l7ocK?100;ocK?11?l0
00000oo=/Kko0000olb`_P02olb`_P06o`000?o8[Koob:foolR]_ol0003objjl0ol000000oo:[;co
0000olJY_003olJY_003o`000?o8ZK_ob:Vk00?ob:Vk00?o0000olBV^oo4Y[/01Ol00002olJU^004
o`000?o1X[Wo`J:iol6R^@;o00001Oo3XkT00ol0003o_inho`000007o`0000;o_Ibg00?o0000okfM
]onmWKL01?nmWKL2okbJ]P04o`000?nkV[Ko^iZfo`0000Go^9Nf0_l00006okRH]`03o`000?nfU[Oo
]YJg00Go]YJg00?o]IBfok>C]oncTkL01OncTkL00onbTkKo0000ok2A]`05ok2A]`;o00001on^T;L0
0ol0003o[8ngojb?]`05ojb?]`06o`000?nYS;OoZHbgojV<]ol0003oZHfg1?l00004ojN;^0;o0000
1onURkT01?l0003oXXVioj:9^OnRRKT5o`0000GoX8Vk00?o0000oif8_?nMR;`00onMR;`3o`0000;o
VhJl1ol00003oiV8_`;o00001OnGQl000ol0003oUXO2oiJ7`P03oiJ7`P;o00001_nCQl<00ol0003o
ThS5oi>8a@02oi>8aAOo000000CoT8o>o`000?l0003o00000onBT]001?l0003oT9?Coi2Cdol00003
oi2Dd`03o`000?nCVMKoTiWF00CoTiWF00?o0000oi:KfOl000001OnBW=X01?l0003oTjGQoi>UhOnC
YN42o`000003oi>UhOl0003o000000;oVZ_S00Go0000oiZ[honJZn?oVZ_So`000002oifik0?o0000
0onP_nl00ol0003oY/[cojK:l`03o`0000?oZM;e00?o0000okKMlol000000_noh_000ol0003o/oCb
ok?dlP02o`000003ojg`Yol0003ooo]Z07[ooo]Z00?o0000oookJ_oonfX00ooonfX1o`00007ooo]Z
0OoonfX000;ooo]Z00?o0000oookJ_oonfX03?oonfX3o`000005onnIG_l0003okj=co`000?o^XW@0
0_l000000oo/Z8?o0000on^WQ005o`0000;oiZfH00Co0000onF/V?l0003o00000_oR[Yl01?l0003o
hZfNo`000?l00002omn_Y003o`000?oO[Z?ogjjS00?o000000?o`lKLo`000?l000000_l00002ol?6
g003o`000?o9a]Ko000000CobLGF00?o0000ol[5eOo:aMD00_o:aMD01Ol0003oc/?@o`000?o=`m7o
000000?ocL?A00?o0000olc2dOo<`]400_o<`]42o`0000?od<3;00Go0000oljoc?o>_lcoc[o<o`00
0002olfnc003o`000?o@_<Oo000000?od;c700?o0000oljkb?o>^lP00_o>^lP3o`000003om2ia?l0
003ockS400?ockS400Co0000olfga?o=]lCocKO40ol000000oo>]<7o0000olfc`@04olfc`@04o`00
0?o9/<;o0000olfa_`?o000000?oc;2no`000?o8[Kl01?o8[Kl01?l0003obZbkolZ/^oo:[;/3o`00
00;oaZVl0_l00004olRY^`03o`000?o4Y[_oa:Jk00;oa:Jk00Co0000olJU^Oo6YKWoaZFi1?l00002
ol6R^@03o`000?o3XkWo`j>i00?o`j>i00Oo0000oknO^?noWkSo_inho`000?o1X;So000000Co`:2i
1Ol00003okfM]`?o_9Zf00?o0000ok^J]_l000001_nhUkH00ol0003o^9RgokRH]`05okRH]`03o`00
0?nfU[Oo]YJg00Co]YJg0_neU;H00ol0003o/i>gok>C]`03ok>C]`;o/Y>f00?o0000ok2A]on`TKL0
0on`TKL00ol0003o/96fo`000006ojj@]`;o00001?n/SkL9o`0000;oZHji00?o0000ojN;^?nWRkP0
0_nWRkP00ol0003oYhfjo`000005ojF;^@Ko00000_nRRKX00onSRk_o0000oj29^`06oj29^`03o`00
0?nMR;coWHRl00Oo00000onLRKh00ol0003oVHRooiV8_`02oiV8_`;o000000?oVXRoo`000?nGQl00
1OnGQl03oiJ7`P;o000000?oUXW3o`000?nCQl<00onCQl<8o`0000;oU8_700?o0000oi6;bOnARlT0
0onARlT2o`0000GoTXk;00?o0000oi2>c_n@S/h01?n@S/h00ol0003oTY;@oi:Bd005oi:Bd0;o0000
1On@U=<00ol0003oTiWFoi>IeP04oi>IeP04o`000?nBW=[oTYcJoi:LfPOo00001?nJY]h00ol0003o
VZ_So`000003oiZ[h`Co00001onP_nl2o`0000;oZM;e0ol00002ojgJm`03o`000?noh_3o000000;o
000000?o__G`o`000?l000000_l0001moookJP03o`000?oonf[ooo]Z00;ooo]Z0Ol00001oookJP7o
oo]Z0002oookJP03o`000?oonf[ooo]Z00gooo]Z1_l00002onjRM0?o00000_o[Yh@3o`000003onNY
T?l0003o000000;oiJbH00Co0000onB[V?l0003o00000_oR[Ih01?l0003ohJbNo`000?l00003omn^
X`Co000000?o`lKLo`000?l000001?o3a]`00ol0003obLGFolW5eP02olW5eP03o`000?o:aMGob/GE
00;ob/GE0_o8`mH00ol0003oc/?@o`000003olg3d@03o`000?o<`]7oc<;A00;oc<;A00Ko0000ol[0
dOl0003o0000om30bol00003oljoc004o`000?o=_/cocKk<olfnc0Co000000?od;c7o`000?o>^lP0
0oo>^lP01?l0003obkW8ol^ib?o;^LP2o`0000?ockS400Go0000olfga?o=]lCocKO4o`000002olZd
a@?o00001?o=/l401Ol0003obK32olV``_o9/<;o000000?oc;2n0_l00004olR]_`;o00000oo:[;/0
0ol0003obJfmolV]_@05o`0000;ob:Vk00?o0000olBV^oo4Y[/00oo4Y[/01Oo3YKco0000olJU^Oo6
YKWo000000?oa:Jk0ol00004ol>S^@03o`000?noWkSo_inh00?o_inh00?o0000ol2P^Oo0X;T00oo0
X;T00ol0003o_9fho`000002okfM^0_o00000onhUkH2o`0000Ko^9Rg0_ngUkH00ol0003o]YJgokJF
]`02okJF]`Co]IBf00Co0000ok>C]oncTkOo/i>g1?nbTkH01Ol0003o/96gok2A]on`TKOo000000?o
/96f00?o0000ojj@]on^T;L02Ol00003ojb?^0;o00001_nYS[T00ol0003oYh^hojN;^002o`0000?o
Yhfj00?o0000ojF;^Ol000000_l00002ojB;^P03o`000?nRRK[oXXVj00CoXh^k00?o0000oj29^onP
RK/01OnPRK/00ol0003oWHRlo`000002o`0000;oWXZn00?o0000oib9__nLRKh01?nLRKh00ol0003o
VHRoo`000004oiZ8_`03o`000?nGQl3oUhO000?oUhO00_l000000onFQl;o0000o`000007o`0000;o
U8W50ol00005oiB;a`04o`000?nARlWoTH_9oi6;b@;o000000?oTX_9o`000?nBS//01OnBS//00ol0
003oT8k>oi2>cP04oi2>cP03o`000?nBT]3oTY;@00CoTY;@00?o0000oi2Ddon@U=<00_n@U=<=o`00
00?oU:CP00?o0000oiZVg_nJY]h01_nJY]h00ol0003oVZ_So`000002o`0000?oW;KZ00?o0000oj2o
konP_nl00ol00002ojC6l@04o`000?nYd_Go0000o`0000Co[M[g1?l00002okkel0Co0000OooonfX0
1Ol0003ooo]ZoookJ_oonf[o000000;ooo]Z0002oookJP03o`000?oonf[ooo]Z00gooo]Z1ol00000
1?o^XWCo0000onfQMOl00002on^WQ0?o00000_oWZI04o`0000;oi:^H00Co0000on:]W_oR[Iko0000
0_oQ[9h5o`000004ok_6h_l0003o`lKLo`0000Co`lKL00Oo0000ol?5g?o3aMco`/GLo`000?o9aMKo
000000Cob/GE0oo8`mH2o`000004olg3d?l0003ocL?Ao`0000Coc<;A00Co0000ol[0dOo:`=7ob/3A
0_l00003oljoc005o`000?o=_/cocKk<olfnc?l000000_o;_<`01?l0003ockc8o`000?l00003oljk
b003o`000?o;^LSobkW800;obkW800Go0000olnha?l0003ockS4o`000003olfga003o`000?o:]<Go
b[C500;ob[C500Ko0000olfc`Ol0003o0000olfc`Ol00003olV``P;o00000oo</;h02?l0003obk2o
o`000?l0003ob:foo`000?o6[;oo00000_o:[;/00ol0003obJfmolV]_@02olV]_@03o`000?o5ZKgo
aJVm00Co00001?o4Y[/2ol>U_003o`000?o6YKWo000000Goa:Jk00?o0000ol6R^_l000001_l00002
oknO^0;o00001?o0X;T01ol0003o_9fhokbM^?nlWKSo0000okfM^?l000001_nmWKT01?l0003o^Y^h
okZK^?njVkPHo`000003ok>C]ol0003o000000oo00001?n^TKT00ol0003o[8nhojb?^002ojb?^0;o
000000?o[92io`000?nYS[T01_nYS[T2o`0000;oYhfj1Ol00004ojB;^P;o00001onSRk/01?l0003o
X8Vkoj29^onPRK/5o`0000GoWXZn00?o0000oib9__nLRKh00onLRKh2o`0000OoVXRo00?o0000oiN7
`?l000000_l000000onHRL;o0000oiN:a005oiN:a003o`000?nDRLGoU8W500;oU8W500?o0000oiF:
aOl000001onDRlL00ol0003oTH_9o`000004oi:;b@03o`000?nBS/_oTXk;00CoTXk;00Co0000oi2>
c_n@S/koT8k>3_l00003oiBIe@07o`000?nCVmSoTi_Hoi>Kf?l0003oTi_Ho`000007oiBTh004o`00
0?nJY]koVZKNoiZVgP;o000000CoVZKNo`000?l0003o00001onL]^X2o`0000KoY<Ka00?o0000ojgJ
mon]f_L00on]f_L3o`0000?o`>Oa1?l00020oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX0
00;ooo]Z00?o0000oookJ_oonfX03OoonfX9o`000004onfQMOl0003o0000o`0000;ojZJ40_l00000
1OoWZI3o0000onJXT?oVZ93o000000;oi:^H0ol00002on6/WP?o00001?nka^82o`0000?o`lKL0_l0
0004ol?5g0;o00001?o:aMD3olS3eP04o`000?o7`mKoal?FolO3eP?o00000oo<`]401?l0003ob/3A
ol[0dOo:`=42o`000004oljoc?l0003oc[o<o`0000?ocKk<00?o0000ol^lc?o;_<`00_o;_<`01_l0
003ock_7olnkaol0003oc[_8o`0000GobkW800?ob[S8o`000?o?^<@00ol000000oo=]lCo0000olZd
a@03olZda@;o00000oo=/l43o`000007olV``_l0003ob;32olR``_l0003oc;2no`000004ol^`_`?o
000000?oaZboo`000?l000001?o9[Kd00ol0003oaJVmolFY_@02olFY_@03o`000?o7Z;_oajRk00;o
000000?oa:Jko`000?o3YK`00_o3YK`00ol0003oa:JkolBV^`03olBV^`06o`000?o1X[[o`J:jo`00
0?o3XkWo00001?o2XkX5o`0000;o`:2i00?o0000okbM^?nlWKP00onlWKP00ol0003o_IfiokfM^@05
okfM^@03o`000?njVkSo^Y^h00;o^Y^h00Go0000okRH]onhV;Oo^9Rgo`000002okRH]`03o`000?ng
VKWo]iVi00?o]iVi0_l00006okFG^003o`000?nbUKSo/YFh00Go/YFh0_l00006ok2C^003o`000?n^
T;Oo000000Go[Y6i00Go0000ojb?^?n/SkSo[8nho`000003ojb@^@03o`000?nYS[WoZHji00CoZHji
1Ol00003ojN=^P04o`000?nTRk[oY8^jojB;^P;o000000?oYHfko`000?nSRk/01OnSRk/5o`0000;o
X8Vl00?oXH^mo`000?nNR[h01_nNR[h00ol0003oW8Vno`000002o`000003oib9__l0003oVXRo00?o
VXRo1Ol000001_nHRL;o0000o`000?l0003oV8[3o`0000KoUh[400?o0000oiB9aOl000001?nER/D0
0ol0003oU8_7oiB;a`04oiB;a`04o`000?nBRlWoTX_9oi:;b@ko00000onDTm001?l0003oTYCBoi:D
d_l00003oi:DdP03o`000?nDVMGoU9WE00CoU9WE00Co0000oi>Kf?nCVmSo00000onCVmP00ol0003o
U:CPoiBTh002oiBTh0;o000000KoU:CPo`000?l0003o0000oif[hOl00003oiVYhP03o`000?nL]^[o
W;KZ00?o00000_nO_>d00ol0003oY<KaojC6l@03o`0000?oYlkd00Go0000ojgJmol0003o0000ok?I
m002o`0000?o`>Oa00?o[oO^o`000?l00000PooonfX01?l0003ooo]ZoookJ_l00002oookJP000_oo
nfX00ol0003ooo]ZoookJP0>oookJP?o000000?oiWhco`000?o/TUT01?l000001_o/X7Ko0000o`00
0?oZYXCo0000onRTQ0;o00000_oVZ903o`0000;ohjZH1?l00002ok_6hP04o`000?nka^;o0000o`00
00;o^lGR00?o0000ol?6g?l000001?o3aM`01Ol0003o`/CKol;4foo2a=_o000000;ob/GE0_o8`mH2
o`0000Coal?F0_l000001?o<`]3o0000olc2dOl00003ol[0d@05o`000?o9_m7obKoAo`000?o>_l`0
0ol000000oo=_/co0000ol^lc003ol^lc003o`000?o9^lco000000;ock_70_l00004ol^ib0?ob[S8
00Co0000olfga?o=]lCocKO40_l00003olZda@03o`000?o9/lGobK?500;o00001?o;//400oo9/<;o
0000olR``P02olR``P03o`000?o;/;oobk2o00;obk2o00Co0000olV__oo9[koobJno1Ol000000oo9
[Kgo0000olFY_@04olFY_@03o`000?o7Z;_oajRk00;oajRk0ol00002ol>U_003o`000?o4Y[_oa:Jk
00;oa:Jk00?o0000ol6R^_o1X[X00_o1X[X00ol0003o`Z>jol:S^P04ol:S^P03o`000?nnWk[o_Ynj
00Ko00000_nlWKP2o`0000Ko_Ifi0_nkVkP01?l0003o^Y^hokZK^?l00005okRH]`;o00001_ngVKT0
0ol0003o]INhokFG^005okFG^003o`000?nbUKSo/YFh00Go/YFh00?o/YBho`000?n`TkP01On`TkP2
o`0000Oo[Y6i00?o0000ojb?^?l000001On/T;T00ol0003oZHjio`000003o`000003ojV?^ol0003o
Yhfj00KoYhfj00?o0000ojB;^_l000001?nUSK/00ol0003oXh^koj>;^`03o`000004oj:;^ol0003o
0000oj29_0GoXH^m00?o0000oij:__nNR[h00onNR[h3o`0000;oW8Vn1ol00003oiZ:`@?o00001?nH
R/<00ol0003oUh[4oiN:a003oiN:a0;o00001?nER/D=o`0000?oUHo;00?o0000oi:@cOnBT<d00_l0
0002oi:@c@03o`000?nDTm3oU9?@00GoU9?@0_l00005oi:DdP03o`000?nDVMGoU9WE00CoU9WE0_l0
0002oi>Kf0Oo00001?nGZ>82oif[h@03o`000?nIZN;oVJWR00Go00001_nO_>d2o`0000OoYlkd00Co
0000ok?Im?ncfOCo00000_o0io400ol0003o[oO^ojogkP02o`0008Gooo]Z00?o0000oookJ_l00000
0_oonfX000;ooo]Z00?o0000oookJ_oonfX03_oonfX2o`000003om9I0?l0003o000000Go000000?o
k:1fo`000?l000000_l00002onRTQ0?o00000_oUYi06o`0000Co^lKR00?o0000ok_5h_nkaN800_nk
aN82o`0000?o`lGL0_l00005ol;4f`;o000000?ob<?Fo`000?o7`mH01?o7`mH01_l0003oa/;FolK2
e_l0003oc<;@o`0000?ob/3A00Co0000olVodOo9_m7obKoA0_l00003oljnc0;o00000oo;_<`01Ol0
003obK_<olVkc?o9^lco000000?ocK[700?o0000ol^ib?o;^LP00oo:^<P2o`0000?ocKO400Go0000
olbfa?l0003ob[C5o`000003olVca@03o`000?o;//7obk;100;obk;100?o0000ol^c`oo;/l<00_l0
00000oo8/<;o0000ol^`_`02ol^`_`03o`000?o9[koobJno00;obJno00?o0000olF/`?l000000_o9
[Kh2o`0000CoaJVm00?o0000olBX__l000000_o7Z;/01?l0003oaZVmolJY_Oo6ZKd5o`000003olBV
^ol0003o`J:j00Co`J:j00?o0000ol:S^_o2XkX00oo2XkX01?l0003o_YnjokjO^_nnWkX2o`0000Co
_j6j1_l00003okfM^@?o^i^h00?o0000okZK^?l000001_nhV;L00ol0003o]iViokNI^@04okNI^@;o
00001_neUkP2okBF^003o`000?nbUKSo/YFh00?o/YFh0_nbU;P00ol0003o/9>hok2C^003ok2C^003
o`000?n`T[So000000Oo[Y6i2ol00005ojV?^`03o`000?nWSK[oYhfj00?oYhfj0_l00005ojF=^`Co
00000_nRRk/2o`000003oj>=_Ol0003oXH^m00GoXH^m00?o0000oij:__nNR[h02?l00003oif;`@03
o`000?nJR/7oVX[100;oVX[10_l000000onKRl7o0000oiR:``05oiR:``04o`000?nGR/CoUh[4oiN:
a0Oo00000onGSLL00ol0003oU8g9oiB=b@02o`000003oiB=bOl0003oUHo;00KoUHo;0_l00005oi:@
c@03o`000?nDTm3oU9?@00CoU9?@00Co0000oi:Dd_nBU=;oTYCB3_l00003oiFSgP03o`000?nGZ>;o
UjSR00KoUjSR1?l00003oif_i003o`000?nO_>goWkc]00?o00000onR`o000ol0003oYlkdojO>m003
o`0000?oZmOg0_l000000oo0io7o0000o`000002ojogkP;o0000Q_oonfX01?l0003ooo]ZoookJ_l0
0001oookJP000_oonfX00ol0003ooo]ZoookJP0?oookJP?o000000GodeX0o`000?oVOSKo0000on^B
G003o`0000;ojied00Go0000onRTQ?oXY8Co0000onRSQ@04o`000003onBVT?l0003o000000;o[lCY
00?o0000ok_6h_l000000_nkaN801?l0003o^lGRo`000?l00002ok[5hP03o`000?o3aMco000000Go
`/CK00?o0000ol;4foo2a=/00ol00003olO3eP;o00000oo6`]H2o`000004olc1d?l0003ob/3Ao`00
00?obKoA00_o0000olRndOo8_]7ob;kAo`000?o>_/co0000olfmc?l0003obkc<o`000004olVkc003
o`000?o=^/OocK[700;ocK[700GobkW8o`000?l0003ob[S8o`000002olVgb@03o`000?o=]lCo0000
00?oc;K40ol00002olVca@05o`000?o;//7obk;1ol^b`Ol000001Oo;/l<3o`000003ol^`_ol0003o
bJno00?obJno00Co0000olF/`?o5[<3oaJc00_l00002olN[_@;o000000OoaJVmo`000?o4Z;koa:Rn
o`000?o7Z;_o000000CoaZVm00Go0000ol:U_Oo2YKgo0000olBV^`04o`0000;o`J:j00?o0000ol6S
^ol000000oo2XkX00ol0003o_YnjokjO^P02okjO^P03o`000?noXK[o_j6j00?o_j6j00Co0000ok^M
^_nkWK[o00000_nlW[T;o`0000?o^9Rg0_l00005okNI^@04o`000?nfUkSo]YNho`0000Co]INh0ond
U[P00ol0003o/YFhok:E^002ok:E^0Co/YBh00Co0000ok2C^?l0003o/9>h2Ol000000on^TKWo0000
o`000006ojb@^P;o00001onYSk/01?l0003oYhfjojN=^_nWSKX2o`000004ojN?_?l0003oYHfkojF=
^`?o00000_nUSK`00ol0003oXX^ko`000004oj>=_@03o`000?nQRkgoXH^m00?oXH^m1?l000000onN
R[ko0000o`000002oin<`003o`000?nMRl7oWH_100CoWH_100?o0000oiZ:`Ol000001OnKRl400ol0
003oV8[3oiR:``08o`0000;oUhc62?nGSLL2o`0000CoU8g900?o0000oiF?bonESl/00onESl/2o`00
00CoTY3=3Ol00003oiBKf0CoUicG0_l000000onDVmSo0000oiFSgP06oiFSgP03o`000?nGZ>;oUjSR
00?o00000_nMZ]l00ol0003oWJoToif_i003oif_i0Co00001onR`o02o`0000?oZmOg0ol000000one
iOKo0000o`000002ojogkP?o0000R?oonfX00ol0003ooo]Zo`000001oookJP0000?ooo]Zo`000?oo
nfX04_oonfX8o`000004on^BGOl0003o0000on^MM0Ko000000Coij:5o`000?l0003o00001On_a>T0
0ol0003o^lGRok_5hP02ok_5hP03o`000?njaN;o^/GR00;o^/GR0_l00004ol;4f`03o`000?o2a=_o
`/CK00?o`/CK00Go0000olS4e_l0003oal?Fo`000004olK2eP05o`000?o5`MKoaL7Fo`000?o<`M00
0ol000000oo9_m7o0000olRnd@03olRnd@;o00000oo=_L`2o`0000?obK_<00Go0000olRjcOl0003o
cK[7o`000004olbib0;o00000oo9]lT01Ol0003oc;K4olbfa?o<]/Co000000?oc;O61?l000000oo;
//7o0000ol^c``04ol^c``03o`000?o7[l?oajo300Co00000_o9[kl00ol0003oaJc0olF/`002olF/
`003o`000?o7Zkgoaj^m00?oaj^m00?oaJVmo`000?l000000_o4Z;h00ol0003oaZVmolJY_@02olJY
_@03o`000?o2YKgo`ZFm00;o`ZFm00?o0000ol>V_?o3Y[`00_o3Y[`6o`000003ol:S^_l0003o_Ynj
00?o_Ynj0_l00004oknQ^P03o`000?nkWK[o^ifj00;o^ifj0_l00007okbN^P04o`000?njV[So^YZh
okZJ^1So000000?o/YFho`000?l000001_l00005ok2D^P03o`000?n^TKWo[Y6i00;o00000on]Tk/0
0ol0003o[92jojb@^P02ojb@^P03o`000?n/T[_o000000OoZHnk00Go0000ojN=^_nWSK[o0000ojN?
_005o`0000CoYHfl0_l00007oj>=_@03o`000?nQRkgo000000;o000000CoXHbno`000?l0003o0000
1OnOS<000ol0003oWH_1oif;`@03oif;`@;o00001OnKRl45o`0000?oVHc50_l00006oiN<aPKoUhg7
0_l00005oiB=b@03o`000?nESl_oUHo;00Wo00000onFU<l01?l0003oU9GBoiBEd_l00002oiBEdP03
o`000?nDVmSoU9_H00GoU9_H0_nGW=L00ol0003oU9_HoiBKf002oiBKf003o`000?nEXmkoUJ?N00;o
UJ?N0_l000000onEXmko0000o`000004oifZg`04oib_i?l0003oWJoToif_i0?o00000onO^^`00ol0
003oX/?`oj;3l003o`0000?oY/_c00Go0000oj_Gmol0003o0000ojkOn003o`0000;o_>Cc1?l0002:
oookJP;o00000OoonfX00003oookJ_l0003ooo]Z01Cooo]Z00?o0000o`1UeOl000001Ol000000ooZ
TEko0000o`000007o`0000?o[lCY0ol00002ojo3j@03o`000?nkaN;o000000;o^lGR00Co0000ok[5
h_l0003o00000_nja>801?l0003o`/CKo`000?l00004ol;4f`06o`000?o2`m_o`/?Ko`000?o8a=Ko
00000oo6`]H2o`0000?oaL7F0_l00003ol_0d0;o00000oo8_]401_l0003oakgAolNmdOl0003ocKg<
o`0000;obkc<00?o0000olVkc?l000000oo8^/d01Ol0003oc;W8olbib?o<^LSo000000?obkS800Oo
0000olVgbOl0003ob;K9o`000?o<]/Co000000Coc;O600?o0000ol^fa_o;]/H00_l00005ol^c``04
o`000?o7[l?oajo3olN_``;o00000_o9[kl3o`0000CoaJc000Go0000olN[_Oo7Zkgoaj^mo`000004
olN/_`Go000000?oaZVmo`000?o2YKd00oo2YKd2o`0000Co`jJl00?o0000oknS_?noXk`00_noXk`6
o`000004okjO^_l0003o0000o`0000;o_j6j00?o0000ok^M^_nkWKX00onkWKX00ol0003o_9jjokbN
^P05okbN^P;o^I^j00Go0000okZJ^?njV[So^YZho`000003okVL^`04o`000?ngVKWo]iVio`0000Co
]iZj00?o0000okFG^Ol000001_ndV;X2o`0000Ko/YJj0_l00007ok2D^P;o00001On]Tk/01Ol0003o
[92jojb@^_n/T;[o000000?o[9:k00Co0000ojV?^onYSk_oZHnk0_l000000onYSk_o0000o`000003
o`0000?oYhnl00Co0000ojF=_?nUSKcoYHfl0_l000000onUSkgo0000oj>=_@04oj>=_@Co00000_nQ
S;h2o`000003oj6>`?l0003oWhc000KoWhc000?o0000oif;`Ol000000_l000001?nMRl7o0000oi^;
`OnKRl43o`0000;oVhg400Co0000oiV<aOnIS<GoVHc50_l000000onISLGo0000oiN<aP05oiN<aP?o
Uhg70ol000000onGSlWo0000oiB=b@02oiB=b@Ko00001?nETLh00ol0003oUYC?oiJDc`05oiJDc`;o
00001?nDUM800ol0003oU9_HoiBKf002oiBKf0;o000000?oU9_Ho`000?l000002Ol00004oiNWh@05
o`000?nMZ]ooWJ[OoifZgonL[n@01?l00007oinjk0;o00001onVbo<01?l0003o[]ohojkOn?l00004
okcTl`04ojcelOl0003o_ocUo`0008[ooo]Z0ol00001oookJP0000?ooo]Zo`000?oonfX05OoonfX=
o`0000GoVkoa0_l00006ojo3j@03o`000?nkaN;o^lGR00;o^lGR0_l00003ok[4hP;o00001?o2a=/0
0ol0003o`/?Kol;3f`03ol;3f`05o`000?o8`mKo0000olK2e_l000001?o5`MH01_l0003oaL3FolG0
e_l0003obl3@o`0000;ob[o@00?o0000olRndOl000000oo7_M42o`0000Cobkc<0ol000001_o8^/go
0000olNjcOl0003oc;W8o`0000GobkS80ol000000oo8]/Wo0000olbgaP03olbgaP03o`000?o;]/Ko
bkK600;obkK61?l000000oo;/l?o0000olN_``03olN_``;oaZo400Go0000olV__oo9[koo0000olR^
`002o`000006olF/`?l0003oa:_1o`000?o7Zkgo00001Oo7[;l00ol0003o`jRoo`000002olFY_P?o
00000_o2YKd00ol0003o`ZJmo`000003ol>V_003o`000?noXkco_j>l00?o_j>l00?o0000ol6R^_o1
X[X00_o1X[X01?l0003o_jBmoknT_OnoY;d6o`0000;o^ifj0_l00006okbN^P?o^I^j00Co0000okZJ
^?njV[So00001OniW;/2o`0000Ko]iZj00?o0000okBH^_ndV;X01OndV;X00ol0003o/YJjok:F^P05
ok:F^P03o`000?n`U;[o/9Bj00Go/9Bj0_l00006ojfC^`03o`000?n/T;[o[92j00;o[9:k2Ol00002
ojVA_@03o`000?nWSkcoYhnl00GoYhnl00?o0000ojF=_?l000001?nUSkd00ol0003oXhfmo`000002
o`0000;oXhfn0ol00004oj6>`003o`000?nOS<3oWhc000?oWhc01?l00002oif;`@Go00001OnKSL@0
0ol0003oVHc5o`000005oiV=a@04o`000?nGS<KoUhc6oiN<aP?o000000?oUhg7o`000?l000001ol0
0003oiJ@b`;o00001_nETLh00ol0003oUYC?oiJDc`03oiJDc`;o00000onDUM87o`0000;oUY_G0_l0
0007oiNOfP03o`000?nGYn7oUjOQ00GoUjOQ00Co0000oifZgol0003o00000onM[^<00ol0003oWk[/
oinjk003o`0000?oX/7_00?o0000ojK;lonVbo<00ol00003ojWDmP05o`000?ndgoKo0000okcTlol0
00000_n/mO400ol0003o_ocUo`000028oookJP?o00001?oonfX00003oookJ_l0003ooo]Z01Kooo]Z
1Ol00003ofn^m`03o`000?mk/oOo000000;oVkoa0ol00002oi^ol@03o`000?n_`nWo[l?Y00?o0000
0on_`nT00ol0003o^lGRo`000002ok_5hP03o`000?nja>;o000000;o^LCR00Co0000ol;4fol0003o
00001?o2`m/01Ol0003o`L?Kol73fol0003ob<?F00;o00000oo5`MH01?l0003oaL3FolG0e_o5`=H2
o`0000Cob[o@00Go0000olNmdOo7_M7oakgAo`000002olJmd@03o`000?o;_<co000000Cob[_<0_l0
0002olNjc@03o`000?o;^<SobkS800;obkS800?o0000ol^ibOo;^LT00_o;^LT2o`0000?oc;O600?o
0000ol^fa_o;]/H00_o;]/H01?l0003oak?6o`000?o;/l@4o`0000;oajo30oo6[l@00ol0003obJno
o`000004olR^`0?o000000?oa:_1o`000?o7[;l01?o7[;l01?l0003o`jRool>X_oo3Z;l2o`0000?o
a:Nl00So0000ol:U_Ol0003o0000ol:V_Ol0003o`jJlo`0000Go_j>l00?o0000okjS_Ol000000_o1
X[X00ol0003o_jBmoknT_@03oknT_@03o`000?nnWk[o_Ynj00;o_Ynj1ol00002okbN^PCo^I^j00?o
0000okZJ^?l000001_niW;/00ol0003o]iZjokNJ^P04okNJ^P;o00001_ndV;X00ondUkWo0000ok:F
^P05ok:F^P03ok:E^_l0003o/9Bj00Co/9Bj0_l000000on`U;[o0000ojfC^`02ojfC^`03o`000?n]
Tk_o[I>k00Go00000on/T[`01?l0003oZHnko`000?l00004ojVA_@03o`000?nWSkcoYhnl00CoYhnl
0_l00004ojF?_@Co00000onSSKh2o`000003oj>?_ol0003oXHk000GoXHk000?o0000oin<`?l00000
0_l000000onOS<3o0000o`000003o`0000?oWHk300?o0000oi^=a?nKSL@00onKSL@2o`0000GoVHg5
1_l00002oiV?b0;o00001OnHT<T00ol0003oUY3;oiJ@b`02oiJ@b`;o000000?oUi7;o`000?nETLh0
1OnETLh00ol0003oUYC?oiJDc`08o`0000?oV9[D00?o0000oiJKeonFVmL00_nFVmL01?l0003oUYcG
oiJLeol00004oiNOfPOo00000onMZMl00ol0003oWJkSoif^h`03oif^h`Co00001onR`Nl2o`0000;o
ZMCf0ol00002ojcMn0;o000000?o[?Gao`000?ngmo000ol00025oookJPCo00001ooonfX00003oook
J_l0003ooo]Z01Cooo]Z1_l000001OlUR>_o0000o`000?l0003oKjkg00Co00001_nK_o42o`0000Oo
[l?Y00?o0000ok_5h_nkaN800_nkaN801?l0003o^LCRokW4h_nia>82o`0000Co`/?K0_l00004ol73
f`06o`000?o7`]Koal;Fo`000?o5`MKo00000oo5`=H01_l0003oa<3FolC0e_l0003ob[o@o`0000;o
bKk@00?o0000olNmdOl000000oo6_M42o`0000Cob[_<00Ko0000olVjc?o9^/co0000olNjcOl00003
ol^hb003o`000?o;^LWobkW900;obkW900Ko0000olNfbOo7]/Wo0000olbga_l00004ol^faP05o`00
0?o7/lKoak?6olNca_l000001?o9//<00oo7[l?o0000olJ_a003olJ_a003o`000?o8[/3ob:k000;o
b:k000Co0000olN_`_o7[l;oajo21?l00002olN/_`03o`000?o3Z;oo`jRo00;o`jRo00?o0000olBW
_?o4Yk`00_o4Yk`01?l0003o`jVool>Y_oo3ZKl6o`0000;o_j>l00Ko0000okjS_OnnXkgo0000ol6R
^_l00006oknT_@03o`000?nnWk[o_Ynj00;o_Ynj00Ko0000okfQ_OnmXKgo_J6mo`000?nlW[/<o`00
00?o^Ibk0_l00005okNJ^P04o`000?nfV;[o]YRjo`0000Co]9Rj0ondUkT00ol0003o/YJjok:F^P02
ok:F^P?o/YFj00?o0000ok2D^_l000002Ol000001On]Tk_o0000ojfD_On]U;go000000Ko[9:l0_l0
0007ojVA_@03o`000?nWSkcoYhnl00?o000000?oZ96no`000?nUSkd00ol00002ojF?_P04o`000?nS
SKkoXhfno`0000CoXhno00?o0000oj6>`?nQS/000onQS/03o`0000;oWhc00_l000000onOSl;o0000
oif>``06oif>``03o`000?nKSLCo000000;o000000CoW8g4o`000?nISLGoVHg50ol00002oiZ?a`04
o`000?nISlSoVHo8oiV?b0;o000000?oVHo8o`000?nHT<T01OnHT<T01?l0003oUY3;oiJ@bol00004
oiNAb`04o`000?nETLkoUI7>oiFAcPGo00001?nFUm800ol0003oV9[DoiRJe005oiRJe003o`000?nF
VmOoUY_G00;oUYcG1ol00003oiVWh003o`000?nMZMooWJWO00?oWJWO00CoWJkSo`000?nM[^?oWJkS
0ol00003oinij`03o`000?nR`NooX/7_00?o00000_nUbO801?l0003oZMCfo`000?l00003ojcMn0;o
00000_nih_@5o`0008?ooo]Z0ol0000;oookJP0000?ooo]Zo`000?oonfX04OoonfX3o`0000Gooo]Z
00Co05o?o`000?l0003o00000om][_P00ol0003oN[?go`000002oi^ol@?o00000_nK__400ol0003o
[l?Yojo3j@03o`0000?o[/?Y00?o0000ok_5h_l000000_nja>800ol0003o^LCRo`000003okW3hP03
o`000?o2`m_o000000Co`L?K00Co0000ol32foo0`]_o00000_o7`]H01Ol0003oaL3FolG0e_o5`=Ko
000000?oa<3F0_l00004olVnd0?o000000Coa[gAo`000?o5_=;o00000oo:^l`00ol0003obK[<olVj
c002olVjc0?o000000?obkS8o`000?o;^LT00oo;^LT01?l0003oakK9olNfbOo7]/T4o`0000;obkK6
00Co0000olNca_o7/lKoak?60_l00003olVb``03o`000?o8//Cob;;400;o000000?oaZo4o`000?l0
00000oo8[/001ol0003oajo2olN_`_o7[l;o0000ol>/`_l000000_o6[L04o`0000;o`jRo0_l00003
olBW_003o`000?o3ZKoo`jVo00?o`jVo0_l00003ol:U_0Go000000?o_Z>mo`000?noY;d01OnoY;d0
0ol0003o_:2lo`000002okjO^P03o`000?nmXKgo_J6m00?o_J6m00?o0000ok^O_?nkWk`01?nkWk`0
0ol0003o^9bko`000003okVL^a3o000000?o]9Rjo`000?l000001Ol000000onbU[[o0000o`000005
o`0000Go[iJl00?o0000ojfC^on]Tk/00_l00004ojfD_@03o`000?n/T[co[9:l00;o[9:l00?o0000
ojbD_Ol000001onYTKd01?l0003oYhnlo`000?nXTKh5o`0000GoYHnn0_l00007oj>?_`03o`000?nQ
S/3o000000Ko00001OnOSl800ol0003oWHk3oif>``03oif>``?o00000_nLSL@5o`0000GoVXo70ol0
0004oiV?b003o`000?nHT<WoV93900GoV93900Co0000oiNAbonGTL_oUi7;1ol00002oiREc`;o0000
1_nFUm800ol0003oV9[DoiRJe005oiRJe0Co00000onHXmd00ol0003oVJOPoiVWh005oiVWh005o`00
0?nMZMooWJWOoifYgonM[^<01?l00007oinij`;o00001_nUbO800ol0003o[=ghojcMn002ojcMn004
o`000?nih_Co^N;dokWRm0;oZO?c00?o0000ok;keOoonfX0P?oonfX4o`0000kooo]Z00000ooonf[o
0000oookJP0>oookJP?o00002OoonfX00ol0003o05o?o`000008o`0000KoVkka0_l00007ojk3j@03
o`000?nja>;o^/CR00;o^/CR0_l00003okW3hP;o00000oo1`m/2o`0000Co`<;K00Ko0000olK2e_o6
`]Ko0000olG0e_l00003olC0eP03o`000?o3_mOo000000?obKk@00Co0000olRmd?o8_M3ob;g@0_l0
0002olFldP03o`000?o:^lco000000?obK[<00Co0000olVlc_o9_<kobKc>0ol00003ol^ib@07o`00
0?o7]/WoakK9olNfbOl0003oa[K:o`000002ol^faPCo000000Ooak?6o`000?o5//OoaK;7o`000?o9
//?o000000Cob;;41Ol000000oo8[/3o0000olN_`P02olN_`P07o`000?o3[<;o`jc2ol>/`_l0003o
aZg0o`000003olFZ_`Go000000?oa:Nlo`000?o3ZKl01Oo3ZKl2ol2V_`04o`000?o2YKco`ZFlo`00
00Co`JJo1Ol00002oknT_@06o`000?nlX;co_:2lo`000?nnWk[o00001OnmXKd2o`0000Go^inl00Co
0000okRL^onhW;_o00000_niW;/2o`0000Co^9fm00?o0000okNJ^ol000001OnfVk`00ol0003o]9Rj
o`000005okBI_0;o00001onaUk`00ol0003o[iJlojnF_005ojnF_0;o00001_n]U;d01Ol0003o[9:l
ojbB_?n/T[co000000?o[9Bm00Co0000ojVA_OnYTKgoZI6m0_l000000onYTKgo0000o`000002o`00
00?oYi6n00Co0000ojF?__nUSkkoYHnn0ol000000onVTL3o0000oj>?_`04oj>?_`Co000000?oXHk0
o`000?l000000_nRT<800ol0003oWho2oin?`P04oin?`P03o`000?nMS/?oWHk300So00000onLSlH0
0ol0003oVXo7oiZ?a`02oiZ?a`;o000000?oVho7o`000?nISlP01OnISlP01?l0003oV939oiR@bOnH
T<T7o`0000SoV9G?00?o0000oiRHd_l000001?nFUm8;o`0000OoV:?M00Co0000oiVWh?nIYn3oVJOP
0_l000001?nIYn3o0000o`000?nMZMl2o`0000?oWJgS00?o0000oinijonO^N/00ol00002oj:okP03
o`000?nUbO;oYLWb00?o00001?nXdOH3o`000004okWRm?nYlo?oZO?cojWcl`;o000000?o/__Eoook
J_oonfX0OOoonfX3o`0001;ooo]Z00000ooonf[o0000oookJP0;oookJP?o00003OoonfX01?l0003o
05_;o`000?l00003of^^n003o`000?mj/oOo000000;oVkka0ol00002oiZnl@03o`000?n^`nWo[/?Y
00?o00000on^`^T00ol0003o^/CRo`000003ok[4hP03o`000?ni`n;o000000;o^<?R00?o0000ol73
fol000001?o0`]/01?l0003o_l;Koko2fol00002olK2eP?o000000?oa<3Fo`000?o3_mL00_o3_mL0
0ol0003obKk@o`000003olRmd005o`000?o7_M7oakgAo`000?o5_=800_l00003olVjc005o`000?o9
_<kobKc>olVlc_l000000_o6^Lh2o`000003ol^ibOl0003oakK900;oakK900Oo0000olJfb_o6]/[o
a[K:o`000?o;]/Ko000000?obKC600?oak?6o`000?o5//L00_o5//L00ol0003ob;;4olRba002olRb
a003o`000?o8//Gob;;500;ob;;51?l000000oo7[l;o0000ol>/`P03ol>/`P;o00001?o5Z[l01?l0
003oa:c2olB/`_o4[<85o`0000?o`jVo0oo0Y[l00ol0003o`ZFlo`000004ol6V_`03o`000?nnXkko
000000?o_jBm2_l00002okfQ_@04o`000?nkWkco^inlo`0000?o^inl00?o0000okRL^onhW;/00_nh
W;/2o`0000Oo^9fm00?o0000okJK_?nfVk`01?nfVk`2o`0000Ko]9Vl00?o/iRko`000?naUk`01Ona
Uk`2o`0000Ko[iJl0_l00007ojfD_@03o`000?n/T[co[9:l00;o[9Bm2Ol000000onYTkoo0000ojNA
_P06ojNA_P03o`000?nUSkko000000GoYY7000?o0000oj>?_ol000000_l000001?nSSl3o0000o`00
0?l00005oj:@`P03o`000?nOSl;oWho200?oWho21?l000000onNS/?o0000o`000002oij@a@03o`00
0?nLSlKoW8o600CoW8o600Co0000oiZ?aonJSlOo00001?nKSlL00ol0003oVHo8oiV?b009o`000003
oiVCc?l0003oV9G?00WoV9G?00?oV9SBo`000?l000001Ol00003oiVKe004o`000?nHW=OoV9cGoiRL
e`;o00000_nHWML01?l0003oV:?MoiRSgOnHXmd2o`000003oiRSgOl0003o000000;o00000onNZMh2
o`0000GoWJgS1?l00006oj:okP;o00000onXdOH3o`0000;oZ]_h00?o0000ojWclonYlo<00ol00000
0onbnmGo0000oookJP1koookJPCo00005OoonfX00003oookJ_l0003ooo]Z00Sooo]Z0ol0000Boook
JP[o00001_nJ__42o`0000Oo[/;Y00?o0000ok[4h_nja>800onja>82o`0000;o^<?R0_l00003ol32
f`;o00001?no`]/00ol0003oaL7FolG1eP02olG1eP;o00000oo3_mL2o`0000?ob;g@00?o0000olNm
dOo7_M400_o7_M42o`000004olBkd_l0003obK[<o`0000?obKc>00?o0000olJic_o6^Lh00_o6^Lh4
o`000003olNfbOl0003oa[K:00Coa[K:00?o0000olVda_o9]<H00_o9]<H01_l0003oak?6o`000?l0
003oaK;7o`0000?ob;;400?o0000olRbaOo8//D00_o8//D00ol0003oa:o5o`000002olN```?o0000
0_o3[<800ol0003o`Z_3o`000003olFZ_`03o`000?o4[<;oa:c200?oa:c200Co0000ol>Y`?o3ZL3o
`jW01?l00002ol2V_`;o00001?o1Y[l01ol0003o_Z>nokjS__nnXkko0000oknT_Ol000001OnnY;h2
o`0000?o_J:m1_l00002ok^O_003o`000?nhW;_o^9bk00?o^9bk00?o0000okRM_OnhWKd01OnhWKd2
o`0000Go]Y^l00?o0000okFJ^ol000001OndVK`2ok>H^`03o`000?naUkco/INl00?o/INl00Co0000
ok6G^onaUk_o00001?n_U[`00ol0003o[iJlo`000007ojfD_@Go00000on/U;d01?l0003oZI6mo`00
0?l00004ojVC_`03o`000?nWTKkoYi6n00?oYi6n0_l00004ojJA`0Go00000onSSl000ol0003oY972
o`000007oj:@`P03o`000?nOSl;o000000;o000000CoWho2o`000?l0003o00001OnNT<D00ol0003o
W8o6oib?aP03oib?aP?o00000onKSlL6o`0000?oVY;:0ol00005oiVCc003o`000?nHULooV9G?00;o
V9G?0_l00002oiREc`;o00000onHVM800ol0003oVI_DoiVKe005oiVKe0?o00000onHWML5o`0000?o
VZOO00?o0000oijYg_nNZMh01?nNZMh01?nN[^?o0000oif]honM[N<3o`0000;oWkSZ00?o0000oj:o
k_nR_nh00ol00003ojC7lP04o`000?nXdOKo0000o`0000?oZ]_h00So0000okOQm?nghOCo]n7do`00
0?ncm_7o0000ok;keG_ooo]Z0ol0000IoookJP0000?o0000oookJ_oonfX01OoonfX3o`0001Kooo]Z
1?l00003ofV^n@;o00000_nJ__43o`0000?oV[ka00?o0000ojk2jOn^`^T00ol00003ojg2j@;o0000
1?ni`n82o`0000;o]l;S00?o0000ol32fol000001?no`]/01_l0003o_l7Koko1fol0003oaL7Fo`00
00?oa<3F00?o0000ol>oeol000000_o2_]L00ol0003ob;g@o`000003olNmd@03o`000?o5^m7oaK_A
00;oaK_A0_l00003olVlcP03o`000?o6^Lkoa[W>00;oa[W>0_l00003olVhb@;o00001?o6]/X2o`00
00?obKC600?o0000olNca_o7/lH00_o7/lH3o`000003olRba?l0003ob;;500?ob;;500Oo0000olB_
aOo4[lGoa:o5o`000?o7/<?o000000;oaZg20ol00002ol:[``03o`000?o5Z[oo000000Goa:c200?o
0000ol6Y`_l000000_o3ZL001?l0003o`ZW1ol:Y`Oo2ZL44o`0000?o`JJo00?o0000okjS__nnXkh0
0onnXkh00ol0003o_ZBnokjT_P03okjT_P04o`000?nkXKko^j6no`0000;o_J:m00?o0000okbR__nl
X[h00_nlX[h>o`0000;o^9fm00Co0000okNK_?ngVkco00000onfVk`01Ol0003o]IZkokFJ^oneV[_o
000000?o]9Vl1?ncV;/01_l0003o/INlok6G_?naUkco0000ok6G^`Ko000000?o[iJlo`000?l00000
1Ol000001On]U;go0000ojfF_on]U[oo000000Ko[9Bm0_l00006ojVC_`04o`000?nWTKkoYi6nojNA
_PSo00000onUTL001?l0003oXho0oj>?`?l00004ojBA`P03o`000?nRT<;oXY3200?oXY320ol00002
oin?`P;o000000?oX975o`000?nNT<D01_nNT<D00ol0003oW8o6o`000008o`0000?oW9;900Co0000
oiZBb_nJT/[oVY;:0_l000000onJT/[o0000oiVCc003oiVCc0Oo00000_nIUm02o`0000KoV9WB00?o
0000oiVKe?nIVm@01?nIVm@00ol0003oV9gGoiRMe`03o`0000;oVZCL00?o0000oiZWgonJYml01?nJ
Yml00ol0003oWZWNoijYgP02oijYgP03oij^hol0003o000000;o00001_nO^>X2o`0000OoY<Ob00?o
0000oj[Kn?nZfoP00ol00003okOQm0;oYo;d0_l0001hoookJPCo00007?oonfX00003o`000?oonf[o
oo]Z00;ooo]Z0ol0000KoookJP06o`000?lJQ>So6XCXo`000?mV[OWoJJki0ol00007oiZnl@;o0000
0on]`^T2o`0000;o[<;Y00Co0000okW3h_l0003o00000onh`n801?l0003o]l;So`000?l00003oko2
f`;o00001?no`M/00ol0003oa<3FolC0eP03olC0eP?o000000?o`[kGo`000?l000000oo7_M400ol0
003oaK_AolFkd@02olFkd@;oa[kC0_l000000oo9_<ko0000olJicP03olJicP06o`000?o4^<koa;S>
o`000?o9^<Wo00000_o8]lX2o`000007olJfb_l0003oaKG;olFebol0003obKC6o`000003olNcaP03
o`000?o7]LWoakG900;oakG90ol00002olRba@03o`000?o4[lGoa:o500?oa:o500?o0000olJ]`_o6
[L800_o6[L800ol0003oaJo4o`000003o`0000Goa:c200Ko0000ol6Y`_o1ZL;o0000ol>Y`?l00005
ol:Y`@03o`000?noY/3o000000Ko00000_nnXkh2o`0000Co_ZBn00Oo0000ok^Q__nkXKko^j6no`00
0?nmX[go000000Ko_::n00?o0000okZM^onjWK/00onjWK/01?l0003o^J2ookVP_ol00003okRM_@oo
000000?o]9Vlo`000?l000002Ol00002ok6H_P03o`000?n_U[co000000Go[iNn00?o0000ojfD_On]
U;d00_l00003ojfF_`03o`000?n/U;go[9Bm00;o[9Bm0_l000000on/U[oo0000ojVC_`05ojVC_`03
o`000?nWTKkoYi6n00?o00000_nXTl000ol0003oYI70ojFA`003ojFA`0?o00001_nTTL800ol0003o
XY32oj:@`P07o`0000GoX97500?o0000oij@aOnNT<D01?nNT<D4o`0000?oWI?900?o0000oibBbOnL
T/T01OnLT/T00ol0003oVY;:o`000002oiZBbPKo00000onKU/h00ol0003oVIO@oiVGd002oiVGd003
o`000?nIUm3o000000KoV9WB00Co0000oiVKe?nIVmCoVI_D1_l00006oiZTg004o`000?nJYmooVZOO
oiZWg`;o000000CoVZOOo`000?l0003oWZWN0_l00003oij^hP03o`000?nO^>[oWkSZ00?o00000_nR
_nh00ol0003oY<ObojC7lP03o`0000CoYm3f00Co0000ok3Lm_l0003o]n7d0onWl_@00ol0003oX?GX
o`00001foookJP?o00008?oonfX00003o`000?oonf[o000000;o00007ooonfX6o`000003ofJ]nOl0
003o000000?o00001?nH__801?l0003o[L;Yo`000?l00005ojc2j@03o`000?nh`n;o^<?R00Co^<?R
0_l000001?nf`^?o0000oko2fol00004oko1f`07o`000?no`mgo_l?Moko3gOl0003oa<3Fo`000004
ol>oeP;o000000Co`KkGo`000?o7_M7o00000oo5^m400ol0003oa[kColJnd`02olJnd`Co00000_o6
^Lh00ol0003oa;S>olBhcP02olBhcP03o`000?o8]l[ob;O:00?ob;O:0ol000000oo5]L_o0000o`00
0003olNcaP03o`000?o7]LWoakG900?oakG900?o0000olRbaOo8//D00ol00004olB_a@;o00000oo6
[L800ol0003oaJo4olF_a002olF_a0Co00000_o4[<800ol0003o`JW2ol6Y`P02ol6Y`P03o`000?o2
ZL7o`ZW100?o`ZW100Ko0000oknV`?noY/3o0000ol6W_ol00004ol2U_PGo00000_nnY;h00ol0003o
^j6nok^Q_P03ok^Q_P03o`000?nlX[ko_::n00Co_::n00?o^Inno`000?njWK/00onjWK/01Ol0003o
^J2ookVP_oniX;oo000000;o^9fm00?o0000okNN__ngW[h00ongW[h2o`0000Ko]Ibn0_l00006ok>J
_P;o00001_naV;h2o`0000Oo[iNn0_l00006ojfF_`04o`000?n/U;go[9Bmo`0000Co[9Jo00?o0000
ojVC_onYTkl00_l000001?nYTkoo0000o`000?l00006ojRC`003o`000?nUTL3o000000;o00000_nV
Tl800ol0003oY972ojBA`P03ojBA`PCo000000?oXY32o`000?l000000_nRT/@00ol0003oX975oj2A
a@04oj2Aa@04o`000?nNT<GoWY35oij@a@Co00001onMTlT00ol0003oW9;9oibBb@03oibBb@;o0000
00CoVY;:o`000?l0003o00002_nKU/h00ol0003oVIO@o`000004oiVGd004o`000?nHVM;oV9WBoiRI
dPOo00000onJW]L00ol0003oVZCLoiZTg005oiZTg0Co00000onOZ]h2o`0000GoWZkR1?l00006oj:o
kP;o00000onWd?H3o`0000;oZM[i00?o0000ojObm?nWl_@00ol000000on[nMGo0000oookJP1boook
JPCo00008ooonfX000;o00008ooonfX01?l0003o05?2o`000?l00003of:]n@03o`000?me/oSo0000
00KoV;kb00?o0000ojc2jOn/`^T00_n/`^T2o`0000;oZl;Z00?o0000okS3h_l000000_l00003okO2
hP03o`000?nf`^?o000000?o_l7K0_l00004oko3g@;o00000oo3_mH01ol0003o`[kFol:ne_o2_]Ko
0000ol6neol000000oo5^m400ol0003oa[kColJnd`03olJnd`;o00000_o8^lh3o`0000?oa;S>0_l0
0003olRgbP03o`000?o7]/[oakK:00;oakK:1?l000000oo7/lKo0000olNeb@04olNeb@;o`k;900?o
0000olRbaOl000000_o6/<D2o`000007olB_aOl0003o`Zk6ol:^a_l0003oaZg2o`000004olF_a005
o`000?o1[<Co`Jc4o`000?o4[L801?l00002ol6Y`P;o00001?o2ZL400ol0003o_jK0oknV`002oknV
`003o`000?o0YKko`:Fn00;o`:Fn00?o0000oknW`_noYl800_noYl86o`0000;o^j6n0_l00005okbR
_P?o^Inn00Co0000okZM^onjWK_o00001OniX;l2o`0000Ko]ijn00?o0000okFL__neW;h01OneW;h0
0oneVkgo/iZnok>J_P04ok>J_P03o`000?ncVKgo/IRn00Go/IRn00?o0000ok6H_Ol000001_n_Ukh2
o`0000Oo[IJo00?o0000ojbD_Ol000000_n/U[l8o`0000;oZIG100?o0000ojRC`?nXTl001?nXTl03
o`0000KoYY?200?o0000ojBA`_l000000_l000001?nTTL;o0000o`000?l00005oj:Ba003o`000?nP
TLGoX97500?oX97500?o0000oj2AaOl000000ol00003oinCa`03o`000?nMTlWoWI?900CoWI?900?o
0000oibBbOnLT/T01_l0000<oi^FcP;o00000onIUm07o`0000?oVicD0_l00006oiZNe`03o`000?nJ
Y=coVZCL00?o000000?oVjSOo`000?nOZ]h01?nOZ]h00ol0003oWjkRo`000002oij^hP?o00000_nP
^>X00ol0003oX[o^oj:okP03o`0000?oY<Oa00Co0000ojO@m_l0003o00000onYf_T01_l0003o]N3f
okGPm_neh?Ko0000oj3ej0;o0000L_oonfX3o`0002Oooo]Z0002oookJP03o`000?oonf[ooo]Z02;o
oo]Z2ol00004oiNnlP04o`000?n/`^Wo0000o`0000GoZl;Z00?o0000okO2h_ng`^801Ong`^83o`00
0003oko1fol0003o_l?M00?o_l?M0_l00002okc0g@03o`000?o3_mKo000000Go`[kF00Go0000oknm
f?l0003oaK_Ao`000005olJnd`06o`000?o2^m?o`[_Co`000?o8^lko00000_o7^/h00ol0003oa;S>
o`000002ol>hc`03o`000?o8]l[o000000?oakK:00?o0000olJhc?o6^<`00_o6^<`3o`0000CoakG9
1?o3//T00ol0003oa[35olJ`a@03olJ`a@?o00000_o2[/H00ol0003oaJo4olF_a002olF_a003o`00
0?o1[<Co`Jc400;o`Jc400?o0000ol>Z`Oo3Z/400_o3Z/45o`0000;o`ZW100?o0000oknV`?noY/00
0_noY/02o`0000?o`:Fn00?o0000oknW`_noYl801?noYl800ol0003o_J:mokfR_@02okfR_@_o0000
00Co^Inno`000?njWK_o00001OniX;l2o`0000Ko]ijn0_l00006okFL_P;o]I^m00Co0000ok>J__nc
V[ko/iZn0_l00002ok>I_@03o`000?naV;ko/IRn00;o/IRn00Go0000ok6H_OnaV;go/IRmo`000003
ojnG_P;o000000?o[iNno`000?n]U[l00_n]U[l00ol0003o[IJoojfF_`06o`0000?oZiK000?o0000
ojVC_ol000001OnYUL401?l0003oZ9?0ojRC`?nXTl02o`000003ojRE`_l0003oYY?200CoYY?21?l0
0002ojBA`P;o000000?oY9?4o`000?nRT/@01_nRT/@00ol0003oX975o`000002o`000003oj6Daol0
003o000000KoWi?700?o0000oifCbOnMTlT00onMTlT4o`0000CoW9G<00?o0000oi^Fc_nKU/h01OnK
U/h01?l0003oViK>oi^Fc_nKU/h7o`0000?oVicD00?o0000oi^Le?nKW=@00onKW=@00ol0003oW9oG
o`000004oiZNe`Go00001OnKZ=l01Ol0003oWj[NoinZg_nOZ]koWjkR00Go00001_nP^>X2o`0000Oo
Y<Oa00?o0000ojWJnOnYf_T00_l00004okGPmP;oY?7e0_l0001_oookJPCo0000:_oonfX000?ooo]Z
00?o0000oookJ_oonfX08_oonfX3o`0000CoGJ_i0_l00006oiNnlP03o`000?n[`^[oZl;Z00;oZl;Z
0_l00003oj[1jP03o`000?ng`^;o000000;o00001?nf`^<00ol0003o_l?Moko3g@02oko3g@03o`00
0?nl`=go_<3M00;o_<3M0_l00003ol:neP;o00000oo1_ML00ono_MSo0000olJnd`03olJnd`;o0000
0oo2^m<2o`0000Coak[>0ol000000oo3^<oo0000o`000003olNfbP03o`000?o6^<coa[S<00;oa[S<
00Go0000ol>ec?l0003oakK9o`000002olNeb@Co`k;90_l00003olJ`a@03o`000?o5//OoaK;700;o
aK;71Ol000000oo5[lCo0000ol6/a003ol6/a0;o00001?o3Z/401?l0003o`Zg4ol:]a?o2[L@5o`00
00;o_jK000Ko0000okfV`_nmY/;o0000ol2U__l00006oknW`P;o00000onmX[d00ol0003o_JG1okfU
`@02okfU`@03o`000?nlX[oo000000Co^j?02ol00005okNN_P04o`000?ngW;go]ibmo`0000Co]Ibn
1?neVkd2ok>J_P03o`000?ncVKgo/iVm00?o/iVm00Go0000ok6H__naV;ko/IRnok6H_@06o`000003
ojnG__l0003o000000Oo00000on]V<400ol0003oZiK0oj^F`004oj^F`0;o00001_nYUL401?l0003o
Z9?0ojRC`?l00004ojRE`P03o`000?nVTl;o000000;o00000_nVTl83o`0000GoY9?400?o0000oj:B
a?nRT/@01?nRT/@2o`0000;oXIC70_l000000onQU<Oo0000oinCa`05oinCa`03o`000?nMTlWoWI?9
00?o000000?oWYG;o`000?l000001_nLUL`00ol0003oViK>oi^FcP02oi^FcP;o000000?oViK>o`00
0?nKU/h00_l00003oi^Id@03o`000?nKW=CoVicD00CoVicD00Go0000oi^Le?nKW=CoVicDoibOe`07
o`0000?oVjGL00?o0000oi^XgonKZ=l01OnKZ=l01?l0003oWj[No`000?l00003oin^h`03o`000?nP
^>[oX;SZ00?o00000onR_nh00ol0003oY<OaojC7l@03o`0000?oYm3f00?o0000ojkLmol000000_ne
h?H3ojCam@?o0000KOoonfX3o`0002kooo]Z0004oookJP03o`000?oonf[ooo]Z02?ooo]Z1Ol00000
0omMZoWo0000o`000002o`0000CoU[gc00Co0000oj_2j_l0003o00001_nZ`NX00ol0003o]/;SokK2
h`02okK2h`;o00000_ne`N<01?l0003o_l?Moko3gOl00004okc0g@06o`000?nk_mgo^koMo`000?o2
_]Ko00001_o1_ML3o`0000;oa[kC1?o2^m<01_l0003o`K[Dol6je?l0003oak[>o`0000CoaKW>0_l0
00001?o2]m3o0000olNfb_l00004olJhc006o`000?o3]Lco`kG<ol>ec?l0003oakK90ol00002ol>b
b@06o`000?o2/LWo`[79o`000?o6/<Go00001?o5//L01Ol0003o`Zo7ol:_aol0003oaK3500Co0000
0_o1[<@01?l0003o`:_5ol2[aOl00002ol>Z`@03o`000?o2[LCo`Zg400;o`Zg400?o_ZW4o`000?o2
Z<400_o2Z<45o`000003okfV`_l0003o_jO200Go_jO200?o0000okbT`Ol000000_nmX[d00ol0003o
_JG1okfU`@03okfU`@;o00001OnkXl000ol0003o^:30o`000004okVQ_`04o`000?niXL7o^J71okVQ
`A_o000000?o/IRno`000?l000000onaV;h00ol0003o[iNno`000005ojnH`003o`000?n]U[oo0000
00Go[IS100Co0000oj^F`?n[U/3oZiK00ol000000on/Ul;o0000ojVE`@05ojVE`@;o00000onXUL85
o`0000?oYY?20_l000000onVULCoY9?4ojBCa005ojBCa003o`000?nRT/CoXY;400Oo00001OnQU<L0
1?l0003oWi?7oinCaonOTlL5o`0000;oWYG;0_l000000onNUL_o0000oibEc005oibEc0Go00000_nL
V<l00onLVLoo0000oi^Id@06oi^Id@04o`000?nKW=CoVicDoi^Le0;o000000?oVicDo`000?nKW=@0
0_l00003oi^Pf003o`000?nKYMcoVjGL00GoVjGL1?l00002oifZg`03oijZgol0003oWjkS00GoWjkS
0ol00007oj:okP;o00000_nWd?H3o`0000;oZ=[i0_l000001_nTlOGo0000o`000?nKlnOo0000oj?f
dV_ooo]Z1?l0000aoookJP001OoonfX00ol0003ooo]ZoookJP0SoookJP?o00000omHZ_T2o`0000Ko
U[gc00?o0000oj[1j_nZ`NX00_nZ`NX2o`0000?oZL7[00Co0000okK2hol0003o00001One`N<2o`00
00?o_<3M0_l00003ok^og@;o00001Oo1_ML01Ol0003o`;gGol2meol0003oaKkC00;o00000oo2^m<0
1?l0003o`K[Dol6je?o1^]@2o`0000CoaKW>00Ko0000olBhcoo4^<oo0000ol:gd?l00004olJhc003
o`000?o3]Lco`kG<00;o`kG<0_l00003olJdb0Co000000?o`[79o`000?l000001?o5//L00ol0003o
`Zo7ol:_a`02ol:_a`03o`000?o4[/Coa:k400;oa:k41?l000001?o0ZlGo0000ol>Z`Ol00004ol:]
a0?o_ZW400Co0000ol:X`Oo2Z<7o00001?o0Z/<5o`0000;o_jO200Co0000okbT`OnlY<7o_:C10_l0
0005okfU`@03o`000?nkXl3o000000Co^j?000Go0000okRP`?nhX<3o^:30o`000002okVQ_`03o`00
0?niXL7o^J7100;o^J7100?o0000okNN__l000001_ngWl000ol0003o]I^mokFK_@05okFK_@03o`00
0?ncVKgo/iVm00Ko/iVm00?o0000ok6H__naV;h01OnaV;h00ol0003o[iS0ojnH`004ojnH`0;o0000
1on]V<400ol0003oZiK0o`000005ojbG`P03o`000?nYUL7o000000So00000onXUL<01?l0003oYY?2
ojJC`_l00004ojJEa003o`000?nTTlCoY9?400CoY9?40ol000000onSULKo0000o`000002oj>EaP03
o`000?nQU<OoXIC700?oXIC71Ol00003oj2FbP?o00001OnNUL/00ol0003oW9G<oibEc003o`000003
oifHc_l0003oW9S?00;oW9S?1?nLVLl00ol0003oViWAoi^Id@03oi^Id@Go00000onLW]D00ol0003o
Vj3Hoi^Pf005oi^Pf003o`000?nKYMco000000;o00000_nOYm`00ol0003oWJ[OoifZg`02oifZg`?o
WZ[O00?o0000oin^honO[^<00ol00002oj6ijP03o`000?nR_nkoX[o^00?o00000_nTao801?l0003o
Ym3fo`000?l00004ojSJn@04o`000?nchOKo/n7fo`0000;oVo?W0_l0001YoookJP?o0000=OoonfX0
00Kooo]Z0_l0000UoookJP05o`14/Ol0003oDJOhoe6Wn?mHZ_T01?l00005oi>ml`;o00001onY`N/0
0ol0003o]L7SokG1h`02okG1h`;o00000_nd`N@2o`000003okc0gOl0003o^koM00;o^koM0_l00000
0oni_mko0000ol6me`02ol6me`;o00001?o0_ML01_l0003oaKgColFmdol0003o`[_Co`0000?o`K[D
00?o0000ol2je?l000000oo5^Lh00ol0003oa;S?olBhc`02olBhc`;o00000oo6^<`00ol0003o`kG<
ol>ec002ol>ec003o`000?o1]<go000000?oa[C800Co0000olBbb?o4//Soa;;81?l00002olFba`03
o`000?o2[lOo`Zo700;o`Zo70_l00003olB^a003o`000?o3[lOo`jo700;o`jo70ol00004ol:]a0Co
_ZW400?o0000ol:X`Ol000001?o0Z/<00ol0003o_JO3o`000003oknW`P[o00000_nmYL401?l0003o
^j?0ok^S`?l00003ok^S`003o`000?nhX<3o^:3000;o^:3000?o0000okVQ_ol000001OniXL42o`00
00Ko]io000?o]9g0o`000?neVkd01?neVkd00ol0003o]9k2o`000005ok>I_@;o000000?o/Yc2o`00
0?naV;h00onaV;h2o`000003ok:L`On_V<3o[iS000Co[iS000?o0000ojnI`?l000001_n]V<42o`00
00Co[9O21_l00004ojZG``03o`000?nXUL?oZ9G300CoZ9G30_l00007ojJEa0?oY9?41_l00006oj>E
aP03o`000?nQU<Oo000000;o00000_nRU/T00ol0003oX9K:oj2FbP03o`000003oj2Fb_l0003oWYG;
00?oWYG;1Ol00004oifHcP;o00001_nLVLl00ol0003oViWAoi^Id@03o`000003oijMdol0003oW9kE
00KoW9kE00Co0000oi^Pf?nKX=SoVj3H1Ol00006oinWg003o`000?nMZ]ooWJ[O00;oWZ[O1Ol00006
oj6ijP;o00001_nTao801?l0003oZ=[iojSJnOnXf_T2o`0000?o/n7f0_nQl?@00ol0003oUo7<oook
JP1VoookJPCo0000>?oonfX000Sooo]Z00?o0000oookJ_oonfX09?oonfX5o`000004oe6Wn?l0003o
0000o`0000CoTKcd00?o0000ojW1jonY`N/00ol00003ojO1k004o`000?ne`N?o0000o`0000Go]<7T
1?l000000onk_mgo0000okVogP03okVogP03o`000?o1_MOo000000Co`;gG00Co0000oknmf?no_MSo
00000_o5_M<3o`000003ol6je?l0003o`;[D00;o`;[D00?o0000olFic_l000000oo4^<l01?l0003o
a;_AolBkdOo4^m44o`0000?o`kG<00Oo0000ol6dcOo1]<go`KC=o`000?o6]<So000000?oa;;800Co
0000olBec?o4]Lcoa;G<0ol00004ol:_a`06o`000?o0[/So`:k8o`000?o4[/Co00001Oo3[lL00ol0
003o_jc6o`000006o`0000;o_ZW40_l00004ol2Z``07o`000?nmYl?o_JO3okfW`ol0003o_jO2o`00
0004okjX``04o`000?nkYL?o^jG3o`0000;o_JG21Ol000001?nkXl3o0000ok^S`?l00005okRP`0;o
00001OniXL400ol0003o^9o0o`000005okNO`0?o]9g000?o0000okFK_OneVkd00_l00003okBN`P05
o`000?ncVKgo/iVmok>I_Ol000000onbW<801Ol0003o/IRnok6H__naV;ko000000?o/Yc100?o0000
ojnH`?n_V<000_n_V<001Ol0003o[iW0ojnI`?n_VL3o000000Co[IS11ol00002oj^G`P;o00001onZ
Ul<00ol0003oZ9G3ojRE``03o`000003ojRGa?l0003oYYG400CoYYG41_l00003ojFGa`03o`000?nS
ULKoXiG600CoXiG60ol00004oj:Fb@Co00000onPU/X6o`0000?oWiS=00Co0000oifHc_nMV<koWIS>
0_l000000onNV<ko0000oibIc`03oibIc`Go00001?nNWM<2o`0000CoW9kE1_l00003oifWg@03o`00
0?nOYmcoWjOL00GoWjOL1Ol00003oj2diP03o`000?nQ^N[oXKWZ00?o00000onS`>h00ol0003oY<Ob
ojC7lP03o`0000?oY]3f00Ko0000ojgLn?l0003o/n7fo`000?nQl?@4o`0006Gooo]Z0ol0000loook
JP002OoonfX00ol0003ooo]ZoookJP0ToookJP;o00001?m9YOL00ol0003oTKcdoi6lm004oi6lm0;o
00001onW`N`00ol0003o]<7TokC1i002okC1i0;o00000_nc`N@00ol0003o_L;Nokg2gP02o`0000Co
^KoN0_l00003ol2me`;o00001?no_MP00ol0003oa;gColBmd`02olBmd`;o00000oo0^]@2o`0000?o
a;S?00?o0000olBkdOo4^m400_o4^m42o`0000;oaKO<00?o0000ol>ec?l000001?o1]<d2o`0000?o
a;;800?o0000olBec?o4]L`00_o4]L`4o`0000;o`Zo700?o0000ol2^b?o0[/P00_o0[/P00ol0003o
`jo7ol>_a`03ol>_a`07o`000?no[<Ko_jc6okn/a_l0003o`Zg5o`000003ol6[``Co00000oo0Z/<0
0ol0003o_JO3okfW``02okfW``;o00001?nnZ<<01Ol0003o^jG3ok^U`onkYL?o000000;o_JG200?o
0000okbV`onlY/<00_nlY/<;o`0000Co^J7100Go0000okRO`?nhWl3o^9o0o`000003okNO`0Co]9g0
00?o0000okFK_Ol000001OndW/801?l0003o/iVmo`000?l00005ok:L`P?o00001OnbW<43ojnH`0;o
[iW02Ol00002ojfI``03o`000?n[Ul;oZiO200;oZiO200?o0000oj^Ia?l000002?nZUl<2o`0000Go
Z9O400?o0000ojJEa?l000000_l000000onVULCoYYO6o`000007ojFGa`03o`000?nSULKoXiG600?o
000000CoXiO9o`000?nRU/WoXYK90ol00002oj:Gb@03o`000?nPU/[o000000;o00000_nQVL`00ol0
003oWiS=oinHc@05oinHc@04o`000?nMV<ko0000oijHcPOo00000onNWM<00ol0003oWYgCoijMd`02
oijMd`03o`000?nNWmGo000000Co00000onMY=X00ol0003oWJOMoifWg@04oifWg@03o`000?nOYmco
WjOL00?o00000onO[>000ol0003oX;CVoj2diP04oj2diP;o00001onS`>h2o`0000;oY]3f0_l00003
ojSKn@;o000000GoXO3do`000?l0003o0000oiOac01SoookJPCo0000?ooonfX000[ooo]Z00?o0000
oookJ_oonfX09OoonfX2o`000003odjTmol0003oBJGg00?o00001On7_OP00ol0003oYl7/ojO1k003
o`0000;oY/3/00Co0000okC1i?l0003o00001Onc`N@01_l0003o_<7Nokc1g_nl`Mko0000okVogP;o
00000_nh_ml00ol0003o`;gGo`000004oknmf006o`000?nn_MWo_[gIo`000?o4_M?o00000oo2_=@0
0ol0003o`;[Do`000002okjje@03o`000?o4^<oo000000Coa;_A00Co0000ol2gdOo0]m7o00000_o5
]l`3o`0000;o`KC=00Ko0000ol2dc_o0]<ko0000olBbb?l00004olBec003o`000?o0/Lco000000;o
a;771?l00002ol2^b0;o00001?o3[lL00ol0003o_jc6okn/aP02okn/aP;o00000oo1Zl<00ol0003o
`:g7ol2]a`02ol2]a`Go00000_nmYl<00ol0003o_JO3o`000003okjX``03o`000?nkYL?o^jG300?o
^jG30_l00006okbV``03o`000?njX[oo^Z:o00;o^Z:o00Co0000okVTa?niY<Co^JC46ol00007ok:L
`PWo000000Co[iS0o`000?l0003o00000on_VL400ol0003o[IS1o`000006ojfI``03o`000?n[Ul;o
000000CoZiW400Co0000ojZG`onZUl?oZYO30ol000000onZVLGo0000ojRGa002ojRGa0Go00000_nV
UL@4ojJGaP03o`000?nUUlOoYIO700?oYIO700Co0000ojFGaol0003o00000onSUlT4o`0000CoXYO9
0ol00006oj6Ic003o`000?nOV<goWiS=00?oWiS=1Ol00003oinMdP03o`000?nNWM?oWYgC00GoWYgC
00?o0000oijMdonNWM<00ol000000onNXMOo0000oifTfP06oifTfP04o`000?nMYmgoWJOMoifWg@;o
000000CoWJOMo`000?l0003o00001?nO[>05o`0000CoX[[Z00?o0000oj?0k_nS`>h00ol00003ojG8
lP;o00001?nXfoT2o`0000;o/N?g00Co0000oiGaiOl0003o0000HOoonfX3o`0004?ooo]Z000;oook
JP;o00009_oonfX2o`000003odjTmol0003o000000;o00001_n7_OP2o`0000KoY/3/00?o0000ok?1
i?nc`N@00_nc`N@2o`0000;o/L3U00Co0000okc1g_nl`Mko_<7N0ol00002okRog`;o00000ono_MP2
o`0000Co_[gI00?o0000ol:le?o2_=@00oo2_=@3o`000003okjjeOl0003o000000Coa;_A00Co0000
ol2gdOo0]m7o`;OA0_l00004olBfc@Co00000_o0]<h00ol0003oa;G<olBec002olBec007o`000?o0
/Lco`;7<ol2ac?l0003oa;77o`000003ol>`a`Go00000_o3[lL00ol0003o_jc6okn/aP02okn/aP03
o`000?nn[<So000000;o`J_300?o0000ol2]aoo0[LL00oo0[LL2o`0000?o_jW31_l000000onnZ<?o
0000ok^U``04ok^U``;o00001_nlY/<2okVS``04o`000?njX[oo^Z:oo`0000Co^JC400?o0000okVQ
`Ol000001_nhX/<2o`0000Go]Yfo00?o0000okJQa?l000001?ndW/801?l0003o]9o4okBOa?l00005
ok:M`P03o`000?nbW/Co000000Ko/9_200?o/9g4o`000?n_VL401on_VL400ol0003o[IW3ojfI``04
ojfI``;o00001_n[VL@01Ol0003oZYO3o`000?l0003oZYW500Oo00000onXUlD2o`0000KoYYO600?o
0000ojFGaonUUlL00ol00002ojFIb@03o`000?nSUlWo000000;o00000_nSUlT00ol0003oXYO9oj:G
b@03o`000003oj:Ic?l0003oXIW<00KoXIW<00?o0000oinHcOnOV<d00ol000000onPW=3o0000oinM
dP06oinMdP04o`000?nNWM?oWYgCoijMd`;o000000CoWYgCo`000?l0003o00001OnNXML01?l0003o
WJCJoifTf_nMY=X2o`000003oifTf_l0003o000000;o00000onQZMd2o`0000;oWjcP0ol00002oj6e
i`03o`000?nR^^[oX[[Z00GoX[[Z0_l00003ojG8lP;o00000_nVd_L01?l0003oZ=_io`000?l00003
ok7Sm`04o`000?nLl??oW?3coj3fhUoooo]Z1?l00016oookJP003OoonfX00ol0003ooo]ZoookJP0V
oookJP03o`000?lRTNco000000Co00001?n:_OP00ol0003oY/3/ojK0k003o`0000;oY<3]00Co0000
ok?1i?l0003o00001Ona`>D2o`0000Co^/7O0_l00002okJnh003o`000?no_MSo000000Co_[gI00Go
0000okg0g?nm`=co0000ol:le002o`0000Co`K_D1?l00002olBkd@Co`;OA00?o0000okngd_l00000
0oo4]/d00ol0003o`[G=ol:ec@02ol:ec@?o00000oo4]L`5ol2ac0;o00001?o3/<L01?l0003o`[;;
ol:bboo2///5o`0000;o_jc600Co0000okj/b?nn[<So_Zc80_l00006ol2]a`03okfZaol0003o_jW3
00;o_jW300?o0000okj[a_nnZlH00_nnZlH5o`0000;o^jG300Co0000ok^V`onkY/?o00001?nlY/<3
okVS``03o`000?njX[oo000000Go^JC40_l00006okRR``03o`000?nfX<;o000000?o]Yfo0_l00003
okJQa004o`000?ndW/;o]9k2o`0000Co]9o400?o0000ok:M`_nbWL800_l00003ok:Na003o`000?n`
Vl;o/9_200;o/9_20on`WL@01?l0003o[iW1ojnI`On_VL43o`000003ojnLa?n]VL?o[IW300?o[IW3
0_l000000on]V/?o0000oj^Ia006oj^Ia0Co00000onZVLD00ol0003oZ9O5ojRGa@02ojRGa@;o0000
00?oZ9W7o`000?nVUlH01_nVUlH2o`0000CoYIW90ol00004oj>Gb@Co00001OnRVL`00ol0003oXIW<
oj6Ic003oj6Ic0Co00001OnPW=000ol0003oWigBoinMdP03oinMdP03o`000?nOWM;o000000;o0000
0onOX=D00ol0003oWZ7GoijQe`04oijQe`Go00000onOZMd00ol0003oXJWMoj6Yg@03oj6Yg@Go0000
1_nQ]NL00ol0003oX[[Zo`000002o`0000?oY<;_00Co0000ojG8l_l0003o00001OnVd_L2o`000004
ok7Smol0003oW?3coic`l`?o0000GOoonfX3o`0004[ooo]Z000>oookJP03o`000?oonf[ooo]Z02Ko
oo]Z0_l000001?lfW??o0000ob:Ak?mn^oX7o`0000KoY<3]00?o0000ok70iOna`>D00_na`>D2o`00
00;o/<3V00Co0000ok[1gol0003o00000oni`=l01?l0003o][kPo`000?l00003okjmf@;o00000onm
`=`2o`0000?o`K_D0_l00004oknje@?o00000oo0]m401ol0003o_kOBokngd_no]m;o0000olBfcOl0
00001?o2]Ld01?l0003o`[SAol:hdOo2^=43o`0000Co`;7<00?o0000oknacOl000000oo3/<L00ol0
003o`[;;ol:bb`02ol:bb`03okj_bol0003o`Zo700;o`Zo71?l00002okj/b003o`000?o0[LOo`:g7
00Co`:g70onmZ/L00ol0003o_jW3o`000005okj[aP03ok^Xa_l0003o_JO300;o_JO31ol00002okbV
``Co^J?30_l00005okVTa003o`000?nhX/;o000000Go^:;300Co0000okJP`_nfX<;o00000_nfWKl0
0ol0003o]Z74okJQa003okJQa003o`000?ndW/;o000000Go]9o400?o0000ok:M`_l000001OnbW/@0
0ol0003o/9_2ok2K`P05ok2Ma004o`000?n_VL7o0000o`0000Go[ic40on]VL<00ol0003o[I[3ojfJ
``02ojfJ``04o`000?n[VLCoZiW4oj^Ia0;o000000?oZiW4o`000?nZVLD01_nZVLD00ol0003oZ9O5
o`000005ojRIa`04o`000?nVUlKoYYO6ojJGaP;o000000CoYi[9o`000?nUVLWoYIW90ol000001?nU
VLWo0000oj>GbOnSUlT3o`0000;oY9[;00?o0000oj:Ic?nRVL`01?nRVL`00ol0003oXIW<o`000002
o`0000?oXIc?00?o0000oj2Ld?nPW=001?nPW=000ol0003oWigBoinMdP03o`0000;oX9oC00?o0000
oinPeOnOX=D01?nOX=D00ol0003oWZ7GoijQe`03o`0000;oWjOK00?o0000oinYgOnOZMd01?nOZMd0
1?l0003oXJWMo`000?nQZMd2o`0000;oXJoQ00?o0000oj6eionQ]NL01OnQ]NL2o`0000OoY<;_00Co
0000ojKBmonVd_OoY];g0_l000002OnWg?[o0000o`000?l0003oW?3co`000?nQlnoo0000oj3fhP1L
oookJP?o0000COoonfX000oooo]Z00?o0000oookJ_oonfX09_oonfX2o`000006ocJLlol0003o0000
o`000?mh^__o00000on7_OP00ol0003oY<3]ojC0k@03o`0000;oXL3^00Co0000ok70iOl0003o0000
1On``>H00ol0003o^L3OokW0g`04okW0g`;o000000Co]KkQo`000?nn_MWo00001?nm`=`01_l0003o
^[cKokZlfol0003o`K_Do`0000Oo_k[E00Go0000ol>jd_l0003o`;OAo`000004okngdP;o00000oo2
]Ld2o`0000Co`[SA0_l000001Oo3]<co0000o`000?o0/Lco000000?o_k7=00?o0000ol>`aol00000
1?o2///3okj_b`03o`000?o2[lOo000000Co`:g70ol00005ol2]a`Co_J[70_l00005okj[aP?o^jS6
00Co0000okfW`onmYl?o00001OnlZLH9o`0000Co^JC400Go0000okRR`_nhX/;o^:;2o`000003okRR
``Go]Z320_l00006okJQa0;o00001_ndWl@2o`0000Ko/Yk40_l00006ok2Ma0;o00001?n_W<@4o`00
0003ojfI`ol0003o000000[o00000_n[VlH00ol0003oZYW5ojZIa@03ojZIa@;o00001onXVLL01Ol0
003oYYO6o`000?l0003oYi[900Go00001?nUVLT3o`0000KoY9[;00?o0000oj:Ic?nRVL`01?nRVL`0
0ol0003oXIc?oj6Lc`04oj6Lc`03o`000?nPW=3oX9c@00?oX9c@00Co0000oj2Ld?l0003o00001?nP
Wm<2o`0000CoWj3E1Ol00006oinWf`04o`000?nOZMgoWjWMoinYg@;o000000?oWjWMo`000?nQ[n40
1OnQ[n45o`0000CoXkc[00?o0000ojC2konT`^l00ol00003ojG;l`;o00000onWg?X2o`0000;o/>Gh
0_nEknl2o`0005Wooo]Z1?l0001@oookJP004?oonfX00ol0003ooo]ZoookJP0WoookJP03o`1[cOl0
003o;9O`00Wo00001_nQ`>h01?l0003o/<3Vok30i_n``>H3o`0000?o[/3W00Co0000okW0gol0003o
00001?ng_n02o`0000?o_L3L0_l00003okZlf`;o00001Ono^]D2o`0000;o_[[F00?o0000ol>jd_l0
00000_l00002okngdP06o`000?nm]m?o_KOCo`000?o2]Lgo00001Oo2^=400ol0003o_[C@o`000003
ol>dc0?o00000_no/Ld2o`0000Co`[;;1?nn[l/2o`0000Co`:g700Co0000okn`bono/<_o_k3;1_l0
0002okfZa`03o`000?nmZlOo000000Co_Z_61?nkZ<H00ol0003o_JO3o`000005okbYaP03okVVa_l0
003o^jG200?o^jG200Co0000okZWa_njYlKo^ZO63_l00003okJP`P03o`000?nfXLCo]Z7400Co]Z74
00?o0000okFP`ol000001OndWl@00ol0003o/ik3o`000005ok:Na003o`000?nbWL?o000000Go/9g4
1ol00002ojjLa0;o00002?n]V/@2o`0000GoZi_600?o0000ojZIaOnZVLD00ol000000onZVlOo0000
ojRIa`05ojRIa`Ko00000onWV/T00ol0003oYIW9ojFIb@03o`000003ojFKbol0003oY9[;00KoY9[;
00?o0000oj:Ic?nRVL`00ol000000onSW<oo0000oj6Lc`06oj6Lc`03o`000?nPW=3o000000;o0000
0_nQWm800ol0003oX9oCoj2Od`03o`000003oj2Odol0003o000000?o00000onPYMT00ol0003oWjOK
oinWf`05oinWf`Co00000_nP[=l2oj6/g`03o`000?nQ[n7oXJoQ00?o000000?oX[SXo`000?nS_>/0
1onS_>/2o`0000;oYL_c0_l00004ojKDn0;o00000_n`iOP3oiG_k`03o`000?nClMSooo]Z05Oooo]Z
0ol0001DoookJP004OoonfX2o`0002Wooo]Z1?l00003og6hn`Ko00001OnO_o02o`0000Oo[/3W00Co
0000okNoh?ng_n3o]koP0_l00003okFnh@03o`000?nm`=co_L3L00?o^[cK0_l000000onh_=go0000
oknje@03oknje@03o`000?nn^]Ko_[[F00?o_[[F00Co0000ol6id_o1^M;o`KWB0ol00003okfgd`03
o`000?o2^=7o`[SA00?o`[SA00Oo0000okjdd?nn]=3o_[C@o`000?o3]<co000000?o`K?<1?l00003
ol:bb`Co_Zo;00?o0000okf_c?l000000oo0[LL00ol0003o_k3;okn`b`02okn`b`;o00001?no[<H4
o`000004okf[aol0003o_Z_6okj[aPGo^jS60_l00005okbYaP?o^JK600Co0000ok^U`_nkYL;o0000
1?njYlH00ol0003o^JC4o`000006okRR`P03o`000?ngXL;o]j7200;o]j728Ol00004ok2NaP03o`00
0?n^W<Co[Yc400;o[Yc400?o0000ojjMaol000001On]V/@2o`000003ojfNaon[VlKoZi_600GoZi_6
0ol00005ojZKa`03o`000?nXVLOoZ9W700?o00000_nXW<T00ol0003oYi[9ojNJb@04ojNJb@?o0000
1OnUVl/00ol0003oY9[;ojBJb`03ojBJb`04o`000?nTV/_o0000o`0000GoXic?00Co0000oj6LconQ
W<ooXIc?1Ol00005oj6OdP?o000000KoX9oCo`000?l0003o0000oj6Tf?l00007oj2Uf@03o`000?nO
Ym_oWjOK00?o00000_nRZ]`00ol0003oX:cOoj2/g`03oj6/g`Co00001OnR^>P00ol0003oXkc[oj>l
j`03o`0000?oY<C`0_l00003ojKDn0?o000000?oY]oko`000?l000000_nEknl2o`000003oi?af?oo
nf[ooo]Z05Cooo]Z1?l0001GoookJP004ooonfX00ol0003ooo]ZoookJP0XoookJP04o`1<[?l0003o
0000o`0000?oJKKl00?o0000ogjjn_l000000_nO_o03o`0000;oW;oa00?o0000ojk0ion^`>L00ol0
0003ojc0j003o`000?ng_n3o000000Ko]KkQ0ol000000onj_=_o0000okRlg@03okRlg@04o`000?no
^]Go0000o`0000Co_[[F00Ko0000okbjeonl^]Oo0000ol6id_l00003oknhd`04o`000?nm]m?o0000
o`0000Co`[SA1Onn]=02o`0000;o`K?<0_l00004oknac@Co00000_nn[l/01ol0003o_Jo<okf_c?nm
[lco0000ol2]aol000001Ono/</00onl[L_o0000okn/aP02okn/aP03o`000?nn[/[o_Zk:00;o_Zk:
1_l00002ok^XaP03o`000?nkZLOo000000Co_:W61?niY/H00ol0003o^jG2o`000005okZWaP;o0000
1OnhX/800ol0003o^:K7o`000003okNQ`P;o00000onfY<H01?l0003o]J74okFQa?l00004okFRaP04
o`000?ndWlCo0000o`0000Go/io300?o0000ok:Na?l000001OnbW/<00ol0003o/9g4o`000006ok2N
aP03o`000?n^W<Co000000Co[Yg700Go0000ojfJa?n]V/Co[I[4o`000003ojfNa`03o`000?n[VlKo
Zi_600;oZi_60_l000000on[W<Oo0000ojZKa`03ojZKa`Go00001OnXW<T01?l0003oYi[9ojNJbOnW
V/T3o`000003ojNMbol0003oYI_;00GoYI_;00?o0000ojBJbonTV//00ol00002ojBMcP03o`000?nS
W<ooXic?00?oXic?1Ol00003oj:Od@03o`000?nQWm;oXIoB00;oXIoB1_l00005oj6Tf003o`000?nP
YMWoX:GI00;oX:GI0_l000000onPYMWo0000o`000005oj:Zg0;o000000CoXJcOo`000?l0003o0000
0_nR]>D00ol0003oX[SXoj:hj005oj:hj0;o00000_nTa?03o`0000;oYLge00Co0000ojKDn?l0003o
00000_nVgo/2o`0000?o[NWi0ol0001DoookJP?o0000FooonfX001Cooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003o04b/o`000002o`0000;oJKKl1?l00006oibol@;o00001on/`>P00ol0003o]KkQ
okFnh@02okFnh@;o00000_nc_n801?l0003o_KoLo`000?l00004okRlg@;o00001?nn^]H00ol0003o
_;[Gokbje`03okbje`03o`000?no^=?o_kSC00?o_kSC1?l00002ol:hd@Co_[C@0_l000001?nl]=;o
0000ol6cc?l00005oknac@03o`000?no]]7o000000;o`K;;1Ol00002okf_c003o`000?no/<_o_k3;
00?o_k3;0onl[L/00ol0003o_jc6o`000005okj^bP;o00001?nmZ/H4o`000004ok^Yaol0003o_:W6
okbYaPGo^JK60_l00005okZWaP03o`000?ngYLKo000000?o^:;20_l00003okRVa`03o`000?ngXL;o
000000Ko]ZC60_l00005okFRaP;o00002?ncWl<00ol0003o/Yk3ok:N``05ok:N``03o`000?n`W/Ko
/9k600Co/9k60_l00006ojjMa`04o`000?n]V/Co0000o`0000Go[Ik70on[VlH00ol0003oZic7o`00
0006o`0000;oZI_800?oZYc9o`000?nXW<T01_nXW<T00ol0003oYi[9o`000004ojNMb`03o`000?nU
Vl_oYI_;00?oYI_;1?l00006ojBMcP03o`000?nSW<oo000000;o00000_nSWm400ol0003oXYoAoj:O
d@04oj:Od@03o`000?nQWm;oXIoB00?o00000_nRY=L00ol0003oXJCHoj6Tf005oj6Tf0Co00000onQ
Z]d00ol0003oXZ[Loj:Zg002oj:Zg0Go00001_nR]>D4o`0000GoY;o]0_l00006ojG=m@03o`000?nV
go_oY]ok00;o00000on]jOT00ol0003oSNgYoh7Wb01BoookJPCo0000G_oonfX001Gooo]Z00?o0000
oookJ_oonfX0:OoonfX4o`0000?oGk?k0_l00002oibol@?o00000_nH__800ol0003o[<3Xojc0j003
o`0000?oZL3Z00Co0000okFnhOl0003o00001Onc_n801Ol0003o^koMok^ogOl0003o^;cM00;o0000
0_nf_=h01?l0003o_[[Fo`000?l00004okbje`05o`000?nk_]co^kkLo`000?no^=<00_l00004okfg
d`Co00000_nn]=001?l0003o_;CBokbdd_nl]=82o`0000Co_k7=0_l00003oknfd@03o`000?o1//_o
000000Co_k3;0ol00004okn`b`Co_:g;0_l00005okj^bP03o`000?nkZl[o000000?o_J[600?o0000
ok^Xa_nkZ<H00_nkZ<H;o`0000Co^ZO61?ngYLH00ol0003o^:;2o`000005okRVa`;o00001_nfY<H2
o`0000Go]J;600?o0000ok>Qa_l000001OncWl<2o`000003ok:Rb?l0003o/Yk300?o/Yk30_l00000
0onbX/Oo/9k6ok2NaP03ok2NaP;o000000?o/9k6o`000?n^WLL01On^WLL2o`0000Co[Ik71?l00000
1?n[VlKo0000o`000?l00003oj^Lb004o`000?nYVlSoZI_8ojVKb0CoZYc900?o0000ojRLbOnXW<T0
1?nXW<T00ol0003oYig;ojNMb`05ojNMb`;o000000?oYI_;o`000?l000000_nVWll00ol0003oY9g>
ojBMcP04ojBMcP?o00001_nSWm401?l0003oXYoAoj:OdOnRWm45o`0000KoXZCG00?o0000oj6Tf?l0
00000_l00002oj:Xf`03o`000?nQZ]goXJ[M00GoXJ[M0_l000000onRZ]co0000o`000003oj:_h@03
o`000?nR]>GoX[CU00?o00000_nS^nX00ol0003oY;o]ojBok@03o`0000;oYLOb00?o0000ojG=mOnU
cOD00ol00004ojGHn@04o`000?n]jOWo0000o`0000;oSNgY00?o0000oookJ_oonfX0CooonfX3o`00
06;ooo]Z000FoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o04FWo`000?l000000_mC[oX01?mO/o_o
0000o`000?l00006oiRnlP;o00001onY`>X00ol0003o/koRok>ohP02ok>ohP;o00000_na_n@00ol0
003o^koMok^og@03o`0000;o][cN0_l00004okbje`03o`000?nk_]co^kkL00;o^kkL0_l00005okfg
d`05o`000?nl^=Go_;SEo`000?o1^=401?l000001?nl]=;o0000ok^ddol00003oknac@03o`000?no
]]7o_kKA00?o_kKA0_l00004okn`b`04o`000?nm[lco_Jo<okf_c0Go00000_nl[L/00ol0003o_:k;
o`000004okj^bP07o`000?nkZl[o^j_:ok^[b_l0003o_J[6o`000005ok^XaP03o`000?nk[Lco0000
00;o^jS60_l00004okZ[bPKo00000ongYLH00ol0003o^:K7okRVa`03okRVa`03o`000?ngY<Ko0000
00Co]ZC60_l000000onfXlGo0000okFRaP03okFRaP05o`000?ncXLKo/j76ok>Qa_l000000oncWl<0
1Ol0003o/Z;8ok:Rb?nbX/So000000?o/Yk300?o0000ok:RaonbX/L00_nbX/L3ok2NaP03o`000?n`
W/Ko/9k600;o/9k600?o0000ojjMaol000002ol000000on]W/So0000oj^Lb007oj^Lb003o`000?nZ
W<WoZYc900CoZYc900?o0000ojRLbOnXW<T00ol00002ojVNc004o`000?nWWL_oYig;ojNMb`Go0000
1_nVWll00ol0003oY9g>ojBMcP03o`000003ojFPdOl0003oXioA00KoXioA00Co0000oj:OdOl0003o
00000onSXmD00ol0003oXZCGoj:Te`05oj:Te`;o00001_nRZ=/01?l0003oXJ[Moj6ZgOnQZ]d2o`00
0003oj6ZgOl0003o000000GoXZoQ1?l00006oj>kjP;o00001_nUao82o`0000?oYMSi0ol00002oj_R
nP04o`000?n=kNWoSNgYo`0004oooo]Z1?l0001UoookJP005ooonfX2o`0002gooo]Z1?l000000omC
[o[o0000o`000002o`0000CoU;kd00?o0000ojW0j_nY`>X00ol00003ojO0j`04o`000?nc_n;o0000
o`0000Go/KoT00?o0000okVng_ni_]h00_ni_]h3o`000003okBlgol0003o_;[G00;o00001?nk_]`0
0ol0003o^;[Ko`000003okfgd`;o00001?nl^=D00ol0003o_kOAokngd@02okngd@Go000000?o_k7=
o`000?no]]401?no]]400ol0003o^k;Ao`000003okn`b`03o`000?nm[lco_Jo<00?o_Jo<00Co0000
okj_bonn[l_o_Zo;1_l00002okj^bPGo^j_:0_l00004ok^XaP;o00000onk[L`2o`0000Ko^Z_:0_l0
0004okVVaA?o000000?o]Z?5o`000?neX/H00_neX/H4ok>QaP04o`000?ncWl?o0000o`0000Go/Z;8
0ol000000onbX/Oo0000o`000003o`000003ok2Na_l0003o000000Oo00001On^W/L01?l0003o[9g8
o`000?l00004ojfNb004o`000?n[W<SoZic8oj^Lb0?o000000?oZio;o`000?nZW<T01_nZW<T2o`00
00CoZIk<1Ol00002ojJLc0;oYio>00?o0000ojJOconVWll01OnVWll2o`0000GoYJ3A00?o0000oj>O
dOnSWm400_nSWm42o`000003oj>OdOl0003oXj?E00GoXj?E00?o0000oj:TeonRY=L00ol000000onS
Z=[o0000oj:Xf`07oj:Xf`?o00000_nR[Ml00ol0003oXZgOo`000002oj:_h@?o00000_nS^>L00ol0
003oXk_Zoj>kjP03o`0000?oYL?_00?o0000ojG7l_nUao800ol00003ojGAm`Co00000_n[h_X01?l0
003oUNgdo`000?n9k=]>oookJP?o0000JOoonfX001Wooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003oA:WgodBYm`02odBYm`03o`000?nD__CoU;kd00CoU;kd0_l00007ojO0j`03o`000?na_nCo/KoT
00;o/KoT0_l00002ojnoi@04o`000?ni_]ko0000o`0000Co]kgN0ol00003ok^ng0;o00000onh^]/0
0ol0003o_KOCo`000004okbhe@03o`000?nk^=Oo000000?o_kOA00?o0000okfed_nm]M800_nm]M82
o`0000Go_kKA00Oo0000ok^bdOnk/]7o^k;Ao`000?no/<_o000000Co_Jo<00?o0000okfdd_l00000
0onn[l/00ol0003o_:g;okb]b`02okb]b`Go00000_nkZlX00ol0003o^J_;o`000003ok^XaP03o`00
0?nk[Lco^jg<00?o^jg<00?o0000okZ[b_njZlX01?njZlX00ol0003o]jS9o`000003okVVa@;o0000
0_nhZL/01Ol0003o^:K8okRVb?nhY/So000000Co]jC600?o0000okJTaol000001?nfXlD;o`0000Oo
/Z;81?l00004ok6Rb0;o00001on`WlH00ol0003o[Yk7ojjNa`05ojjNa`03o`000?n]W/So[Ik800Co
[Ik800Co0000oj^Lb?l0003o00001?n[Wl/01?l0003oZYc9ojZLbOnZW<T3o`000004ojZQcOl0003o
ZIk<ojVNc0?o000000CoZ9k<o`000?l0003oYYc<1_nWWlh00ol0003oYYo?o`000002o`0000;oYZ7A
00?o0000ojFPdOnUX=401OnUX=44o`0000?oY:?D00?o0000oj>SeOnSXmD00onSXmD4o`0000GoXjSJ
00?o0000oj:XfonRZ=/00ol00002oj>/gP?o00000onR[Ml4o`0000KoXkSW0_l00007ojG3k`;o0000
0_nUdOL3o`0000;oY=ck00?o0000oj_Rn_l000001?l0001<oookJPCo0000K?oonfX001[ooo]Z00?o
0000oookJ_oonfX0;OoonfX01?l0003oCJWho`000?m4ZOL3o`0000GoPkok00?o0000ojO0jonW`>/0
0ol00002ojBok@04o`000?na_nCo0000o`0000Go[koU00Co0000okNmg_ng_Mko]kgN0_l00004okBl
g`03o`000?nk_]co^kkL00Go^;[K0_l00003okbhe@;o00000onk^=L00ol0003o_kOAo`000004okfe
dP03o`000?nk]M?o^kGC00?o000000?o_kKAo`000?nk/]400onk/]42o`0000?o_Jo<0_l00003okfd
dP03o`000?nn[l_o000000Co_:g;00?o0000okbbd?l000000onm[/X6o`000003ok^Xa_l0003o^jg<
00Co^jg<0_l00005okZ[bP04o`000?ngZ<Wo]jS9okNXb@?o00001OnhZL/00ol0003o^:K8o`000006
okNTaP03o`000?nfXlGo]Z?500?o]Z?500?o0000okFWbol000001OndXLD00ol0003o/jG:o`000004
ok:Sb0;o000000?o/ZC:o`000?naX/P01?naX/P2o`000003ok2Sb_l0003o/9o600;o/9o60ol00000
0on_X/_o0000ojjNa`03ojjNa`;o000000?o[J;<o`000?n]W/P01_n]W/P00ol0003oZio;oj^Ob`05
oj^Ob`?o00000_nZXLd5o`0000?oZ9k<00?o0000ojRPc_l000001onWWlh2o`0000KoYZ7A00?o0000
ojFPdOl000000_l000000onUY=Co0000o`000007ojBSe003o`000?nSXmGo000000;o00000_nTYmT0
0ol0003oXjSJoj>XfP05oj>XfP;o00000onS[=h2o`000003oj>/g_l0003oXZgO00?o00000onT]ND0
0ol0003oXkSWoj>hi`03o`0000;oY;o/00?o0000ojG3konU`nl00ol00002ojG<m004o`000?nUdOOo
0000o`0000?oY=ck0_l00002ojSWn`?o0000BooonfX3o`00073ooo]Z000KoookJP03o`000?oonf[o
oo]Z02oooo]Z00Go0000oc>Ql_l0003o0000oh>on`02o`0000?oPkok0_l00006ojBok@04o`000?n_
_nGo[koUojnoi@?o00000_n]_nL00ol0003o]kgNo`000006okBlg`Co000000Co^;[Ko`000?l0003o
00000_nf^]d00ol0003o_;SEo`000006ok^he`04o`000?nm]M;o_KGBokfedP;o00001?nk]M<5o`00
00;o^k;A00Ko0000okVbd_ni/];o0000okf_c?l00005okfddP;o00001?nl[L/01ol0003o_;;@okbb
d?nl/]3o0000okf^b_l000001Onk[<X5o`0000;o^jg<00Co0000okZ[b_njZl[o00000onjZlX5okNX
b@03o`000?nhZL_o^:W;00Go^:W;0_l00004okNTaP;o000000?o]ZW<o`000?nfXlD00_nfXlD2o`00
00?o]JO;00?o0000okBQaOndXLD00_l00003ok>UbP04o`000?nbXlSo0000o`0000Co/ZC:00Co0000
ok6Rb?naX/So00001On`XlX3o`0000Go[j;;00Co0000ojjNaol0003o00001?n]X/`01?l0003o[Ik8
ojfNb?n]W/P2o`000003ojfRc?l0003oZio;00;oZio;00?o0000oj^Obon[Wl/01_l00003ojZPc@04
o`000?nXW/coZ9k<o`0000CoZ:3>00Co0000ojNOc_nWWlkoYio>0_l000000onWXm7o0000ojJQd@05
ojJQd@?o00000_nUY=@2o`000003ojFTe?l0003oY:?D00GoY:?D0ol00006ojBWf@03o`000?nSZ=[o
XjSJ00?o000000KoY:_Lo`000?nS[=koXjcNo`000?nS[=h5o`0000OoY;GU0_l00006ojBok0;o0000
1_nUc?@01Ol0003oY=ckojCLnonTg?_o000000?oZ>Ok00?o0000ohS[jol00000BOoonfX4o`0007?o
oo]Z000LoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oc>Ql_l000000_l000001?me_Oco0000
ohNonOn7_oT5o`0000GoX;o_0_l00006ojfoi`03o`000?nd_=oo];cO00;o];cO0_l00002ok:mhP03
o`000?nk_Mco^kgL00?o00000onf^]d2o`0000Co^kSG0_l00002okZmg003o`000?nm]M;o000000Co
^kGC00?o0000okZfe_l000001?nn]M44o`0000;o^K;B00?o0000okfdd_nm]=800_nm]=82o`000003
okV`dOl0003o_:g;00;o_:g;00?o0000okbbd?nl/]000_nl/]02o`0000Go^jc:00?o0000okZad?l0
00000onk[/`7o`000003okZ[b_ngZ<Wo]jS900?o]jS90_l00005okRYb`;o000000?o]JO:o`000?ng
Y<H00_ngY<H00ol0003o]ZW<okJYc002okJYc003o`000?nfXlGo000000Go]JO;00?o0000okBQaOl0
00001OncYLX2o`0000Ko/ZC:0_l00006ok2SbP;o00001on_X//2o`0000Ko[J;<00Go0000ojfNb?l0
003o0000ojfRc008o`0000?oZj;=00?o0000ojZPcOnZX<d00onZX<d3o`0000KoZ:3>00Co0000ojNO
c_l0003o00001?nWXm401?l0003oYZ7AojJQdOnVXM46o`0000GoYJCD00?o0000ojBSe?nTXm@00ol0
00000onUYmSo0000ojBWf@07ojBWf@;o00001?nTZm`5o`0000CoY;?S00?o0000ojBeiOnT]ND00ol0
0002ojBljP03o`000?nT_ncoY;o/00?o00000onUao800ol0003oYLcdojG<m003o`0000?oY=Oi00Co
0000ojSWnol0003o00000_n8jn/00ol0003ooo]ZoookJP16oookJP?o0000MooonfX001gooo]Z0_l0
000boookJPOo00000_n1__X00ol0003oX;o_oj2ok`03o`0000;oW;oa00?o0000ojfoion]_nL00ol0
0002ojZoj@04o`000?nd_=oo0000o`0000Go/[gR00?o0000okVmgOni_Md00_ni_Md3o`0000;o/k[N
00Co0000ok^heol0003o00001?nj_M`2o`0000?o^kGC0_l00003okZfeP04o`000?nn]M7o0000o`00
00Co_;?A1Ol000000onm]=;o0000okV`d@03okV`d@03o`000?nl[L_o000000Co_;;@00?o0000okR_
d?l000000onk[<X2o`0000?o^[7@00?o0000ok^^c?l000001_njZ/X:o`0000?o^:W;00?o0000okFW
b_neYlX00_neYlX3o`0000Go]ZW<0_l00006okFWb`;o00001?ncYLX2o`000003ok>TbOl0003o/ZC:
00?o/ZC:0_l000000onbXl[o0000ok2SbP03ok2SbP;o00000_n`XlX00ol0003o[j;;ojnRb`02ojnR
b`;o000000?o[j?;o`000?n]X/`00_n]X/`00ol0003o[J;<ojfRc005o`0000?o[J;=0_l00007oj^R
c@03o`000?nZX<go000000;o00000_nZX/h00ol0003oZ:3>ojRPcP05ojRPcP03o`000?nWXm7oYj?A
00?oYj?A1?l000000onVXM7o0000o`000002ojNUe@03o`000?nUY=CoYJCD00?oYJCD1?l00005ojFW
f003o`000?nTYmWoY:OI00?o00000_nTZm`00ol0003oY:_LojB[g003o`0000;oY;;R00?o0000ojBc
honT/n<01OnT/n<2o`0000KoY;cZ0_l00007ojG7lP;o00000_nTeoT3o`0000;oYn7k00?o0000ohS[
jol000000_l00015oookJPCo0000N_oonfX001oooo]Z00?o0000oookJ_oonfX0<?oonfX5o`000003
ofVjoOl0003o000000?o00001_nL_o42o`0000KoZ[oY00?o0000ok:mh_nb_N800_nb_N82o`0000;o
/;gT00Co0000okVmgOl0003o00000onf^md2o`000003ok>jg_l0003o^[gL00?o^[gL0_l00002okJh
f`03o`000?nk]M?o000000Ko^[KF00?o0000okbcdOnl/m400_nl/m42o`0000;o^[?C00?o0000okfe
d_l000001?l00002okV`d@;o00000onl/]02o`0000?o^:o@00?o0000ok^/b_l000001Onj/M02o`00
00Go^Z[:00?o0000okV_d?l000000onjZ/X00ol0003o^:W;okRYb`02okRYb`ko00000_nfZL`00ol0
003o]JO;o`000004okFWb`;o000000?o]:K:o`000?ncYLX00_ncYLX00ol0003o/jC9ok>Tb@02ok>T
b@04o`000?nbY<[o/ZC:o`0000Co/Z?:00?o0000ok2Sb_n`XlX00on`XlX@o`0000;o[Z?=00?o0000
ojfRcOn]X/d00_n]X/d2o`000003ojbSc_l0003oZj;=00KoZj;=0_l00006ojZRcP03o`000?nXX<ko
000000;o00000_nYY=800ol0003oYj?AojNSd@03o`000003ojNSdOl0003o000000OoYjGE00?o0000
ojFTe?l000000_l00002ojJWe`03o`000?nUYmSoYJOH00GoYJOH0_l00005ojB[g0?o00001_nT/^80
0ol0003oY;?SojBch`03o`0000;oYK[X00?o0000ojBlj_nT_>X00ol00002ojG4k`03o`000?nUao;o
YLOb00?o00000onUdOL4o`0000;oYn7k00Go0000oi3[mOl0003oQn_YogOTe014oookJP?o0000O_oo
nfX0023ooo]Z00?o0000oookJ_oonfX0<OoonfX5o`0000;oF[Kl1Ol00004oiNol`03o`000?nZ_nWo
Z[oY00?o00000_nW_n/01?l0003o/[gRo`000?l00005ok2mi003o`000?nf^mgo][_M00Go][_M1?l0
00000onj_Mco0000okJhf`03okJhf`;o00001Onj]]H01Ol0003o^K_KokVkfol0003o_;?A00;o0000
1Onj/m<00ol0003o_;;@okbbd003okbbd0Go000000?o_;;@o`000?nh[m001?nh[m02o`0000Go^[7@
00?o0000okN]col000000onjZ/X2o`0000?o^Jo@00?o0000okZZb_l000001_nhZL/00ol0003o]jS9
okNXb@03okNXb@04o`000?nfZLco]ZW<o`0000?o]ZW<5ol000000onbY<[o0000o`000005o`000004
ok2Sb_l0003o0000o`0000?o/:?;0_l00005ojnSb`04o`000?n]X/co0000o`0000Go[Z?=00?o0000
ojfRcOl000001On/Xlh01?l0003oZj;=oj^RcOn[X/d2o`000003oj^UdOl0003oZZ;>00KoZZ;>0_l0
0003ojVTdPGo000000?oYj?Ao`000?l000000_nXY]@00ol0003oYjGEojNUe@05ojNUe@;o00001_nV
YmL4o`0000CoYJ_K00?o0000ojB[g?nTZm`00ol000000onU/N7o0000ojBbhP07ojBbhP;o00001_nU
^^P2o`0000KoYLC_0_l00002ojGAm`?o00000_nRg?`00ol0003oYn7ko`000002o`000003ohO[jOl0
003ooo]Z04;ooo]Z1?l00021oookJP008OoonfX00ol0003ooo]ZoookJP0coookJP?o00000om8[oP2
o`0000KoUkoc0_l00006ojNoj`03o`000?n`_NCo/;gT00;o/;gT0_l00002ojjniP03o`000?nf^mgo
][_M00?o00001?nd^ml4o`000005okJhfol0003o0000ok>igOl000000onj]]H2o`0000?o^K_K0_l0
0005okZcd`03o`000?ni]MGo000000?o_;;@0_l00005okZad@Co00000_nh[m000ol0003o^K3Ao`00
0003okZad0;o00000ong[Ll00ol0003o^Z[:o`000005okV_d0;o00001OnhZL/00ol0003o]jk@o`00
0003okNXb@;o00001?nfZL`3o`0000Go]JO;0_l00007okBVbP03o`000?ncYL[o/jG:00Go/jG:00?o
0000ok:Tb_nbY<X01OnbY<X00ol0003o/:?;ok2Sb`05ok2Sb`03o`000?n_Xl_o[j?;00Go[j?;00?o
0000ojjScOn^Xld01On^Xld00ol0003o[:?>ojbScP05ojbScP04o`000?n[X/go0000o`0000CoZjGA
00?o0000ojZRc_nZX/h02Ol00002ojRTdP?o00001_nXY]@00ol0003oYjGEojNUe@03o`0000;oYjSG
00?o0000ojJWeonVYmL00ol000000onV[=_o0000ojF[f`07ojF[f`;o00001OnU/N400ol0003oY;;R
ojBbhP03o`0000;oYKSW00?o0000ojFjj?nU^^P00ol00002ojG1kP03o`000?nUa>ooYLC_00?o0000
1?nUc_D2o`0000;oX]cl0_l00003oj7Wn`?o0000@_oonfX3o`0008Gooo]Z000RoookJP;o0000=Ooo
nfX01OmV003o0000oe>^n_mC[_[oB:oh00Co00001?n3`_`00ol0003oYko[ojNoj`03o`0000;oXko]
00Co0000ok2mi?l0003o00001On^_^H2o`0000?o];_O0ol00002ok6lhP03o`000?ni_=co^KcL00?o
00000_nc^Md00ol0003o^[KFo`000003okVkf`;o000000?o];OJo`000?nj/m<00_nj/m<2o`0000?o
^KGE00?o0000okbbd?l000001Onj/M400ol0003o^;?Do`000003ok^ad0Ko000000?o^[7@o`000?ng
[Ll01?ng[Ll2o`0000Co^Jo@0_l000000onf[<oo0000okRYb`02okRYb`;o00000ong[]000ol0003o
]jS9o`000006okJYc003o`000?neYl_o]JO;00?o]JO;00?o0000okB/d?l000001?ndY/X3o`000003
ok>Zd?l0003o/jG:00;o/jG:0ol000000onbZLoo0000ok:TbP03ok:TbP;o000000?o/JK=o`000?n`
Xl/00on`Xl/2o`000003ojnWcol0003o[j?;00?o[j?;0_l000000on^Ym3o0000ojjSc@03ojjSc@;o
000000?o[JOAo`000?n/Xlh01on/Xlh00ol0003oZjGAoj^Ud@04oj^Ud@?o000000?oZZKCo`000?l0
00000_nZY]<01?l0003oZ:CBojRTd_nXY=82o`000003ojVWe?l0003oZ:KD00OoZ:KD0_l00006ojNX
e`;o00001OnV[=/01?l0003oYJ_KojF[fonUZm/2o`000003ojF[fol0003o000000OoYK7Q0_l00006
ojFhi`;o00001_nU`Nh2o`0000?oYLke0_l00003oj;Hn`;o00000_nQio/3o`000003oggViol0003o
oo]Z03oooo]Z1?l00028oookJP009?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?mC[_[oDjkj
00Ko00000on3`_`2o`0000KoXko]00Co0000ojjni_n^_^Ko[[kV0ol00002oj^nj004o`000?nd^moo
0000o`0000Ko/KcR00?o0000okJjg?nf^]`00_nf^]`4o`0000?o^K_K00?o0000okBgf_nd]mX00_nd
]mX00ol0003o^[?Co`000006okVee@03o`000?nj/M7o^[7A00;o^[7A00?o0000okRce?nh/m@00_nh
/m@3o`0000Ko^K3@2Ol00003okV_d003o`000?nf[<oo]Zc?00;o]Zc?00?o0000okRYbol000001Ong
[]02o`0000Go]ZW<00?o0000okF^d_l000000oneYl/2o`0000?o]:c@00Co0000okBVb_l0003o0000
1OncZ]03o`0000Go/ZW?00Co0000ok:Tb_l0003o00001?naY/d01?l0003o/:?;o`000?l00004ojnW
c`04o`000?n_Xl_o0000o`0000Co[ZO@00Co0000ojjScOl0003o00001?n]Ym400ol0003o[:?>ojbS
cP03o`0000;o[JSB00?o0000oj^UdOn[YM400on[YM44o`0000GoZZKC0ol00005ojVWe003o`000?nX
Y]CoZ:KD00?o00000_nXZML00ol0003oYjSGojNXe`03o`0000;oYjgK00?o0000ojJ/fonV[=/01?nV
[=/4o`0000GoY[7P00?o0000ojFahOl000000_l00003ojJgiP03o`000?nU^>OoYKSW00?o00000_nU
_n`00ol0003oYL7^ojG1kP03o`0000?oYL[c0_l00003oj;Hn`;o00000onPi?`2o`000003oggViol0
003ooo]Z03oooo]Z0ol0002<oookJP009OoonfX00ol0003ooo]ZoookJP0foookJPCo1X_M00?o0000
og:ooOmb_od01ol00005oio0l0;o00001_n[_^P00ol0003o/KcRok6lhP02ok6lhP?o00000_n__N@0
1?l0003o][[Lo`000?l00004okBjgPCo00001?nd]mX2o`0000Co^KGE0_l00002okNjg004o`000?nj
/M7o0000o`0000Go^;?D00?o0000okV`d?ni/=000_ni/=03o`0000;o^;;C00?o0000okZ`d?l00000
1?nh[m06o`0000?o]Zc?0_l00003okN^d0?o000000?o]:_@o`000?nfZL`00_nfZL`2o`0000?o]JkB
00?o0000okFWbol000001Ond[=02o`0000Ko/j[@0_l00007ok:Yc`;o00001onaY/d00ol0003o[jO?
ojnWc`04ojnWc`;o00001_n^Ym02o`0000Oo[JOA0_l00002ojfXdPSo00001?n[Ym<00ol0003oZZKC
ojZVd`03o`000003ojZXeOl0003oZJOD00KoZJOD0_l00006ojRYe`;o00001_nW[M/00ol0003oYZcK
ojJ/f`03o`0000;oY[;P00Co0000ojJah?nV/N3oY[7P1Ol00007ojJgiP;o00001_nU_n`2o`0000;o
YL[c0ol00002oj?En@04o`000?nRf?_o0000o`0000?oX>Cl00CoQ>O`o`000?m`h=coF=2m?_oonfX4
o`0008oooo]Z000VoookJP03o`000?oonf[ooo]Z03Sooo]Z00Co0000o`J;gOl0003o00000omR^od0
0ol0003oP;oko`000002oio0l0?o00000_nI`?<00ol0003oZkkXoj^nj003o`0000;oYko[00Co0000
ok6lh_l0003o00001_n__N@00ol0003o];[NokBjgP05okBjgP05o`000?nh^]_o^;[Ko`000?nd]mX0
0_l00002ok:gg@04o`000?ni]MGo0000o`0000Co]k[L0_l00004okRce0;o00000_ng^M/01?l0003o
^K3@o`000?l00006okRbd`03o`000?nh[m3o^:o@00;o^:o@0_l000000ong/M?o0000okR^c`02okR^
c`_o00000_ndZm000ol0003o]ZW<o`000005okF^dP;o00001Ond[=000ol0003o]:_?o`000004ok>Z
d0;o000000?o/jW?ok:YconbZLl00onbZLl3o`000003ok2Wcol0003o/JK=00;o/JK=0ol000000onb
Zm;o[jO?ojnWc`03ojnWc`;o000000?o[jO@o`000?n^Ym000on^Ym02o`000003ojjWdOl0003o[JOA
00;o[JOA00?o0000ojfWdOn]Ym401Ol00003ojbWd`;o00002?n[Ym<2o`0000GoZZSE00?o0000ojVW
e?nYYm@00ol00002ojVZf003o`000?nXZMOoZ:WG00?o000000?oZ:kLo`000?nW[M/01OnW[M/3o`00
0003ojJ/fonV/^3oY[;P00CoY[;P0ol00004ojJgi@03o`000?nV]nKoY[OV00?o00000_nV_^/00ol0
003oYKo/ojFok003o`0000CoYLSb0_l00006oj?En@04o`000?nPi?co0000ohCWl0?o0000?_oonfX3
o`0009?ooo]Z000WoookJP03o`000?oonf[ooo]Z03Wooo]Z00CoDP00o`000?l0003o00000_mR^od4
o`0000KoVL3c0_l00006ojNoj`03o`000?n__NCo[kgT00;o[kgT0ol00002ojbni`03o`000?nd^]ko
];[N00?o00000_na^n400ol0003o^;[KokRjf`04o`0000;o/[OM00?o0000okNjg?ng^]`00_ng^]`2
o`0000;o/kKK00Co0000okRce?l0003o00001?ng^M/2o`0000Go^;;C0_l000000onf]m[o0000okR_
d002okR_d003o`000?ng/M?o]k7C00;o]k7C00Co0000okR^col0003o00001Onf[]400ol0003o]Zg?
okJ]c`02okJ]c`co00001?nd[=001Ol0003o]:_?okB[condZloo000000?o/j[@1?ncZLl3ok:Yc`03
o`000?n`Yloo/:O?00?o/:O?0ol00005ok:[dP?o[jO?00?o0000ojnWd?l000001Ol000000on^Ym3o
0000o`000007o`0000?o[JSB00Co0000ojbWdon/Ym?o[:OC0_l000000on/ZMCo0000oj^Wd`03oj^W
d`?o000000?oZj[Fo`000?nZZ=D01_nZZ=D2o`0000KoZJ[H0_l00005ojR^g003o`000?nW[M_oYjgK
00?o00000_nW/^000ol0003oY[;PojJbh003o`0000;oYkOT00?o0000ojJgiOnV]nD01OnV]nD2o`00
00KoY[k[0_l00003ojG8lP;o00000_nSd_P00ol0003oXmGioj?En@05o`0000?oRNOf0_l0000loook
JPCo0000U_oonfX002Sooo]Z0_l0000loookJP04oe800?l0003o0000o`0000;oCKCj1?l00004ohC4
o003o`000?nW_n_oYko[00?o00000_nS`>h01?l0003o[kgTo`000?l00006ojbni`;o00001_na^n40
0ol0003o][WLokJig003okJig0Go000000?o]k[Lo`000?nc]]/01?nc]]/00ol0003o]kWKokNif`02
okNif`;o000000?o/kCJo`000?nh/]<00onh/]<00ol0003o][OJokJgfP02okJgfP?o00001_ng/M<0
0ol0003o]ZkAokJ^d@02okJ^d@;o000000?o]K3Do`000?nf[Ll00_nf[Ll2o`0000?o]JkB00?o0000
okF^d_l000001?nd[=0Bo`000003ok:Ycol0003o000000ko000000Co[jO?o`000?l0003o00001?n_
Ym000ol0003o[ZSAojjXd@05ojjXd@03o`000?n]Z=;o[JSB00Go[JSB0_l00005ojbYe004o`000?n[
Ym?o0000o`0000GoZj[F00?o0000ojZXeOl000000_l00002ojZ/f@03o`000?nYZ]SoZJ[H00;oZJ[H
0_l000000onY/=go0000ojR^g003ojR^g0Go00001_nW/^02o`0000KoYkOT00?o0000ojJgiOnV]nD0
0ol00002ojJmjP03o`000?nV_^_oY[k[00?o00000onUa_42o`0000KoXm;h1?l00002ohWWmP;o0000
00?oLn7RoookJ_oonfX0>_oonfX3o`0009[ooo]Z000ZoookJP03o`000?oonf[ooo]Z03cooo]Z00?o
0000oeVcnomI/o/00_mI/o/4o`0000?oQ<Cl0_l00006oj?0kP03o`000?n/_^Oo[;kW00;o[;kW0ol0
0002ojRoj@03o`000?na^n7o/K_Q00?o00000_n__><00ol0003o][WLo`000002o`0000Co/kWN1Ol0
0002ok>ff`03o`000?nc^=co000000;o]kWK00?o0000ok>df_nc]=X00_nc]=X01?l0003o^;;Co`00
0?l00004okJgfP;o00001?ng/M<3o`000003okFff_l0003o]ZkA00;o]ZkA00?o0000okF`e?ne/=@0
0_ne/=@00ol0003o]Zg?o`000006okF^dP03o`000?nd[=3o]:c@00Go]:c@00?o0000okB[condZll0
0ondZll00ol0003o/jgCo`000004ok>Yc`;o000000?o/ZcBo`000?nbZ<l00onbZ<l2o`000003ok6[
d_l0003o/:_C00Go/:_C00?o0000ok2[d_l000000on_Ym03o`000003ojnZdol0003o[ZSA00;o[ZSA
0ol000000on^Z]Co0000ojfXdP03ojfXdP;o000000?o[J_Fo`000?n/ZM@01_n/ZM@00ol0003oZj[F
oj^ZeP05oj^ZeP;o00001_nZ[=T01?l0003oZJ[Ho`000?l00002ojV`g@Ko00000_nW[]`2ojRbh003
o`000?nW/^3oYk;P00?o000000?oYkOTo`000?nW]n@01onW]n@2o`0000KoY[gZ0_l00002ojG6l@;o
00000onSd?L00ol0003oXm;hoj?Bn005o`0000;oS>Ki0ol0000koookJPCo0000WOoonfX002_ooo]Z
00?o0000oookJ_oonfX0?OoonfX00ol0003o18cJo`B<fP02o`B<fP04o`000?m``?ko0000o`0000;o
R<?k1?l00004oig0l@04o`000?n/_^Oo0000o`0000KoZ;oY0_l00006ojnlh`03o`000?nc^Mko/kWN
00;o/kWN0_l00002ok2kh@04o`000?nf^M_o][WKokJif`Wo00000onc]=X2o`0000Co][OJ0_l00002
ok:cf@04o`000?ng/M?o0000o`0000Go]KKJ0ol00006okF`e003o`000?ne[];o]JkB00;o]JkB0_l0
00000ond/=Go0000okB/d003okB/d0;o000000?o/jkCo`000?ndZll00_ndZll2o`0000?o/jgC00Co
0000ok>Ycol0003o00001?nb[=801?l0003o/ZS?o`000?l00004ok6[dP04o`000?n`Zm?o/:_Cok2[
d`Go/:_B0ol00005ojnZd`?o00001On^Z]@01?l0003o[JSBo`000?l00004ojf[eP03o`000?n/ZMCo
[:WD00?o00000_n/[=L00ol0003oZj[Foj^ZeP03o`000003ojV_g?l0003oZZcI00OoZZcI00?o0000
ojV`gOl000000_l000001OnX/=go0000o`000?l0003oYjkL00KoZ;;P0_l00005ojNgi003o`000?nW
]nCoYkOT00?o00000_nV_NX00ol0003oY[gZojJmjP03o`0000?oYLG`0_l00007oj?@m`Co00000on<
i_T2o`0003_ooo]Z0ol0002QoookJP00;?oonfX00ol0003ooo]ZoookJP10oookJP03o`000?l4S=[o
000000Go000000?oOl7lo`000?nM`?401OnM`?400ol0003oZ;oYojRoj@02ojRoj@;o00000onT`>d0
0ol0003o[kcSojnlh`03o`0000;o[;gV00Co0000ok>ig_l0003o00001On`^n42o`0000Ko/kSL00Co
0000okJhf_nf^=[o][SJ1_l00002okJgfP03o`000?nb/mWo/[?I00;o/[?I0_l00006okFffP;o0000
1?ne/=@3o`000003ok>ffol0003o]JkB00;o]JkB00?o0000okB`eOnd/=D00_nd/=D01?l0003o]:c@
o`000?l00004ok>^d`03o`000?ndZloo000000Ko/jgC00?o0000ok:/d_nb[=801Onb[=800ol0003o
/J_Bok6[dP05ok6[dP03o`000?n`Zm;o/:_B00Go/:_B00?o0000ojnZdon_Z]<01On_Z]<00ol0003o
[Z[DojjZe006ojjZe003o`000?n]ZmKo[J_F00Go[J_F0_l00006ojb/e`;o00001OnY[m`00ol0003o
ZZcIojZ/f@07o`0000;oZ;3M0_l00002ojRdh@03o`000?nX/^3oZ;;P00?o00000onX^>D00ol0003o
YkOTojNgi004ojNgi0;o00001_nV_NX2o`0000;oYLG`0ol00002oj??m`03o`000?nSd?OoXm3g00?o
000000GoWm[loikMoOnNgOgo0000ohcVn@03o`0003[ooo]Z1?l0002ToookJP00;OoonfX00ol0003o
oo]ZoookJP13oookJP?o000000?oG;_lo`000?l000000ol00005oiO1m0;o00001onT`>d2o`0000Ko
[;gV00?o0000ok2khOn`^n400_n`^n42o`0000;o[[cT00?o0000ok>hg?nc^=`00ol00002ok6ig`03
o`000?nf^=[o000000Go/kKK1Ol00002ok:cf@03o`000?nc]]_o000000Co]KKJ0_l00002ok6cfP04
o`000?ne/=Co0000o`0000Go/kKK0ol00006okB`e@03o`000?nc[]?o/jkC00Go/jkC00?o0000ok>]
donc[M<00_nc[M<2o`000003ok:_e_l0003o/ZcB00?o/ZcB0_l000000ona[]Go0000ok6[dP03ok6[
dP;o000000?o/:gEo`000?n`Zm800on`Zm82o`0000;o[jgF00?o0000ojnZdon_Z]<00ol000000on^
[MKo0000ojjZe003ojjZe0?o000000?o[;3Jo`000?n]ZmH00_n]ZmH3o`000003oj^ag?l0003o[:cG
00?o[:cG0_l000000on//]go0000ojV_g002ojV_g003o`000?nY[mcoZJoL00Go00000onY/]l3o`00
00KoZ;CQ0_l00007ojRhi@?o00001OnW_^X3o`0000GoYLG`0_l00006oj??m`?o00000_nNgOd2o`00
0003ohgTnomagnOo000003[ooo]Z0ol0002XoookJP00;_oonfX2o`0004Gooo]Z0ol00003od:amP?o
00001?mla?h00ol0003oY<3]ojC0k@03o`0000?oW/7a00?o0000ojbmi_n/_NH00ol00002ojRojP04
o`000?n`^n7o0000o`0000Go[[cT0_l00006ok6ig`03o`000?nc]]_o/kKK00;o/kKK0_l00002ok6i
g`03o`000?nf]m[o][OJ00Ko00000_ne]]X00ol0003o/K?Jok6cfP02ok6cfP;o00001_nc]]/2o`00
00Co];3E0ol000000ona]]co0000ok>^d`02ok>^d`?o00000_na]=/01?l0003o/jgCo`000?l00004
ok:_eP04o`000?nb[=;o0000o`0000Co/JkE00Co0000ok6[d_l0003o00001?n`[MD01?l0003o/:_B
o`000?l00005ojn]eP;o00001On^[MH01?l0003o[Z[Do`000?l00005ojb`fP?o00001On[/M`01Ol0
003o[:cGo`000?l0003o[;;M00So00000onZ/ml00ol0003oZK;OojVbg`03o`0000;oZKGR00?o0000
ojRdhOnX]>400ol00002ojRiiP03o`000?nX^>GoZ;SU00?o00000_nW_^/00ol0003oYkkZojNnjP03
o`0000;oYLG`00?o0000ojG5l?nUaO000ol00003oj?>m`03o`000?nScoOoXlog00Co00000_nLg?d5
o`0003Wooo]Z1?l0002[oookJP00<?oonfX00ol0003ooo]ZoookJP14oookJP;o000000?oD;?jo`00
0?l000001?l00003ogc4oP;o00001onN`O42o`0000KoZ;oZ00?o0000ojjli?n^_>@00_n^_>@2o`00
00;oZ[kX00?o0000ok6igona^Ml00ol00002ojjkh`04o`000?nc]]_o0000o`0000Go/KWO0_l00005
ok>ff`Go00000_na/mX01?l0003o/[KLok:fg?l00003ok>ff`;o00000_n`/]X01?l0003o];3Eo`00
0?l00005ok6fg0?o00001Ona]=/2o`0000Oo/ZoF00?o0000ok6^eOna[]D01Ona[]D00ol0003o/:gE
ok2]e@05ok2]e@03o`000?n_[MKo[jgF00;o[jgF0_l000000on]/mgo0000ojj]eP06ojj]eP03o`00
0?n//=[o[;3J00Co[;3J0_l00006oj^ag0Ko00000_nZ/]h3o`0000OoZ[?O0_l00006ojVehP;o0000
1_nX^NH2o`0000KoYkk[0_l00006ojG5l0;o00001onSc_L3o`0000;oW=cm00Go0000ohgSo?l0003o
JmcUo`00000ioookJP?o0000[ooonfX0037ooo]Z00?o0000oookJ_oonfX0AooonfX7o`000003of2n
oOl0003o000000Co00001?nH`_@4o`0000CoXl3^00Co0000ojjli?l0003o00001OnZ_^P2o`0000Ko
[[_S00?o0000ok6igona^Ml00_na^Ml2o`0000;o[k[R00?o0000ok>ffonc]]/00ol00002ok2hg`03
o`000?nd]][o];KJ00_o00000on`/]X00ol0003o/KKLok6fg004ok6fg0?o00000ona]=/3o`000003
ojjbfol0003o/ZoF00;o/ZoF0ol00002ojnfgP03o`000?na[]Go/JkE00?o00000_n^]=d00ol0003o
/:gEok2]e@03o`0000;o[[CM00Co0000ojn]e_l0003o00001?n]/md00ol0003o[ZgFojj]eP03o`00
00;o[[CM00Co0000ojb`f_n//=[o[;3J2Ol00003oj^cgP04o`000?nZ/]koZ[;NojZbgP;o00000_nZ
]>000ol0003oZ[?OojZcg`03o`0000?oZKOS00?o0000ojVeh_nY]N800ol00002ojRki`03o`000?nX
^NKoZ;WV00?o00000_nW`>`00ol0003oYkk[ojNnj`03o`0000;oYLKa00?o0000ojG5l?nUaO000ol0
0003oj;?m`Ko00000_nJfod6o`0003Sooo]Z1?l0002boookJP00<_oonfX00ol0003ooo]ZoookJP1:
oookJPGo00000om4]?H3o`0000CoNlKn00?o0000oj?0k_nS`>h01OnS`>h01?l0003oZ[kXojZnj?nZ
_^P3o`0000;oY[o/00?o0000ojjkhon^^n<00ol00002oj^miP04o`000?na^Moo0000o`0000Go[k[R
0_l00006ok2hg`;o00001_nb]M/00ol0003o/kGJok>efP02ok>efQ?o00000_n^/]/3o`0000Go[kKN
0ol00005ojjdg@?o00001On^]=d2o`0000Ko[K?M2_l000000on//=[o0000o`000004ojbag003o`00
0?n[/mkoZk?N00GoZk?N0_l00006ojZdh0;o00001onY]n<2o`0000KoZ;_W0_l00006ojO0k0;o0000
1_nUa_42o`0000;oX/og0ol00002oi[Io@;o00000_nJfod01?n;h_co0000o`000?mUf^@2o`0003So
oo]Z0ol0002foookJP00<ooonfX00ol0003ooo]ZoookJP1=oookJP06o`000?mB]__o0000o`000?mB
]__o00000_mca?l01?l0003oNlKnog_6o_mka_h4o`0000GoWL;b0_l00006ojJok0;o00001_n[_NH0
0ol0003o[k[RojnjhP02ojnjhP;o00000_n[_>H00ol0003o/;SOok2hg`03o`0000;o[[[R00?o0000
ok:efonb]M/00ol00002ojnhg`03o`000?nc]M[o000000;o00001?n`]]d2o`0000Ko/KCK00?o0000
ok6cf_na/mX00ona/mXGo`0000;o[[CM2?l00003ojfdgP03o`000?n//mko[;?N00?o[;?N0_n/]=l0
0ol0003o[;7Lojbag003o`0000;oZkKQ00?o0000oj^cg_n[/mh00ol00002ojZgh`03o`000?nZ]>3o
Z[CP00?o00000_nY^^D00ol0003oZKOSojVgh`03o`0000;oZ;gY00?o0000ojRkionX^nL00ol00002
ojK2k@03o`000?nW`>coYl3/00?o00000onTb?800ol0003oYLKaojG6l@03o`0000?oXM3h0_l00002
oi[Io@;o00000on8hO`2o`000003ofGJi?l0003ooo]Z03Oooo]Z1?l0002ioookJP00=?oonfX2o`00
057ooo]Z1?l00004oe^oo0Ko00000on5b?d00ol0003oY[o/ojJok003o`0000?oX<7`00?o0000oj^m
i_n[_NH00ol00002ojNoj`04o`000?n_^^;o0000o`0000GoZkcV0_l00006ojjjhP;o00001_n_^=l0
0ol0003o/;KMok2fg@02ok2fg@;o00000_n^^N400ol0003o/KCKok6df`03o`0000;o[kOO00?o0000
ok6cf_na/mX00ol00002ojnfgP03o`000?n_]]ko000000;o00000on_]Md00ol0003o[[CMo`000002
o`0000?o[[CM00?o0000ojjdgOl000000_l00005ojjdg@03o`000?n]]=ko[KCN00Go[KCN00?o0000
ojbcg_n/]=l01On/]=l2o`0000KoZkKQ0_l00006ojZgh`;o00001_nY^^D2o`0000KoZ;gY0_l00006
ojK2k@;o00001onTb?82o`0000;oXM3h0_l00003oiOJoP;o00000_n8hO`3o`000003oecDgol0003o
oo]Z03Oooo]Z0ol0002moookJP00=_oonfX00ol0003ooo]ZoookJP1BoookJP?o00001OmV__h3o`00
00?oQLSm0_l00007oj31l0;o00001_nW_n/01?l0003oZkcVoj^li_n[_>H3o`0000;oYko[00?o0000
ojjjh_n^^^800ol00002oj^mi`03o`000?n_^=oo[kSO00?o00000_n]^n@01?l0003o/;KMo`000?l0
0005ojjih@;o00001_n_]ml2o`0000Ko[kKN00?o0000ojnegOn_]Md01On_]Md00ol0003o[[CMojjd
g@05ojjdg@03o`000?n^]=go[[CM00;o[[CM0ol000000on/^>;o0000ojfdgP02ojfdgP?o000000Co
ZkSRo`000?n/]=oo[;CO0ol00003oj^ii003o`000?n[]^7oZkKQ00?o00000_nY^^H00ol0003oZ[OS
ojZgh`03o`0000;oZ;gX00?o0000ojVjiOnY^^D00ol00002ojO0j`03o`000?nX_NWoZ;gY00?o0000
0_nUa>l00ol0003oY/;]ojK2k@03o`0000;oXl[d00?o0000ojC8l_nTb?800ol00003oioAn@;o0000
0_nGf_h3o`0000?oP^3j1?l0000goookJPCo0000`?oonfX003Oooo]Z00?o0000oookJ_oonfX0E?oo
nfX2o`000004o`BAd_l0003o0000o`0000CoJ/Cn1ol00004oiW3m@Co00001OnR`Nl2o`0000KoYko[
0_l00006oj^mi`;o00001_n]^n@00ol0003o[[WQojjih@02ojjih@;o00000_n[_>D00ol0003o[kOO
ojngg`03o`0000;o[;[T00?o0000ojnfg_n_]]h00ol00002ojfihP03o`000?n_]Mgo[kGM00?o0000
0_n]^>800ol0003o[[CMojjdg@03o`0000;o[KSQ00Co0000ojjdgOl0003o00001On/^>83o`0000Go
ZkSR0_l00007oj^ii0;o00001_nY^^H2o`0000KoZ;gX0_l00006ojO0j`;o00001_nUa>l2o`0000Ko
Xl[d0_l00002oioAn@?o00000on<g?h2o`0000;oP^3j00?o0000odo=eolY/[40>OoonfX3o`000<Co
oo]Z000hoookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX00ooonfX01?mA003o197B
o`000?l00005od^km`Co00001?mjb?l00ol0003oX/7_oj;1k`03o`0000;oVlCd00?o0000ojNojonW
_n/00ol00003oj;2k`03o`000?n[_NOoZkgW00?o00000_nW_n/00ol0003o[K_Tojfki003o`0000;o
ZKgX00Co0000ojjihOl0003o00001On[_>D2o`0000Ko[;[T0_l00006ojfihP;o00001_n]^>82o`00
00Ko[KSQ00?o0000ojbhh_n/^>801On/^>800ol0003oZkSRoj^hhP02oj^hhP;o00000_nY_NP00ol0
003oZkWToj^ii003o`0000;oZ;kY00?o0000ojVji_nY^^H00ol00002ojO0k003o`000?nX_NSoZ;gX
00?o00000_nV`nh00ol0003oYl3[ojO0j`03o`0000?oY<Ob00?o0000ojG4konUa>l00ol00003oj7=
mP?o00001OnMdo/2o`0000;oS=cn00Go0000og[Nn?l0003o0000ock2b`0koookJPCo0000aooonfX0
03Wooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z00Oooo]Z00?oA@00o`000?l000000_mH_?`6o`00
00?oN/So0_l00006oi_4m0;o00001onR`^l2o`0000KoYko[0_l00006ojVmj004o`000?n[_>GoZkcU
oj^li@?o00000_nW_n/00ol0003o[;[Tojbji003o`0000;oZKkX00?o0000ojfih_n]^N800ol00002
ojZmi`03o`000?n]^>;o[KSR00?o00000_nZ_>H00ol0003o[KSQojfhh@03o`0000;oZ[cV00?o0000
ojbhh_n/^>800ol00002ojZli`04o`000?n[^>;o0000o`0000GoZKgX0_l00006ojRnj@;o00001_nW
`>`2o`0000KoY/?^0_l00007ojC7lP;o00000_nQcOH2o`0000?oTmOn1ol00003ofgJlP?o0000>ooo
nfX3o`000<_ooo]Z000koookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX03OoonfX0
1?l0003o07njo`1o^_l0OkX3o`0000;oE;oj1?l00005ogg9o`Co00001?nKaOD4o`0000CoXL?a00?o
0000ojVmj?nY_NP00ol00003ojG1k@;o00001_nW_n/2o`0000KoZKkX0_l00006ojZmi`;o00001_nZ
_>H2o`0000KoZ[cV0_l00006ojZli`04o`000?nY_NSoZKgXojVmj0?o00000_nV`^h00ol0003oZ;kY
ojRnj@03o`0000;oYLC`00?o0000ojO0k?nW`>`00ol00002oj?7lP03o`000?nV`nkoY/?^00?o0000
0onQboD4o`0000CoW]3i0_l00002oi?GoPSo00000_m]f_800ol0003o:[>ioookJP0koookJPCo0000
c_oonfX003cooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0BoookJP;o00000_mO
`?d;o`0000;oVlGe0ol00002ogc;o`03o`000?nQ`o7oXL?a00GoXL?a0_l00002ojG1k@;o00000_nN
aO<00ol0003oYko[ojNoj`03o`0000?oX/?`00?o0000ojVnj?nY_^P00ol00002ojG2kP03o`000?nZ
_NOoZ[gW00?o00000_nV`Nd00ol0003oZ[cVojZliP03o`0000;oY/7/00?o0000ojZli_nZ_>H00ol0
0003ojO1k0?o00001OnV`Nd2o`0000KoY/;^0_l00006ojG4l0;o00001_nSao82o`0000;oXL_e0ol0
0003oi3FoP?o000000?oS=Woo`000?n2fOh00_n2fOh5o`0000;o@/GF0_l0000noookJP?o0000d_oo
nfX003gooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0HoookJP?o08Fm0ol00002
oeO1nP?o00001_mlbol4o`0000CoRLcn0_l00006oik5l`;o00001onR`o02o`0000KoYL;^0_l00006
ojK1k@;o00001_nV`N`2o`0000;oYl7/0ol00002oj;6l`03o`000?nV`NgoY/7]00?o00000_nQao<0
0ol0003oY/;^ojK2kP03o`0000;oX<We00?o0000ojG4l?nUa?000ol00003oio<m`?o00001OnLcoT2
o`0000CoT=Kn1?l00002oh;IoP04o`000?mcf_Wo0000o`0004?ooo]Z1?l0003EoookJP00?_oonfX0
0ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z027ooo]Z1?l00005ogS8o`co00001On4cOl4
o`0000CoV/Og1?l00004oik7m0Co00001?nPa_<4o`0000GoXLKc0_l00006oj;6l`;o00001_nQao<2
o`0000KoX<We0_l00002oio<m`;o00001?n8eOl3o`000003ohKHoomjeokoN]On00;oN]On0_l00002
ohCIoPCo0000A_oonfX3o`000=Wooo]Z000ooookJP;o0000C?oonfX00ol0003ooo]ZoookJP0Voook
JPCo00000omM`_`2o`0000GoLLWo3?l00004og[>o`03o`000?nNaoCoW/Od00?o00000_n2col00ol0
003oX<Kcoj36l`03o`0000;oQm3o00?o0000oj76lonQa_<00ol00003oh_@oPCo00001?n<dOh4o`00
00CoS=;n1?l00004oh_Co`;o00000on8eOl2o`000003og_Go_l0003o000000Go000000?o6:Jgo`00
0?m70000B_oonfX3o`000=cooo]Z0011oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oo
nfX0;_oonfX00oll003o0000o`000003o`0000?o2Y[:0ol00003ofG8o@Go00000omjc_l2o`0000Ko
P/oo0_l00006ohO@o`;o00000_n;d?h7o`000003ohcAo_l0003o000000Go000000?oS=;no`000?l0
00001_l00003oh7Fo`So000000?o9;37oa800?lB0000C_oonfX4o`000=oooo]Z0012oookJP03o`00
0?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0?OoonfX4o``00003o`000?mbc?ooL/co00Go2ic5
1ol00004oh7@o`Co00001?n4dOl5ofO>n`03o`000?n5d_ooQM;o00GoIm3j00Ko0000ohCDoon4e?oo
Hm3ho`000?l1001KoookJP?o0000hooonfX004?ooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003o
oo]ZoookJP36oookJPCo0000i_oonfX004Cooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]Z
oookJP33oookJP?o0000j_oonfX004Gooo]Z0_l00016oookJP03o`000?oonf[ooo]Z0;oooo]Z1?l0
003]oookJP00AooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z0;cooo]Z0ol0003a
oookJP00B?oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z0;Sooo]Z1?l0003doook
JP00BOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z0;Gooo]Z0ol0003hoookJP00
B_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0003koookJP00Booo
nfX2o`00043ooo]Z00?o0000oookJ_oonfX0[_oonfX3o`000?oooo]Z001=oookJP03o`000?oonf[o
oo]Z03gooo]Z00?o0000oookJ_oonfX0Z_oonfX4o`000?oooo]Z0ooonfX004kooo]Z00?o0000oook
J_oonfX0??oonfX00ol0003ooo]ZoookJP2WoookJP?o0000oooonfX7oookJP00CooonfX00ol0003o
oo]ZoookJP0koookJP03o`000?oonf[ooo]Z0:?ooo]Z1?l0003ooookJP[ooo]Z001@oookJP;o0000
>_oonfX00ol0003ooo]ZoookJP2QoookJP?o0000oooonfX>oookJP00D_oonfX00ol0003ooo]Zoook
JP0goookJP03o`000?oonf[ooo]Z09gooo]Z1?l0003ooookJQ7ooo]Z001CoookJP03o`000?oonf[o
oo]Z03Kooo]Z00?o0000oookJ_oonfX0V_oonfX3o`000?oooo]Z5OoonfX005Cooo]Z00?o0000oook
J_oonfX0=OoonfX00ol0003ooo]ZoookJP2FoookJPCo0000oooonfXHoookJP00EOoonfX00ol0003o
oo]ZoookJP0doookJP03o`000?oonf[ooo]Z09?ooo]Z0ol0003ooookJQcooo]Z001FoookJP;o0000
=?oonfX00ol0003ooo]ZoookJP2?oookJPCo0000oooonfXOoookJP00F?oonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z08cooo]Z0ol0003ooookJR?ooo]Z001IoookJP03o`000?oonf[o
oo]Z033ooo]Z00?o0000oookJ_oonfX0R?oonfX4o`000?oooo]Z9_oonfX005[ooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP25oookJP?o0000oooonfXZoookJP00FooonfX00ol0003o
oo]ZoookJP0^oookJP03o`000?oonf[ooo]Z087ooo]Z1?l0003ooookJRgooo]Z001LoookJP;o0000
;_oonfX00ol0003ooo]ZoookJP1noookJP?o0000oooonfXaoookJP00G_oonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z07[ooo]Z1?l0003ooookJSCooo]Z001OoookJP03o`000?oonf[o
oo]Z02[ooo]Z00?o0000oookJ_oonfX0MooonfX3o`000?oooo]Z>?oonfX0063ooo]Z00?o0000oook
J_oonfX0:OoonfX00ol0003ooo]ZoookJP1coookJPCo0000oooonfXkoookJP00HOoonfX00ol0003o
oo]ZoookJP0XoookJP03o`000?oonf[ooo]Z073ooo]Z0ol0003ooookJSoooo]Z001RoookJP;o0000
:?oonfX00ol0003ooo]ZoookJP1/oookJPCo0000oooonfY2oookJP00I?oonfX00ol0003ooo]Zoook
JP0UoookJP03o`000?oonf[ooo]Z06Wooo]Z0ol0003ooookJTKooo]Z001UoookJP03o`000?oonf[o
oo]Z02Cooo]Z00?o0000oookJ_oonfX0IOoonfX4o`000?oooo]ZBOoonfX006Kooo]Z00?o0000oook
J_oonfX08ooonfX00ol0003ooo]ZoookJP1RoookJP?o0000oooonfY=oookJP00IooonfX2o`0002?o
oo]Z00?o0000oookJ_oonfX0G_oonfX4o`000?oooo]ZD?oonfX006Wooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP1LoookJP?o0000oooonfYDoookJP00J_oonfX00ol0003ooo]Zoook
JP0NoookJP03o`000?oonf[ooo]Z05Sooo]Z1?l0003ooookJUOooo]Z001[oookJP03o`000?oonf[o
oo]Z01gooo]Z00?o0000oookJ_oonfX0EOoonfX3o`000?oooo]ZFooonfX006cooo]Z00?o0000oook
J_oonfX07?oonfX00ol0003ooo]ZoookJP1AoookJPCo0000oooonfYNoookJP00KOoonfX2o`0001co
oo]Z00?o0000oookJ_oonfX0C_oonfX3o`000?oooo]ZH_oonfX006oooo]Z00?o0000oookJ_oonfX0
6OoonfX00ol0003ooo]ZoookJP1:oookJPCo0000oooonfYUoookJP00L?oonfX00ol0003ooo]Zoook
JP0HoookJP03o`000?oonf[ooo]Z04Oooo]Z0ol0003ooookJVWooo]Z001aoookJP03o`000?oonf[o
oo]Z01Oooo]Z00?o0000oookJ_oonfX0A?oonfX3o`000?oooo]ZK?oonfX007;ooo]Z00?o0000oook
J_oonfX05_oonfX00ol0003ooo]ZoookJP10oookJPCo0000oooonfY_oookJP00LooonfX2o`0001Ko
oo]Z00?o0000oookJ_oonfX0?OoonfX3o`000?oooo]ZLooonfX007Gooo]Z00?o0000oookJ_oonfX0
4ooonfX00ol0003ooo]ZoookJP0ioookJPCo0000oooonfYfoookJP00M_oonfX00ol0003ooo]Zoook
JP0BoookJP03o`000?oonf[ooo]Z03Kooo]Z0ol0003ooookJW[ooo]Z001goookJP03o`000?oonf[o
oo]Z017ooo]Z00?o0000oookJ_oonfX0<_oonfX4o`000?oooo]ZOOoonfX007Sooo]Z00?o0000oook
J_oonfX04?oonfX00ol0003ooo]ZoookJP0_oookJP?o0000oooonfZ1oookJP00NOoonfX2o`00013o
oo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?oooo]ZQ?oonfX007_ooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP0XoookJP?o0000oooonfZ8oookJP00O?oonfX00ol0003ooo]Zoook
JP0<oookJP03o`000?oonf[ooo]Z02Cooo]Z1?l0003ooookJX_ooo]Z001moookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX08OoonfX3o`000?oooo]ZSooonfX007kooo]Z0_l0000;oook
JP03o`000?oonf[ooo]Z01gooo]Z1?l0003ooookJY;ooo]Z0020oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX06ooonfX3o`000?oooo]ZU_oonfX0087ooo]Z00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP0GoookJPCo0000oooonfZIoookJP00P_oonfX00ol0003ooo]Zoook
JP05oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0003ooookJYgooo]Z0023oookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX04?oonfX4o`000?oooo]ZX?oonfX008Cooo]Z0_l00004oook
JP03o`000?oonf[ooo]Z00gooo]Z0ol0003ooookJZCooo]Z0026oookJP05o`000?oonf[ooo]Zoook
J_l000002ooonfX4o`000?oooo]ZYooonfX008Oooo]Z00Co0000oookJ_oonf[o00002?oonfX3o`00
0?oooo]ZZooonfX008Sooo]Z00?o0000oookJ_l000001?oonfX4o`000?oooo]Z[_oonfX008Wooo]Z
0_l000001?oonf[o0000o`000?l0003ooookJ[;ooo]Z002:oookJP;o0000oooonfZeoookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {378.688, 0}} -> {0.00392505, 0.143336, \
0.0017332, 0.0017332}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(p2 = 
      ContourPlot3D[
        Abs[HAtom[3, 2, 1, SphericalCoords[x, y, z]]], {x, \(-10\), 10}, {y, 
          epsilon, 10}, {z, \(-epsilon\), \(-10\)}, MaxRecursion \[Rule] 2, 
        PlotPoints -> {7, 7}, Contours -> {0.95  pdens[\([1]\)]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .65926 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00445854 1.00446 -0.143979 1.00446 [
[ 0 0 0 0 ]
[ 1 .65926 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02168 .27949 m
0 .45986 L
s
0 .45986 m
.23973 .65926 L
s
.23973 .65926 m
.24993 .48772 L
s
.24993 .48772 m
.02168 .27949 L
s
.80488 0 m
.97794 .26024 L
s
.97794 .26024 m
1 .44134 L
s
1 .44134 m
.82069 .18956 L
s
.82069 .18956 m
.80488 0 L
s
.02168 .27949 m
0 .45986 L
s
0 .45986 m
.82069 .18956 L
s
.82069 .18956 m
.80488 0 L
s
.80488 0 m
.02168 .27949 L
s
.24993 .48772 m
.97794 .26024 L
s
.97794 .26024 m
1 .44134 L
s
1 .44134 m
.23973 .65926 L
s
.23973 .65926 m
.24993 .48772 L
s
0 0 m
1 0 L
1 .65926 L
0 .65926 L
closepath
clip
newpath
.5 Mabswid
.705 .588 .723 r
.40577 .41792 m .4136 .41785 L p .41671 .41013 L F P
0 g
s
.705 .588 .723 r
.40464 .41439 m .40577 .41792 L p .41671 .41013 L F P
0 g
s
.704 .558 .686 r
.4136 .41785 m .40577 .41792 L .40747 .4243 L closepath p F P
0 g
s
.709 .579 .707 r
.40464 .41439 m .40091 .41788 L .40577 .41792 L closepath p F P
0 g
s
.709 .561 .684 r
.40706 .4248 m .40747 .4243 L .40577 .41792 L p F P
0 g
s
.709 .561 .684 r
.39475 .4247 m .40706 .4248 L p .40577 .41792 L F P
0 g
s
.709 .561 .684 r
.40577 .41792 m .40091 .41788 L .39475 .4247 L p F P
0 g
s
.705 .588 .723 r
.41671 .41013 m .40981 .41019 L .40464 .41439 L p F P
0 g
s
.706 .59 .724 r
.40981 .41019 m .40314 .41022 L .40464 .41439 L closepath p F P
0 g
s
.71 .591 .721 r
.40091 .41788 m .40464 .41439 L .40314 .41022 L p F P
0 g
s
.71 .591 .721 r
.39198 .41778 m .40091 .41788 L p .40314 .41022 L F P
0 g
s
.71 .562 .685 r
.39383 .42469 m .39475 .4247 L .40091 .41788 L p F P
0 g
s
.71 .562 .685 r
.40091 .41788 m .39198 .41778 L .39383 .42469 L p F P
0 g
s
.704 .575 .708 r
.41805 .41389 m .4136 .41785 L .41929 .41778 L closepath p F P
0 g
s
.703 .556 .685 r
.41929 .41778 m .4136 .41785 L .40747 .4243 L p F P
0 g
s
.705 .588 .723 r
.4136 .41785 m .41805 .41389 L .41671 .41013 L p F P
0 g
s
.699 .584 .723 r
.41805 .41389 m .41929 .41778 L p .43001 .40977 L F P
0 g
s
.699 .584 .723 r
.43001 .40977 m .42309 .40997 L .41805 .41389 L p F P
0 g
s
.701 .586 .724 r
.42309 .40997 m .41671 .41013 L .41805 .41389 L closepath p F P
0 g
s
.71 .591 .721 r
.39121 .4154 m .39198 .41778 L p .40314 .41022 L F P
0 g
s
.715 .582 .705 r
.39121 .4154 m .38889 .41769 L .39198 .41778 L closepath p F P
0 g
s
.715 .565 .683 r
.38316 .42438 m .39383 .42469 L .39198 .41778 L p F P
0 g
s
.715 .565 .683 r
.39198 .41778 m .38889 .41769 L .38316 .42438 L p F P
0 g
s
.71 .591 .721 r
.40314 .41022 m .39734 .41015 L .39121 .4154 L p F P
0 g
s
.711 .592 .721 r
.39734 .41015 m .38928 .41003 L .39121 .4154 L closepath p F P
0 g
s
.716 .593 .718 r
.38889 .41769 m .39121 .4154 L .38928 .41003 L p F P
0 g
s
.699 .584 .723 r
.41929 .41778 m .42716 .41755 L p .43001 .40977 L F P
0 g
s
.698 .554 .686 r
.42716 .41755 m .41929 .41778 L .42089 .42383 L closepath p F P
0 g
s
.703 .556 .685 r
.42018 .42464 m .42089 .42383 L .41929 .41778 L p F P
0 g
s
.703 .556 .685 r
.40759 .4248 m .42018 .42464 L p .41929 .41778 L F P
0 g
s
.703 .556 .685 r
.40747 .4243 m .40759 .4248 L p .41929 .41778 L F P
0 g
s
.716 .593 .718 r
.3779 .41736 m .38889 .41769 L p .38928 .41003 L F P
0 g
s
.716 .565 .684 r
.37975 .42428 m .38316 .42438 L .38889 .41769 L p F P
0 g
s
.716 .565 .684 r
.38889 .41769 m .3779 .41736 L .37975 .42428 L p F P
0 g
s
.704 .62 .76 r
.40314 .41022 m .40981 .41019 L p .41282 .40114 L F P
0 g
s
.704 .62 .76 r
.40175 .4068 m .40314 .41022 L p .41282 .40114 L F P
0 g
s
.709 .607 .74 r
.40175 .4068 m .39734 .41015 L .40314 .41022 L closepath p F P
0 g
s
.704 .604 .741 r
.41516 .40631 m .40981 .41019 L .41671 .41013 L closepath p F P
0 g
s
.704 .62 .76 r
.40981 .41019 m .41516 .40631 L .41282 .40114 L p F P
0 g
s
.709 .622 .758 r
.39734 .41015 m .40175 .4068 L .39917 .40116 L p F P
0 g
s
.709 .622 .758 r
.38928 .41003 m .39734 .41015 L p .39917 .40116 L F P
0 g
s
.699 .616 .761 r
.41671 .41013 m .42309 .40997 L p .4262 .40085 L F P
0 g
s
.699 .616 .761 r
.41516 .40631 m .41671 .41013 L p .4262 .40085 L F P
0 g
s
.698 .57 .707 r
.43145 .41389 m .42716 .41755 L .43254 .41737 L closepath p F P
0 g
s
.697 .551 .685 r
.43254 .41737 m .42716 .41755 L .42089 .42383 L p F P
0 g
s
.699 .584 .723 r
.42716 .41755 m .43145 .41389 L .43001 .40977 L p F P
0 g
s
.709 .622 .758 r
.38832 .40766 m .38928 .41003 L p .39917 .40116 L F P
0 g
s
.715 .609 .738 r
.38832 .40766 m .38552 .40989 L .38928 .41003 L closepath p F P
0 g
s
.716 .593 .718 r
.37777 .41696 m .3779 .41736 L p .38928 .41003 L F P
0 g
s
.716 .593 .718 r
.38928 .41003 m .38552 .40989 L .37777 .41696 L p F P
0 g
s
.699 .599 .741 r
.42857 .40616 m .42309 .40997 L .43001 .40977 L closepath p F P
0 g
s
.699 .616 .761 r
.42309 .40997 m .42857 .40616 L .4262 .40085 L p F P
0 g
s
.707 .55 .673 r
.40747 .4243 m .40706 .4248 L .40759 .4248 L closepath p F P
0 g
s
.695 .582 .724 r
.43741 .40944 m .43001 .40977 L .43145 .41389 L closepath p F P
0 g
s
.694 .578 .721 r
.43145 .41389 m .43254 .41737 L p .44307 .40915 L F P
0 g
s
.694 .578 .721 r
.44307 .40915 m .43741 .40944 L .43145 .41389 L p F P
0 g
s
.694 .578 .721 r
.43254 .41737 m .44177 .41692 L p .44307 .40915 L F P
0 g
s
.692 .548 .685 r
.44177 .41692 m .43254 .41737 L .43429 .42409 L closepath p F P
0 g
s
.697 .551 .685 r
.4342 .42419 m .43429 .42409 L .43254 .41737 L p F P
0 g
s
.697 .551 .685 r
.42108 .42462 m .4342 .42419 L p .43254 .41737 L F P
0 g
s
.697 .551 .685 r
.42089 .42383 m .42108 .42462 L p .43254 .41737 L F P
0 g
s
.716 .593 .718 r
.38552 .40989 m .37514 .40953 L .37777 .41696 L closepath p F P
0 g
s
.721 .584 .702 r
.37777 .41696 m .37742 .41733 L .3779 .41736 L closepath p F P
0 g
s
.722 .596 .715 r
.37742 .41733 m .37777 .41696 L .37514 .40953 L p F P
0 g
s
.721 .569 .682 r
.37208 .4239 m .37975 .42428 L .3779 .41736 L p F P
0 g
s
.721 .569 .682 r
.3779 .41736 m .37742 .41733 L .37208 .4239 L p F P
0 g
s
.701 .53 .653 r
.42018 .42464 m .40759 .4248 L .40878 .43103 L p F P
0 g
s
.706 .533 .652 r
.40286 .43101 m .40878 .43103 L .40759 .4248 L p F P
0 g
s
.706 .533 .652 r
.40759 .4248 m .40706 .4248 L .40286 .43101 L p F P
0 g
s
.708 .541 .661 r
.39504 .43096 m .40286 .43101 L .40706 .4248 L p F P
0 g
s
.708 .541 .661 r
.39404 .42568 m .39504 .43096 L p .40706 .4248 L F P
0 g
s
.708 .541 .661 r
.40706 .4248 m .39475 .4247 L .39404 .42568 L p F P
0 g
s
.715 .608 .736 r
.38552 .40989 m .38832 .40766 L p .37488 .40891 L F P
0 g
s
.715 .608 .736 r
.37488 .40891 m .37514 .40953 L .38552 .40989 L p F P
0 g
s
.722 .596 .715 r
.36667 .41674 m .37742 .41733 L p .37514 .40953 L F P
0 g
s
.723 .578 .692 r
.36537 .42356 m .37208 .4239 L .37742 .41733 L p F P
0 g
s
.723 .578 .692 r
.36429 .41946 m .36537 .42356 L p .37742 .41733 L F P
0 g
s
.723 .578 .692 r
.37742 .41733 m .36667 .41674 L .36429 .41946 L p F P
0 g
s
.701 .546 .673 r
.42089 .42383 m .42018 .42464 L .42108 .42462 L closepath p F P
0 g
s
.709 .543 .661 r
.39475 .4247 m .39383 .42469 L .39404 .42568 L closepath p F P
0 g
s
.715 .545 .658 r
.39073 .43086 m .39404 .42568 L .39383 .42469 L p F P
0 g
s
.715 .545 .658 r
.38101 .4306 m .39073 .43086 L p .39383 .42469 L F P
0 g
s
.715 .545 .658 r
.38057 .42819 m .38101 .4306 L p .39383 .42469 L F P
0 g
s
.715 .545 .658 r
.39383 .42469 m .38316 .42438 L .38057 .42819 L p F P
0 g
s
.704 .62 .76 r
.41282 .40114 m .41033 .40115 L .40175 .4068 L p F P
0 g
s
.705 .621 .761 r
.41033 .40115 m .39917 .40116 L .40175 .4068 L closepath p F P
0 g
s
.695 .612 .759 r
.43001 .40977 m .43741 .40944 L p .43934 .4003 L F P
0 g
s
.695 .612 .759 r
.42857 .40616 m .43001 .40977 L p .43934 .4003 L F P
0 g
s
.701 .53 .653 r
.40878 .43103 m .41568 .43094 L .42018 .42464 L p F P
0 g
s
.7 .528 .652 r
.42108 .42462 m .42018 .42464 L .41568 .43094 L p F P
0 g
s
.7 .528 .652 r
.41568 .43094 m .42225 .43083 L .42108 .42462 L p F P
0 g
s
.695 .525 .653 r
.4342 .42419 m .42108 .42462 L .42225 .43083 L p F P
0 g
s
.709 .622 .758 r
.39917 .40116 m .39777 .40114 L .38832 .40766 L p F P
0 g
s
.709 .622 .758 r
.39777 .40114 m .38832 .40766 L .38539 .40122 L p F P
0 g
s
.715 .608 .736 r
.38832 .40766 m .38539 .40122 L .37488 .40891 L p F P
0 g
s
.699 .616 .761 r
.4262 .40085 m .4237 .40092 L .41516 .40631 L p F P
0 g
s
.7 .619 .762 r
.4237 .40092 m .41282 .40114 L .41516 .40631 L closepath p F P
0 g
s
.713 .538 .651 r
.39404 .42568 m .39073 .43086 L .39504 .43096 L closepath p F P
0 g
s
.72 .611 .734 r
.37488 .40891 m .37421 .40948 L .37514 .40953 L closepath p F P
0 g
s
.722 .596 .715 r
.37514 .40953 m .37421 .40948 L .36667 .41674 L p F P
0 g
s
.715 .545 .658 r
.38316 .42438 m .37975 .42428 L .38057 .42819 L closepath p F P
0 g
s
.719 .622 .749 r
.37421 .40948 m .37488 .40891 L .37195 .40233 L p F P
0 g
s
.719 .622 .749 r
.37195 .40233 m .3636 .40884 L .37421 .40948 L p F P
0 g
s
.722 .607 .729 r
.36344 .41657 m .36667 .41674 L .37421 .40948 L p F P
0 g
s
.722 .607 .729 r
.36142 .41077 m .36344 .41657 L p .37421 .40948 L F P
0 g
s
.722 .607 .729 r
.37421 .40948 m .3636 .40884 L .36142 .41077 L p F P
0 g
s
.692 .564 .705 r
.44486 .41439 m .44177 .41692 L .44557 .41671 L closepath p F P
0 g
s
.69 .545 .683 r
.44557 .41671 m .44177 .41692 L .43429 .42409 L p F P
0 g
s
.694 .578 .721 r
.44177 .41692 m .44486 .41439 L .44307 .40915 L p F P
0 g
s
.713 .638 .772 r
.37488 .40891 m .38539 .40122 L .38522 .40088 L p F P
0 g
s
.713 .638 .772 r
.37195 .40233 m .37488 .40891 L p .38522 .40088 L F P
0 g
s
.695 .612 .759 r
.43741 .40944 m .44198 .40635 L .43934 .4003 L p F P
0 g
s
.694 .594 .739 r
.44198 .40635 m .43741 .40944 L .44307 .40915 L closepath p F P
0 g
s
.721 .548 .655 r
.37918 .43052 m .38057 .42819 L .37975 .42428 L p F P
0 g
s
.721 .548 .655 r
.36821 .43 m .37918 .43052 L p .37975 .42428 L F P
0 g
s
.721 .548 .655 r
.37975 .42428 m .37208 .4239 L .36821 .43 L p F P
0 g
s
.695 .612 .759 r
.43934 .4003 m .43806 .40036 L .42857 .40616 L p F P
0 g
s
.696 .615 .762 r
.43806 .40036 m .4262 .40085 L .42857 .40616 L closepath p F P
0 g
s
.688 .572 .719 r
.44486 .41439 m .44557 .41671 L p .45591 .40828 L F P
0 g
s
.688 .572 .719 r
.45591 .40828 m .45301 .40849 L .44486 .41439 L p F P
0 g
s
.69 .575 .722 r
.45301 .40849 m .44307 .40915 L .44486 .41439 L closepath p F P
0 g
s
.69 .545 .683 r
.43429 .42409 m .43432 .42419 L p .44557 .41671 L F P
0 g
s
.695 .54 .673 r
.43429 .42409 m .4342 .42419 L .43432 .42419 L closepath p F P
0 g
s
.693 .522 .652 r
.43432 .42419 m .4342 .42419 L .42939 .4306 L p F P
0 g
s
.695 .525 .653 r
.42225 .43083 m .42939 .4306 L .4342 .42419 L p F P
0 g
s
.722 .577 .692 r
.36667 .41674 m .36344 .41657 L .36429 .41946 L closepath p F P
0 g
s
.69 .545 .683 r
.43432 .42419 m .4473 .42349 L .44557 .41671 L p F P
0 g
s
.688 .519 .653 r
.44769 .42544 m .4473 .42349 L .43432 .42419 L p F P
0 g
s
.688 .519 .653 r
.4442 .42992 m .44769 .42544 L p .43432 .42419 L F P
0 g
s
.688 .519 .653 r
.43432 .42419 m .43547 .43038 L .4442 .42992 L p F P
0 g
s
.693 .522 .652 r
.42939 .4306 m .43547 .43038 L .43432 .42419 L p F P
0 g
s
.688 .572 .719 r
.44557 .41671 m .45772 .41587 L p .45591 .40828 L F P
0 g
s
.686 .542 .684 r
.45772 .41587 m .44557 .41671 L .4473 .42349 L p F P
0 g
s
.691 .592 .741 r
.44198 .40635 m .44307 .40915 L .45301 .40849 L p F P
0 g
s
.727 .597 .711 r
.36142 .41077 m .35632 .41602 L .36344 .41657 L closepath p F P
0 g
s
.729 .579 .686 r
.36141 .42328 m .36429 .41946 L .36344 .41657 L p F P
0 g
s
.729 .579 .686 r
.35108 .42256 m .36141 .42328 L p .36344 .41657 L F P
0 g
s
.729 .579 .686 r
.36344 .41657 m .35632 .41602 L .35108 .42256 L p F P
0 g
s
.727 .571 .678 r
.36429 .41946 m .36141 .42328 L .36537 .42356 L closepath p F P
0 g
s
.721 .548 .655 r
.36666 .42992 m .36821 .43 L .37208 .4239 L p F P
0 g
s
.721 .548 .655 r
.37208 .4239 m .36537 .42356 L .36666 .42992 L p F P
0 g
s
.721 .607 .728 r
.3636 .40884 m .36061 .40867 L .36142 .41077 L closepath p F P
0 g
s
.728 .607 .723 r
.35632 .41602 m .36142 .41077 L .36061 .40867 L p F P
0 g
s
.692 .61 .76 r
.43934 .4003 m .44198 .40635 L .45251 .40009 L p F P
0 g
s
.691 .592 .741 r
.4554 .40693 m .45251 .40009 L .44198 .40635 L p F P
0 g
s
.691 .592 .741 r
.45301 .40849 m .4554 .40693 L p .44198 .40635 L F P
0 g
s
.719 .638 .766 r
.3636 .40884 m .37195 .40233 L .37089 .40022 L p F P
0 g
s
.719 .638 .766 r
.36061 .40867 m .3636 .40884 L p .37089 .40022 L F P
0 g
s
.719 .541 .648 r
.38057 .42819 m .37918 .43052 L .38101 .4306 L closepath p F P
0 g
s
.698 .507 .626 r
.41568 .43094 m .40878 .43103 L .40953 .43684 L p F P
0 g
s
.704 .512 .625 r
.40002 .4368 m .40953 .43684 L .40878 .43103 L p F P
0 g
s
.704 .512 .625 r
.40878 .43103 m .40286 .43101 L .40002 .4368 L p F P
0 g
s
.719 .638 .766 r
.35849 .40383 m .36061 .40867 L p .37089 .40022 L F P
0 g
s
.725 .623 .743 r
.35849 .40383 m .35342 .40807 L .36061 .40867 L closepath p F P
0 g
s
.728 .607 .723 r
.34865 .41545 m .35632 .41602 L p .36061 .40867 L F P
0 g
s
.728 .607 .723 r
.34793 .41332 m .34865 .41545 L p .36061 .40867 L F P
0 g
s
.728 .607 .723 r
.36061 .40867 m .35342 .40807 L .34793 .41332 L p F P
0 g
s
.705 .513 .626 r
.39579 .43677 m .40002 .4368 L .40286 .43101 L p F P
0 g
s
.705 .513 .626 r
.40286 .43101 m .39504 .43096 L .39579 .43677 L p F P
0 g
s
.728 .552 .654 r
.35779 .42931 m .36666 .42992 L .36537 .42356 L p F P
0 g
s
.728 .552 .654 r
.36537 .42356 m .36141 .42328 L .35779 .42931 L p F P
0 g
s
.703 .633 .775 r
.39882 .40047 m .39917 .40116 L .41033 .40115 L p F P
0 g
s
.707 .635 .773 r
.39882 .40047 m .39777 .40114 L .39917 .40116 L closepath p F P
0 g
s
.711 .517 .625 r
.38807 .43659 m .39579 .43677 L .39504 .43096 L p F P
0 g
s
.711 .517 .625 r
.39504 .43096 m .39073 .43086 L .38807 .43659 L p F P
0 g
s
.703 .632 .775 r
.41225 .39999 m .41033 .40115 L .41282 .40114 L closepath p F P
0 g
s
.703 .633 .775 r
.41033 .40115 m .41225 .39999 L p .39882 .40047 L F P
0 g
s
.697 .506 .625 r
.42225 .43083 m .41568 .43094 L .41267 .4368 L p F P
0 g
s
.698 .507 .626 r
.40953 .43684 m .41267 .4368 L .41568 .43094 L p F P
0 g
s
.699 .631 .776 r
.41225 .39999 m .41282 .40114 L .4237 .40092 L p F P
0 g
s
.705 .648 .79 r
.39777 .40114 m .39882 .40047 L .39587 .39508 L p F P
0 g
s
.705 .648 .79 r
.39587 .39508 m .38591 .40089 L .39777 .40114 L p F P
0 g
s
.709 .622 .758 r
.38539 .40122 m .38591 .40089 L .39777 .40114 L p F P
0 g
s
.686 .542 .684 r
.4473 .42349 m .44958 .42333 L .45772 .41587 L p F P
0 g
s
.683 .521 .66 r
.44958 .42333 m .4473 .42349 L .44769 .42544 L closepath p F P
0 g
s
.728 .578 .686 r
.35065 .42252 m .35108 .42256 L .35632 .41602 L p F P
0 g
s
.728 .578 .686 r
.35632 .41602 m .34865 .41545 L .35065 .42252 L p F P
0 g
s
.712 .518 .625 r
.38176 .43643 m .38807 .43659 L .39073 .43086 L p F P
0 g
s
.712 .518 .625 r
.39073 .43086 m .38101 .4306 L .38176 .43643 L p F P
0 g
s
.689 .587 .736 r
.4554 .40693 m .45301 .40849 L .45591 .40828 L closepath p F P
0 g
s
.691 .502 .626 r
.42939 .4306 m .42225 .43083 L .423 .43662 L p F P
0 g
s
.697 .506 .625 r
.41267 .4368 m .423 .43662 L .42225 .43083 L p F P
0 g
s
.703 .633 .775 r
.41225 .39999 m .40931 .39461 L .39882 .40047 L p F P
0 g
s
.698 .668 .817 r
.40931 .39461 m .39882 .40047 L .39587 .39508 L p F P
0 g
s
.684 .539 .682 r
.44958 .42333 m .46006 .42254 L .45838 .41583 L p F P
0 g
s
.684 .539 .682 r
.45838 .41583 m .45772 .41587 L .44958 .42333 L p F P
0 g
s
.681 .518 .658 r
.46006 .42254 m .44958 .42333 L .44769 .42544 L p F P
0 g
s
.686 .556 .702 r
.45826 .41544 m .45772 .41587 L .45838 .41583 L closepath p F P
0 g
s
.688 .572 .719 r
.45772 .41587 m .45826 .41544 L .45591 .40828 L p F P
0 g
s
.708 .637 .776 r
.38591 .40089 m .38522 .40088 L .38539 .40122 L closepath p F P
0 g
s
.681 .553 .703 r
.47093 .41466 m .46882 .408 L .45826 .41544 L p F P
0 g
s
.681 .553 .703 r
.45826 .41544 m .45838 .41583 L .47093 .41466 L p F P
0 g
s
.685 .568 .718 r
.45591 .40828 m .45826 .41544 L .46882 .408 L p F P
0 g
s
.728 .558 .662 r
.35194 .4289 m .35779 .42931 L .36141 .42328 L p F P
0 g
s
.728 .558 .662 r
.35077 .42303 m .35194 .4289 L p .36141 .42328 L F P
0 g
s
.728 .558 .662 r
.36141 .42328 m .35108 .42256 L .35077 .42303 L p F P
0 g
s
.68 .536 .683 r
.47168 .41744 m .47093 .41466 L .45838 .41583 L p F P
0 g
s
.68 .536 .683 r
.46658 .42196 m .47168 .41744 L p .45838 .41583 L F P
0 g
s
.68 .536 .683 r
.45838 .41583 m .46006 .42254 L .46658 .42196 L p F P
0 g
s
.698 .629 .775 r
.42567 .39976 m .4237 .40092 L .4262 .40085 L closepath p F P
0 g
s
.699 .631 .776 r
.4237 .40092 m .42567 .39976 L p .41225 .39999 L F P
0 g
s
.706 .648 .789 r
.38591 .40089 m .39587 .39508 L p .38243 .39575 L F P
0 g
s
.706 .648 .789 r
.38243 .39575 m .38522 .40088 L .38591 .40089 L p F P
0 g
s
.713 .638 .772 r
.38522 .40088 m .37487 .40039 L .37195 .40233 L p F P
0 g
s
.711 .65 .787 r
.38243 .39575 m .37487 .40039 L .38522 .40088 L closepath p F P
0 g
s
.695 .627 .776 r
.42567 .39976 m .4262 .40085 L .43806 .40036 L p F P
0 g
s
.699 .631 .776 r
.42567 .39976 m .42274 .39434 L .41225 .39999 L p F P
0 g
s
.694 .666 .818 r
.42274 .39434 m .41225 .39999 L .40931 .39461 L p F P
0 g
s
.685 .585 .738 r
.4554 .40693 m .45591 .40828 L .46852 .40718 L p F P
0 g
s
.685 .568 .718 r
.46882 .408 m .46852 .40718 L .45591 .40828 L p F P
0 g
s
.69 .5 .625 r
.43547 .43038 m .42939 .4306 L .42617 .43652 L p F P
0 g
s
.691 .502 .626 r
.423 .43662 m .42617 .43652 L .42939 .4306 L p F P
0 g
s
.718 .522 .624 r
.37668 .4362 m .38176 .43643 L .38101 .4306 L p F P
0 g
s
.718 .522 .624 r
.38101 .4306 m .37918 .43052 L .37668 .4362 L p F P
0 g
s
.712 .637 .771 r
.37487 .40039 m .37089 .40022 L .37195 .40233 L closepath p F P
0 g
s
.681 .518 .658 r
.44769 .42544 m .44846 .42968 L p .46006 .42254 L F P
0 g
s
.686 .515 .65 r
.44769 .42544 m .4442 .42992 L .44846 .42968 L closepath p F P
0 g
s
.719 .527 .629 r
.36743 .43578 m .37668 .4362 L .37918 .43052 L p F P
0 g
s
.719 .527 .629 r
.36702 .43253 m .36743 .43578 L p .37918 .43052 L F P
0 g
s
.719 .527 .629 r
.37918 .43052 m .36821 .43 L .36702 .43253 L p F P
0 g
s
.685 .585 .738 r
.46852 .40718 m .46594 .40076 L .4554 .40693 L p F P
0 g
s
.686 .615 .772 r
.4554 .40693 m .46594 .40076 L .46485 .39837 L p F P
0 g
s
.686 .615 .772 r
.45251 .40009 m .4554 .40693 L p .46485 .39837 L F P
0 g
s
.724 .636 .759 r
.35342 .40807 m .35849 .40383 L .35626 .39926 L p F P
0 g
s
.724 .636 .759 r
.34572 .40746 m .35342 .40807 L p .35626 .39926 L F P
0 g
s
.727 .606 .721 r
.35342 .40807 m .34572 .40746 L .34793 .41332 L closepath p F P
0 g
s
.684 .496 .626 r
.4442 .42992 m .43547 .43038 L .43621 .43615 L p F P
0 g
s
.69 .5 .625 r
.42617 .43652 m .43621 .43615 L .43547 .43038 L p F P
0 g
s
.695 .627 .776 r
.43909 .39978 m .43617 .39425 L .42567 .39976 L p F P
0 g
s
.695 .627 .776 r
.43806 .40036 m .43909 .39978 L p .42567 .39976 L F P
0 g
s
.691 .662 .816 r
.43617 .39425 m .42567 .39976 L .42274 .39434 L p F P
0 g
s
.733 .597 .705 r
.34793 .41332 m .34623 .41522 L .34865 .41545 L closepath p F P
0 g
s
.735 .582 .684 r
.34137 .42163 m .35065 .42252 L .34865 .41545 L p F P
0 g
s
.735 .582 .684 r
.34865 .41545 m .34623 .41522 L .34137 .42163 L p F P
0 g
s
.734 .608 .717 r
.34623 .41522 m .34793 .41332 L .34572 .40746 L p F P
0 g
s
.719 .638 .766 r
.37089 .40022 m .36423 .39976 L .35849 .40383 L p F P
0 g
s
.717 .635 .765 r
.36423 .39976 m .35626 .39926 L .35849 .40383 L closepath p F P
0 g
s
.71 .647 .785 r
.37487 .40039 m .38243 .39575 L p .36899 .39667 L F P
0 g
s
.71 .647 .785 r
.36899 .39667 m .37089 .40022 L .37487 .40039 L p F P
0 g
s
.694 .624 .773 r
.43909 .39978 m .43806 .40036 L .43934 .4003 L closepath p F P
0 g
s
.734 .608 .717 r
.33661 .41426 m .34623 .41522 L p .34572 .40746 L F P
0 g
s
.735 .588 .692 r
.3355 .42107 m .34137 .42163 L .34623 .41522 L p F P
0 g
s
.735 .588 .692 r
.33438 .417 m .3355 .42107 L p .34623 .41522 L F P
0 g
s
.735 .588 .692 r
.34623 .41522 m .33661 .41426 L .33438 .417 L p F P
0 g
s
.691 .622 .775 r
.43909 .39978 m .43934 .4003 L .45222 .39947 L p F P
0 g
s
.692 .61 .76 r
.45251 .40009 m .45222 .39947 L .43934 .4003 L p F P
0 g
s
.716 .649 .782 r
.36899 .39667 m .36423 .39976 L .37089 .40022 L closepath p F P
0 g
s
.729 .56 .663 r
.35108 .42256 m .35065 .42252 L .35077 .42303 L closepath p F P
0 g
s
.72 .528 .63 r
.36821 .43 m .36666 .42992 L .36702 .43253 L closepath p F P
0 g
s
.676 .513 .657 r
.46658 .42196 m .46006 .42254 L .4611 .42792 L closepath p F P
0 g
s
.681 .518 .658 r
.46037 .42881 m .4611 .42792 L .46006 .42254 L p F P
0 g
s
.681 .518 .658 r
.44846 .42968 m .46037 .42881 L p .46006 .42254 L F P
0 g
s
.691 .622 .775 r
.45222 .39947 m .44961 .39437 L .43909 .39978 L p F P
0 g
s
.688 .655 .813 r
.44961 .39437 m .43909 .39978 L .43617 .39425 L p F P
0 g
s
.736 .561 .657 r
.34766 .42851 m .35077 .42303 L .35065 .42252 L p F P
0 g
s
.736 .561 .657 r
.33783 .42762 m .34766 .42851 L p .35065 .42252 L F P
0 g
s
.736 .561 .657 r
.35065 .42252 m .34137 .42163 L .33783 .42762 L p F P
0 g
s
.727 .532 .627 r
.36574 .43567 m .36702 .43253 L .36666 .42992 L p F P
0 g
s
.727 .532 .627 r
.35533 .43497 m .36574 .43567 L p .36666 .42992 L F P
0 g
s
.727 .532 .627 r
.36666 .42992 m .35779 .42931 L .35533 .43497 L p F P
0 g
s
.682 .493 .624 r
.44846 .42968 m .4442 .42992 L .44075 .43591 L p F P
0 g
s
.684 .496 .626 r
.43621 .43615 m .44075 .43591 L .4442 .42992 L p F P
0 g
s
.734 .556 .652 r
.35077 .42303 m .34766 .42851 L .35194 .4289 L closepath p F P
0 g
s
.724 .636 .759 r
.34502 .4058 m .34572 .40746 L p .35626 .39926 L F P
0 g
s
.731 .622 .737 r
.34502 .4058 m .34344 .40722 L .34572 .40746 L closepath p F P
0 g
s
.734 .608 .717 r
.34572 .40746 m .34344 .40722 L .33661 .41426 L p F P
0 g
s
.677 .49 .625 r
.46037 .42881 m .44846 .42968 L .44919 .43543 L p F P
0 g
s
.682 .493 .624 r
.44075 .43591 m .44919 .43543 L .44846 .42968 L p F P
0 g
s
.678 .571 .727 r
.46882 .408 m .47093 .41466 L p .48089 .4058 L F P
0 g
s
.678 .571 .727 r
.48089 .4058 m .47047 .40697 L .46882 .408 L p F P
0 g
s
.681 .577 .731 r
.47047 .40697 m .46852 .40718 L .46882 .408 L closepath p F P
0 g
s
.729 .632 .75 r
.34344 .40722 m .34502 .4058 L .34205 .39951 L p F P
0 g
s
.729 .632 .75 r
.34205 .39951 m .33397 .40621 L .34344 .40722 L p F P
0 g
s
.733 .617 .729 r
.33345 .41395 m .33661 .41426 L .34344 .40722 L p F P
0 g
s
.733 .617 .729 r
.3315 .40856 m .33345 .41395 L p .34344 .40722 L F P
0 g
s
.733 .617 .729 r
.34344 .40722 m .33397 .40621 L .3315 .40856 L p F P
0 g
s
.715 .646 .779 r
.36423 .39976 m .36899 .39667 L p .35553 .39787 L F P
0 g
s
.715 .646 .779 r
.35553 .39787 m .35626 .39926 L .36423 .39976 L p F P
0 g
s
.724 .636 .759 r
.35626 .39926 m .35385 .39904 L .34502 .4058 L p F P
0 g
s
.722 .631 .756 r
.35385 .39904 m .34502 .4058 L .34205 .39951 L p F P
0 g
s
.678 .571 .727 r
.47093 .41466 m .47593 .41413 L p .48089 .4058 L F P
0 g
s
.676 .54 .692 r
.47593 .41413 m .47093 .41466 L .47168 .41744 L closepath p F P
0 g
s
.681 .606 .766 r
.46852 .40718 m .47047 .40697 L p .4773 .39706 L F P
0 g
s
.681 .606 .766 r
.46594 .40076 m .46852 .40718 L p .4773 .39706 L F P
0 g
s
.686 .615 .772 r
.46485 .39837 m .45392 .39934 L .45251 .40009 L p F P
0 g
s
.688 .621 .776 r
.45392 .39934 m .45222 .39947 L .45251 .40009 L closepath p F P
0 g
s
.677 .53 .678 r
.47168 .41744 m .46658 .42196 L .47262 .42138 L closepath p F P
0 g
s
.674 .509 .654 r
.47262 .42138 m .46658 .42196 L .4611 .42792 L p F P
0 g
s
.695 .484 .598 r
.41267 .4368 m .40953 .43684 L .4099 .44226 L p F P
0 g
s
.701 .489 .598 r
.3984 .44222 m .4099 .44226 L .40953 .43684 L p F P
0 g
s
.701 .489 .598 r
.40953 .43684 m .40002 .4368 L .3984 .44222 L p F P
0 g
s
.702 .49 .598 r
.39615 .44221 m .3984 .44222 L .40002 .4368 L p F P
0 g
s
.702 .49 .598 r
.40002 .4368 m .39579 .43677 L .39615 .44221 L p F P
0 g
s
.693 .483 .598 r
.423 .43662 m .41267 .4368 L .41095 .44225 L p F P
0 g
s
.695 .484 .598 r
.4099 .44226 m .41095 .44225 L .41267 .4368 L p F P
0 g
s
.679 .586 .743 r
.47937 .40184 m .47047 .40697 L .48089 .4058 L closepath p F P
0 g
s
.681 .606 .766 r
.47047 .40697 m .47937 .40184 L .4773 .39706 L p F P
0 g
s
.673 .535 .688 r
.47168 .41744 m .47262 .42138 L p .48331 .41328 L F P
0 g
s
.673 .535 .688 r
.48331 .41328 m .47593 .41413 L .47168 .41744 L p F P
0 g
s
.709 .495 .598 r
.38654 .44198 m .39615 .44221 L .39579 .43677 L p F P
0 g
s
.709 .495 .598 r
.39579 .43677 m .38807 .43659 L .38654 .44198 L p F P
0 g
s
.727 .532 .627 r
.35273 .43479 m .35533 .43497 L .35779 .42931 L p F P
0 g
s
.727 .532 .627 r
.35779 .42931 m .35194 .4289 L .35273 .43479 L p F P
0 g
s
.687 .633 .789 r
.44961 .39437 m .45222 .39947 L .45392 .39934 L p F P
0 g
s
.725 .526 .622 r
.36702 .43253 m .36574 .43567 L .36743 .43578 L closepath p F P
0 g
s
.735 .588 .692 r
.33661 .41426 m .33345 .41395 L .33438 .417 L closepath p F P
0 g
s
.693 .483 .598 r
.41095 .44225 m .42337 .44204 L .423 .43662 L p F P
0 g
s
.688 .478 .598 r
.42617 .43652 m .423 .43662 L .42337 .44204 L p F P
0 g
s
.687 .633 .789 r
.45392 .39934 m .46305 .39472 L p .44961 .39437 L F P
0 g
s
.686 .627 .784 r
.46305 .39472 m .45392 .39934 L .46485 .39837 L closepath p F P
0 g
s
.709 .496 .598 r
.38211 .44186 m .38654 .44198 L .38807 .43659 L p F P
0 g
s
.709 .496 .598 r
.38807 .43659 m .38176 .43643 L .38211 .44186 L p F P
0 g
s
.735 .56 .656 r
.33687 .42753 m .33783 .42762 L .34137 .42163 L p F P
0 g
s
.735 .56 .656 r
.34137 .42163 m .3355 .42107 L .33687 .42753 L p F P
0 g
s
.721 .648 .776 r
.35553 .39787 m .35385 .39904 L .35626 .39926 L closepath p F P
0 g
s
.686 .476 .597 r
.43621 .43615 m .42617 .43652 L .42435 .44201 L p F P
0 g
s
.688 .478 .598 r
.42337 .44204 m .42435 .44201 L .42617 .43652 L p F P
0 g
s
.676 .553 .708 r
.48224 .40978 m .47593 .41413 L .48331 .41328 L closepath p F P
0 g
s
.678 .571 .727 r
.47593 .41413 m .48224 .40978 L .48089 .4058 L p F P
0 g
s
.706 .648 .789 r
.39587 .39508 m .3929 .39026 L .38243 .39575 L p F P
0 g
s
.697 .686 .835 r
.38243 .39575 m .3929 .39026 L .39171 .38854 L p F P
0 g
s
.697 .686 .835 r
.37945 .39087 m .38243 .39575 L p .39171 .38854 L F P
0 g
s
.71 .647 .785 r
.38243 .39575 m .37945 .39087 L .36899 .39667 L p F P
0 g
s
.716 .501 .597 r
.37523 .44156 m .38211 .44186 L .38176 .43643 L p F P
0 g
s
.716 .501 .597 r
.38176 .43643 m .37668 .4362 L .37523 .44156 L p F P
0 g
s
.698 .668 .817 r
.39587 .39508 m .40635 .38982 L .40931 .39461 L p F P
0 g
s
.693 .686 .839 r
.39587 .39508 m .40635 .38982 L .40558 .38871 L p F P
0 g
s
.693 .686 .839 r
.3929 .39026 m .39587 .39508 L p .40558 .38871 L F P
0 g
s
.674 .509 .654 r
.4611 .42792 m .46124 .42875 L p .47262 .42138 L F P
0 g
s
.679 .507 .647 r
.4611 .42792 m .46037 .42881 L .46124 .42875 L closepath p F P
0 g
s
.702 .684 .83 r
.36899 .39667 m .37945 .39087 L .37754 .38806 L p F P
0 g
s
.702 .684 .83 r
.36599 .39166 m .36899 .39667 L p .37754 .38806 L F P
0 g
s
.715 .646 .779 r
.36899 .39667 m .36599 .39166 L .35553 .39787 L p F P
0 g
s
.734 .536 .626 r
.34536 .43413 m .35273 .43479 L .35194 .4289 L p F P
0 g
s
.734 .536 .626 r
.35194 .4289 m .34766 .42851 L .34536 .43413 L p F P
0 g
s
.722 .631 .756 r
.34205 .39951 m .34401 .39814 L .35385 .39904 L p F P
0 g
s
.718 .658 .79 r
.35385 .39904 m .35553 .39787 L .35253 .3927 L p F P
0 g
s
.718 .658 .79 r
.35253 .3927 m .34401 .39814 L .35385 .39904 L p F P
0 g
s
.74 .607 .711 r
.3315 .40856 m .32734 .41318 L .33345 .41395 L closepath p F P
0 g
s
.742 .59 .686 r
.33183 .42064 m .33438 .417 L .33345 .41395 L p F P
0 g
s
.742 .59 .686 r
.3226 .41956 m .33183 .42064 L p .33345 .41395 L F P
0 g
s
.742 .59 .686 r
.33345 .41395 m .32734 .41318 L .3226 .41956 L p F P
0 g
s
.673 .535 .688 r
.47262 .42138 m .48501 .42002 L .48331 .41328 L p F P
0 g
s
.669 .506 .655 r
.4851 .4205 m .48501 .42002 L .47262 .42138 L p F P
0 g
s
.669 .506 .655 r
.47882 .427 m .4851 .4205 L p .47262 .42138 L F P
0 g
s
.669 .506 .655 r
.47262 .42138 m .47378 .42756 L .47882 .427 L p F P
0 g
s
.674 .509 .654 r
.46124 .42875 m .47378 .42756 L .47262 .42138 L p F P
0 g
s
.675 .487 .624 r
.46124 .42875 m .46037 .42881 L .45668 .43489 L p F P
0 g
s
.677 .49 .625 r
.44919 .43543 m .45668 .43489 L .46037 .42881 L p F P
0 g
s
.694 .666 .818 r
.40931 .39461 m .4198 .38953 L .42274 .39434 L p F P
0 g
s
.69 .685 .84 r
.40931 .39461 m .4198 .38953 L .41913 .38856 L p F P
0 g
s
.69 .685 .84 r
.40635 .38982 m .40931 .39461 L p .41913 .38856 L F P
0 g
s
.741 .582 .678 r
.33438 .417 m .33183 .42064 L .3355 .42107 L closepath p F P
0 g
s
.67 .483 .624 r
.4745 .43303 m .47378 .42756 L .46124 .42875 L p F P
0 g
s
.67 .483 .624 r
.47431 .43334 m .4745 .43303 L p .46124 .42875 L F P
0 g
s
.67 .483 .624 r
.46124 .42875 m .46196 .43448 L .47431 .43334 L p F P
0 g
s
.675 .487 .624 r
.45668 .43489 m .46196 .43448 L .46124 .42875 L p F P
0 g
s
.717 .502 .597 r
.36777 .44122 m .37523 .44156 L .37668 .4362 L p F P
0 g
s
.717 .502 .597 r
.37668 .4362 m .36743 .43578 L .36777 .44122 L p F P
0 g
s
.681 .606 .766 r
.4773 .39706 m .47185 .39767 L .46594 .40076 L p F P
0 g
s
.683 .613 .771 r
.47185 .39767 m .46485 .39837 L .46594 .40076 L closepath p F P
0 g
s
.68 .472 .598 r
.44075 .43591 m .43621 .43615 L .43659 .44156 L p F P
0 g
s
.686 .476 .597 r
.42435 .44201 m .43659 .44156 L .43621 .43615 L p F P
0 g
s
.708 .681 .822 r
.35553 .39787 m .36599 .39166 L .36309 .3873 L p F P
0 g
s
.708 .681 .822 r
.35253 .3927 m .35553 .39787 L p .36309 .3873 L F P
0 g
s
.729 .646 .767 r
.33397 .40621 m .34205 .39951 L .34121 .3979 L p F P
0 g
s
.729 .646 .767 r
.3304 .40584 m .33397 .40621 L p .34121 .3979 L F P
0 g
s
.732 .616 .728 r
.33397 .40621 m .3304 .40584 L .3315 .40856 L closepath p F P
0 g
s
.691 .662 .816 r
.42274 .39434 m .43324 .38937 L .43617 .39425 L p F P
0 g
s
.687 .682 .839 r
.42274 .39434 m .43324 .38937 L .43239 .3881 L p F P
0 g
s
.687 .682 .839 r
.4198 .38953 m .42274 .39434 L p .43239 .3881 L F P
0 g
s
.74 .616 .72 r
.32734 .41318 m .3315 .40856 L .3304 .40584 L p F P
0 g
s
.742 .565 .654 r
.32853 .42656 m .33687 .42753 L .3355 .42107 L p F P
0 g
s
.742 .565 .654 r
.3355 .42107 m .33183 .42064 L .32853 .42656 L p F P
0 g
s
.734 .54 .63 r
.33766 .43344 m .34536 .43413 L .34766 .42851 L p F P
0 g
s
.734 .54 .63 r
.33712 .42925 m .33766 .43344 L p .34766 .42851 L F P
0 g
s
.734 .54 .63 r
.34766 .42851 m .33783 .42762 L .33712 .42925 L p F P
0 g
s
.678 .47 .597 r
.44919 .43543 m .44075 .43591 L .43882 .44145 L p F P
0 g
s
.68 .472 .598 r
.43659 .44156 m .43882 .44145 L .44075 .43591 L p F P
0 g
s
.723 .507 .597 r
.36436 .44101 m .36777 .44122 L .36743 .43578 L p F P
0 g
s
.723 .507 .597 r
.36743 .43578 m .36574 .43567 L .36436 .44101 L p F P
0 g
s
.672 .56 .72 r
.48224 .40978 m .48331 .41328 L p .49313 .40425 L F P
0 g
s
.672 .56 .72 r
.49313 .40425 m .49078 .40456 L .48224 .40978 L p F P
0 g
s
.675 .566 .725 r
.49078 .40456 m .48089 .4058 L .48224 .40978 L closepath p F P
0 g
s
.688 .655 .813 r
.43617 .39425 m .44669 .38935 L .44961 .39437 L p F P
0 g
s
.685 .677 .837 r
.43617 .39425 m .44669 .38935 L .44538 .38735 L p F P
0 g
s
.685 .677 .837 r
.43324 .38937 m .43617 .39425 L p .44538 .38735 L F P
0 g
s
.729 .646 .767 r
.32854 .40172 m .3304 .40584 L p .34121 .3979 L F P
0 g
s
.737 .631 .742 r
.32854 .40172 m .3248 .4051 L .3304 .40584 L closepath p F P
0 g
s
.74 .616 .72 r
.31813 .41209 m .32734 .41318 L p .3304 .40584 L F P
0 g
s
.74 .616 .72 r
.3304 .40584 m .3248 .4051 L .31813 .41209 L p F P
0 g
s
.725 .509 .599 r
.3539 .44032 m .36436 .44101 L .36574 .43567 L p F P
0 g
s
.725 .509 .599 r
.36574 .43567 m .35533 .43497 L .3539 .44032 L p F P
0 g
s
.721 .646 .774 r
.34401 .39814 m .34121 .3979 L .34205 .39951 L closepath p F P
0 g
s
.683 .626 .785 r
.46305 .39472 m .46485 .39837 L .47185 .39767 L p F P
0 g
s
.672 .56 .72 r
.48331 .41328 m .49551 .41171 L .49313 .40425 L p F P
0 g
s
.669 .53 .686 r
.49569 .41235 m .49551 .41171 L .48331 .41328 L p F P
0 g
s
.669 .53 .686 r
.48575 .41992 m .49569 .41235 L p .48331 .41328 L F P
0 g
s
.669 .53 .686 r
.48331 .41328 m .48501 .42002 L .48575 .41992 L p F P
0 g
s
.676 .584 .744 r
.47937 .40184 m .48089 .4058 L .49078 .40456 L p F P
0 g
s
.742 .569 .66 r
.32133 .42574 m .32853 .42656 L .33183 .42064 L p F P
0 g
s
.742 .569 .66 r
.32072 .42274 m .32133 .42574 L p .33183 .42064 L F P
0 g
s
.742 .569 .66 r
.33183 .42064 m .3226 .41956 L .32072 .42274 L p F P
0 g
s
.74 .596 .696 r
.31993 .41924 m .3226 .41956 L .32734 .41318 L p F P
0 g
s
.74 .596 .696 r
.31792 .41235 m .31993 .41924 L p .32734 .41318 L F P
0 g
s
.74 .596 .696 r
.32734 .41318 m .31813 .41209 L .31792 .41235 L p F P
0 g
s
.718 .655 .787 r
.34401 .39814 m .35253 .3927 L p .33905 .39404 L F P
0 g
s
.718 .655 .787 r
.33905 .39404 m .34121 .3979 L .34401 .39814 L p F P
0 g
s
.672 .466 .597 r
.45668 .43489 m .44919 .43543 L .44957 .44083 L p F P
0 g
s
.678 .47 .597 r
.43882 .44145 m .44957 .44083 L .44919 .43543 L p F P
0 g
s
.687 .633 .789 r
.46305 .39472 m .46015 .38951 L .44961 .39437 L p F P
0 g
s
.683 .671 .832 r
.44961 .39437 m .46015 .38951 L .45817 .38638 L p F P
0 g
s
.683 .671 .832 r
.44669 .38935 m .44961 .39437 L p .45817 .38638 L F P
0 g
s
.676 .584 .744 r
.49282 .40341 m .48995 .39637 L .47937 .40184 L p F P
0 g
s
.676 .584 .744 r
.49078 .40456 m .49282 .40341 L p .47937 .40184 L F P
0 g
s
.679 .603 .764 r
.4773 .39706 m .47937 .40184 L .48995 .39637 L p F P
0 g
s
.725 .658 .783 r
.33905 .39404 m .33462 .39709 L .34121 .3979 L closepath p F P
0 g
s
.729 .646 .767 r
.34121 .3979 m .33462 .39709 L .32854 .40172 L p F P
0 g
s
.735 .541 .631 r
.33783 .42762 m .33687 .42753 L .33712 .42925 L closepath p F P
0 g
s
.664 .481 .627 r
.47882 .427 m .47378 .42756 L .4745 .43303 L closepath p F P
0 g
s
.742 .545 .627 r
.33559 .43322 m .33712 .42925 L .33687 .42753 L p F P
0 g
s
.742 .545 .627 r
.32627 .43216 m .33559 .43322 L p .33687 .42753 L F P
0 g
s
.742 .545 .627 r
.33687 .42753 m .32853 .42656 L .32627 .43216 L p F P
0 g
s
.681 .618 .778 r
.4765 .39535 m .47185 .39767 L .4773 .39706 L closepath p F P
0 g
s
.683 .626 .785 r
.47185 .39767 m .4765 .39535 L p .46305 .39472 L F P
0 g
s
.725 .51 .599 r
.35309 .44026 m .3539 .44032 L .35533 .43497 L p F P
0 g
s
.725 .51 .599 r
.35533 .43497 m .35273 .43479 L .35309 .44026 L p F P
0 g
s
.736 .643 .756 r
.3248 .4051 m .32854 .40172 L .32574 .39614 L p F P
0 g
s
.736 .643 .756 r
.31573 .40395 m .3248 .4051 L p .32574 .39614 L F P
0 g
s
.737 .623 .732 r
.31782 .41205 m .31813 .41209 L .3248 .4051 L p F P
0 g
s
.737 .623 .732 r
.31499 .40465 m .31782 .41205 L p .3248 .4051 L F P
0 g
s
.737 .623 .732 r
.3248 .4051 m .31573 .40395 L .31499 .40465 L p F P
0 g
s
.665 .508 .662 r
.48575 .41992 m .48501 .42002 L .4851 .4205 L closepath p F P
0 g
s
.727 .642 .764 r
.33462 .39709 m .32574 .39614 L .32854 .40172 L closepath p F P
0 g
s
.67 .463 .596 r
.46196 .43448 m .45668 .43489 L .45461 .44047 L p F P
0 g
s
.672 .466 .597 r
.44957 .44083 m .45461 .44047 L .45668 .43489 L p F P
0 g
s
.666 .501 .652 r
.4851 .4205 m .47882 .427 L .48614 .42616 L closepath p F P
0 g
s
.662 .503 .659 r
.4851 .4205 m .48614 .42616 L p .49716 .41838 L F P
0 g
s
.662 .503 .659 r
.49716 .41838 m .48575 .41992 L .4851 .4205 L p F P
0 g
s
.666 .524 .682 r
.49569 .41235 m .48575 .41992 L .49716 .41838 L closepath p F P
0 g
s
.691 .461 .569 r
.41095 .44225 m .4099 .44226 L .40992 .44736 L p F P
0 g
s
.697 .466 .569 r
.39786 .44732 m .40992 .44736 L .4099 .44226 L p F P
0 g
s
.697 .466 .569 r
.4099 .44226 m .3984 .44222 L .39786 .44732 L p F P
0 g
s
.691 .461 .569 r
.40992 .44736 m .41039 .44735 L .41095 .44225 L p F P
0 g
s
.689 .459 .569 r
.42337 .44204 m .41095 .44225 L .41039 .44735 L p F P
0 g
s
.732 .516 .598 r
.34399 .43945 m .35309 .44026 L .35273 .43479 L p F P
0 g
s
.732 .516 .598 r
.35273 .43479 m .34536 .43413 L .34399 .43945 L p F P
0 g
s
.698 .467 .569 r
.39616 .44731 m .39786 .44732 L .3984 .44222 L p F P
0 g
s
.698 .467 .569 r
.3984 .44222 m .39615 .44221 L .39616 .44731 L p F P
0 g
s
.705 .473 .569 r
.38601 .44707 m .39616 .44731 L .39615 .44221 L p F P
0 g
s
.705 .473 .569 r
.39615 .44221 m .38654 .44198 L .38601 .44707 L p F P
0 g
s
.683 .626 .785 r
.4765 .39535 m .47361 .38988 L .46305 .39472 L p F P
0 g
s
.68 .662 .826 r
.46305 .39472 m .47361 .38988 L .4708 .38522 L p F P
0 g
s
.68 .662 .826 r
.46015 .38951 m .46305 .39472 L p .4708 .38522 L F P
0 g
s
.683 .454 .569 r
.42435 .44201 m .42337 .44204 L .42341 .44714 L p F P
0 g
s
.689 .459 .569 r
.41039 .44735 m .42341 .44714 L .42337 .44204 L p F P
0 g
s
.74 .54 .623 r
.33712 .42925 m .33559 .43322 L .33766 .43344 L closepath p F P
0 g
s
.681 .452 .569 r
.43659 .44156 m .42435 .44201 L .42378 .44712 L p F P
0 g
s
.683 .454 .569 r
.42341 .44714 m .42378 .44712 L .42435 .44201 L p F P
0 g
s
.706 .473 .569 r
.38211 .44696 m .38601 .44707 L .38654 .44198 L p F P
0 g
s
.706 .473 .569 r
.38654 .44198 m .38211 .44186 L .38211 .44696 L p F P
0 g
s
.742 .57 .66 r
.3226 .41956 m .31993 .41924 L .32072 .42274 L closepath p F P
0 g
s
.664 .459 .596 r
.47431 .43334 m .46196 .43448 L .46234 .43987 L p F P
0 g
s
.67 .463 .596 r
.45461 .44047 m .46234 .43987 L .46196 .43448 L p F P
0 g
s
.741 .597 .697 r
.31813 .41209 m .31782 .41205 L .31792 .41235 L closepath p F P
0 g
s
.661 .477 .625 r
.48614 .42616 m .47882 .427 L .4745 .43303 L p F P
0 g
s
.748 .592 .682 r
.31792 .41235 m .31374 .41835 L .31993 .41924 L closepath p F P
0 g
s
.75 .598 .688 r
.31374 .41835 m .31792 .41235 L .31782 .41205 L p F P
0 g
s
.746 .616 .714 r
.31499 .40465 m .30955 .41078 L .31782 .41205 L closepath p F P
0 g
s
.75 .598 .688 r
.30496 .41711 m .31374 .41835 L p .31782 .41205 L F P
0 g
s
.75 .598 .688 r
.31782 .41205 m .30955 .41078 L .30496 .41711 L p F P
0 g
s
.674 .575 .736 r
.49282 .40341 m .49078 .40456 L .49313 .40425 L closepath p F P
0 g
s
.724 .652 .777 r
.33462 .39709 m .33905 .39404 L p .32555 .39578 L F P
0 g
s
.724 .652 .777 r
.32555 .39578 m .32574 .39614 L .33462 .39709 L p F P
0 g
s
.713 .479 .569 r
.37471 .44664 m .38211 .44696 L .38211 .44186 L p F P
0 g
s
.713 .479 .569 r
.38211 .44186 m .37523 .44156 L .37471 .44664 L p F P
0 g
s
.679 .603 .764 r
.48995 .39637 m .48956 .39553 L .4773 .39706 L p F P
0 g
s
.679 .617 .779 r
.4765 .39535 m .4773 .39706 L .48956 .39553 L p F P
0 g
s
.697 .686 .835 r
.39171 .38854 m .38492 .38827 L .37945 .39087 L p F P
0 g
s
.697 .683 .833 r
.38492 .38827 m .37754 .38806 L .37945 .39087 L closepath p F P
0 g
s
.702 .684 .83 r
.37754 .38806 m .37369 .38781 L .36599 .39166 L p F P
0 g
s
.701 .68 .827 r
.37369 .38781 m .36309 .3873 L .36599 .39166 L closepath p F P
0 g
s
.693 .685 .838 r
.3966 .38858 m .39171 .38854 L .3929 .39026 L closepath p F P
0 g
s
.693 .686 .839 r
.40558 .38871 m .3966 .38858 L .3929 .39026 L p F P
0 g
s
.708 .681 .822 r
.36309 .3873 m .36272 .38727 L .35253 .3927 L p F P
0 g
s
.706 .675 .818 r
.36272 .38727 m .35253 .3927 L .3495 .38801 L p F P
0 g
s
.718 .655 .787 r
.35253 .3927 m .3495 .38801 L .33905 .39404 L p F P
0 g
s
.75 .573 .656 r
.31932 .42547 m .32072 .42274 L .31993 .41924 L p F P
0 g
s
.75 .573 .656 r
.31054 .42424 m .31932 .42547 L p .31993 .41924 L F P
0 g
s
.75 .573 .656 r
.31993 .41924 m .31374 .41835 L .31054 .42424 L p F P
0 g
s
.732 .515 .598 r
.33801 .43892 m .34399 .43945 L .34536 .43413 L p F P
0 g
s
.732 .515 .598 r
.34536 .43413 m .33766 .43344 L .33801 .43892 L p F P
0 g
s
.69 .685 .84 r
.41913 .38856 m .40895 .38868 L .40635 .38982 L p F P
0 g
s
.69 .685 .84 r
.40895 .38868 m .40558 .38871 L .40635 .38982 L closepath p F P
0 g
s
.669 .573 .738 r
.49282 .40341 m .49313 .40425 L .50512 .40243 L p F P
0 g
s
.668 .555 .718 r
.50628 .40587 m .50512 .40243 L .49313 .40425 L p F P
0 g
s
.668 .555 .718 r
.49697 .4115 m .50628 .40587 L p .49313 .40425 L F P
0 g
s
.668 .555 .718 r
.49313 .40425 m .49551 .41171 L .49697 .4115 L p F P
0 g
s
.665 .535 .696 r
.49697 .4115 m .49551 .41171 L .49569 .41235 L closepath p F P
0 g
s
.714 .48 .569 r
.36775 .44633 m .37471 .44664 L .37523 .44156 L p F P
0 g
s
.714 .48 .569 r
.37523 .44156 m .36777 .44122 L .36775 .44633 L p F P
0 g
s
.675 .447 .569 r
.43882 .44145 m .43659 .44156 L .43664 .44665 L p F P
0 g
s
.681 .452 .569 r
.42378 .44712 m .43664 .44665 L .43659 .44156 L p F P
0 g
s
.661 .528 .691 r
.49569 .41235 m .49716 .41838 L p .50749 .40987 L F P
0 g
s
.661 .528 .691 r
.50749 .40987 m .49697 .4115 L .49569 .41235 L p F P
0 g
s
.669 .573 .738 r
.50512 .40243 m .50341 .39795 L .49282 .40341 L p F P
0 g
s
.672 .603 .77 r
.49282 .40341 m .50341 .39795 L .50159 .39373 L p F P
0 g
s
.672 .603 .77 r
.48995 .39637 m .49282 .40341 L p .50159 .39373 L F P
0 g
s
.742 .544 .627 r
.32215 .43169 m .32627 .43216 L .32853 .42656 L p F P
0 g
s
.742 .544 .627 r
.32853 .42656 m .32133 .42574 L .32215 .43169 L p F P
0 g
s
.673 .445 .568 r
.44957 .44083 m .43882 .44145 L .43822 .44657 L p F P
0 g
s
.675 .447 .569 r
.43664 .44665 m .43822 .44657 L .43882 .44145 L p F P
0 g
s
.679 .617 .779 r
.48956 .39553 m .48707 .39052 L .4765 .39535 L p F P
0 g
s
.677 .649 .815 r
.48707 .39052 m .4765 .39535 L .47361 .38988 L p F P
0 g
s
.687 .682 .839 r
.43239 .3881 m .42224 .38847 L .4198 .38953 L p F P
0 g
s
.688 .684 .841 r
.42224 .38847 m .41913 .38856 L .4198 .38953 L closepath p F P
0 g
s
.665 .546 .71 r
.50628 .40587 m .49697 .4115 L .50749 .40987 L closepath p F P
0 g
s
.708 .692 .832 r
.33905 .39404 m .3495 .38801 L .34807 .38599 L p F P
0 g
s
.708 .692 .832 r
.33602 .38914 m .33905 .39404 L p .34807 .38599 L F P
0 g
s
.724 .652 .777 r
.33905 .39404 m .33602 .38914 L .32555 .39578 L p F P
0 g
s
.736 .643 .756 r
.32574 .39614 m .32518 .39606 L .31573 .40395 L p F P
0 g
s
.733 .654 .771 r
.31464 .40381 m .31573 .40395 L .32518 .39606 L p F P
0 g
s
.737 .624 .733 r
.31573 .40395 m .31464 .40381 L .31499 .40465 L closepath p F P
0 g
s
.747 .624 .723 r
.30955 .41078 m .31499 .40465 L .31464 .40381 L p F P
0 g
s
.721 .485 .569 r
.36385 .44608 m .36775 .44633 L .36777 .44122 L p F P
0 g
s
.721 .485 .569 r
.36777 .44122 m .36436 .44101 L .36385 .44608 L p F P
0 g
s
.748 .567 .649 r
.32072 .42274 m .31932 .42547 L .32133 .42574 L closepath p F P
0 g
s
.733 .654 .771 r
.31201 .39824 m .31464 .40381 L p .32518 .39606 L F P
0 g
s
.742 .639 .746 r
.31201 .39824 m .30724 .40261 L .31464 .40381 L closepath p F P
0 g
s
.747 .624 .723 r
.30165 .40964 m .30955 .41078 L p .31464 .40381 L F P
0 g
s
.747 .624 .723 r
.30137 .40887 m .30165 .40964 L p .31464 .40381 L F P
0 g
s
.747 .624 .723 r
.31464 .40381 m .30724 .40261 L .30137 .40887 L p F P
0 g
s
.661 .477 .625 r
.47454 .43332 m .48688 .43189 L .48614 .42616 L p F P
0 g
s
.661 .477 .625 r
.4745 .43303 m .47454 .43332 L p .48614 .42616 L F P
0 g
s
.662 .503 .659 r
.48614 .42616 m .49833 .42456 L .49716 .41838 L p F P
0 g
s
.656 .473 .625 r
.49856 .42622 m .49833 .42456 L .48614 .42616 L p F P
0 g
s
.656 .473 .625 r
.49507 .43083 m .49856 .42622 L p .48614 .42616 L F P
0 g
s
.656 .473 .625 r
.48614 .42616 m .48688 .43189 L .49507 .43083 L p F P
0 g
s
.686 .681 .84 r
.43672 .38789 m .43239 .3881 L .43324 .38937 L closepath p F P
0 g
s
.685 .677 .837 r
.44538 .38735 m .43672 .38789 L .43324 .38937 L p F P
0 g
s
.721 .486 .57 r
.35337 .4454 m .36385 .44608 L .36436 .44101 L p F P
0 g
s
.721 .486 .57 r
.36436 .44101 m .3539 .44032 L .35337 .4454 L p F P
0 g
s
.691 .692 .846 r
.40337 .3856 m .3966 .38858 L .40558 .38871 L closepath p F P
0 g
s
.688 .691 .847 r
.40337 .3856 m .40558 .38871 L .40895 .38868 L p F P
0 g
s
.731 .655 .773 r
.32555 .39578 m .32518 .39606 L .32574 .39614 L closepath p F P
0 g
s
.688 .691 .847 r
.41683 .3853 m .40895 .38868 L .41913 .38856 L closepath p F P
0 g
s
.688 .691 .847 r
.40895 .38868 m .41683 .3853 L p .40337 .3856 L F P
0 g
s
.739 .521 .597 r
.3343 .43852 m .33801 .43892 L .33766 .43344 L p F P
0 g
s
.739 .521 .597 r
.33766 .43344 m .33559 .43322 L .3343 .43852 L p F P
0 g
s
.667 .478 .62 r
.4745 .43303 m .47431 .43334 L .47454 .43332 L closepath p F P
0 g
s
.733 .654 .771 r
.32518 .39606 m .31654 .39477 L .31201 .39824 L p F P
0 g
s
.729 .665 .788 r
.32518 .39606 m .32555 .39578 L .32252 .39062 L p F P
0 g
s
.729 .665 .788 r
.32252 .39062 m .31654 .39477 L .32518 .39606 L p F P
0 g
s
.691 .691 .845 r
.3966 .38858 m .40337 .3856 L p .38991 .386 L F P
0 g
s
.691 .691 .845 r
.38991 .386 m .39171 .38854 L .3966 .38858 L p F P
0 g
s
.666 .441 .568 r
.45461 .44047 m .44957 .44083 L .44964 .44592 L p F P
0 g
s
.673 .445 .568 r
.43822 .44657 m .44964 .44592 L .44957 .44083 L p F P
0 g
s
.717 .688 .822 r
.33602 .38914 m .32555 .39578 L .32252 .39062 L p F P
0 g
s
.686 .69 .848 r
.41683 .3853 m .41913 .38856 L .42224 .38847 L p F P
0 g
s
.662 .456 .595 r
.47454 .43332 m .47431 .43334 L .47209 .43897 L p F P
0 g
s
.664 .459 .596 r
.46234 .43987 m .47209 .43897 L .47431 .43334 L p F P
0 g
s
.695 .692 .843 r
.38991 .386 m .38492 .38827 L .39171 .38854 L closepath p F P
0 g
s
.656 .451 .596 r
.48729 .43729 m .48688 .43189 L .47454 .43332 L p F P
0 g
s
.656 .451 .596 r
.47454 .43332 m .47492 .4387 L .48729 .43729 L p F P
0 g
s
.662 .456 .595 r
.47209 .43897 m .47492 .4387 L .47454 .43332 L p F P
0 g
s
.661 .528 .691 r
.49716 .41838 m .509 .41662 L p .50749 .40987 L F P
0 g
s
.656 .497 .656 r
.509 .41662 m .49716 .41838 L .49833 .42456 L p F P
0 g
s
.749 .577 .662 r
.30532 .42351 m .31054 .42424 L .31374 .41835 L p F P
0 g
s
.749 .577 .662 r
.30421 .41838 m .30532 .42351 L p .31374 .41835 L F P
0 g
s
.749 .577 .662 r
.31374 .41835 m .30496 .41711 L .30421 .41838 L p F P
0 g
s
.686 .688 .846 r
.4303 .38509 m .42224 .38847 L .43239 .3881 L closepath p F P
0 g
s
.686 .69 .848 r
.42224 .38847 m .4303 .38509 L p .41683 .3853 L F P
0 g
s
.741 .523 .599 r
.32493 .43748 m .3343 .43852 L .33559 .43322 L p F P
0 g
s
.741 .523 .599 r
.33559 .43322 m .32627 .43216 L .32493 .43748 L p F P
0 g
s
.683 .671 .832 r
.45817 .38638 m .45262 .38685 L .44669 .38935 L p F P
0 g
s
.684 .676 .837 r
.45262 .38685 m .44538 .38735 L .44669 .38935 L closepath p F P
0 g
s
.749 .549 .625 r
.31721 .43102 m .32215 .43169 L .32133 .42574 L p F P
0 g
s
.749 .549 .625 r
.32133 .42574 m .31932 .42547 L .31721 .43102 L p F P
0 g
s
.747 .595 .687 r
.30387 .41695 m .30496 .41711 L .30955 .41078 L p F P
0 g
s
.747 .595 .687 r
.30955 .41078 m .30165 .40964 L .30387 .41695 L p F P
0 g
s
.694 .689 .841 r
.38492 .38827 m .38991 .386 L p .37645 .3865 L F P
0 g
s
.694 .689 .841 r
.37645 .3865 m .37754 .38806 L .38492 .38827 L p F P
0 g
s
.672 .603 .77 r
.50159 .39373 m .49262 .3951 L .48995 .39637 L p F P
0 g
s
.675 .612 .777 r
.49262 .3951 m .48956 .39553 L .48995 .39637 L closepath p F P
0 g
s
.664 .439 .568 r
.46234 .43987 m .45461 .44047 L .45399 .44561 L p F P
0 g
s
.666 .441 .568 r
.44964 .44592 m .45399 .44561 L .45461 .44047 L p F P
0 g
s
.75 .552 .628 r
.30834 .42981 m .31721 .43102 L .31932 .42547 L p F P
0 g
s
.75 .552 .628 r
.31932 .42547 m .31054 .42424 L .30834 .42981 L p F P
0 g
s
.684 .687 .847 r
.4303 .38509 m .43239 .3881 L .43672 .38789 L p F P
0 g
s
.676 .625 .79 r
.48707 .39052 m .48956 .39553 L .49262 .3951 L p F P
0 g
s
.699 .691 .838 r
.37645 .3865 m .37369 .38781 L .37754 .38806 L closepath p F P
0 g
s
.723 .488 .57 r
.35307 .44537 m .35337 .4454 L .3539 .44032 L p F P
0 g
s
.723 .488 .57 r
.3539 .44032 m .35309 .44026 L .35307 .44537 L p F P
0 g
s
.73 .494 .57 r
.34347 .44452 m .35307 .44537 L .35309 .44026 L p F P
0 g
s
.73 .494 .57 r
.35309 .44026 m .34399 .43945 L .34347 .44452 L p F P
0 g
s
.68 .662 .826 r
.4708 .38522 m .4702 .38529 L .46015 .38951 L p F P
0 g
s
.682 .67 .831 r
.4702 .38529 m .45817 .38638 L .46015 .38951 L closepath p F P
0 g
s
.684 .687 .847 r
.43672 .38789 m .44376 .38497 L p .4303 .38509 L F P
0 g
s
.684 .683 .844 r
.44376 .38497 m .43672 .38789 L .44538 .38735 L closepath p F P
0 g
s
.699 .686 .835 r
.37369 .38781 m .37645 .3865 L p .36298 .38714 L F P
0 g
s
.699 .686 .835 r
.36298 .38714 m .36309 .3873 L .37369 .38781 L p F P
0 g
s
.741 .65 .759 r
.30724 .40261 m .31201 .39824 L .30972 .39386 L p F P
0 g
s
.741 .65 .759 r
.29859 .40131 m .30724 .40261 L p .30972 .39386 L F P
0 g
s
.744 .62 .721 r
.29842 .40148 m .29859 .40131 L .30724 .40261 L p F P
0 g
s
.744 .62 .721 r
.30724 .40261 m .30137 .40887 L .29842 .40148 L p F P
0 g
s
.731 .649 .768 r
.31654 .39477 m .30972 .39386 L .31201 .39824 L closepath p F P
0 g
s
.673 .614 .781 r
.50055 .3915 m .49262 .3951 L .50159 .39373 L closepath p F P
0 g
s
.676 .625 .79 r
.49262 .3951 m .50055 .3915 L p .48707 .39052 L F P
0 g
s
.685 .436 .539 r
.41039 .44735 m .40992 .44736 L .40964 .45216 L p F P
0 g
s
.692 .442 .54 r
.39829 .45212 m .40964 .45216 L .40992 .44736 L p F P
0 g
s
.692 .442 .54 r
.40992 .44736 m .39786 .44732 L .39829 .45212 L p F P
0 g
s
.684 .435 .539 r
.42341 .44714 m .41039 .44735 L .41089 .45214 L p F P
0 g
s
.685 .436 .539 r
.40964 .45216 m .41089 .45214 L .41039 .44735 L p F P
0 g
s
.661 .552 .721 r
.50628 .40587 m .50749 .40987 L p .517 .40045 L F P
0 g
s
.661 .552 .721 r
.517 .40045 m .51601 .40062 L .50628 .40587 L p F P
0 g
s
.664 .56 .727 r
.51601 .40062 m .50512 .40243 L .50628 .40587 L closepath p F P
0 g
s
.658 .434 .568 r
.47209 .43897 m .46234 .43987 L .46242 .44496 L p F P
0 g
s
.664 .439 .568 r
.45399 .44561 m .46242 .44496 L .46234 .43987 L p F P
0 g
s
.694 .443 .54 r
.39586 .4521 m .39829 .45212 L .39786 .44732 L p F P
0 g
s
.694 .443 .54 r
.39786 .44732 m .39616 .44731 L .39586 .4521 L p F P
0 g
s
.701 .449 .54 r
.38639 .45188 m .39586 .4521 L .39616 .44731 L p F P
0 g
s
.701 .449 .54 r
.39616 .44731 m .38601 .44707 L .38639 .45188 L p F P
0 g
s
.667 .579 .746 r
.50341 .39795 m .50512 .40243 L .51601 .40062 L p F P
0 g
s
.661 .552 .721 r
.50749 .40987 m .51934 .40786 L .517 .40045 L p F P
0 g
s
.657 .522 .687 r
.51977 .40951 m .51934 .40786 L .50749 .40987 L p F P
0 g
s
.657 .522 .687 r
.50749 .40987 m .50916 .4165 L .51977 .40951 L p F P
0 g
s
.661 .528 .691 r
.509 .41662 m .50916 .4165 L .50749 .40987 L p F P
0 g
s
.677 .429 .539 r
.42378 .44712 m .42341 .44714 L .42315 .45194 L p F P
0 g
s
.684 .435 .539 r
.41089 .45214 m .42315 .45194 L .42341 .44714 L p F P
0 g
s
.675 .428 .539 r
.43664 .44665 m .42378 .44712 L .42433 .4519 L p F P
0 g
s
.677 .429 .539 r
.42315 .45194 m .42433 .4519 L .42378 .44712 L p F P
0 g
s
.683 .683 .844 r
.44376 .38497 m .44538 .38735 L .45262 .38685 L p F P
0 g
s
.677 .649 .815 r
.47361 .38988 m .48419 .38543 L .48707 .39052 L p F P
0 g
s
.68 .661 .824 r
.4708 .38522 m .47361 .38988 L .48419 .38543 L p F P
0 g
s
.741 .523 .599 r
.32251 .4372 m .32493 .43748 L .32627 .43216 L p F P
0 g
s
.741 .523 .599 r
.32627 .43216 m .32215 .43169 L .32251 .4372 L p F P
0 g
s
.704 .688 .832 r
.36298 .38714 m .36272 .38727 L .36309 .3873 L closepath p F P
0 g
s
.727 .658 .781 r
.31654 .39477 m .32252 .39062 L p .30899 .39256 L F P
0 g
s
.727 .658 .781 r
.30899 .39256 m .30972 .39386 L .31654 .39477 L p F P
0 g
s
.702 .45 .54 r
.38179 .45176 m .38639 .45188 L .38601 .44707 L p F P
0 g
s
.702 .45 .54 r
.38601 .44707 m .38211 .44696 L .38179 .45176 L p F P
0 g
s
.698 .702 .85 r
.36272 .38727 m .36298 .38714 L .35994 .38311 L p F P
0 g
s
.698 .702 .85 r
.35994 .38311 m .35298 .38633 L .36272 .38727 L p F P
0 g
s
.706 .675 .818 r
.3495 .38801 m .35298 .38633 L .36272 .38727 L p F P
0 g
s
.753 .613 .704 r
.30137 .40887 m .30086 .40951 L .30165 .40964 L closepath p F P
0 g
s
.756 .6 .684 r
.29665 .41571 m .30387 .41695 L .30165 .40964 L p F P
0 g
s
.756 .6 .684 r
.30165 .40964 m .30086 .40951 L .29665 .41571 L p F P
0 g
s
.75 .578 .663 r
.30496 .41711 m .30387 .41695 L .30421 .41838 L closepath p F P
0 g
s
.699 .686 .835 r
.37645 .3865 m .37342 .38259 L .36298 .38714 L p F P
0 g
s
.683 .723 .88 r
.37342 .38259 m .36298 .38714 L .35994 .38311 L p F P
0 g
s
.656 .497 .656 r
.49833 .42456 m .50028 .42427 L .509 .41662 L p F P
0 g
s
.651 .473 .63 r
.50028 .42427 m .49833 .42456 L .49856 .42622 L closepath p F P
0 g
s
.709 .456 .541 r
.37504 .45147 m .38179 .45176 L .38211 .44696 L p F P
0 g
s
.709 .456 .541 r
.38211 .44696 m .37471 .44664 L .37504 .45147 L p F P
0 g
s
.752 .623 .716 r
.30086 .40951 m .30137 .40887 L .29842 .40148 L p F P
0 g
s
.694 .689 .841 r
.38991 .386 m .3869 .38217 L .37645 .3865 L p F P
0 g
s
.678 .727 .887 r
.3869 .38217 m .37645 .3865 L .37342 .38259 L p F P
0 g
s
.7 .691 .838 r
.35298 .38633 m .34807 .38599 L .3495 .38801 L closepath p F P
0 g
s
.73 .494 .57 r
.33797 .44403 m .34347 .44452 L .34399 .43945 L p F P
0 g
s
.73 .494 .57 r
.34399 .43945 m .33801 .43892 L .33797 .44403 L p F P
0 g
s
.752 .623 .716 r
.29842 .40148 m .29273 .40805 L .30086 .40951 L p F P
0 g
s
.757 .605 .689 r
.28831 .41432 m .29665 .41571 L .30086 .40951 L p F P
0 g
s
.757 .605 .689 r
.30086 .40951 m .29273 .40805 L .28831 .41432 L p F P
0 g
s
.758 .581 .657 r
.3019 .42295 m .30421 .41838 L .30387 .41695 L p F P
0 g
s
.758 .581 .657 r
.29355 .42157 m .3019 .42295 L p .30387 .41695 L F P
0 g
s
.758 .581 .657 r
.30387 .41695 m .29665 .41571 L .29355 .42157 L p F P
0 g
s
.65 .448 .597 r
.49507 .43083 m .48688 .43189 L .48729 .43729 L p F P
0 g
s
.691 .691 .845 r
.40337 .3856 m .40038 .38182 L .38991 .386 L p F P
0 g
s
.674 .729 .891 r
.40038 .38182 m .38991 .386 L .3869 .38217 L p F P
0 g
s
.667 .579 .746 r
.5169 .40017 m .51403 .39298 L .50341 .39795 L p F P
0 g
s
.667 .579 .746 r
.51601 .40062 m .5169 .40017 L p .50341 .39795 L F P
0 g
s
.67 .599 .767 r
.50159 .39373 m .50341 .39795 L .51403 .39298 L p F P
0 g
s
.708 .692 .832 r
.34807 .38599 m .34321 .3854 L .33602 .38914 L p F P
0 g
s
.706 .685 .827 r
.34321 .3854 m .33602 .38914 L .33297 .38468 L p F P
0 g
s
.717 .688 .822 r
.32252 .39062 m .33297 .38468 L .33602 .38914 L p F P
0 g
s
.653 .492 .653 r
.50028 .42427 m .5103 .42272 L .50918 .41659 L p F P
0 g
s
.653 .492 .653 r
.50918 .41659 m .509 .41662 L .50028 .42427 L p F P
0 g
s
.648 .468 .627 r
.5103 .42272 m .50028 .42427 L .49856 .42622 L p F P
0 g
s
.756 .575 .652 r
.30421 .41838 m .3019 .42295 L .30532 .42351 L closepath p F P
0 g
s
.75 .552 .628 r
.30618 .42951 m .30834 .42981 L .31054 .42424 L p F P
0 g
s
.75 .552 .628 r
.31054 .42424 m .30532 .42351 L .30618 .42951 L p F P
0 g
s
.668 .422 .539 r
.43822 .44657 m .43664 .44665 L .4364 .45146 L p F P
0 g
s
.675 .428 .539 r
.42433 .4519 m .4364 .45146 L .43664 .44665 L p F P
0 g
s
.71 .457 .54 r
.36741 .45112 m .37504 .45147 L .37471 .44664 L p F P
0 g
s
.71 .457 .54 r
.37471 .44664 m .36775 .44633 L .36741 .45112 L p F P
0 g
s
.682 .677 .839 r
.45723 .38495 m .45262 .38685 L .45817 .38638 L closepath p F P
0 g
s
.683 .683 .844 r
.45262 .38685 m .45723 .38495 L p .44376 .38497 L F P
0 g
s
.749 .529 .598 r
.31593 .43631 m .32251 .4372 L .32215 .43169 L p F P
0 g
s
.749 .529 .598 r
.32215 .43169 m .31721 .43102 L .31593 .43631 L p F P
0 g
s
.672 .73 .893 r
.41386 .38153 m .40337 .3856 L .40038 .38182 L p F P
0 g
s
.688 .691 .847 r
.41683 .3853 m .41386 .38153 L .40337 .3856 L p F P
0 g
s
.666 .42 .539 r
.44964 .44592 m .43822 .44657 L .43884 .45133 L p F P
0 g
s
.668 .422 .539 r
.4364 .45146 m .43884 .45133 L .43822 .44657 L p F P
0 g
s
.658 .512 .674 r
.50916 .4165 m .509 .41662 L .50918 .41659 L closepath p F P
0 g
s
.652 .508 .675 r
.52098 .41453 m .51977 .40951 L .50916 .4165 L p F P
0 g
s
.652 .508 .675 r
.50916 .4165 m .50918 .41659 L .52098 .41453 L p F P
0 g
s
.648 .468 .627 r
.49856 .42622 m .49907 .43029 L p .5103 .42272 L F P
0 g
s
.653 .469 .622 r
.49856 .42622 m .49507 .43083 L .49907 .43029 L closepath p F P
0 g
s
.648 .488 .653 r
.52214 .42069 m .52098 .41453 L .50918 .41659 L p F P
0 g
s
.648 .488 .653 r
.50918 .41659 m .5103 .42272 L .52214 .42069 L p F P
0 g
s
.656 .432 .567 r
.47492 .4387 m .47209 .43897 L .47145 .44413 L p F P
0 g
s
.658 .434 .568 r
.46242 .44496 m .47145 .44413 L .47209 .43897 L p F P
0 g
s
.676 .625 .79 r
.50055 .3915 m .49767 .38605 L .48707 .39052 L p F P
0 g
s
.674 .662 .83 r
.48707 .39052 m .49767 .38605 L .49522 .38197 L p F P
0 g
s
.674 .662 .83 r
.48419 .38543 m .48707 .39052 L p .49522 .38197 L F P
0 g
s
.686 .69 .848 r
.4303 .38509 m .42734 .38128 L .41683 .3853 L p F P
0 g
s
.67 .728 .893 r
.42734 .38128 m .41683 .3853 L .41386 .38153 L p F P
0 g
s
.738 .5 .569 r
.3338 .44358 m .33797 .44403 L .33801 .43892 L p F P
0 g
s
.738 .5 .569 r
.33801 .43892 m .3343 .43852 L .3338 .44358 L p F P
0 g
s
.71 .7 .839 r
.32252 .39062 m .33297 .38468 L .33277 .38442 L p F P
0 g
s
.71 .7 .839 r
.31946 .38591 m .32252 .39062 L p .33277 .38442 L F P
0 g
s
.727 .658 .781 r
.32252 .39062 m .31946 .38591 L .30899 .39256 L p F P
0 g
s
.717 .463 .541 r
.36414 .45091 m .36741 .45112 L .36775 .44633 L p F P
0 g
s
.717 .463 .541 r
.36775 .44633 m .36385 .44608 L .36414 .45091 L p F P
0 g
s
.741 .65 .759 r
.30972 .39386 m .30773 .39352 L .29859 .40131 L p F P
0 g
s
.736 .661 .776 r
.30899 .39256 m .30773 .39352 L .30972 .39386 L closepath p F P
0 g
s
.681 .677 .839 r
.45723 .38495 m .45817 .38638 L .4702 .38529 L p F P
0 g
s
.649 .426 .567 r
.48739 .44238 m .48729 .43729 L .47492 .4387 L p F P
0 g
s
.649 .426 .567 r
.47492 .4387 m .47501 .44378 L .48739 .44238 L p F P
0 g
s
.656 .432 .567 r
.47145 .44413 m .47501 .44378 L .47492 .4387 L p F P
0 g
s
.738 .659 .773 r
.29833 .40127 m .29859 .40131 L .30773 .39352 L p F P
0 g
s
.743 .631 .735 r
.29859 .40131 m .29833 .40127 L .29842 .40148 L closepath p F P
0 g
s
.753 .63 .724 r
.29273 .40805 m .29842 .40148 L .29833 .40127 L p F P
0 g
s
.697 .696 .845 r
.35298 .38633 m .35994 .38311 L p .34646 .38379 L F P
0 g
s
.697 .696 .845 r
.34646 .38379 m .34807 .38599 L .35298 .38633 L p F P
0 g
s
.684 .687 .847 r
.44376 .38497 m .44082 .38109 L .4303 .38509 L p F P
0 g
s
.67 .725 .891 r
.44082 .38109 m .4303 .38509 L .42734 .38128 L p F P
0 g
s
.738 .659 .773 r
.29541 .39528 m .29833 .40127 L p .30773 .39352 L F P
0 g
s
.748 .645 .747 r
.29541 .39528 m .29062 .3998 L .29833 .40127 L closepath p F P
0 g
s
.753 .63 .724 r
.2849 .40671 m .29273 .40805 L p .29833 .40127 L F P
0 g
s
.753 .63 .724 r
.28474 .40628 m .2849 .40671 L p .29833 .40127 L F P
0 g
s
.753 .63 .724 r
.29833 .40127 m .29062 .3998 L .28474 .40628 L p F P
0 g
s
.718 .463 .54 r
.35366 .45023 m .36414 .45091 L .36385 .44608 L p F P
0 g
s
.718 .463 .54 r
.36385 .44608 m .35337 .4454 L .35366 .45023 L p F P
0 g
s
.671 .613 .782 r
.50055 .3915 m .50159 .39373 L .51348 .39175 L p F P
0 g
s
.67 .599 .767 r
.51403 .39298 m .51348 .39175 L .50159 .39373 L p F P
0 g
s
.739 .501 .57 r
.3244 .44254 m .3338 .44358 L .3343 .43852 L p F P
0 g
s
.739 .501 .57 r
.3343 .43852 m .32493 .43748 L .3244 .44254 L p F P
0 g
s
.749 .53 .599 r
.30702 .43512 m .31593 .43631 L .31721 .43102 L p F P
0 g
s
.749 .53 .599 r
.31721 .43102 m .30834 .42981 L .30702 .43512 L p F P
0 g
s
.757 .557 .626 r
.29984 .42848 m .30618 .42951 L .30532 .42351 L p F P
0 g
s
.757 .557 .626 r
.30532 .42351 m .3019 .42295 L .29984 .42848 L p F P
0 g
s
.66 .415 .538 r
.45399 .44561 m .44964 .44592 L .44942 .45073 L p F P
0 g
s
.666 .42 .539 r
.43884 .45133 m .44942 .45073 L .44964 .44592 L p F P
0 g
s
.738 .659 .773 r
.30773 .39352 m .29951 .39208 L .29541 .39528 L p F P
0 g
s
.732 .67 .789 r
.30773 .39352 m .30899 .39256 L .30593 .38755 L p F P
0 g
s
.732 .67 .789 r
.30593 .38755 m .29951 .39208 L .30773 .39352 L p F P
0 g
s
.683 .683 .844 r
.45723 .38495 m .45431 .38096 L .44376 .38497 L p F P
0 g
s
.671 .72 .886 r
.45431 .38096 m .44376 .38497 L .44082 .38109 L p F P
0 g
s
.705 .698 .841 r
.34646 .38379 m .34321 .3854 L .34807 .38599 L closepath p F P
0 g
s
.647 .445 .595 r
.49907 .43029 m .49507 .43083 L .49232 .43663 L p F P
0 g
s
.65 .448 .597 r
.48729 .43729 m .49232 .43663 L .49507 .43083 L p F P
0 g
s
.719 .693 .824 r
.30899 .39256 m .31946 .38591 L .31686 .38226 L p F P
0 g
s
.719 .693 .824 r
.30593 .38755 m .30899 .39256 L p .31686 .38226 L F P
0 g
s
.756 .584 .663 r
.28875 .42078 m .29355 .42157 L .29665 .41571 L p F P
0 g
s
.756 .584 .663 r
.28759 .41558 m .28875 .42078 L p .29665 .41571 L F P
0 g
s
.756 .584 .663 r
.29665 .41571 m .28831 .41432 L .28759 .41558 L p F P
0 g
s
.658 .413 .539 r
.46242 .44496 m .45399 .44561 L .45468 .45035 L p F P
0 g
s
.66 .415 .538 r
.44942 .45073 m .45468 .45035 L .45399 .44561 L p F P
0 g
s
.671 .613 .782 r
.51348 .39175 m .51117 .38701 L .50055 .3915 L p F P
0 g
s
.67 .644 .815 r
.51117 .38701 m .50055 .3915 L .49767 .38605 L p F P
0 g
s
.663 .567 .736 r
.5169 .40017 m .51601 .40062 L .517 .40045 L closepath p F P
0 g
s
.754 .602 .688 r
.28724 .41414 m .28831 .41432 L .29273 .40805 L p F P
0 g
s
.754 .602 .688 r
.29273 .40805 m .2849 .40671 L .28724 .41414 L p F P
0 g
s
.681 .677 .839 r
.47071 .38508 m .4678 .38092 L .45723 .38495 L p F P
0 g
s
.681 .677 .839 r
.4702 .38529 m .47071 .38508 L p .45723 .38495 L F P
0 g
s
.671 .712 .879 r
.4678 .38092 m .45723 .38495 L .45431 .38096 L p F P
0 g
s
.72 .465 .54 r
.3527 .45016 m .35366 .45023 L .35337 .4454 L p F P
0 g
s
.72 .465 .54 r
.35337 .4454 m .35307 .44537 L .3527 .45016 L p F P
0 g
s
.758 .56 .628 r
.29141 .42712 m .29984 .42848 L .3019 .42295 L p F P
0 g
s
.758 .56 .628 r
.3019 .42295 m .29355 .42157 L .29141 .42712 L p F P
0 g
s
.727 .472 .54 r
.34372 .44937 m .3527 .45016 L .35307 .44537 L p F P
0 g
s
.727 .472 .54 r
.35307 .44537 m .34347 .44452 L .34372 .44937 L p F P
0 g
s
.659 .564 .738 r
.5169 .40017 m .517 .40045 L .52864 .39818 L p F P
0 g
s
.657 .547 .718 r
.53041 .40364 m .52864 .39818 L .517 .40045 L p F P
0 g
s
.657 .547 .718 r
.52419 .40695 m .53041 .40364 L p .517 .40045 L F P
0 g
s
.657 .547 .718 r
.517 .40045 m .51934 .40786 L .52419 .40695 L p F P
0 g
s
.659 .564 .738 r
.52864 .39818 m .52754 .39522 L .5169 .40017 L p F P
0 g
s
.663 .594 .768 r
.5169 .40017 m .52754 .39522 L .52518 .38954 L p F P
0 g
s
.663 .594 .768 r
.51403 .39298 m .5169 .40017 L p .52518 .38954 L F P
0 g
s
.652 .525 .695 r
.52419 .40695 m .51934 .40786 L .51977 .40951 L closepath p F P
0 g
s
.648 .468 .627 r
.49907 .43029 m .51106 .42845 L .5103 .42272 L p F P
0 g
s
.641 .44 .596 r
.51148 .43384 m .51106 .42845 L .49907 .43029 L p F P
0 g
s
.641 .44 .596 r
.49907 .43029 m .49947 .43567 L .51148 .43384 L p F P
0 g
s
.647 .445 .595 r
.49232 .43663 m .49947 .43567 L .49907 .43029 L p F P
0 g
s
.696 .704 .854 r
.34321 .3854 m .34646 .38379 L .34339 .37996 L p F P
0 g
s
.696 .704 .854 r
.34339 .37996 m .3334 .38447 L .34321 .3854 L p F P
0 g
s
.706 .685 .827 r
.33297 .38468 m .3334 .38447 L .34321 .3854 L p F P
0 g
s
.642 .463 .626 r
.52269 .42467 m .52214 .42069 L .5103 .42272 L p F P
0 g
s
.642 .463 .626 r
.52075 .42681 m .52269 .42467 L p .5103 .42272 L F P
0 g
s
.642 .463 .626 r
.5103 .42272 m .51106 .42845 L .52075 .42681 L p F P
0 g
s
.68 .669 .833 r
.47071 .38508 m .4702 .38529 L .4708 .38522 L closepath p F P
0 g
s
.649 .518 .69 r
.51977 .40951 m .52098 .41453 L p .53099 .40563 L F P
0 g
s
.649 .518 .69 r
.53099 .40563 m .52419 .40695 L .51977 .40951 L p F P
0 g
s
.677 .668 .834 r
.47071 .38508 m .4708 .38522 L .48304 .38364 L p F P
0 g
s
.68 .661 .824 r
.48419 .38543 m .48304 .38364 L .4708 .38522 L p F P
0 g
s
.677 .668 .834 r
.48304 .38364 m .48129 .38102 L .47071 .38508 L p F P
0 g
s
.672 .702 .87 r
.48129 .38102 m .47071 .38508 L .4678 .38092 L p F P
0 g
s
.651 .408 .538 r
.47145 .44413 m .46242 .44496 L .46222 .44978 L p F P
0 g
s
.658 .413 .539 r
.45468 .45035 m .46222 .44978 L .46242 .44496 L p F P
0 g
s
.74 .502 .57 r
.32246 .44232 m .3244 .44254 L .32493 .43748 L p F P
0 g
s
.74 .502 .57 r
.32493 .43748 m .32251 .4372 L .32246 .44232 L p F P
0 g
s
.75 .531 .599 r
.30655 .43505 m .30702 .43512 L .30834 .42981 L p F P
0 g
s
.75 .531 .599 r
.30834 .42981 m .30618 .42951 L .30655 .43505 L p F P
0 g
s
.642 .421 .567 r
.49232 .43663 m .48729 .43729 L .48739 .44238 L p F P
0 g
s
.735 .654 .769 r
.29951 .39208 m .29314 .39107 L .29541 .39528 L closepath p F P
0 g
s
.747 .655 .759 r
.29062 .3998 m .29541 .39528 L .29314 .39107 L p F P
0 g
s
.747 .509 .57 r
.31541 .44138 m .32246 .44232 L .32251 .4372 L p F P
0 g
s
.747 .509 .57 r
.32251 .4372 m .31593 .43631 L .31541 .44138 L p F P
0 g
s
.679 .411 .508 r
.41089 .45214 m .40964 .45216 L .40908 .45669 L p F P
0 g
s
.687 .417 .51 r
.39961 .45666 m .40908 .45669 L .40964 .45216 L p F P
0 g
s
.687 .417 .51 r
.40964 .45216 m .39829 .45212 L .39961 .45666 L p F P
0 g
s
.747 .655 .759 r
.28245 .39834 m .29062 .3998 L p .29314 .39107 L F P
0 g
s
.75 .625 .721 r
.28177 .39902 m .28245 .39834 L .29062 .3998 L p F P
0 g
s
.75 .625 .721 r
.29062 .3998 m .28474 .40628 L .28177 .39902 L p F P
0 g
s
.679 .411 .508 r
.40908 .45669 m .41233 .45665 L .41089 .45214 L p F P
0 g
s
.678 .41 .509 r
.42315 .45194 m .41089 .45214 L .41233 .45665 L p F P
0 g
s
.688 .418 .509 r
.39528 .45663 m .39961 .45666 L .39829 .45212 L p F P
0 g
s
.688 .418 .509 r
.39829 .45212 m .39586 .4521 L .39528 .45663 L p F P
0 g
s
.695 .425 .51 r
.38759 .45645 m .39528 .45663 L .39586 .4521 L p F P
0 g
s
.695 .425 .51 r
.39586 .4521 m .38639 .45188 L .38759 .45645 L p F P
0 g
s
.728 .472 .54 r
.33757 .44882 m .34372 .44937 L .34347 .44452 L p F P
0 g
s
.728 .472 .54 r
.34347 .44452 m .33797 .44403 L .33757 .44882 L p F P
0 g
s
.697 .696 .845 r
.35994 .38311 m .35688 .37943 L .34646 .38379 L p F P
0 g
s
.678 .733 .892 r
.35688 .37943 m .34646 .38379 L .34339 .37996 L p F P
0 g
s
.758 .538 .598 r
.29859 .43377 m .30655 .43505 L .30618 .42951 L p F P
0 g
s
.758 .538 .598 r
.30618 .42951 m .29984 .42848 L .29859 .43377 L p F P
0 g
s
.683 .723 .88 r
.35994 .38311 m .37038 .37903 L .37342 .38259 L p F P
0 g
s
.671 .739 .901 r
.37038 .37903 m .35994 .38311 L .35688 .37943 L p F P
0 g
s
.67 .403 .508 r
.42433 .4519 m .42315 .45194 L .42262 .45648 L p F P
0 g
s
.678 .41 .509 r
.41233 .45665 m .42262 .45648 L .42315 .45194 L p F P
0 g
s
.649 .518 .69 r
.52098 .41453 m .53264 .4123 L .53099 .40563 L p F P
0 g
s
.643 .486 .656 r
.53332 .41573 m .53264 .4123 L .52098 .41453 L p F P
0 g
s
.643 .486 .656 r
.52817 .41955 m .53332 .41573 L p .52098 .41453 L F P
0 g
s
.643 .486 .656 r
.52098 .41453 m .52214 .42069 L .52817 .41955 L p F P
0 g
s
.732 .663 .782 r
.29951 .39208 m .30593 .38755 L p .29237 .38973 L F P
0 g
s
.732 .663 .782 r
.29237 .38973 m .29314 .39107 L .29951 .39208 L p F P
0 g
s
.699 .698 .846 r
.3334 .38447 m .33277 .38442 L .33297 .38468 L closepath p F P
0 g
s
.676 .672 .839 r
.4916 .38252 m .48304 .38364 L .48419 .38543 L closepath p F P
0 g
s
.674 .662 .83 r
.49522 .38197 m .4916 .38252 L .48419 .38543 L p F P
0 g
s
.668 .402 .509 r
.4364 .45146 m .42433 .4519 L .42591 .45637 L p F P
0 g
s
.67 .403 .508 r
.42262 .45648 m .42591 .45637 L .42433 .4519 L p F P
0 g
s
.697 .426 .51 r
.38118 .45628 m .38759 .45645 L .38639 .45188 L p F P
0 g
s
.697 .426 .51 r
.38639 .45188 m .38179 .45176 L .38118 .45628 L p F P
0 g
s
.663 .594 .768 r
.52518 .38954 m .51935 .39068 L .51403 .39298 L p F P
0 g
s
.667 .605 .777 r
.51935 .39068 m .51348 .39175 L .51403 .39298 L closepath p F P
0 g
s
.653 .535 .707 r
.53041 .40364 m .52419 .40695 L .53099 .40563 L closepath p F P
0 g
s
.678 .727 .887 r
.37342 .38259 m .38387 .37869 L .3869 .38217 L p F P
0 g
s
.665 .744 .909 r
.38387 .37869 m .37342 .38259 L .37038 .37903 L p F P
0 g
s
.696 .703 .852 r
.3334 .38447 m .34339 .37996 L p .32989 .38065 L F P
0 g
s
.696 .703 .852 r
.32989 .38065 m .33277 .38442 L .3334 .38447 L p F P
0 g
s
.704 .433 .511 r
.37614 .45606 m .38118 .45628 L .38179 .45176 L p F P
0 g
s
.704 .433 .511 r
.38179 .45176 m .37504 .45147 L .37614 .45606 L p F P
0 g
s
.705 .705 .847 r
.32989 .38065 m .3248 .38315 L .33277 .38442 L closepath p F P
0 g
s
.71 .7 .839 r
.33277 .38442 m .3248 .38315 L .31946 .38591 L p F P
0 g
s
.757 .585 .664 r
.28831 .41432 m .28724 .41414 L .28759 .41558 L closepath p F P
0 g
s
.674 .729 .891 r
.3869 .38217 m .39736 .3784 L .40038 .38182 L p F P
0 g
s
.661 .747 .914 r
.39736 .3784 m .3869 .38217 L .38387 .37869 L p F P
0 g
s
.707 .691 .832 r
.3248 .38315 m .31686 .38226 L .31946 .38591 L closepath p F P
0 g
s
.649 .406 .538 r
.47501 .44378 m .47145 .44413 L .47223 .44886 L p F P
0 g
s
.651 .408 .538 r
.46222 .44978 m .47223 .44886 L .47145 .44413 L p F P
0 g
s
.668 .619 .791 r
.51117 .38701 m .51348 .39175 L .51935 .39068 L p F P
0 g
s
.76 .62 .704 r
.28474 .40628 m .28447 .40663 L .2849 .40671 L closepath p F P
0 g
s
.763 .606 .684 r
.28043 .41278 m .28724 .41414 L .2849 .40671 L p F P
0 g
s
.763 .606 .684 r
.2849 .40671 m .28447 .40663 L .28043 .41278 L p F P
0 g
s
.64 .419 .567 r
.49947 .43567 m .49232 .43663 L .49155 .44184 L p F P
0 g
s
.642 .421 .567 r
.48739 .44238 m .49155 .44184 L .49232 .43663 L p F P
0 g
s
.759 .629 .715 r
.28447 .40663 m .28474 .40628 L .28177 .39902 L p F P
0 g
s
.766 .588 .657 r
.28536 .42013 m .28759 .41558 L .28724 .41414 L p F P
0 g
s
.766 .588 .657 r
.27744 .4186 m .28536 .42013 L p .28724 .41414 L F P
0 g
s
.766 .588 .657 r
.28724 .41414 m .28043 .41278 L .27744 .4186 L p F P
0 g
s
.759 .629 .715 r
.28177 .39902 m .27677 .40502 L .28447 .40663 L p F P
0 g
s
.764 .612 .69 r
.27253 .41123 m .28043 .41278 L .28447 .40663 L p F P
0 g
s
.764 .612 .69 r
.28447 .40663 m .27677 .40502 L .27253 .41123 L p F P
0 g
s
.735 .479 .541 r
.334 .44843 m .33757 .44882 L .33797 .44403 L p F P
0 g
s
.735 .479 .541 r
.33797 .44403 m .3338 .44358 L .334 .44843 L p F P
0 g
s
.758 .559 .628 r
.28965 .42683 m .29141 .42712 L .29355 .42157 L p F P
0 g
s
.758 .559 .628 r
.29355 .42157 m .28875 .42078 L .28965 .42683 L p F P
0 g
s
.705 .433 .51 r
.36678 .45564 m .37614 .45606 L .37504 .45147 L p F P
0 g
s
.705 .433 .51 r
.37504 .45147 m .36741 .45112 L .36678 .45564 L p F P
0 g
s
.661 .396 .508 r
.43884 .45133 m .4364 .45146 L .4359 .45601 L p F P
0 g
s
.668 .402 .509 r
.42591 .45637 m .4359 .45601 L .4364 .45146 L p F P
0 g
s
.672 .73 .893 r
.40038 .38182 m .41086 .37813 L .41386 .38153 L p F P
0 g
s
.659 .748 .916 r
.41086 .37813 m .40038 .38182 L .39736 .3784 L p F P
0 g
s
.764 .583 .652 r
.28759 .41558 m .28536 .42013 L .28875 .42078 L closepath p F P
0 g
s
.659 .395 .509 r
.44942 .45073 m .43884 .45133 L .44056 .45577 L p F P
0 g
s
.661 .396 .508 r
.4359 .45601 m .44056 .45577 L .43884 .45133 L p F P
0 g
s
.747 .508 .57 r
.30649 .44019 m .31541 .44138 L .31593 .43631 L p F P
0 g
s
.747 .508 .57 r
.30649 .44014 m .30649 .44019 L p .31593 .43631 L F P
0 g
s
.747 .508 .57 r
.31593 .43631 m .30702 .43512 L .30649 .44014 L p F P
0 g
s
.641 .4 .538 r
.48722 .4472 m .48739 .44238 L .47501 .44378 L p F P
0 g
s
.641 .4 .538 r
.47501 .44378 m .47483 .44861 L .48722 .4472 L p F P
0 g
s
.649 .406 .538 r
.47223 .44886 m .47483 .44861 L .47501 .44378 L p F P
0 g
s
.67 .728 .893 r
.41386 .38153 m .42436 .37787 L .42734 .38128 L p F P
0 g
s
.658 .748 .916 r
.42436 .37787 m .41386 .38153 L .41086 .37813 L p F P
0 g
s
.67 .644 .815 r
.49767 .38605 m .5083 .38186 L .51117 .38701 L p F P
0 g
s
.674 .66 .828 r
.49522 .38197 m .49767 .38605 L .5083 .38186 L p F P
0 g
s
.719 .693 .824 r
.31686 .38226 m .31557 .38203 L .30593 .38755 L p F P
0 g
s
.715 .682 .817 r
.31557 .38203 m .30593 .38755 L .30284 .38294 L p F P
0 g
s
.732 .663 .782 r
.30593 .38755 m .30284 .38294 L .29237 .38973 L p F P
0 g
s
.713 .44 .511 r
.36515 .45554 m .36678 .45564 L .36741 .45112 L p F P
0 g
s
.713 .44 .511 r
.36741 .45112 m .36414 .45091 L .36515 .45554 L p F P
0 g
s
.736 .479 .54 r
.32461 .44739 m .334 .44843 L .3338 .44358 L p F P
0 g
s
.736 .479 .54 r
.3338 .44358 m .3244 .44254 L .32461 .44739 L p F P
0 g
s
.676 .679 .846 r
.48129 .38102 m .48304 .38364 L .4916 .38252 L p F P
0 g
s
.67 .725 .891 r
.42734 .38128 m .43786 .37763 L .44082 .38109 L p F P
0 g
s
.659 .746 .914 r
.43786 .37763 m .42734 .38128 L .42436 .37787 L p F P
0 g
s
.741 .666 .777 r
.29237 .38973 m .29117 .39067 L .29314 .39107 L closepath p F P
0 g
s
.747 .655 .759 r
.29314 .39107 m .29117 .39067 L .28245 .39834 L p F P
0 g
s
.757 .538 .599 r
.29012 .43242 m .29859 .43377 L .29984 .42848 L p F P
0 g
s
.757 .538 .599 r
.29984 .42848 m .29141 .42712 L .29012 .43242 L p F P
0 g
s
.714 .44 .51 r
.35469 .45484 m .36515 .45554 L .36414 .45091 L p F P
0 g
s
.714 .44 .51 r
.36414 .45091 m .35366 .45023 L .35469 .45484 L p F P
0 g
s
.634 .436 .597 r
.52075 .42681 m .51106 .42845 L .51148 .43384 L p F P
0 g
s
.743 .664 .772 r
.28138 .39814 m .28245 .39834 L .29117 .39067 L p F P
0 g
s
.749 .636 .735 r
.28245 .39834 m .28138 .39814 L .28177 .39902 L closepath p F P
0 g
s
.652 .388 .508 r
.45468 .45035 m .44942 .45073 L .44894 .45529 L p F P
0 g
s
.659 .395 .509 r
.44056 .45577 m .44894 .45529 L .44942 .45073 L p F P
0 g
s
.766 .565 .626 r
.28336 .42564 m .28965 .42683 L .28875 .42078 L p F P
0 g
s
.766 .565 .626 r
.28875 .42078 m .28536 .42013 L .28336 .42564 L p F P
0 g
s
.76 .636 .723 r
.27677 .40502 m .28177 .39902 L .28138 .39814 L p F P
0 g
s
.671 .72 .886 r
.44082 .38109 m .45137 .3774 L .45431 .38096 L p F P
0 g
s
.661 .742 .91 r
.45137 .3774 m .44082 .38109 L .43786 .37763 L p F P
0 g
s
.633 .413 .567 r
.51161 .43894 m .51148 .43384 L .49947 .43567 L p F P
0 g
s
.633 .413 .567 r
.49947 .43567 m .49958 .44076 L .51161 .43894 L p F P
0 g
s
.64 .419 .567 r
.49155 .44184 m .49958 .44076 L .49947 .43567 L p F P
0 g
s
.648 .532 .708 r
.54248 .40317 m .54108 .39852 L .53041 .40364 L p F P
0 g
s
.648 .532 .708 r
.53041 .40364 m .53099 .40563 L .54248 .40317 L p F P
0 g
s
.653 .549 .724 r
.52864 .39818 m .53041 .40364 L .54108 .39852 L p F P
0 g
s
.635 .46 .628 r
.52817 .41955 m .52214 .42069 L .52269 .42467 L closepath p F P
0 g
s
.656 .568 .744 r
.52754 .39522 m .52864 .39818 L .54015 .39575 L p F P
0 g
s
.653 .549 .724 r
.54108 .39852 m .54015 .39575 L .52864 .39818 L p F P
0 g
s
.665 .605 .779 r
.52468 .38844 m .51935 .39068 L .52518 .38954 L closepath p F P
0 g
s
.668 .619 .791 r
.51935 .39068 m .52468 .38844 L p .51117 .38701 L F P
0 g
s
.737 .675 .789 r
.29117 .39067 m .29237 .38973 L .28928 .38479 L p F P
0 g
s
.737 .675 .789 r
.28928 .38479 m .2834 .38907 L .29117 .39067 L p F P
0 g
s
.743 .664 .772 r
.27874 .39285 m .28138 .39814 L p .29117 .39067 L F P
0 g
s
.743 .664 .772 r
.29117 .39067 m .2834 .38907 L .27874 .39285 L p F P
0 g
s
.754 .65 .746 r
.27874 .39285 m .27482 .39669 L .28138 .39814 L closepath p F P
0 g
s
.76 .636 .723 r
.26893 .40344 m .27677 .40502 L p .28138 .39814 L F P
0 g
s
.76 .636 .723 r
.28138 .39814 m .27482 .39669 L .26893 .40344 L p F P
0 g
s
.643 .511 .686 r
.54398 .40909 m .54248 .40317 L .53099 .40563 L p F P
0 g
s
.643 .511 .686 r
.54164 .41041 m .54398 .40909 L p .53099 .40563 L F P
0 g
s
.643 .511 .686 r
.53099 .40563 m .53264 .4123 L .54164 .41041 L p F P
0 g
s
.704 .696 .84 r
.3248 .38315 m .32989 .38065 L p .31638 .38159 L F P
0 g
s
.704 .696 .84 r
.31638 .38159 m .31686 .38226 L .3248 .38315 L p F P
0 g
s
.723 .697 .825 r
.29237 .38973 m .30284 .38294 L .30039 .37958 L p F P
0 g
s
.723 .697 .825 r
.28928 .38479 m .29237 .38973 L p .30039 .37958 L F P
0 g
s
.663 .735 .903 r
.46488 .37723 m .45431 .38096 L .45137 .3774 L p F P
0 g
s
.671 .712 .879 r
.45431 .38096 m .46488 .37723 L .4678 .38092 L p F P
0 g
s
.65 .387 .509 r
.46222 .44978 m .45468 .45035 L .45657 .45475 L p F P
0 g
s
.652 .388 .508 r
.44894 .45529 m .45657 .45475 L .45468 .45035 L p F P
0 g
s
.656 .568 .744 r
.54015 .39575 m .53821 .39065 L .52754 .39522 L p F P
0 g
s
.661 .589 .764 r
.52518 .38954 m .52754 .39522 L .53821 .39065 L p F P
0 g
s
.668 .619 .791 r
.52468 .38844 m .52182 .3828 L .51117 .38701 L p F P
0 g
s
.668 .655 .828 r
.51117 .38701 m .52182 .3828 L .51896 .37788 L p F P
0 g
s
.668 .655 .828 r
.5083 .38186 m .51117 .38701 L p .51896 .37788 L F P
0 g
s
.715 .441 .509 r
.35201 .45465 m .35469 .45484 L .35366 .45023 L p F P
0 g
s
.715 .441 .509 r
.35366 .45023 m .3527 .45016 L .35201 .45465 L p F P
0 g
s
.764 .59 .662 r
.27155 .41747 m .27744 .4186 L .28043 .41278 L p F P
0 g
s
.764 .59 .662 r
.27084 .41435 m .27155 .41747 L p .28043 .41278 L F P
0 g
s
.764 .59 .662 r
.28043 .41278 m .27253 .41123 L .27084 .41435 L p F P
0 g
s
.723 .449 .51 r
.34466 .454 m .35201 .45465 L .3527 .45016 L p F P
0 g
s
.723 .449 .51 r
.3527 .45016 m .34372 .44937 L .34466 .454 L p F P
0 g
s
.749 .51 .57 r
.30702 .43512 m .30655 .43505 L .30649 .44014 L closepath p F P
0 g
s
.767 .568 .629 r
.27537 .42413 m .28336 .42564 L .28536 .42013 L p F P
0 g
s
.767 .568 .629 r
.28536 .42013 m .27744 .4186 L .27537 .42413 L p F P
0 g
s
.737 .48 .54 r
.32204 .4471 m .32461 .44739 L .3244 .44254 L p F P
0 g
s
.737 .48 .54 r
.3244 .44254 m .32246 .44232 L .32204 .4471 L p F P
0 g
s
.757 .517 .57 r
.30649 .44018 m .30649 .44014 L .30655 .43505 L p F P
0 g
s
.757 .517 .57 r
.29806 .43883 m .30649 .44018 L p .30655 .43505 L F P
0 g
s
.757 .517 .57 r
.30655 .43505 m .29859 .43377 L .29806 .43883 L p F P
0 g
s
.672 .702 .87 r
.4678 .38092 m .47839 .37714 L .48129 .38102 L p F P
0 g
s
.666 .726 .895 r
.47839 .37714 m .4678 .38092 L .46488 .37723 L p F P
0 g
s
.761 .615 .697 r
.26993 .41072 m .27253 .41123 L .27677 .40502 L p F P
0 g
s
.761 .615 .697 r
.268 .40471 m .26993 .41072 L p .27677 .40502 L F P
0 g
s
.761 .615 .697 r
.27677 .40502 m .26893 .40344 L .268 .40471 L p F P
0 g
s
.676 .679 .846 r
.4916 .38252 m .4948 .38129 L p .48129 .38102 L F P
0 g
s
.674 .668 .837 r
.4948 .38129 m .4916 .38252 L .49522 .38197 L closepath p F P
0 g
s
.634 .394 .537 r
.49155 .44184 m .48739 .44238 L .48722 .4472 L p F P
0 g
s
.745 .487 .54 r
.31558 .44624 m .32204 .4471 L .32246 .44232 L p F P
0 g
s
.745 .487 .54 r
.32246 .44232 m .31541 .44138 L .31558 .44624 L p F P
0 g
s
.643 .381 .508 r
.47223 .44886 m .46222 .44978 L .46177 .45435 L p F P
0 g
s
.65 .387 .509 r
.45657 .45475 m .46177 .45435 L .46222 .44978 L p F P
0 g
s
.637 .485 .66 r
.54164 .41041 m .53264 .4123 L .53332 .41573 L closepath p F P
0 g
s
.714 .699 .835 r
.31638 .38159 m .31557 .38203 L .31686 .38226 L closepath p F P
0 g
s
.759 .539 .6 r
.29004 .43241 m .29012 .43242 L .29141 .42712 L p F P
0 g
s
.759 .539 .6 r
.29141 .42712 m .28965 .42683 L .29004 .43241 L p F P
0 g
s
.676 .679 .846 r
.4948 .38129 m .49191 .37717 L .48129 .38102 L p F P
0 g
s
.667 .715 .884 r
.49191 .37717 m .48129 .38102 L .47839 .37714 L p F P
0 g
s
.639 .479 .65 r
.53332 .41573 m .52817 .41955 L .5338 .41845 L closepath p F P
0 g
s
.633 .455 .625 r
.5338 .41845 m .52817 .41955 L .52269 .42467 L p F P
0 g
s
.661 .589 .764 r
.53821 .39065 m .53668 .38708 L .52518 .38954 L p F P
0 g
s
.661 .604 .78 r
.52468 .38844 m .52518 .38954 L .53668 .38708 L p F P
0 g
s
.633 .455 .625 r
.52269 .42467 m .5229 .42643 L p .5338 .41845 L F P
0 g
s
.639 .457 .621 r
.52269 .42467 m .52075 .42681 L .5229 .42643 L closepath p F P
0 g
s
.707 .709 .849 r
.31557 .38203 m .31638 .38159 L .31327 .37767 L p F P
0 g
s
.707 .709 .849 r
.31327 .37767 m .30746 .38054 L .31557 .38203 L p F P
0 g
s
.715 .682 .817 r
.30284 .38294 m .30746 .38054 L .31557 .38203 L p F P
0 g
s
.672 .667 .837 r
.4948 .38129 m .49522 .38197 L .5071 .37995 L p F P
0 g
s
.674 .66 .828 r
.5083 .38186 m .5071 .37995 L .49522 .38197 L p F P
0 g
s
.696 .703 .852 r
.34339 .37996 m .3403 .37643 L .32989 .38065 L p F P
0 g
s
.674 .74 .9 r
.3403 .37643 m .32989 .38065 L .32679 .37694 L p F P
0 g
s
.704 .696 .84 r
.32989 .38065 m .32679 .37694 L .31638 .38159 L p F P
0 g
s
.724 .449 .51 r
.33686 .45331 m .34466 .454 L .34372 .44937 L p F P
0 g
s
.724 .449 .51 r
.34372 .44937 m .33757 .44882 L .33686 .45331 L p F P
0 g
s
.678 .733 .892 r
.34339 .37996 m .35381 .37606 L .35688 .37943 L p F P
0 g
s
.664 .747 .912 r
.35381 .37606 m .34339 .37996 L .3403 .37643 L p F P
0 g
s
.632 .392 .537 r
.49958 .44076 m .49155 .44184 L .49255 .44651 L p F P
0 g
s
.634 .394 .537 r
.48722 .4472 m .49255 .44651 L .49155 .44184 L p F P
0 g
s
.767 .546 .599 r
.28213 .43091 m .29004 .43241 L .28965 .42683 L p F P
0 g
s
.767 .546 .599 r
.28965 .42683 m .28336 .42564 L .28213 .43091 L p F P
0 g
s
.632 .432 .595 r
.5229 .42643 m .52075 .42681 L .51718 .43288 L p F P
0 g
s
.634 .436 .597 r
.51148 .43384 m .51718 .43288 L .52075 .42681 L p F P
0 g
s
.686 .732 .885 r
.32679 .37694 m .31638 .38159 L .31327 .37767 L p F P
0 g
s
.741 .658 .769 r
.2834 .38907 m .27591 .38768 L .27874 .39285 L closepath p F P
0 g
s
.753 .66 .758 r
.27482 .39669 m .27874 .39285 L .27591 .38768 L p F P
0 g
s
.671 .739 .901 r
.35688 .37943 m .36731 .37578 L .37038 .37903 L p F P
0 g
s
.655 .754 .922 r
.36731 .37578 m .35688 .37943 L .35381 .37606 L p F P
0 g
s
.661 .604 .78 r
.53668 .38708 m .53536 .38424 L .52468 .38844 L p F P
0 g
s
.663 .632 .808 r
.53536 .38424 m .52468 .38844 L .52182 .3828 L p F P
0 g
s
.672 .384 .477 r
.41233 .45665 m .40908 .45669 L .40827 .46098 L p F P
0 g
s
.68 .392 .479 r
.40174 .46096 m .40827 .46098 L .40908 .45669 L p F P
0 g
s
.68 .392 .479 r
.40908 .45669 m .39961 .45666 L .40174 .46096 L p F P
0 g
s
.681 .393 .478 r
.39443 .46091 m .40174 .46096 L .39961 .45666 L p F P
0 g
s
.681 .393 .478 r
.39961 .45666 m .39528 .45663 L .39443 .46091 L p F P
0 g
s
.67 .384 .478 r
.42262 .45648 m .41233 .45665 L .41464 .4609 L p F P
0 g
s
.672 .384 .477 r
.40827 .46098 m .41464 .4609 L .41233 .45665 L p F P
0 g
s
.689 .4 .479 r
.38956 .4608 m .39443 .46091 L .39528 .45663 L p F P
0 g
s
.689 .4 .479 r
.39528 .45663 m .38759 .45645 L .38956 .4608 L p F P
0 g
s
.753 .66 .758 r
.26713 .39506 m .27482 .39669 L p .27591 .38768 L F P
0 g
s
.756 .64 .733 r
.26744 .40314 m .26893 .40344 L .27482 .39669 L p F P
0 g
s
.756 .64 .733 r
.26503 .3973 m .26744 .40314 L p .27482 .39669 L F P
0 g
s
.756 .64 .733 r
.27482 .39669 m .26713 .39506 L .26503 .3973 L p F P
0 g
s
.634 .479 .656 r
.53332 .41573 m .5338 .41845 L p .54416 .40987 L F P
0 g
s
.634 .479 .656 r
.54416 .40987 m .54164 .41041 L .53332 .41573 L p F P
0 g
s
.665 .744 .909 r
.37038 .37903 m .38082 .37554 L .38387 .37869 L p F P
0 g
s
.649 .759 .93 r
.38082 .37554 m .37038 .37903 L .36731 .37578 L p F P
0 g
s
.668 .7 .871 r
.50543 .37739 m .4948 .38129 L .49191 .37717 L p F P
0 g
s
.672 .667 .837 r
.5071 .37995 m .50543 .37739 L .4948 .38129 L p F P
0 g
s
.737 .667 .781 r
.2834 .38907 m .28928 .38479 L p .27568 .38729 L F P
0 g
s
.737 .667 .781 r
.27568 .38729 m .27591 .38768 L .2834 .38907 L p F P
0 g
s
.67 .384 .478 r
.41464 .4609 m .42183 .46078 L .42262 .45648 L p F P
0 g
s
.663 .377 .476 r
.42591 .45637 m .42262 .45648 L .42183 .46078 L p F P
0 g
s
.709 .695 .835 r
.30746 .38054 m .30039 .37958 L .30284 .38294 L closepath p F P
0 g
s
.69 .401 .478 r
.3803 .46055 m .38956 .4608 L .38759 .45645 L p F P
0 g
s
.69 .401 .478 r
.38759 .45645 m .38118 .45628 L .3803 .46055 L p F P
0 g
s
.633 .455 .625 r
.5229 .42643 m .53455 .42417 L .5338 .41845 L p F P
0 g
s
.624 .427 .595 r
.53499 .42956 m .53455 .42417 L .5229 .42643 L p F P
0 g
s
.624 .427 .595 r
.5229 .42643 m .52332 .43181 L .53499 .42956 L p F P
0 g
s
.632 .432 .595 r
.51718 .43288 m .52332 .43181 L .5229 .42643 L p F P
0 g
s
.661 .376 .478 r
.4359 .45601 m .42591 .45637 L .42842 .46057 L p F P
0 g
s
.663 .377 .476 r
.42183 .46078 m .42842 .46057 L .42591 .45637 L p F P
0 g
s
.745 .486 .539 r
.30666 .44504 m .31558 .44624 L .31541 .44138 L p F P
0 g
s
.745 .486 .539 r
.30649 .44022 m .30666 .44504 L p .31541 .44138 L F P
0 g
s
.745 .486 .539 r
.31541 .44138 m .30649 .44019 L .30649 .44022 L p F P
0 g
s
.641 .38 .508 r
.47483 .44861 m .47223 .44886 L .47431 .4532 L p F P
0 g
s
.643 .381 .508 r
.46177 .45435 m .47431 .4532 L .47223 .44886 L p F P
0 g
s
.661 .747 .914 r
.38387 .37869 m .39433 .37531 L .39736 .3784 L p F P
0 g
s
.645 .763 .935 r
.39433 .37531 m .38387 .37869 L .38082 .37554 L p F P
0 g
s
.625 .408 .567 r
.51718 .43288 m .51148 .43384 L .51161 .43894 L p F P
0 g
s
.732 .456 .511 r
.33486 .45309 m .33686 .45331 L .33757 .44882 L p F P
0 g
s
.732 .456 .511 r
.33757 .44882 m .334 .44843 L .33486 .45309 L p F P
0 g
s
.698 .408 .48 r
.37796 .46045 m .3803 .46055 L .38118 .45628 L p F P
0 g
s
.698 .408 .48 r
.38118 .45628 m .37614 .45606 L .37796 .46045 L p F P
0 g
s
.756 .517 .57 r
.28996 .43754 m .29806 .43883 L .29859 .43377 L p F P
0 g
s
.756 .517 .57 r
.29003 .43326 m .28996 .43754 L p .29859 .43377 L F P
0 g
s
.756 .517 .57 r
.29859 .43377 m .29012 .43242 L .29003 .43326 L p F P
0 g
s
.765 .591 .662 r
.27253 .41123 m .26993 .41072 L .27084 .41435 L closepath p F P
0 g
s
.659 .748 .916 r
.39736 .3784 m .40785 .37507 L .41086 .37813 L p F P
0 g
s
.642 .766 .938 r
.40785 .37507 m .39736 .3784 L .39433 .37531 L p F P
0 g
s
.632 .373 .507 r
.48681 .45178 m .48722 .4472 L .47483 .44861 L p F P
0 g
s
.632 .373 .507 r
.47483 .44861 m .4744 .45319 L .48681 .45178 L p F P
0 g
s
.641 .38 .508 r
.47431 .4532 m .4744 .45319 L .47483 .44861 L p F P
0 g
s
.699 .408 .478 r
.3669 .45994 m .37796 .46045 L .37614 .45606 L p F P
0 g
s
.699 .408 .478 r
.36621 .45826 m .3669 .45994 L p .37614 .45606 L F P
0 g
s
.699 .408 .478 r
.37614 .45606 m .36678 .45564 L .36621 .45826 L p F P
0 g
s
.766 .567 .628 r
.27249 .42358 m .27537 .42413 L .27744 .4186 L p F P
0 g
s
.766 .567 .628 r
.27744 .4186 m .27155 .41747 L .27249 .42358 L p F P
0 g
s
.653 .369 .476 r
.44056 .45577 m .4359 .45601 L .43514 .46033 L p F P
0 g
s
.661 .376 .478 r
.42842 .46057 m .43514 .46033 L .4359 .45601 L p F P
0 g
s
.733 .456 .509 r
.32548 .45205 m .33486 .45309 L .334 .44843 L p F P
0 g
s
.733 .456 .509 r
.334 .44843 m .32461 .44739 L .32548 .45205 L p F P
0 g
s
.634 .479 .656 r
.5338 .41845 m .54529 .416 L .54416 .40987 L p F P
0 g
s
.626 .45 .625 r
.54607 .42173 m .54529 .416 L .5338 .41845 L p F P
0 g
s
.626 .45 .625 r
.5338 .41845 m .53455 .42417 L .54607 .42173 L p F P
0 g
s
.719 .685 .817 r
.29877 .37923 m .28928 .38479 L .28617 .38021 L p F P
0 g
s
.737 .667 .781 r
.28928 .38479 m .28617 .38021 L .27568 .38729 L p F P
0 g
s
.723 .697 .825 r
.30039 .37958 m .29877 .37923 L .28928 .38479 L p F P
0 g
s
.761 .616 .698 r
.26893 .40344 m .26744 .40314 L .268 .40471 L closepath p F P
0 g
s
.668 .655 .828 r
.51896 .37788 m .51896 .37788 L .5083 .38186 L p F P
0 g
s
.671 .669 .839 r
.51896 .37788 m .5071 .37995 L .5083 .38186 L closepath p F P
0 g
s
.658 .748 .916 r
.41086 .37813 m .42137 .37482 L .42436 .37787 L p F P
0 g
s
.643 .767 .939 r
.42137 .37482 m .41086 .37813 L .40785 .37507 L p F P
0 g
s
.644 .533 .714 r
.55383 .40053 m .55178 .39387 L .54108 .39852 L p F P
0 g
s
.644 .533 .714 r
.54108 .39852 m .54248 .40317 L .55383 .40053 L p F P
0 g
s
.649 .551 .731 r
.54015 .39575 m .54108 .39852 L .55178 .39387 L p F P
0 g
s
.651 .368 .477 r
.44894 .45529 m .44056 .45577 L .4433 .4599 L p F P
0 g
s
.653 .369 .476 r
.43514 .46033 m .4433 .4599 L .44056 .45577 L p F P
0 g
s
.624 .386 .536 r
.51148 .44376 m .51161 .43894 L .49958 .44076 L p F P
0 g
s
.624 .386 .536 r
.49958 .44076 m .49944 .44558 L .51148 .44376 L p F P
0 g
s
.632 .392 .537 r
.49255 .44651 m .49944 .44558 L .49958 .44076 L p F P
0 g
s
.652 .571 .75 r
.53821 .39065 m .54015 .39575 L .55152 .39312 L p F P
0 g
s
.649 .551 .731 r
.55178 .39387 m .55152 .39312 L .54015 .39575 L p F P
0 g
s
.77 .612 .682 r
.268 .40471 m .26494 .40958 L .26993 .41072 L closepath p F P
0 g
s
.774 .595 .657 r
.26958 .41704 m .27084 .41435 L .26993 .41072 L p F P
0 g
s
.774 .595 .657 r
.26208 .41536 m .26958 .41704 L p .26993 .41072 L F P
0 g
s
.774 .595 .657 r
.26993 .41072 m .26494 .40958 L .26208 .41536 L p F P
0 g
s
.772 .618 .689 r
.26494 .40958 m .268 .40471 L .26744 .40314 L p F P
0 g
s
.707 .416 .48 r
.36678 .45564 m .36621 .45826 L .36515 .45554 L closepath p F P
0 g
s
.639 .51 .69 r
.55467 .40376 m .55383 .40053 L .54248 .40317 L p F P
0 g
s
.639 .51 .69 r
.54248 .40317 m .54398 .40909 L .55467 .40376 L p F P
0 g
s
.766 .546 .6 r
.2741 .42942 m .28213 .43091 L .28336 .42564 L p F P
0 g
s
.766 .546 .6 r
.28336 .42564 m .27537 .42413 L .2741 .42942 L p F P
0 g
s
.659 .746 .914 r
.42436 .37787 m .43489 .37454 L .43786 .37763 L p F P
0 g
s
.645 .766 .937 r
.43489 .37454 m .42436 .37787 L .42137 .37482 L p F P
0 g
s
.767 .633 .713 r
.26503 .3973 m .26152 .40173 L .26744 .40314 L closepath p F P
0 g
s
.772 .618 .689 r
.25749 .40788 m .26494 .40958 L p .26744 .40314 L F P
0 g
s
.772 .618 .689 r
.26744 .40314 m .26152 .40173 L .25749 .40788 L p F P
0 g
s
.708 .416 .48 r
.35641 .45925 m .35469 .45484 L .36515 .45554 L p F P
0 g
s
.708 .416 .48 r
.36585 .45989 m .35641 .45925 L p .36515 .45554 L F P
0 g
s
.708 .416 .48 r
.36515 .45554 m .36621 .45826 L .36585 .45989 L p F P
0 g
s
.706 .7 .842 r
.30746 .38054 m .31327 .37767 L p .29973 .3787 L F P
0 g
s
.706 .7 .842 r
.29973 .3787 m .30039 .37958 L .30746 .38054 L p F P
0 g
s
.639 .5 .676 r
.54398 .40909 m .54164 .41041 L .54416 .40987 L closepath p F P
0 g
s
.625 .408 .567 r
.51161 .43894 m .51619 .43816 L .51718 .43288 L p F P
0 g
s
.623 .406 .566 r
.52332 .43181 m .51718 .43288 L .51619 .43816 L p F P
0 g
s
.772 .589 .651 r
.27084 .41435 m .26958 .41704 L .27155 .41747 L closepath p F P
0 g
s
.661 .742 .91 r
.43786 .37763 m .44842 .37424 L .45137 .3774 L p F P
0 g
s
.648 .764 .933 r
.44842 .37424 m .43786 .37763 L .43489 .37454 L p F P
0 g
s
.643 .361 .476 r
.45657 .45475 m .44894 .45529 L .44822 .45963 L p F P
0 g
s
.651 .368 .477 r
.4433 .4599 m .44822 .45963 L .44894 .45529 L p F P
0 g
s
.652 .571 .75 r
.55152 .39312 m .54892 .38641 L .53821 .39065 L p F P
0 g
s
.657 .593 .771 r
.53668 .38708 m .53821 .39065 L .54892 .38641 L p F P
0 g
s
.754 .514 .568 r
.30649 .44014 m .30649 .44018 L .30649 .44019 L closepath p F P
0 g
s
.753 .493 .54 r
.30649 .44019 m .30649 .44022 L .30649 .44018 L closepath p F P
0 g
s
.753 .494 .54 r
.29818 .4437 m .29806 .43883 L .30649 .44018 L p F P
0 g
s
.753 .494 .54 r
.30604 .44495 m .29818 .4437 L p .30649 .44018 L F P
0 g
s
.753 .494 .54 r
.30649 .44018 m .30649 .44022 L .30604 .44495 L p F P
0 g
s
.747 .488 .539 r
.30649 .44022 m .30666 .44504 L .30604 .44495 L closepath p F P
0 g
s
.747 .67 .775 r
.27568 .38729 m .27536 .38755 L .27591 .38768 L closepath p F P
0 g
s
.753 .66 .758 r
.27591 .38768 m .27536 .38755 L .26713 .39506 L p F P
0 g
s
.663 .735 .903 r
.45137 .3774 m .46195 .37396 L .46488 .37723 L p F P
0 g
s
.652 .758 .927 r
.46195 .37396 m .45137 .3774 L .44842 .37424 L p F P
0 g
s
.751 .668 .77 r
.26369 .39434 m .26713 .39506 L .27536 .38755 L p F P
0 g
s
.755 .639 .732 r
.26713 .39506 m .26369 .39434 L .26503 .3973 L closepath p F P
0 g
s
.744 .679 .788 r
.27536 .38755 m .27568 .38729 L .27257 .38235 L p F P
0 g
s
.744 .679 .788 r
.27257 .38235 m .26807 .38578 L .27536 .38755 L p F P
0 g
s
.751 .668 .77 r
.26199 .39098 m .26369 .39434 L p .27536 .38755 L F P
0 g
s
.751 .668 .77 r
.27536 .38755 m .26807 .38578 L .26199 .39098 L p F P
0 g
s
.728 .699 .823 r
.27568 .38729 m .28617 .38021 L .2833 .37631 L p F P
0 g
s
.728 .699 .823 r
.27257 .38235 m .27568 .38729 L p .2833 .37631 L F P
0 g
s
.663 .632 .808 r
.52182 .3828 m .53251 .3788 L .53536 .38424 L p F P
0 g
s
.668 .652 .825 r
.51896 .37788 m .52182 .3828 L .53251 .3788 L p F P
0 g
s
.633 .496 .677 r
.55548 .40721 m .55467 .40376 L .54398 .40909 L p F P
0 g
s
.633 .496 .677 r
.54398 .40909 m .54416 .40987 L .55548 .40721 L p F P
0 g
s
.774 .573 .626 r
.26765 .42253 m .27249 .42358 L .27155 .41747 L p F P
0 g
s
.774 .573 .626 r
.27155 .41747 m .26958 .41704 L .26765 .42253 L p F P
0 g
s
.671 .676 .847 r
.50543 .37739 m .5071 .37995 L .51896 .37788 L p F P
0 g
s
.758 .519 .57 r
.29012 .43242 m .29004 .43241 L .29003 .43326 L closepath p F P
0 g
s
.767 .526 .57 r
.2896 .43748 m .29003 .43326 L .29004 .43241 L p F P
0 g
s
.767 .526 .57 r
.2816 .43598 m .2896 .43748 L p .29004 .43241 L F P
0 g
s
.767 .526 .57 r
.29004 .43241 m .28213 .43091 L .2816 .43598 L p F P
0 g
s
.734 .457 .509 r
.32128 .45157 m .32548 .45205 L .32461 .44739 L p F P
0 g
s
.734 .457 .509 r
.32461 .44739 m .32204 .4471 L .32128 .45157 L p F P
0 g
s
.767 .641 .722 r
.26152 .40173 m .26503 .3973 L .26369 .39434 L p F P
0 g
s
.627 .474 .654 r
.55665 .41335 m .55548 .40721 L .54416 .40987 L p F P
0 g
s
.627 .474 .654 r
.54416 .40987 m .54529 .416 L .55665 .41335 L p F P
0 g
s
.71 .416 .477 r
.35103 .45887 m .35641 .45925 L .35469 .45484 L p F P
0 g
s
.71 .416 .477 r
.35469 .45484 m .35201 .45465 L .35103 .45887 L p F P
0 g
s
.666 .726 .895 r
.46488 .37723 m .47548 .37371 L .47839 .37714 L p F P
0 g
s
.657 .75 .919 r
.47548 .37371 m .46488 .37723 L .46195 .37396 L p F P
0 g
s
.642 .361 .477 r
.46177 .45435 m .45657 .45475 L .45956 .45881 L p F P
0 g
s
.643 .361 .476 r
.44822 .45963 m .45956 .45881 L .45657 .45475 L p F P
0 g
s
.624 .365 .505 r
.49255 .44651 m .48722 .4472 L .48681 .45178 L p F P
0 g
s
.718 .425 .479 r
.34623 .45846 m .35103 .45887 L .35201 .45465 L p F P
0 g
s
.718 .425 .479 r
.35201 .45465 m .34466 .454 L .34623 .45846 L p F P
0 g
s
.742 .465 .51 r
.31637 .45091 m .32128 .45157 L .32204 .4471 L p F P
0 g
s
.742 .465 .51 r
.32204 .4471 m .31558 .44624 L .31637 .45091 L p F P
0 g
s
.774 .597 .66 r
.25452 .4137 m .26208 .41536 L .26494 .40958 L p F P
0 g
s
.774 .597 .66 r
.26494 .40958 m .25749 .40788 L .25452 .4137 L p F P
0 g
s
.658 .607 .786 r
.53536 .38424 m .53668 .38708 L .54805 .38444 L p F P
0 g
s
.657 .593 .771 r
.54892 .38641 m .54805 .38444 L .53668 .38708 L p F P
0 g
s
.717 .703 .836 r
.29973 .3787 m .29877 .37923 L .30039 .37958 L closepath p F P
0 g
s
.776 .576 .629 r
.26008 .42087 m .26765 .42253 L .26958 .41704 L p F P
0 g
s
.776 .576 .629 r
.26958 .41704 m .26208 .41536 L .26008 .42087 L p F P
0 g
s
.764 .523 .569 r
.29003 .43326 m .2896 .43748 L .28996 .43754 L closepath p F P
0 g
s
.667 .715 .884 r
.47839 .37714 m .48902 .37353 L .49191 .37717 L p F P
0 g
s
.661 .739 .908 r
.48902 .37353 m .47839 .37714 L .47548 .37371 L p F P
0 g
s
.634 .353 .476 r
.47431 .4532 m .46177 .45435 L .46109 .4587 L p F P
0 g
s
.642 .361 .477 r
.45956 .45881 m .46109 .4587 L .46177 .45435 L p F P
0 g
s
.761 .654 .743 r
.26199 .39098 m .2597 .39335 L .26369 .39434 L closepath p F P
0 g
s
.767 .641 .722 r
.25415 .39999 m .26152 .40173 L p .26369 .39434 L F P
0 g
s
.767 .641 .722 r
.26369 .39434 m .2597 .39335 L .25415 .39999 L p F P
0 g
s
.616 .4 .566 r
.53515 .43466 m .53499 .42956 L .52332 .43181 L p F P
0 g
s
.616 .4 .566 r
.52332 .43181 m .52346 .4369 L .53515 .43466 L p F P
0 g
s
.623 .406 .566 r
.51619 .43816 m .52346 .4369 L .52332 .43181 L p F P
0 g
s
.71 .711 .85 r
.29877 .37923 m .29973 .3787 L .2966 .37481 L p F P
0 g
s
.71 .711 .85 r
.2966 .37481 m .29112 .37757 L .29877 .37923 L p F P
0 g
s
.719 .685 .817 r
.28617 .38021 m .29112 .37757 L .29877 .37923 L p F P
0 g
s
.77 .621 .694 r
.25185 .40661 m .25749 .40788 L .26152 .40173 L p F P
0 g
s
.77 .621 .694 r
.25113 .40437 m .25185 .40661 L p .26152 .40173 L F P
0 g
s
.77 .621 .694 r
.26152 .40173 m .25415 .39999 L .25113 .40437 L p F P
0 g
s
.686 .732 .885 r
.31327 .37767 m .32367 .3735 L .32679 .37694 L p F P
0 g
s
.672 .744 .904 r
.32367 .3735 m .31327 .37767 L .31014 .37402 L p F P
0 g
s
.706 .7 .842 r
.31327 .37767 m .31014 .37402 L .29973 .3787 L p F P
0 g
s
.617 .422 .596 r
.54652 .42713 m .54607 .42173 L .53455 .42417 L p F P
0 g
s
.617 .422 .596 r
.53455 .42417 m .53499 .42956 L .54652 .42713 L p F P
0 g
s
.674 .74 .9 r
.32679 .37694 m .33719 .37317 L .3403 .37643 L p F P
0 g
s
.659 .752 .919 r
.33719 .37317 m .32679 .37694 L .32367 .3735 L p F P
0 g
s
.767 .547 .6 r
.27289 .42918 m .2741 .42942 L .27537 .42413 L p F P
0 g
s
.767 .547 .6 r
.27537 .42413 m .27249 .42358 L .27289 .42918 L p F P
0 g
s
.668 .7 .871 r
.49191 .37717 m .50256 .37349 L .50543 .37739 L p F P
0 g
s
.664 .726 .895 r
.50256 .37349 m .49191 .37717 L .48902 .37353 L p F P
0 g
s
.664 .747 .912 r
.3403 .37643 m .35071 .37296 L .35381 .37606 L p F P
0 g
s
.647 .76 .932 r
.35071 .37296 m .3403 .37643 L .33719 .37317 L p F P
0 g
s
.687 .735 .887 r
.31014 .37402 m .29973 .3787 L .2966 .37481 L p F P
0 g
s
.623 .365 .506 r
.49944 .44558 m .49255 .44651 L .49519 .45069 L p F P
0 g
s
.624 .365 .505 r
.48681 .45178 m .49519 .45069 L .49255 .44651 L p F P
0 g
s
.719 .424 .478 r
.33634 .45757 m .34623 .45846 L .34466 .454 L p F P
0 g
s
.719 .424 .478 r
.33604 .45671 m .33634 .45757 L p .34466 .454 L F P
0 g
s
.719 .424 .478 r
.34466 .454 m .33686 .45331 L .33604 .45671 L p F P
0 g
s
.616 .379 .535 r
.51619 .43816 m .51161 .43894 L .51148 .44376 L p F P
0 g
s
.658 .607 .786 r
.54805 .38444 m .54607 .38025 L .53536 .38424 L p F P
0 g
s
.661 .636 .815 r
.54607 .38025 m .53536 .38424 L .53251 .3788 L p F P
0 g
s
.636 .767 .942 r
.36423 .37281 m .35381 .37606 L .35071 .37296 L p F P
0 g
s
.655 .754 .922 r
.35381 .37606 m .36423 .37281 L .36731 .37578 L p F P
0 g
s
.755 .495 .54 r
.28971 .44235 m .29818 .4437 L .29806 .43883 L p F P
0 g
s
.755 .495 .54 r
.28967 .44046 m .28971 .44235 L p .29806 .43883 L F P
0 g
s
.755 .495 .54 r
.29806 .43883 m .28996 .43754 L .28967 .44046 L p F P
0 g
s
.742 .464 .509 r
.30746 .44971 m .31637 .45091 L .31558 .44624 L p F P
0 g
s
.742 .464 .509 r
.31558 .44624 m .30666 .44504 L .30746 .44971 L p F P
0 g
s
.712 .697 .834 r
.29112 .37757 m .2833 .37631 L .28617 .38021 L closepath p F P
0 g
s
.701 .41 .478 r
.36621 .45826 m .3669 .45994 L .36585 .45989 L closepath p F P
0 g
s
.649 .759 .93 r
.36731 .37578 m .37776 .37267 L .38082 .37554 L p F P
0 g
s
.629 .773 .95 r
.37776 .37267 m .36731 .37578 L .36423 .37281 L p F P
0 g
s
.776 .554 .598 r
.26645 .42779 m .27289 .42918 L .27249 .42358 L p F P
0 g
s
.776 .554 .598 r
.27249 .42358 m .26765 .42253 L .26645 .42779 L p F P
0 g
s
.671 .676 .847 r
.51896 .37788 m .5161 .37365 L .50543 .37739 L p F P
0 g
s
.671 .676 .847 r
.51896 .37788 m .51896 .37788 L p .50543 .37739 L F P
0 g
s
.666 .71 .881 r
.5161 .37365 m .50543 .37739 L .50256 .37349 L p F P
0 g
s
.746 .66 .764 r
.26807 .38578 m .26199 .39098 L .25891 .38536 L p F P
0 g
s
.758 .659 .753 r
.2597 .39335 m .26199 .39098 L .25891 .38536 L p F P
0 g
s
.619 .446 .626 r
.55744 .4191 m .55665 .41335 L .54529 .416 L p F P
0 g
s
.619 .446 .626 r
.54529 .416 m .54607 .42173 L .55744 .4191 L p F P
0 g
s
.664 .358 .444 r
.41464 .4609 m .40827 .46098 L .40721 .46505 L p F P
0 g
s
.672 .366 .447 r
.40463 .46505 m .40721 .46505 L .40827 .46098 L p F P
0 g
s
.672 .366 .447 r
.40827 .46098 m .40174 .46096 L .40463 .46505 L p F P
0 g
s
.674 .366 .445 r
.39333 .46497 m .40463 .46505 L .40174 .46096 L p F P
0 g
s
.674 .366 .445 r
.40174 .46096 m .39443 .46091 L .39333 .46497 L p F P
0 g
s
.766 .525 .57 r
.27356 .43448 m .2816 .43598 L .28213 .43091 L p F P
0 g
s
.766 .525 .57 r
.28213 .43091 m .2741 .42942 L .27356 .43448 L p F P
0 g
s
.682 .375 .447 r
.39224 .46494 m .39333 .46497 L .39443 .46091 L p F P
0 g
s
.682 .375 .447 r
.39443 .46091 m .38956 .4608 L .39224 .46494 L p F P
0 g
s
.662 .357 .446 r
.42183 .46078 m .41464 .4609 L .41776 .46492 L p F P
0 g
s
.664 .358 .444 r
.40721 .46505 m .41776 .46492 L .41464 .4609 L p F P
0 g
s
.758 .659 .753 r
.25891 .38536 m .2525 .39155 L .2597 .39335 L p F P
0 g
s
.765 .645 .729 r
.24917 .39884 m .25415 .39999 L .2597 .39335 L p F P
0 g
s
.765 .645 .729 r
.24818 .39644 m .24917 .39884 L p .2597 .39335 L F P
0 g
s
.765 .645 .729 r
.2597 .39335 m .2525 .39155 L .24818 .39644 L p F P
0 g
s
.645 .763 .935 r
.38082 .37554 m .39129 .37252 L .39433 .37531 L p F P
0 g
s
.624 .778 .955 r
.39129 .37252 m .38082 .37554 L .37776 .37267 L p F P
0 g
s
.746 .66 .764 r
.25891 .38536 m .26051 .3841 L .26807 .38578 L p F P
0 g
s
.737 .681 .796 r
.26807 .38578 m .27257 .38235 L .26944 .37776 L p F P
0 g
s
.737 .681 .796 r
.26944 .37776 m .26051 .3841 L .26807 .38578 L p F P
0 g
s
.727 .433 .48 r
.33686 .45331 m .33604 .45671 L .33486 .45309 L closepath p F P
0 g
s
.683 .373 .444 r
.38053 .46462 m .39224 .46494 L .38956 .4608 L p F P
0 g
s
.683 .373 .444 r
.37957 .46312 m .38053 .46462 L p .38956 .4608 L F P
0 g
s
.683 .373 .444 r
.38956 .4608 m .3803 .46055 L .37957 .46312 L p F P
0 g
s
.662 .357 .446 r
.41776 .46492 m .42081 .46487 L .42183 .46078 L p F P
0 g
s
.654 .349 .443 r
.42842 .46057 m .42183 .46078 L .42081 .46487 L p F P
0 g
s
.631 .35 .474 r
.4744 .45319 m .47439 .45329 L .47431 .4532 L closepath p F P
0 g
s
.634 .353 .476 r
.47373 .45752 m .47439 .45329 L .47431 .4532 L p F P
0 g
s
.634 .353 .476 r
.46109 .4587 m .47373 .45752 L p .47431 .4532 L F P
0 g
s
.624 .344 .472 r
.48617 .45613 m .48681 .45178 L .4744 .45319 L p F P
0 g
s
.624 .344 .472 r
.47801 .45706 m .48617 .45613 L p .4744 .45319 L F P
0 g
s
.624 .344 .472 r
.4744 .45319 m .47439 .45329 L .47801 .45706 L p F P
0 g
s
.64 .542 .727 r
.55178 .39387 m .55383 .40053 L p .56272 .39027 L F P
0 g
s
.64 .542 .727 r
.56272 .39027 m .55748 .39162 L .55178 .39387 L p F P
0 g
s
.644 .552 .736 r
.55748 .39162 m .55152 .39312 L .55178 .39387 L closepath p F P
0 g
s
.614 .378 .536 r
.52346 .4369 m .51619 .43816 L .51755 .44274 L p F P
0 g
s
.616 .379 .535 r
.51148 .44376 m .51755 .44274 L .51619 .43816 L p F P
0 g
s
.648 .572 .755 r
.54892 .38641 m .55152 .39312 L .55748 .39162 L p F P
0 g
s
.624 .343 .472 r
.47439 .45329 m .47801 .45706 L .47373 .45752 L closepath p F P
0 g
s
.728 .433 .48 r
.32697 .45652 m .32548 .45205 L .33486 .45309 L p F P
0 g
s
.728 .433 .48 r
.33585 .45752 m .32697 .45652 L p .33486 .45309 L F P
0 g
s
.728 .433 .48 r
.33486 .45309 m .33604 .45671 L .33585 .45752 L p F P
0 g
s
.614 .357 .505 r
.51111 .44835 m .51148 .44376 L .49944 .44558 L p F P
0 g
s
.614 .357 .505 r
.49944 .44558 m .49905 .45017 L .51111 .44835 L p F P
0 g
s
.623 .365 .506 r
.49519 .45069 m .49905 .45017 L .49944 .44558 L p F P
0 g
s
.642 .766 .938 r
.39433 .37531 m .40482 .37233 L .40785 .37507 L p F P
0 g
s
.622 .782 .958 r
.40482 .37233 m .39433 .37531 L .39129 .37252 L p F P
0 g
s
.652 .349 .445 r
.43514 .46033 m .42842 .46057 L .4318 .46452 L p F P
0 g
s
.654 .349 .443 r
.42081 .46487 m .4318 .46452 L .42842 .46057 L p F P
0 g
s
.64 .542 .727 r
.55383 .40053 m .56504 .39769 L .56272 .39027 L p F P
0 g
s
.633 .51 .695 r
.5654 .39906 m .56504 .39769 L .55383 .40053 L p F P
0 g
s
.633 .51 .695 r
.55383 .40053 m .55467 .40376 L .5654 .39906 L p F P
0 g
s
.691 .382 .447 r
.3803 .46055 m .37957 .46312 L .37796 .46045 L closepath p F P
0 g
s
.692 .382 .446 r
.36943 .46412 m .3669 .45994 L .37796 .46045 L p F P
0 g
s
.692 .382 .446 r
.37915 .46458 m .36943 .46412 L p .37796 .46045 L F P
0 g
s
.692 .382 .446 r
.37796 .46045 m .37957 .46312 L .37915 .46458 L p F P
0 g
s
.728 .699 .823 r
.2833 .37631 m .2827 .37617 L .27257 .38235 L p F P
0 g
s
.723 .686 .814 r
.2827 .37617 m .27257 .38235 L .26944 .37776 L p F P
0 g
s
.668 .661 .834 r
.51896 .37788 m .51896 .37788 L .51896 .37788 L closepath p F P
0 g
s
.666 .66 .835 r
.51896 .37788 m .51896 .37788 L .53045 .37536 L p F P
0 g
s
.668 .652 .825 r
.53251 .3788 m .53045 .37536 L .51896 .37788 L p F P
0 g
s
.666 .66 .835 r
.53045 .37536 m .52966 .37409 L .51896 .37788 L p F P
0 g
s
.665 .691 .864 r
.52966 .37409 m .51896 .37788 L .5161 .37365 L p F P
0 g
s
.773 .596 .659 r
.25359 .41349 m .25452 .4137 L .25749 .40788 L p F P
0 g
s
.773 .596 .659 r
.25749 .40788 m .25185 .40661 L .25359 .41349 L p F P
0 g
s
.774 .577 .633 r
.25459 .41967 m .26008 .42087 L .26208 .41536 L p F P
0 g
s
.774 .577 .633 r
.2539 .41529 m .25459 .41967 L p .26208 .41536 L F P
0 g
s
.774 .577 .633 r
.26208 .41536 m .25452 .4137 L .2539 .41529 L p F P
0 g
s
.644 .341 .443 r
.4433 .4599 m .43514 .46033 L .43417 .46443 L p F P
0 g
s
.652 .349 .445 r
.4318 .46452 m .43417 .46443 L .43514 .46033 L p F P
0 g
s
.643 .767 .939 r
.40785 .37507 m .41836 .37209 L .42137 .37482 L p F P
0 g
s
.622 .784 .959 r
.41836 .37209 m .40785 .37507 L .40482 .37233 L p F P
0 g
s
.628 .495 .681 r
.56668 .40435 m .5654 .39906 L .55467 .40376 L p F P
0 g
s
.628 .495 .681 r
.55467 .40376 m .55548 .40721 L .56668 .40435 L p F P
0 g
s
.709 .702 .841 r
.29112 .37757 m .2966 .37481 L p .28304 .37598 L F P
0 g
s
.709 .702 .841 r
.28304 .37598 m .2833 .37631 L .29112 .37757 L p F P
0 g
s
.645 .766 .937 r
.42137 .37482 m .43191 .37179 L .43489 .37454 L p F P
0 g
s
.625 .785 .958 r
.43191 .37179 m .42137 .37482 L .41836 .37209 L p F P
0 g
s
.763 .502 .54 r
.28996 .43754 m .28967 .44046 L .2896 .43748 L closepath p F P
0 g
s
.776 .555 .6 r
.25884 .42615 m .26645 .42779 L .26765 .42253 L p F P
0 g
s
.776 .555 .6 r
.26765 .42253 m .26008 .42087 L .25884 .42615 L p F P
0 g
s
.744 .465 .508 r
.30522 .44939 m .30746 .44971 L .30666 .44504 L p F P
0 g
s
.744 .465 .508 r
.30666 .44504 m .30604 .44495 L .30522 .44939 L p F P
0 g
s
.769 .62 .694 r
.25415 .39999 m .24917 .39884 L .25113 .40437 L closepath p F P
0 g
s
.763 .503 .54 r
.28169 .44085 m .2816 .43598 L .2896 .43748 L p F P
0 g
s
.763 .503 .54 r
.28948 .44231 m .28169 .44085 L p .2896 .43748 L F P
0 g
s
.763 .503 .54 r
.2896 .43748 m .28967 .44046 L .28948 .44231 L p F P
0 g
s
.753 .474 .51 r
.29891 .44839 m .30522 .44939 L .30604 .44495 L p F P
0 g
s
.753 .474 .51 r
.30604 .44495 m .29818 .4437 L .29891 .44839 L p F P
0 g
s
.694 .381 .442 r
.36464 .46388 m .36943 .46412 L .3669 .45994 L p F P
0 g
s
.694 .381 .442 r
.3669 .45994 m .36585 .45989 L .36464 .46388 L p F P
0 g
s
.648 .572 .755 r
.56251 .38968 m .55965 .38244 L .54892 .38641 L p F P
0 g
s
.648 .572 .755 r
.55748 .39162 m .56251 .38968 L p .54892 .38641 L F P
0 g
s
.653 .595 .777 r
.54805 .38444 m .54892 .38641 L .55965 .38244 L p F P
0 g
s
.642 .341 .445 r
.44822 .45963 m .4433 .4599 L .44698 .46377 L p F P
0 g
s
.644 .341 .443 r
.43417 .46443 m .44698 .46377 L .4433 .4599 L p F P
0 g
s
.703 .391 .445 r
.35875 .46348 m .36464 .46388 L .36585 .45989 L p F P
0 g
s
.703 .391 .445 r
.36585 .45989 m .35641 .45925 L .35875 .46348 L p F P
0 g
s
.631 .783 .955 r
.44546 .37144 m .43489 .37454 L .43191 .37179 L p F P
0 g
s
.648 .764 .933 r
.43489 .37454 m .44546 .37144 L .44842 .37424 L p F P
0 g
s
.621 .47 .656 r
.56786 .41052 m .56668 .40435 L .55548 .40721 L p F P
0 g
s
.621 .47 .656 r
.55548 .40721 m .55665 .41335 L .56786 .41052 L p F P
0 g
s
.634 .333 .443 r
.45956 .45881 m .44822 .45963 L .44728 .46375 L p F P
0 g
s
.642 .341 .445 r
.44698 .46377 m .44728 .46375 L .44822 .45963 L p F P
0 g
s
.652 .758 .927 r
.44842 .37424 m .45901 .37106 L .46195 .37396 L p F P
0 g
s
.637 .78 .949 r
.45901 .37106 m .44842 .37424 L .44546 .37144 L p F P
0 g
s
.608 .394 .565 r
.54669 .43223 m .54652 .42713 L .53499 .42956 L p F P
0 g
s
.608 .394 .565 r
.53499 .42956 m .53515 .43466 L .54669 .43223 L p F P
0 g
s
.661 .636 .815 r
.53251 .3788 m .54322 .37498 L .54607 .38025 L p F P
0 g
s
.665 .658 .833 r
.53045 .37536 m .53251 .3788 L .54322 .37498 L p F P
0 g
s
.729 .433 .477 r
.32021 .45575 m .32697 .45652 L .32548 .45205 L p F P
0 g
s
.729 .433 .477 r
.32548 .45205 m .32128 .45157 L .32021 .45575 L p F P
0 g
s
.653 .595 .777 r
.55965 .38244 m .55928 .38161 L .54805 .38444 L p F P
0 g
s
.655 .61 .791 r
.54607 .38025 m .54805 .38444 L .55928 .38161 L p F P
0 g
s
.768 .527 .57 r
.2728 .43434 m .27356 .43448 L .2741 .42942 L p F P
0 g
s
.768 .527 .57 r
.2741 .42942 m .27289 .42918 L .2728 .43434 L p F P
0 g
s
.614 .378 .536 r
.51755 .44274 m .52335 .44173 L .52346 .4369 L p F P
0 g
s
.606 .371 .535 r
.53505 .43949 m .53515 .43466 L .52346 .4369 L p F P
0 g
s
.606 .371 .535 r
.52346 .4369 m .52335 .44173 L .53505 .43949 L p F P
0 g
s
.657 .75 .919 r
.46195 .37396 m .47256 .37067 L .47548 .37371 L p F P
0 g
s
.644 .773 .942 r
.47256 .37067 m .46195 .37396 L .45901 .37106 L p F P
0 g
s
.743 .67 .779 r
.26051 .3841 m .25782 .38351 L .25891 .38536 L closepath p F P
0 g
s
.759 .67 .764 r
.2525 .39155 m .25891 .38536 L .25782 .38351 L p F P
0 g
s
.614 .336 .472 r
.49519 .45069 m .48681 .45178 L .48617 .45613 L p F P
0 g
s
.61 .417 .596 r
.55769 .42194 m .55744 .4191 L .54607 .42173 L p F P
0 g
s
.61 .417 .596 r
.5546 .42527 m .55769 .42194 L p .54607 .42173 L F P
0 g
s
.61 .417 .596 r
.54607 .42173 m .54652 .42713 L .5546 .42527 L p F P
0 g
s
.704 .391 .444 r
.34978 .46286 m .35875 .46348 L .35641 .45925 L p F P
0 g
s
.704 .391 .444 r
.35641 .45925 m .35103 .45887 L .34978 .46286 L p F P
0 g
s
.776 .534 .569 r
.26591 .43285 m .2728 .43434 L .27289 .42918 L p F P
0 g
s
.776 .534 .569 r
.27289 .42918 m .26645 .42779 L .26591 .43285 L p F P
0 g
s
.643 .555 .74 r
.56251 .38968 m .55748 .39162 L .56272 .39027 L closepath p F P
0 g
s
.739 .677 .791 r
.26051 .3841 m .26944 .37776 L p .25579 .38029 L F P
0 g
s
.739 .677 .791 r
.25579 .38029 m .25782 .38351 L .26051 .3841 L p F P
0 g
s
.778 .616 .679 r
.25113 .40437 m .25008 .40616 L .25185 .40661 L closepath p F P
0 g
s
.782 .602 .656 r
.24735 .4119 m .25359 .41349 L .25185 .40661 L p F P
0 g
s
.782 .602 .656 r
.25185 .40661 m .25008 .40616 L .24735 .4119 L p F P
0 g
s
.779 .624 .687 r
.25008 .40616 m .25113 .40437 L .24917 .39884 L p F P
0 g
s
.759 .67 .764 r
.24517 .3898 m .2525 .39155 L p .25782 .38351 L F P
0 g
s
.763 .642 .727 r
.2525 .39155 m .24517 .3898 L .24818 .39644 L closepath p F P
0 g
s
.651 .764 .932 r
.48611 .37032 m .47548 .37371 L .47256 .37067 L p F P
0 g
s
.661 .739 .908 r
.47548 .37371 m .48611 .37032 L .48902 .37353 L p F P
0 g
s
.738 .442 .479 r
.31773 .45542 m .32021 .45575 L .32128 .45157 L p F P
0 g
s
.738 .442 .479 r
.32128 .45157 m .31637 .45091 L .31773 .45542 L p F P
0 g
s
.672 .744 .904 r
.31014 .37402 m .32053 .37031 L .32367 .3735 L p F P
0 g
s
.656 .755 .923 r
.32053 .37031 m .31014 .37402 L .30699 .37062 L p F P
0 g
s
.687 .735 .887 r
.2966 .37481 m .30699 .37062 L .31014 .37402 L p F P
0 g
s
.673 .745 .905 r
.30699 .37062 m .2966 .37481 L .29344 .37117 L p F P
0 g
s
.709 .702 .841 r
.2966 .37481 m .29344 .37117 L .28304 .37598 L p F P
0 g
s
.722 .705 .834 r
.28304 .37598 m .2827 .37617 L .2833 .37631 L closepath p F P
0 g
s
.775 .637 .709 r
.24818 .39644 m .24686 .39822 L .24917 .39884 L closepath p F P
0 g
s
.779 .624 .687 r
.24305 .40431 m .25008 .40616 L p .24917 .39884 L F P
0 g
s
.779 .624 .687 r
.24917 .39884 m .24686 .39822 L .24305 .40431 L p F P
0 g
s
.712 .4 .447 r
.34841 .46274 m .34978 .46286 L .35103 .45887 L p F P
0 g
s
.712 .4 .447 r
.35103 .45887 m .34623 .45846 L .34841 .46274 L p F P
0 g
s
.659 .752 .919 r
.32367 .3735 m .33406 .37017 L .33719 .37317 L p F P
0 g
s
.64 .763 .938 r
.33406 .37017 m .32367 .3735 L .32053 .37031 L p F P
0 g
s
.664 .726 .895 r
.48902 .37353 m .49967 .37005 L .50256 .37349 L p F P
0 g
s
.657 .751 .92 r
.49967 .37005 m .48902 .37353 L .48611 .37032 L p F P
0 g
s
.631 .33 .442 r
.46109 .4587 m .46081 .45994 L .45956 .45881 L closepath p F P
0 g
s
.634 .333 .443 r
.46016 .46281 m .46081 .45994 L .45956 .45881 L p F P
0 g
s
.634 .333 .443 r
.44728 .46375 m .46016 .46281 L p .45956 .45881 L F P
0 g
s
.605 .349 .503 r
.51755 .44274 m .51148 .44376 L .51111 .44835 L p F P
0 g
s
.715 .714 .848 r
.2827 .37617 m .28304 .37598 L .27988 .37207 L p F P
0 g
s
.715 .714 .848 r
.27988 .37207 m .2756 .37432 L .2827 .37617 L p F P
0 g
s
.723 .686 .814 r
.26944 .37776 m .2756 .37432 L .2827 .37617 L p F P
0 g
s
.776 .579 .633 r
.25452 .4137 m .25359 .41349 L .2539 .41529 L closepath p F P
0 g
s
.783 .605 .659 r
.24021 .41008 m .24735 .4119 L .25008 .40616 L p F P
0 g
s
.783 .605 .659 r
.25008 .40616 m .24305 .40431 L .24021 .41008 L p F P
0 g
s
.69 .736 .885 r
.29344 .37117 m .28304 .37598 L .27988 .37207 L p F P
0 g
s
.752 .472 .508 r
.29046 .44703 m .29891 .44839 L .29818 .4437 L p F P
0 g
s
.752 .472 .508 r
.29818 .4437 m .28971 .44235 L .29046 .44703 L p F P
0 g
s
.624 .323 .44 r
.47283 .46165 m .47373 .45752 L .46109 .4587 L p F P
0 g
s
.624 .323 .44 r
.46391 .46248 m .47283 .46165 L p .46109 .4587 L F P
0 g
s
.624 .323 .44 r
.46109 .4587 m .46081 .45994 L .46391 .46248 L p F P
0 g
s
.774 .645 .719 r
.24686 .39822 m .24818 .39644 L .24517 .3898 L p F P
0 g
s
.759 .67 .764 r
.24515 .38977 m .24517 .3898 L p .25782 .38351 L F P
0 g
s
.759 .67 .764 r
.25782 .38351 m .25334 .38227 L .24515 .38977 L p F P
0 g
s
.751 .681 .783 r
.25579 .38029 m .25334 .38227 L .25782 .38351 L closepath p F P
0 g
s
.647 .76 .932 r
.33719 .37317 m .3476 .37011 L .35071 .37296 L p F P
0 g
s
.626 .771 .95 r
.3476 .37011 m .33719 .37317 L .33406 .37017 L p F P
0 g
s
.785 .584 .628 r
.25259 .41918 m .2539 .41529 L .25359 .41349 L p F P
0 g
s
.785 .584 .628 r
.24543 .41738 m .25259 .41918 L p .25359 .41349 L F P
0 g
s
.785 .584 .628 r
.25359 .41349 m .24735 .4119 L .24543 .41738 L p F P
0 g
s
.765 .503 .539 r
.27365 .43935 m .28169 .44085 L .2816 .43598 L p F P
0 g
s
.765 .503 .539 r
.2816 .43598 m .27356 .43448 L .27365 .43935 L p F P
0 g
s
.713 .398 .443 r
.33856 .46183 m .34841 .46274 L .34623 .45846 L p F P
0 g
s
.713 .398 .443 r
.34623 .45846 m .33634 .45757 L .33856 .46183 L p F P
0 g
s
.666 .71 .881 r
.50256 .37349 m .51324 .36992 L .5161 .37365 L p F P
0 g
s
.661 .736 .905 r
.51324 .36992 m .50256 .37349 L .49967 .37005 L p F P
0 g
s
.655 .61 .791 r
.55928 .38161 m .55681 .37646 L .54607 .38025 L p F P
0 g
s
.658 .64 .82 r
.55681 .37646 m .54607 .38025 L .54322 .37498 L p F P
0 g
s
.776 .555 .599 r
.25499 .4253 m .25884 .42615 L .26008 .42087 L p F P
0 g
s
.776 .555 .599 r
.26008 .42087 m .25459 .41967 L .25499 .4253 L p F P
0 g
s
.612 .441 .627 r
.5684 .41432 m .56786 .41052 L .55665 .41335 L p F P
0 g
s
.612 .441 .627 r
.56276 .41776 m .5684 .41432 L p .55665 .41335 L F P
0 g
s
.612 .441 .627 r
.55665 .41335 m .55744 .4191 L .56276 .41776 L p F P
0 g
s
.739 .441 .477 r
.30886 .4542 m .31773 .45542 L .31637 .45091 L p F P
0 g
s
.739 .441 .477 r
.31637 .45091 m .30746 .44971 L .30886 .4542 L p F P
0 g
s
.757 .497 .54 r
.28967 .44046 m .28971 .44235 L .28948 .44231 L closepath p F P
0 g
s
.636 .767 .942 r
.35071 .37296 m .36113 .3701 L .36423 .37281 L p F P
0 g
s
.613 .779 .96 r
.36113 .3701 m .35071 .37296 L .3476 .37011 L p F P
0 g
s
.685 .375 .444 r
.37957 .46312 m .38053 .46462 L .37915 .46458 L closepath p F P
0 g
s
.774 .645 .719 r
.23993 .39633 m .24686 .39822 L p .24517 .3898 L F P
0 g
s
.78 .627 .692 r
.23595 .40247 m .24305 .40431 L .24686 .39822 L p F P
0 g
s
.78 .627 .692 r
.24686 .39822 m .23993 .39633 L .23595 .40247 L p F P
0 g
s
.783 .579 .625 r
.2539 .41529 m .25259 .41918 L .25459 .41967 L closepath p F P
0 g
s
.612 .336 .474 r
.49905 .45017 m .49856 .4537 L .49519 .45069 L closepath p F P
0 g
s
.614 .336 .472 r
.49844 .45454 m .49856 .4537 L .49519 .45069 L p F P
0 g
s
.614 .336 .472 r
.48617 .45613 m .49844 .45454 L p .49519 .45069 L F P
0 g
s
.717 .697 .83 r
.2756 .37432 m .26944 .37776 L .26629 .37347 L p F P
0 g
s
.739 .677 .791 r
.26944 .37776 m .26629 .37347 L .25579 .38029 L p F P
0 g
s
.721 .426 .478 r
.33604 .45671 m .33634 .45757 L .33585 .45752 L closepath p F P
0 g
s
.604 .785 .968 r
.37468 .37007 m .36423 .37281 L .36113 .3701 L p F P
0 g
s
.629 .773 .95 r
.36423 .37281 m .37468 .37007 L .37776 .37267 L p F P
0 g
s
.664 .666 .842 r
.52966 .37409 m .53045 .37536 L .54183 .3727 L p F P
0 g
s
.665 .658 .833 r
.54322 .37498 m .54183 .3727 L .53045 .37536 L p F P
0 g
s
.665 .691 .864 r
.5161 .37365 m .5268 .37002 L .52966 .37409 L p F P
0 g
s
.664 .717 .889 r
.5268 .37002 m .5161 .37365 L .51324 .36992 L p F P
0 g
s
.639 .552 .741 r
.56251 .38968 m .56272 .39027 L .57375 .38719 L p F P
0 g
s
.634 .532 .722 r
.5761 .39464 m .57375 .38719 L .56272 .39027 L p F P
0 g
s
.634 .532 .722 r
.56272 .39027 m .56504 .39769 L .5761 .39464 L p F P
0 g
s
.639 .552 .741 r
.57375 .38719 m .57328 .38586 L .56251 .38968 L p F P
0 g
s
.643 .575 .763 r
.57328 .38586 m .56251 .38968 L .55965 .38244 L p F P
0 g
s
.776 .534 .57 r
.25829 .43121 m .26591 .43285 L .26645 .42779 L p F P
0 g
s
.776 .534 .57 r
.26645 .42779 m .25884 .42615 L .25829 .43121 L p F P
0 g
s
.627 .508 .698 r
.57617 .39492 m .5761 .39464 L .56504 .39769 L p F P
0 g
s
.627 .508 .698 r
.56504 .39769 m .5654 .39906 L .57617 .39492 L p F P
0 g
s
.604 .349 .505 r
.52335 .44173 m .51755 .44274 L .52105 .44667 L p F P
0 g
s
.605 .349 .503 r
.51111 .44835 m .52105 .44667 L .51755 .44274 L p F P
0 g
s
.624 .778 .955 r
.37776 .37267 m .38823 .37 L .39129 .37252 L p F P
0 g
s
.598 .791 .973 r
.38823 .37 m .37776 .37267 L .37468 .37007 L p F P
0 g
s
.605 .329 .472 r
.51051 .45271 m .51111 .44835 L .49905 .45017 L p F P
0 g
s
.605 .329 .472 r
.49945 .45439 m .51051 .45271 L p .49905 .45017 L F P
0 g
s
.605 .329 .472 r
.49905 .45017 m .49856 .4537 L .49945 .45439 L p F P
0 g
s
.622 .494 .684 r
.57773 .4013 m .57617 .39492 L .5654 .39906 L p F P
0 g
s
.622 .494 .684 r
.5654 .39906 m .56668 .40435 L .57773 .4013 L p F P
0 g
s
.624 .323 .439 r
.46081 .45994 m .46391 .46248 L .46016 .46281 L closepath p F P
0 g
s
.715 .398 .441 r
.33452 .46145 m .33856 .46183 L .33634 .45757 L p F P
0 g
s
.715 .398 .441 r
.33634 .45757 m .33585 .45752 L .33452 .46145 L p F P
0 g
s
.654 .327 .407 r
.41776 .46492 m .40721 .46505 L .40653 .46705 L p F P
0 g
s
.663 .336 .41 r
.40721 .46505 m .40653 .46705 L .40463 .46505 L closepath p F P
0 g
s
.663 .334 .406 r
.40591 .4689 m .40653 .46705 L .40463 .46505 L p F P
0 g
s
.663 .334 .406 r
.39583 .46882 m .40591 .4689 L p .40463 .46505 L F P
0 g
s
.663 .334 .406 r
.39302 .46584 m .39583 .46882 L p .40463 .46505 L F P
0 g
s
.663 .334 .406 r
.40463 .46505 m .39333 .46497 L .39302 .46584 L p F P
0 g
s
.613 .314 .438 r
.47801 .45706 m .47373 .45752 L .47283 .46165 L p F P
0 g
s
.724 .408 .445 r
.32902 .46083 m .33452 .46145 L .33585 .45752 L p F P
0 g
s
.724 .408 .445 r
.33585 .45752 m .32697 .45652 L .32902 .46083 L p F P
0 g
s
.673 .344 .409 r
.39333 .46497 m .39302 .46584 L .39224 .46494 L closepath p F P
0 g
s
.769 .656 .738 r
.24515 .38977 m .24513 .38979 L .24517 .3898 L closepath p F P
0 g
s
.774 .645 .719 r
.24517 .3898 m .24513 .38979 L .23993 .39633 L p F P
0 g
s
.753 .659 .757 r
.25334 .38227 m .24515 .38977 L .24206 .38403 L p F P
0 g
s
.768 .664 .748 r
.24513 .38979 m .24515 .38977 L .24206 .38403 L p F P
0 g
s
.768 .664 .748 r
.24206 .38403 m .23838 .38783 L .24513 .38979 L p F P
0 g
s
.775 .651 .726 r
.23291 .39445 m .23993 .39633 L .24513 .38979 L p F P
0 g
s
.775 .651 .726 r
.24513 .38979 m .23838 .38783 L .23291 .39445 L p F P
0 g
s
.753 .659 .757 r
.24206 .38403 m .24635 .38039 L .25334 .38227 L p F P
0 g
s
.746 .686 .793 r
.25334 .38227 m .25579 .38029 L .25264 .37562 L p F P
0 g
s
.746 .686 .793 r
.25264 .37562 m .24635 .38039 L .25334 .38227 L p F P
0 g
s
.673 .344 .409 r
.38394 .46856 m .38053 .46462 L .39224 .46494 L p F P
0 g
s
.673 .344 .409 r
.39197 .46878 m .38394 .46856 L p .39224 .46494 L F P
0 g
s
.673 .344 .409 r
.39224 .46494 m .39302 .46584 L .39197 .46878 L p F P
0 g
s
.622 .782 .958 r
.39129 .37252 m .40178 .36987 L .40482 .37233 L p F P
0 g
s
.595 .796 .976 r
.40178 .36987 m .39129 .37252 L .38823 .37 L p F P
0 g
s
.652 .328 .41 r
.42081 .46487 m .42008 .46714 L .41776 .46492 L closepath p F P
0 g
s
.654 .327 .407 r
.41956 .46874 m .42008 .46714 L .41776 .46492 L p F P
0 g
s
.654 .327 .407 r
.4084 .46888 m .41956 .46874 L p .41776 .46492 L F P
0 g
s
.654 .327 .407 r
.40653 .46705 m .4084 .46888 L p .41776 .46492 L F P
0 g
s
.664 .666 .842 r
.54183 .3727 m .54038 .37042 L .52966 .37409 L p F P
0 g
s
.664 .696 .87 r
.54038 .37042 m .52966 .37409 L .5268 .37002 L p F P
0 g
s
.754 .474 .507 r
.28861 .44673 m .29046 .44703 L .28971 .44235 L p F P
0 g
s
.754 .474 .507 r
.28971 .44235 m .28948 .44231 L .28861 .44673 L p F P
0 g
s
.643 .318 .406 r
.4318 .46452 m .42081 .46487 L .42008 .46714 L p F P
0 g
s
.763 .483 .509 r
.28234 .44556 m .28861 .44673 L .28948 .44231 L p F P
0 g
s
.763 .483 .509 r
.28948 .44231 m .28169 .44085 L .28234 .44556 L p F P
0 g
s
.728 .71 .833 r
.25579 .38029 m .26629 .37347 L .26531 .37223 L p F P
0 g
s
.728 .71 .833 r
.25264 .37562 m .25579 .38029 L p .26531 .37223 L F P
0 g
s
.785 .561 .598 r
.25143 .42443 m .25499 .4253 L .25459 .41967 L p F P
0 g
s
.785 .561 .598 r
.25459 .41967 m .25259 .41918 L .25143 .42443 L p F P
0 g
s
.74 .441 .476 r
.30408 .45354 m .30886 .4542 L .30746 .44971 L p F P
0 g
s
.74 .441 .476 r
.30746 .44971 m .30522 .44939 L .30408 .45354 L p F P
0 g
s
.597 .364 .534 r
.54661 .43707 m .54669 .43223 L .53515 .43466 L p F P
0 g
s
.597 .364 .534 r
.53515 .43466 m .53505 .43949 L .54661 .43707 L p F P
0 g
s
.599 .387 .565 r
.5546 .42527 m .54652 .42713 L .54669 .43223 L p F P
0 g
s
.622 .784 .959 r
.40482 .37233 m .41534 .36965 L .41836 .37209 L p F P
0 g
s
.595 .799 .978 r
.41534 .36965 m .40482 .37233 L .40178 .36987 L p F P
0 g
s
.676 .344 .406 r
.37774 .46836 m .38394 .46856 L .38053 .46462 L p F P
0 g
s
.676 .344 .406 r
.38053 .46462 m .37915 .46458 L .37774 .46836 L p F P
0 g
s
.685 .354 .41 r
.37259 .46812 m .37774 .46836 L .37915 .46458 L p F P
0 g
s
.685 .354 .41 r
.37915 .46458 m .36943 .46412 L .37259 .46812 L p F P
0 g
s
.612 .315 .441 r
.48617 .45613 m .47801 .45706 L .48298 .46055 L p F P
0 g
s
.613 .314 .438 r
.47283 .46165 m .48298 .46055 L .47801 .45706 L p F P
0 g
s
.767 .505 .539 r
.27228 .43909 m .27365 .43935 L .27356 .43448 L p F P
0 g
s
.767 .505 .539 r
.27356 .43448 m .2728 .43434 L .27228 .43909 L p F P
0 g
s
.705 .715 .856 r
.2756 .37432 m .27988 .37207 L .2767 .3684 L p F P
0 g
s
.705 .715 .856 r
.2767 .3684 m .26781 .37269 L .2756 .37432 L p F P
0 g
s
.717 .697 .83 r
.26629 .37347 m .26781 .37269 L .2756 .37432 L p F P
0 g
s
.642 .318 .408 r
.43417 .46443 m .43364 .4661 L .4318 .46452 L closepath p F P
0 g
s
.643 .318 .406 r
.43295 .46831 m .43364 .4661 L .4318 .46452 L p F P
0 g
s
.643 .318 .406 r
.42181 .46867 m .43295 .46831 L p .4318 .46452 L F P
0 g
s
.643 .318 .406 r
.42008 .46714 m .42181 .46867 L p .4318 .46452 L F P
0 g
s
.785 .585 .63 r
.23823 .41558 m .24543 .41738 L .24735 .4119 L p F P
0 g
s
.785 .585 .63 r
.24735 .4119 m .24021 .41008 L .23823 .41558 L p F P
0 g
s
.614 .466 .657 r
.57892 .40747 m .57773 .4013 L .56668 .40435 L p F P
0 g
s
.614 .466 .657 r
.56668 .40435 m .56786 .41052 L .57892 .40747 L p F P
0 g
s
.643 .575 .763 r
.55965 .38244 m .57042 .37871 L .57328 .38586 L p F P
0 g
s
.649 .596 .782 r
.55928 .38161 m .55965 .38244 L .57042 .37871 L p F P
0 g
s
.782 .607 .663 r
.2347 .40868 m .24021 .41008 L .24305 .40431 L p F P
0 g
s
.782 .607 .663 r
.23406 .40615 m .2347 .40868 L p .24305 .40431 L F P
0 g
s
.782 .607 .663 r
.24305 .40431 m .23595 .40247 L .23406 .40615 L p F P
0 g
s
.632 .309 .405 r
.44698 .46377 m .43417 .46443 L .43364 .4661 L p F P
0 g
s
.749 .451 .478 r
.30018 .45292 m .30408 .45354 L .30522 .44939 L p F P
0 g
s
.749 .451 .478 r
.30522 .44939 m .29891 .44839 L .30018 .45292 L p F P
0 g
s
.775 .513 .539 r
.26596 .43774 m .27228 .43909 L .2728 .43434 L p F P
0 g
s
.775 .513 .539 r
.2728 .43434 m .26591 .43285 L .26596 .43774 L p F P
0 g
s
.625 .785 .958 r
.41836 .37209 m .42891 .36935 L .43191 .37179 L p F P
0 g
s
.6 .801 .977 r
.42891 .36935 m .41836 .37209 L .41534 .36965 L p F P
0 g
s
.652 .611 .796 r
.55681 .37646 m .55928 .38161 L .57035 .37856 L p F P
0 g
s
.649 .596 .782 r
.57042 .37871 m .57035 .37856 L .55928 .38161 L p F P
0 g
s
.786 .564 .599 r
.24422 .42265 m .25143 .42443 L .25259 .41918 L p F P
0 g
s
.786 .564 .599 r
.25259 .41918 m .24543 .41738 L .24422 .42265 L p F P
0 g
s
.604 .349 .505 r
.52105 .44667 m .52301 .44633 L .52335 .44173 L p F P
0 g
s
.594 .341 .503 r
.53472 .44409 m .53505 .43949 L .52335 .44173 L p F P
0 g
s
.594 .341 .503 r
.52335 .44173 m .52301 .44633 L .53472 .44409 L p F P
0 g
s
.602 .412 .597 r
.56276 .41776 m .55744 .4191 L .55769 .42194 L closepath p F P
0 g
s
.631 .783 .955 r
.43191 .37179 m .44248 .36896 L .44546 .37144 L p F P
0 g
s
.608 .801 .974 r
.44248 .36896 m .43191 .37179 L .42891 .36935 L p F P
0 g
s
.666 .336 .406 r
.39302 .46584 m .39583 .46882 L .39197 .46878 L closepath p F P
0 g
s
.686 .354 .408 r
.36318 .46765 m .37259 .46812 L .36943 .46412 L p F P
0 g
s
.686 .354 .408 r
.36943 .46412 m .36464 .46388 L .36318 .46765 L p F P
0 g
s
.658 .64 .82 r
.54322 .37498 m .55397 .37129 L .55681 .37646 L p F P
0 g
s
.663 .663 .84 r
.54183 .3727 m .54322 .37498 L .55397 .37129 L p F P
0 g
s
.724 .407 .443 r
.31968 .45976 m .32902 .46083 L .32697 .45652 L p F P
0 g
s
.724 .407 .443 r
.31917 .45869 m .31968 .45976 L p .32697 .45652 L F P
0 g
s
.724 .407 .443 r
.32697 .45652 m .32021 .45575 L .31917 .45869 L p F P
0 g
s
.777 .63 .698 r
.23281 .40165 m .23595 .40247 L .23993 .39633 L p F P
0 g
s
.777 .63 .698 r
.23118 .39698 m .23281 .40165 L p .23993 .39633 L F P
0 g
s
.777 .63 .698 r
.23993 .39633 m .23291 .39445 L .23118 .39698 L p F P
0 g
s
.637 .78 .949 r
.44546 .37144 m .45605 .3685 L .45901 .37106 L p F P
0 g
s
.617 .799 .969 r
.45605 .3685 m .44546 .37144 L .44248 .36896 L p F P
0 g
s
.695 .364 .412 r
.36168 .46755 m .36318 .46765 L .36464 .46388 L p F P
0 g
s
.695 .364 .412 r
.36464 .46388 m .35875 .46348 L .36168 .46755 L p F P
0 g
s
.63 .307 .405 r
.44728 .46375 m .44722 .46395 L .44698 .46377 L closepath p F P
0 g
s
.632 .309 .405 r
.44609 .46764 m .44722 .46395 L .44698 .46377 L p F P
0 g
s
.632 .309 .405 r
.43626 .46815 m .44609 .46764 L p .44698 .46377 L F P
0 g
s
.632 .309 .405 r
.43364 .4661 m .43626 .46815 L p .44698 .46377 L F P
0 g
s
.644 .773 .942 r
.45901 .37106 m .46963 .368 L .47256 .37067 L p F P
0 g
s
.627 .794 .963 r
.46963 .368 m .45901 .37106 L .45605 .3685 L p F P
0 g
s
.622 .299 .402 r
.45902 .46672 m .46016 .46281 L .44728 .46375 L p F P
0 g
s
.622 .299 .402 r
.45202 .46723 m .45902 .46672 L p .44728 .46375 L F P
0 g
s
.622 .299 .402 r
.44728 .46375 m .44722 .46395 L .45202 .46723 L p F P
0 g
s
.777 .535 .569 r
.2549 .43047 m .25829 .43121 L .25884 .42615 L p F P
0 g
s
.777 .535 .569 r
.25884 .42615 m .25499 .4253 L .2549 .43047 L p F P
0 g
s
.673 .745 .905 r
.29344 .37117 m .30382 .36743 L .30699 .37062 L p F P
0 g
s
.657 .755 .922 r
.30382 .36743 m .29344 .37117 L .29027 .36776 L p F P
0 g
s
.69 .736 .885 r
.27988 .37207 m .29027 .36776 L .29344 .37117 L p F P
0 g
s
.602 .305 .438 r
.4976 .45868 m .49844 .45454 L .48617 .45613 L p F P
0 g
s
.602 .305 .438 r
.48617 .45613 m .48532 .46028 L .4976 .45868 L p F P
0 g
s
.612 .315 .441 r
.48298 .46055 m .48532 .46028 L .48617 .45613 L p F P
0 g
s
.677 .745 .902 r
.29027 .36776 m .27988 .37207 L .2767 .3684 L p F P
0 g
s
.656 .755 .923 r
.30699 .37062 m .31737 .36734 L .32053 .37031 L p F P
0 g
s
.637 .764 .94 r
.31737 .36734 m .30699 .37062 L .30382 .36743 L p F P
0 g
s
.651 .764 .932 r
.47256 .37067 m .4832 .3675 L .48611 .37032 L p F P
0 g
s
.637 .787 .954 r
.4832 .3675 m .47256 .37067 L .46963 .368 L p F P
0 g
s
.623 .299 .402 r
.44722 .46395 m .45202 .46723 L .44609 .46764 L closepath p F P
0 g
s
.695 .36 .405 r
.35132 .4668 m .36168 .46755 L .35875 .46348 L p F P
0 g
s
.695 .36 .405 r
.3493 .46403 m .35132 .4668 L p .35875 .46348 L F P
0 g
s
.695 .36 .405 r
.35875 .46348 m .34978 .46286 L .3493 .46403 L p F P
0 g
s
.749 .449 .475 r
.29176 .45155 m .30018 .45292 L .29891 .44839 L p F P
0 g
s
.749 .449 .475 r
.29891 .44839 m .29046 .44703 L .29176 .45155 L p F P
0 g
s
.763 .481 .507 r
.27432 .44405 m .28234 .44556 L .28169 .44085 L p F P
0 g
s
.763 .481 .507 r
.28169 .44085 m .27365 .43935 L .27432 .44405 L p F P
0 g
s
.594 .319 .47 r
.52105 .44667 m .51111 .44835 L .51051 .45271 L p F P
0 g
s
.64 .763 .938 r
.32053 .37031 m .33091 .36738 L .33406 .37017 L p F P
0 g
s
.618 .772 .954 r
.33091 .36738 m .32053 .37031 L .31737 .36734 L p F P
0 g
s
.646 .776 .943 r
.49678 .36702 m .48611 .37032 L .4832 .3675 L p F P
0 g
s
.657 .751 .92 r
.48611 .37032 m .49678 .36702 L .49967 .37005 L p F P
0 g
s
.709 .707 .846 r
.26781 .37269 m .26531 .37223 L .26629 .37347 L closepath p F P
0 g
s
.751 .67 .772 r
.24635 .38039 m .24206 .38403 L .23893 .37871 L p F P
0 g
s
.763 .667 .757 r
.23838 .38783 m .24206 .38403 L .23893 .37871 L p F P
0 g
s
.733 .417 .446 r
.32021 .45575 m .31917 .45869 L .31773 .45542 L closepath p F P
0 g
s
.605 .438 .629 r
.57917 .40914 m .57892 .40747 L .56786 .41052 L p F P
0 g
s
.605 .438 .629 r
.56786 .41052 m .5684 .41432 L .57917 .40914 L p F P
0 g
s
.656 .329 .407 r
.40653 .46705 m .4084 .46888 L .40591 .4689 L closepath p F P
0 g
s
.6 .409 .595 r
.55769 .42194 m .5579 .4245 L p .56865 .41626 L F P
0 g
s
.6 .409 .595 r
.56865 .41626 m .56276 .41776 L .55769 .42194 L p F P
0 g
s
.607 .413 .593 r
.55769 .42194 m .5546 .42527 L .5579 .4245 L closepath p F P
0 g
s
.739 .687 .801 r
.24635 .38039 m .25264 .37562 L .24947 .37125 L p F P
0 g
s
.739 .687 .801 r
.24947 .37125 m .2391 .37858 L .24635 .38039 L p F P
0 g
s
.751 .67 .772 r
.23893 .37871 m .2391 .37858 L .24635 .38039 L p F P
0 g
s
.661 .736 .905 r
.49967 .37005 m .51036 .36665 L .51324 .36992 L p F P
0 g
s
.654 .762 .929 r
.51036 .36665 m .49967 .37005 L .49678 .36702 L p F P
0 g
s
.626 .771 .95 r
.33406 .37017 m .34446 .36749 L .3476 .37011 L p F P
0 g
s
.601 .78 .966 r
.34446 .36749 m .33406 .37017 L .33091 .36738 L p F P
0 g
s
.763 .667 .757 r
.23893 .37871 m .23153 .38589 L .23838 .38783 L p F P
0 g
s
.771 .654 .733 r
.2299 .39365 m .23291 .39445 L .23838 .38783 L p F P
0 g
s
.771 .654 .733 r
.22817 .38974 m .2299 .39365 L p .23838 .38783 L F P
0 g
s
.771 .654 .733 r
.23838 .38783 m .23153 .38589 L .22817 .38974 L p F P
0 g
s
.662 .67 .847 r
.54038 .37042 m .54183 .3727 L .55308 .36985 L p F P
0 g
s
.663 .663 .84 r
.55397 .37129 m .55308 .36985 L .54183 .3727 L p F P
0 g
s
.706 .71 .852 r
.26781 .37269 m .2767 .3684 L p .2631 .36949 L F P
0 g
s
.706 .71 .852 r
.2631 .36949 m .26531 .37223 L .26781 .37269 L p F P
0 g
s
.775 .513 .539 r
.25834 .4361 m .26596 .43774 L .26591 .43285 L p F P
0 g
s
.775 .513 .539 r
.26591 .43285 m .25829 .43121 L .25834 .4361 L p F P
0 g
s
.733 .417 .446 r
.31079 .45855 m .30886 .4542 L .31773 .45542 L p F P
0 g
s
.733 .417 .446 r
.31883 .45966 m .31079 .45855 L p .31773 .45542 L F P
0 g
s
.733 .417 .446 r
.31773 .45542 m .31917 .45869 L .31883 .45966 L p F P
0 g
s
.652 .611 .796 r
.57035 .37856 m .56758 .37283 L .55681 .37646 L p F P
0 g
s
.656 .641 .824 r
.56758 .37283 m .55681 .37646 L .55397 .37129 L p F P
0 g
s
.785 .542 .569 r
.25088 .4295 m .2549 .43047 L .25499 .4253 L p F P
0 g
s
.785 .542 .569 r
.25499 .4253 m .25143 .42443 L .25088 .4295 L p F P
0 g
s
.609 .435 .621 r
.5684 .41432 m .56276 .41776 L .56865 .41626 L closepath p F P
0 g
s
.597 .385 .564 r
.5579 .4245 m .5546 .42527 L .55279 .43083 L p F P
0 g
s
.599 .387 .565 r
.54669 .43223 m .55279 .43083 L .5546 .42527 L p F P
0 g
s
.634 .31 .405 r
.43364 .4661 m .43626 .46815 L .43295 .46831 L closepath p F P
0 g
s
.704 .371 .409 r
.34978 .46286 m .3493 .46403 L .34841 .46274 L closepath p F P
0 g
s
.612 .291 .402 r
.46391 .46248 m .46016 .46281 L .45902 .46672 L p F P
0 g
s
.664 .717 .889 r
.51324 .36992 m .52395 .36643 L .5268 .37002 L p F P
0 g
s
.659 .744 .913 r
.52395 .36643 m .51324 .36992 L .51036 .36665 L p F P
0 g
s
.785 .585 .63 r
.23578 .41496 m .23823 .41558 L .24021 .41008 L p F P
0 g
s
.785 .585 .63 r
.24021 .41008 m .2347 .40868 L .23578 .41496 L p F P
0 g
s
.705 .371 .409 r
.34134 .46594 m .33856 .46183 L .34841 .46274 L p F P
0 g
s
.705 .371 .409 r
.34825 .46657 m .34134 .46594 L p .34841 .46274 L F P
0 g
s
.705 .371 .409 r
.34841 .46274 m .3493 .46403 L .34825 .46657 L p F P
0 g
s
.645 .32 .406 r
.42008 .46714 m .42181 .46867 L .41956 .46874 L closepath p F P
0 g
s
.613 .779 .96 r
.3476 .37011 m .35802 .36762 L .36113 .3701 L p F P
0 g
s
.584 .789 .977 r
.35802 .36762 m .3476 .37011 L .34446 .36749 L p F P
0 g
s
.605 .329 .472 r
.49856 .4537 m .49945 .45439 L .49844 .45454 L closepath p F P
0 g
s
.782 .608 .664 r
.23595 .40247 m .23281 .40165 L .23406 .40615 L closepath p F P
0 g
s
.728 .71 .833 r
.26531 .37223 m .26066 .37085 L .25264 .37562 L p F P
0 g
s
.724 .696 .823 r
.26066 .37085 m .25264 .37562 L .24947 .37125 L p F P
0 g
s
.786 .564 .6 r
.237 .42086 m .24422 .42265 L .24543 .41738 L p F P
0 g
s
.786 .564 .6 r
.24543 .41738 m .23823 .41558 L .237 .42086 L p F P
0 g
s
.722 .715 .843 r
.2631 .36949 m .26066 .37085 L .26531 .37223 L closepath p F P
0 g
s
.611 .292 .406 r
.47283 .46165 m .46391 .46248 L .46947 .4658 L p F P
0 g
s
.612 .291 .402 r
.45902 .46672 m .46947 .4658 L .46391 .46248 L p F P
0 g
s
.634 .551 .744 r
.57328 .38586 m .57375 .38719 L .58465 .38391 L p F P
0 g
s
.628 .53 .724 r
.58698 .39131 m .58465 .38391 L .57375 .38719 L p F P
0 g
s
.628 .53 .724 r
.5846 .3921 m .58698 .39131 L p .57375 .38719 L F P
0 g
s
.628 .53 .724 r
.57375 .38719 m .5761 .39464 L .5846 .3921 L p F P
0 g
s
.662 .724 .895 r
.53754 .36646 m .5268 .37002 L .52395 .36643 L p F P
0 g
s
.664 .696 .87 r
.5268 .37002 m .53754 .36646 L .54038 .37042 L p F P
0 g
s
.621 .506 .701 r
.5846 .3921 m .5761 .39464 L .57617 .39492 L closepath p F P
0 g
s
.634 .551 .744 r
.58465 .38391 m .58409 .38233 L .57328 .38586 L p F P
0 g
s
.641 .581 .771 r
.57328 .38586 m .58409 .38233 L .58126 .37527 L p F P
0 g
s
.641 .581 .771 r
.57042 .37871 m .57328 .38586 L p .58126 .37527 L F P
0 g
s
.618 .497 .693 r
.57617 .39492 m .57773 .4013 L p .587 .39138 L F P
0 g
s
.618 .497 .693 r
.587 .39138 m .5846 .3921 L .57617 .39492 L p F P
0 g
s
.604 .785 .968 r
.36113 .3701 m .37158 .36771 L .37468 .37007 L p F P
0 g
s
.57 .796 .984 r
.37158 .36771 m .36113 .3701 L .35802 .36762 L p F P
0 g
s
.588 .356 .533 r
.55279 .43083 m .54669 .43223 L .54661 .43707 L p F P
0 g
s
.777 .63 .698 r
.23291 .39445 m .2299 .39365 L .23118 .39698 L closepath p F P
0 g
s
.6 .409 .595 r
.5579 .4245 m .56911 .42165 L .56865 .41626 L p F P
0 g
s
.589 .379 .564 r
.56931 .42675 m .56911 .42165 L .5579 .4245 L p F P
0 g
s
.589 .379 .564 r
.5579 .4245 m .55808 .4296 L .56931 .42675 L p F P
0 g
s
.597 .385 .564 r
.55279 .43083 m .55808 .4296 L .5579 .4245 L p F P
0 g
s
.751 .45 .474 r
.2874 .45083 m .29176 .45155 L .29046 .44703 L p F P
0 g
s
.751 .45 .474 r
.29046 .44703 m .28861 .44673 L .2874 .45083 L p F P
0 g
s
.585 .333 .501 r
.54629 .44166 m .54661 .43707 L .53505 .43949 L p F P
0 g
s
.585 .333 .501 r
.53505 .43949 m .53472 .44409 L .54629 .44166 L p F P
0 g
s
.592 .294 .433 r
.49945 .45439 m .49844 .45454 L .4976 .45868 L p F P
0 g
s
.787 .544 .569 r
.24366 .42771 m .25088 .4295 L .25143 .42443 L p F P
0 g
s
.787 .544 .569 r
.25143 .42443 m .24422 .42265 L .24366 .42771 L p F P
0 g
s
.601 .429 .621 r
.57971 .41321 m .57917 .40914 L .5684 .41432 L p F P
0 g
s
.601 .429 .621 r
.5684 .41432 m .56865 .41626 L .57971 .41321 L p F P
0 g
s
.562 .801 .989 r
.38478 .36782 m .37468 .37007 L .37158 .36771 L p F P
0 g
s
.598 .791 .973 r
.38528 .36783 m .38823 .37 L p .37468 .37007 L F P
0 g
s
.598 .791 .973 r
.37468 .37007 m .38478 .36782 L .38528 .36783 L p F P
0 g
s
.765 .483 .507 r
.27136 .44349 m .27432 .44405 L .27365 .43935 L p F P
0 g
s
.765 .483 .507 r
.27365 .43935 m .27228 .43909 L .27136 .44349 L p F P
0 g
s
.591 .296 .437 r
.51051 .45271 m .49945 .45439 L .50582 .45747 L p F P
0 g
s
.592 .294 .433 r
.4976 .45868 m .50582 .45747 L .49945 .45439 L p F P
0 g
s
.787 .627 .682 r
.23118 .39698 m .22909 .40055 L .23281 .40165 L closepath p F P
0 g
s
.792 .612 .658 r
.23314 .40824 m .23406 .40615 L .23281 .40165 L p F P
0 g
s
.792 .612 .658 r
.2264 .40627 m .23314 .40824 L p .23281 .40165 L F P
0 g
s
.792 .612 .658 r
.23281 .40165 m .22909 .40055 L .2264 .40627 L p F P
0 g
s
.707 .372 .407 r
.33292 .46514 m .34134 .46594 L .33856 .46183 L p F P
0 g
s
.707 .372 .407 r
.33856 .46183 m .33452 .46145 L .33292 .46514 L p F P
0 g
s
.662 .67 .847 r
.55308 .36985 m .55114 .36684 L .54038 .37042 L p F P
0 g
s
.662 .701 .875 r
.55114 .36684 m .54038 .37042 L .53754 .36646 L p F P
0 g
s
.76 .46 .477 r
.28353 .45011 m .2874 .45083 L .28861 .44673 L p F P
0 g
s
.76 .46 .477 r
.28861 .44673 m .28234 .44556 L .28353 .45011 L p F P
0 g
s
.735 .416 .442 r
.30263 .45741 m .31079 .45855 L .30886 .4542 L p F P
0 g
s
.735 .416 .442 r
.30886 .4542 m .30408 .45354 L .30263 .45741 L p F P
0 g
s
.592 .317 .47 r
.52301 .44633 m .52282 .44771 L .52105 .44667 L closepath p F P
0 g
s
.594 .319 .47 r
.52243 .4507 m .52282 .44771 L .52105 .44667 L p F P
0 g
s
.594 .319 .47 r
.51051 .45271 m .52243 .4507 L p .52105 .44667 L F P
0 g
s
.788 .634 .689 r
.22909 .40055 m .23118 .39698 L .2299 .39365 L p F P
0 g
s
.773 .492 .508 r
.26656 .44246 m .27136 .44349 L .27228 .43909 L p F P
0 g
s
.773 .492 .508 r
.27228 .43909 m .26596 .43774 L .26656 .44246 L p F P
0 g
s
.601 .283 .403 r
.48298 .46055 m .47283 .46165 L .47174 .46559 L p F P
0 g
s
.611 .292 .406 r
.46947 .4658 m .47174 .46559 L .47283 .46165 L p F P
0 g
s
.698 .363 .406 r
.3493 .46403 m .35132 .4668 L .34825 .46657 L closepath p F P
0 g
s
.595 .796 .976 r
.39948 .36822 m .40178 .36987 L p .38823 .37 L F P
0 g
s
.595 .796 .976 r
.38823 .37 m .3964 .36819 L .39948 .36822 L p F P
0 g
s
.598 .791 .973 r
.38823 .37 m .3964 .36819 L .38528 .36783 L closepath p F P
0 g
s
.79 .606 .651 r
.23406 .40615 m .23314 .40824 L .2347 .40868 L closepath p F P
0 g
s
.618 .497 .693 r
.57773 .4013 m .58863 .39804 L .587 .39138 L p F P
0 g
s
.607 .462 .658 r
.58984 .40423 m .58863 .39804 L .57773 .4013 L p F P
0 g
s
.607 .462 .658 r
.57773 .4013 m .57892 .40747 L .58984 .40423 L p F P
0 g
s
.717 .382 .411 r
.33159 .46499 m .33292 .46514 L .33452 .46145 L p F P
0 g
s
.717 .382 .411 r
.33452 .46145 m .32902 .46083 L .33159 .46499 L p F P
0 g
s
.591 .402 .594 r
.58019 .4186 m .57971 .41321 L .56865 .41626 L p F P
0 g
s
.591 .402 .594 r
.56865 .41626 m .56911 .42165 L .58019 .4186 L p F P
0 g
s
.783 .647 .712 r
.22817 .38974 m .22615 .39249 L .2299 .39365 L closepath p F P
0 g
s
.788 .634 .689 r
.22242 .39855 m .22909 .40055 L p .2299 .39365 L F P
0 g
s
.788 .634 .689 r
.2299 .39365 m .22615 .39249 L .22242 .39855 L p F P
0 g
s
.747 .679 .785 r
.2391 .37858 m .2388 .3785 L .23893 .37871 L closepath p F P
0 g
s
.765 .679 .768 r
.23153 .38589 m .23893 .37871 L .2388 .3785 L p F P
0 g
s
.641 .581 .771 r
.58126 .37527 m .57779 .37632 L .57042 .37871 L p F P
0 g
s
.645 .596 .785 r
.57779 .37632 m .57035 .37856 L .57042 .37871 L closepath p F P
0 g
s
.583 .31 .468 r
.53417 .44847 m .53472 .44409 L .52301 .44633 L p F P
0 g
s
.583 .31 .468 r
.52724 .4498 m .53417 .44847 L p .52301 .44633 L F P
0 g
s
.583 .31 .468 r
.52301 .44633 m .52282 .44771 L .52724 .4498 L p F P
0 g
s
.737 .708 .824 r
.2391 .37858 m .24947 .37125 L .24644 .36734 L p F P
0 g
s
.737 .708 .824 r
.2388 .3785 m .2391 .37858 L p .24644 .36734 L F P
0 g
s
.794 .591 .627 r
.2313 .41369 m .23578 .41496 L .2347 .40868 L p F P
0 g
s
.794 .591 .627 r
.2347 .40868 m .23314 .40824 L .2313 .41369 L p F P
0 g
s
.644 .295 .366 r
.4084 .46888 m .40591 .4689 L .40436 .47252 L p F P
0 g
s
.654 .306 .371 r
.40017 .47249 m .40436 .47252 L .40591 .4689 L p F P
0 g
s
.654 .306 .371 r
.40591 .4689 m .39583 .46882 L .40017 .47249 L p F P
0 g
s
.648 .611 .799 r
.56758 .37283 m .57035 .37856 L .57779 .37632 L p F P
0 g
s
.643 .296 .37 r
.41956 .46874 m .4084 .46888 L .41308 .47244 L p F P
0 g
s
.644 .295 .366 r
.40436 .47252 m .41308 .47244 L .4084 .46888 L p F P
0 g
s
.777 .514 .538 r
.25434 .43522 m .25834 .4361 L .25829 .43121 L p F P
0 g
s
.777 .514 .538 r
.25829 .43121 m .2549 .43047 L .25434 .43522 L p F P
0 g
s
.765 .679 .768 r
.22551 .38424 m .23153 .38589 L p .2388 .3785 L F P
0 g
s
.765 .679 .768 r
.22509 .38346 m .22551 .38424 L p .2388 .3785 L F P
0 g
s
.765 .679 .768 r
.2388 .3785 m .23258 .37652 L .22509 .38346 L p F P
0 g
s
.737 .708 .824 r
.23577 .37391 m .2388 .3785 L p .24644 .36734 L F P
0 g
s
.756 .689 .787 r
.23577 .37391 m .23258 .37652 L .2388 .3785 L closepath p F P
0 g
s
.595 .799 .978 r
.41329 .3682 m .41534 .36965 L p .40178 .36987 L F P
0 g
s
.595 .799 .978 r
.40178 .36987 m .40902 .36824 L .41329 .3682 L p F P
0 g
s
.597 .796 .976 r
.40178 .36987 m .40902 .36824 L .39948 .36822 L closepath p F P
0 g
s
.655 .305 .368 r
.39038 .47238 m .40017 .47249 L .39583 .46882 L p F P
0 g
s
.655 .305 .368 r
.39583 .46882 m .39197 .46878 L .39038 .47238 L p F P
0 g
s
.665 .316 .373 r
.38796 .47231 m .39038 .47238 L .39197 .46878 L p F P
0 g
s
.665 .316 .373 r
.39197 .46878 m .38394 .46856 L .38796 .47231 L p F P
0 g
s
.633 .286 .365 r
.42181 .46867 m .41956 .46874 L .41806 .47238 L p F P
0 g
s
.643 .296 .37 r
.41308 .47244 m .41806 .47238 L .41956 .46874 L p F P
0 g
s
.713 .718 .853 r
.26066 .37085 m .2631 .36949 L .2599 .36575 L p F P
0 g
s
.713 .718 .853 r
.2599 .36575 m .2537 .36894 L .26066 .37085 L p F P
0 g
s
.724 .696 .823 r
.24947 .37125 m .2537 .36894 L .26066 .37085 L p F P
0 g
s
.77 .651 .732 r
.23153 .38589 m .22551 .38424 L .22817 .38974 L closepath p F P
0 g
s
.633 .286 .365 r
.41806 .47238 m .42687 .47213 L .42181 .46867 L p F P
0 g
s
.632 .287 .369 r
.43295 .46831 m .42181 .46867 L .42687 .47213 L p F P
0 g
s
.744 .427 .445 r
.30197 .4573 m .30263 .45741 L .30408 .45354 L p F P
0 g
s
.744 .427 .445 r
.30408 .45354 m .30018 .45292 L .30197 .4573 L p F P
0 g
s
.6 .801 .977 r
.42676 .36781 m .42891 .36935 L p .41534 .36965 L F P
0 g
s
.6 .801 .977 r
.41534 .36965 m .42274 .36793 L .42676 .36781 L p F P
0 g
s
.6 .801 .976 r
.41534 .36965 m .42274 .36793 L .41329 .3682 L closepath p F P
0 g
s
.666 .315 .37 r
.37635 .47195 m .38796 .47231 L .38394 .46856 L p F P
0 g
s
.666 .315 .37 r
.37617 .47177 m .37635 .47195 L p .38394 .46856 L F P
0 g
s
.666 .315 .37 r
.38394 .46856 m .37774 .46836 L .37617 .47177 L p F P
0 g
s
.656 .641 .824 r
.55397 .37129 m .56476 .36772 L .56758 .37283 L p F P
0 g
s
.66 .666 .845 r
.55308 .36985 m .55397 .37129 L .56476 .36772 L p F P
0 g
s
.586 .356 .533 r
.55808 .4296 m .55279 .43083 L .55536 .43506 L p F P
0 g
s
.588 .356 .533 r
.54661 .43707 m .55536 .43506 L .55279 .43083 L p F P
0 g
s
.795 .594 .629 r
.2245 .41175 m .2313 .41369 L .23314 .40824 L p F P
0 g
s
.795 .594 .629 r
.23314 .40824 m .2264 .40627 L .2245 .41175 L p F P
0 g
s
.677 .745 .902 r
.2767 .3684 m .28707 .36454 L .29027 .36776 L p F P
0 g
s
.661 .753 .918 r
.28707 .36454 m .2767 .3684 L .2735 .36493 L p F P
0 g
s
.706 .71 .852 r
.2767 .3684 m .2735 .36493 L .2631 .36949 L p F P
0 g
s
.657 .755 .922 r
.29027 .36776 m .30063 .36445 L .30382 .36743 L p F P
0 g
s
.638 .762 .938 r
.30063 .36445 m .29027 .36776 L .28707 .36454 L p F P
0 g
s
.676 .327 .374 r
.37774 .46836 m .37617 .47177 L .37259 .46812 L closepath p F P
0 g
s
.717 .379 .406 r
.32231 .4639 m .33159 .46499 L .32902 .46083 L p F P
0 g
s
.717 .379 .406 r
.32902 .46083 m .31968 .45976 L .32231 .4639 L p F P
0 g
s
.608 .801 .974 r
.43989 .36707 m .44248 .36896 L p .42891 .36935 L F P
0 g
s
.608 .801 .974 r
.42891 .36935 m .43785 .36717 L .43989 .36707 L p F P
0 g
s
.607 .803 .975 r
.42891 .36935 m .43785 .36717 L .42676 .36781 L closepath p F P
0 g
s
.792 .615 .661 r
.21964 .40431 m .2264 .40627 L .22909 .40055 L p F P
0 g
s
.792 .615 .661 r
.22909 .40055 m .22242 .39855 L .21964 .40431 L p F P
0 g
s
.621 .277 .365 r
.43626 .46815 m .43295 .46831 L .4315 .47198 L p F P
0 g
s
.632 .287 .369 r
.42687 .47213 m .4315 .47198 L .43295 .46831 L p F P
0 g
s
.783 .655 .721 r
.22615 .39249 m .22817 .38974 L .22551 .38424 L p F P
0 g
s
.787 .566 .6 r
.23624 .42066 m .237 .42086 L .23823 .41558 L p F P
0 g
s
.787 .566 .6 r
.23823 .41558 m .23578 .41496 L .23624 .42066 L p F P
0 g
s
.684 .743 .896 r
.2735 .36493 m .2631 .36949 L .2599 .36575 L p F P
0 g
s
.76 .459 .475 r
.27553 .4486 m .28353 .45011 L .28234 .44556 L p F P
0 g
s
.76 .459 .475 r
.28234 .44556 m .27432 .44405 L .27553 .4486 L p F P
0 g
s
.637 .764 .94 r
.30382 .36743 m .31419 .36456 L .31737 .36734 L p F P
0 g
s
.614 .771 .955 r
.31419 .36456 m .30382 .36743 L .30063 .36445 L p F P
0 g
s
.62 .278 .369 r
.44609 .46764 m .43626 .46815 L .44175 .47149 L p F P
0 g
s
.621 .277 .365 r
.4315 .47198 m .44175 .47149 L .43626 .46815 L p F P
0 g
s
.617 .799 .969 r
.44248 .36896 m .45308 .36626 L .45605 .3685 L p F P
0 g
s
.613 .803 .973 r
.45278 .36607 m .45308 .36626 L .44248 .36896 L p F P
0 g
s
.613 .803 .973 r
.44248 .36896 m .43989 .36707 L .45278 .36607 L p F P
0 g
s
.785 .522 .539 r
.2509 .43439 m .25434 .43522 L .2549 .43047 L p F P
0 g
s
.785 .522 .539 r
.2549 .43047 m .25088 .4295 L .2509 .43439 L p F P
0 g
s
.675 .321 .366 r
.37609 .47194 m .37617 .47177 L .37259 .46812 L p F P
0 g
s
.675 .321 .366 r
.36541 .47138 m .37609 .47194 L p .37259 .46812 L F P
0 g
s
.675 .321 .366 r
.36269 .46864 m .36541 .47138 L p .37259 .46812 L F P
0 g
s
.675 .321 .366 r
.37259 .46812 m .36318 .46765 L .36269 .46864 L p F P
0 g
s
.726 .41 .443 r
.31917 .45869 m .31968 .45976 L .31883 .45966 L closepath p F P
0 g
s
.598 .28 .402 r
.48532 .46028 m .48498 .46153 L .48298 .46055 L closepath p F P
0 g
s
.601 .283 .403 r
.48424 .46422 m .48498 .46153 L .48298 .46055 L p F P
0 g
s
.601 .283 .403 r
.47174 .46559 m .48424 .46422 L p .48298 .46055 L F P
0 g
s
.627 .794 .963 r
.45605 .3685 m .46668 .36567 L .46963 .368 L p F P
0 g
s
.603 .814 .981 r
.46668 .36567 m .45605 .3685 L .45308 .36626 L p F P
0 g
s
.745 .425 .441 r
.29357 .45592 m .30197 .4573 L .30018 .45292 L p F P
0 g
s
.745 .425 .441 r
.30018 .45292 m .29176 .45155 L .29357 .45592 L p F P
0 g
s
.583 .31 .467 r
.52282 .44771 m .52724 .4498 L .52243 .4507 L closepath p F P
0 g
s
.774 .491 .507 r
.25895 .44081 m .26656 .44246 L .26596 .43774 L p F P
0 g
s
.774 .491 .507 r
.26596 .43774 m .25834 .4361 L .25895 .44081 L p F P
0 g
s
.637 .787 .954 r
.46963 .368 m .48028 .36502 L .4832 .3675 L p F P
0 g
s
.618 .807 .972 r
.48028 .36502 m .46963 .368 L .46668 .36567 L p F P
0 g
s
.787 .544 .569 r
.23642 .42593 m .24366 .42771 L .24422 .42265 L p F P
0 g
s
.787 .544 .569 r
.24422 .42265 m .237 .42086 L .23642 .42593 L p F P
0 g
s
.618 .772 .954 r
.31737 .36734 m .32775 .36479 L .33091 .36738 L p F P
0 g
s
.592 .779 .969 r
.32775 .36479 m .31737 .36734 L .31419 .36456 L p F P
0 g
s
.59 .272 .399 r
.49655 .46263 m .4976 .45868 L .48532 .46028 L p F P
0 g
s
.59 .272 .399 r
.48968 .46353 m .49655 .46263 L p .48532 .46028 L F P
0 g
s
.59 .272 .399 r
.48532 .46028 m .48498 .46153 L .48968 .46353 L p F P
0 g
s
.783 .655 .721 r
.21959 .39045 m .22615 .39249 L p .22551 .38424 L F P
0 g
s
.788 .637 .693 r
.21571 .39656 m .22242 .39855 L .22615 .39249 L p F P
0 g
s
.788 .637 .693 r
.22615 .39249 m .21959 .39045 L .21571 .39656 L p F P
0 g
s
.58 .287 .435 r
.52164 .45486 m .52243 .4507 L .51051 .45271 L p F P
0 g
s
.58 .287 .435 r
.51051 .45271 m .50971 .45688 L .52164 .45486 L p F P
0 g
s
.591 .296 .437 r
.50582 .45747 m .50971 .45688 L .51051 .45271 L p F P
0 g
s
.66 .673 .852 r
.55114 .36684 m .55308 .36985 L .56418 .36679 L p F P
0 g
s
.66 .666 .845 r
.56476 .36772 m .56418 .36679 L .55308 .36985 L p F P
0 g
s
.716 .705 .839 r
.2537 .36894 m .24644 .36734 L .24947 .37125 L closepath p F P
0 g
s
.646 .776 .943 r
.4832 .3675 m .49388 .36437 L .49678 .36702 L p F P
0 g
s
.631 .799 .963 r
.49388 .36437 m .4832 .3675 L .48028 .36502 L p F P
0 g
s
.597 .433 .631 r
.58999 .40519 m .58984 .40423 L .57892 .40747 L p F P
0 g
s
.597 .433 .631 r
.57892 .40747 m .57917 .40914 L .58999 .40519 L p F P
0 g
s
.796 .573 .598 r
.23012 .41895 m .23624 .42066 L .23578 .41496 L p F P
0 g
s
.796 .573 .598 r
.23578 .41496 m .2313 .41369 L .23012 .41895 L p F P
0 g
s
.685 .332 .371 r
.36318 .46765 m .36269 .46864 L .36168 .46755 L closepath p F P
0 g
s
.61 .268 .365 r
.45202 .46723 m .44609 .46764 L .4447 .47133 L p F P
0 g
s
.62 .278 .369 r
.44175 .47149 m .4447 .47133 L .44609 .46764 L p F P
0 g
s
.654 .762 .929 r
.49678 .36702 m .50748 .36377 L .51036 .36665 L p F P
0 g
s
.643 .787 .951 r
.50748 .36377 m .49678 .36702 L .49388 .36437 L p F P
0 g
s
.685 .332 .37 r
.35487 .47069 m .35132 .4668 L .36168 .46755 L p F P
0 g
s
.685 .332 .37 r
.36144 .47116 m .35487 .47069 L p .36168 .46755 L F P
0 g
s
.685 .332 .37 r
.36168 .46755 m .36269 .46864 L .36144 .47116 L p F P
0 g
s
.623 .513 .708 r
.58698 .39131 m .5846 .3921 L .587 .39138 L closepath p F P
0 g
s
.567 .788 .982 r
.34131 .36507 m .33091 .36738 L .32775 .36479 L p F P
0 g
s
.601 .78 .966 r
.33091 .36738 m .34131 .36507 L .34446 .36749 L p F P
0 g
s
.659 .744 .913 r
.51036 .36665 m .52109 .36328 L .52395 .36643 L p F P
0 g
s
.652 .771 .936 r
.52109 .36328 m .51036 .36665 L .50748 .36377 L p F P
0 g
s
.648 .611 .799 r
.58123 .37521 m .5784 .36935 L .56758 .37283 L p F P
0 g
s
.648 .611 .799 r
.57779 .37632 m .58123 .37521 L p .56758 .37283 L F P
0 g
s
.653 .641 .825 r
.5784 .36935 m .56758 .37283 L .56476 .36772 L p F P
0 g
s
.719 .379 .403 r
.31713 .46328 m .32231 .4639 L .31968 .45976 L p F P
0 g
s
.719 .379 .403 r
.31968 .45976 m .31883 .45966 L .31713 .46328 L p F P
0 g
s
.577 .348 .532 r
.56925 .4316 m .56931 .42675 L .55808 .4296 L p F P
0 g
s
.577 .348 .532 r
.55808 .4296 m .55801 .43444 L .56925 .4316 L p F P
0 g
s
.586 .356 .533 r
.55536 .43506 m .55801 .43444 L .55808 .4296 L p F P
0 g
s
.594 .425 .623 r
.59064 .40996 m .58999 .40519 L .57917 .40914 L p F P
0 g
s
.594 .425 .623 r
.57917 .40914 m .57971 .41321 L .59064 .40996 L p F P
0 g
s
.609 .269 .369 r
.45902 .46672 m .45774 .47027 L .45202 .46723 L closepath p F P
0 g
s
.61 .268 .365 r
.45767 .47045 m .45774 .47027 L .45202 .46723 L p F P
0 g
s
.61 .268 .365 r
.4447 .47133 m .45767 .47045 L p .45202 .46723 L F P
0 g
s
.575 .324 .499 r
.55536 .43506 m .54661 .43707 L .54629 .44166 L p F P
0 g
s
.729 .391 .408 r
.31322 .46274 m .31713 .46328 L .31883 .45966 L p F P
0 g
s
.729 .391 .408 r
.31883 .45966 m .31079 .45855 L .31322 .46274 L p F P
0 g
s
.786 .523 .538 r
.24367 .43261 m .2509 .43439 L .25088 .4295 L p F P
0 g
s
.786 .523 .538 r
.25088 .4295 m .24366 .42771 L .24367 .43261 L p F P
0 g
s
.662 .724 .895 r
.52395 .36643 m .53469 .36297 L .53754 .36646 L p F P
0 g
s
.658 .751 .919 r
.53469 .36297 m .52395 .36643 L .52109 .36328 L p F P
0 g
s
.776 .665 .74 r
.22509 .38346 m .22464 .38396 L .22551 .38424 L closepath p F P
0 g
s
.783 .655 .721 r
.22551 .38424 m .22464 .38396 L .21959 .39045 L p F P
0 g
s
.584 .789 .977 r
.35588 .36608 m .35802 .36762 L p .34446 .36749 L F P
0 g
s
.584 .789 .977 r
.34446 .36749 m .35253 .36584 L .35588 .36608 L p F P
0 g
s
.551 .789 .987 r
.35253 .36584 m .34446 .36749 L .34131 .36507 L p F P
0 g
s
.759 .668 .761 r
.22196 .37794 m .22595 .37449 L .23258 .37652 L p F P
0 g
s
.759 .668 .761 r
.23258 .37652 m .22509 .38346 L .22196 .37794 L p F P
0 g
s
.751 .692 .795 r
.23258 .37652 m .23577 .37391 L .23257 .3694 L p F P
0 g
s
.751 .692 .795 r
.23257 .3694 m .22595 .37449 L .23258 .37652 L p F P
0 g
s
.775 .672 .75 r
.22464 .38396 m .22509 .38346 L .22196 .37794 L p F P
0 g
s
.713 .709 .845 r
.2537 .36894 m .2599 .36575 L p .24627 .36713 L F P
0 g
s
.713 .709 .845 r
.24627 .36713 m .24644 .36734 L .2537 .36894 L p F P
0 g
s
.58 .372 .563 r
.58039 .42371 m .58019 .4186 L .56911 .42165 L p F P
0 g
s
.58 .372 .563 r
.56911 .42165 m .56931 .42675 L .58039 .42371 L p F P
0 g
s
.775 .672 .75 r
.22196 .37794 m .21826 .38185 L .22464 .38396 L p F P
0 g
s
.783 .66 .727 r
.21297 .38843 m .21959 .39045 L .22464 .38396 L p F P
0 g
s
.783 .66 .727 r
.22464 .38396 m .21826 .38185 L .21297 .38843 L p F P
0 g
s
.629 .549 .745 r
.58409 .38233 m .58465 .38391 L .59541 .38043 L p F P
0 g
s
.622 .527 .725 r
.59776 .3879 m .59541 .38043 L .58465 .38391 L p F P
0 g
s
.622 .527 .725 r
.58936 .39062 m .59776 .3879 L p .58465 .38391 L F P
0 g
s
.622 .527 .725 r
.58465 .38391 m .58698 .39131 L .58936 .39062 L p F P
0 g
s
.688 .333 .367 r
.34645 .47006 m .35487 .47069 L .35132 .4668 L p F P
0 g
s
.688 .333 .367 r
.35132 .4668 m .34825 .46657 L .34645 .47006 L p F P
0 g
s
.737 .708 .824 r
.24644 .36734 m .24609 .36723 L .23577 .37391 L p F P
0 g
s
.732 .693 .814 r
.24609 .36723 m .23577 .37391 L .23257 .3694 L p F P
0 g
s
.643 .59 .78 r
.58123 .37521 m .57779 .37632 L .58126 .37527 L closepath p F P
0 g
s
.617 .509 .709 r
.58698 .39131 m .58936 .39062 L .587 .39138 L closepath p F P
0 g
s
.612 .493 .693 r
.5994 .39457 m .58863 .39804 L .587 .39138 L p F P
0 g
s
.612 .493 .693 r
.59784 .38818 m .5994 .39457 L p .587 .39138 L F P
0 g
s
.612 .493 .693 r
.587 .39138 m .58936 .39062 L .59784 .38818 L p F P
0 g
s
.661 .729 .899 r
.54831 .36295 m .53754 .36646 L .53469 .36297 L p F P
0 g
s
.662 .701 .875 r
.53754 .36646 m .54831 .36295 L .55114 .36684 L p F P
0 g
s
.599 .259 .365 r
.46947 .4658 m .45902 .46672 L .45774 .47027 L p F P
0 g
s
.629 .549 .745 r
.59541 .38043 m .59493 .37909 L .58409 .38233 L p F P
0 g
s
.634 .571 .766 r
.58126 .37527 m .58409 .38233 L .59493 .37909 L p F P
0 g
s
.572 .301 .467 r
.54575 .44604 m .54629 .44166 L .53472 .44409 L p F P
0 g
s
.572 .301 .467 r
.53472 .44409 m .53417 .44847 L .54575 .44604 L p F P
0 g
s
.59 .271 .398 r
.48498 .46153 m .48968 .46353 L .48424 .46422 L closepath p F P
0 g
s
.762 .459 .473 r
.27008 .44755 m .27553 .4486 L .27432 .44405 L p F P
0 g
s
.762 .459 .473 r
.27432 .44405 m .27136 .44349 L .27008 .44755 L p F P
0 g
s
.746 .425 .44 r
.28587 .45465 m .29357 .45592 L .29176 .45155 L p F P
0 g
s
.746 .425 .44 r
.29176 .45155 m .2874 .45083 L .28587 .45465 L p F P
0 g
s
.698 .345 .373 r
.34464 .46989 m .34645 .47006 L .34825 .46657 L p F P
0 g
s
.698 .345 .373 r
.34825 .46657 m .34134 .46594 L .34464 .46989 L p F P
0 g
s
.795 .595 .631 r
.21769 .40981 m .2245 .41175 L .2264 .40627 L p F P
0 g
s
.795 .595 .631 r
.2264 .40627 m .21964 .40431 L .21769 .40981 L p F P
0 g
s
.57 .796 .984 r
.37082 .3672 m .37158 .36771 L p .35802 .36762 L F P
0 g
s
.57 .796 .984 r
.35802 .36762 m .36254 .36674 L .37082 .3672 L p F P
0 g
s
.578 .785 .978 r
.35802 .36762 m .36254 .36674 L .35588 .36608 L closepath p F P
0 g
s
.678 .324 .366 r
.36269 .46864 m .36541 .47138 L .36144 .47116 L closepath p F P
0 g
s
.797 .574 .6 r
.2233 .41701 m .23012 .41895 L .2313 .41369 L p F P
0 g
s
.797 .574 .6 r
.2313 .41369 m .2245 .41175 L .2233 .41701 L p F P
0 g
s
.791 .617 .665 r
.21466 .40286 m .21964 .40431 L .22242 .39855 L p F P
0 g
s
.791 .617 .665 r
.21393 .40012 m .21466 .40286 L p .22242 .39855 L F P
0 g
s
.791 .617 .665 r
.22242 .39855 m .21571 .39656 L .21393 .40012 L p F P
0 g
s
.775 .492 .506 r
.25337 .43959 m .25895 .44081 L .25834 .4361 L p F P
0 g
s
.775 .492 .506 r
.25834 .4361 m .25434 .43522 L .25337 .43959 L p F P
0 g
s
.594 .8 .978 r
.41329 .3682 m .4123 .3675 L .40902 .36824 L closepath p F P
0 g
s
.596 .797 .976 r
.40925 .36564 m .4123 .3675 L .40902 .36824 L p F P
0 g
s
.596 .797 .976 r
.39872 .36768 m .40925 .36564 L p .40902 .36824 L F P
0 g
s
.596 .797 .976 r
.40902 .36824 m .39948 .36822 L .39872 .36768 L p F P
0 g
s
.578 .262 .397 r
.50582 .45747 m .4976 .45868 L .49655 .46263 L p F P
0 g
s
.594 .796 .977 r
.39948 .36822 m .39872 .36768 L .3964 .36819 L closepath p F P
0 g
s
.599 .801 .977 r
.42274 .36793 m .41329 .3682 L .4123 .3675 L p F P
0 g
s
.596 .791 .974 r
.39564 .36576 m .39872 .36768 L .3964 .36819 L p F P
0 g
s
.596 .791 .974 r
.38515 .36774 m .39564 .36576 L p .3964 .36819 L F P
0 g
s
.596 .791 .974 r
.3964 .36819 m .38528 .36783 L .38515 .36774 L p F P
0 g
s
.66 .673 .852 r
.56418 .36679 m .56193 .36332 L .55114 .36684 L p F P
0 g
s
.661 .703 .878 r
.56193 .36332 m .55114 .36684 L .54831 .36295 L p F P
0 g
s
.771 .469 .476 r
.26766 .44704 m .27008 .44755 L .27136 .44349 L p F P
0 g
s
.771 .469 .476 r
.27136 .44349 m .26656 .44246 L .26766 .44704 L p F P
0 g
s
.562 .801 .989 r
.37158 .36771 m .37339 .36737 L .38478 .36782 L p F P
0 g
s
.568 .794 .984 r
.37158 .36771 m .37339 .36737 L .37082 .3672 L closepath p F P
0 g
s
.789 .546 .569 r
.23614 .42585 m .23642 .42593 L .237 .42086 L p F P
0 g
s
.789 .546 .569 r
.237 .42086 m .23624 .42066 L .23614 .42585 L p F P
0 g
s
.727 .386 .401 r
.30441 .46149 m .31322 .46274 L .31079 .45855 L p F P
0 g
s
.727 .386 .401 r
.30234 .45799 m .30441 .46149 L p .31079 .45855 L F P
0 g
s
.727 .386 .401 r
.31079 .45855 m .30263 .45741 L .30234 .45799 L p F P
0 g
s
.615 .502 .702 r
.58936 .39062 m .59776 .3879 L .59784 .38818 L closepath p F P
0 g
s
.583 .396 .594 r
.59113 .41536 m .59064 .40996 L .57971 .41321 L p F P
0 g
s
.583 .396 .594 r
.57971 .41321 m .58019 .4186 L .59113 .41536 L p F P
0 g
s
.599 .802 .977 r
.42676 .36781 m .42589 .3672 L .42274 .36793 L closepath p F P
0 g
s
.599 .801 .977 r
.42286 .36536 m .42589 .3672 L .42274 .36793 L p F P
0 g
s
.599 .801 .977 r
.4123 .3675 m .42286 .36536 L p .42274 .36793 L F P
0 g
s
.697 .339 .364 r
.33488 .46895 m .34464 .46989 L .34134 .46594 L p F P
0 g
s
.697 .339 .364 r
.33243 .46604 m .33488 .46895 L p .34134 .46594 L F P
0 g
s
.697 .339 .364 r
.34134 .46594 m .33292 .46514 L .33243 .46604 L p F P
0 g
s
.755 .436 .444 r
.2852 .45453 m .28587 .45465 L .2874 .45083 L p F P
0 g
s
.755 .436 .444 r
.2874 .45083 m .28353 .45011 L .2852 .45453 L p F P
0 g
s
.797 .553 .569 r
.22956 .42401 m .23614 .42585 L .23624 .42066 L p F P
0 g
s
.797 .553 .569 r
.23624 .42066 m .23012 .41895 L .22956 .42401 L p F P
0 g
s
.599 .457 .659 r
.60062 .40077 m .5994 .39457 L .58863 .39804 L p F P
0 g
s
.599 .457 .659 r
.58863 .39804 m .58984 .40423 L .60062 .40077 L p F P
0 g
s
.786 .639 .699 r
.21259 .39563 m .21571 .39656 L .21959 .39045 L p F P
0 g
s
.786 .639 .699 r
.211 .39136 m .21259 .39563 L p .21959 .39045 L F P
0 g
s
.786 .639 .699 r
.21959 .39045 m .21297 .38843 L .211 .39136 L p F P
0 g
s
.597 .791 .973 r
.38528 .36783 m .38515 .36774 L .38478 .36782 L closepath p F P
0 g
s
.585 .81 .985 r
.38205 .36575 m .37339 .36737 L .38478 .36782 L p F P
0 g
s
.585 .81 .985 r
.38478 .36782 m .38515 .36774 L .38205 .36575 L p F P
0 g
s
.606 .804 .976 r
.43785 .36717 m .42676 .36781 L .42589 .3672 L p F P
0 g
s
.596 .256 .363 r
.47174 .46559 m .47136 .46663 L .46947 .4658 L closepath p F P
0 g
s
.599 .259 .365 r
.47041 .46931 m .47136 .46663 L .46947 .4658 L p F P
0 g
s
.599 .259 .365 r
.45804 .47042 m .47041 .46931 L p .46947 .4658 L F P
0 g
s
.599 .259 .365 r
.45774 .47027 m .45804 .47042 L p .46947 .4658 L F P
0 g
s
.569 .276 .43 r
.52724 .4498 m .52243 .4507 L .52164 .45486 L p F P
0 g
s
.634 .571 .766 r
.59208 .37191 m .58468 .37416 L .58126 .37527 L p F P
0 g
s
.634 .571 .766 r
.59493 .37909 m .59208 .37191 L p .58126 .37527 L F P
0 g
s
.639 .588 .781 r
.58123 .37521 m .58468 .37416 L .58126 .37527 L closepath p F P
0 g
s
.644 .609 .8 r
.58468 .37416 m .58123 .37521 L .5784 .36935 L p F P
0 g
s
.515 .81 .999 r
.39564 .36576 m .38515 .36774 L .38205 .36575 L p F P
0 g
s
.661 .753 .918 r
.2735 .36493 m .28386 .36151 L .28707 .36454 L p F P
0 g
s
.643 .76 .933 r
.28386 .36151 m .2735 .36493 L .27028 .36165 L p F P
0 g
s
.684 .743 .896 r
.2599 .36575 m .27028 .36165 L .2735 .36493 L p F P
0 g
s
.587 .247 .36 r
.48295 .46795 m .48424 .46422 L .47174 .46559 L p F P
0 g
s
.587 .247 .36 r
.47661 .46865 m .48295 .46795 L p .47174 .46559 L F P
0 g
s
.587 .247 .36 r
.47174 .46559 m .47136 .46663 L .47661 .46865 L p F P
0 g
s
.67 .75 .911 r
.27028 .36165 m .2599 .36575 L .25668 .36219 L p F P
0 g
s
.713 .709 .845 r
.2599 .36575 m .25668 .36219 L .24627 .36713 L p F P
0 g
s
.786 .523 .538 r
.23644 .43082 m .24367 .43261 L .24366 .42771 L p F P
0 g
s
.786 .523 .538 r
.24366 .42771 m .23642 .42593 L .23644 .43082 L p F P
0 g
s
.638 .762 .938 r
.28707 .36454 m .29743 .36164 L .30063 .36445 L p F P
0 g
s
.616 .768 .953 r
.29743 .36164 m .28707 .36454 L .28386 .36151 L p F P
0 g
s
.566 .794 .985 r
.37893 .36397 m .38205 .36575 L .37339 .36737 L p F P
0 g
s
.566 .794 .985 r
.36846 .3656 m .37893 .36397 L p .37339 .36737 L F P
0 g
s
.566 .794 .985 r
.37339 .36737 m .37082 .3672 L .36846 .3656 L p F P
0 g
s
.784 .501 .508 r
.25143 .43913 m .25337 .43959 L .25434 .43522 L p F P
0 g
s
.784 .501 .508 r
.25434 .43522 m .2509 .43439 L .25143 .43913 L p F P
0 g
s
.73 .713 .835 r
.24627 .36713 m .24609 .36723 L .24644 .36734 L closepath p F P
0 g
s
.516 .816 .999 r
.40925 .36564 m .39872 .36768 L .39564 .36576 L p F P
0 g
s
.653 .641 .825 r
.56476 .36772 m .57557 .36425 L .5784 .36935 L p F P
0 g
s
.657 .667 .848 r
.56418 .36679 m .56476 .36772 L .57557 .36425 L p F P
0 g
s
.723 .72 .847 r
.24609 .36723 m .24627 .36713 L .24304 .36328 L p F P
0 g
s
.723 .72 .847 r
.24304 .36328 m .23982 .36508 L .24609 .36723 L p F P
0 g
s
.732 .693 .814 r
.23257 .3694 m .23982 .36508 L .24609 .36723 L p F P
0 g
s
.695 .74 .886 r
.25668 .36219 m .24627 .36713 L .24304 .36328 L p F P
0 g
s
.57 .796 .984 r
.37082 .3672 m .36846 .3656 L .36254 .36674 L closepath p F P
0 g
s
.574 .324 .5 r
.55801 .43444 m .5579 .43617 L .55536 .43506 L closepath p F P
0 g
s
.575 .324 .499 r
.55771 .43904 m .5579 .43617 L .55536 .43506 L p F P
0 g
s
.575 .324 .499 r
.54629 .44166 m .55771 .43904 L p .55536 .43506 L F P
0 g
s
.606 .802 .975 r
.43989 .36707 m .43949 .36678 L .43785 .36717 L closepath p F P
0 g
s
.606 .804 .976 r
.43648 .36493 m .43949 .36678 L .43785 .36717 L p F P
0 g
s
.606 .804 .976 r
.42589 .3672 m .43648 .36493 L p .43785 .36717 L F P
0 g
s
.757 .435 .44 r
.27723 .453 m .2852 .45453 L .28353 .45011 L p F P
0 g
s
.757 .435 .44 r
.28353 .45011 m .27553 .4486 L .27723 .453 L p F P
0 g
s
.707 .351 .369 r
.33292 .46514 m .33243 .46604 L .33159 .46499 L closepath p F P
0 g
s
.598 .799 .976 r
.4501 .36436 m .45278 .36607 L .43989 .36707 L p F P
0 g
s
.598 .799 .976 r
.43989 .36707 m .43949 .36678 L .4501 .36436 L p F P
0 g
s
.757 .678 .775 r
.22595 .37449 m .22196 .37794 L .21879 .37279 L p F P
0 g
s
.77 .675 .758 r
.21826 .38185 m .22196 .37794 L .21879 .37279 L p F P
0 g
s
.772 .469 .474 r
.26006 .44538 m .26766 .44704 L .26656 .44246 L p F P
0 g
s
.772 .469 .474 r
.26656 .44246 m .25895 .44081 L .26006 .44538 L p F P
0 g
s
.614 .771 .955 r
.30063 .36445 m .31099 .36197 L .31419 .36456 L p F P
0 g
s
.589 .776 .969 r
.31099 .36197 m .30063 .36445 L .29743 .36164 L p F P
0 g
s
.523 .821 .999 r
.42286 .36536 m .4123 .3675 L .40925 .36564 L p F P
0 g
s
.576 .261 .398 r
.50971 .45688 m .50928 .45858 L .50582 .45747 L closepath p F P
0 g
s
.578 .262 .397 r
.50869 .46084 m .50928 .45858 L .50582 .45747 L p F P
0 g
s
.578 .262 .397 r
.49655 .46263 m .50869 .46084 L p .50582 .45747 L F P
0 g
s
.744 .694 .803 r
.22595 .37449 m .23257 .3694 L .22936 .36513 L p F P
0 g
s
.744 .694 .803 r
.22936 .36513 m .21913 .37251 L .22595 .37449 L p F P
0 g
s
.757 .678 .775 r
.21879 .37279 m .21913 .37251 L .22595 .37449 L p F P
0 g
s
.708 .351 .369 r
.32543 .4679 m .32231 .4639 L .33159 .46499 L p F P
0 g
s
.708 .351 .369 r
.33103 .46856 m .32543 .4679 L p .33159 .46499 L F P
0 g
s
.708 .351 .369 r
.33159 .46499 m .33243 .46604 L .33103 .46856 L p F P
0 g
s
.63 .261 .324 r
.41308 .47244 m .40436 .47252 L .40327 .47462 L p F P
0 g
s
.641 .273 .33 r
.40436 .47252 m .40327 .47462 L .40017 .47249 L closepath p F P
0 g
s
.737 .397 .406 r
.30263 .45741 m .30234 .45799 L .30197 .4573 L closepath p F P
0 g
s
.641 .269 .323 r
.40258 .47593 m .40327 .47462 L .40017 .47249 L p F P
0 g
s
.641 .269 .323 r
.39286 .47582 m .40258 .47593 L p .40017 .47249 L F P
0 g
s
.641 .269 .323 r
.3897 .47361 m .39286 .47582 L p .40017 .47249 L F P
0 g
s
.641 .269 .323 r
.40017 .47249 m .39038 .47238 L .3897 .47361 L p F P
0 g
s
.63 .264 .33 r
.41806 .47238 m .41686 .47479 L .41308 .47244 L closepath p F P
0 g
s
.63 .261 .324 r
.41634 .47583 m .41686 .47479 L .41308 .47244 L p F P
0 g
s
.63 .261 .324 r
.40532 .47592 m .41634 .47583 L p .41308 .47244 L F P
0 g
s
.63 .261 .324 r
.40327 .47462 m .40532 .47592 L p .41308 .47244 L F P
0 g
s
.569 .276 .43 r
.53342 .45265 m .53363 .45149 L .52724 .4498 L p F P
0 g
s
.569 .276 .43 r
.52164 .45486 m .53342 .45265 L p .52724 .4498 L F P
0 g
s
.568 .277 .433 r
.53417 .44847 m .53363 .45149 L .52724 .4498 L closepath p F P
0 g
s
.658 .675 .855 r
.56193 .36332 m .56418 .36679 L .57511 .3635 L p F P
0 g
s
.657 .667 .848 r
.57557 .36425 m .57511 .3635 L .56418 .36679 L p F P
0 g
s
.737 .397 .405 r
.29587 .46016 m .29357 .45592 L .30197 .4573 L p F P
0 g
s
.737 .397 .405 r
.30085 .46098 m .29587 .46016 L p .30197 .4573 L F P
0 g
s
.737 .397 .405 r
.30197 .4573 m .30234 .45799 L .30085 .46098 L p F P
0 g
s
.619 .252 .324 r
.42687 .47213 m .41806 .47238 L .41686 .47479 L p F P
0 g
s
.652 .281 .329 r
.39038 .47238 m .3897 .47361 L .38796 .47231 L closepath p F P
0 g
s
.77 .675 .758 r
.21879 .37279 m .21182 .37976 L .21826 .38185 L p F P
0 g
s
.779 .662 .733 r
.20936 .38732 m .21297 .38843 L .21826 .38185 L p F P
0 g
s
.779 .662 .733 r
.20796 .38431 m .20936 .38732 L p .21826 .38185 L F P
0 g
s
.779 .662 .733 r
.21826 .38185 m .21182 .37976 L .20796 .38431 L p F P
0 g
s
.534 .826 .999 r
.43648 .36493 m .42589 .3672 L .42286 .36536 L p F P
0 g
s
.576 .786 .978 r
.36532 .36371 m .36846 .3656 L .36254 .36674 L p F P
0 g
s
.576 .786 .978 r
.35488 .36536 m .36532 .36371 L p .36254 .36674 L F P
0 g
s
.576 .786 .978 r
.36254 .36674 m .35588 .36608 L .35488 .36536 L p F P
0 g
s
.652 .281 .328 r
.38106 .47551 m .37635 .47195 L .38796 .47231 L p F P
0 g
s
.652 .281 .328 r
.38853 .47575 m .38106 .47551 L p .38796 .47231 L F P
0 g
s
.652 .281 .328 r
.38796 .47231 m .3897 .47361 L .38853 .47575 L p F P
0 g
s
.644 .609 .8 r
.59201 .37176 m .58468 .37416 L p .5784 .36935 L F P
0 g
s
.64 .594 .786 r
.58468 .37416 m .59201 .37176 L .59208 .37191 L closepath p F P
0 g
s
.795 .595 .631 r
.21587 .40928 m .21769 .40981 L .21964 .40431 L p F P
0 g
s
.795 .595 .631 r
.21964 .40431 m .21466 .40286 L .21587 .40928 L p F P
0 g
s
.55 .829 .997 r
.4501 .36436 m .43949 .36678 L .43648 .36493 L p F P
0 g
s
.592 .779 .969 r
.31419 .36456 m .32457 .36239 L .32775 .36479 L p F P
0 g
s
.556 .785 .984 r
.32457 .36239 m .31419 .36456 L .31099 .36197 L p F P
0 g
s
.564 .316 .498 r
.56898 .43621 m .56925 .4316 L .55801 .43444 L p F P
0 g
s
.564 .316 .498 r
.56357 .43758 m .56898 .43621 L p .55801 .43444 L F P
0 g
s
.564 .316 .498 r
.55801 .43444 m .5579 .43617 L .56357 .43758 L p F P
0 g
s
.618 .253 .328 r
.4315 .47198 m .43048 .47412 L .42687 .47213 L closepath p F P
0 g
s
.619 .252 .324 r
.42984 .47545 m .43048 .47412 L .42687 .47213 L p F P
0 g
s
.619 .252 .324 r
.41859 .47577 m .42984 .47545 L p .42687 .47213 L F P
0 g
s
.619 .252 .324 r
.41686 .47479 m .41859 .47577 L p .42687 .47213 L F P
0 g
s
.668 .318 .37 r
.37617 .47177 m .37635 .47195 L .37609 .47194 L closepath p F P
0 g
s
.589 .428 .632 r
.60087 .40243 m .60062 .40077 L .58984 .40423 L p F P
0 g
s
.589 .428 .632 r
.58984 .40423 m .58999 .40519 L .60087 .40243 L p F P
0 g
s
.785 .502 .506 r
.24421 .43734 m .25143 .43913 L .2509 .43439 L p F P
0 g
s
.785 .502 .506 r
.2509 .43439 m .24367 .43261 L .24421 .43734 L p F P
0 g
s
.797 .575 .6 r
.21646 .41508 m .2233 .41701 L .2245 .41175 L p F P
0 g
s
.797 .575 .6 r
.2245 .41175 m .21769 .40981 L .21646 .41508 L p F P
0 g
s
.603 .814 .981 r
.4655 .36487 m .46668 .36567 L p .45308 .36626 L F P
0 g
s
.603 .814 .981 r
.45308 .36626 m .45474 .36585 L .4655 .36487 L p F P
0 g
s
.598 .821 .985 r
.45308 .36626 m .45474 .36585 L .45278 .36607 L closepath p F P
0 g
s
.587 .246 .359 r
.47136 .46663 m .47661 .46865 L .47041 .46931 L closepath p F P
0 g
s
.567 .34 .531 r
.58036 .42856 m .58039 .42371 L .56931 .42675 L p F P
0 g
s
.567 .34 .531 r
.56931 .42675 m .56925 .4316 L .58036 .42856 L p F P
0 g
s
.726 .702 .828 r
.23982 .36508 m .23257 .3694 L .22936 .36513 L p F P
0 g
s
.792 .618 .665 r
.21571 .39656 m .21259 .39563 L .21393 .40012 L closepath p F P
0 g
s
.613 .818 .979 r
.46668 .36567 m .4744 .36365 L .4655 .36487 L closepath p F P
0 g
s
.618 .807 .972 r
.47786 .36326 m .48028 .36502 L p .46668 .36567 L F P
0 g
s
.618 .807 .972 r
.46668 .36567 m .4744 .36365 L .47786 .36326 L p F P
0 g
s
.607 .241 .323 r
.44175 .47149 m .4315 .47198 L .43048 .47412 L p F P
0 g
s
.567 .252 .395 r
.52065 .45883 m .52164 .45486 L .50971 .45688 L p F P
0 g
s
.567 .252 .395 r
.51444 .45988 m .52065 .45883 L p .50971 .45688 L F P
0 g
s
.567 .252 .395 r
.50971 .45688 m .50928 .45858 L .51444 .45988 L p F P
0 g
s
.654 .279 .322 r
.37416 .47526 m .38106 .47551 L .37635 .47195 L p F P
0 g
s
.654 .279 .322 r
.37635 .47195 m .37609 .47194 L .37416 .47526 L p F P
0 g
s
.665 .292 .329 r
.36978 .47504 m .37416 .47526 L .37609 .47194 L p F P
0 g
s
.665 .292 .329 r
.37609 .47194 m .36541 .47138 L .36978 .47504 L p F P
0 g
s
.631 .799 .963 r
.48028 .36502 m .49097 .36207 L .49388 .36437 L p F P
0 g
s
.623 .81 .972 r
.49008 .36147 m .49097 .36207 L .48028 .36502 L p F P
0 g
s
.623 .81 .972 r
.48028 .36502 m .47786 .36326 L .49008 .36147 L p F P
0 g
s
.643 .787 .951 r
.49388 .36437 m .5046 .36127 L .50748 .36377 L p F P
0 g
s
.628 .809 .969 r
.5046 .36127 m .49388 .36437 L .49097 .36207 L p F P
0 g
s
.731 .389 .402 r
.30234 .45799 m .30441 .46149 L .30085 .46098 L closepath p F P
0 g
s
.586 .42 .624 r
.60143 .40651 m .60087 .40243 L .58999 .40519 L p F P
0 g
s
.586 .42 .624 r
.58999 .40519 m .59064 .40996 L .60143 .40651 L p F P
0 g
s
.561 .291 .464 r
.55719 .44342 m .55771 .43904 L .54629 .44166 L p F P
0 g
s
.561 .291 .464 r
.54629 .44166 m .54575 .44604 L .55719 .44342 L p F P
0 g
s
.652 .771 .936 r
.50748 .36377 m .51822 .36053 L .52109 .36328 L p F P
0 g
s
.641 .796 .957 r
.51822 .36053 m .50748 .36377 L .5046 .36127 L p F P
0 g
s
.798 .554 .569 r
.22272 .42209 m .22956 .42401 L .23012 .41895 L p F P
0 g
s
.798 .554 .569 r
.23012 .41895 m .2233 .41701 L .22272 .42209 L p F P
0 g
s
.575 .236 .358 r
.48968 .46353 m .48424 .46422 L .48295 .46795 L p F P
0 g
s
.584 .789 .977 r
.35588 .36608 m .35488 .36536 L .35253 .36584 L closepath p F P
0 g
s
.597 .821 .986 r
.45474 .36585 m .45278 .36607 L .4501 .36436 L p F P
0 g
s
.658 .751 .919 r
.52109 .36328 m .53185 .35992 L .53469 .36297 L p F P
0 g
s
.651 .778 .941 r
.53185 .35992 m .52109 .36328 L .51822 .36053 L p F P
0 g
s
.567 .788 .982 r
.34044 .36447 m .34131 .36507 L p .32775 .36479 L F P
0 g
s
.567 .788 .982 r
.32775 .36479 m .33329 .36377 L .34044 .36447 L p F P
0 g
s
.539 .778 .986 r
.33329 .36377 m .32775 .36479 L .32457 .36239 L p F P
0 g
s
.644 .609 .8 r
.5784 .36935 m .58925 .36601 L .59201 .37176 L p F P
0 g
s
.65 .639 .825 r
.58925 .36601 m .5784 .36935 L .57557 .36425 L p F P
0 g
s
.7 .342 .365 r
.33243 .46604 m .33488 .46895 L .33103 .46856 L closepath p F P
0 g
s
.601 .815 .982 r
.4655 .36487 m .46372 .36367 L .45474 .36585 L closepath p F P
0 g
s
.597 .821 .986 r
.46075 .36198 m .46372 .36367 L .45474 .36585 L p F P
0 g
s
.597 .821 .986 r
.4501 .36436 m .46075 .36198 L p .45474 .36585 L F P
0 g
s
.551 .789 .987 r
.34131 .36507 m .34292 .36481 L .35253 .36584 L p F P
0 g
s
.574 .804 .986 r
.35173 .36333 m .34292 .36481 L .35253 .36584 L p F P
0 g
s
.574 .804 .986 r
.35253 .36584 m .35488 .36536 L .35173 .36333 L p F P
0 g
s
.605 .241 .325 r
.4447 .47133 m .44411 .47261 L .44175 .47149 L closepath p F P
0 g
s
.607 .241 .323 r
.44308 .47482 m .44411 .47261 L .44175 .47149 L p F P
0 g
s
.607 .241 .323 r
.43289 .47532 m .44308 .47482 L p .44175 .47149 L F P
0 g
s
.607 .241 .323 r
.43048 .47412 m .43289 .47532 L p .44175 .47149 L F P
0 g
s
.71 .35 .365 r
.31619 .46679 m .32543 .4679 L .32231 .4639 L p F P
0 g
s
.71 .35 .365 r
.31556 .46598 m .31619 .46679 L p .32231 .4639 L F P
0 g
s
.71 .35 .365 r
.32231 .4639 m .31713 .46328 L .31556 .46598 L p F P
0 g
s
.661 .729 .899 r
.53469 .36297 m .54547 .35954 L .54831 .36295 L p F P
0 g
s
.658 .757 .923 r
.54547 .35954 m .53469 .36297 L .53185 .35992 L p F P
0 g
s
.786 .639 .699 r
.21297 .38843 m .20936 .38732 L .211 .39136 L closepath p F P
0 g
s
.57 .365 .563 r
.59134 .42047 m .59113 .41536 L .58019 .4186 L p F P
0 g
s
.57 .365 .563 r
.58019 .4186 m .58039 .42371 L .59134 .42047 L p F P
0 g
s
.666 .291 .326 r
.35946 .47447 m .36978 .47504 L .36541 .47138 L p F P
0 g
s
.666 .291 .326 r
.36541 .47138 m .36144 .47116 L .35946 .47447 L p F P
0 g
s
.596 .231 .32 r
.45608 .47395 m .45767 .47045 L .4447 .47133 L p F P
0 g
s
.596 .231 .32 r
.44846 .47447 m .45608 .47395 L p .4447 .47133 L F P
0 g
s
.596 .231 .32 r
.4447 .47133 m .44411 .47261 L .44846 .47447 L p F P
0 g
s
.757 .434 .438 r
.26926 .45147 m .27723 .453 L .27553 .4486 L p F P
0 g
s
.757 .434 .438 r
.26885 .45037 m .26926 .45147 L p .27553 .4486 L F P
0 g
s
.757 .434 .438 r
.27553 .4486 m .27008 .44755 L .26885 .45037 L p F P
0 g
s
.789 .525 .537 r
.23553 .43059 m .23644 .43082 L .23642 .42593 L p F P
0 g
s
.789 .525 .537 r
.23642 .42593 m .23614 .42585 L .23553 .43059 L p F P
0 g
s
.677 .304 .332 r
.35894 .47443 m .35946 .47447 L .36144 .47116 L p F P
0 g
s
.677 .304 .332 r
.36144 .47116 m .35487 .47069 L .35894 .47443 L p F P
0 g
s
.556 .783 .983 r
.34131 .36507 m .34292 .36481 L .34044 .36447 L closepath p F P
0 g
s
.798 .533 .538 r
.22954 .42892 m .23553 .43059 L .23614 .42585 L p F P
0 g
s
.798 .533 .538 r
.23614 .42585 m .22956 .42401 L .22954 .42892 L p F P
0 g
s
.559 .268 .431 r
.54502 .45022 m .54575 .44604 L .53417 .44847 L p F P
0 g
s
.559 .268 .431 r
.53653 .45201 m .54502 .45022 L p .53417 .44847 L F P
0 g
s
.559 .268 .431 r
.53417 .44847 m .53363 .45149 L .53653 .45201 L p F P
0 g
s
.797 .636 .683 r
.211 .39136 m .20922 .3945 L .21259 .39563 L closepath p F P
0 g
s
.802 .622 .658 r
.21297 .40231 m .21393 .40012 L .21259 .39563 L p F P
0 g
s
.802 .622 .658 r
.2066 .40021 m .21297 .40231 L p .21259 .39563 L F P
0 g
s
.802 .622 .658 r
.21259 .39563 m .20922 .3945 L .2066 .40021 L p F P
0 g
s
.574 .237 .361 r
.49655 .46263 m .49566 .46533 L .48968 .46353 L closepath p F P
0 g
s
.575 .236 .358 r
.49531 .46639 m .49566 .46533 L .48968 .46353 L p F P
0 g
s
.575 .236 .358 r
.48295 .46795 m .49531 .46639 L p .48968 .46353 L F P
0 g
s
.661 .703 .878 r
.54831 .36295 m .55911 .35948 L .56193 .36332 L p F P
0 g
s
.661 .732 .902 r
.55911 .35948 m .54831 .36295 L .54547 .35954 L p F P
0 g
s
.564 .316 .498 r
.5579 .43617 m .56357 .43758 L .55771 .43904 L closepath p F P
0 g
s
.739 .395 .399 r
.28751 .45876 m .29587 .46016 L .29357 .45592 L p F P
0 g
s
.739 .395 .399 r
.28556 .45522 m .28751 .45876 L p .29357 .45592 L F P
0 g
s
.739 .395 .399 r
.29357 .45592 m .28587 .45465 L .28556 .45522 L p F P
0 g
s
.772 .468 .472 r
.25247 .44372 m .26006 .44538 L .25895 .44081 L p F P
0 g
s
.772 .468 .472 r
.25226 .44284 m .25247 .44372 L p .25895 .44081 L F P
0 g
s
.772 .468 .472 r
.25895 .44081 m .25337 .43959 L .25226 .44284 L p F P
0 g
s
.624 .545 .746 r
.59493 .37909 m .59541 .38043 L .60603 .37674 L p F P
0 g
s
.616 .523 .726 r
.60837 .3842 m .60603 .37674 L .59541 .38043 L p F P
0 g
s
.616 .523 .726 r
.59541 .38043 m .59776 .3879 L .60837 .3842 L p F P
0 g
s
.8 .616 .652 r
.21393 .40012 m .21297 .40231 L .21466 .40286 L closepath p F P
0 g
s
.607 .498 .703 r
.60874 .38558 m .60837 .3842 L .59776 .3879 L p F P
0 g
s
.607 .498 .703 r
.59776 .3879 m .59784 .38818 L .60874 .38558 L p F P
0 g
s
.624 .545 .746 r
.60603 .37674 m .60582 .37615 L .59493 .37909 L p F P
0 g
s
.63 .565 .763 r
.60582 .37615 m .59493 .37909 L .59208 .37191 L p F P
0 g
s
.603 .482 .688 r
.61003 .3909 m .60874 .38558 L .59784 .38818 L p F P
0 g
s
.603 .482 .688 r
.59784 .38818 m .5994 .39457 L .61003 .3909 L p F P
0 g
s
.644 .272 .324 r
.3897 .47361 m .39286 .47582 L .38853 .47575 L closepath p F P
0 g
s
.72 .363 .371 r
.31713 .46328 m .31556 .46598 L .31322 .46274 L closepath p F P
0 g
s
.798 .643 .69 r
.20922 .3945 m .211 .39136 L .20936 .38732 L p F P
0 g
s
.804 .601 .627 r
.21116 .40776 m .21587 .40928 L .21466 .40286 L p F P
0 g
s
.804 .601 .627 r
.21466 .40286 m .21297 .40231 L .21116 .40776 L p F P
0 g
s
.714 .721 .855 r
.23982 .36508 m .24304 .36328 L .2398 .3596 L p F P
0 g
s
.714 .721 .855 r
.2398 .3596 m .23319 .36303 L .23982 .36508 L p F P
0 g
s
.726 .702 .828 r
.22936 .36513 m .23319 .36303 L .23982 .36508 L p F P
0 g
s
.675 .297 .321 r
.34869 .47364 m .35894 .47443 L .35487 .47069 L p F P
0 g
s
.675 .297 .321 r
.34582 .47103 m .34869 .47364 L p .35487 .47069 L F P
0 g
s
.675 .297 .321 r
.35487 .47069 m .34645 .47006 L .34582 .47103 L p F P
0 g
s
.753 .685 .787 r
.21913 .37251 m .21849 .37233 L .21879 .37279 L closepath p F P
0 g
s
.772 .686 .768 r
.21182 .37976 m .21879 .37279 L .21849 .37233 L p F P
0 g
s
.742 .713 .824 r
.21913 .37251 m .22936 .36513 L .22626 .36126 L p F P
0 g
s
.742 .713 .824 r
.21849 .37233 m .21913 .37251 L p .22626 .36126 L F P
0 g
s
.601 .26 .365 r
.45774 .47027 m .45804 .47042 L .45767 .47045 L closepath p F P
0 g
s
.486 .798 .999 r
.36532 .36371 m .35488 .36536 L .35173 .36333 L p F P
0 g
s
.612 .818 .98 r
.4744 .36365 m .4655 .36487 L .46372 .36367 L p F P
0 g
s
.553 .783 .984 r
.34855 .36149 m .35173 .36333 L .34292 .36481 L p F P
0 g
s
.553 .783 .984 r
.33814 .36288 m .34855 .36149 L p .34292 .36481 L F P
0 g
s
.553 .783 .984 r
.34292 .36481 m .34044 .36447 L .33814 .36288 L p F P
0 g
s
.658 .675 .855 r
.57511 .3635 m .57276 .35986 L .56193 .36332 L p F P
0 g
s
.66 .704 .879 r
.57276 .35986 m .56193 .36332 L .55911 .35948 L p F P
0 g
s
.772 .686 .768 r
.20528 .37769 m .21182 .37976 L p .21849 .37233 L F P
0 g
s
.772 .686 .768 r
.21849 .37233 m .21295 .37032 L .20528 .37769 L p F P
0 g
s
.742 .713 .824 r
.21559 .36808 m .21849 .37233 L p .22626 .36126 L F P
0 g
s
.763 .695 .787 r
.21559 .36808 m .21295 .37032 L .21849 .37233 L closepath p F P
0 g
s
.583 .218 .315 r
.45804 .47042 m .45767 .47045 L .45608 .47395 L p F P
0 g
s
.567 .251 .394 r
.50928 .45858 m .51444 .45988 L .50869 .46084 L closepath p F P
0 g
s
.582 .222 .322 r
.47041 .46931 m .45804 .47042 L .46568 .47313 L p F P
0 g
s
.583 .218 .315 r
.45608 .47395 m .46568 .47313 L .45804 .47042 L p F P
0 g
s
.791 .655 .712 r
.20796 .38431 m .20653 .38633 L .20936 .38732 L closepath p F P
0 g
s
.798 .643 .69 r
.20293 .39236 m .20922 .3945 L p .20936 .38732 L F P
0 g
s
.798 .643 .69 r
.20936 .38732 m .20653 .38633 L .20293 .39236 L p F P
0 g
s
.574 .39 .594 r
.60193 .41192 m .60143 .40651 L .59064 .40996 L p F P
0 g
s
.574 .39 .594 r
.59064 .40996 m .59113 .41536 L .60193 .41192 L p F P
0 g
s
.778 .659 .732 r
.20485 .37816 m .20528 .37769 L .21182 .37976 L p F P
0 g
s
.778 .659 .732 r
.21182 .37976 m .20796 .38431 L .20485 .37816 L p F P
0 g
s
.786 .501 .505 r
.237 .43555 m .24421 .43734 L .24367 .43261 L p F P
0 g
s
.786 .501 .505 r
.24367 .43261 m .23644 .43082 L .237 .43555 L p F P
0 g
s
.67 .75 .911 r
.25668 .36219 m .26704 .35853 L .27028 .36165 L p F P
0 g
s
.653 .756 .925 r
.26704 .35853 m .25668 .36219 L .25343 .35881 L p F P
0 g
s
.695 .74 .886 r
.24304 .36328 m .25343 .35881 L .25668 .36219 L p F P
0 g
s
.721 .363 .37 r
.30737 .46554 m .30441 .46149 L .31322 .46274 L p F P
0 g
s
.721 .363 .37 r
.31516 .46666 m .30737 .46554 L p .31322 .46274 L F P
0 g
s
.721 .363 .37 r
.31322 .46274 m .31556 .46598 L .31516 .46666 L p F P
0 g
s
.806 .605 .63 r
.20474 .40567 m .21116 .40776 L .21297 .40231 L p F P
0 g
s
.806 .605 .63 r
.21297 .40231 m .2066 .40021 L .20474 .40567 L p F P
0 g
s
.798 .577 .601 r
.21638 .41505 m .21646 .41508 L .21769 .40981 L p F P
0 g
s
.798 .577 .601 r
.21769 .40981 m .21587 .40928 L .21638 .41505 L p F P
0 g
s
.766 .445 .442 r
.27008 .44755 m .26885 .45037 L .26766 .44704 L closepath p F P
0 g
s
.643 .76 .933 r
.27028 .36165 m .28062 .35863 L .28386 .36151 L p F P
0 g
s
.623 .765 .947 r
.28062 .35863 m .27028 .36165 L .26704 .35853 L p F P
0 g
s
.568 .788 .982 r
.34044 .36447 m .33814 .36288 L .33329 .36377 L closepath p F P
0 g
s
.564 .228 .357 r
.50747 .46459 m .50869 .46084 L .49655 .46263 L p F P
0 g
s
.564 .228 .357 r
.49824 .46597 m .50747 .46459 L p .49655 .46263 L F P
0 g
s
.564 .228 .357 r
.49655 .46263 m .49566 .46533 L .49824 .46597 L p F P
0 g
s
.682 .746 .9 r
.25343 .35881 m .24304 .36328 L .2398 .3596 L p F P
0 g
s
.473 .802 1 r
.37893 .36397 m .36846 .3656 L .36532 .36371 L p F P
0 g
s
.591 .451 .659 r
.61125 .3971 m .61003 .3909 L .5994 .39457 L p F P
0 g
s
.591 .451 .659 r
.5994 .39457 m .60062 .40077 L .61125 .3971 L p F P
0 g
s
.687 .31 .328 r
.34645 .47006 m .34582 .47103 L .34464 .46989 L closepath p F P
0 g
s
.803 .625 .661 r
.20023 .39809 m .2066 .40021 L .20922 .3945 L p F P
0 g
s
.803 .625 .661 r
.20922 .3945 m .20293 .39236 L .20023 .39809 L p F P
0 g
s
.633 .263 .325 r
.40327 .47462 m .40532 .47592 L .40258 .47593 L closepath p F P
0 g
s
.63 .565 .763 r
.59208 .37191 m .60297 .36885 L .60582 .37615 L p F P
0 g
s
.635 .591 .788 r
.59201 .37176 m .59208 .37191 L .60297 .36885 L p F P
0 g
s
.554 .241 .393 r
.53244 .45661 m .53342 .45265 L .52164 .45486 L p F P
0 g
s
.554 .241 .393 r
.52164 .45486 m .52065 .45883 L .53244 .45661 L p F P
0 g
s
.635 .591 .788 r
.60297 .36885 m .6026 .36801 L .59201 .37176 L p F P
0 g
s
.64 .607 .801 r
.58925 .36601 m .59201 .37176 L .6026 .36801 L p F P
0 g
s
.687 .31 .327 r
.33875 .47274 m .33488 .46895 L .34464 .46989 L p F P
0 g
s
.687 .31 .327 r
.34436 .47329 m .33875 .47274 L p .34464 .46989 L F P
0 g
s
.687 .31 .327 r
.34464 .46989 m .34582 .47103 L .34436 .47329 L p F P
0 g
s
.616 .768 .953 r
.28386 .36151 m .2942 .359 L .29743 .36164 L p F P
0 g
s
.592 .772 .966 r
.2942 .359 m .28386 .36151 L .28062 .35863 L p F P
0 g
s
.798 .555 .57 r
.21626 .42026 m .22272 .42209 L .2233 .41701 L p F P
0 g
s
.798 .555 .57 r
.21636 .41592 m .21626 .42026 L p .2233 .41701 L F P
0 g
s
.798 .555 .57 r
.2233 .41701 m .21646 .41508 L .21636 .41592 L p F P
0 g
s
.596 .231 .319 r
.44411 .47261 m .44846 .47447 L .44308 .47482 L closepath p F P
0 g
s
.79 .661 .72 r
.20653 .38633 m .20796 .38431 L .20485 .37816 L p F P
0 g
s
.781 .478 .475 r
.25337 .43959 m .25226 .44284 L .25143 .43913 L closepath p F P
0 g
s
.749 .407 .404 r
.28587 .45465 m .28556 .45522 L .2852 .45453 L closepath p F P
0 g
s
.767 .445 .441 r
.26165 .44982 m .26006 .44538 L .26766 .44704 L p F P
0 g
s
.767 .445 .441 r
.26844 .45131 m .26165 .44982 L p .26766 .44704 L F P
0 g
s
.767 .445 .441 r
.26766 .44704 m .26885 .45037 L .26844 .45131 L p F P
0 g
s
.807 .583 .598 r
.20999 .41301 m .21638 .41505 L .21587 .40928 L p F P
0 g
s
.807 .583 .598 r
.21587 .40928 m .21116 .40776 L .20999 .41301 L p F P
0 g
s
.515 .81 .999 r
.38205 .36575 m .39255 .36408 L .39564 .36576 L p F P
0 g
s
.466 .807 .999 r
.39255 .36408 m .38205 .36575 L .37893 .36397 L p F P
0 g
s
.65 .639 .825 r
.57557 .36425 m .58643 .36087 L .58925 .36601 L p F P
0 g
s
.655 .667 .85 r
.57511 .3635 m .57557 .36425 L .58643 .36087 L p F P
0 g
s
.749 .407 .403 r
.27939 .45727 m .27723 .453 L .2852 .45453 L p F P
0 g
s
.749 .407 .403 r
.28397 .45815 m .27939 .45727 L p .2852 .45453 L F P
0 g
s
.749 .407 .403 r
.2852 .45453 m .28556 .45522 L .28397 .45815 L p F P
0 g
s
.719 .71 .842 r
.23319 .36303 m .22626 .36126 L .22936 .36513 L closepath p F P
0 g
s
.539 .778 .986 r
.32457 .36239 m .32484 .36235 L .33329 .36377 L p F P
0 g
s
.558 .8 .989 r
.33495 .36086 m .32484 .36235 L .33329 .36377 L p F P
0 g
s
.558 .8 .989 r
.33329 .36377 m .33814 .36288 L .33495 .36086 L p F P
0 g
s
.621 .254 .324 r
.41686 .47479 m .41859 .47577 L .41634 .47583 L closepath p F P
0 g
s
.609 .243 .323 r
.43048 .47412 m .43289 .47532 L .42984 .47545 L closepath p F P
0 g
s
.589 .776 .969 r
.29743 .36164 m .30778 .35953 L .31099 .36197 L p F P
0 g
s
.554 .781 .983 r
.30778 .35953 m .29743 .36164 L .2942 .359 L p F P
0 g
s
.79 .661 .72 r
.20485 .37816 m .20035 .38414 L .20653 .38633 L p F P
0 g
s
.798 .646 .694 r
.19662 .39021 m .20293 .39236 L .20653 .38633 L p F P
0 g
s
.798 .646 .694 r
.20653 .38633 m .20035 .38414 L .19662 .39021 L p F P
0 g
s
.616 .809 .974 r
.47786 .36326 m .47735 .36288 L .4744 .36365 L closepath p F P
0 g
s
.612 .818 .98 r
.4744 .3611 m .47735 .36288 L .4744 .36365 L p F P
0 g
s
.612 .818 .98 r
.46372 .36367 m .4744 .3611 L p .4744 .36365 L F P
0 g
s
.553 .308 .497 r
.5801 .43318 m .58036 .42856 L .56925 .4316 L p F P
0 g
s
.553 .308 .497 r
.56925 .4316 m .56898 .43621 L .5801 .43318 L p F P
0 g
s
.782 .478 .475 r
.24524 .44194 m .24421 .43734 L .25143 .43913 L p F P
0 g
s
.782 .478 .475 r
.252 .44361 m .24524 .44194 L p .25143 .43913 L F P
0 g
s
.782 .478 .475 r
.25143 .43913 m .25226 .44284 L .252 .44361 L p F P
0 g
s
.798 .534 .537 r
.22269 .42699 m .22954 .42892 L .22956 .42401 L p F P
0 g
s
.798 .534 .537 r
.22956 .42401 m .22272 .42209 L .22269 .42699 L p F P
0 g
s
.571 .21 .317 r
.47661 .46865 m .47041 .46931 L .46888 .47284 L p F P
0 g
s
.582 .222 .322 r
.46568 .47313 m .46888 .47284 L .47041 .46931 L p F P
0 g
s
.549 .281 .461 r
.56357 .43758 m .55771 .43904 L .55719 .44342 L p F P
0 g
s
.656 .675 .856 r
.57276 .35986 m .57511 .3635 L .58586 .35995 L p F P
0 g
s
.655 .667 .85 r
.58643 .36087 m .58586 .35995 L .57511 .3635 L p F P
0 g
s
.467 .813 .998 r
.40618 .36401 m .39564 .36576 L .39255 .36408 L p F P
0 g
s
.516 .816 .999 r
.39564 .36576 m .40618 .36401 L .40925 .36564 L p F P
0 g
s
.742 .398 .4 r
.28556 .45522 m .28751 .45876 L .28397 .45815 L closepath p F P
0 g
s
.722 .36 .363 r
.29877 .46429 m .30737 .46554 L .30441 .46149 L p F P
0 g
s
.722 .36 .363 r
.30441 .46149 m .30085 .46098 L .29877 .46429 L p F P
0 g
s
.557 .332 .53 r
.59132 .42532 m .59134 .42047 L .58039 .42371 L p F P
0 g
s
.557 .332 .53 r
.58039 .42371 m .58036 .42856 L .59132 .42532 L p F P
0 g
s
.615 .808 .974 r
.48805 .36012 m .49008 .36147 L .47786 .36326 L p F P
0 g
s
.615 .808 .974 r
.47786 .36326 m .47735 .36288 L .48805 .36012 L p F P
0 g
s
.689 .31 .323 r
.32905 .47177 m .33875 .47274 L .33488 .46895 L p F P
0 g
s
.689 .31 .323 r
.32893 .47166 m .32905 .47177 L p .33488 .46895 L F P
0 g
s
.689 .31 .323 r
.33488 .46895 m .33103 .46856 L .32893 .47166 L p F P
0 g
s
.523 .821 .999 r
.40925 .36564 m .41981 .36377 L .42286 .36536 L p F P
0 g
s
.474 .82 .998 r
.41981 .36377 m .40925 .36564 L .40618 .36401 L p F P
0 g
s
.531 .771 .985 r
.31559 .36118 m .31099 .36197 L .30778 .35953 L p F P
0 g
s
.556 .785 .984 r
.32439 .36227 m .32457 .36239 L p .31099 .36197 L F P
0 g
s
.556 .785 .984 r
.31099 .36197 m .31559 .36118 L .32439 .36227 L p F P
0 g
s
.715 .713 .847 r
.23319 .36303 m .2398 .3596 L p .22612 .36109 L F P
0 g
s
.715 .713 .847 r
.22612 .36109 m .22626 .36126 L .23319 .36303 L p F P
0 g
s
.579 .421 .631 r
.61182 .40092 m .61125 .3971 L .60062 .40077 L p F P
0 g
s
.579 .421 .631 r
.60062 .40077 m .60087 .40243 L .61182 .40092 L p F P
0 g
s
.679 .3 .322 r
.34582 .47103 m .34869 .47364 L .34436 .47329 L closepath p F P
0 g
s
.546 .257 .428 r
.55647 .44759 m .55719 .44342 L .54575 .44604 L p F P
0 g
s
.546 .257 .428 r
.54575 .44604 m .54502 .45022 L .55647 .44759 L p F P
0 g
s
.559 .268 .43 r
.53363 .45149 m .53653 .45201 L .53342 .45265 L closepath p F P
0 g
s
.534 .826 .999 r
.42286 .36536 m .43346 .36334 L .43648 .36493 L p F P
0 g
s
.488 .827 .998 r
.43346 .36334 m .42286 .36536 L .41981 .36377 L p F P
0 g
s
.569 .21 .319 r
.48295 .46795 m .48201 .4702 L .47661 .46865 L closepath p F P
0 g
s
.571 .21 .317 r
.48147 .47151 m .48201 .4702 L .47661 .46865 L p F P
0 g
s
.571 .21 .317 r
.46888 .47284 m .48147 .47151 L p .47661 .46865 L F P
0 g
s
.788 .502 .504 r
.23447 .4349 m .237 .43555 L .23644 .43082 L p F P
0 g
s
.788 .502 .504 r
.23644 .43082 m .23553 .43059 L .23447 .4349 L p F P
0 g
s
.701 .324 .331 r
.33103 .46856 m .32893 .47166 L .32543 .4679 L closepath p F P
0 g
s
.767 .689 .777 r
.20445 .37742 m .20528 .37769 L .21295 .37032 L p F P
0 g
s
.767 .689 .777 r
.20168 .3727 m .20445 .37742 L p .21295 .37032 L F P
0 g
s
.767 .689 .777 r
.21295 .37032 m .20675 .36812 L .20168 .3727 L p F P
0 g
s
.758 .698 .795 r
.21295 .37032 m .21559 .36808 L .21236 .36364 L p F P
0 g
s
.758 .698 .795 r
.21236 .36364 m .20675 .36812 L .21295 .37032 L p F P
0 g
s
.733 .373 .37 r
.29862 .46427 m .29877 .46429 L .30085 .46098 L p F P
0 g
s
.733 .373 .37 r
.30085 .46098 m .29587 .46016 L .29862 .46427 L p F P
0 g
s
.55 .829 .997 r
.43648 .36493 m .4471 .36274 L .4501 .36436 L p F P
0 g
s
.506 .833 .999 r
.4471 .36274 m .43648 .36493 L .43346 .36334 L p F P
0 g
s
.641 .796 .957 r
.5046 .36127 m .51535 .35814 L .51822 .36053 L p F P
0 g
s
.632 .812 .969 r
.51382 .35706 m .51535 .35814 L .5046 .36127 L p F P
0 g
s
.632 .812 .969 r
.5046 .36127 m .50197 .35931 L .51382 .35706 L p F P
0 g
s
.628 .809 .969 r
.50197 .35931 m .5046 .36127 L p .49097 .36207 L F P
0 g
s
.651 .778 .941 r
.51822 .36053 m .52899 .35726 L .53185 .35992 L p F P
0 g
s
.641 .804 .961 r
.52899 .35726 m .51822 .36053 L .51535 .35814 L p F P
0 g
s
.742 .713 .824 r
.22626 .36126 m .22599 .36116 L .21559 .36808 L p F P
0 g
s
.737 .698 .814 r
.22599 .36116 m .21559 .36808 L .21236 .36364 L p F P
0 g
s
.628 .809 .969 r
.49097 .36207 m .49954 .3597 L .50197 .35931 L p F P
0 g
s
.62 .825 .979 r
.49097 .36207 m .49954 .3597 L .49008 .36147 L closepath p F P
0 g
s
.529 .838 .999 r
.46075 .36198 m .4501 .36436 L .4471 .36274 L p F P
0 g
s
.578 .84 .994 r
.48805 .36012 m .47735 .36288 L .4744 .3611 L p F P
0 g
s
.553 .841 .998 r
.4744 .3611 m .46372 .36367 L .46075 .36198 L p F P
0 g
s
.55 .214 .352 r
.51444 .45988 m .50869 .46084 L .50747 .46459 L p F P
0 g
s
.658 .757 .923 r
.53185 .35992 m .54264 .35655 L .54547 .35954 L p F P
0 g
s
.652 .784 .944 r
.54264 .35655 m .53185 .35992 L .52899 .35726 L p F P
0 g
s
.776 .667 .743 r
.20528 .37769 m .20445 .37742 L .20485 .37816 L closepath p F P
0 g
s
.797 .512 .506 r
.23002 .43367 m .23447 .4349 L .23553 .43059 L p F P
0 g
s
.797 .512 .506 r
.23553 .43059 m .22954 .42892 L .23002 .43367 L p F P
0 g
s
.616 .224 .277 r
.40532 .47592 m .40258 .47593 L .40056 .47913 L p F P
0 g
s
.629 .238 .284 r
.39853 .4791 m .40056 .47913 L .40258 .47593 L p F P
0 g
s
.629 .238 .284 r
.40258 .47593 m .39286 .47582 L .39853 .4791 L p F P
0 g
s
.64 .607 .801 r
.6026 .36801 m .60014 .36282 L .58925 .36601 L p F P
0 g
s
.647 .635 .824 r
.60014 .36282 m .58925 .36601 L .58643 .36087 L p F P
0 g
s
.616 .227 .282 r
.41634 .47583 m .40532 .47592 L .41143 .47908 L p F P
0 g
s
.616 .224 .277 r
.40056 .47913 m .41143 .47908 L .40532 .47592 L p F P
0 g
s
.792 .668 .727 r
.20035 .38414 m .20485 .37816 L .20445 .37742 L p F P
0 g
s
.577 .414 .623 r
.61209 .40287 m .61182 .40092 L .60087 .40243 L p F P
0 g
s
.577 .414 .623 r
.60087 .40243 m .60143 .40651 L .61209 .40287 L p F P
0 g
s
.54 .777 .986 r
.32457 .36239 m .32484 .36235 L .32439 .36227 L closepath p F P
0 g
s
.604 .213 .275 r
.41859 .47577 m .41634 .47583 L .41439 .47906 L p F P
0 g
s
.616 .227 .282 r
.41143 .47908 m .41439 .47906 L .41634 .47583 L p F P
0 g
s
.561 .357 .562 r
.60216 .41703 m .60193 .41192 L .59113 .41536 L p F P
0 g
s
.561 .357 .562 r
.59113 .41536 m .59134 .42047 L .60216 .41703 L p F P
0 g
s
.629 .236 .28 r
.38645 .47892 m .39853 .4791 L .39286 .47582 L p F P
0 g
s
.629 .236 .28 r
.39286 .47582 m .38853 .47575 L .38645 .47892 L p F P
0 g
s
.806 .606 .631 r
.19832 .40358 m .20474 .40567 L .2066 .40021 L p F P
0 g
s
.806 .606 .631 r
.2066 .40021 m .20023 .39809 L .19832 .40358 L p F P
0 g
s
.809 .585 .6 r
.20354 .41093 m .20999 .41301 L .21116 .40776 L p F P
0 g
s
.809 .585 .6 r
.21116 .40776 m .20474 .40567 L .20354 .41093 L p F P
0 g
s
.604 .216 .281 r
.42984 .47545 m .41859 .47577 L .42519 .4788 L p F P
0 g
s
.604 .213 .275 r
.41439 .47906 m .42519 .4788 L .41859 .47577 L p F P
0 g
s
.661 .732 .902 r
.54547 .35954 m .55629 .3561 L .55911 .35948 L p F P
0 g
s
.659 .76 .925 r
.55629 .3561 m .54547 .35954 L .54264 .35655 L p F P
0 g
s
.641 .25 .287 r
.38632 .47891 m .38645 .47892 L .38853 .47575 L p F P
0 g
s
.641 .25 .287 r
.38853 .47575 m .38106 .47551 L .38632 .47891 L p F P
0 g
s
.537 .777 .987 r
.33175 .35901 m .33495 .36086 L .32484 .36235 L p F P
0 g
s
.537 .777 .987 r
.32136 .36019 m .33175 .35901 L p .32484 .36235 L F P
0 g
s
.537 .777 .987 r
.32484 .36235 m .32439 .36227 L .32136 .36019 L p F P
0 g
s
.783 .679 .749 r
.20168 .3727 m .1992 .37545 L .20445 .37742 L closepath p F P
0 g
s
.792 .668 .727 r
.19415 .38195 m .20035 .38414 L p .20445 .37742 L F P
0 g
s
.792 .668 .727 r
.20445 .37742 m .1992 .37545 L .19415 .38195 L p F P
0 g
s
.751 .407 .4 r
.27147 .45573 m .27939 .45727 L .27723 .453 L p F P
0 g
s
.751 .407 .4 r
.27723 .453 m .26926 .45147 L .27147 .45573 L p F P
0 g
s
.558 .785 .984 r
.32439 .36227 m .32136 .36019 L .31559 .36118 L closepath p F P
0 g
s
.768 .443 .435 r
.25409 .44814 m .26165 .44982 L .26006 .44538 L p F P
0 g
s
.768 .443 .435 r
.26006 .44538 m .25247 .44372 L .25409 .44814 L p F P
0 g
s
.801 .557 .57 r
.21646 .41508 m .21638 .41505 L .21636 .41592 L closepath p F P
0 g
s
.809 .565 .568 r
.21589 .42014 m .21636 .41592 L .21638 .41505 L p F P
0 g
s
.809 .565 .568 r
.20941 .41809 m .21589 .42014 L p .21638 .41505 L F P
0 g
s
.809 .565 .568 r
.21638 .41505 m .20999 .41301 L .20941 .41809 L p F P
0 g
s
.559 .2 .315 r
.49385 .46994 m .49531 .46639 L .48295 .46795 L p F P
0 g
s
.559 .2 .315 r
.48546 .47101 m .49385 .46994 L p .48295 .46795 L F P
0 g
s
.559 .2 .315 r
.48295 .46795 m .48201 .4702 L .48546 .47101 L p F P
0 g
s
.802 .627 .664 r
.19385 .39597 m .20023 .39809 L .20293 .39236 L p F P
0 g
s
.802 .627 .664 r
.20293 .39236 m .19662 .39021 L .19385 .39597 L p F P
0 g
s
.64 .243 .277 r
.37487 .47849 m .38632 .47891 L .38106 .47551 L p F P
0 g
s
.64 .243 .277 r
.37283 .47717 m .37487 .47849 L p .38106 .47551 L F P
0 g
s
.64 .243 .277 r
.38106 .47551 m .37416 .47526 L .37283 .47717 L p F P
0 g
s
.701 .323 .33 r
.31985 .47064 m .31619 .46679 L .32543 .4679 L p F P
0 g
s
.701 .323 .33 r
.32886 .47175 m .31985 .47064 L p .32543 .4679 L F P
0 g
s
.701 .323 .33 r
.32543 .4679 m .32893 .47166 L .32886 .47175 L p F P
0 g
s
.591 .203 .274 r
.43289 .47532 m .42984 .47545 L .42794 .47872 L p F P
0 g
s
.604 .216 .281 r
.42519 .4788 m .42794 .47872 L .42984 .47545 L p F P
0 g
s
.661 .733 .903 r
.56995 .35603 m .55911 .35948 L .55629 .3561 L p F P
0 g
s
.66 .704 .879 r
.55911 .35948 m .56995 .35603 L .57276 .35986 L p F P
0 g
s
.549 .281 .462 r
.56898 .43621 m .5688 .43776 L .56357 .43758 L closepath p F P
0 g
s
.549 .281 .461 r
.56848 .4406 m .5688 .43776 L .56357 .43758 L p F P
0 g
s
.549 .281 .461 r
.55719 .44342 m .56848 .4406 L p .56357 .43758 L F P
0 g
s
.541 .228 .387 r
.53653 .45201 m .53342 .45265 L .53244 .45661 L p F P
0 g
s
.591 .203 .274 r
.42794 .47872 m .44004 .47818 L .43289 .47532 L p F P
0 g
s
.591 .206 .281 r
.44308 .47482 m .43289 .47532 L .44004 .47818 L p F P
0 g
s
.733 .37 .363 r
.29031 .46285 m .29862 .46427 L .29587 .46016 L p F P
0 g
s
.733 .37 .363 r
.29587 .46016 m .28751 .45876 L .29031 .46285 L p F P
0 g
s
.652 .258 .285 r
.37416 .47526 m .37283 .47717 L .36978 .47504 L closepath p F P
0 g
s
.458 .788 .999 r
.34855 .36149 m .33814 .36288 L .33495 .36086 L p F P
0 g
s
.806 .561 .568 r
.21636 .41592 m .21589 .42014 L .21626 .42026 L closepath p F P
0 g
s
.784 .478 .471 r
.23805 .44013 m .24524 .44194 L .24421 .43734 L p F P
0 g
s
.784 .478 .471 r
.24421 .43734 m .237 .43555 L .23805 .44013 L p F P
0 g
s
.713 .354 .366 r
.31556 .46598 m .31619 .46679 L .31516 .46666 L closepath p F P
0 g
s
.65 .25 .273 r
.37199 .47838 m .37283 .47717 L .36978 .47504 L p F P
0 g
s
.65 .25 .273 r
.3639 .47791 m .37199 .47838 L p .36978 .47504 L F P
0 g
s
.65 .25 .273 r
.35929 .47469 m .3639 .47791 L p .36978 .47504 L F P
0 g
s
.65 .25 .273 r
.36978 .47504 m .35946 .47447 L .35929 .47469 L p F P
0 g
s
.618 .541 .745 r
.60582 .37615 m .61095 .37491 L .60603 .37674 L closepath p F P
0 g
s
.613 .526 .732 r
.61884 .38029 m .60837 .3842 L .60603 .37674 L p F P
0 g
s
.613 .526 .732 r
.61676 .37357 m .61884 .38029 L p .60603 .37674 L F P
0 g
s
.613 .526 .732 r
.60603 .37674 m .61095 .37491 L .61676 .37357 L p F P
0 g
s
.564 .227 .356 r
.49566 .46533 m .49824 .46597 L .49531 .46639 L closepath p F P
0 g
s
.799 .534 .537 r
.21586 .42505 m .22269 .42699 L .22272 .42209 L p F P
0 g
s
.799 .534 .537 r
.21587 .42315 m .21586 .42505 L p .22272 .42209 L F P
0 g
s
.799 .534 .537 r
.22272 .42209 m .21626 .42026 L .21587 .42315 L p F P
0 g
s
.548 .214 .354 r
.52065 .45883 m .52005 .46075 L .51444 .45988 L closepath p F P
0 g
s
.55 .214 .352 r
.51946 .4626 m .52005 .46075 L .51444 .45988 L p F P
0 g
s
.55 .214 .352 r
.50747 .46459 m .51946 .4626 L p .51444 .45988 L F P
0 g
s
.624 .559 .761 r
.61095 .37491 m .60582 .37615 L .60297 .36885 L p F P
0 g
s
.653 .756 .925 r
.25343 .35881 m .26378 .35555 L .26704 .35853 L p F P
0 g
s
.635 .761 .938 r
.26378 .35555 m .25343 .35881 L .25017 .35557 L p F P
0 g
s
.682 .746 .9 r
.2398 .3596 m .25017 .35557 L .25343 .35881 L p F P
0 g
s
.715 .713 .847 r
.2398 .3596 m .23653 .35609 L .22612 .36109 L p F P
0 g
s
.667 .752 .913 r
.25017 .35557 m .2398 .3596 L .23653 .35609 L p F P
0 g
s
.599 .491 .702 r
.6197 .38355 m .61884 .38029 L .60837 .3842 L p F P
0 g
s
.599 .491 .702 r
.60837 .3842 m .60874 .38558 L .6197 .38355 L p F P
0 g
s
.76 .437 .438 r
.26885 .45037 m .26926 .45147 L .26844 .45131 L closepath p F P
0 g
s
.619 .826 .98 r
.49954 .3597 m .49008 .36147 L .48805 .36012 L p F P
0 g
s
.797 .648 .697 r
.19081 .38824 m .19662 .39021 L .20035 .38414 L p F P
0 g
s
.797 .648 .697 r
.19057 .38761 m .19081 .38824 L p .20035 .38414 L F P
0 g
s
.797 .648 .697 r
.20035 .38414 m .19415 .38195 L .19057 .38761 L p F P
0 g
s
.579 .193 .274 r
.44846 .47447 m .44308 .47482 L .44124 .47812 L p F P
0 g
s
.591 .206 .281 r
.44004 .47818 m .44124 .47812 L .44308 .47482 L p F P
0 g
s
.656 .675 .856 r
.58586 .35995 m .58362 .35646 L .57276 .35986 L p F P
0 g
s
.659 .702 .879 r
.58362 .35646 m .57276 .35986 L .56995 .35603 L p F P
0 g
s
.595 .476 .687 r
.62053 .38702 m .6197 .38355 L .60874 .38558 L p F P
0 g
s
.595 .476 .687 r
.60874 .38558 m .61003 .3909 L .62053 .38702 L p F P
0 g
s
.623 .765 .947 r
.26704 .35853 m .27737 .3559 L .28062 .35863 L p F P
0 g
s
.601 .768 .96 r
.27737 .3559 m .26704 .35853 L .26378 .35555 L p F P
0 g
s
.734 .718 .836 r
.22612 .36109 m .22599 .36116 L .22626 .36126 L closepath p F P
0 g
s
.541 .228 .387 r
.54408 .4542 m .54447 .45256 L .53653 .45201 L p F P
0 g
s
.541 .228 .387 r
.53244 .45661 m .54408 .4542 L p .53653 .45201 L F P
0 g
s
.541 .23 .39 r
.54502 .45022 m .54447 .45256 L .53653 .45201 L closepath p F P
0 g
s
.531 .771 .985 r
.30778 .35953 m .30782 .35953 L .31559 .36118 L p F P
0 g
s
.549 .795 .99 r
.31814 .35815 m .30782 .35953 L .31559 .36118 L p F P
0 g
s
.549 .795 .99 r
.31559 .36118 m .32136 .36019 L .31814 .35815 L p F P
0 g
s
.728 .724 .847 r
.22599 .36116 m .22612 .36109 L .22286 .35727 L p F P
0 g
s
.728 .724 .847 r
.22286 .35727 m .22009 .35886 L .22599 .36116 L p F P
0 g
s
.737 .698 .814 r
.21236 .36364 m .22009 .35886 L .22599 .36116 L p F P
0 g
s
.486 .798 .999 r
.35173 .36333 m .36217 .36201 L .36532 .36371 L p F P
0 g
s
.43 .79 .996 r
.36217 .36201 m .35173 .36333 L .34855 .36149 L p F P
0 g
s
.697 .742 .886 r
.23653 .35609 m .22612 .36109 L .22286 .35727 L p F P
0 g
s
.565 .383 .593 r
.6126 .40827 m .61209 .40287 L .60143 .40651 L p F P
0 g
s
.565 .383 .593 r
.60143 .40651 m .60193 .41192 L .6126 .40827 L p F P
0 g
s
.775 .471 .473 r
.25226 .44284 m .25247 .44372 L .252 .44361 L closepath p F P
0 g
s
.578 .194 .279 r
.45608 .47395 m .45468 .47658 L .44846 .47447 L closepath p F P
0 g
s
.579 .193 .274 r
.4543 .47727 m .45468 .47658 L .44846 .47447 L p F P
0 g
s
.579 .193 .274 r
.44124 .47812 m .4543 .47727 L p .44846 .47447 L F P
0 g
s
.662 .264 .281 r
.35946 .47447 m .35929 .47469 L .35894 .47443 L closepath p F P
0 g
s
.662 .264 .28 r
.35334 .47721 m .34869 .47364 L .35894 .47443 L p F P
0 g
s
.662 .264 .28 r
.35719 .47751 m .35334 .47721 L p .35894 .47443 L F P
0 g
s
.662 .264 .28 r
.35894 .47443 m .35929 .47469 L .35719 .47751 L p F P
0 g
s
.701 .318 .318 r
.31287 .46976 m .31985 .47064 L .31619 .46679 L p F P
0 g
s
.701 .318 .318 r
.31619 .46679 m .31516 .46666 L .31287 .46976 L p F P
0 g
s
.798 .512 .504 r
.22318 .43174 m .23002 .43367 L .22954 .42892 L p F P
0 g
s
.798 .512 .504 r
.22954 .42892 m .22269 .42699 L .22318 .43174 L p F P
0 g
s
.592 .772 .966 r
.28062 .35863 m .29096 .35649 L .2942 .359 L p F P
0 g
s
.56 .776 .979 r
.29096 .35649 m .28062 .35863 L .27737 .3559 L p F P
0 g
s
.713 .332 .326 r
.31078 .46947 m .31287 .46976 L .31516 .46666 L p F P
0 g
s
.713 .332 .326 r
.31516 .46666 m .30737 .46554 L .31078 .46947 L p F P
0 g
s
.754 .407 .397 r
.26642 .45473 m .27147 .45573 L .26926 .45147 L p F P
0 g
s
.754 .407 .397 r
.26926 .45147 m .26844 .45131 L .26642 .45473 L p F P
0 g
s
.653 .253 .274 r
.35929 .47469 m .3639 .47791 L .35719 .47751 L closepath p F P
0 g
s
.583 .446 .659 r
.62175 .39322 m .62053 .38702 L .61003 .3909 L p F P
0 g
s
.583 .446 .659 r
.61003 .3909 m .61125 .3971 L .62175 .39322 L p F P
0 g
s
.624 .559 .761 r
.6165 .37281 m .61095 .37491 L p .60297 .36885 L F P
0 g
s
.624 .559 .761 r
.60297 .36885 m .6139 .36603 L .6165 .37281 L p F P
0 g
s
.63 .586 .787 r
.6026 .36801 m .60297 .36885 L .6139 .36603 L p F P
0 g
s
.764 .682 .773 r
.20675 .36812 m .20168 .3727 L .19848 .36761 L p F P
0 g
s
.78 .683 .756 r
.1992 .37545 m .20168 .3727 L .19848 .36761 L p F P
0 g
s
.538 .272 .46 r
.57971 .43673 m .5801 .43318 L .56898 .43621 L p F P
0 g
s
.538 .272 .46 r
.56898 .43621 m .5688 .43776 L .57971 .43673 L p F P
0 g
s
.764 .682 .773 r
.19848 .36761 m .20043 .36595 L .20675 .36812 L p F P
0 g
s
.752 .7 .803 r
.20675 .36812 m .21236 .36364 L .20911 .35941 L p F P
0 g
s
.752 .7 .803 r
.20911 .35941 m .20043 .36595 L .20675 .36812 L p F P
0 g
s
.473 .802 1 r
.36532 .36371 m .3758 .36239 L .37893 .36397 L p F P
0 g
s
.406 .79 .991 r
.3758 .36239 m .36532 .36371 L .36217 .36201 L p F P
0 g
s
.764 .42 .403 r
.26368 .45413 m .26642 .45473 L .26844 .45131 L p F P
0 g
s
.764 .42 .403 r
.26844 .45131 m .26165 .44982 L .26368 .45413 L p F P
0 g
s
.771 .444 .433 r
.25022 .44727 m .25409 .44814 L .25247 .44372 L p F P
0 g
s
.771 .444 .433 r
.25247 .44372 m .252 .44361 L .25022 .44727 L p F P
0 g
s
.537 .204 .35 r
.53129 .4604 m .53244 .45661 L .52065 .45883 L p F P
0 g
s
.537 .204 .35 r
.5263 .46134 m .53129 .4604 L p .52065 .45883 L F P
0 g
s
.537 .204 .35 r
.52065 .45883 m .52005 .46075 L .5263 .46134 L p F P
0 g
s
.544 .185 .308 r
.49824 .46597 m .49531 .46639 L .49385 .46994 L p F P
0 g
s
.542 .298 .496 r
.59107 .42994 m .59132 .42532 L .58036 .42856 L p F P
0 g
s
.542 .298 .496 r
.58036 .42856 m .5801 .43318 L .59107 .42994 L p F P
0 g
s
.566 .181 .272 r
.46568 .47313 m .45608 .47395 L .45468 .47658 L p F P
0 g
s
.63 .586 .787 r
.6139 .36603 m .61304 .36404 L .6026 .36801 L p F P
0 g
s
.635 .603 .8 r
.60014 .36282 m .6026 .36801 L .61304 .36404 L p F P
0 g
s
.647 .635 .824 r
.58643 .36087 m .59732 .35761 L .60014 .36282 L p F P
0 g
s
.651 .665 .85 r
.58586 .35995 m .58643 .36087 L .59732 .35761 L p F P
0 g
s
.734 .369 .36 r
.282 .46142 m .29031 .46285 L .28751 .45876 L p F P
0 g
s
.734 .369 .36 r
.28187 .46123 m .282 .46142 L p .28751 .45876 L F P
0 g
s
.734 .369 .36 r
.28751 .45876 m .28397 .45815 L .28187 .46123 L p F P
0 g
s
.78 .456 .438 r
.24672 .4464 m .25022 .44727 L .252 .44361 L p F P
0 g
s
.78 .456 .438 r
.252 .44361 m .24524 .44194 L .24672 .4464 L p F P
0 g
s
.78 .683 .756 r
.19848 .36761 m .19317 .37319 L .1992 .37545 L p F P
0 g
s
.79 .67 .731 r
.18791 .37977 m .19415 .38195 L .1992 .37545 L p F P
0 g
s
.79 .67 .731 r
.1992 .37545 m .19317 .37319 L .18791 .37977 L p F P
0 g
s
.809 .586 .601 r
.1971 .40885 m .20354 .41093 L .20474 .40567 L p F P
0 g
s
.809 .586 .601 r
.20474 .40567 m .19832 .40358 L .1971 .40885 L p F P
0 g
s
.805 .608 .636 r
.1945 .40231 m .19832 .40358 L .20023 .39809 L p F P
0 g
s
.805 .608 .636 r
.19345 .39706 m .1945 .40231 L p .20023 .39809 L F P
0 g
s
.805 .608 .636 r
.20023 .39809 m .19385 .39597 L .19345 .39706 L p F P
0 g
s
.554 .781 .983 r
.30775 .35951 m .30778 .35953 L p .2942 .359 L F P
0 g
s
.554 .781 .983 r
.2942 .359 m .299 .3582 L .30775 .35951 L p F P
0 g
s
.529 .766 .984 r
.299 .3582 m .2942 .359 L .29096 .35649 L p F P
0 g
s
.533 .245 .423 r
.56777 .44477 m .56848 .4406 L .55719 .44342 L p F P
0 g
s
.533 .245 .423 r
.55719 .44342 m .55647 .44759 L .56777 .44477 L p F P
0 g
s
.731 .706 .827 r
.22009 .35886 m .21236 .36364 L .20911 .35941 L p F P
0 g
s
.665 .264 .276 r
.34315 .47639 m .35334 .47721 L .34869 .47364 L p F P
0 g
s
.665 .264 .276 r
.3424 .4758 m .34315 .47639 L p .34869 .47364 L F P
0 g
s
.665 .264 .276 r
.34869 .47364 m .34436 .47329 L .3424 .4758 L p F P
0 g
s
.81 .566 .569 r
.20295 .41601 m .20941 .41809 L .20999 .41301 L p F P
0 g
s
.81 .566 .569 r
.20999 .41301 m .20354 .41093 L .20295 .41601 L p F P
0 g
s
.544 .188 .314 r
.50747 .46459 m .50641 .46728 L .49824 .46597 L closepath p F P
0 g
s
.544 .185 .308 r
.50606 .46817 m .50641 .46728 L .49824 .46597 L p F P
0 g
s
.544 .185 .308 r
.49385 .46994 m .50606 .46817 L p .49824 .46597 L F P
0 g
s
.466 .807 .999 r
.37893 .36397 m .38944 .3626 L .39255 .36408 L p F P
0 g
s
.393 .793 .985 r
.38944 .3626 m .37893 .36397 L .3758 .36239 L p F P
0 g
s
.653 .673 .856 r
.58362 .35646 m .58586 .35995 L .59644 .35616 L p F P
0 g
s
.651 .665 .85 r
.59732 .35761 m .59644 .35616 L .58586 .35995 L p F P
0 g
s
.802 .626 .664 r
.19316 .39574 m .19385 .39597 L .19662 .39021 L p F P
0 g
s
.802 .626 .664 r
.19662 .39021 m .19081 .38824 L .19316 .39574 L p F P
0 g
s
.546 .324 .529 r
.60215 .42189 m .60216 .41703 L .59134 .42047 L p F P
0 g
s
.546 .324 .529 r
.59134 .42047 m .59132 .42532 L .60215 .42189 L p F P
0 g
s
.786 .479 .469 r
.23298 .43885 m .23805 .44013 L .237 .43555 L p F P
0 g
s
.786 .479 .469 r
.237 .43555 m .23447 .4349 L .23298 .43885 L p F P
0 g
s
.615 .536 .742 r
.61095 .37491 m .6165 .37281 L .61676 .37357 L closepath p F P
0 g
s
.677 .279 .285 r
.34436 .47329 m .3424 .4758 L .33875 .47274 L closepath p F P
0 g
s
.745 .383 .367 r
.28397 .45815 m .28187 .46123 L .27939 .45727 L closepath p F P
0 g
s
.807 .542 .537 r
.21626 .42026 m .21587 .42315 L .21589 .42014 L closepath p F P
0 g
s
.626 .811 .971 r
.50197 .35931 m .5017 .35911 L .49954 .3597 L closepath p F P
0 g
s
.619 .826 .98 r
.49879 .35732 m .5017 .35911 L .49954 .3597 L p F P
0 g
s
.619 .826 .98 r
.48805 .36012 m .49879 .35732 L p .49954 .3597 L F P
0 g
s
.563 .179 .273 r
.46888 .47284 m .46835 .47386 L .46568 .47313 L closepath p F P
0 g
s
.566 .181 .272 r
.46713 .47617 m .46835 .47386 L .46568 .47313 L p F P
0 g
s
.566 .181 .272 r
.45644 .47709 m .46713 .47617 L p .46568 .47313 L F P
0 g
s
.566 .181 .272 r
.45468 .47658 m .45644 .47709 L p .46568 .47313 L F P
0 g
s
.808 .542 .537 r
.20935 .423 m .20941 .41809 L .21589 .42014 L p F P
0 g
s
.808 .542 .537 r
.21561 .42498 m .20935 .423 L p .21589 .42014 L F P
0 g
s
.808 .542 .537 r
.21589 .42014 m .21587 .42315 L .21561 .42498 L p F P
0 g
s
.71 .322 .313 r
.30208 .46817 m .31078 .46947 L .30737 .46554 L p F P
0 g
s
.71 .322 .313 r
.2987 .46437 m .30208 .46817 L p .30737 .46554 L F P
0 g
s
.71 .322 .313 r
.30737 .46554 m .29877 .46429 L .2987 .46437 L p F P
0 g
s
.531 .77 .985 r
.30778 .35953 m .30782 .35953 L .30775 .35951 L closepath p F P
0 g
s
.467 .813 .998 r
.39255 .36408 m .40309 .36261 L .40618 .36401 L p F P
0 g
s
.39 .797 .981 r
.40309 .36261 m .39255 .36408 L .38944 .3626 L p F P
0 g
s
.527 .77 .986 r
.3149 .35624 m .31814 .35815 L .30782 .35953 L p F P
0 g
s
.527 .77 .986 r
.30455 .35728 m .3149 .35624 L p .30782 .35953 L F P
0 g
s
.527 .77 .986 r
.30782 .35953 m .30775 .35951 L .30455 .35728 L p F P
0 g
s
.556 .78 .983 r
.30775 .35951 m .30455 .35728 L .299 .3582 L closepath p F P
0 g
s
.559 .199 .314 r
.48201 .4702 m .48546 .47101 L .48147 .47151 L closepath p F P
0 g
s
.538 .271 .459 r
.57962 .43757 m .57971 .43673 L .5688 .43776 L p F P
0 g
s
.538 .271 .459 r
.5688 .43776 m .56848 .4406 L .57962 .43757 L p F P
0 g
s
.529 .22 .387 r
.55556 .45159 m .55647 .44759 L .54502 .45022 L p F P
0 g
s
.529 .22 .387 r
.55142 .45254 m .55556 .45159 L p .54502 .45022 L F P
0 g
s
.529 .22 .387 r
.54502 .45022 m .54447 .45256 L .55142 .45254 L p F P
0 g
s
.628 .811 .97 r
.51246 .35611 m .51382 .35706 L .50197 .35931 L p F P
0 g
s
.628 .811 .97 r
.50197 .35931 m .5017 .35911 L .51246 .35611 L p F P
0 g
s
.552 .168 .267 r
.47976 .47486 m .48147 .47151 L .46888 .47284 L p F P
0 g
s
.552 .168 .267 r
.47495 .47537 m .47976 .47486 L p .46888 .47284 L F P
0 g
s
.552 .168 .267 r
.46888 .47284 m .46835 .47386 L .47495 .47537 L p F P
0 g
s
.569 .413 .63 r
.6226 .399 m .62175 .39322 L .61125 .3971 L p F P
0 g
s
.569 .413 .63 r
.61762 .40084 m .6226 .399 L p .61125 .3971 L F P
0 g
s
.569 .413 .63 r
.61125 .3971 m .61182 .40092 L .61762 .40084 L p F P
0 g
s
.796 .646 .697 r
.18752 .38035 m .18791 .37977 L .19415 .38195 L p F P
0 g
s
.796 .646 .697 r
.19415 .38195 m .19057 .38761 L .18752 .38035 L p F P
0 g
s
.795 .49 .473 r
.23096 .43829 m .23298 .43885 L .23447 .4349 L p F P
0 g
s
.795 .49 .473 r
.23447 .4349 m .23002 .43367 L .23096 .43829 L p F P
0 g
s
.677 .279 .284 r
.33346 .47541 m .32905 .47177 L .33875 .47274 L p F P
0 g
s
.677 .279 .284 r
.34201 .47629 m .33346 .47541 L p .33875 .47274 L F P
0 g
s
.677 .279 .284 r
.33875 .47274 m .3424 .4758 L .34201 .47629 L p F P
0 g
s
.4 .805 .982 r
.41644 .36246 m .40618 .36401 L .40309 .36261 L p F P
0 g
s
.474 .82 .998 r
.41684 .36245 m .41981 .36377 L p .40618 .36401 L F P
0 g
s
.474 .82 .998 r
.40618 .36401 m .41644 .36246 L .41684 .36245 L p F P
0 g
s
.652 .784 .944 r
.52899 .35726 m .5398 .35395 L .54264 .35655 L p F P
0 g
s
.642 .81 .964 r
.5398 .35395 m .52899 .35726 L .52613 .35496 L p F P
0 g
s
.641 .804 .961 r
.51535 .35814 m .52613 .35496 L .52899 .35726 L p F P
0 g
s
.659 .76 .925 r
.54264 .35655 m .55346 .35315 L .55629 .3561 L p F P
0 g
s
.653 .788 .946 r
.55346 .35315 m .54264 .35655 L .5398 .35395 L p F P
0 g
s
.632 .823 .974 r
.52535 .35443 m .52613 .35496 L .51535 .35814 L p F P
0 g
s
.632 .823 .974 r
.51535 .35814 m .51382 .35706 L .52535 .35443 L p F P
0 g
s
.635 .603 .8 r
.61304 .36404 m .61107 .3598 L .60014 .36282 L p F P
0 g
s
.643 .628 .82 r
.61107 .3598 m .60014 .36282 L .59732 .35761 L p F P
0 g
s
.643 .246 .278 r
.37283 .47717 m .37487 .47849 L .37199 .47838 L closepath p F P
0 g
s
.764 .418 .398 r
.25616 .45244 m .26368 .45413 L .26165 .44982 L p F P
0 g
s
.764 .418 .398 r
.26165 .44982 m .25409 .44814 L .25616 .45244 L p F P
0 g
s
.599 .843 .991 r
.51246 .35611 m .5017 .35911 L .49879 .35732 L p F P
0 g
s
.661 .733 .903 r
.55629 .3561 m .56714 .35265 L .56995 .35603 L p F P
0 g
s
.66 .761 .925 r
.56714 .35265 m .55629 .3561 L .55346 .35315 L p F P
0 g
s
.551 .35 .561 r
.61284 .41339 m .6126 .40827 L .60193 .41192 L p F P
0 g
s
.551 .35 .561 r
.60193 .41192 m .60216 .41703 L .61284 .41339 L p F P
0 g
s
.488 .827 .998 r
.41981 .36377 m .43042 .36199 L .43346 .36334 L p F P
0 g
s
.488 .826 .999 r
.43028 .36195 m .43042 .36199 L .41981 .36377 L p F P
0 g
s
.488 .826 .999 r
.41981 .36377 m .41684 .36245 L .43028 .36195 L p F P
0 g
s
.72 .725 .854 r
.22009 .35886 m .22286 .35727 L .21957 .3536 L p F P
0 g
s
.72 .725 .854 r
.21957 .3536 m .21397 .35662 L .22009 .35886 L p F P
0 g
s
.731 .706 .827 r
.20911 .35941 m .21397 .35662 L .22009 .35886 L p F P
0 g
s
.745 .383 .367 r
.2741 .45986 m .27147 .45573 L .27939 .45727 L p F P
0 g
s
.745 .383 .367 r
.28177 .46138 m .2741 .45986 L p .27939 .45727 L F P
0 g
s
.745 .383 .367 r
.27939 .45727 m .28187 .46123 L .28177 .46138 L p F P
0 g
s
.798 .512 .503 r
.21636 .4298 m .22318 .43174 L .22269 .42699 L p F P
0 g
s
.798 .512 .503 r
.22269 .42699 m .21586 .42505 L .21636 .4298 L p F P
0 g
s
.572 .849 .996 r
.49879 .35732 m .48805 .36012 L .48512 .3585 L p F P
0 g
s
.578 .84 .994 r
.4744 .3611 m .48512 .3585 L .48805 .36012 L p F P
0 g
s
.44 .778 .998 r
.33175 .35901 m .32136 .36019 L .31814 .35815 L p F P
0 g
s
.506 .833 .999 r
.43346 .36334 m .44409 .36137 L .4471 .36274 L p F P
0 g
s
.444 .827 .988 r
.44409 .36137 m .43346 .36334 L .43042 .36199 L p F P
0 g
s
.542 .85 .998 r
.48512 .3585 m .4744 .3611 L .47144 .35959 L p F P
0 g
s
.553 .841 .998 r
.46075 .36198 m .47144 .35959 L .4744 .3611 L p F P
0 g
s
.781 .454 .435 r
.23955 .44459 m .24672 .4464 L .24524 .44194 L p F P
0 g
s
.781 .454 .435 r
.24524 .44194 m .23805 .44013 L .23955 .44459 L p F P
0 g
s
.513 .845 .997 r
.47144 .35959 m .46075 .36198 L .45777 .36057 L p F P
0 g
s
.529 .838 .999 r
.4471 .36274 m .45777 .36057 L .46075 .36198 L p F P
0 g
s
.477 .838 .993 r
.45777 .36057 m .4471 .36274 L .44409 .36137 L p F P
0 g
s
.532 .176 .309 r
.51807 .46618 m .51946 .4626 L .50747 .46459 L p F P
0 g
s
.532 .176 .309 r
.50949 .46761 m .51807 .46618 L p .50747 .46459 L F P
0 g
s
.532 .176 .309 r
.50747 .46459 m .50641 .46728 L .50949 .46761 L p F P
0 g
s
.661 .732 .902 r
.58082 .35259 m .56995 .35603 L .56714 .35265 L p F P
0 g
s
.659 .702 .879 r
.56995 .35603 m .58082 .35259 L .58362 .35646 L p F P
0 g
s
.697 .742 .886 r
.22286 .35727 m .23325 .35271 L .23653 .35609 L p F P
0 g
s
.667 .752 .913 r
.23653 .35609 m .24689 .35247 L .25017 .35557 L p F P
0 g
s
.652 .756 .926 r
.24689 .35247 m .23653 .35609 L .23325 .35271 L p F P
0 g
s
.761 .69 .784 r
.20043 .36595 m .19649 .36463 L .19848 .36761 L closepath p F P
0 g
s
.78 .692 .766 r
.19317 .37319 m .19848 .36761 L .19649 .36463 L p F P
0 g
s
.537 .203 .349 r
.52005 .46075 m .5263 .46134 L .51946 .4626 L closepath p F P
0 g
s
.635 .761 .938 r
.25017 .35557 m .2605 .3527 L .26378 .35555 L p F P
0 g
s
.616 .764 .95 r
.2605 .3527 m .25017 .35557 L .24689 .35247 L p F P
0 g
s
.755 .696 .795 r
.20043 .36595 m .20911 .35941 L p .19525 .36285 L F P
0 g
s
.755 .696 .795 r
.19525 .36285 m .19649 .36463 L .20043 .36595 L p F P
0 g
s
.685 .747 .899 r
.23325 .35271 m .22286 .35727 L .21957 .3536 L p F P
0 g
s
.693 .313 .325 r
.32893 .47166 m .32905 .47177 L .32886 .47175 L closepath p F P
0 g
s
.721 .337 .321 r
.29877 .46429 m .2987 .46437 L .29862 .46427 L closepath p F P
0 g
s
.722 .337 .32 r
.29353 .46682 m .29031 .46285 L .29862 .46427 L p F P
0 g
s
.722 .337 .32 r
.29634 .4673 m .29353 .46682 L p .29862 .46427 L F P
0 g
s
.722 .337 .32 r
.29862 .46427 m .2987 .46437 L .29634 .4673 L p F P
0 g
s
.529 .766 .984 r
.29096 .35649 m .29162 .35641 L .299 .3582 L p F P
0 g
s
.548 .789 .988 r
.30129 .35516 m .29162 .35641 L .299 .3582 L p F P
0 g
s
.548 .789 .988 r
.299 .3582 m .30455 .35728 L .30129 .35516 L p F P
0 g
s
.677 .272 .271 r
.32639 .47467 m .33346 .47541 L .32905 .47177 L p F P
0 g
s
.677 .272 .271 r
.32905 .47177 m .32886 .47175 L .32639 .47467 L p F P
0 g
s
.523 .191 .347 r
.54294 .45798 m .54408 .4542 L .53244 .45661 L p F P
0 g
s
.523 .191 .347 r
.53244 .45661 m .53129 .4604 L .54294 .45798 L p F P
0 g
s
.69 .288 .281 r
.32397 .47437 m .32639 .47467 L .32886 .47175 L p F P
0 g
s
.69 .288 .281 r
.32886 .47175 m .31985 .47064 L .32397 .47437 L p F P
0 g
s
.714 .327 .314 r
.2987 .46437 m .30208 .46817 L .29634 .4673 L closepath p F P
0 g
s
.81 .587 .601 r
.19507 .40817 m .1971 .40885 L .19832 .40358 L p F P
0 g
s
.81 .587 .601 r
.19832 .40358 m .1945 .40231 L .19507 .40817 L p F P
0 g
s
.807 .611 .636 r
.19385 .39597 m .19316 .39574 L .19345 .39706 L closepath p F P
0 g
s
.568 .406 .622 r
.61182 .40092 m .61762 .40084 L .61209 .40287 L closepath p F P
0 g
s
.78 .692 .766 r
.1871 .37094 m .19317 .37319 L p .19649 .36463 L F P
0 g
s
.786 .673 .739 r
.18713 .37949 m .18791 .37977 L .19317 .37319 L p F P
0 g
s
.786 .673 .739 r
.18438 .37415 m .18713 .37949 L p .19317 .37319 L F P
0 g
s
.786 .673 .739 r
.19317 .37319 m .1871 .37094 L .18438 .37415 L p F P
0 g
s
.601 .768 .96 r
.26378 .35555 m .2741 .35329 L .27737 .3559 L p F P
0 g
s
.574 .771 .972 r
.2741 .35329 m .26378 .35555 L .2605 .3527 L p F P
0 g
s
.458 .788 .999 r
.33495 .36086 m .34536 .35981 L .34855 .36149 L p F P
0 g
s
.393 .775 .991 r
.34536 .35981 m .33495 .36086 L .33175 .35901 L p F P
0 g
s
.596 .179 .222 r
.41143 .47908 m .40056 .47913 L .40003 .47983 L p F P
0 g
s
.609 .195 .231 r
.40056 .47913 m .40003 .47983 L .39853 .4791 L closepath p F P
0 g
s
.807 .644 .68 r
.19057 .38761 m .19033 .38806 L .19081 .38824 L closepath p F P
0 g
s
.812 .632 .658 r
.1878 .39374 m .19316 .39574 L .19081 .38824 L p F P
0 g
s
.812 .632 .658 r
.19081 .38824 m .19033 .38806 L .1878 .39374 L p F P
0 g
s
.653 .673 .856 r
.59644 .35616 m .59452 .35311 L .58362 .35646 L p F P
0 g
s
.658 .699 .877 r
.59452 .35311 m .58362 .35646 L .58082 .35259 L p F P
0 g
s
.552 .167 .266 r
.46835 .47386 m .47495 .47537 L .46713 .47617 L closepath p F P
0 g
s
.796 .49 .47 r
.22413 .43635 m .23096 .43829 L .23002 .43367 L p F P
0 g
s
.796 .49 .47 r
.23002 .43367 m .22318 .43174 L .22413 .43635 L p F P
0 g
s
.802 .536 .537 r
.21587 .42315 m .21586 .42505 L .21561 .42498 L closepath p F P
0 g
s
.608 .189 .221 r
.39829 .4821 m .40003 .47983 L .39853 .4791 L p F P
0 g
s
.608 .189 .221 r
.39267 .48201 m .39829 .4821 L p .39853 .4791 L F P
0 g
s
.608 .189 .221 r
.38641 .47896 m .39267 .48201 L p .39853 .4791 L F P
0 g
s
.608 .189 .221 r
.39853 .4791 m .38645 .47892 L .38641 .47896 L p F P
0 g
s
.811 .566 .569 r
.19649 .41392 m .20295 .41601 L .20354 .41093 L p F P
0 g
s
.811 .566 .569 r
.20354 .41093 m .1971 .40885 L .19649 .41392 L p F P
0 g
s
.597 .184 .231 r
.41439 .47906 m .41367 .48004 L .41143 .47908 L closepath p F P
0 g
s
.596 .179 .222 r
.41219 .48207 m .41367 .48004 L .41143 .47908 L p F P
0 g
s
.596 .179 .222 r
.40522 .4821 m .41219 .48207 L p .41143 .47908 L F P
0 g
s
.596 .179 .222 r
.40003 .47983 m .40522 .4821 L p .41143 .47908 L F P
0 g
s
.538 .155 .263 r
.48546 .47101 m .48147 .47151 L .47976 .47486 L p F P
0 g
s
.807 .651 .688 r
.19033 .38806 m .19057 .38761 L .18752 .38035 L p F P
0 g
s
.583 .169 .222 r
.42519 .4788 m .41439 .47906 L .41367 .48004 L p F P
0 g
s
.817 .615 .629 r
.19204 .40143 m .19345 .39706 L .19316 .39574 L p F P
0 g
s
.817 .615 .629 r
.18599 .39919 m .19204 .40143 L p .19316 .39574 L F P
0 g
s
.817 .615 .629 r
.19316 .39574 m .1878 .39374 L .18599 .39919 L p F P
0 g
s
.807 .651 .688 r
.18752 .38035 m .18441 .38577 L .19033 .38806 L p F P
0 g
s
.814 .636 .661 r
.18182 .39147 m .1878 .39374 L .19033 .38806 L p F P
0 g
s
.814 .636 .661 r
.19033 .38806 m .18441 .38577 L .18182 .39147 L p F P
0 g
s
.621 .204 .23 r
.38645 .47892 m .38641 .47896 L .38632 .47891 L closepath p F P
0 g
s
.621 .204 .229 r
.38077 .48171 m .37487 .47849 L .38632 .47891 L p F P
0 g
s
.621 .204 .229 r
.38409 .48184 m .38077 .48171 L p .38632 .47891 L F P
0 g
s
.621 .204 .229 r
.38632 .47891 m .38641 .47896 L .38409 .48184 L p F P
0 g
s
.602 .512 .725 r
.62918 .37617 m .62776 .37146 L .61676 .37357 L p F P
0 g
s
.602 .512 .725 r
.61676 .37357 m .61884 .38029 L .62918 .37617 L p F P
0 g
s
.608 .532 .743 r
.6165 .37281 m .61676 .37357 L .62776 .37146 L p F P
0 g
s
.815 .611 .626 r
.19345 .39706 m .19204 .40143 L .1945 .40231 L closepath p F P
0 g
s
.617 .555 .762 r
.6139 .36603 m .6165 .37281 L .62682 .36865 L p F P
0 g
s
.608 .532 .743 r
.62776 .37146 m .62682 .36865 L .6165 .37281 L p F P
0 g
s
.611 .192 .222 r
.38641 .47896 m .39267 .48201 L .38409 .48184 L closepath p F P
0 g
s
.583 .172 .229 r
.42794 .47872 m .42733 .47959 L .42519 .4788 L closepath p F P
0 g
s
.583 .169 .222 r
.42581 .48177 m .42733 .47959 L .42519 .4788 L p F P
0 g
s
.583 .169 .222 r
.4186 .48194 m .42581 .48177 L p .42519 .4788 L F P
0 g
s
.583 .169 .222 r
.41367 .48004 m .4186 .48194 L p .42519 .4788 L F P
0 g
s
.724 .713 .839 r
.21397 .35662 m .20911 .35941 L .20583 .35536 L p F P
0 g
s
.755 .696 .795 r
.20911 .35941 m .20583 .35536 L .19525 .36285 L p F P
0 g
s
.59 .483 .7 r
.63072 .38216 m .62918 .37617 L .61884 .38029 L p F P
0 g
s
.59 .483 .7 r
.61884 .38029 m .6197 .38355 L .63072 .38216 L p F P
0 g
s
.57 .157 .22 r
.44004 .47818 m .42794 .47872 L .42733 .47959 L p F P
0 g
s
.811 .545 .536 r
.20288 .42092 m .20935 .423 L .20941 .41809 L p F P
0 g
s
.811 .545 .536 r
.20941 .41809 m .20295 .41601 L .20288 .42092 L p F P
0 g
s
.56 .776 .979 r
.29041 .3561 m .29096 .35649 L p .27737 .3559 L F P
0 g
s
.56 .776 .979 r
.27737 .3559 m .28339 .35488 L .29041 .3561 L p F P
0 g
s
.534 .764 .982 r
.28339 .35488 m .27737 .3559 L .2741 .35329 L p F P
0 g
s
.526 .263 .459 r
.59064 .43418 m .59107 .42994 L .5801 .43318 L p F P
0 g
s
.526 .263 .459 r
.5801 .43318 m .57971 .43673 L .59064 .43418 L p F P
0 g
s
.556 .377 .594 r
.62314 .40443 m .6126 .40827 L .61209 .40287 L p F P
0 g
s
.556 .377 .594 r
.62289 .40186 m .62314 .40443 L p .61209 .40287 L F P
0 g
s
.556 .377 .594 r
.61209 .40287 m .61762 .40084 L .62289 .40186 L p F P
0 g
s
.537 .157 .268 r
.49385 .46994 m .49274 .47221 L .48546 .47101 L closepath p F P
0 g
s
.538 .155 .263 r
.49219 .47331 m .49274 .47221 L .48546 .47101 L p F P
0 g
s
.538 .155 .263 r
.47976 .47486 m .49219 .47331 L p .48546 .47101 L F P
0 g
s
.43 .79 .996 r
.35948 .36072 m .36217 .36201 L p .34855 .36149 L F P
0 g
s
.43 .79 .996 r
.34855 .36149 m .3579 .3606 L .35948 .36072 L p F P
0 g
s
.361 .769 .982 r
.3579 .3606 m .34855 .36149 L .34536 .35981 L p F P
0 g
s
.625 .205 .227 r
.36957 .48126 m .38077 .48171 L .37487 .47849 L p F P
0 g
s
.625 .205 .227 r
.37487 .47849 m .37199 .47838 L .36957 .48126 L p F P
0 g
s
.52 .233 .419 r
.57893 .44175 m .57962 .43757 L .56848 .4406 L p F P
0 g
s
.52 .233 .419 r
.56848 .4406 m .56777 .44477 L .57893 .44175 L p F P
0 g
s
.745 .376 .354 r
.26623 .45829 m .2741 .45986 L .27147 .45573 L p F P
0 g
s
.745 .376 .354 r
.26509 .45649 m .26623 .45829 L p .27147 .45573 L F P
0 g
s
.745 .376 .354 r
.27147 .45573 m .26642 .45473 L .26509 .45649 L p F P
0 g
s
.587 .469 .685 r
.63091 .38294 m .63072 .38216 L .6197 .38355 L p F P
0 g
s
.587 .469 .685 r
.6197 .38355 m .62053 .38702 L .63091 .38294 L p F P
0 g
s
.765 .417 .395 r
.24865 .45074 m .25616 .45244 L .25409 .44814 L p F P
0 g
s
.765 .417 .395 r
.24837 .45015 m .24865 .45074 L p .25409 .44814 L F P
0 g
s
.765 .417 .395 r
.25409 .44814 m .25022 .44727 L .24837 .45015 L p F P
0 g
s
.529 .219 .386 r
.54447 .45256 m .55142 .45254 L .54408 .4542 L closepath p F P
0 g
s
.638 .221 .236 r
.3694 .48125 m .36957 .48126 L .37199 .47838 L p F P
0 g
s
.638 .221 .236 r
.37199 .47838 m .3639 .47791 L .3694 .48125 L p F P
0 g
s
.531 .289 .494 r
.60192 .42651 m .60215 .42189 L .59132 .42532 L p F P
0 g
s
.531 .289 .494 r
.59132 .42532 m .59107 .42994 L .60192 .42651 L p F P
0 g
s
.627 .822 .976 r
.52326 .35303 m .52535 .35443 L .51382 .35706 L p F P
0 g
s
.627 .822 .976 r
.51382 .35706 m .51246 .35611 L .52326 .35303 L p F P
0 g
s
.78 .692 .766 r
.19649 .36463 m .19427 .36373 L .1871 .37094 L p F P
0 g
s
.771 .7 .784 r
.19525 .36285 m .19427 .36373 L .19649 .36463 L closepath p F P
0 g
s
.795 .654 .707 r
.18791 .37977 m .18713 .37949 L .18752 .38035 L closepath p F P
0 g
s
.687 .279 .268 r
.31485 .4732 m .32397 .47437 L .31985 .47064 L p F P
0 g
s
.687 .279 .268 r
.31204 .47067 m .31485 .4732 L p .31985 .47064 L F P
0 g
s
.687 .279 .268 r
.31985 .47064 m .31287 .46976 L .31204 .47067 L p F P
0 g
s
.569 .159 .225 r
.44124 .47812 m .441 .47848 L .44004 .47818 L closepath p F P
0 g
s
.57 .157 .22 r
.43917 .4812 m .441 .47848 L .44004 .47818 L p F P
0 g
s
.57 .157 .22 r
.43299 .48147 m .43917 .4812 L p .44004 .47818 L F P
0 g
s
.57 .157 .22 r
.42733 .47959 m .43299 .48147 L p .44004 .47818 L F P
0 g
s
.643 .628 .82 r
.59732 .35761 m .60826 .35445 L .61107 .3598 L p F P
0 g
s
.647 .661 .849 r
.59644 .35616 m .59732 .35761 L .60826 .35445 L p F P
0 g
s
.567 .182 .272 r
.45468 .47658 m .45644 .47709 L .4543 .47727 L closepath p F P
0 g
s
.809 .656 .693 r
.18441 .38577 m .18752 .38035 L .18713 .37949 L p F P
0 g
s
.558 .147 .218 r
.45229 .48038 m .4543 .47727 L .44124 .47812 L p F P
0 g
s
.558 .147 .218 r
.44867 .48061 m .45229 .48038 L p .44124 .47812 L F P
0 g
s
.558 .147 .218 r
.44124 .47812 m .441 .47848 L .44867 .48061 L p F P
0 g
s
.617 .555 .762 r
.62682 .36865 m .62488 .36348 L .6139 .36603 L p F P
0 g
s
.623 .58 .785 r
.61304 .36404 m .6139 .36603 L .62488 .36348 L p F P
0 g
s
.801 .514 .502 r
.21445 .42924 m .21636 .4298 L .21586 .42505 L p F P
0 g
s
.801 .514 .502 r
.21586 .42505 m .21561 .42498 L .21445 .42924 L p F P
0 g
s
.819 .594 .598 r
.19089 .40667 m .19507 .40817 L .1945 .40231 L p F P
0 g
s
.819 .594 .598 r
.1945 .40231 m .19204 .40143 L .19089 .40667 L p F P
0 g
s
.599 .182 .223 r
.40003 .47983 m .40522 .4821 L .39829 .4821 L closepath p F P
0 g
s
.81 .523 .504 r
.20978 .42777 m .21445 .42924 L .21561 .42498 L p F P
0 g
s
.81 .523 .504 r
.21561 .42498 m .20935 .423 L .20978 .42777 L p F P
0 g
s
.782 .453 .431 r
.23239 .44276 m .23955 .44459 L .23805 .44013 L p F P
0 g
s
.782 .453 .431 r
.23181 .44102 m .23239 .44276 L p .23805 .44013 L F P
0 g
s
.782 .453 .431 r
.23805 .44013 m .23298 .43885 L .23181 .44102 L p F P
0 g
s
.724 .337 .316 r
.28528 .46538 m .29353 .46682 L .29031 .46285 L p F P
0 g
s
.724 .337 .316 r
.29031 .46285 m .282 .46142 L .28528 .46538 L p F P
0 g
s
.801 .668 .717 r
.18438 .37415 m .18205 .37745 L .18713 .37949 L closepath p F P
0 g
s
.809 .656 .693 r
.1785 .38346 m .18441 .38577 L p .18713 .37949 L F P
0 g
s
.809 .656 .693 r
.18713 .37949 m .18205 .37745 L .1785 .38346 L p F P
0 g
s
.575 .44 .659 r
.63212 .38913 m .63091 .38294 L .62053 .38702 L p F P
0 g
s
.575 .44 .659 r
.62053 .38702 m .62175 .39322 L .63212 .38913 L p F P
0 g
s
.531 .763 .982 r
.29096 .35649 m .29162 .35641 L .29041 .3561 L closepath p F P
0 g
s
.635 .212 .223 r
.3587 .48059 m .3694 .48125 L .3639 .47791 L p F P
0 g
s
.635 .212 .223 r
.35594 .47891 m .3587 .48059 L p .3639 .47791 L F P
0 g
s
.635 .212 .223 r
.3639 .47791 m .35719 .47751 L .35594 .47891 L p F P
0 g
s
.515 .208 .385 r
.56688 .44876 m .56777 .44477 L .55647 .44759 L p F P
0 g
s
.515 .208 .385 r
.55647 .44759 m .55556 .45159 L .56688 .44876 L p F P
0 g
s
.711 .725 .861 r
.21397 .35662 m .21957 .3536 L .21627 .35007 L p F P
0 g
s
.711 .725 .861 r
.21627 .35007 m .20743 .35451 L .21397 .35662 L p F P
0 g
s
.724 .713 .839 r
.20583 .35536 m .20743 .35451 L .21397 .35662 L p F P
0 g
s
.406 .79 .991 r
.37448 .36182 m .3758 .36239 L p .36217 .36201 L F P
0 g
s
.406 .79 .991 r
.36217 .36201 m .36811 .36146 L .37448 .36182 L p F P
0 g
s
.431 .788 .996 r
.36217 .36201 m .36811 .36146 L .35948 .36072 L closepath p F P
0 g
s
.517 .161 .302 r
.5263 .46134 m .51946 .4626 L .51807 .46618 L p F P
0 g
s
.63 .597 .798 r
.61107 .3598 m .61304 .36404 L .62335 .35986 L p F P
0 g
s
.623 .58 .785 r
.62488 .36348 m .62335 .35986 L .61304 .36404 L p F P
0 g
s
.527 .763 .983 r
.29802 .35316 m .30129 .35516 L .29162 .35641 L p F P
0 g
s
.527 .763 .983 r
.2877 .35414 m .29802 .35316 L p .29162 .35641 L F P
0 g
s
.527 .763 .983 r
.29162 .35641 m .29041 .3561 L .2877 .35414 L p F P
0 g
s
.535 .315 .527 r
.61284 .41825 m .61284 .41339 L .60216 .41703 L p F P
0 g
s
.535 .315 .527 r
.60216 .41703 m .60215 .42189 L .61284 .41825 L p F P
0 g
s
.558 .146 .217 r
.441 .47848 m .44867 .48061 L .43917 .4812 L closepath p F P
0 g
s
.775 .43 .401 r
.25022 .44727 m .24837 .45015 L .24672 .4464 L closepath p F P
0 g
s
.586 .171 .223 r
.41367 .48004 m .4186 .48194 L .41219 .48207 L closepath p F P
0 g
s
.525 .145 .262 r
.50443 .47155 m .50606 .46817 L .49385 .46994 L p F P
0 g
s
.525 .145 .262 r
.49667 .47268 m .50443 .47155 L p .49385 .46994 L F P
0 g
s
.525 .145 .262 r
.49385 .46994 m .49274 .47221 L .49667 .47268 L p F P
0 g
s
.649 .229 .233 r
.35719 .47751 m .35594 .47891 L .35334 .47721 L closepath p F P
0 g
s
.756 .391 .362 r
.26642 .45473 m .26509 .45649 L .26368 .45413 L closepath p F P
0 g
s
.65 .669 .855 r
.59452 .35311 m .59644 .35616 L .60688 .35214 L p F P
0 g
s
.647 .661 .849 r
.60826 .35445 m .60688 .35214 L .59644 .35616 L p F P
0 g
s
.778 .696 .772 r
.18146 .36887 m .1871 .37094 L .19427 .36373 L p F P
0 g
s
.778 .696 .772 r
.1812 .36845 m .18146 .36887 L p .19427 .36373 L F P
0 g
s
.778 .696 .772 r
.19427 .36373 m .18852 .36135 L .1812 .36845 L p F P
0 g
s
.768 .704 .792 r
.19427 .36373 m .19525 .36285 L .19198 .3584 L p F P
0 g
s
.768 .704 .792 r
.19198 .3584 m .18852 .36135 L .19427 .36373 L p F P
0 g
s
.745 .722 .831 r
.19525 .36285 m .20583 .35536 L .20434 .35359 L p F P
0 g
s
.745 .722 .831 r
.19198 .3584 m .19525 .36285 L p .20434 .35359 L F P
0 g
s
.572 .16 .221 r
.42733 .47959 m .43299 .48147 L .42581 .48177 L closepath p F P
0 g
s
.562 .776 .978 r
.29041 .3561 m .2877 .35414 L .28339 .35488 L closepath p F P
0 g
s
.699 .295 .278 r
.31287 .46976 m .31204 .47067 L .31078 .46947 L closepath p F P
0 g
s
.544 .135 .216 r
.45644 .47709 m .4543 .47727 L .45229 .48038 L p F P
0 g
s
.393 .793 .985 r
.38898 .36242 m .38944 .3626 L p .3758 .36239 L F P
0 g
s
.393 .793 .985 r
.3758 .36239 m .37907 .36208 L .38898 .36242 L p F P
0 g
s
.414 .793 .992 r
.3758 .36239 m .37907 .36208 L .37448 .36182 L closepath p F P
0 g
s
.821 .597 .599 r
.18481 .40445 m .19089 .40667 L .19204 .40143 L p F P
0 g
s
.821 .597 .599 r
.19204 .40143 m .18599 .39919 L .18481 .40445 L p F P
0 g
s
.797 .489 .467 r
.21733 .4344 m .22413 .43635 L .22318 .43174 L p F P
0 g
s
.797 .489 .467 r
.22318 .43174 m .21636 .4298 L .21733 .4344 L p F P
0 g
s
.649 .228 .232 r
.34837 .47981 m .34315 .47639 L .35334 .47721 L p F P
0 g
s
.649 .228 .232 r
.35466 .48033 m .34837 .47981 L p .35334 .47721 L F P
0 g
s
.649 .228 .232 r
.35334 .47721 m .35594 .47891 L .35466 .48033 L p F P
0 g
s
.433 .77 .997 r
.3149 .35624 m .30455 .35728 L .30129 .35516 L p F P
0 g
s
.818 .617 .631 r
.17996 .39694 m .18599 .39919 L .1878 .39374 L p F P
0 g
s
.818 .617 .631 r
.1878 .39374 m .18182 .39147 L .17996 .39694 L p F P
0 g
s
.545 .14 .225 r
.46713 .47617 m .46533 .47909 L .45644 .47709 L closepath p F P
0 g
s
.544 .135 .216 r
.46518 .47932 m .46533 .47909 L .45644 .47709 L p F P
0 g
s
.544 .135 .216 r
.45229 .48038 m .46518 .47932 L p .45644 .47709 L F P
0 g
s
.786 .672 .738 r
.1871 .37094 m .18146 .36887 L .18438 .37415 L closepath p F P
0 g
s
.813 .568 .568 r
.19497 .41342 m .19649 .41392 L .1971 .40885 L p F P
0 g
s
.813 .568 .568 r
.1971 .40885 m .19507 .40817 L .19497 .41342 L p F P
0 g
s
.7 .295 .277 r
.30598 .47196 m .30208 .46817 L .31078 .46947 L p F P
0 g
s
.7 .295 .277 r
.31027 .4726 m .30598 .47196 L p .31078 .46947 L F P
0 g
s
.7 .295 .277 r
.31078 .46947 m .31204 .47067 L .31027 .4726 L p F P
0 g
s
.668 .268 .277 r
.3424 .4758 m .34315 .47639 L .34201 .47629 L closepath p F P
0 g
s
.66 .761 .925 r
.55346 .35315 m .56433 .34971 L .56714 .35265 L p F P
0 g
s
.656 .789 .946 r
.56433 .34971 m .55346 .35315 L .55064 .35058 L p F P
0 g
s
.653 .788 .946 r
.5398 .35395 m .55064 .35058 L .55346 .35315 L p F P
0 g
s
.509 .177 .34 r
.55142 .45254 m .54408 .4542 L .54294 .45798 L p F P
0 g
s
.645 .814 .965 r
.55064 .35058 m .5398 .35395 L .53695 .35171 L p F P
0 g
s
.642 .81 .964 r
.52613 .35496 m .53695 .35171 L .5398 .35395 L p F P
0 g
s
.757 .391 .361 r
.25863 .45662 m .25616 .45244 L .26368 .45413 L p F P
0 g
s
.757 .391 .361 r
.26406 .45784 m .25863 .45662 L p .26368 .45413 L F P
0 g
s
.757 .391 .361 r
.26368 .45413 m .26509 .45649 L .26406 .45784 L p F P
0 g
s
.661 .732 .902 r
.56714 .35265 m .57802 .3492 L .58082 .35259 L p F P
0 g
s
.661 .761 .924 r
.57802 .3492 m .56714 .35265 L .56433 .34971 L p F P
0 g
s
.632 .832 .977 r
.53666 .35152 m .53695 .35171 L .52613 .35496 L p F P
0 g
s
.632 .832 .977 r
.52613 .35496 m .52535 .35443 L .53666 .35152 L p F P
0 g
s
.652 .756 .926 r
.23325 .35271 m .24359 .34948 L .24689 .35247 L p F P
0 g
s
.635 .759 .937 r
.24359 .34948 m .23325 .35271 L .22995 .34946 L p F P
0 g
s
.685 .747 .899 r
.21957 .3536 m .22995 .34946 L .23325 .35271 L p F P
0 g
s
.39 .797 .981 r
.40307 .3626 m .40309 .36261 L p .38944 .3626 L F P
0 g
s
.39 .797 .981 r
.38944 .3626 m .39074 .36246 L .40307 .3626 L p F P
0 g
s
.407 .798 .988 r
.38944 .3626 m .39074 .36246 L .38898 .36242 L closepath p F P
0 g
s
.532 .175 .307 r
.50641 .46728 m .50949 .46761 L .50606 .46817 L closepath p F P
0 g
s
.791 .465 .436 r
.23298 .43885 m .23181 .44102 L .23096 .43829 L closepath p F P
0 g
s
.814 .638 .664 r
.17584 .38919 m .18182 .39147 L .18441 .38577 L p F P
0 g
s
.814 .638 .664 r
.18441 .38577 m .1785 .38346 L .17584 .38919 L p F P
0 g
s
.738 .373 .362 r
.28187 .46123 m .282 .46142 L .28177 .46138 L closepath p F P
0 g
s
.776 .43 .401 r
.24147 .44892 m .23955 .44459 L .24672 .4464 L p F P
0 g
s
.776 .43 .401 r
.24807 .45061 m .24147 .44892 L p .24672 .4464 L F P
0 g
s
.776 .43 .401 r
.24672 .4464 m .24837 .45015 L .24807 .45061 L p F P
0 g
s
.671 .751 .91 r
.22995 .34946 m .21957 .3536 L .21627 .35007 L p F P
0 g
s
.801 .675 .725 r
.18205 .37745 m .18438 .37415 L .18146 .36887 L p F P
0 g
s
.812 .545 .535 r
.19644 .41884 m .20288 .42092 L .20295 .41601 L p F P
0 g
s
.812 .545 .535 r
.20295 .41601 m .19649 .41392 L .19644 .41884 L p F P
0 g
s
.556 .378 .596 r
.61762 .40084 m .6226 .399 L .62289 .40186 L closepath p F P
0 g
s
.63 .597 .798 r
.62335 .35986 m .62204 .35697 L .61107 .3598 L p F P
0 g
s
.638 .62 .816 r
.62204 .35697 m .61107 .3598 L .60826 .35445 L p F P
0 g
s
.561 .405 .628 r
.63298 .39491 m .63212 .38913 L .62175 .39322 L p F P
0 g
s
.561 .405 .628 r
.62175 .39322 m .6226 .399 L .63298 .39491 L p F P
0 g
s
.6 .851 .992 r
.52326 .35303 m .51246 .35611 L .50957 .35443 L p F P
0 g
s
.599 .843 .991 r
.49879 .35732 m .50957 .35443 L .51246 .35611 L p F P
0 g
s
.726 .336 .311 r
.2792 .46429 m .28528 .46538 L .282 .46142 L p F P
0 g
s
.726 .336 .311 r
.282 .46142 m .28177 .46138 L .2792 .46429 L p F P
0 g
s
.738 .352 .32 r
.27714 .46389 m .2792 .46429 L .28177 .46138 L p F P
0 g
s
.738 .352 .32 r
.28177 .46138 m .2741 .45986 L .27714 .46389 L p F P
0 g
s
.616 .764 .95 r
.24689 .35247 m .25721 .34997 L .2605 .3527 L p F P
0 g
s
.594 .765 .961 r
.25721 .34997 m .24689 .35247 L .24359 .34948 L p F P
0 g
s
.54 .342 .56 r
.62339 .40955 m .62314 .40443 L .6126 .40827 L p F P
0 g
s
.54 .342 .56 r
.6126 .40827 m .61284 .41339 L .62339 .40955 L p F P
0 g
s
.515 .16 .303 r
.53129 .4604 m .53088 .46148 L .5263 .46134 L closepath p F P
0 g
s
.517 .161 .302 r
.52992 .46398 m .53088 .46148 L .5263 .46134 L p F P
0 g
s
.517 .161 .302 r
.51807 .46618 m .52992 .46398 L p .5263 .46134 L F P
0 g
s
.658 .699 .877 r
.58082 .35259 m .59173 .34918 L .59452 .35311 L p F P
0 g
s
.661 .728 .899 r
.59173 .34918 m .58082 .35259 L .57802 .3492 L p F P
0 g
s
.821 .576 .567 r
.19029 .41175 m .19497 .41342 L .19507 .40817 L p F P
0 g
s
.821 .576 .567 r
.19507 .40817 m .19089 .40667 L .19029 .41175 L p F P
0 g
s
.649 .224 .222 r
.33937 .47904 m .34837 .47981 L .34315 .47639 L p F P
0 g
s
.649 .224 .222 r
.34315 .47639 m .34201 .47629 L .33937 .47904 L p F P
0 g
s
.4 .805 .982 r
.40309 .36261 m .40315 .3626 L .41644 .36246 L p F P
0 g
s
.409 .806 .985 r
.40309 .36261 m .40315 .3626 L .40307 .3626 L closepath p F P
0 g
s
.569 .858 .996 r
.50957 .35443 m .49879 .35732 L .49588 .35582 L p F P
0 g
s
.572 .849 .996 r
.48512 .3585 m .49588 .35582 L .49879 .35732 L p F P
0 g
s
.404 .805 .984 r
.40315 .3626 m .40307 .3626 L .39998 .36149 L p F P
0 g
s
.388 .797 .981 r
.40307 .3626 m .39998 .36149 L .39074 .36246 L closepath p F P
0 g
s
.431 .822 .986 r
.41367 .36135 m .40315 .3626 L .41644 .36246 L p F P
0 g
s
.404 .805 .984 r
.41057 .36049 m .41367 .36135 L .40315 .3626 L p F P
0 g
s
.404 .805 .984 r
.39998 .36149 m .41057 .36049 L p .40315 .3626 L F P
0 g
s
.44 .778 .998 r
.31814 .35815 m .32852 .3573 L .33175 .35901 L p F P
0 g
s
.37 .761 .987 r
.32852 .3573 m .31814 .35815 L .3149 .35624 L p F P
0 g
s
.663 .241 .233 r
.33832 .47893 m .33937 .47904 L .34201 .47629 L p F P
0 g
s
.663 .241 .233 r
.34201 .47629 m .33346 .47541 L .33832 .47893 L p F P
0 g
s
.534 .764 .982 r
.2741 .35329 m .27615 .35302 L .28339 .35488 L p F P
0 g
s
.556 .784 .984 r
.28441 .35192 m .27615 .35302 L .28339 .35488 L p F P
0 g
s
.556 .784 .984 r
.28339 .35488 m .2877 .35414 L .28441 .35192 L p F P
0 g
s
.401 .797 .986 r
.39686 .36056 m .39998 .36149 L .39074 .36246 L p F P
0 g
s
.401 .797 .986 r
.38631 .36138 m .39686 .36056 L p .39074 .36246 L F P
0 g
s
.401 .797 .986 r
.39074 .36246 m .38898 .36242 L .38631 .36138 L p F P
0 g
s
.431 .822 .986 r
.41644 .36246 m .41675 .36241 L .41367 .36135 L p F P
0 g
s
.47 .819 .998 r
.41684 .36245 m .41675 .36241 L .41644 .36246 L closepath p F P
0 g
s
.456 .813 .997 r
.42736 .36096 m .43028 .36195 L .41684 .36245 L p F P
0 g
s
.456 .813 .997 r
.41684 .36245 m .41675 .36241 L .42736 .36096 L p F P
0 g
s
.716 .719 .851 r
.20743 .35451 m .20434 .35359 L .20583 .35536 L closepath p F P
0 g
s
.792 .465 .435 r
.22552 .44084 m .22413 .43635 L .23096 .43829 L p F P
0 g
s
.792 .465 .435 r
.23106 .44242 m .22552 .44084 L p .23096 .43829 L F P
0 g
s
.792 .465 .435 r
.23096 .43829 m .23181 .44102 L .23106 .44242 L p F P
0 g
s
.392 .792 .985 r
.38898 .36242 m .38631 .36138 L .37907 .36208 L closepath p F P
0 g
s
.531 .125 .217 r
.47495 .47537 m .46713 .47617 L .46533 .47909 L p F P
0 g
s
.538 .857 .997 r
.49588 .35582 m .48512 .3585 L .48218 .35715 L p F P
0 g
s
.542 .85 .998 r
.47144 .35959 m .48218 .35715 L .48512 .3585 L p F P
0 g
s
.526 .262 .458 r
.59062 .43435 m .59064 .43418 L .57971 .43673 L p F P
0 g
s
.526 .262 .458 r
.57971 .43673 m .57962 .43757 L .59062 .43435 L p F P
0 g
s
.344 .792 .954 r
.42736 .36096 m .41675 .36241 L .41367 .36135 L p F P
0 g
s
.811 .524 .503 r
.20331 .42569 m .20978 .42777 L .20935 .423 L p F P
0 g
s
.811 .524 .503 r
.20935 .423 m .20288 .42092 L .20331 .42569 L p F P
0 g
s
.801 .675 .725 r
.17626 .3751 m .18205 .37745 L p .18146 .36887 L F P
0 g
s
.808 .658 .696 r
.1726 .38115 m .1785 .38346 L .18205 .37745 L p F P
0 g
s
.808 .658 .696 r
.18205 .37745 m .17626 .3751 L .1726 .38115 L p F P
0 g
s
.574 .771 .972 r
.27214 .3518 m .2741 .35329 L p .2605 .3527 L F P
0 g
s
.574 .771 .972 r
.2605 .3527 m .26887 .35117 L .27214 .3518 L p F P
0 g
s
.546 .765 .979 r
.26887 .35117 m .2605 .3527 L .25721 .34997 L p F P
0 g
s
.525 .852 .997 r
.48122 .35682 m .48218 .35715 L .47144 .35959 L p F P
0 g
s
.525 .852 .997 r
.47144 .35959 m .46886 .35853 L .48122 .35682 L p F P
0 g
s
.513 .845 .997 r
.46886 .35853 m .47144 .35959 L p .45777 .36057 L F P
0 g
s
.444 .827 .988 r
.44344 .36115 m .44409 .36137 L p .43042 .36199 L F P
0 g
s
.444 .827 .988 r
.43042 .36199 m .43101 .3619 L .44344 .36115 L p F P
0 g
s
.44 .827 .986 r
.43042 .36199 m .43101 .3619 L .43028 .36195 L closepath p F P
0 g
s
.513 .845 .997 r
.45777 .36057 m .46632 .35881 L .46886 .35853 L p F P
0 g
s
.498 .848 .994 r
.45777 .36057 m .46632 .35881 L .45631 .36002 L closepath p F P
0 g
s
.477 .838 .993 r
.45631 .36002 m .45777 .36057 L p .44409 .36137 L F P
0 g
s
.713 .721 .856 r
.20743 .35451 m .21627 .35007 L p .20253 .3515 L F P
0 g
s
.713 .721 .856 r
.20253 .3515 m .20434 .35359 L .20743 .35451 L p F P
0 g
s
.408 .791 .991 r
.38316 .36036 m .38631 .36138 L .37907 .36208 L p F P
0 g
s
.408 .791 .991 r
.37265 .36104 m .38316 .36036 L p .37907 .36208 L F P
0 g
s
.408 .791 .991 r
.37907 .36208 m .37448 .36182 L .37265 .36104 L p F P
0 g
s
.477 .838 .993 r
.44409 .36137 m .4473 .36079 L .45631 .36002 L p F P
0 g
s
.466 .838 .99 r
.44409 .36137 m .4473 .36079 L .44344 .36115 L closepath p F P
0 g
s
.691 .284 .27 r
.31204 .47067 m .31485 .4732 L .31027 .4726 L closepath p F P
0 g
s
.65 .669 .855 r
.60688 .35214 m .60546 .34983 L .59452 .35311 L p F P
0 g
s
.656 .694 .873 r
.60546 .34983 m .59452 .35311 L .59173 .34918 L p F P
0 g
s
.628 .832 .979 r
.5341 .34985 m .53666 .35152 L .52535 .35443 L p F P
0 g
s
.628 .832 .979 r
.52535 .35443 m .52326 .35303 L .5341 .34985 L p F P
0 g
s
.509 .128 .254 r
.50949 .46761 m .50606 .46817 L .50443 .47155 L p F P
0 g
s
.7 .289 .264 r
.29735 .47063 m .30598 .47196 L .30208 .46817 L p F P
0 g
s
.7 .289 .264 r
.29515 .4685 m .29735 .47063 L p .30208 .46817 L F P
0 g
s
.7 .289 .264 r
.30208 .46817 m .29634 .4673 L .29515 .4685 L p F P
0 g
s
.436 .826 .985 r
.43101 .3619 m .43028 .36195 L .42736 .36096 L p F P
0 g
s
.437 .826 .986 r
.44344 .36115 m .44106 .36032 L .43101 .3619 L closepath p F P
0 g
s
.436 .826 .985 r
.43802 .35952 m .44106 .36032 L .43101 .3619 L p F P
0 g
s
.436 .826 .985 r
.42736 .36096 m .43802 .35952 L p .43101 .3619 L F P
0 g
s
.407 .791 .991 r
.37448 .36182 m .37265 .36104 L .36811 .36146 L closepath p F P
0 g
s
.502 .147 .297 r
.54175 .46123 m .54294 .45798 L .53129 .4604 L p F P
0 g
s
.502 .147 .297 r
.53129 .4604 m .53088 .46148 L .54175 .46123 L p F P
0 g
s
.393 .775 .991 r
.34403 .35918 m .34536 .35981 L p .33175 .35901 L F P
0 g
s
.393 .775 .991 r
.33175 .35901 m .33837 .35857 L .34403 .35918 L p F P
0 g
s
.343 .751 .981 r
.33837 .35857 m .33175 .35901 L .32852 .3573 L p F P
0 g
s
.506 .221 .415 r
.58994 .43852 m .59062 .43435 L .57962 .43757 L p F P
0 g
s
.506 .221 .415 r
.57962 .43757 m .57893 .44175 L .58994 .43852 L p F P
0 g
s
.514 .253 .457 r
.60156 .43007 m .60192 .42651 L .59107 .42994 L p F P
0 g
s
.514 .253 .457 r
.59107 .42994 m .59064 .43418 L .60156 .43007 L p F P
0 g
s
.659 .23 .217 r
.32878 .4779 m .33832 .47893 L .33346 .47541 L p F P
0 g
s
.659 .23 .217 r
.32548 .47553 m .32878 .4779 L p .33346 .47541 L F P
0 g
s
.659 .23 .217 r
.33346 .47541 m .32639 .47467 L .32548 .47553 L p F P
0 g
s
.528 .123 .217 r
.47976 .47486 m .47904 .47605 L .47495 .47537 L closepath p F P
0 g
s
.531 .125 .217 r
.47785 .47801 m .47904 .47605 L .47495 .47537 L p F P
0 g
s
.531 .125 .217 r
.46609 .47923 m .47785 .47801 L p .47495 .47537 L F P
0 g
s
.531 .125 .217 r
.46533 .47909 m .46609 .47923 L p .47495 .47537 L F P
0 g
s
.54 .757 .977 r
.2741 .35329 m .27615 .35302 L .27214 .3518 L closepath p F P
0 g
s
.799 .49 .466 r
.21281 .43309 m .21733 .4344 L .21636 .4298 L p F P
0 g
s
.799 .49 .466 r
.21636 .4298 m .21445 .42924 L .21281 .43309 L p F P
0 g
s
.507 .176 .341 r
.55556 .45159 m .55535 .4523 L .55142 .45254 L closepath p F P
0 g
s
.509 .177 .34 r
.55444 .45537 m .55535 .4523 L .55142 .45254 L p F P
0 g
s
.509 .177 .34 r
.54294 .45798 m .55444 .45537 L p .55142 .45254 L F P
0 g
s
.425 .787 .996 r
.36947 .35989 m .37265 .36104 L .36811 .36146 L p F P
0 g
s
.425 .787 .996 r
.359 .36049 m .36947 .35989 L p .36811 .36146 L F P
0 g
s
.425 .787 .996 r
.36811 .36146 m .35948 .36072 L .359 .36049 L p F P
0 g
s
.758 .387 .353 r
.25117 .4549 m .25863 .45662 L .25616 .45244 L p F P
0 g
s
.758 .387 .353 r
.25616 .45244 m .24865 .45074 L .25117 .4549 L p F P
0 g
s
.508 .13 .259 r
.51807 .46618 m .51722 .46801 L .50949 .46761 L closepath p F P
0 g
s
.509 .128 .254 r
.51648 .46957 m .51722 .46801 L .50949 .46761 L p F P
0 g
s
.509 .128 .254 r
.50443 .47155 m .51648 .46957 L p .50949 .46761 L F P
0 g
s
.773 .685 .766 r
.17797 .36333 m .18271 .35899 L .18852 .36135 L p F P
0 g
s
.773 .685 .766 r
.18852 .36135 m .1812 .36845 L .17797 .36333 L p F P
0 g
s
.763 .707 .799 r
.18852 .36135 m .19198 .3584 L .1887 .35414 L p F P
0 g
s
.763 .707 .799 r
.1887 .35414 m .18271 .35899 L .18852 .36135 L p F P
0 g
s
.639 .216 .224 r
.35594 .47891 m .3587 .48059 L .35466 .48033 L closepath p F P
0 g
s
.501 .195 .379 r
.57805 .44573 m .57893 .44175 L .56777 .44477 L p F P
0 g
s
.501 .195 .379 r
.56777 .44477 m .56688 .44876 L .57805 .44573 L p F P
0 g
s
.793 .684 .744 r
.1812 .36845 m .18101 .36868 L .18146 .36887 L closepath p F P
0 g
s
.801 .675 .725 r
.18146 .36887 m .18101 .36868 L .17626 .3751 L p F P
0 g
s
.822 .599 .6 r
.17875 .40221 m .18481 .40445 L .18599 .39919 L p F P
0 g
s
.822 .599 .6 r
.18599 .39919 m .17996 .39694 L .17875 .40221 L p F P
0 g
s
.739 .707 .821 r
.20128 .35226 m .19198 .3584 L .1887 .35414 L p F P
0 g
s
.745 .722 .831 r
.20434 .35359 m .20128 .35226 L .19198 .3584 L p F P
0 g
s
.737 .347 .313 r
.26932 .46229 m .27714 .46389 L .2741 .45986 L p F P
0 g
s
.737 .347 .313 r
.2741 .45986 m .26623 .45829 L .26932 .46229 L p F P
0 g
s
.736 .726 .842 r
.20253 .3515 m .20128 .35226 L .20434 .35359 L closepath p F P
0 g
s
.519 .279 .492 r
.61263 .42288 m .61284 .41825 L .60215 .42189 L p F P
0 g
s
.519 .279 .492 r
.60215 .42189 m .60192 .42651 L .61263 .42288 L p F P
0 g
s
.463 .838 .989 r
.4473 .36079 m .44344 .36115 L .44106 .36032 L p F P
0 g
s
.595 .504 .722 r
.6394 .37184 m .63881 .36982 L .62776 .37146 L p F P
0 g
s
.595 .504 .722 r
.62776 .37146 m .62918 .37617 L .6394 .37184 L p F P
0 g
s
.598 .522 .74 r
.62682 .36865 m .62776 .37146 L .63881 .36982 L p F P
0 g
s
.823 .578 .568 r
.1842 .40953 m .19029 .41175 L .19089 .40667 L p F P
0 g
s
.823 .578 .568 r
.19089 .40667 m .18481 .40445 L .1842 .40953 L p F P
0 g
s
.792 .689 .752 r
.18101 .36868 m .1812 .36845 L .17797 .36333 L p F P
0 g
s
.749 .381 .356 r
.26509 .45649 m .26623 .45829 L .26406 .45784 L closepath p F P
0 g
s
.819 .619 .633 r
.17394 .39468 m .17996 .39694 L .18182 .39147 L p F P
0 g
s
.819 .619 .633 r
.18182 .39147 m .17584 .38919 L .17394 .39468 L p F P
0 g
s
.777 .427 .392 r
.23435 .44709 m .24147 .44892 L .23955 .44459 L p F P
0 g
s
.777 .427 .392 r
.23955 .44459 m .23239 .44276 L .23435 .44709 L p F P
0 g
s
.792 .689 .752 r
.17797 .36333 m .17538 .36626 L .18101 .36868 L p F P
0 g
s
.801 .679 .73 r
.17046 .37273 m .17626 .3751 L .18101 .36868 L p F P
0 g
s
.801 .679 .73 r
.18101 .36868 m .17538 .36626 L .17046 .37273 L p F P
0 g
s
.61 .547 .759 r
.62488 .36348 m .62682 .36865 L .63701 .36428 L p F P
0 g
s
.598 .522 .74 r
.63881 .36982 m .63701 .36428 L .62682 .36865 L p F P
0 g
s
.543 .369 .596 r
.63353 .40035 m .63298 .39491 L .6226 .399 L p F P
0 g
s
.543 .369 .596 r
.62615 .40326 m .63353 .40035 L p .6226 .399 L F P
0 g
s
.543 .369 .596 r
.6226 .399 m .62289 .40186 L .62615 .40326 L p F P
0 g
s
.712 .306 .275 r
.29634 .4673 m .29515 .4685 L .29353 .46682 L closepath p F P
0 g
s
.516 .11 .21 r
.49032 .47649 m .49219 .47331 L .47976 .47486 L p F P
0 g
s
.516 .11 .21 r
.48639 .47698 m .49032 .47649 L p .47976 .47486 L F P
0 g
s
.516 .11 .21 r
.47976 .47486 m .47904 .47605 L .48639 .47698 L p F P
0 g
s
.579 .473 .697 r
.64112 .37861 m .6394 .37184 L .62918 .37617 L p F P
0 g
s
.579 .473 .697 r
.63315 .38201 m .64112 .37861 L p .62918 .37617 L F P
0 g
s
.579 .473 .697 r
.62918 .37617 m .63072 .38216 L .63315 .38201 L p F P
0 g
s
.808 .501 .47 r
.21065 .43241 m .21281 .43309 L .21445 .42924 L p F P
0 g
s
.808 .501 .47 r
.21445 .42924 m .20978 .42777 L .21065 .43241 L p F P
0 g
s
.638 .62 .816 r
.60826 .35445 m .61923 .35144 L .62204 .35697 L p F P
0 g
s
.643 .654 .846 r
.60688 .35214 m .60826 .35445 L .61923 .35144 L p F P
0 g
s
.361 .769 .982 r
.34536 .35981 m .34791 .35966 L .3579 .3606 L p F P
0 g
s
.388 .77 .991 r
.34536 .35981 m .34791 .35966 L .34403 .35918 L closepath p F P
0 g
s
.525 .144 .261 r
.49274 .47221 m .49667 .47268 L .49219 .47331 L closepath p F P
0 g
s
.673 .248 .228 r
.32639 .47467 m .32548 .47553 L .32397 .47437 L closepath p F P
0 g
s
.814 .547 .535 r
.19425 .41811 m .19644 .41884 L .19649 .41392 L p F P
0 g
s
.814 .547 .535 r
.19649 .41392 m .19497 .41342 L .19425 .41811 L p F P
0 g
s
.469 .837 .992 r
.45631 .36002 m .45477 .35945 L .4473 .36079 L closepath p F P
0 g
s
.463 .838 .989 r
.45175 .35862 m .45477 .35945 L .4473 .36079 L p F P
0 g
s
.463 .838 .989 r
.44106 .36032 m .45175 .35862 L p .4473 .36079 L F P
0 g
s
.431 .79 .996 r
.35948 .36072 m .359 .36049 L .3579 .3606 L closepath p F P
0 g
s
.814 .64 .666 r
.16987 .3869 m .17584 .38919 L .1785 .38346 L p F P
0 g
s
.814 .64 .666 r
.1785 .38346 m .1726 .38115 L .16987 .3869 L p F P
0 g
s
.438 .764 .996 r
.29802 .35316 m .2877 .35414 L .28441 .35192 L p F P
0 g
s
.576 .136 .167 r
.40522 .4821 m .39829 .4821 L .3968 .48373 L p F P
0 g
s
.591 .153 .177 r
.39829 .4821 m .3968 .48373 L .39267 .48201 L closepath p F P
0 g
s
.578 .142 .177 r
.41219 .48207 m .41049 .48404 L .40522 .4821 L closepath p F P
0 g
s
.576 .136 .167 r
.40976 .48488 m .41049 .48404 L .40522 .4821 L p F P
0 g
s
.576 .136 .167 r
.39983 .48487 m .40976 .48488 L p .40522 .4821 L F P
0 g
s
.576 .136 .167 r
.3968 .48373 m .39983 .48487 L p .40522 .4821 L F P
0 g
s
.563 .125 .166 r
.4186 .48194 m .41219 .48207 L .41049 .48404 L p F P
0 g
s
.536 .757 .978 r
.28112 .3498 m .28441 .35192 L .27615 .35302 L p F P
0 g
s
.536 .757 .978 r
.27081 .35081 m .28112 .3498 L p .27615 .35302 L F P
0 g
s
.536 .757 .978 r
.27615 .35302 m .27214 .3518 L .27081 .35081 L p F P
0 g
s
.402 .792 .989 r
.35581 .3592 m .34791 .35966 L .3579 .3606 L p F P
0 g
s
.402 .792 .989 r
.3579 .3606 m .359 .36049 L .35581 .3592 L p F P
0 g
s
.589 .146 .165 r
.39577 .48486 m .3968 .48373 L .39267 .48201 L p F P
0 g
s
.589 .146 .165 r
.38756 .48468 m .39577 .48486 L p .39267 .48201 L F P
0 g
s
.589 .146 .165 r
.38315 .48281 m .38756 .48468 L p .39267 .48201 L F P
0 g
s
.589 .146 .165 r
.39267 .48201 m .38409 .48184 L .38315 .48281 L p F P
0 g
s
.713 .306 .274 r
.28897 .46922 m .28528 .46538 L .29353 .46682 L p F P
0 g
s
.713 .306 .274 r
.2936 .47004 m .28897 .46922 L p .29353 .46682 L F P
0 g
s
.713 .306 .274 r
.29353 .46682 m .29515 .4685 L .2936 .47004 L p F P
0 g
s
.61 .547 .759 r
.63701 .36428 m .63591 .36126 L .62488 .36348 L p F P
0 g
s
.615 .571 .782 r
.62335 .35986 m .62488 .36348 L .63591 .36126 L p F P
0 g
s
.502 .146 .296 r
.54162 .46159 m .54175 .46123 L .53088 .46148 L p F P
0 g
s
.502 .146 .296 r
.53088 .46148 m .52992 .46398 L .54162 .46159 L p F P
0 g
s
.673 .247 .227 r
.31946 .47679 m .31485 .4732 L .32397 .47437 L p F P
0 g
s
.673 .247 .227 r
.32361 .47732 m .31946 .47679 L p .32397 .47437 L F P
0 g
s
.673 .247 .227 r
.32397 .47437 m .32548 .47553 L .32361 .47732 L p F P
0 g
s
.493 .163 .336 r
.56626 .45091 m .56688 .44876 L .55556 .45159 L p F P
0 g
s
.493 .163 .336 r
.55556 .45159 m .55535 .4523 L .56626 .45091 L p F P
0 g
s
.785 .457 .432 r
.23181 .44102 m .23239 .44276 L .23106 .44242 L closepath p F P
0 g
s
.564 .13 .175 r
.42581 .48177 m .42418 .48373 L .4186 .48194 L closepath p F P
0 g
s
.563 .125 .166 r
.42345 .48461 m .42418 .48373 L .4186 .48194 L p F P
0 g
s
.563 .125 .166 r
.41287 .48483 m .42345 .48461 L p .4186 .48194 L F P
0 g
s
.563 .125 .166 r
.41049 .48404 m .41287 .48483 L p .4186 .48194 L F P
0 g
s
.795 .465 .431 r
.21874 .43888 m .22552 .44084 L .22413 .43635 L p F P
0 g
s
.795 .465 .431 r
.22413 .43635 m .21733 .4344 L .21874 .43888 L p F P
0 g
s
.604 .163 .177 r
.38409 .48184 m .38315 .48281 L .38077 .48171 L closepath p F P
0 g
s
.578 .46 .682 r
.63072 .38216 m .63315 .38201 L .63091 .38294 L closepath p F P
0 g
s
.549 .113 .165 r
.43299 .48147 m .42581 .48177 L .42418 .48373 L p F P
0 g
s
.823 .556 .535 r
.1902 .41667 m .19425 .41811 L .19497 .41342 L p F P
0 g
s
.823 .556 .535 r
.19497 .41342 m .19029 .41175 L .1902 .41667 L p F P
0 g
s
.524 .306 .526 r
.62341 .41442 m .62339 .40955 L .61284 .41339 L p F P
0 g
s
.524 .306 .526 r
.61284 .41339 m .61284 .41825 L .62341 .41442 L p F P
0 g
s
.6 .154 .163 r
.38148 .48453 m .38315 .48281 L .38077 .48171 L p F P
0 g
s
.6 .154 .163 r
.37592 .4843 m .38148 .48453 L p .38077 .48171 L F P
0 g
s
.6 .154 .163 r
.36952 .48131 m .37592 .4843 L p .38077 .48171 L F P
0 g
s
.6 .154 .163 r
.38077 .48171 m .36957 .48126 L .36952 .48131 L p F P
0 g
s
.812 .524 .501 r
.19688 .4236 m .20331 .42569 L .20288 .42092 L p F P
0 g
s
.812 .524 .501 r
.20288 .42092 m .19644 .41884 L .19688 .4236 L p F P
0 g
s
.568 .435 .66 r
.64237 .38484 m .63212 .38913 L .63091 .38294 L p F P
0 g
s
.568 .435 .66 r
.64184 .38208 m .64237 .38484 L p .63091 .38294 L F P
0 g
s
.568 .435 .66 r
.63091 .38294 m .63315 .38201 L .64184 .38208 L p F P
0 g
s
.253 .732 .934 r
.36947 .35989 m .359 .36049 L .35581 .3592 L p F P
0 g
s
.769 .421 .396 r
.24837 .45015 m .24865 .45074 L .24807 .45061 L closepath p F P
0 g
s
.495 .848 .994 r
.46632 .35881 m .45631 .36002 L .45477 .35945 L p F P
0 g
s
.671 .751 .91 r
.21627 .35007 m .22663 .34632 L .22995 .34946 L p F P
0 g
s
.657 .754 .921 r
.22663 .34632 m .21627 .35007 L .21295 .34665 L p F P
0 g
s
.713 .721 .856 r
.21627 .35007 m .21295 .34665 L .20253 .3515 L p F P
0 g
s
.549 .117 .171 r
.43917 .4812 m .4379 .4828 L .43299 .48147 L closepath p F P
0 g
s
.549 .113 .165 r
.43687 .48408 m .4379 .4828 L .43299 .48147 L p F P
0 g
s
.549 .113 .165 r
.42687 .48449 m .43687 .48408 L p .43299 .48147 L F P
0 g
s
.549 .113 .165 r
.42418 .48373 m .42687 .48449 L p .43299 .48147 L F P
0 g
s
.635 .759 .937 r
.22995 .34946 m .24027 .34659 L .24359 .34948 L p F P
0 g
s
.617 .761 .948 r
.24027 .34659 m .22995 .34946 L .22663 .34632 L p F P
0 g
s
.545 .367 .591 r
.62289 .40186 m .62615 .40326 L .62314 .40443 L closepath p F P
0 g
s
.808 .66 .699 r
.1668 .37887 m .1726 .38115 L .17626 .3751 L p F P
0 g
s
.808 .66 .699 r
.16675 .37874 m .1668 .37887 L p .17626 .3751 L F P
0 g
s
.808 .66 .699 r
.17626 .3751 m .17046 .37273 L .16675 .37874 L p F P
0 g
s
.495 .117 .252 r
.52837 .46739 m .52992 .46398 L .51807 .46618 L p F P
0 g
s
.495 .117 .252 r
.52484 .46805 m .52837 .46739 L p .51807 .46618 L F P
0 g
s
.495 .117 .252 r
.51807 .46618 m .51722 .46801 L .52484 .46805 L p F P
0 g
s
.625 .591 .795 r
.62204 .35697 m .62335 .35986 L .63355 .35548 L p F P
0 g
s
.615 .571 .782 r
.63591 .36126 m .63355 .35548 L .62335 .35986 L p F P
0 g
s
.729 .729 .85 r
.20128 .35226 m .20253 .3515 L .19921 .34779 L p F P
0 g
s
.729 .729 .85 r
.19921 .34779 m .19569 .34981 L .20128 .35226 L p F P
0 g
s
.739 .707 .821 r
.1887 .35414 m .19569 .34981 L .20128 .35226 L p F P
0 g
s
.661 .761 .924 r
.56433 .34971 m .57522 .34622 L .57802 .3492 L p F P
0 g
s
.658 .789 .944 r
.57522 .34622 m .56433 .34971 L .56151 .34715 L p F P
0 g
s
.656 .789 .946 r
.55064 .35058 m .56151 .34715 L .56433 .34971 L p F P
0 g
s
.615 .172 .174 r
.36957 .48126 m .36952 .48131 L .3694 .48125 L closepath p F P
0 g
s
.615 .172 .173 r
.36477 .48377 m .3587 .48059 L .3694 .48125 L p F P
0 g
s
.615 .172 .173 r
.36685 .48389 m .36477 .48377 L p .3694 .48125 L F P
0 g
s
.615 .172 .173 r
.3694 .48125 m .36952 .48131 L .36685 .48389 L p F P
0 g
s
.493 .163 .334 r
.56579 .45255 m .56626 .45091 L .55535 .4523 L p F P
0 g
s
.493 .163 .334 r
.55535 .4523 m .55444 .45537 L .56579 .45255 L p F P
0 g
s
.648 .664 .852 r
.60546 .34983 m .60688 .35214 L .61721 .34794 L p F P
0 g
s
.643 .654 .846 r
.61923 .35144 m .61721 .34794 L .60688 .35214 L p F P
0 g
s
.649 .813 .962 r
.56151 .34715 m .55064 .35058 L .54781 .34838 L p F P
0 g
s
.645 .814 .965 r
.53695 .35171 m .54781 .34838 L .55064 .35058 L p F P
0 g
s
.433 .77 .997 r
.30129 .35516 m .31164 .35446 L .3149 .35624 L p F P
0 g
s
.365 .753 .988 r
.31164 .35446 m .30129 .35516 L .29802 .35316 L p F P
0 g
s
.534 .1 .162 r
.44867 .48061 m .43917 .4812 L .4379 .4828 L p F P
0 g
s
.38 .768 .989 r
.3526 .35806 m .35581 .3592 L .34791 .35966 L p F P
0 g
s
.38 .768 .989 r
.34215 .35832 m .3526 .35806 L p .34791 .35966 L F P
0 g
s
.38 .768 .989 r
.34791 .35966 m .34403 .35918 L .34215 .35832 L p F P
0 g
s
.604 .158 .164 r
.36952 .48131 m .37592 .4843 L .36685 .48389 L closepath p F P
0 g
s
.661 .728 .899 r
.57802 .3492 m .58894 .34573 L .59173 .34918 L p F P
0 g
s
.662 .758 .921 r
.58894 .34573 m .57802 .3492 L .57522 .34622 L p F P
0 g
s
.693 .746 .892 r
.21295 .34665 m .20253 .3515 L .19921 .34779 L p F P
0 g
s
.76 .388 .349 r
.24552 .45359 m .25117 .4549 L .24865 .45074 L p F P
0 g
s
.76 .388 .349 r
.24865 .45074 m .24807 .45061 L .24552 .45359 L p F P
0 g
s
.738 .346 .308 r
.26151 .46069 m .26932 .46229 L .26623 .45829 L p F P
0 g
s
.738 .346 .308 r
.26142 .46057 m .26151 .46069 L p .26623 .45829 L F P
0 g
s
.738 .346 .308 r
.26623 .45829 m .26406 .45784 L .26142 .46057 L p F P
0 g
s
.634 .839 .979 r
.54779 .34836 m .54781 .34838 L .53695 .35171 L p F P
0 g
s
.634 .839 .979 r
.53695 .35171 m .53666 .35152 L .54779 .34836 L p F P
0 g
s
.594 .765 .961 r
.24359 .34948 m .2539 .34733 L .25721 .34997 L p F P
0 g
s
.568 .767 .972 r
.2539 .34733 m .24359 .34948 L .24027 .34659 L p F P
0 g
s
.771 .403 .358 r
.2438 .45315 m .24552 .45359 L .24807 .45061 L p F P
0 g
s
.771 .403 .358 r
.24807 .45061 m .24147 .44892 L .2438 .45315 L p F P
0 g
s
.81 .502 .467 r
.20419 .43033 m .21065 .43241 L .20978 .42777 L p F P
0 g
s
.81 .502 .467 r
.20978 .42777 m .20331 .42569 L .20419 .43033 L p F P
0 g
s
.229 .725 .914 r
.38316 .36036 m .37265 .36104 L .36947 .35989 L p F P
0 g
s
.576 .771 .971 r
.27214 .3518 m .27081 .35081 L .26887 .35117 L closepath p F P
0 g
s
.5 .096 .205 r
.49667 .47268 m .49219 .47331 L .49032 .47649 L p F P
0 g
s
.673 .241 .214 r
.31044 .47558 m .31946 .47679 L .31485 .4732 L p F P
0 g
s
.673 .241 .214 r
.30856 .47411 m .31044 .47558 L p .31485 .4732 L F P
0 g
s
.673 .241 .214 r
.31485 .4732 m .31027 .4726 L .30856 .47411 L p F P
0 g
s
.656 .694 .873 r
.59173 .34918 m .60267 .34581 L .60546 .34983 L p F P
0 g
s
.66 .723 .896 r
.60267 .34581 m .59173 .34918 L .58894 .34573 L p F P
0 g
s
.516 .109 .208 r
.47904 .47605 m .48639 .47698 L .47785 .47801 L closepath p F P
0 g
s
.489 .138 .297 r
.55314 .45897 m .55444 .45537 L .54294 .45798 L p F P
0 g
s
.489 .138 .297 r
.544 .46105 m .55314 .45897 L p .54294 .45798 L F P
0 g
s
.489 .138 .297 r
.54294 .45798 m .54175 .46123 L .544 .46105 L p F P
0 g
s
.568 .44 .665 r
.63315 .38201 m .64112 .37861 L .64184 .38208 L closepath p F P
0 g
s
.603 .857 .992 r
.5341 .34985 m .52326 .35303 L .52039 .35144 L p F P
0 g
s
.6 .851 .992 r
.50957 .35443 m .52039 .35144 L .52326 .35303 L p F P
0 g
s
.78 .427 .389 r
.22873 .44561 m .23435 .44709 L .23239 .44276 L p F P
0 g
s
.78 .427 .389 r
.23239 .44276 m .23106 .44242 L .22873 .44561 L p F P
0 g
s
.396 .776 .992 r
.34403 .35918 m .34215 .35832 L .33837 .35857 L closepath p F P
0 g
s
.625 .591 .795 r
.63355 .35548 m .63306 .35436 L .62204 .35697 L p F P
0 g
s
.633 .61 .809 r
.63306 .35436 m .62204 .35697 L .61923 .35144 L p F P
0 g
s
.631 .839 .98 r
.54497 .34656 m .54779 .34836 L .53666 .35152 L p F P
0 g
s
.631 .839 .98 r
.53666 .35152 m .5341 .34985 L .54497 .34656 L p F P
0 g
s
.663 .235 .219 r
.32548 .47553 m .32878 .4779 L .32361 .47732 L closepath p F P
0 g
s
.75 .363 .319 r
.26406 .45784 m .26142 .46057 L .25863 .45662 L closepath p F P
0 g
s
.534 .1 .162 r
.45005 .48328 m .45161 .48126 L .44867 .48061 L p F P
0 g
s
.534 .1 .162 r
.4421 .48377 m .45005 .48328 L p .44867 .48061 L F P
0 g
s
.534 .1 .162 r
.4379 .4828 m .4421 .48377 L p .44867 .48061 L F P
0 g
s
.533 .102 .167 r
.45229 .48038 m .45161 .48126 L .44867 .48061 L closepath p F P
0 g
s
.617 .169 .165 r
.35417 .48306 m .36477 .48377 L .3587 .48059 L p F P
0 g
s
.617 .169 .165 r
.35259 .48222 m .35417 .48306 L p .3587 .48059 L F P
0 g
s
.617 .169 .165 r
.3587 .48059 m .35466 .48033 L .35259 .48222 L p F P
0 g
s
.712 .297 .259 r
.28079 .46774 m .28897 .46922 L .28528 .46538 L p F P
0 g
s
.712 .297 .259 r
.27827 .46513 m .28079 .46774 L p .28528 .46538 L F P
0 g
s
.712 .297 .259 r
.28528 .46538 m .2792 .46429 L .27827 .46513 L p F P
0 g
s
.771 .693 .777 r
.17471 .35847 m .17683 .35664 L .18271 .35899 L p F P
0 g
s
.771 .693 .777 r
.18271 .35899 m .17797 .36333 L .17471 .35847 L p F P
0 g
s
.758 .709 .806 r
.18271 .35899 m .1887 .35414 L .18539 .35004 L p F P
0 g
s
.758 .709 .806 r
.18539 .35004 m .17683 .35664 L .18271 .35899 L p F P
0 g
s
.789 .693 .758 r
.17538 .36626 m .17797 .36333 L .17471 .35847 L p F P
0 g
s
.823 .6 .601 r
.17272 .39995 m .17875 .40221 L .17996 .39694 L p F P
0 g
s
.823 .6 .601 r
.17996 .39694 m .17394 .39468 L .17272 .39995 L p F P
0 g
s
.571 .865 .996 r
.52039 .35144 m .50957 .35443 L .50667 .35305 L p F P
0 g
s
.569 .858 .996 r
.49588 .35582 m .50667 .35305 L .50957 .35443 L p F P
0 g
s
.824 .579 .568 r
.17813 .40729 m .1842 .40953 L .18481 .40445 L p F P
0 g
s
.824 .579 .568 r
.18481 .40445 m .17875 .40221 L .17813 .40729 L p F P
0 g
s
.79 .441 .397 r
.22732 .44521 m .22873 .44561 L .23106 .44242 L p F P
0 g
s
.79 .441 .397 r
.23106 .44242 m .22552 .44084 L .22732 .44521 L p F P
0 g
s
.53 .334 .559 r
.62823 .40767 m .62339 .40955 L .62314 .40443 L p F P
0 g
s
.53 .334 .559 r
.62314 .40443 m .62615 .40326 L .62823 .40767 L p F P
0 g
s
.546 .765 .979 r
.25721 .34997 m .26147 .34935 L .26887 .35117 L p F P
0 g
s
.521 .752 .98 r
.26147 .34935 m .25721 .34997 L .2539 .34733 L p F P
0 g
s
.521 .088 .158 r
.463 .48225 m .46518 .47932 L .45229 .48038 L p F P
0 g
s
.521 .088 .158 r
.45891 .48259 m .463 .48225 L p .45229 .48038 L F P
0 g
s
.521 .088 .158 r
.45229 .48038 m .45161 .48126 L .45891 .48259 L p F P
0 g
s
.704 .294 .267 r
.29515 .4685 m .29735 .47063 L .2936 .47004 L closepath p F P
0 g
s
.22 .725 .901 r
.39686 .36056 m .38631 .36138 L .38316 .36036 L p F P
0 g
s
.506 .845 .997 r
.46886 .35853 m .46847 .35837 L .46632 .35881 L closepath p F P
0 g
s
.495 .848 .994 r
.46549 .35748 m .46847 .35837 L .46632 .35881 L p F P
0 g
s
.495 .848 .994 r
.45477 .35945 m .46549 .35748 L p .46632 .35881 L F P
0 g
s
.818 .622 .638 r
.17116 .39361 m .17394 .39468 L .17584 .38919 L p F P
0 g
s
.818 .622 .638 r
.16971 .38733 m .17116 .39361 L p .17584 .38919 L F P
0 g
s
.818 .622 .638 r
.17584 .38919 m .16987 .3869 L .16971 .38733 L p F P
0 g
s
.571 .779 .977 r
.26751 .34845 m .26147 .34935 L .26887 .35117 L p F P
0 g
s
.571 .779 .977 r
.26887 .35117 m .27081 .35081 L .26751 .34845 L p F P
0 g
s
.632 .188 .178 r
.35466 .48033 m .35259 .48222 L .34837 .47981 L closepath p F P
0 g
s
.551 .398 .627 r
.64323 .39062 m .64237 .38484 L .63212 .38913 L p F P
0 g
s
.551 .398 .627 r
.63212 .38913 m .63298 .39491 L .64323 .39062 L p F P
0 g
s
.37 .761 .987 r
.32796 .35703 m .32852 .3573 L p .3149 .35624 L F P
0 g
s
.37 .761 .987 r
.3149 .35624 m .32046 .356 L .32796 .35703 L p F P
0 g
s
.331 .737 .981 r
.32046 .356 m .3149 .35624 L .31164 .35446 L p F P
0 g
s
.499 .097 .209 r
.50443 .47155 m .50352 .47314 L .49667 .47268 L closepath p F P
0 g
s
.5 .096 .205 r
.5026 .47474 m .50352 .47314 L .49667 .47268 L p F P
0 g
s
.5 .096 .205 r
.49032 .47649 m .5026 .47474 L p .49667 .47268 L F P
0 g
s
.789 .693 .758 r
.17471 .35847 m .16976 .36383 L .17538 .36626 L p F P
0 g
s
.8 .681 .734 r
.16466 .37037 m .17046 .37273 L .17538 .36626 L p F P
0 g
s
.8 .681 .734 r
.17538 .36626 m .16976 .36383 L .16466 .37037 L p F P
0 g
s
.687 .26 .227 r
.31027 .4726 m .30856 .47411 L .30598 .47196 L closepath p F P
0 g
s
.733 .714 .832 r
.19569 .34981 m .1887 .35414 L .18539 .35004 L p F P
0 g
s
.372 .775 .984 r
.33893 .357 m .32946 .35727 L .33837 .35857 L p F P
0 g
s
.372 .775 .984 r
.33837 .35857 m .34215 .35832 L .33893 .357 L p F P
0 g
s
.343 .751 .981 r
.32852 .3573 m .32946 .35727 L .33837 .35857 L p F P
0 g
s
.825 .558 .535 r
.1841 .41445 m .1902 .41667 L .19029 .41175 L p F P
0 g
s
.825 .558 .535 r
.19029 .41175 m .1842 .40953 L .1841 .41445 L p F P
0 g
s
.547 .863 .996 r
.50521 .35252 m .50667 .35305 L .49588 .35582 L p F P
0 g
s
.547 .863 .996 r
.49588 .35582 m .49329 .35476 L .50521 .35252 L p F P
0 g
s
.538 .857 .997 r
.49329 .35476 m .49588 .35582 L p .48218 .35715 L F P
0 g
s
.51 .847 .997 r
.47922 .35614 m .48122 .35682 L .46886 .35853 L p F P
0 g
s
.51 .847 .997 r
.46886 .35853 m .46847 .35837 L .47922 .35614 L p F P
0 g
s
.648 .664 .852 r
.61721 .34794 m .61644 .34664 L .60546 .34983 L p F P
0 g
s
.654 .686 .868 r
.61644 .34664 m .60546 .34983 L .60267 .34581 L p F P
0 g
s
.513 .252 .456 r
.60148 .43091 m .60156 .43007 L .59064 .43418 L p F P
0 g
s
.513 .252 .456 r
.59064 .43418 m .59062 .43435 L .60148 .43091 L p F P
0 g
s
.592 .149 .167 r
.38315 .48281 m .38756 .48468 L .38148 .48453 L closepath p F P
0 g
s
.796 .464 .426 r
.21198 .43691 m .21874 .43888 L .21733 .4344 L p F P
0 g
s
.796 .464 .426 r
.21148 .43528 m .21198 .43691 L p .21733 .4344 L F P
0 g
s
.796 .464 .426 r
.21733 .4344 m .21281 .43309 L .21148 .43528 L p F P
0 g
s
.492 .208 .411 r
.60082 .43509 m .60148 .43091 L .59062 .43435 L p F P
0 g
s
.492 .208 .411 r
.59062 .43435 m .58994 .43852 L .60082 .43509 L p F P
0 g
s
.814 .64 .666 r
.16957 .38679 m .16987 .3869 L .1726 .38115 L p F P
0 g
s
.814 .64 .666 r
.1726 .38115 m .1668 .37887 L .16957 .38679 L p F P
0 g
s
.227 .732 .896 r
.41057 .36049 m .39998 .36149 L .39686 .36056 L p F P
0 g
s
.538 .857 .997 r
.48218 .35715 m .4903 .35524 L .49329 .35476 L p F P
0 g
s
.513 .862 .991 r
.48218 .35715 m .4903 .35524 L .48122 .35682 L closepath p F P
0 g
s
.627 .175 .159 r
.35185 .4829 m .35259 .48222 L .34837 .47981 L p F P
0 g
s
.627 .175 .159 r
.34403 .48221 m .35185 .4829 L p .34837 .47981 L F P
0 g
s
.627 .175 .159 r
.339 .47935 m .34403 .48221 L p .34837 .47981 L F P
0 g
s
.627 .175 .159 r
.34837 .47981 m .33937 .47904 L .339 .47935 L p F P
0 g
s
.487 .182 .374 r
.58908 .44251 m .58994 .43852 L .57893 .44175 L p F P
0 g
s
.487 .182 .374 r
.57893 .44175 m .57805 .44573 L .58908 .44251 L p F P
0 g
s
.5 .241 .453 r
.61248 .42443 m .61263 .42288 L .60192 .42651 L p F P
0 g
s
.5 .241 .453 r
.60192 .42651 m .60156 .43007 L .61248 .42443 L p F P
0 g
s
.533 .126 .216 r
.46533 .47909 m .46609 .47923 L .46518 .47932 L closepath p F P
0 g
s
.815 .525 .5 r
.19297 .42231 m .19688 .4236 L .19644 .41884 L p F P
0 g
s
.815 .525 .5 r
.19644 .41884 m .19425 .41811 L .19297 .42231 L p F P
0 g
s
.344 .792 .954 r
.41367 .36135 m .42429 .36014 L .42736 .36096 L p F P
0 g
s
.248 .748 .9 r
.42429 .36014 m .41367 .36135 L .41057 .36049 L p F P
0 g
s
.424 .84 .966 r
.47922 .35614 m .46847 .35837 L .46549 .35748 L p F P
0 g
s
.453 .76 .995 r
.28112 .3498 m .27081 .35081 L .26751 .34845 L p F P
0 g
s
.687 .259 .226 r
.30172 .47428 m .29735 .47063 L .30598 .47196 L p F P
0 g
s
.687 .259 .226 r
.30736 .47516 m .30172 .47428 L p .30598 .47196 L F P
0 g
s
.687 .259 .226 r
.30598 .47196 m .30856 .47411 L .30736 .47516 L p F P
0 g
s
.725 .315 .27 r
.2792 .46429 m .27827 .46513 L .27714 .46389 L closepath p F P
0 g
s
.283 .769 .913 r
.43802 .35952 m .42736 .36096 L .42429 .36014 L p F P
0 g
s
.382 .821 .953 r
.46549 .35748 m .45477 .35945 L .45175 .35862 L p F P
0 g
s
.751 .363 .318 r
.25408 .45896 m .25117 .4549 L .25863 .45662 L p F P
0 g
s
.751 .363 .318 r
.26134 .46065 m .25408 .45896 L p .25863 .45662 L F P
0 g
s
.751 .363 .318 r
.25863 .45662 m .26142 .46057 L .26134 .46065 L p F P
0 g
s
.329 .795 .932 r
.45175 .35862 m .44106 .36032 L .43802 .35952 L p F P
0 g
s
.357 .752 .986 r
.32852 .3573 m .32946 .35727 L .32796 .35703 L closepath p F P
0 g
s
.772 .4 .352 r
.23671 .4513 m .2438 .45315 L .24147 .44892 L p F P
0 g
s
.772 .4 .352 r
.24147 .44892 m .23435 .44709 L .23671 .4513 L p F P
0 g
s
.504 .072 .152 r
.46609 .47923 m .46518 .47932 L .463 .48225 L p F P
0 g
s
.528 .333 .56 r
.6338 .40549 m .62823 .40767 L .62615 .40326 L p F P
0 g
s
.528 .333 .56 r
.62615 .40326 m .63353 .40035 L .6338 .40549 L p F P
0 g
s
.579 .139 .168 r
.3968 .48373 m .39983 .48487 L .39577 .48486 L closepath p F P
0 g
s
.505 .078 .162 r
.47785 .47801 m .47605 .48053 L .46609 .47923 L closepath p F P
0 g
s
.504 .072 .152 r
.47573 .48098 m .47605 .48053 L .46609 .47923 L p F P
0 g
s
.504 .072 .152 r
.463 .48225 m .47573 .48098 L p .46609 .47923 L F P
0 g
s
.478 .102 .247 r
.54008 .46499 m .54162 .46159 L .52992 .46398 L p F P
0 g
s
.478 .102 .247 r
.52992 .46398 m .52837 .46739 L .54008 .46499 L p F P
0 g
s
.48 .152 .333 r
.57721 .44877 m .57805 .44573 L .56688 .44876 L p F P
0 g
s
.48 .152 .333 r
.56688 .44876 m .56626 .45091 L .57721 .44877 L p F P
0 g
s
.806 .658 .699 r
.16363 .37193 m .16466 .37037 L .17046 .37273 L p F P
0 g
s
.806 .658 .699 r
.17046 .37273 m .16675 .37874 L .16363 .37193 L p F P
0 g
s
.485 .083 .201 r
.5147 .47278 m .51648 .46957 L .50443 .47155 L p F P
0 g
s
.485 .083 .201 r
.51132 .47334 m .5147 .47278 L p .50443 .47155 L F P
0 g
s
.485 .083 .201 r
.50443 .47155 m .50352 .47314 L .51132 .47334 L p F P
0 g
s
.494 .116 .251 r
.51722 .46801 m .52484 .46805 L .51648 .46957 L closepath p F P
0 g
s
.725 .315 .269 r
.2728 .46619 m .26932 .46229 L .27714 .46389 L p F P
0 g
s
.725 .315 .269 r
.27629 .46691 m .2728 .46619 L p .27714 .46389 L F P
0 g
s
.725 .315 .269 r
.27714 .46389 m .27827 .46513 L .27629 .46691 L p F P
0 g
s
.507 .27 .49 r
.62333 .41616 m .62341 .41442 L .61284 .41825 L p F P
0 g
s
.507 .27 .49 r
.61771 .42104 m .62333 .41616 L p .61284 .41825 L F P
0 g
s
.507 .27 .49 r
.61284 .41825 m .61263 .42288 L .61771 .42104 L p F P
0 g
s
.722 .73 .857 r
.19569 .34981 m .19921 .34779 L .19588 .34419 L p F P
0 g
s
.722 .73 .857 r
.19588 .34419 m .18993 .34742 L .19569 .34981 L p F P
0 g
s
.733 .714 .832 r
.18539 .35004 m .18993 .34742 L .19569 .34981 L p F P
0 g
s
.642 .194 .172 r
.33937 .47904 m .339 .47935 L .33832 .47893 L closepath p F P
0 g
s
.52 .087 .157 r
.45161 .48126 m .45891 .48259 L .45005 .48328 L closepath p F P
0 g
s
.823 .535 .502 r
.19057 .42146 m .19297 .42231 L .19425 .41811 L p F P
0 g
s
.823 .535 .502 r
.19425 .41811 m .1902 .41667 L .19057 .42146 L p F P
0 g
s
.642 .194 .171 r
.33415 .48127 m .32878 .4779 L .33832 .47893 L p F P
0 g
s
.642 .194 .171 r
.33642 .48152 m .33415 .48127 L p .33832 .47893 L F P
0 g
s
.642 .194 .171 r
.33832 .47893 m .339 .47935 L .33642 .48152 L p F P
0 g
s
.348 .749 .984 r
.33568 .3558 m .33893 .357 L .32946 .35727 L p F P
0 g
s
.348 .749 .984 r
.32528 .35577 m .33568 .3558 L p .32946 .35727 L F P
0 g
s
.348 .749 .984 r
.32946 .35727 m .32796 .35703 L .32528 .35577 L p F P
0 g
s
.811 .501 .465 r
.19777 .42823 m .20419 .43033 L .20331 .42569 L p F P
0 g
s
.811 .501 .465 r
.20331 .42569 m .19688 .4236 L .19777 .42823 L p F P
0 g
s
.633 .61 .809 r
.61923 .35144 m .63025 .3486 L .63306 .35436 L p F P
0 g
s
.637 .646 .842 r
.61721 .34794 m .61923 .35144 L .63025 .3486 L p F P
0 g
s
.791 .44 .392 r
.22056 .44325 m .22732 .44521 L .22552 .44084 L p F P
0 g
s
.791 .44 .392 r
.22552 .44084 m .21874 .43888 L .22056 .44325 L p F P
0 g
s
.566 .128 .167 r
.41049 .48404 m .41287 .48483 L .40976 .48488 L closepath p F P
0 g
s
.805 .476 .432 r
.21281 .43309 m .21148 .43528 L .21065 .43241 L closepath p F P
0 g
s
.376 .763 .989 r
.32796 .35703 m .32528 .35577 L .32046 .356 L closepath p F P
0 g
s
.377 .749 .991 r
.29474 .35127 m .28441 .35192 L .28112 .3498 L p F P
0 g
s
.438 .764 .996 r
.28441 .35192 m .29474 .35127 L .29802 .35316 L p F P
0 g
s
.521 .752 .98 r
.2539 .34733 m .25499 .34721 L .26147 .34935 L p F P
0 g
s
.541 .776 .985 r
.26418 .34617 m .25499 .34721 L .26147 .34935 L p F P
0 g
s
.541 .776 .985 r
.26147 .34935 m .26751 .34845 L .26418 .34617 L p F P
0 g
s
.657 .754 .921 r
.21295 .34665 m .22329 .34327 L .22663 .34632 L p F P
0 g
s
.642 .756 .932 r
.22329 .34327 m .21295 .34665 L .20961 .34334 L p F P
0 g
s
.693 .746 .892 r
.19921 .34779 m .20961 .34334 L .21295 .34665 L p F P
0 g
s
.536 .102 .162 r
.4379 .4828 m .4421 .48377 L .43687 .48408 L closepath p F P
0 g
s
.535 .362 .594 r
.64378 .39606 m .64323 .39062 L .63298 .39491 L p F P
0 g
s
.535 .362 .594 r
.63298 .39491 m .63353 .40035 L .64378 .39606 L p F P
0 g
s
.511 .862 .991 r
.4903 .35524 m .48122 .35682 L .47922 .35614 L p F P
0 g
s
.552 .115 .165 r
.42418 .48373 m .42687 .48449 L .42345 .48461 L closepath p F P
0 g
s
.193 .696 .909 r
.3526 .35806 m .34215 .35832 L .33893 .357 L p F P
0 g
s
.586 .495 .718 r
.63881 .36982 m .64531 .36919 L .6394 .37184 L closepath p F P
0 g
s
.588 .511 .736 r
.63701 .36428 m .63881 .36982 L .64531 .36919 L p F P
0 g
s
.631 .18 .162 r
.339 .47935 m .34403 .48221 L .33642 .48152 L closepath p F P
0 g
s
.682 .75 .902 r
.20961 .34334 m .19921 .34779 L .19588 .34419 L p F P
0 g
s
.768 .7 .787 r
.17683 .35664 m .1721 .35478 L .17471 .35847 L closepath p F P
0 g
s
.789 .701 .768 r
.16976 .36383 m .17471 .35847 L .1721 .35478 L p F P
0 g
s
.617 .761 .948 r
.22663 .34632 m .23694 .3438 L .24027 .34659 L p F P
0 g
s
.597 .761 .957 r
.23694 .3438 m .22663 .34632 L .22329 .34327 L p F P
0 g
s
.603 .539 .755 r
.63591 .36126 m .63701 .36428 L .64709 .35972 L p F P
0 g
s
.588 .511 .736 r
.64948 .36728 m .64709 .35972 L .63701 .36428 L p F P
0 g
s
.588 .511 .736 r
.64531 .36919 m .64948 .36728 L p .63701 .36428 L F P
0 g
s
.824 .602 .601 r
.17186 .39962 m .17272 .39995 L .17394 .39468 L p F P
0 g
s
.824 .602 .601 r
.17394 .39468 m .17116 .39361 L .17186 .39962 L p F P
0 g
s
.762 .704 .798 r
.17683 .35664 m .18539 .35004 L p .17143 .35386 L F P
0 g
s
.762 .704 .798 r
.17143 .35386 m .1721 .35478 L .17683 .35664 L p F P
0 g
s
.577 .473 .699 r
.6512 .37406 m .64112 .37861 L .6394 .37184 L p F P
0 g
s
.577 .473 .699 r
.64994 .36896 m .6512 .37406 L p .6394 .37184 L F P
0 g
s
.577 .473 .699 r
.6394 .37184 m .64531 .36919 L .64994 .36896 L p F P
0 g
s
.826 .58 .568 r
.17209 .40504 m .17813 .40729 L .17875 .40221 L p F P
0 g
s
.826 .58 .568 r
.17875 .40221 m .17272 .39995 L .17209 .40504 L p F P
0 g
s
.686 .25 .209 r
.29317 .47292 m .30172 .47428 L .29735 .47063 L p F P
0 g
s
.686 .25 .209 r
.29162 .47161 m .29317 .47292 L p .29735 .47063 L F P
0 g
s
.686 .25 .209 r
.29735 .47063 m .2936 .47004 L .29162 .47161 L p F P
0 g
s
.471 .12 .289 r
.5645 .45615 m .56579 .45255 L .55444 .45537 L p F P
0 g
s
.471 .12 .289 r
.55444 .45537 m .55314 .45897 L .5645 .45615 L p F P
0 g
s
.821 .625 .638 r
.16987 .3869 m .16957 .38679 L .16971 .38733 L closepath p F P
0 g
s
.603 .539 .755 r
.64709 .35972 m .64699 .35944 L .63591 .36126 L p F P
0 g
s
.606 .56 .777 r
.63355 .35548 m .63591 .36126 L .64699 .35944 L p F P
0 g
s
.825 .645 .659 r
.16423 .38449 m .16957 .38679 L .1668 .37887 L p F P
0 g
s
.831 .629 .63 r
.1681 .39234 m .16971 .38733 L .16957 .38679 L p F P
0 g
s
.831 .629 .63 r
.16243 .38995 m .1681 .39234 L p .16957 .38679 L F P
0 g
s
.831 .629 .63 r
.16957 .38679 m .16423 .38449 L .16243 .38995 L p F P
0 g
s
.806 .476 .432 r
.20549 .43484 m .20419 .43033 L .21065 .43241 L p F P
0 g
s
.806 .476 .432 r
.21072 .43653 m .20549 .43484 L p .21065 .43241 L F P
0 g
s
.806 .476 .432 r
.21065 .43241 m .21148 .43528 L .21072 .43653 L p F P
0 g
s
.662 .758 .921 r
.57522 .34622 m .58615 .3427 L .58894 .34573 L p F P
0 g
s
.661 .787 .941 r
.58615 .3427 m .57522 .34622 L .57242 .34364 L p F P
0 g
s
.658 .789 .944 r
.56151 .34715 m .57242 .34364 L .57522 .34622 L p F P
0 g
s
.828 .625 .628 r
.16971 .38733 m .1681 .39234 L .17116 .39361 L closepath p F P
0 g
s
.49 .061 .152 r
.48639 .47698 m .47785 .47801 L .47605 .48053 L p F P
0 g
s
.513 .297 .524 r
.62584 .41347 m .62341 .41442 L .62339 .40955 L p F P
0 g
s
.513 .297 .524 r
.62339 .40955 m .62823 .40767 L .62584 .41347 L p F P
0 g
s
.826 .559 .534 r
.17803 .41222 m .1841 .41445 L .1842 .40953 L p F P
0 g
s
.826 .559 .534 r
.1842 .40953 m .17813 .40729 L .17803 .41222 L p F P
0 g
s
.653 .818 .963 r
.56962 .34141 m .57242 .34364 L .56151 .34715 L p F P
0 g
s
.653 .818 .963 r
.56766 .34205 m .56962 .34141 L p .56151 .34715 L F P
0 g
s
.653 .818 .963 r
.56151 .34715 m .5588 .34503 L .56766 .34205 L p F P
0 g
s
.649 .813 .962 r
.5588 .34503 m .56151 .34715 L p .54781 .34838 L F P
0 g
s
.789 .701 .768 r
.16412 .3614 m .16976 .36383 L p .1721 .35478 L F P
0 g
s
.797 .684 .74 r
.16239 .36943 m .16466 .37037 L .16976 .36383 L p F P
0 g
s
.797 .684 .74 r
.16045 .36591 m .16239 .36943 L p .16976 .36383 L F P
0 g
s
.797 .684 .74 r
.16976 .36383 m .16412 .3614 L .16045 .36591 L p F P
0 g
s
.716 .302 .261 r
.27827 .46513 m .28079 .46774 L .27629 .46691 L closepath p F P
0 g
s
.66 .723 .896 r
.58894 .34573 m .59989 .34226 L .60267 .34581 L p F P
0 g
s
.663 .753 .917 r
.59989 .34226 m .58894 .34573 L .58615 .3427 L p F P
0 g
s
.641 .187 .157 r
.3247 .4802 m .33415 .48127 L .32878 .4779 L p F P
0 g
s
.641 .187 .157 r
.32205 .47853 m .3247 .4802 L p .32878 .4779 L F P
0 g
s
.641 .187 .157 r
.32878 .4779 m .32361 .47732 L .32205 .47853 L p F P
0 g
s
.568 .767 .972 r
.25264 .34637 m .2539 .34733 L p .24027 .34659 L F P
0 g
s
.568 .767 .972 r
.24027 .34659 m .24791 .34527 L .25264 .34637 L p F P
0 g
s
.543 .758 .976 r
.24791 .34527 m .24027 .34659 L .23694 .3438 L p F P
0 g
s
.818 .656 .682 r
.16675 .37874 m .1667 .37883 L .1668 .37887 L closepath p F P
0 g
s
.825 .645 .659 r
.1668 .37887 m .1667 .37883 L .16423 .38449 L p F P
0 g
s
.819 .662 .689 r
.1667 .37883 m .16675 .37874 L .16363 .37193 L p F P
0 g
s
.749 .351 .298 r
.24668 .45721 m .25408 .45896 L .25117 .4549 L p F P
0 g
s
.749 .351 .298 r
.24464 .45438 m .24668 .45721 L p .25117 .4549 L F P
0 g
s
.749 .351 .298 r
.25117 .4549 m .24552 .45359 L .24464 .45438 L p F P
0 g
s
.819 .662 .689 r
.16363 .37193 m .16117 .37637 L .1667 .37883 L p F P
0 g
s
.827 .649 .662 r
.15863 .38206 m .16423 .38449 L .1667 .37883 L p F P
0 g
s
.827 .649 .662 r
.1667 .37883 m .16117 .37637 L .15863 .38206 L p F P
0 g
s
.356 .763 .983 r
.32201 .35438 m .31226 .35445 L .32046 .356 L p F P
0 g
s
.356 .763 .983 r
.32046 .356 m .32528 .35577 L .32201 .35438 L p F P
0 g
s
.331 .737 .981 r
.31164 .35446 m .31226 .35445 L .32046 .356 L p F P
0 g
s
.649 .813 .962 r
.54781 .34838 m .54976 .34776 L .5588 .34503 L p F P
0 g
s
.637 .844 .98 r
.54781 .34838 m .54976 .34776 L .54779 .34836 L closepath p F P
0 g
s
.636 .844 .98 r
.54976 .34776 m .54779 .34836 L .54497 .34656 L p F P
0 g
s
.7 .27 .223 r
.2936 .47004 m .29162 .47161 L .28897 .46922 L closepath p F P
0 g
s
.727 .719 .843 r
.18993 .34742 m .18539 .35004 L .18206 .34609 L p F P
0 g
s
.762 .704 .798 r
.18539 .35004 m .18206 .34609 L .17143 .35386 L p F P
0 g
s
.253 .732 .934 r
.36682 .35908 m .36947 .35989 L p .35581 .3592 L F P
0 g
s
.253 .732 .934 r
.35581 .3592 m .36505 .35896 L .36682 .35908 L p F P
0 g
s
.162 .682 .885 r
.36505 .35896 m .35581 .3592 L .3526 .35806 L p F P
0 g
s
.365 .753 .988 r
.31122 .35424 m .31164 .35446 L p .29802 .35316 L F P
0 g
s
.365 .753 .988 r
.29802 .35316 m .30378 .35299 L .31122 .35424 L p F P
0 g
s
.328 .728 .981 r
.30378 .35299 m .29802 .35316 L .29474 .35127 L p F P
0 g
s
.825 .537 .501 r
.18447 .41924 m .19057 .42146 L .1902 .41667 L p F P
0 g
s
.825 .537 .501 r
.1902 .41667 m .1841 .41445 L .18447 .41924 L p F P
0 g
s
.771 .394 .341 r
.22965 .44943 m .23671 .4513 L .23435 .44709 L p F P
0 g
s
.771 .394 .341 r
.22795 .44641 m .22965 .44943 L p .23435 .44709 L F P
0 g
s
.771 .394 .341 r
.23435 .44709 m .22873 .44561 L .22795 .44641 L p F P
0 g
s
.556 .431 .666 r
.65247 .38031 m .6512 .37406 L .64112 .37861 L p F P
0 g
s
.556 .431 .666 r
.64726 .38267 m .65247 .38031 L p .64112 .37861 L F P
0 g
s
.556 .431 .666 r
.64112 .37861 m .64184 .38208 L .64726 .38267 L p F P
0 g
s
.726 .311 .26 r
.26505 .46457 m .2728 .46619 L .26932 .46229 L p F P
0 g
s
.726 .311 .26 r
.26932 .46229 m .26151 .46069 L .26505 .46457 L p F P
0 g
s
.659 .716 .89 r
.61366 .34248 m .60267 .34581 L .59989 .34226 L p F P
0 g
s
.654 .686 .868 r
.60267 .34581 m .61366 .34248 L .61644 .34664 L p F P
0 g
s
.609 .863 .991 r
.54497 .34656 m .5341 .34985 L .53124 .34832 L p F P
0 g
s
.603 .857 .992 r
.52039 .35144 m .53124 .34832 L .5341 .34985 L p F P
0 g
s
.657 .207 .172 r
.32361 .47732 m .32205 .47853 L .31946 .47679 L closepath p F P
0 g
s
.833 .608 .598 r
.16695 .39759 m .17186 .39962 L .17116 .39361 L p F P
0 g
s
.833 .608 .598 r
.17116 .39361 m .1681 .39234 L .16695 .39759 L p F P
0 g
s
.644 .658 .848 r
.61644 .34664 m .61721 .34794 L .62745 .34357 L p F P
0 g
s
.637 .646 .842 r
.63025 .3486 m .62745 .34357 L .61721 .34794 L p F P
0 g
s
.555 .095 .116 r
.40976 .48488 m .4073 .48725 L .39983 .48487 L closepath p F P
0 g
s
.538 .075 .103 r
.41287 .48483 m .40976 .48488 L .4073 .48725 L p F P
0 g
s
.552 .086 .103 r
.40707 .48746 m .4073 .48725 L .39983 .48487 L p F P
0 g
s
.552 .086 .103 r
.39525 .48741 m .40707 .48746 L p .39983 .48487 L F P
0 g
s
.552 .086 .103 r
.39358 .48686 m .39525 .48741 L p .39983 .48487 L F P
0 g
s
.552 .086 .103 r
.39983 .48487 m .39577 .48486 L .39358 .48686 L p F P
0 g
s
.569 .106 .116 r
.39577 .48486 m .39358 .48686 L .38756 .48468 L closepath p F P
0 g
s
.677 .246 .217 r
.30856 .47411 m .31044 .47558 L .30736 .47516 L closepath p F P
0 g
s
.606 .56 .777 r
.64413 .35209 m .63859 .35319 L .63355 .35548 L p F P
0 g
s
.606 .56 .777 r
.64699 .35944 m .64413 .35209 L p .63355 .35548 L F P
0 g
s
.618 .582 .791 r
.63306 .35436 m .63859 .35319 L .63355 .35548 L closepath p F P
0 g
s
.54 .082 .114 r
.42345 .48461 m .42103 .48706 L .41287 .48483 L closepath p F P
0 g
s
.538 .075 .103 r
.42085 .48725 m .42103 .48706 L .41287 .48483 L p F P
0 g
s
.538 .075 .103 r
.40801 .48745 m .42085 .48725 L p .41287 .48483 L F P
0 g
s
.538 .075 .103 r
.4073 .48725 m .40801 .48745 L p .41287 .48483 L F P
0 g
s
.488 .136 .295 r
.54175 .46123 m .544 .46105 L .54162 .46159 L closepath p F P
0 g
s
.499 .24 .452 r
.61219 .42727 m .61248 .42443 L .60156 .43007 L p F P
0 g
s
.499 .24 .452 r
.60156 .43007 m .60148 .43091 L .61219 .42727 L p F P
0 g
s
.468 .068 .196 r
.52484 .46805 m .51648 .46957 L .5147 .47278 L p F P
0 g
s
.648 .817 .964 r
.5588 .34503 m .55869 .34494 L .54976 .34776 L closepath p F P
0 g
s
.636 .844 .98 r
.55587 .34313 m .55869 .34494 L .54976 .34776 L p F P
0 g
s
.636 .844 .98 r
.54497 .34656 m .55587 .34313 L p .54976 .34776 L F P
0 g
s
.525 .749 .977 r
.2539 .34733 m .25499 .34721 L .25264 .34637 L closepath p F P
0 g
s
.565 .097 .102 r
.393 .48739 m .39358 .48686 L .38756 .48468 L p F P
0 g
s
.565 .097 .102 r
.38322 .48713 m .393 .48739 L p .38756 .48468 L F P
0 g
s
.565 .097 .102 r
.37988 .48591 m .38322 .48713 L p .38756 .48468 L F P
0 g
s
.565 .097 .102 r
.38756 .48468 m .38148 .48453 L .37988 .48591 L p F P
0 g
s
.479 .151 .332 r
.57699 .44954 m .57721 .44877 L .56626 .45091 L p F P
0 g
s
.479 .151 .332 r
.56626 .45091 m .56579 .45255 L .57699 .44954 L p F P
0 g
s
.523 .063 .101 r
.42687 .48449 m .42345 .48461 L .42103 .48706 L p F P
0 g
s
.53 .857 .996 r
.49329 .35476 m .49295 .35463 L .4903 .35524 L closepath p F P
0 g
s
.511 .862 .991 r
.49001 .35378 m .49295 .35463 L .4903 .35524 L p F P
0 g
s
.511 .862 .991 r
.47922 .35614 m .49001 .35378 L p .4903 .35524 L F P
0 g
s
.626 .599 .803 r
.63859 .35319 m .63306 .35436 L .63025 .3486 L p F P
0 g
s
.487 .059 .153 r
.49032 .47649 m .48979 .47725 L .48639 .47698 L closepath p F P
0 g
s
.49 .061 .152 r
.48824 .47946 m .48979 .47725 L .48639 .47698 L p F P
0 g
s
.49 .061 .152 r
.478 .48071 m .48824 .47946 L p .48639 .47698 L F P
0 g
s
.49 .061 .152 r
.47605 .48053 m .478 .48071 L p .48639 .47698 L F P
0 g
s
.485 .081 .199 r
.50352 .47314 m .51132 .47334 L .5026 .47474 L closepath p F P
0 g
s
.792 .438 .387 r
.21383 .44126 m .22056 .44325 L .21874 .43888 L p F P
0 g
s
.792 .438 .387 r
.21874 .43888 m .21198 .43691 L .21383 .44126 L p F P
0 g
s
.576 .872 .995 r
.53124 .34832 m .52039 .35144 L .5175 .35014 L p F P
0 g
s
.571 .865 .996 r
.50667 .35305 m .5175 .35014 L .52039 .35144 L p F P
0 g
s
.582 .117 .115 r
.38148 .48453 m .37988 .48591 L .37592 .4843 L closepath p F P
0 g
s
.807 .666 .708 r
.16466 .37037 m .16239 .36943 L .16363 .37193 L closepath p F P
0 g
s
.229 .725 .914 r
.38167 .35997 m .38316 .36036 L p .36947 .35989 L F P
0 g
s
.229 .725 .914 r
.36947 .35989 m .3757 .35969 L .38167 .35997 L p F P
0 g
s
.267 .739 .941 r
.36947 .35989 m .3757 .35969 L .36682 .35908 L closepath p F P
0 g
s
.524 .068 .11 r
.43687 .48408 m .43478 .48628 L .42687 .48449 L closepath p F P
0 g
s
.523 .063 .101 r
.43434 .48675 m .43478 .48628 L .42687 .48449 L p F P
0 g
s
.523 .063 .101 r
.42171 .48722 m .43434 .48675 L p .42687 .48449 L F P
0 g
s
.523 .063 .101 r
.42103 .48706 m .42171 .48722 L p .42687 .48449 L F P
0 g
s
.813 .502 .463 r
.19138 .42611 m .19777 .42823 L .19688 .4236 L p F P
0 g
s
.813 .502 .463 r
.19131 .42576 m .19138 .42611 L p .19688 .4236 L F P
0 g
s
.813 .502 .463 r
.19688 .4236 m .19297 .42231 L .19131 .42576 L p F P
0 g
s
.701 .269 .222 r
.28492 .47146 m .28079 .46774 L .28897 .46922 L p F P
0 g
s
.701 .269 .222 r
.29052 .47248 m .28492 .47146 L p .28897 .46922 L F P
0 g
s
.701 .269 .222 r
.28897 .46922 m .29162 .47161 L .29052 .47248 L p F P
0 g
s
.557 .423 .654 r
.64184 .38208 m .64726 .38267 L .64237 .38484 L closepath p F P
0 g
s
.46 .083 .236 r
.544 .46105 m .54162 .46159 L .54008 .46499 L p F P
0 g
s
.714 .73 .863 r
.18993 .34742 m .19588 .34419 L .19252 .34069 L p F P
0 g
s
.714 .73 .863 r
.19252 .34069 m .18387 .34511 L .18993 .34742 L p F P
0 g
s
.727 .719 .843 r
.18206 .34609 m .18387 .34511 L .18993 .34742 L p F P
0 g
s
.657 .207 .17 r
.31553 .47904 m .31044 .47558 L .31946 .47679 L p F P
0 g
s
.657 .207 .17 r
.32053 .47971 m .31553 .47904 L p .31946 .47679 L F P
0 g
s
.657 .207 .17 r
.31946 .47679 m .32205 .47853 L .32053 .47971 L p F P
0 g
s
.577 .105 .099 r
.3786 .487 m .37988 .48591 L .37592 .4843 L p F P
0 g
s
.577 .105 .099 r
.37178 .48668 m .3786 .487 L p .37592 .4843 L F P
0 g
s
.577 .105 .099 r
.36621 .48441 m .37178 .48668 L p .37592 .4843 L F P
0 g
s
.577 .105 .099 r
.37592 .4843 m .36685 .48389 L .36621 .48441 L p F P
0 g
s
.644 .658 .848 r
.62745 .34357 m .62745 .34357 L .61644 .34664 L p F P
0 g
s
.651 .677 .862 r
.62745 .34357 m .61644 .34664 L .61366 .34248 L p F P
0 g
s
.621 .173 .167 r
.35259 .48222 m .35417 .48306 L .35185 .4829 L closepath p F P
0 g
s
.52 .748 .979 r
.26084 .34398 m .26418 .34617 L .25499 .34721 L p F P
0 g
s
.52 .748 .979 r
.25057 .3448 m .26084 .34398 L p .25499 .34721 L F P
0 g
s
.52 .748 .979 r
.25499 .34721 m .25264 .34637 L .25057 .3448 L p F P
0 g
s
.477 .196 .407 r
.61155 .43145 m .61219 .42727 L .60148 .43091 L p F P
0 g
s
.477 .196 .407 r
.60148 .43091 m .60082 .43509 L .61155 .43145 L p F P
0 g
s
.471 .168 .369 r
.59998 .43908 m .60082 .43509 L .58994 .43852 L p F P
0 g
s
.471 .168 .369 r
.58994 .43852 m .58908 .44251 L .59998 .43908 L p F P
0 g
s
.82 .668 .694 r
.16117 .37637 m .16363 .37193 L .16239 .36943 L p F P
0 g
s
.789 .701 .768 r
.1721 .35478 m .17099 .35427 L .16412 .3614 L p F P
0 g
s
.78 .708 .785 r
.17143 .35386 m .17099 .35427 L .1721 .35478 L closepath p F P
0 g
s
.342 .737 .984 r
.31164 .35446 m .31226 .35445 L .31122 .35424 L closepath p F P
0 g
s
.54 .861 .996 r
.50376 .35199 m .50521 .35252 L .49329 .35476 L p F P
0 g
s
.54 .861 .996 r
.49329 .35476 m .49295 .35463 L .50376 .35199 L p F P
0 g
s
.545 .873 .993 r
.51684 .34992 m .5175 .35014 L .50667 .35305 L p F P
0 g
s
.545 .873 .993 r
.50667 .35305 m .50521 .35252 L .51684 .34992 L p F P
0 g
s
.472 .044 .144 r
.5006 .4777 m .5026 .47474 L .49032 .47649 L p F P
0 g
s
.472 .044 .144 r
.49032 .47649 m .48979 .47725 L .5006 .4777 L p F P
0 g
s
.517 .325 .558 r
.64407 .4012 m .64378 .39606 L .63353 .40035 L p F P
0 g
s
.517 .325 .558 r
.63353 .40035 m .6338 .40549 L .64407 .4012 L p F P
0 g
s
.507 .049 .098 r
.4421 .48377 m .43687 .48408 L .43478 .48628 L p F P
0 g
s
.761 .368 .31 r
.24552 .45359 m .24464 .45438 L .2438 .45315 L closepath p F P
0 g
s
.594 .126 .113 r
.36685 .48389 m .36621 .48441 L .36477 .48377 L closepath p F P
0 g
s
.46 .085 .24 r
.55314 .45897 m .55266 .46006 L .544 .46105 L closepath p F P
0 g
s
.46 .083 .236 r
.55163 .46238 m .55266 .46006 L .544 .46105 L p F P
0 g
s
.46 .083 .236 r
.54008 .46499 m .55163 .46238 L p .544 .46105 L F P
0 g
s
.22 .725 .901 r
.39605 .36039 m .39686 .36056 L p .38316 .36036 L F P
0 g
s
.22 .725 .901 r
.38316 .36036 m .3871 .36018 L .39605 .36039 L p F P
0 g
s
.251 .738 .925 r
.38316 .36036 m .3871 .36018 L .38167 .35997 L closepath p F P
0 g
s
.332 .734 .981 r
.319 .3532 m .32201 .35438 L .31226 .35445 L p F P
0 g
s
.332 .734 .981 r
.31828 .35309 m .319 .3532 L p .31226 .35445 L F P
0 g
s
.332 .734 .981 r
.30837 .35284 m .31828 .35309 L p .31226 .35445 L F P
0 g
s
.332 .734 .981 r
.31226 .35445 m .31122 .35424 L .30837 .35284 L p F P
0 g
s
.543 .392 .627 r
.65336 .38613 m .64323 .39062 L .64237 .38484 L p F P
0 g
s
.543 .392 .627 r
.6531 .38435 m .65336 .38613 L p .64237 .38484 L F P
0 g
s
.543 .392 .627 r
.64237 .38484 m .64726 .38267 L .6531 .38435 L p F P
0 g
s
.51 .295 .523 r
.63383 .41035 m .62584 .41347 L .62823 .40767 L p F P
0 g
s
.51 .295 .523 r
.62823 .40767 m .6338 .40549 L .63383 .41035 L p F P
0 g
s
.465 .14 .33 r
.58818 .44584 m .58908 .44251 L .57805 .44573 L p F P
0 g
s
.465 .14 .33 r
.57805 .44573 m .57721 .44877 L .58818 .44584 L p F P
0 g
s
.487 .229 .449 r
.61263 .42288 m .61248 .42443 L .61771 .42104 L closepath p F P
0 g
s
.508 .052 .105 r
.45005 .48328 m .44854 .48494 L .4421 .48377 L closepath p F P
0 g
s
.507 .049 .098 r
.44758 .48599 m .44854 .48494 L .4421 .48377 L p F P
0 g
s
.507 .049 .098 r
.43657 .48663 m .44758 .48599 L p .4421 .48377 L F P
0 g
s
.507 .049 .098 r
.43478 .48628 m .43657 .48663 L p .4421 .48377 L F P
0 g
s
.594 .125 .112 r
.36081 .48608 m .35417 .48306 L .36477 .48377 L p F P
0 g
s
.594 .125 .112 r
.36386 .48628 m .36081 .48608 L p .36477 .48377 L F P
0 g
s
.594 .125 .112 r
.36477 .48377 m .36621 .48441 L .36386 .48628 L p F P
0 g
s
.453 .76 .995 r
.26751 .34845 m .2778 .34776 L .28112 .3498 L p F P
0 g
s
.406 .75 .994 r
.2778 .34776 m .26751 .34845 L .26418 .34617 L p F P
0 g
s
.8 .468 .428 r
.21148 .43528 m .21198 .43691 L .21072 .43653 L closepath p F P
0 g
s
.835 .611 .599 r
.16125 .39521 m .16695 .39759 L .1681 .39234 L p F P
0 g
s
.835 .611 .599 r
.1681 .39234 m .16243 .38995 L .16125 .39521 L p F P
0 g
s
.828 .583 .568 r
.17176 .40491 m .17209 .40504 L .17272 .39995 L p F P
0 g
s
.828 .583 .568 r
.17272 .39995 m .17186 .39962 L .17176 .40491 L p F P
0 g
s
.752 .728 .83 r
.17143 .35386 m .18206 .34609 L .18002 .34375 L p F P
0 g
s
.752 .728 .83 r
.16811 .34953 m .17143 .35386 L p .18002 .34375 L F P
0 g
s
.777 .713 .792 r
.17099 .35427 m .17143 .35386 L .16811 .34953 L p F P
0 g
s
.469 .861 .973 r
.50376 .35199 m .49295 .35463 L .49001 .35378 L p F P
0 g
s
.788 .705 .773 r
.15847 .35896 m .16412 .3614 L .17099 .35427 L p F P
0 g
s
.788 .705 .773 r
.17099 .35427 m .16565 .35172 L .15847 .35896 L p F P
0 g
s
.777 .713 .792 r
.16811 .34953 m .16565 .35172 L .17099 .35427 L p F P
0 g
s
.782 .409 .351 r
.22873 .44561 m .22795 .44641 L .22732 .44521 L closepath p F P
0 g
s
.373 .755 .989 r
.31122 .35424 m .30837 .35284 L .30378 .35299 L closepath p F P
0 g
s
.743 .351 .311 r
.26142 .46057 m .26151 .46069 L .26134 .46065 L closepath p F P
0 g
s
.812 .679 .717 r
.16045 .36591 m .15909 .36791 L .16239 .36943 L closepath p F P
0 g
s
.82 .668 .694 r
.15566 .3739 m .16117 .37637 L p .16239 .36943 L F P
0 g
s
.82 .668 .694 r
.16239 .36943 m .15909 .36791 L .15566 .3739 L p F P
0 g
s
.809 .477 .427 r
.19908 .43273 m .20549 .43484 L .20419 .43033 L p F P
0 g
s
.809 .477 .427 r
.20419 .43033 m .19777 .42823 L .19908 .43273 L p F P
0 g
s
.762 .368 .309 r
.23944 .45541 m .23671 .4513 L .2438 .45315 L p F P
0 g
s
.762 .368 .309 r
.24257 .45622 m .23944 .45541 L p .2438 .45315 L F P
0 g
s
.762 .368 .309 r
.2438 .45315 m .24464 .45438 L .24257 .45622 L p F P
0 g
s
.728 .309 .254 r
.25822 .46311 m .26505 .46457 L .26151 .46069 L p F P
0 g
s
.728 .309 .254 r
.26151 .46069 m .26134 .46065 L .25822 .46311 L p F P
0 g
s
.741 .329 .267 r
.25736 .46292 m .25822 .46311 L .26134 .46065 L p F P
0 g
s
.741 .329 .267 r
.26134 .46065 m .25408 .45896 L .25736 .46292 L p F P
0 g
s
.832 .632 .632 r
.1568 .38753 m .16243 .38995 L .16423 .38449 L p F P
0 g
s
.832 .632 .632 r
.16423 .38449 m .15863 .38206 L .1568 .38753 L p F P
0 g
s
.828 .559 .533 r
.17199 .40996 m .17803 .41222 L .17813 .40729 L p F P
0 g
s
.828 .559 .533 r
.17813 .40729 m .17209 .40504 L .17199 .40996 L p F P
0 g
s
.571 .766 .971 r
.25264 .34637 m .25057 .3448 L .24791 .34527 L closepath p F P
0 g
s
.578 .479 .705 r
.64531 .36919 m .64948 .36728 L .64994 .36896 L closepath p F P
0 g
s
.227 .732 .896 r
.41003 .36039 m .41057 .36049 L p .39686 .36056 L F P
0 g
s
.227 .732 .896 r
.39686 .36056 m .3993 .36041 L .41003 .36039 L p F P
0 g
s
.249 .742 .913 r
.39686 .36056 m .3993 .36041 L .39605 .36039 L closepath p F P
0 g
s
.837 .59 .566 r
.16632 .40268 m .17176 .40491 L .17186 .39962 L p F P
0 g
s
.837 .59 .566 r
.17186 .39962 m .16695 .39759 L .16632 .40268 L p F P
0 g
s
.422 .844 .959 r
.49001 .35378 m .47922 .35614 L .47625 .35541 L p F P
0 g
s
.424 .84 .966 r
.46549 .35748 m .47625 .35541 L .47922 .35614 L p F P
0 g
s
.783 .41 .35 r
.22276 .4475 m .22056 .44325 L .22732 .44521 L p F P
0 g
s
.783 .41 .35 r
.22595 .44843 m .22276 .4475 L p .22732 .44521 L F P
0 g
s
.783 .41 .35 r
.22732 .44521 m .22795 .44641 L .22595 .44843 L p F P
0 g
s
.491 .033 .094 r
.45891 .48259 m .45005 .48328 L .44854 .48494 L p F P
0 g
s
.466 .065 .195 r
.52837 .46739 m .52807 .46794 L .52484 .46805 L closepath p F P
0 g
s
.468 .068 .196 r
.52661 .47059 m .52807 .46794 L .52484 .46805 L p F P
0 g
s
.468 .068 .196 r
.5147 .47278 m .52661 .47059 L p .52484 .46805 L F P
0 g
s
.642 .756 .932 r
.20961 .34334 m .21994 .3403 L .22329 .34327 L p F P
0 g
s
.626 .757 .941 r
.21994 .3403 m .20961 .34334 L .20626 .34011 L p F P
0 g
s
.682 .75 .902 r
.19588 .34419 m .20626 .34011 L .20961 .34334 L p F P
0 g
s
.796 .681 .738 r
.15721 .36042 m .15847 .35896 L .16412 .3614 L p F P
0 g
s
.796 .681 .738 r
.16412 .3614 m .16045 .36591 L .15721 .36042 L p F P
0 g
s
.822 .513 .467 r
.19297 .42231 m .19131 .42576 L .19057 .42146 L closepath p F P
0 g
s
.655 .197 .153 r
.3066 .47779 m .31553 .47904 L .31044 .47558 L p F P
0 g
s
.655 .197 .153 r
.30509 .47676 m .3066 .47779 L p .31044 .47558 L F P
0 g
s
.655 .197 .153 r
.31044 .47558 m .30736 .47516 L .30509 .47676 L p F P
0 g
s
.67 .752 .912 r
.20626 .34011 m .19588 .34419 L .19252 .34069 L p F P
0 g
s
.156 .669 .896 r
.33568 .3558 m .32528 .35577 L .32201 .35438 L p F P
0 g
s
.593 .12 .099 r
.35031 .48533 m .36081 .48608 L .35417 .48306 L p F P
0 g
s
.593 .12 .099 r
.34924 .48484 m .35031 .48533 L p .35417 .48306 L F P
0 g
s
.593 .12 .099 r
.35417 .48306 m .35185 .4829 L .34924 .48484 L p F P
0 g
s
.248 .748 .9 r
.42367 .36004 m .42429 .36014 L p .41057 .36049 L F P
0 g
s
.248 .748 .9 r
.41057 .36049 m .41243 .36034 L .42367 .36004 L p F P
0 g
s
.259 .753 .909 r
.41057 .36049 m .41243 .36034 L .41003 .36039 L closepath p F P
0 g
s
.4 .832 .955 r
.47517 .35525 m .47625 .35541 L .46549 .35748 L p F P
0 g
s
.4 .832 .955 r
.46549 .35748 m .46267 .35688 L .47517 .35525 L p F P
0 g
s
.382 .821 .953 r
.46267 .35688 m .46549 .35748 L p .45175 .35862 L F P
0 g
s
.454 .103 .28 r
.57572 .45313 m .57699 .44954 L .56579 .45255 L p F P
0 g
s
.454 .103 .28 r
.56579 .45255 m .5645 .45615 L .57572 .45313 L p F P
0 g
s
.827 .537 .499 r
.1784 .417 m .18447 .41924 L .1841 .41445 L p F P
0 g
s
.827 .537 .499 r
.1841 .41445 m .17803 .41222 L .1784 .417 L p F P
0 g
s
.827 .651 .664 r
.15306 .37961 m .15863 .38206 L .16117 .37637 L p F P
0 g
s
.827 .651 .664 r
.16117 .37637 m .15566 .3739 L .15306 .37961 L p F P
0 g
s
.698 .258 .202 r
.27683 .46994 m .28492 .47146 L .28079 .46774 L p F P
0 g
s
.698 .258 .202 r
.2747 .46802 m .27683 .46994 L p .28079 .46774 L F P
0 g
s
.698 .258 .202 r
.28079 .46774 m .27629 .46691 L .2747 .46802 L p F P
0 g
s
.494 .258 .486 r
.62341 .41442 m .62333 .41616 L .62584 .41347 L closepath p F P
0 g
s
.472 .043 .142 r
.50057 .47775 m .5006 .4777 L .48979 .47725 L p F P
0 g
s
.472 .043 .142 r
.48979 .47725 m .48824 .47946 L .50057 .47775 L p F P
0 g
s
.611 .141 .115 r
.35185 .4829 m .34924 .48484 L .34403 .48221 L closepath p F P
0 g
s
.597 .761 .957 r
.22329 .34327 m .23359 .34108 L .23694 .3438 L p F P
0 g
s
.574 .762 .967 r
.23359 .34108 m .22329 .34327 L .21994 .3403 L p F P
0 g
s
.626 .599 .803 r
.64358 .35084 m .63859 .35319 L p .63025 .3486 L F P
0 g
s
.626 .599 .803 r
.63025 .3486 m .64131 .34598 L .64358 .35084 L p F P
0 g
s
.63 .636 .837 r
.62745 .34357 m .63025 .3486 L .64131 .34598 L p F P
0 g
s
.382 .821 .953 r
.45175 .35862 m .46149 .35701 L .46267 .35688 L p F P
0 g
s
.361 .814 .939 r
.45175 .35862 m .46149 .35701 L .45 .35829 L closepath p F P
0 g
s
.329 .795 .932 r
.45 .35829 m .45175 .35862 L p .43802 .35952 L F P
0 g
s
.283 .769 .913 r
.43699 .35934 m .43802 .35952 L p .42429 .36014 L F P
0 g
s
.283 .769 .913 r
.42429 .36014 m .42677 .35987 L .43699 .35934 L p F P
0 g
s
.283 .769 .913 r
.42429 .36014 m .42677 .35987 L .42367 .36004 L closepath p F P
0 g
s
.671 .219 .169 r
.30736 .47516 m .30509 .47676 L .30172 .47428 L closepath p F P
0 g
s
.581 .11 .101 r
.36621 .48441 m .37178 .48668 L .36386 .48628 L closepath p F P
0 g
s
.318 .791 .923 r
.43802 .35952 m .44283 .35886 L .43699 .35934 L closepath p F P
0 g
s
.329 .795 .932 r
.43802 .35952 m .44283 .35886 L .45 .35829 L p F P
0 g
s
.615 .579 .79 r
.63859 .35319 m .64358 .35084 L .64413 .35209 L closepath p F P
0 g
s
.486 .228 .448 r
.61771 .42104 m .61248 .42443 L .61219 .42727 L p F P
0 g
s
.377 .749 .991 r
.29369 .35071 m .29474 .35127 L p .28112 .3498 L F P
0 g
s
.377 .749 .991 r
.28112 .3498 m .28817 .34962 L .29369 .35071 L p F P
0 g
s
.336 .726 .983 r
.28817 .34962 m .28112 .3498 L .2778 .34776 L p F P
0 g
s
.449 .048 .186 r
.53897 .46706 m .54008 .46499 L .52837 .46739 L p F P
0 g
s
.449 .048 .186 r
.52837 .46739 m .52807 .46794 L .53897 .46706 L p F P
0 g
s
.719 .724 .853 r
.18387 .34511 m .18002 .34375 L .18206 .34609 L closepath p F P
0 g
s
.794 .438 .383 r
.20815 .43955 m .21383 .44126 L .21198 .43691 L p F P
0 g
s
.794 .438 .383 r
.21198 .43691 m .21072 .43653 L .20815 .43955 L p F P
0 g
s
.811 .683 .723 r
.15909 .36791 m .16045 .36591 L .15721 .36042 L p F P
0 g
s
.491 .033 .094 r
.46059 .48498 m .4623 .48304 L .45891 .48259 L p F P
0 g
s
.491 .033 .094 r
.45293 .48558 m .46059 .48498 L p .45891 .48259 L F P
0 g
s
.491 .033 .094 r
.44854 .48494 m .45293 .48558 L p .45891 .48259 L F P
0 g
s
.49 .036 .099 r
.463 .48225 m .4623 .48304 L .45891 .48259 L closepath p F P
0 g
s
.754 .357 .301 r
.24464 .45438 m .24668 .45721 L .24257 .45622 L closepath p F P
0 g
s
.357 .755 .985 r
.30507 .35133 m .29604 .35129 L .30378 .35299 L p F P
0 g
s
.357 .755 .985 r
.30378 .35299 m .30837 .35284 L .30507 .35133 L p F P
0 g
s
.328 .728 .981 r
.29474 .35127 m .29604 .35129 L .30378 .35299 L p F P
0 g
s
.663 .753 .917 r
.58615 .3427 m .59711 .33915 L .59989 .34226 L p F P
0 g
s
.664 .782 .937 r
.59711 .33915 m .58615 .3427 L .58336 .34006 L p F P
0 g
s
.661 .787 .941 r
.57242 .34364 m .58336 .34006 L .58615 .3427 L p F P
0 g
s
.823 .513 .466 r
.18527 .42389 m .18447 .41924 L .19057 .42146 L p F P
0 g
s
.823 .513 .466 r
.19117 .42604 m .18527 .42389 L p .19057 .42146 L F P
0 g
s
.823 .513 .466 r
.19057 .42146 m .19131 .42576 L .19117 .42604 L p F P
0 g
s
.543 .758 .976 r
.23694 .3438 m .24111 .34322 L .24791 .34527 L p F P
0 g
s
.567 .772 .975 r
.24722 .34236 m .24111 .34322 L .24791 .34527 L p F P
0 g
s
.567 .772 .975 r
.24791 .34527 m .25057 .3448 L .24722 .34236 L p F P
0 g
s
.457 .032 .142 r
.51132 .47334 m .5026 .47474 L .5006 .4777 L p F P
0 g
s
.775 .399 .344 r
.22795 .44641 m .22965 .44943 L .22595 .44843 L closepath p F P
0 g
s
.658 .814 .959 r
.58336 .34006 m .57242 .34364 L .56962 .34141 L p F P
0 g
s
.222 .73 .892 r
.41003 .36039 m .40745 .35992 L .3993 .36041 L closepath p F P
0 g
s
.241 .738 .908 r
.40434 .35954 m .40745 .35992 L .3993 .36041 L p F P
0 g
s
.241 .738 .908 r
.40425 .35954 m .40434 .35954 L p .3993 .36041 L F P
0 g
s
.241 .738 .908 r
.39371 .35989 m .40425 .35954 L p .3993 .36041 L F P
0 g
s
.241 .738 .908 r
.3993 .36041 m .39605 .36039 L .39371 .35989 L p F P
0 g
s
.646 .192 .16 r
.32205 .47853 m .3247 .4802 L .32053 .47971 L closepath p F P
0 g
s
.252 .749 .905 r
.41243 .36034 m .41003 .36039 L .40745 .35992 L p F P
0 g
s
.218 .723 .899 r
.39605 .36039 m .39371 .35989 L .3871 .36018 L closepath p F P
0 g
s
.475 .02 .089 r
.47338 .48374 m .47573 .48098 L .463 .48225 L p F P
0 g
s
.475 .02 .089 r
.47126 .48395 m .47338 .48374 L p .463 .48225 L F P
0 g
s
.475 .02 .089 r
.463 .48225 m .4623 .48304 L .47126 .48395 L p F P
0 g
s
.716 .726 .858 r
.18387 .34511 m .19252 .34069 L p .17871 .34227 L F P
0 g
s
.716 .726 .858 r
.17871 .34227 m .18002 .34375 L .18387 .34511 L p F P
0 g
s
.659 .716 .89 r
.59989 .34226 m .61088 .33881 L .61366 .34248 L p F P
0 g
s
.663 .746 .911 r
.61088 .33881 m .59989 .34226 L .59711 .33915 L p F P
0 g
s
.804 .453 .392 r
.20718 .43924 m .20815 .43955 L .21072 .43653 L p F P
0 g
s
.804 .453 .392 r
.21072 .43653 m .20549 .43484 L .20718 .43924 L p F P
0 g
s
.241 .744 .895 r
.42367 .36004 m .4212 .35962 L .41243 .36034 L closepath p F P
0 g
s
.252 .749 .905 r
.41816 .35931 m .4212 .35962 L .41243 .36034 L p F P
0 g
s
.252 .749 .905 r
.41789 .35932 m .41816 .35931 L p .41243 .36034 L F P
0 g
s
.252 .749 .905 r
.40745 .35992 m .41789 .35932 L p .41243 .36034 L F P
0 g
s
.52 .745 .977 r
.24111 .34322 m .23694 .3438 L .23359 .34108 L p F P
0 g
s
.604 .126 .094 r
.34874 .48521 m .34924 .48484 L .34403 .48221 L p F P
0 g
s
.604 .126 .094 r
.34032 .48442 m .34874 .48521 L p .34403 .48221 L F P
0 g
s
.604 .126 .094 r
.33562 .48207 m .34032 .48442 L p .34403 .48221 L F P
0 g
s
.604 .126 .094 r
.34403 .48221 m .33642 .48152 L .33562 .48207 L p F P
0 g
s
.811 .683 .723 r
.15721 .36042 m .1537 .36539 L .15909 .36791 L p F P
0 g
s
.821 .671 .697 r
.15017 .37141 m .15566 .3739 L .15909 .36791 L p F P
0 g
s
.821 .671 .697 r
.15909 .36791 m .1537 .36539 L .15017 .37141 L p F P
0 g
s
.653 .818 .963 r
.5588 .34503 m .55869 .34494 L .56766 .34205 L closepath p F P
0 g
s
.713 .278 .216 r
.27629 .46691 m .2747 .46802 L .2728 .46619 L closepath p F P
0 g
s
.193 .696 .909 r
.3515 .35773 m .3526 .35806 L p .33893 .357 L F P
0 g
s
.193 .696 .909 r
.33893 .357 m .34499 .35707 L .3515 .35773 L p F P
0 g
s
.14 .659 .887 r
.34499 .35707 m .33893 .357 L .33568 .3558 L p F P
0 g
s
.242 .733 .919 r
.39055 .35942 m .39371 .35989 L .3871 .36018 L p F P
0 g
s
.242 .733 .919 r
.37999 .35955 m .39055 .35942 L p .3871 .36018 L F P
0 g
s
.242 .733 .919 r
.3871 .36018 m .38167 .35997 L .37999 .35955 L p F P
0 g
s
.525 .355 .593 r
.65392 .39157 m .65336 .38613 L .64323 .39062 L p F P
0 g
s
.525 .355 .593 r
.64323 .39062 m .64378 .39606 L .65392 .39157 L p F P
0 g
s
.493 .257 .485 r
.63363 .41497 m .63383 .41035 L .62584 .41347 L p F P
0 g
s
.493 .257 .485 r
.6232 .41903 m .63363 .41497 L p .62584 .41347 L F P
0 g
s
.493 .257 .485 r
.62584 .41347 m .62333 .41616 L .6232 .41903 L p F P
0 g
s
.537 .871 .992 r
.51461 .3492 m .51684 .34992 L .50521 .35252 L p F P
0 g
s
.537 .871 .992 r
.50521 .35252 m .50376 .35199 L .51461 .3492 L p F P
0 g
s
.641 .847 .979 r
.56766 .34205 m .55869 .34494 L .55587 .34313 L p F P
0 g
s
.486 .228 .448 r
.62277 .42342 m .6232 .41903 L .61771 .42104 L p F P
0 g
s
.486 .228 .448 r
.61219 .42727 m .62277 .42342 L p .61771 .42104 L F P
0 g
s
.504 .267 .487 r
.62333 .41616 m .61771 .42104 L .6232 .41903 L closepath p F P
0 g
s
.277 .766 .909 r
.42677 .35987 m .42367 .36004 L .4212 .35962 L p F P
0 g
s
.691 .256 .212 r
.29162 .47161 m .29317 .47292 L .29052 .47248 L closepath p F P
0 g
s
.671 .218 .167 r
.298 .47644 m .29317 .47292 L .30172 .47428 L p F P
0 g
s
.671 .218 .167 r
.30411 .47744 m .298 .47644 L p .30172 .47428 L F P
0 g
s
.671 .218 .167 r
.30172 .47428 m .30509 .47676 L .30411 .47744 L p F P
0 g
s
.229 .725 .914 r
.38167 .35997 m .37999 .35955 L .3757 .35969 L closepath p F P
0 g
s
.449 .047 .185 r
.53836 .46821 m .53897 .46706 L .52807 .46794 L p F P
0 g
s
.449 .047 .185 r
.52807 .46794 m .52661 .47059 L .53836 .46821 L p F P
0 g
s
.444 .069 .232 r
.5636 .45825 m .5645 .45615 L .55314 .45897 L p F P
0 g
s
.444 .069 .232 r
.55314 .45897 m .55266 .46006 L .5636 .45825 L p F P
0 g
s
.74 .323 .258 r
.25001 .46115 m .25736 .46292 L .25408 .45896 L p F P
0 g
s
.74 .323 .258 r
.25408 .45896 m .24668 .45721 L .25001 .46115 L p F P
0 g
s
.273 .764 .906 r
.43699 .35934 m .43496 .359 L .42677 .35987 L closepath p F P
0 g
s
.277 .766 .909 r
.43188 .35872 m .43496 .359 L .42677 .35987 L p F P
0 g
s
.277 .766 .909 r
.4212 .35962 m .43188 .35872 L p .42677 .35987 L F P
0 g
s
.764 .368 .302 r
.23242 .45352 m .23944 .45541 L .23671 .4513 L p F P
0 g
s
.764 .368 .302 r
.23671 .4513 m .22965 .44943 L .23242 .45352 L p F P
0 g
s
.657 .706 .884 r
.62468 .33923 m .61366 .34248 L .61088 .33881 L p F P
0 g
s
.651 .677 .862 r
.61366 .34248 m .62468 .33923 L .62745 .34357 L p F P
0 g
s
.542 .395 .63 r
.64726 .38267 m .65247 .38031 L .6531 .38435 L closepath p F P
0 g
s
.498 .286 .521 r
.64411 .40607 m .64407 .4012 L .6338 .40549 L p F P
0 g
s
.498 .286 .521 r
.6338 .40549 m .63383 .41035 L .64411 .40607 L p F P
0 g
s
.491 .062 .151 r
.47605 .48053 m .478 .48071 L .47573 .48098 L closepath p F P
0 g
s
.568 .1 .103 r
.37988 .48591 m .38322 .48713 L .3786 .487 L closepath p F P
0 g
s
.594 .528 .75 r
.64699 .35944 m .64792 .35933 L .64709 .35972 L closepath p F P
0 g
s
.587 .509 .734 r
.6594 .36246 m .64948 .36728 L .64709 .35972 L p F P
0 g
s
.587 .509 .734 r
.65815 .35837 m .6594 .36246 L p .64709 .35972 L F P
0 g
s
.587 .509 .734 r
.64709 .35972 m .64792 .35933 L .65815 .35837 L p F P
0 g
s
.603 .544 .761 r
.64792 .35933 m .64699 .35944 L .64413 .35209 L p F P
0 g
s
.257 .734 .936 r
.3768 .35895 m .37999 .35955 L .3757 .35969 L p F P
0 g
s
.257 .734 .936 r
.36628 .35892 m .3768 .35895 L p .3757 .35969 L F P
0 g
s
.257 .734 .936 r
.3757 .35969 m .36682 .35908 L .36628 .35892 L p F P
0 g
s
.618 .866 .99 r
.55587 .34313 m .54497 .34656 L .54213 .34505 L p F P
0 g
s
.609 .863 .991 r
.53124 .34832 m .54213 .34505 L .54497 .34656 L p F P
0 g
s
.565 .471 .706 r
.66116 .36922 m .6594 .36246 L .64948 .36728 L p F P
0 g
s
.565 .471 .706 r
.64948 .36728 m .64994 .36896 L .66116 .36922 L p F P
0 g
s
.81 .476 .422 r
.19271 .43061 m .19908 .43273 L .19777 .42823 L p F P
0 g
s
.81 .476 .422 r
.19777 .42823 m .19138 .42611 L .19271 .43061 L p F P
0 g
s
.344 .728 .985 r
.29474 .35127 m .29604 .35129 L .29369 .35071 L closepath p F P
0 g
s
.621 .148 .11 r
.33642 .48152 m .33562 .48207 L .33415 .48127 L closepath p F P
0 g
s
.566 .458 .691 r
.66118 .36932 m .66116 .36922 L .64994 .36896 L p F P
0 g
s
.566 .458 .691 r
.64994 .36896 m .6512 .37406 L .66118 .36932 L p F P
0 g
s
.713 .278 .215 r
.26895 .46835 m .26505 .46457 L .2728 .46619 L p F P
0 g
s
.713 .278 .215 r
.27301 .46921 m .26895 .46835 L p .2728 .46619 L F P
0 g
s
.713 .278 .215 r
.2728 .46619 m .2747 .46802 L .27301 .46921 L p F P
0 g
s
.838 .592 .567 r
.16062 .40029 m .16632 .40268 L .16695 .39759 L p F P
0 g
s
.838 .592 .567 r
.16695 .39759 m .16125 .39521 L .16062 .40029 L p F P
0 g
s
.837 .613 .6 r
.15559 .39279 m .16125 .39521 L .16243 .38995 L p F P
0 g
s
.837 .613 .6 r
.16243 .38995 m .1568 .38753 L .15559 .39279 L p F P
0 g
s
.786 .411 .345 r
.21606 .4455 m .22276 .4475 L .22056 .44325 L p F P
0 g
s
.786 .411 .345 r
.22056 .44325 m .21383 .44126 L .21606 .4455 L p F P
0 g
s
.444 .75 .993 r
.26084 .34398 m .25057 .3448 L .24722 .34236 L p F P
0 g
s
.785 .708 .779 r
.15549 .35766 m .15847 .35896 L .16565 .35172 L p F P
0 g
s
.785 .708 .779 r
.15394 .35533 m .15549 .35766 L p .16565 .35172 L F P
0 g
s
.785 .708 .779 r
.16565 .35172 m .16029 .34916 L .15394 .35533 L p F P
0 g
s
.773 .715 .798 r
.16565 .35172 m .16811 .34953 L .16477 .34534 L p F P
0 g
s
.773 .715 .798 r
.16477 .34534 m .16029 .34916 L .16565 .35172 L p F P
0 g
s
.312 .788 .92 r
.44283 .35886 m .43699 .35934 L .43496 .359 L p F P
0 g
s
.603 .544 .761 r
.65697 .35485 m .64792 .35933 L p .64413 .35209 L F P
0 g
s
.587 .516 .742 r
.64792 .35933 m .65697 .35485 L .65815 .35837 L closepath p F P
0 g
s
.621 .148 .108 r
.33057 .48344 m .3247 .4802 L .33415 .48127 L p F P
0 g
s
.621 .148 .108 r
.33317 .48373 m .33057 .48344 L p .33415 .48127 L F P
0 g
s
.621 .148 .108 r
.33415 .48127 m .33562 .48207 L .33317 .48373 L p F P
0 g
s
.831 .562 .532 r
.17096 .40956 m .17199 .40996 L .17209 .40504 L p F P
0 g
s
.831 .562 .532 r
.17209 .40504 m .17176 .40491 L .17096 .40956 L p F P
0 g
s
.752 .728 .83 r
.18002 .34375 m .17798 .34273 L .16811 .34953 L p F P
0 g
s
.746 .714 .821 r
.17798 .34273 m .16811 .34953 L .16477 .34534 L p F P
0 g
s
.162 .682 .885 r
.3526 .35806 m .3548 .35808 L .36505 .35896 L p F P
0 g
s
.202 .699 .916 r
.3526 .35806 m .3548 .35808 L .3515 .35773 L closepath p F P
0 g
s
.833 .634 .633 r
.15119 .38509 m .1568 .38753 L .15863 .38206 L p F P
0 g
s
.833 .634 .633 r
.15863 .38206 m .15306 .37961 L .15119 .38509 L p F P
0 g
s
.839 .571 .533 r
.16619 .40761 m .17096 .40956 L .17176 .40491 L p F P
0 g
s
.839 .571 .533 r
.17176 .40491 m .16632 .40268 L .16619 .40761 L p F P
0 g
s
.589 .875 .993 r
.54213 .34505 m .53124 .34832 L .52837 .34708 L p F P
0 g
s
.576 .872 .995 r
.5175 .35014 m .52837 .34708 L .53124 .34832 L p F P
0 g
s
.255 .733 .935 r
.36682 .35908 m .36628 .35892 L .36505 .35896 L closepath p F P
0 g
s
.458 .004 .083 r
.478 .48071 m .47573 .48098 L .47338 .48374 L p F P
0 g
s
.742 .731 .842 r
.17871 .34227 m .17798 .34273 L .18002 .34375 L closepath p F P
0 g
s
.453 .028 .14 r
.5147 .47278 m .51435 .4733 L .51132 .47334 L closepath p F P
0 g
s
.457 .032 .142 r
.51269 .47578 m .51435 .4733 L .51132 .47334 L p F P
0 g
s
.457 .032 .142 r
.50087 .4777 m .51269 .47578 L p .51132 .47334 L F P
0 g
s
.457 .032 .142 r
.5006 .4777 m .50087 .4777 L p .51132 .47334 L F P
0 g
s
.795 .688 .747 r
.15847 .35896 m .15549 .35766 L .15721 .36042 L closepath p F P
0 g
s
.211 .716 .903 r
.36308 .35817 m .3548 .35808 L .36505 .35896 L p F P
0 g
s
.211 .716 .903 r
.36505 .35896 m .36628 .35892 L .36308 .35817 L p F P
0 g
s
.333 .724 .983 r
.30176 .34991 m .30507 .35133 L .29604 .35129 L p F P
0 g
s
.333 .724 .983 r
.29143 .34951 m .30176 .34991 L p .29604 .35129 L F P
0 g
s
.333 .724 .983 r
.29604 .35129 m .29369 .35071 L .29143 .34951 L p F P
0 g
s
.312 .788 .92 r
.44568 .35779 m .44872 .35806 L .44283 .35886 L p F P
0 g
s
.312 .788 .92 r
.43496 .359 m .44568 .35779 L p .44283 .35886 L F P
0 g
s
.317 .79 .924 r
.45 .35829 m .44872 .35806 L .44283 .35886 L closepath p F P
0 g
s
.456 .155 .365 r
.61073 .43544 m .61155 .43145 L .60082 .43509 L p F P
0 g
s
.456 .155 .365 r
.60082 .43509 m .59998 .43908 L .61073 .43544 L p F P
0 g
s
.829 .538 .497 r
.17237 .41474 m .1784 .417 L .17803 .41222 L p F P
0 g
s
.829 .538 .497 r
.17803 .41222 m .17199 .40996 L .17237 .41474 L p F P
0 g
s
.475 .018 .087 r
.4623 .48304 m .47126 .48395 L .46059 .48498 L closepath p F P
0 g
s
.555 .09 .104 r
.39358 .48686 m .39525 .48741 L .393 .48739 L closepath p F P
0 g
s
.464 .138 .328 r
.58804 .44631 m .58818 .44584 L .57721 .44877 L p F P
0 g
s
.464 .138 .328 r
.57721 .44877 m .57699 .44954 L .58804 .44631 L p F P
0 g
s
.639 .649 .844 r
.62745 .34357 m .62746 .34357 L .62745 .34357 L closepath p F P
0 g
s
.63 .636 .837 r
.63851 .34069 m .62746 .34357 L .62745 .34357 L p F P
0 g
s
.63 .636 .837 r
.64131 .34598 m .63851 .34069 L p .62745 .34357 L F P
0 g
s
.646 .666 .855 r
.62746 .34357 m .62745 .34357 L .62468 .33923 L p F P
0 g
s
.646 .666 .855 r
.63735 .33872 m .62746 .34357 L p .62468 .33923 L F P
0 g
s
.639 .655 .85 r
.62746 .34357 m .63735 .33872 L .63851 .34069 L closepath p F P
0 g
s
.549 .424 .662 r
.66243 .37555 m .66118 .36932 L .6512 .37406 L p F P
0 g
s
.549 .424 .662 r
.6512 .37406 m .65247 .38031 L .66243 .37555 L p F P
0 g
s
.812 .69 .73 r
.1537 .36539 m .15721 .36042 L .15549 .35766 L p F P
0 g
s
.603 .544 .761 r
.64413 .35209 m .65526 .35027 L .65697 .35485 L p F P
0 g
s
.606 .575 .792 r
.64358 .35084 m .64413 .35209 L .65526 .35027 L p F P
0 g
s
.458 .007 .09 r
.48824 .47946 m .48683 .48117 L .478 .48071 L closepath p F P
0 g
s
.458 .004 .083 r
.48594 .48225 m .48683 .48117 L .478 .48071 L p F P
0 g
s
.458 .004 .083 r
.47338 .48374 m .48594 .48225 L p .478 .48071 L F P
0 g
s
.463 .184 .404 r
.62215 .4276 m .62277 .42342 L .61219 .42727 L p F P
0 g
s
.463 .184 .404 r
.61219 .42727 m .61155 .43145 L .62215 .4276 L p F P
0 g
s
.828 .654 .667 r
.14752 .37714 m .15306 .37961 L .15566 .3739 L p F P
0 g
s
.828 .654 .667 r
.15566 .3739 m .15017 .37141 L .14752 .37714 L p F P
0 g
s
.449 .125 .324 r
.59916 .44211 m .59998 .43908 L .58908 .44251 L p F P
0 g
s
.449 .125 .324 r
.58908 .44251 m .58818 .44584 L .59916 .44211 L p F P
0 g
s
.806 .452 .387 r
.20079 .43713 m .20718 .43924 L .20549 .43484 L p F P
0 g
s
.806 .452 .387 r
.20549 .43484 m .19908 .43273 L .20079 .43713 L p F P
0 g
s
.546 .881 .989 r
.52825 .34704 m .52837 .34708 L .5175 .35014 L p F P
0 g
s
.546 .881 .989 r
.5175 .35014 m .51684 .34992 L .52825 .34704 L p F P
0 g
s
.668 .206 .146 r
.28954 .47504 m .298 .47644 L .29317 .47292 L p F P
0 g
s
.668 .206 .146 r
.28812 .47398 m .28954 .47504 L p .29317 .47292 L F P
0 g
s
.668 .206 .146 r
.29317 .47292 m .29052 .47248 L .28812 .47398 L p F P
0 g
s
.443 .068 .231 r
.56303 .45957 m .5636 .45825 L .55266 .46006 L p F P
0 g
s
.443 .068 .231 r
.55266 .46006 m .55163 .46238 L .56303 .45957 L p F P
0 g
s
.52 .745 .977 r
.23359 .34108 m .23503 .34093 L .24111 .34322 L p F P
0 g
s
.539 .768 .982 r
.24386 .33998 m .23503 .34093 L .24111 .34322 L p F P
0 g
s
.539 .768 .982 r
.24111 .34322 m .24722 .34236 L .24386 .33998 L p F P
0 g
s
.617 .594 .805 r
.64131 .34598 m .64358 .35084 L .65345 .34593 L p F P
0 g
s
.606 .575 .792 r
.65526 .35027 m .65345 .34593 L .64358 .35084 L p F P
0 g
s
.436 .01 .13 r
.52524 .47272 m .52661 .47059 L .5147 .47278 L p F P
0 g
s
.436 .01 .13 r
.5147 .47278 m .51435 .4733 L .52524 .47272 L p F P
0 g
s
.03 .598 .773 r
.3768 .35895 m .36628 .35892 L .36308 .35817 L p F P
0 g
s
.148 .657 .9 r
.31828 .35309 m .30837 .35284 L .30507 .35133 L p F P
0 g
s
.386 .752 .992 r
.29369 .35071 m .29143 .34951 L .28817 .34962 L closepath p F P
0 g
s
.67 .752 .912 r
.19252 .34069 m .20289 .33695 L .20626 .34011 L p F P
0 g
s
.657 .753 .921 r
.20289 .33695 m .19252 .34069 L .18915 .33728 L p F P
0 g
s
.716 .726 .858 r
.19252 .34069 m .18915 .33728 L .17871 .34227 L p F P
0 g
s
.357 .813 .936 r
.46149 .35701 m .45 .35829 L .44872 .35806 L p F P
0 g
s
.493 .035 .093 r
.44854 .48494 m .45293 .48558 L .44758 .48599 L closepath p F P
0 g
s
.541 .078 .104 r
.4073 .48725 m .40801 .48745 L .40707 .48746 L closepath p F P
0 g
s
.406 .75 .994 r
.27513 .3462 m .2778 .34776 L p .26418 .34617 L F P
0 g
s
.406 .75 .994 r
.26418 .34617 m .27361 .34586 L .27513 .3462 L p F P
0 g
s
.355 .73 .987 r
.27361 .34586 m .26418 .34617 L .26084 .34398 L p F P
0 g
s
.826 .515 .462 r
.17921 .42165 m .18527 .42389 L .18447 .41924 L p F P
0 g
s
.826 .515 .462 r
.18447 .41924 m .1784 .417 L .17921 .42165 L p F P
0 g
s
.434 .036 .183 r
.54995 .46562 m .55163 .46238 L .54008 .46499 L p F P
0 g
s
.434 .036 .183 r
.54929 .46577 m .54995 .46562 L p .54008 .46499 L F P
0 g
s
.434 .036 .183 r
.54008 .46499 m .53897 .46706 L .54929 .46577 L p F P
0 g
s
.626 .757 .941 r
.20626 .34011 m .21657 .33739 L .21994 .3403 L p F P
0 g
s
.61 .757 .949 r
.21657 .33739 m .20626 .34011 L .20289 .33695 L p F P
0 g
s
.618 .137 .09 r
.32123 .48232 m .33057 .48344 L .3247 .4802 L p F P
0 g
s
.618 .137 .09 r
.31863 .48088 m .32123 .48232 L p .3247 .4802 L F P
0 g
s
.618 .137 .09 r
.3247 .4802 m .32053 .47971 L .31863 .48088 L p F P
0 g
s
.608 .132 .097 r
.33562 .48207 m .34032 .48442 L .33317 .48373 L closepath p F P
0 g
s
.19 .693 .909 r
.36042 .35768 m .36308 .35817 L .3548 .35808 L p F P
0 g
s
.19 .693 .909 r
.3586 .35753 m .36042 .35768 L p .3548 .35808 L F P
0 g
s
.19 .693 .909 r
.34937 .35711 m .3586 .35753 L p .3548 .35808 L F P
0 g
s
.19 .693 .909 r
.3548 .35808 m .3515 .35773 L .34937 .35711 L p F P
0 g
s
.684 .228 .163 r
.29052 .47248 m .28812 .47398 L .28492 .47146 L closepath p F P
0 g
s
.739 .316 .244 r
.24268 .45937 m .25001 .46115 L .24668 .45721 L p F P
0 g
s
.739 .316 .244 r
.24096 .45732 m .24268 .45937 L p .24668 .45721 L F P
0 g
s
.739 .316 .244 r
.24668 .45721 m .24257 .45622 L .24096 .45732 L p F P
0 g
s
.47 .214 .443 r
.63322 .41936 m .63363 .41497 L .6232 .41903 L p F P
0 g
s
.47 .214 .443 r
.6232 .41903 m .62277 .42342 L .63322 .41936 L p F P
0 g
s
.436 .086 .272 r
.58679 .44991 m .58804 .44631 L .57699 .44954 L p F P
0 g
s
.436 .086 .272 r
.57699 .44954 m .57572 .45313 L .58679 .44991 L p F P
0 g
s
.736 .734 .849 r
.17798 .34273 m .17871 .34227 L .17534 .33858 L p F P
0 g
s
.736 .734 .849 r
.17534 .33858 m .17281 .34011 L .17798 .34273 L p F P
0 g
s
.746 .714 .821 r
.16477 .34534 m .17281 .34011 L .17798 .34273 L p F P
0 g
s
.473 .868 .968 r
.51461 .3492 m .50376 .35199 L .50083 .35125 L p F P
0 g
s
.469 .861 .973 r
.49001 .35378 m .50083 .35125 L .50376 .35199 L p F P
0 g
s
.51 .051 .098 r
.43478 .48628 m .43657 .48663 L .43434 .48675 L closepath p F P
0 g
s
.526 .065 .102 r
.42103 .48706 m .42171 .48722 L .42085 .48725 L closepath p F P
0 g
s
.506 .316 .557 r
.65422 .39671 m .65392 .39157 L .64378 .39606 L p F P
0 g
s
.506 .316 .557 r
.64378 .39606 m .64407 .4012 L .65422 .39671 L p F P
0 g
s
.764 .362 .291 r
.22544 .45162 m .23242 .45352 L .22965 .44943 L p F P
0 g
s
.764 .362 .291 r
.22419 .44977 m .22544 .45162 L p .22965 .44943 L F P
0 g
s
.764 .362 .291 r
.22965 .44943 m .22595 .44843 L .22419 .44977 L p F P
0 g
s
.699 .748 .889 r
.18915 .33728 m .17871 .34227 L .17534 .33858 L p F P
0 g
s
.507 .018 .031 r
.40801 .48745 m .40707 .48746 L .40412 .48981 L p F P
0 g
s
.526 .04 .046 r
.40405 .48981 m .40412 .48981 L .40707 .48746 L p F P
0 g
s
.526 .04 .046 r
.40707 .48746 m .39525 .48741 L .40405 .48981 L p F P
0 g
s
.51 .026 .043 r
.42085 .48725 m .40801 .48745 L .41753 .48965 L p F P
0 g
s
.507 .018 .031 r
.40412 .48981 m .41753 .48965 L .40801 .48745 L p F P
0 g
s
.709 .264 .191 r
.26129 .46669 m .26895 .46835 L .26505 .46457 L p F P
0 g
s
.709 .264 .191 r
.2578 .46337 m .26129 .46669 L p .26505 .46457 L F P
0 g
s
.709 .264 .191 r
.26505 .46457 m .25822 .46311 L .2578 .46337 L p F P
0 g
s
.812 .69 .73 r
.14833 .36284 m .1537 .36539 L p .15549 .35766 L F P
0 g
s
.821 .674 .7 r
.14471 .3689 m .15017 .37141 L .1537 .36539 L p F P
0 g
s
.821 .674 .7 r
.1537 .36539 m .14833 .36284 L .14471 .3689 L p F P
0 g
s
.521 .03 .031 r
.39149 .48969 m .40405 .48981 L .39525 .48741 L p F P
0 g
s
.521 .03 .031 r
.39035 .48937 m .39149 .48969 L p .39525 .48741 L F P
0 g
s
.521 .03 .031 r
.39525 .48741 m .393 .48739 L .39035 .48937 L p F P
0 g
s
.199 .699 .913 r
.3515 .35773 m .34937 .35711 L .34499 .35707 L closepath p F P
0 g
s
.541 .053 .047 r
.393 .48739 m .39035 .48937 L .38322 .48713 L closepath p F P
0 g
s
.574 .762 .967 r
.23159 .3395 m .23359 .34108 L p .21994 .3403 L F P
0 g
s
.574 .762 .967 r
.21994 .3403 m .22868 .33872 L .23159 .3395 L p F P
0 g
s
.551 .755 .972 r
.22868 .33872 m .21994 .3403 L .21657 .33739 L p F P
0 g
s
.817 .506 .464 r
.19131 .42576 m .19138 .42611 L .19117 .42604 L closepath p F P
0 g
s
.636 .161 .107 r
.32053 .47971 m .31863 .48088 L .31553 .47904 L closepath p F P
0 g
s
.803 .698 .749 r
.15394 .35533 m .15301 .35644 L .15549 .35766 L closepath p F P
0 g
s
.812 .69 .73 r
.15549 .35766 m .15301 .35644 L .14833 .36284 L p F P
0 g
s
.016 .589 .746 r
.39055 .35942 m .37999 .35955 L .3768 .35895 L p F P
0 g
s
.491 .004 .028 r
.42171 .48722 m .42085 .48725 L .41798 .48964 L p F P
0 g
s
.51 .026 .043 r
.41753 .48965 m .41798 .48964 L .42085 .48725 L p F P
0 g
s
.436 .009 .128 r
.52465 .47362 m .52524 .47272 L .51435 .4733 L p F P
0 g
s
.436 .009 .128 r
.51435 .4733 m .51269 .47578 L .52465 .47362 L p F P
0 g
s
.538 .879 .988 r
.52549 .34621 m .52825 .34704 L .51684 .34992 L p F P
0 g
s
.538 .879 .988 r
.51684 .34992 m .51461 .3492 L .52549 .34621 L p F P
0 g
s
.494 .012 .041 r
.43434 .48675 m .43166 .48911 L .42171 .48722 L closepath p F P
0 g
s
.491 .004 .028 r
.43156 .4892 m .43166 .48911 L .42171 .48722 L p F P
0 g
s
.491 .004 .028 r
.41798 .48964 m .43156 .4892 L p .42171 .48722 L F P
0 g
s
.703 .264 .205 r
.2747 .46802 m .27683 .46994 L .27301 .46921 L closepath p F P
0 g
s
.813 .477 .42 r
.18881 .42928 m .19271 .43061 L .19138 .42611 L p F P
0 g
s
.813 .477 .42 r
.19138 .42611 m .19117 .42604 L .18881 .42928 L p F P
0 g
s
.535 .041 .03 r
.38995 .48967 m .39035 .48937 L .38322 .48713 L p F P
0 g
s
.535 .041 .03 r
.37963 .48936 m .38995 .48967 L p .38322 .48713 L F P
0 g
s
.535 .041 .03 r
.37662 .48839 m .37963 .48936 L p .38322 .48713 L F P
0 g
s
.535 .041 .03 r
.38322 .48713 m .3786 .487 L .37662 .48839 L p F P
0 g
s
.436 .853 .957 r
.49934 .35103 m .50083 .35125 L .49001 .35378 L p F P
0 g
s
.436 .853 .957 r
.49001 .35378 m .48733 .35325 L .49934 .35103 L p F P
0 g
s
.422 .844 .959 r
.48733 .35325 m .49001 .35378 L p .47625 .35541 L F P
0 g
s
.527 .384 .63 r
.66333 .38137 m .66243 .37555 L .65247 .38031 L p F P
0 g
s
.527 .384 .63 r
.65518 .38527 m .66333 .38137 L p .65247 .38031 L F P
0 g
s
.527 .384 .63 r
.65247 .38031 m .6531 .38435 L .65518 .38527 L p F P
0 g
s
.442 0 .08 r
.49831 .48054 m .50057 .47775 L .48824 .47946 L p F P
0 g
s
.442 0 .08 r
.49303 .48128 m .49831 .48054 L p .48824 .47946 L F P
0 g
s
.442 0 .08 r
.48824 .47946 m .48683 .48117 L .49303 .48128 L p F P
0 g
s
.823 .49 .427 r
.18647 .42843 m .18881 .42928 L .19117 .42604 L p F P
0 g
s
.823 .49 .427 r
.19117 .42604 m .18527 .42389 L .18647 .42843 L p F P
0 g
s
.786 .404 .333 r
.2094 .44349 m .21606 .4455 L .21383 .44126 L p F P
0 g
s
.786 .404 .333 r
.20758 .44004 m .2094 .44349 L p .21383 .44126 L F P
0 g
s
.786 .404 .333 r
.21383 .44126 m .20815 .43955 L .20758 .44004 L p F P
0 g
s
.641 .845 .978 r
.56962 .34141 m .56766 .34205 L .5696 .3414 L closepath p F P
0 g
s
.641 .847 .979 r
.56681 .33957 m .5696 .3414 L .56766 .34205 L p F P
0 g
s
.641 .847 .979 r
.55587 .34313 m .56681 .33957 L p .56766 .34205 L F P
0 g
s
.554 .064 .046 r
.3786 .487 m .37662 .48839 L .37178 .48668 L closepath p F P
0 g
s
.373 .753 .989 r
.28811 .34786 m .2807 .3478 L .28817 .34962 L p F P
0 g
s
.373 .753 .989 r
.28817 .34962 m .29143 .34951 L .28811 .34786 L p F P
0 g
s
.336 .726 .983 r
.2778 .34776 m .2807 .3478 L .28817 .34962 L p F P
0 g
s
.617 .594 .805 r
.65345 .34593 m .65242 .34364 L .64131 .34598 L p F P
0 g
s
.629 .614 .817 r
.65242 .34364 m .64131 .34598 L .63851 .34069 L p F P
0 g
s
.156 .669 .896 r
.33556 .35577 m .33568 .3558 L p .32201 .35438 L F P
0 g
s
.156 .669 .896 r
.32201 .35438 m .32669 .35458 L .33556 .35577 L p F P
0 g
s
.22 .693 .94 r
.32201 .35438 m .32669 .35458 L .319 .3532 L closepath p F P
0 g
s
.663 .746 .911 r
.59711 .33915 m .60811 .33558 L .61088 .33881 L p F P
0 g
s
.666 .775 .931 r
.60811 .33558 m .59711 .33915 L .59434 .33643 L p F P
0 g
s
.664 .782 .937 r
.58336 .34006 m .59434 .33643 L .59711 .33915 L p F P
0 g
s
.14 .659 .887 r
.33568 .3558 m .33588 .35581 L .34499 .35707 L p F P
0 g
s
.167 .685 .888 r
.34612 .35632 m .33588 .35581 L .34499 .35707 L p F P
0 g
s
.167 .685 .888 r
.34499 .35707 m .34937 .35711 L .34612 .35632 L p F P
0 g
s
.84 .594 .567 r
.15495 .39789 m .16062 .40029 L .16125 .39521 L p F P
0 g
s
.84 .594 .567 r
.16125 .39521 m .15559 .39279 L .15495 .39789 L p F P
0 g
s
.475 0 .026 r
.43657 .48663 m .43434 .48675 L .43166 .48911 L p F P
0 g
s
.752 .335 .258 r
.24257 .45622 m .24096 .45732 L .23944 .45541 L closepath p F P
0 g
s
.02 .594 .734 r
.40425 .35954 m .39371 .35989 L .39055 .35942 L p F P
0 g
s
.369 .816 .946 r
.46267 .35688 m .46249 .35684 L .46149 .35701 L closepath p F P
0 g
s
.357 .813 .936 r
.45947 .35654 m .46249 .35684 L .46149 .35701 L p F P
0 g
s
.357 .813 .936 r
.44872 .35806 m .45947 .35654 L p .46149 .35701 L F P
0 g
s
.838 .615 .601 r
.14997 .39036 m .15559 .39279 L .1568 .38753 L p F P
0 g
s
.838 .615 .601 r
.1568 .38753 m .15119 .38509 L .14997 .39036 L p F P
0 g
s
.662 .81 .954 r
.59434 .33643 m .58336 .34006 L .58057 .33778 L p F P
0 g
s
.658 .814 .959 r
.56962 .34141 m .58057 .33778 L .58336 .34006 L p F P
0 g
s
.685 .228 .162 r
.2814 .47354 m .27683 .46994 L .28492 .47146 L p F P
0 g
s
.685 .228 .162 r
.28708 .47462 m .2814 .47354 L p .28492 .47146 L F P
0 g
s
.685 .228 .162 r
.28492 .47146 m .28812 .47398 L .28708 .47462 L p F P
0 g
s
.362 .724 .988 r
.2778 .34776 m .2807 .3478 L .27513 .3462 L closepath p F P
0 g
s
.547 .05 .027 r
.37544 .48921 m .37662 .48839 L .37178 .48668 L p F P
0 g
s
.547 .05 .027 r
.36834 .48885 m .37544 .48921 L p .37178 .48668 L F P
0 g
s
.547 .05 .027 r
.36291 .4869 m .36834 .48885 L p .37178 .48668 L F P
0 g
s
.547 .05 .027 r
.37178 .48668 m .36386 .48628 L .36291 .4869 L p F P
0 g
s
.422 .844 .959 r
.47625 .35541 m .48494 .35362 L .48733 .35325 L p F P
0 g
s
.383 .832 .932 r
.47625 .35541 m .48494 .35362 L .47517 .35525 L closepath p F P
0 g
s
.427 .055 .228 r
.57458 .45584 m .57572 .45313 L .5645 .45615 L p F P
0 g
s
.427 .055 .228 r
.5645 .45615 m .5636 .45825 L .57458 .45584 L p F P
0 g
s
.66 .203 .156 r
.30509 .47676 m .3066 .47779 L .30411 .47744 L closepath p F P
0 g
s
.636 .16 .106 r
.31216 .48111 m .3066 .47779 L .31553 .47904 L p F P
0 g
s
.636 .16 .106 r
.31711 .48181 m .31216 .48111 L p .31553 .47904 L F P
0 g
s
.636 .16 .106 r
.31553 .47904 m .31863 .48088 L .31711 .48181 L p F P
0 g
s
.478 .245 .482 r
.64393 .41069 m .64411 .40607 L .63383 .41035 L p F P
0 g
s
.478 .245 .482 r
.63383 .41035 m .63363 .41497 L .64393 .41069 L p F P
0 g
s
.476 0 .036 r
.44758 .48599 m .44546 .48794 L .43657 .48663 L closepath p F P
0 g
s
.475 0 .026 r
.44487 .48847 m .44546 .48794 L .43657 .48663 L p F P
0 g
s
.475 0 .026 r
.43206 .48917 m .44487 .48847 L p .43657 .48663 L F P
0 g
s
.475 0 .026 r
.43166 .48911 m .43206 .48917 L p .43657 .48663 L F P
0 g
s
.841 .572 .533 r
.16048 .40523 m .16619 .40761 L .16632 .40268 L p F P
0 g
s
.841 .572 .533 r
.16632 .40268 m .16062 .40029 L .16048 .40523 L p F P
0 g
s
.38 .822 .949 r
.47326 .35499 m .47517 .35525 L .46267 .35688 L p F P
0 g
s
.38 .822 .949 r
.46267 .35688 m .46249 .35684 L .47326 .35499 L p F P
0 g
s
.524 .741 .974 r
.23359 .34108 m .23503 .34093 L .23159 .3395 L closepath p F P
0 g
s
.776 .38 .304 r
.22595 .44843 m .22419 .44977 L .22276 .4475 L closepath p F P
0 g
s
.657 .706 .884 r
.61088 .33881 m .62191 .3354 L .62468 .33923 L p F P
0 g
s
.663 .736 .905 r
.62191 .3354 m .61088 .33881 L .60811 .33558 L p F P
0 g
s
.769 .717 .804 r
.16029 .34916 m .16477 .34534 L .16141 .34129 L p F P
0 g
s
.769 .717 .804 r
.16141 .34129 m .15491 .3466 L .16029 .34916 L p F P
0 g
s
.781 .7 .774 r
.15063 .35058 m .15491 .3466 L .16029 .34916 L p F P
0 g
s
.781 .7 .774 r
.16029 .34916 m .15394 .35533 L .15063 .35058 L p F P
0 g
s
.834 .636 .635 r
.14562 .38263 m .15119 .38509 L .15306 .37961 L p F P
0 g
s
.834 .636 .635 r
.15306 .37961 m .14752 .37714 L .14562 .38263 L p F P
0 g
s
.646 .846 .977 r
.58029 .33759 m .58057 .33778 L .56962 .34141 L p F P
0 g
s
.646 .846 .977 r
.56962 .34141 m .5696 .3414 L .58029 .33759 L p F P
0 g
s
.648 .848 .977 r
.57778 .33589 m .58029 .33759 L .5696 .3414 L p F P
0 g
s
.648 .848 .977 r
.5696 .3414 m .56681 .33957 L .57778 .33589 L p F P
0 g
s
.741 .719 .831 r
.17281 .34011 m .16477 .34534 L .16141 .34129 L p F P
0 g
s
.256 .764 .858 r
.47326 .35499 m .46249 .35684 L .45947 .35654 L p F P
0 g
s
.801 .702 .756 r
.15301 .35644 m .15394 .35533 L .15063 .35058 L p F P
0 g
s
.172 .702 .85 r
.40745 .35992 m .41789 .35932 L .40434 .35954 L closepath p F P
0 g
s
.567 .074 .044 r
.36386 .48628 m .36291 .4869 L .36081 .48608 L closepath p F P
0 g
s
.831 .54 .496 r
.1695 .41364 m .17237 .41474 L .17199 .40996 L p F P
0 g
s
.831 .54 .496 r
.17199 .40996 m .17096 .40956 L .1695 .41364 L p F P
0 g
s
.801 .702 .756 r
.15063 .35058 m .1478 .35383 L .15301 .35644 L p F P
0 g
s
.812 .693 .734 r
.14298 .36028 m .14833 .36284 L .15301 .35644 L p F P
0 g
s
.812 .693 .734 r
.15301 .35644 m .1478 .35383 L .14298 .36028 L p F P
0 g
s
.807 .45 .382 r
.19444 .43499 m .20079 .43713 L .19908 .43273 L p F P
0 g
s
.807 .45 .382 r
.19908 .43273 m .19271 .43061 L .19444 .43499 L p F P
0 g
s
.193 .723 .823 r
.45947 .35654 m .44872 .35806 L .44568 .35779 L p F P
0 g
s
.191 .717 .851 r
.43163 .35872 m .43188 .35872 L .4212 .35962 L p F P
0 g
s
.191 .717 .851 r
.4212 .35962 m .41816 .35931 L .43163 .35872 L p F P
0 g
s
.567 .073 .043 r
.35751 .48819 m .35031 .48533 L .36081 .48608 L p F P
0 g
s
.567 .073 .043 r
.36057 .48842 m .35751 .48819 L p .36081 .48608 L F P
0 g
s
.567 .073 .043 r
.36081 .48608 m .36291 .4869 L .36057 .48842 L p F P
0 g
s
.598 .125 .102 r
.34924 .48484 m .35031 .48533 L .34874 .48521 L closepath p F P
0 g
s
.128 .677 .782 r
.44568 .35779 m .43496 .359 L .43188 .35872 L p F P
0 g
s
.724 .285 .208 r
.25822 .46311 m .2578 .46337 L .25736 .46292 L closepath p F P
0 g
s
.457 0 .022 r
.45293 .48558 m .44758 .48599 L .44546 .48794 L p F P
0 g
s
.646 .666 .855 r
.62468 .33923 m .63574 .33609 L .63735 .33872 L p F P
0 g
s
.654 .695 .876 r
.63574 .33609 m .62468 .33923 L .62191 .3354 L p F P
0 g
s
.518 .74 .975 r
.24048 .33765 m .24386 .33998 L .23503 .34093 L p F P
0 g
s
.518 .74 .975 r
.23023 .33843 m .24048 .33765 L p .23503 .34093 L F P
0 g
s
.518 .74 .975 r
.23503 .34093 m .23159 .3395 L .23023 .33843 L p F P
0 g
s
.531 .38 .622 r
.6531 .38435 m .65518 .38527 L .65336 .38613 L closepath p F P
0 g
s
.627 .868 .987 r
.56681 .33957 m .55587 .34313 L .55305 .34163 L p F P
0 g
s
.618 .866 .99 r
.54213 .34505 m .55305 .34163 L .55587 .34313 L p F P
0 g
s
.753 .335 .257 r
.23555 .45752 m .23242 .45352 L .23944 .45541 L p F P
0 g
s
.753 .335 .257 r
.2392 .4585 m .23555 .45752 L p .23944 .45541 L F P
0 g
s
.753 .335 .257 r
.23944 .45541 m .24096 .45732 L .2392 .4585 L p F P
0 g
s
.828 .656 .67 r
.14279 .375 m .14752 .37714 L .15017 .37141 L p F P
0 g
s
.828 .656 .67 r
.14236 .37387 m .14279 .375 L p .15017 .37141 L F P
0 g
s
.828 .656 .67 r
.15017 .37141 m .14471 .3689 L .14236 .37387 L p F P
0 g
s
.839 .55 .498 r
.1665 .41242 m .1695 .41364 L .17096 .40956 L p F P
0 g
s
.839 .55 .498 r
.17096 .40956 m .16619 .40761 L .1665 .41242 L p F P
0 g
s
.421 0 .127 r
.53644 .47125 m .53836 .46821 L .52661 .47059 L p F P
0 g
s
.421 0 .127 r
.5326 .47203 m .53644 .47125 L p .52661 .47059 L F P
0 g
s
.421 0 .127 r
.52661 .47059 m .52524 .47272 L .5326 .47203 L p F P
0 g
s
.724 .285 .206 r
.25369 .465 m .25001 .46115 L .25736 .46292 L p F P
0 g
s
.724 .285 .206 r
.2547 .46524 m .25369 .465 L p .25736 .46292 L F P
0 g
s
.724 .285 .206 r
.25736 .46292 m .2578 .46337 L .2547 .46524 L p F P
0 g
s
.155 .666 .899 r
.33568 .3558 m .33588 .35581 L .33556 .35577 L closepath p F P
0 g
s
.828 .515 .459 r
.1732 .41939 m .17921 .42165 L .1784 .417 L p F P
0 g
s
.828 .515 .459 r
.1784 .417 m .17237 .41474 L .1732 .41939 L p F P
0 g
s
.777 .38 .303 r
.21866 .44965 m .21606 .4455 L .22276 .4475 L p F P
0 g
s
.777 .38 .303 r
.22274 .45087 m .21866 .44965 L p .22276 .4475 L F P
0 g
s
.777 .38 .303 r
.22276 .4475 m .22419 .44977 L .22274 .45087 L p F P
0 g
s
.141 .658 .891 r
.34477 .35605 m .34612 .35632 L .33588 .35581 L p F P
0 g
s
.141 .658 .891 r
.33917 .35539 m .34477 .35605 L p .33588 .35581 L F P
0 g
s
.141 .658 .891 r
.33241 .35481 m .33917 .35539 L p .33588 .35581 L F P
0 g
s
.141 .658 .891 r
.33588 .35581 m .33556 .35577 L .33241 .35481 L p F P
0 g
s
.458 0 .03 r
.46059 .48498 m .45925 .48625 L .45293 .48558 L closepath p F P
0 g
s
.457 0 .022 r
.45794 .48749 m .45925 .48625 L .45293 .48558 L p F P
0 g
s
.457 0 .022 r
.44808 .48824 m .45794 .48749 L p .45293 .48558 L F P
0 g
s
.457 0 .022 r
.44546 .48794 m .44808 .48824 L p .45293 .48558 L F P
0 g
s
.166 .674 .902 r
.33556 .35577 m .33241 .35481 L .32669 .35458 L closepath p F P
0 g
s
.444 .75 .993 r
.24722 .34236 m .25749 .34185 L .26084 .34398 L p F P
0 g
s
.399 .739 .992 r
.25749 .34185 m .24722 .34236 L .24386 .33998 L p F P
0 g
s
.458 .031 .141 r
.5006 .4777 m .50087 .4777 L .50057 .47775 L closepath p F P
0 g
s
.631 .147 .083 r
.30333 .47983 m .31216 .48111 L .3066 .47779 L p F P
0 g
s
.631 .147 .083 r
.30163 .4788 m .30333 .47983 L p .3066 .47779 L F P
0 g
s
.631 .147 .083 r
.3066 .47779 m .30411 .47744 L .30163 .4788 L p F P
0 g
s
.156 .655 .911 r
.30176 .34991 m .29143 .34951 L .28811 .34786 L p F P
0 g
s
.514 .346 .591 r
.65912 .38912 m .65392 .39157 L .65336 .38613 L p F P
0 g
s
.514 .346 .591 r
.65336 .38613 m .65518 .38527 L .65912 .38912 L p F P
0 g
s
.42 0 .067 r
.50087 .4777 m .50057 .47775 L .49831 .48054 L p F P
0 g
s
.714 .271 .196 r
.2578 .46337 m .26129 .46669 L .2547 .46524 L closepath p F P
0 g
s
.796 .42 .343 r
.20815 .43955 m .20758 .44004 L .20718 .43924 L closepath p F P
0 g
s
.595 .882 .992 r
.55057 .34058 m .55305 .34163 L .54213 .34505 L p F P
0 g
s
.595 .882 .992 r
.54213 .34505 m .53951 .34395 L .55057 .34058 L p F P
0 g
s
.589 .875 .993 r
.53951 .34395 m .54213 .34505 L p .52837 .34708 L F P
0 g
s
.422 0 .075 r
.51269 .47578 m .51147 .47735 L .50087 .4777 L closepath p F P
0 g
s
.42 0 .067 r
.51049 .4786 m .51147 .47735 L .50087 .4777 L p F P
0 g
s
.42 0 .067 r
.49831 .48054 m .51049 .4786 L p .50087 .4777 L F P
0 g
s
.564 .064 .025 r
.34713 .4874 m .35751 .48819 L .35031 .48533 L p F P
0 g
s
.564 .064 .025 r
.3459 .4869 m .34713 .4874 L p .35031 .48533 L F P
0 g
s
.564 .064 .025 r
.35031 .48533 m .34874 .48521 L .3459 .4869 L p F P
0 g
s
.415 .019 .177 r
.56136 .46281 m .56303 .45957 L .55163 .46238 L p F P
0 g
s
.415 .019 .177 r
.55163 .46238 m .54995 .46562 L .56136 .46281 L p F P
0 g
s
.35 .721 .986 r
.28477 .34628 m .28811 .34786 L .2807 .3478 L p F P
0 g
s
.35 .721 .986 r
.27447 .34582 m .28477 .34628 L p .2807 .3478 L F P
0 g
s
.35 .721 .986 r
.2807 .3478 m .27513 .3462 L .27447 .34582 L p F P
0 g
s
.679 .212 .137 r
.2734 .47198 m .2814 .47354 L .27683 .46994 L p F P
0 g
s
.679 .212 .137 r
.27115 .4702 m .2734 .47198 L p .27683 .46994 L F P
0 g
s
.679 .212 .137 r
.27683 .46994 m .27301 .46921 L .27115 .4702 L p F P
0 g
s
.584 .089 .044 r
.34874 .48521 m .3459 .4869 L .34032 .48442 L closepath p F P
0 g
s
.487 .277 .52 r
.65427 .40158 m .65422 .39671 L .64407 .4012 L p F P
0 g
s
.487 .277 .52 r
.64407 .4012 m .64411 .40607 L .65427 .40158 L p F P
0 g
s
.73 .735 .855 r
.17281 .34011 m .17534 .33858 L .17196 .33498 L p F P
0 g
s
.73 .735 .855 r
.17196 .33498 m .16757 .33749 L .17281 .34011 L p F P
0 g
s
.741 .719 .831 r
.16141 .34129 m .16757 .33749 L .17281 .34011 L p F P
0 g
s
.379 .831 .929 r
.48494 .35362 m .47517 .35525 L .47326 .35499 L p F P
0 g
s
.65 .172 .103 r
.30411 .47744 m .30163 .4788 L .298 .47644 L closepath p F P
0 g
s
.797 .42 .343 r
.20287 .44142 m .20079 .43713 L .20718 .43924 L p F P
0 g
s
.797 .42 .343 r
.20508 .44215 m .20287 .44142 L p .20718 .43924 L F P
0 g
s
.797 .42 .343 r
.20718 .43924 m .20758 .44004 L .20508 .44215 L p F P
0 g
s
.433 .034 .181 r
.53897 .46706 m .54929 .46577 L .53836 .46821 L closepath p F P
0 g
s
.657 .753 .921 r
.18915 .33728 m .1995 .33386 L .20289 .33695 L p F P
0 g
s
.644 .754 .929 r
.1995 .33386 m .18915 .33728 L .18577 .33394 L p F P
0 g
s
.699 .748 .889 r
.17534 .33858 m .18577 .33394 L .18915 .33728 L p F P
0 g
s
.821 .676 .703 r
.13927 .36637 m .14471 .3689 L .14833 .36284 L p F P
0 g
s
.821 .676 .703 r
.14833 .36284 m .14298 .36028 L .13927 .36637 L p F P
0 g
s
.825 .491 .423 r
.18043 .42619 m .18647 .42843 L .18527 .42389 L p F P
0 g
s
.825 .491 .423 r
.18527 .42389 m .17921 .42165 L .18043 .42619 L p F P
0 g
s
.448 .124 .323 r
.59895 .44288 m .59916 .44211 L .58818 .44584 L p F P
0 g
s
.448 .124 .323 r
.58818 .44584 m .58804 .44631 L .59895 .44288 L p F P
0 g
s
.439 0 .016 r
.47126 .48395 m .46059 .48498 L .45925 .48625 L p F P
0 g
s
.44 .142 .36 r
.62135 .4316 m .62215 .4276 L .61155 .43145 L p F P
0 g
s
.44 .142 .36 r
.61155 .43145 m .61073 .43544 L .62135 .4316 L p F P
0 g
s
.431 .109 .318 r
.61016 .43759 m .61073 .43544 L .59998 .43908 L p F P
0 g
s
.431 .109 .318 r
.59998 .43908 m .59916 .44211 L .61016 .43759 L p F P
0 g
s
.629 .614 .817 r
.63851 .34069 m .64962 .33802 L .65242 .34364 L p F P
0 g
s
.632 .652 .852 r
.63735 .33872 m .63851 .34069 L .64962 .33802 L p F P
0 g
s
.61 .757 .949 r
.20289 .33695 m .21319 .33455 L .21657 .33739 L p F P
0 g
s
.593 .756 .956 r
.21319 .33455 m .20289 .33695 L .1995 .33386 L p F P
0 g
s
.574 .492 .725 r
.65815 .35837 m .66804 .35807 L .6594 .36246 L closepath p F P
0 g
s
.574 .508 .743 r
.65697 .35485 m .65815 .35837 L .66804 .35807 L p F P
0 g
s
.689 .75 .898 r
.18577 .33394 m .17534 .33858 L .17196 .33498 L p F P
0 g
s
.589 .875 .993 r
.52837 .34708 m .53252 .34585 L .53951 .34395 L p F P
0 g
s
.55 .888 .985 r
.52837 .34708 m .53252 .34585 L .52825 .34704 L closepath p F P
0 g
s
.593 .538 .762 r
.65526 .35027 m .65697 .35485 L .66677 .3498 L p F P
0 g
s
.574 .508 .743 r
.66922 .35745 m .66677 .3498 L .65697 .35485 L p F P
0 g
s
.574 .508 .743 r
.66804 .35807 m .66922 .35745 L p .65697 .35485 L F P
0 g
s
.552 .056 .03 r
.36291 .4869 m .36834 .48885 L .36057 .48842 L closepath p F P
0 g
s
.552 .456 .699 r
.6694 .35811 m .66804 .35807 L .6594 .36246 L p F P
0 g
s
.552 .456 .699 r
.67097 .36427 m .6694 .35811 L p .6594 .36246 L F P
0 g
s
.552 .456 .699 r
.66133 .36924 m .67097 .36427 L p .6594 .36246 L F P
0 g
s
.552 .456 .699 r
.6594 .36246 m .66116 .36922 L .66133 .36924 L p F P
0 g
s
0 .549 .74 r
.3586 .35753 m .34937 .35711 L .34612 .35632 L p F P
0 g
s
.577 .762 .966 r
.23159 .3395 m .23023 .33843 L .22868 .33872 L closepath p F P
0 g
s
.512 .346 .593 r
.66392 .38684 m .65912 .38912 L .65518 .38527 L p F P
0 g
s
.512 .346 .593 r
.65518 .38527 m .66333 .38137 L .66392 .38684 L p F P
0 g
s
.549 .888 .985 r
.53252 .34585 m .52825 .34704 L .52549 .34621 L p F P
0 g
s
.448 .172 .401 r
.63262 .42355 m .63322 .41936 L .62277 .42342 L p F P
0 g
s
.448 .172 .401 r
.62277 .42342 m .62215 .4276 L .63262 .42355 L p F P
0 g
s
.417 .069 .264 r
.59772 .44647 m .59895 .44288 L .58804 .44631 L p F P
0 g
s
.417 .069 .264 r
.58804 .44631 m .58679 .44991 L .59772 .44647 L p F P
0 g
s
.697 .236 .155 r
.27301 .46921 m .27115 .4702 L .26895 .46835 L closepath p F P
0 g
s
.842 .596 .567 r
.14932 .39546 m .15495 .39789 L .15559 .39279 L p F P
0 g
s
.842 .596 .567 r
.15559 .39279 m .14997 .39036 L .14932 .39546 L p F P
0 g
s
.206 .686 .933 r
.32913 .35392 m .33241 .35481 L .32669 .35458 L p F P
0 g
s
.206 .686 .933 r
.31873 .3531 m .32913 .35392 L p .32669 .35458 L F P
0 g
s
.206 .686 .933 r
.32669 .35458 m .319 .3532 L .31873 .3531 L p F P
0 g
s
.79 .41 .335 r
.20758 .44004 m .2094 .44349 L .20508 .44215 L closepath p F P
0 g
s
.574 .071 .02 r
.34531 .48725 m .3459 .4869 L .34032 .48442 L p F P
0 g
s
.574 .071 .02 r
.33725 .48645 m .34531 .48725 L p .34032 .48442 L F P
0 g
s
.574 .071 .02 r
.33224 .48423 m .33725 .48645 L p .34032 .48442 L F P
0 g
s
.574 .071 .02 r
.34032 .48442 m .33317 .48373 L .33224 .48423 L p F P
0 g
s
.839 .618 .603 r
.14571 .38849 m .14997 .39036 L .15119 .38509 L p F P
0 g
s
.839 .618 .603 r
.14517 .3845 m .14571 .38849 L p .15119 .38509 L F P
0 g
s
.839 .618 .603 r
.15119 .38509 m .14562 .38263 L .14517 .3845 L p F P
0 g
s
.355 .73 .987 r
.26084 .34398 m .26622 .344 L .27361 .34586 L p F P
0 g
s
.323 .707 .981 r
.26622 .344 m .26084 .34398 L .25749 .34185 L p F P
0 g
s
.843 .574 .532 r
.1548 .40283 m .16048 .40523 L .16062 .40029 L p F P
0 g
s
.843 .574 .532 r
.16062 .40029 m .15495 .39789 L .1548 .40283 L p F P
0 g
s
.623 .143 .093 r
.31863 .48088 m .32123 .48232 L .31711 .48181 L closepath p F P
0 g
s
.593 .538 .762 r
.66677 .3498 m .66646 .34894 L .65526 .35027 L p F P
0 g
s
.595 .56 .785 r
.65345 .34593 m .65526 .35027 L .66646 .34894 L p F P
0 g
s
.744 .322 .248 r
.24096 .45732 m .24268 .45937 L .2392 .4585 L closepath p F P
0 g
s
.551 .755 .972 r
.21657 .33739 m .22206 .33659 L .22868 .33872 L p F P
0 g
s
.531 .744 .973 r
.22206 .33659 m .21657 .33739 L .21319 .33455 L p F P
0 g
s
.441 0 .077 r
.48683 .48117 m .49303 .48128 L .48594 .48225 L closepath p F P
0 g
s
.426 .054 .226 r
.57428 .45656 m .57458 .45584 L .5636 .45825 L p F P
0 g
s
.426 .054 .226 r
.5636 .45825 m .56303 .45957 L .57428 .45656 L p F P
0 g
s
.779 .706 .783 r
.14729 .34601 m .14952 .34404 L .15491 .3466 L p F P
0 g
s
.779 .706 .783 r
.15491 .3466 m .15063 .35058 L .14729 .34601 L p F P
0 g
s
.765 .719 .81 r
.15491 .3466 m .16141 .34129 L .15803 .33735 L p F P
0 g
s
.765 .719 .81 r
.15803 .33735 m .14952 .34404 L .15491 .3466 L p F P
0 g
s
.115 .628 .893 r
.30972 .35164 m .30507 .35133 L .30176 .34991 L p F P
0 g
s
.148 .657 .9 r
.30507 .35133 m .30972 .35164 L .31828 .35309 L p F P
0 g
s
.835 .637 .635 r
.14482 .38227 m .14562 .38263 L .14752 .37714 L p F P
0 g
s
.835 .637 .635 r
.14752 .37714 m .14279 .375 L .14482 .38227 L p F P
0 g
s
.799 .705 .762 r
.1478 .35383 m .15063 .35058 L .14729 .34601 L p F P
0 g
s
.808 .448 .374 r
.18814 .43284 m .19444 .43499 L .19271 .43061 L p F P
0 g
s
.808 .448 .374 r
.18731 .43073 m .18814 .43284 L p .19271 .43061 L F P
0 g
s
.808 .448 .374 r
.19271 .43061 m .18881 .42928 L .18731 .43073 L p F P
0 g
s
.754 .331 .246 r
.22861 .4556 m .23555 .45752 L .23242 .45352 L p F P
0 g
s
.754 .331 .246 r
.23242 .45352 m .22544 .45162 L .22861 .4556 L p F P
0 g
s
.65 .171 .101 r
.29482 .47844 m .28954 .47504 L .298 .47644 L p F P
0 g
s
.65 .171 .101 r
.30051 .4794 m .29482 .47844 L p .298 .47644 L F P
0 g
s
.65 .171 .101 r
.298 .47644 m .30163 .4788 L .30051 .4794 L p F P
0 g
s
.727 .284 .199 r
.24642 .46319 m .25369 .465 L .25001 .46115 L p F P
0 g
s
.727 .284 .199 r
.25001 .46115 m .24268 .45937 L .24642 .46319 L p F P
0 g
s
.482 .876 .964 r
.52549 .34621 m .51461 .3492 L .5117 .34854 L p F P
0 g
s
.473 .868 .968 r
.50083 .35125 m .5117 .34854 L .51461 .3492 L p F P
0 g
s
.842 .551 .497 r
.16079 .41003 m .1665 .41242 L .16619 .40761 L p F P
0 g
s
.842 .551 .497 r
.16619 .40761 m .16048 .40523 L .16079 .41003 L p F P
0 g
s
.439 0 .022 r
.47338 .48374 m .47305 .48406 L .47126 .48395 L closepath p F P
0 g
s
.439 0 .016 r
.47079 .48628 m .47305 .48406 L .47126 .48395 L p F P
0 g
s
.439 0 .016 r
.46599 .48675 m .47079 .48628 L p .47126 .48395 L F P
0 g
s
.439 0 .016 r
.45925 .48625 m .46599 .48675 L p .47126 .48395 L F P
0 g
s
.554 .445 .684 r
.66116 .36922 m .66133 .36924 L .66118 .36932 L closepath p F P
0 g
s
.54 .416 .66 r
.67069 .37139 m .66243 .37555 L .66118 .36932 L p F P
0 g
s
.54 .416 .66 r
.66118 .36932 m .66133 .36924 L .67069 .37139 L p F P
0 g
s
.673 .212 .15 r
.28812 .47398 m .28954 .47504 L .28708 .47462 L closepath p F P
0 g
s
.641 .664 .857 r
.63574 .33609 m .63735 .33872 L .64725 .33381 L p F P
0 g
s
.632 .652 .852 r
.64962 .33802 m .64725 .33381 L .63735 .33872 L p F P
0 g
s
.575 .766 .969 r
.22684 .33586 m .22206 .33659 L .22868 .33872 L p F P
0 g
s
.575 .766 .969 r
.22868 .33872 m .23023 .33843 L .22684 .33586 L p F P
0 g
s
.539 .419 .664 r
.67228 .37057 m .67069 .37139 L .66133 .36924 L p F P
0 g
s
.539 .419 .664 r
.66133 .36924 m .67097 .36427 L .67228 .37057 L p F P
0 g
s
.769 .369 .294 r
.22419 .44977 m .22544 .45162 L .22274 .45087 L closepath p F P
0 g
s
.736 .723 .84 r
.16757 .33749 m .16141 .34129 L .15803 .33735 L p F P
0 g
s
.414 .752 .994 r
.27513 .3462 m .27447 .34582 L .27361 .34586 L closepath p F P
0 g
s
.457 .203 .441 r
.64354 .41509 m .64393 .41069 L .63363 .41497 L p F P
0 g
s
.457 .203 .441 r
.63363 .41497 m .63322 .41936 L .64354 .41509 L p F P
0 g
s
.799 .705 .762 r
.14729 .34601 m .14261 .3512 L .1478 .35383 L p F P
0 g
s
.811 .695 .737 r
.13765 .35771 m .14298 .36028 L .1478 .35383 L p F P
0 g
s
.811 .695 .737 r
.1478 .35383 m .14261 .3512 L .13765 .35771 L p F P
0 g
s
.42 0 .009 r
.48386 .48438 m .48594 .48225 L .47338 .48374 L p F P
0 g
s
.42 0 .009 r
.47338 .48374 m .47305 .48406 L .48386 .48438 L p F P
0 g
s
.082 .632 .828 r
.36308 .35817 m .3689 .35839 L .36042 .35768 L closepath p F P
0 g
s
.03 .598 .773 r
.37555 .3588 m .3768 .35895 L p .36308 .35817 L F P
0 g
s
.03 .598 .773 r
.36308 .35817 m .3689 .35839 L .37555 .3588 L p F P
0 g
s
.595 .096 .039 r
.33317 .48373 m .33224 .48423 L .33057 .48344 L closepath p F P
0 g
s
.779 .378 .293 r
.21203 .44762 m .21866 .44965 L .21606 .4455 L p F P
0 g
s
.779 .378 .293 r
.21606 .4455 m .2094 .44349 L .21203 .44762 L p F P
0 g
s
.409 .039 .221 r
.58558 .45283 m .58679 .44991 L .57572 .45313 L p F P
0 g
s
.409 .039 .221 r
.57572 .45313 m .57458 .45584 L .58558 .45283 L p F P
0 g
s
.697 .236 .154 r
.2656 .47036 m .26129 .46669 L .26895 .46835 L p F P
0 g
s
.697 .236 .154 r
.26934 .47117 m .2656 .47036 L p .26895 .46835 L F P
0 g
s
.697 .236 .154 r
.26895 .46835 m .27115 .4702 L .26934 .47117 L p F P
0 g
s
.539 .045 .032 r
.37662 .48839 m .37963 .48936 L .37544 .48921 L closepath p F P
0 g
s
.663 .736 .905 r
.60811 .33558 m .61915 .33202 L .62191 .3354 L p F P
0 g
s
.667 .766 .924 r
.61915 .33202 m .60811 .33558 L .60535 .33275 L p F P
0 g
s
.666 .775 .931 r
.59434 .33643 m .60535 .33275 L .60811 .33558 L p F P
0 g
s
.406 .839 .95 r
.48733 .35325 m .48705 .35319 L .48494 .35362 L closepath p F P
0 g
s
.379 .831 .929 r
.48408 .35295 m .48705 .35319 L .48494 .35362 L p F P
0 g
s
.379 .831 .929 r
.47326 .35499 m .48408 .35295 L p .48494 .35362 L F P
0 g
s
.829 .658 .67 r
.13927 .36637 m .13927 .36637 L .14471 .3689 L p F P
0 g
s
.829 .658 .67 r
.14471 .3689 m .14236 .37387 L .13927 .36637 L p F P
0 g
s
.666 .804 .948 r
.60535 .33275 m .59434 .33643 L .59156 .33407 L p F P
0 g
s
.662 .81 .954 r
.58057 .33778 m .59156 .33407 L .59434 .33643 L p F P
0 g
s
.831 .516 .457 r
.16744 .41718 m .1732 .41939 L .17237 .41474 L p F P
0 g
s
.831 .516 .457 r
.17237 .41474 m .1695 .41364 L .16744 .41718 L p F P
0 g
s
.595 .56 .785 r
.6636 .34169 m .66078 .34214 L .65345 .34593 L p F P
0 g
s
.595 .56 .785 r
.66646 .34894 m .6636 .34169 L p .65345 .34593 L F P
0 g
s
.611 .583 .798 r
.65242 .34364 m .66078 .34214 L .65345 .34593 L closepath p F P
0 g
s
.4 0 .118 r
.54929 .46577 m .53836 .46821 L .53644 .47125 L p F P
0 g
s
.595 .095 .038 r
.32759 .48542 m .32123 .48232 L .33057 .48344 L p F P
0 g
s
.595 .095 .038 r
.32958 .48566 m .32759 .48542 L p .33057 .48344 L F P
0 g
s
.595 .095 .038 r
.33057 .48344 m .33224 .48423 L .32958 .48566 L p F P
0 g
s
.404 0 .064 r
.52249 .47646 m .52465 .47362 L .51269 .47578 L p F P
0 g
s
.404 0 .064 r
.52121 .47669 m .52249 .47646 L p .51269 .47578 L F P
0 g
s
.404 0 .064 r
.51269 .47578 m .51147 .47735 L .52121 .47669 L p F P
0 g
s
.403 .755 .994 r
.27112 .34399 m .26622 .344 L .27361 .34586 L p F P
0 g
s
.403 .755 .994 r
.27361 .34586 m .27447 .34582 L .27112 .34399 L p F P
0 g
s
.582 .878 .993 r
.53951 .34395 m .53927 .34385 L .53252 .34585 L closepath p F P
0 g
s
.549 .888 .985 r
.53641 .34302 m .53927 .34385 L .53252 .34585 L p F P
0 g
s
.549 .888 .985 r
.52549 .34621 m .53641 .34302 L p .53252 .34585 L F P
0 g
s
.433 .859 .944 r
.51105 .34847 m .5117 .34854 L .50083 .35125 L p F P
0 g
s
.433 .859 .944 r
.50083 .35125 m .49934 .35103 L .51105 .34847 L p F P
0 g
s
.495 .308 .556 r
.66037 .39382 m .65422 .39671 L .65392 .39157 L p F P
0 g
s
.495 .308 .556 r
.65392 .39157 m .65912 .38912 L .66037 .39382 L p F P
0 g
s
.453 .743 .99 r
.24048 .33765 m .23023 .33843 L .22684 .33586 L p F P
0 g
s
.654 .695 .876 r
.62191 .3354 m .63297 .33206 L .63574 .33609 L p F P
0 g
s
.661 .725 .897 r
.63297 .33206 m .62191 .3354 L .61915 .33202 L p F P
0 g
s
.653 .844 .974 r
.5908 .33353 m .59156 .33407 L .58057 .33778 L p F P
0 g
s
.653 .844 .974 r
.58057 .33778 m .58029 .33759 L .5908 .33353 L p F P
0 g
s
.425 .848 .954 r
.4979 .35082 m .49934 .35103 L .48733 .35325 L p F P
0 g
s
.425 .848 .954 r
.48733 .35325 m .48705 .35319 L .4979 .35082 L p F P
0 g
s
.244 .709 .947 r
.319 .3532 m .31873 .3531 L .31828 .35309 L closepath p F P
0 g
s
.42 0 .007 r
.48342 .48482 m .48386 .48438 L .47305 .48406 L p F P
0 g
s
.42 0 .007 r
.47305 .48406 m .47079 .48628 L .48342 .48482 L p F P
0 g
s
.215 .7 .929 r
.31543 .35199 m .30972 .35164 L .31828 .35309 L p F P
0 g
s
.215 .7 .929 r
.31828 .35309 m .31873 .3531 L .31543 .35199 L p F P
0 g
s
.193 .667 .935 r
.28477 .34628 m .27447 .34582 L .27112 .34399 L p F P
0 g
s
.801 .423 .339 r
.19654 .43928 m .20287 .44142 L .20079 .43713 L p F P
0 g
s
.801 .423 .339 r
.20079 .43713 m .19444 .43499 L .19654 .43928 L p F P
0 g
s
.62 .598 .807 r
.66078 .34214 m .65242 .34364 L .64962 .33802 L p F P
0 g
s
.016 .589 .746 r
.39016 .35939 m .39055 .35942 L p .3768 .35895 L F P
0 g
s
.016 .589 .746 r
.3768 .35895 m .37992 .35903 L .39016 .35939 L p F P
0 g
s
.059 .62 .794 r
.3768 .35895 m .37992 .35903 L .37555 .3588 L closepath p F P
0 g
s
.655 .846 .973 r
.58878 .33208 m .5908 .33353 L .58029 .33759 L p F P
0 g
s
.655 .846 .973 r
.58029 .33759 m .57778 .33589 L .58878 .33208 L p F P
0 g
s
0 .551 .775 r
.32913 .35392 m .31873 .3531 L .31543 .35199 L p F P
0 g
s
.826 .49 .419 r
.17443 .42391 m .18043 .42619 L .17921 .42165 L p F P
0 g
s
.826 .49 .419 r
.17921 .42165 m .1732 .41939 L .17443 .42391 L p F P
0 g
s
.818 .462 .383 r
.18881 .42928 m .18731 .43073 L .18647 .42843 L closepath p F P
0 g
s
.319 .805 .878 r
.4979 .35082 m .48705 .35319 L .48408 .35295 L p F P
0 g
s
.723 .735 .861 r
.16757 .33749 m .17196 .33498 L .16856 .33145 L p F P
0 g
s
.723 .735 .861 r
.16856 .33145 m .16222 .33491 L .16757 .33749 L p F P
0 g
s
.736 .723 .84 r
.15803 .33735 m .16222 .33491 L .16757 .33749 L p F P
0 g
s
.525 .034 .032 r
.39035 .48937 m .39149 .48969 L .38995 .48967 L closepath p F P
0 g
s
.638 .868 .985 r
.57778 .33589 m .56681 .33957 L .564 .33805 L p F P
0 g
s
.627 .868 .987 r
.55305 .34163 m .564 .33805 L .56681 .33957 L p F P
0 g
s
.644 .154 .075 r
.28647 .477 m .29482 .47844 L .28954 .47504 L p F P
0 g
s
.644 .154 .075 r
.28462 .47579 m .28647 .477 L p .28954 .47504 L F P
0 g
s
.644 .154 .075 r
.28954 .47504 m .28708 .47462 L .28462 .47579 L p F P
0 g
s
.42 0 .124 r
.52524 .47272 m .5326 .47203 L .52465 .47362 L closepath p F P
0 g
s
.819 .68 .71 r
.13927 .36636 m .13927 .36637 L .14298 .36028 L p F P
0 g
s
.819 .68 .71 r
.13606 .36019 m .13927 .36636 L p .14298 .36028 L F P
0 g
s
.819 .68 .71 r
.14298 .36028 m .13765 .35771 L .13606 .36019 L p F P
0 g
s
.524 .382 .63 r
.67318 .3764 m .66333 .38137 L .66243 .37555 L p F P
0 g
s
.524 .382 .63 r
.67256 .37227 m .67318 .3764 L p .66243 .37555 L F P
0 g
s
.524 .382 .63 r
.66243 .37555 m .67069 .37139 L .67256 .37227 L p F P
0 g
s
.465 .236 .48 r
.65411 .40621 m .65427 .40158 L .64411 .40607 L p F P
0 g
s
.465 .236 .48 r
.64411 .40607 m .64393 .41069 L .65411 .40621 L p F P
0 g
s
.641 .664 .857 r
.64725 .33381 m .64684 .33311 L .63574 .33609 L p F P
0 g
s
.649 .681 .867 r
.64684 .33311 m .63574 .33609 L .63297 .33206 L p F P
0 g
s
.394 0 .165 r
.57263 .45979 m .57428 .45656 L .56303 .45957 L p F P
0 g
s
.394 0 .165 r
.56303 .45957 m .56136 .46281 L .57263 .45979 L p F P
0 g
s
.839 .527 .462 r
.16723 .4171 m .16744 .41718 L .1695 .41364 L p F P
0 g
s
.839 .527 .462 r
.1695 .41364 m .1665 .41242 L .16723 .4171 L p F P
0 g
s
.441 0 .015 r
.45925 .48625 m .46599 .48675 L .45794 .48749 L closepath p F P
0 g
s
.02 .594 .734 r
.39055 .35942 m .39167 .35942 L .40425 .35954 L p F P
0 g
s
.052 .617 .77 r
.39055 .35942 m .39167 .35942 L .39016 .35939 L closepath p F P
0 g
s
.589 .081 .014 r
.31836 .48426 m .32759 .48542 L .32123 .48232 L p F P
0 g
s
.589 .081 .014 r
.31522 .48272 m .31836 .48426 L p .32123 .48232 L F P
0 g
s
.589 .081 .014 r
.32123 .48232 m .31711 .48181 L .31522 .48272 L p F P
0 g
s
.724 .274 .182 r
.23918 .46138 m .24642 .46319 L .24268 .45937 L p F P
0 g
s
.724 .274 .182 r
.23731 .45945 m .23918 .46138 L p .24268 .45937 L F P
0 g
s
.724 .274 .182 r
.24268 .45937 m .2392 .4585 L .23731 .45945 L p F P
0 g
s
.663 .181 .096 r
.28708 .47462 m .28462 .47579 L .2814 .47354 L closepath p F P
0 g
s
.247 .76 .836 r
.48408 .35295 m .47326 .35499 L .47026 .35485 L p F P
0 g
s
.256 .764 .858 r
.45947 .35654 m .47026 .35485 L .47326 .35499 L p F P
0 g
s
.58 .077 .023 r
.33224 .48423 m .33725 .48645 L .32958 .48566 L closepath p F P
0 g
s
.403 0 .005 r
.49303 .48128 m .48594 .48225 L .48386 .48438 L p F P
0 g
s
.754 .325 .233 r
.2217 .45367 m .22861 .4556 L .22544 .45162 L p F P
0 g
s
.754 .325 .233 r
.22049 .45212 m .2217 .45367 L p .22544 .45162 L F P
0 g
s
.754 .325 .233 r
.22544 .45162 m .22274 .45087 L .22049 .45212 L p F P
0 g
s
.465 0 0 r
.41753 .48965 m .40412 .48981 L .4041 .48982 L p F P
0 g
s
.486 0 0 r
.40412 .48981 m .4041 .48982 L .40405 .48981 L closepath p F P
0 g
s
.486 0 0 r
.4009 .4919 m .39149 .48969 L .40405 .48981 L p F P
0 g
s
.486 0 0 r
.40405 .48981 m .4041 .48982 L .4009 .4919 L p F P
0 g
s
.844 .598 .566 r
.14563 .39384 m .14932 .39546 L .14997 .39036 L p F P
0 g
s
.844 .598 .566 r
.14997 .39036 m .14571 .38849 L .14563 .39384 L p F P
0 g
s
.465 0 0 r
.4041 .48982 m .41428 .49181 L p .41753 .48965 L F P
0 g
s
.477 0 0 r
.41428 .49181 m .4041 .48982 L .4009 .4919 L p F P
0 g
s
.357 .72 .987 r
.2528 .33982 m .24386 .33998 L .24048 .33765 L p F P
0 g
s
.399 .739 .992 r
.25529 .3405 m .25749 .34185 L p .24386 .33998 L F P
0 g
s
.399 .739 .992 r
.24386 .33998 m .2528 .33982 L .25529 .3405 L p F P
0 g
s
.644 .754 .929 r
.18577 .33394 m .1961 .33083 L .1995 .33386 L p F P
0 g
s
.631 .754 .936 r
.1961 .33083 m .18577 .33394 L .18237 .33066 L p F P
0 g
s
.689 .75 .898 r
.17196 .33498 m .18237 .33066 L .18577 .33394 L p F P
0 g
s
.838 .655 .655 r
.14236 .37387 m .14204 .37464 L .14279 .375 L closepath p F P
0 g
s
.844 .642 .629 r
.14029 .38008 m .14482 .38227 L .14279 .375 L p F P
0 g
s
.844 .642 .629 r
.14279 .375 m .14204 .37464 L .14029 .38008 L p F P
0 g
s
.842 .621 .603 r
.14562 .38263 m .14482 .38227 L .14517 .3845 L closepath p F P
0 g
s
.606 .887 .99 r
.56141 .33693 m .564 .33805 L .55305 .34163 L p F P
0 g
s
.606 .887 .99 r
.55305 .34163 m .55057 .34058 L .56141 .33693 L p F P
0 g
s
.484 0 0 r
.40088 .49191 m .4009 .4919 L .39149 .48969 L p F P
0 g
s
.484 0 0 r
.38855 .49173 m .40088 .49191 L p .39149 .48969 L F P
0 g
s
.484 0 0 r
.38711 .49139 m .38855 .49173 L p .39149 .48969 L F P
0 g
s
.484 0 0 r
.39149 .48969 m .38995 .48967 L .38711 .49139 L p F P
0 g
s
.506 0 0 r
.38995 .48967 m .38711 .49139 L .37963 .48936 L closepath p F P
0 g
s
.845 .575 .531 r
.14917 .4004 m .1548 .40283 L .15495 .39789 L p F P
0 g
s
.845 .575 .531 r
.15495 .39789 m .14932 .39546 L .14917 .4004 L p F P
0 g
s
.47 0 0 r
.41798 .48964 m .41788 .48972 L .41753 .48965 L closepath p F P
0 g
s
.465 0 0 r
.41484 .4918 m .41788 .48972 L .41753 .48965 L p F P
0 g
s
.465 0 0 r
.41428 .49181 m .41484 .4918 L p .41753 .48965 L F P
0 g
s
.453 0 0 r
.42853 .49139 m .43156 .4892 L .41798 .48964 L p F P
0 g
s
.453 0 0 r
.41798 .48964 m .41788 .48972 L .42853 .49139 L p F P
0 g
s
.839 .661 .661 r
.14204 .37464 m .14236 .37387 L .13927 .36637 L p F P
0 g
s
.69 .218 .125 r
.25803 .46865 m .2656 .47036 L .26129 .46669 L p F P
0 g
s
.69 .218 .125 r
.25421 .46546 m .25803 .46865 L p .26129 .46669 L F P
0 g
s
.69 .218 .125 r
.26129 .46669 m .2547 .46524 L .25421 .46546 L p F P
0 g
s
.819 .463 .383 r
.18202 .43061 m .18043 .42619 L .18647 .42843 L p F P
0 g
s
.819 .463 .383 r
.18592 .43206 m .18202 .43061 L p .18647 .42843 L F P
0 g
s
.819 .463 .383 r
.18647 .42843 m .18731 .43073 L .18592 .43206 L p F P
0 g
s
.46 0 .021 r
.44546 .48794 m .44808 .48824 L .44487 .48847 L closepath p F P
0 g
s
.679 .751 .906 r
.18237 .33066 m .17196 .33498 L .16856 .33145 L p F P
0 g
s
.163 .696 .843 r
.41789 .35932 m .40434 .35954 L .40432 .35954 L p F P
0 g
s
.129 .673 .826 r
.40434 .35954 m .40432 .35954 L .40425 .35954 L closepath p F P
0 g
s
.066 .63 .759 r
.40116 .35945 m .39167 .35942 L .40425 .35954 L p F P
0 g
s
.066 .63 .759 r
.40425 .35954 m .40432 .35954 L .40116 .35945 L p F P
0 g
s
.531 .744 .973 r
.21319 .33455 m .21613 .33421 L .22206 .33659 L p F P
0 g
s
.551 .762 .976 r
.22345 .33333 m .21613 .33421 L .22206 .33659 L p F P
0 g
s
.551 .762 .976 r
.22206 .33659 m .22684 .33586 L .22345 .33333 L p F P
0 g
s
.43 .107 .316 r
.60972 .43924 m .61016 .43759 L .59916 .44211 L p F P
0 g
s
.43 .107 .316 r
.59916 .44211 m .59895 .44288 L .60972 .43924 L p F P
0 g
s
.163 .696 .843 r
.40432 .35954 m .41497 .3593 L p .41789 .35932 L F P
0 g
s
.059 0 0 r
.41497 .3593 m .40432 .35954 L .40116 .35945 L p F P
0 g
s
.233 .75 .836 r
.47016 .35485 m .47026 .35485 L .45947 .35654 L p F P
0 g
s
.233 .75 .836 r
.45947 .35654 m .45764 .35651 L .47016 .35485 L p F P
0 g
s
.193 .723 .823 r
.45764 .35651 m .45947 .35654 L p .44568 .35779 L F P
0 g
s
.61 .108 .035 r
.31711 .48181 m .31522 .48272 L .31216 .48111 L closepath p F P
0 g
s
.452 0 0 r
.42852 .49141 m .42853 .49139 L .41788 .48972 L p F P
0 g
s
.452 0 0 r
.41788 .48972 m .41484 .4918 L .42852 .49141 L p F P
0 g
s
.042 .609 .761 r
.3994 .35951 m .40116 .35945 L .39167 .35942 L p F P
0 g
s
.042 .609 .761 r
.39388 .35943 m .3994 .35951 L p .39167 .35942 L F P
0 g
s
.042 .609 .761 r
.38737 .3592 m .39388 .35943 L p .39167 .35942 L F P
0 g
s
.042 .609 .761 r
.39167 .35942 m .39016 .35939 L .38737 .3592 L p F P
0 g
s
.015 .588 .745 r
.39016 .35939 m .38737 .3592 L .37992 .35903 L closepath p F P
0 g
s
.776 .712 .792 r
.14952 .34404 m .14729 .34601 L .14393 .34161 L p F P
0 g
s
.797 .708 .767 r
.14261 .3512 m .14729 .34601 L .14393 .34161 L p F P
0 g
s
.477 0 .026 r
.43166 .48911 m .43206 .48917 L .43156 .4892 L closepath p F P
0 g
s
.778 .371 .279 r
.20544 .44557 m .21203 .44762 L .2094 .44349 L p F P
0 g
s
.778 .371 .279 r
.20378 .44295 m .20544 .44557 L p .2094 .44349 L F P
0 g
s
.778 .371 .279 r
.2094 .44349 m .20508 .44215 L .20378 .44295 L p F P
0 g
s
.76 .721 .816 r
.14952 .34404 m .15803 .33735 L .15464 .33351 L p F P
0 g
s
.76 .721 .816 r
.15464 .33351 m .14408 .34148 L .14952 .34404 L p F P
0 g
s
.776 .712 .792 r
.14393 .34161 m .14408 .34148 L .14952 .34404 L p F P
0 g
s
.839 .661 .661 r
.13927 .36637 m .13683 .37203 L .14204 .37464 L p F P
0 g
s
.847 .646 .631 r
.13505 .37749 m .14029 .38008 L .14204 .37464 L p F P
0 g
s
.847 .646 .631 r
.14204 .37464 m .13683 .37203 L .13505 .37749 L p F P
0 g
s
.844 .552 .495 r
.15512 .40763 m .16079 .41003 L .16048 .40523 L p F P
0 g
s
.844 .552 .495 r
.16048 .40523 m .1548 .40283 L .15512 .40763 L p F P
0 g
s
.593 .756 .956 r
.1995 .33386 m .20979 .33175 L .21319 .33455 L p F P
0 g
s
.573 .755 .964 r
.20979 .33175 m .1995 .33386 L .1961 .33083 L p F P
0 g
s
.85 .626 .598 r
.14444 .38789 m .14517 .3845 L .14482 .38227 L p F P
0 g
s
.85 .626 .598 r
.13912 .38534 m .14444 .38789 L p .14482 .38227 L F P
0 g
s
.85 .626 .598 r
.14482 .38227 m .14029 .38008 L .13912 .38534 L p F P
0 g
s
.147 .687 .827 r
.41816 .35931 m .4181 .35931 L .41789 .35932 L closepath p F P
0 g
s
.163 .696 .843 r
.41497 .3593 m .4181 .35931 L .41789 .35932 L p F P
0 g
s
.498 0 0 r
.3866 .4917 m .38711 .49139 L .37963 .48936 L p F P
0 g
s
.498 0 0 r
.37682 .49135 m .3866 .4917 L p .37963 .48936 L F P
0 g
s
.498 0 0 r
.37335 .49039 m .37682 .49135 L p .37963 .48936 L F P
0 g
s
.498 0 0 r
.37963 .48936 m .37544 .48921 L .37335 .49039 L p F P
0 g
s
.024 0 0 r
.42879 .35875 m .4181 .35931 L .41497 .3593 L p F P
0 g
s
.024 0 0 r
.42073 .35915 m .427 .35891 L p .41814 .3592 L F P
0 g
s
.024 0 0 r
.41497 .3593 m .41682 .35925 L p .41814 .3592 L F P
0 g
s
.024 0 0 r
.41682 .35925 m .42073 .35915 L p .41814 .3592 L F P
0 g
s
.142 .684 .825 r
.43163 .35872 m .41816 .35931 L p .42858 .35877 L F P
0 g
s
.142 .684 .825 r
.42879 .35875 m .42886 .35875 L p .42858 .35877 L F P
0 g
s
.142 .684 .825 r
.42886 .35875 m .43163 .35872 L p .42858 .35877 L F P
0 g
s
.142 .684 .825 r
.41816 .35931 m .4181 .35931 L .42879 .35875 L p F P
0 g
s
.323 .707 .981 r
.25749 .34185 m .25947 .34193 L .26622 .344 L p F P
0 g
s
.353 .735 .987 r
.26775 .34222 m .25947 .34193 L .26622 .344 L p F P
0 g
s
.353 .735 .987 r
.26622 .344 m .27112 .34399 L .26775 .34222 L p F P
0 g
s
.115 .628 .893 r
.30176 .34991 m .30193 .34993 L .30972 .35164 L p F P
0 g
s
.139 .655 .891 r
.31211 .35097 m .30193 .34993 L .30972 .35164 L p F P
0 g
s
.139 .655 .891 r
.30972 .35164 m .31543 .35199 L .31211 .35097 L p F P
0 g
s
.594 .883 .992 r
.55021 .34044 m .55057 .34058 L .53951 .34395 L p F P
0 g
s
.594 .883 .992 r
.53951 .34395 m .53927 .34385 L .55021 .34044 L p F P
0 g
s
.685 .22 .141 r
.27115 .4702 m .2734 .47198 L .26934 .47117 L closepath p F P
0 g
s
.193 .723 .823 r
.44568 .35779 m .45027 .35723 L .45764 .35651 L p F P
0 g
s
.173 .709 .801 r
.44568 .35779 m .45027 .35723 L .44479 .35779 L closepath p F P
0 g
s
.128 .677 .782 r
.44479 .35779 m .44568 .35779 L p .43188 .35872 L F P
0 g
s
.156 .655 .911 r
.30162 .34986 m .30176 .34991 L p .28811 .34786 L F P
0 g
s
.156 .655 .911 r
.28811 .34786 m .29385 .34831 L .30162 .34986 L p F P
0 g
s
.121 .625 .901 r
.29385 .34831 m .28811 .34786 L .28477 .34628 L p F P
0 g
s
0 .529 .748 r
.33917 .35539 m .33241 .35481 L .32913 .35392 L p F P
0 g
s
.52 .005 0 r
.37544 .48921 m .37335 .49039 L .36834 .48885 L closepath p F P
0 g
s
.435 0 0 r
.43206 .48917 m .43156 .4892 L .42853 .49139 L p F P
0 g
s
.128 .677 .782 r
.43188 .35872 m .433 .35862 L .44479 .35779 L p F P
0 g
s
.122 .672 .775 r
.43188 .35872 m .433 .35862 L .43163 .35872 L closepath p F P
0 g
s
.435 0 0 r
.44191 .49073 m .44236 .49038 L .43206 .48917 L p F P
0 g
s
.435 0 0 r
.4286 .4914 m .44191 .49073 L p .43206 .48917 L F P
0 g
s
.435 0 0 r
.42853 .49139 m .4286 .4914 L p .43206 .48917 L F P
0 g
s
.439 0 0 r
.44487 .48847 m .44236 .49038 L .43206 .48917 L closepath p F P
0 g
s
.767 .346 .25 r
.22274 .45087 m .22049 .45212 L .21866 .44965 L closepath p F P
0 g
s
.74 .297 .2 r
.2392 .4585 m .23731 .45945 L .23555 .45752 L closepath p F P
0 g
s
.047 .611 .784 r
.38499 .35918 m .38737 .3592 L .37992 .35903 L p F P
0 g
s
.047 .611 .784 r
.38203 .35905 m .38499 .35918 L p .37992 .35903 L F P
0 g
s
.047 .611 .784 r
.3736 .35857 m .38203 .35905 L p .37992 .35903 L F P
0 g
s
.047 .611 .784 r
.37992 .35903 m .37555 .3588 L .3736 .35857 L p F P
0 g
s
.413 .092 .309 r
.62116 .43231 m .62135 .4316 L .61073 .43544 L p F P
0 g
s
.413 .092 .309 r
.61073 .43544 m .61016 .43759 L .62116 .43231 L p F P
0 g
s
.555 .894 .982 r
.55021 .34044 m .53927 .34385 L .53641 .34302 L p F P
0 g
s
.402 0 .008 r
.49831 .48054 m .49767 .48121 L .49303 .48128 L closepath p F P
0 g
s
.403 0 .005 r
.49583 .48313 m .49767 .48121 L .49303 .48128 L p F P
0 g
s
.403 0 .005 r
.48684 .48437 m .49583 .48313 L p .49303 .48128 L F P
0 g
s
.403 0 .005 r
.48386 .48438 m .48684 .48437 L p .49303 .48128 L F P
0 g
s
.842 .529 .459 r
.16152 .41471 m .16723 .4171 L .1665 .41242 L p F P
0 g
s
.842 .529 .459 r
.1665 .41242 m .16079 .41003 L .16152 .41471 L p F P
0 g
s
.383 0 .056 r
.5326 .47203 m .52465 .47362 L .52249 .47646 L p F P
0 g
s
.797 .708 .767 r
.14393 .34161 m .13744 .34856 L .14261 .3512 L p F P
0 g
s
.81 .698 .741 r
.13355 .35569 m .13765 .35771 L .14261 .3512 L p F P
0 g
s
.81 .698 .741 r
.13281 .35448 m .13355 .35569 L p .14261 .3512 L F P
0 g
s
.81 .698 .741 r
.14261 .3512 m .13744 .34856 L .13281 .35448 L p F P
0 g
s
.847 .622 .596 r
.14517 .3845 m .14444 .38789 L .14571 .38849 L closepath p F P
0 g
s
.032 .599 .775 r
.37555 .3588 m .3736 .35857 L .3689 .35839 L closepath p F P
0 g
s
.512 0 0 r
.37197 .49116 m .37335 .49039 L .36834 .48885 L p F P
0 g
s
.512 0 0 r
.36563 .4908 m .37197 .49116 L p .36834 .48885 L F P
0 g
s
.512 0 0 r
.35961 .48892 m .36563 .4908 L p .36834 .48885 L F P
0 g
s
.512 0 0 r
.36834 .48885 m .36057 .48842 L .35961 .48892 L p F P
0 g
s
.663 .18 .094 r
.27839 .47546 m .2734 .47198 L .2814 .47354 L p F P
0 g
s
.663 .18 .094 r
.28326 .47642 m .27839 .47546 L p .2814 .47354 L F P
0 g
s
.663 .18 .094 r
.2814 .47354 m .28462 .47579 L .28326 .47642 L p F P
0 g
s
.424 .128 .356 r
.63216 .42589 m .63262 .42355 L .62215 .4276 L p F P
0 g
s
.424 .128 .356 r
.62513 .43014 m .63216 .42589 L p .62215 .4276 L F P
0 g
s
.424 .128 .356 r
.62215 .4276 m .62135 .4316 L .62513 .43014 L p F P
0 g
s
.637 .154 .088 r
.30163 .4788 m .30333 .47983 L .30051 .4794 L closepath p F P
0 g
s
.62 .598 .807 r
.66322 .34083 m .66078 .34214 L p .64962 .33802 L F P
0 g
s
.62 .598 .807 r
.64962 .33802 m .66078 .33565 L .66322 .34083 L p F P
0 g
s
.623 .638 .844 r
.64725 .33381 m .64962 .33802 L .66078 .33565 L p F P
0 g
s
.115 .667 .768 r
.433 .35862 m .43163 .35872 L .42879 .35875 L p F P
0 g
s
.83 .664 .677 r
.13927 .36637 m .13927 .36636 L .13927 .36637 L closepath p F P
0 g
s
.399 .052 .257 r
.60851 .44283 m .60972 .43924 L .59895 .44288 L p F P
0 g
s
.399 .052 .257 r
.59895 .44288 m .59772 .44647 L .60851 .44283 L p F P
0 g
s
.842 .665 .664 r
.13683 .37203 m .13927 .36637 L .13927 .36636 L p F P
0 g
s
.833 .678 .69 r
.13606 .36019 m .13415 .36372 L .13927 .36636 L closepath p F P
0 g
s
.842 .665 .664 r
.13166 .36941 m .13683 .37203 L p .13927 .36636 L F P
0 g
s
.842 .665 .664 r
.13927 .36636 m .13415 .36372 L .13166 .36941 L p F P
0 g
s
.61 .107 .033 r
.30936 .48302 m .30333 .47983 L .31216 .48111 L p F P
0 g
s
.61 .107 .033 r
.31334 .48361 m .30936 .48302 L p .31216 .48111 L F P
0 g
s
.61 .107 .033 r
.31216 .48111 m .31522 .48272 L .31334 .48361 L p F P
0 g
s
.73 .727 .848 r
.16222 .33491 m .15803 .33735 L .15464 .33351 L p F P
0 g
s
.42 .852 .94 r
.50878 .34823 m .51105 .34847 L .49934 .35103 L p F P
0 g
s
.42 .852 .94 r
.49934 .35103 m .4979 .35082 L .50878 .34823 L p F P
0 g
s
.397 0 .115 r
.54995 .46562 m .54991 .46568 L .54929 .46577 L closepath p F P
0 g
s
.4 0 .118 r
.54804 .46864 m .54991 .46568 L .54929 .46577 L p F P
0 g
s
.4 0 .118 r
.53644 .47125 m .54804 .46864 L p .54929 .46577 L F P
0 g
s
.114 .666 .768 r
.44479 .35779 m .44261 .35781 L .433 .35862 L closepath p F P
0 g
s
.115 .667 .768 r
.42879 .35875 m .43642 .35828 L p .433 .35862 L F P
0 g
s
0 0 0 r
.42567 .35904 m .43048 .35889 L p .43642 .35828 L F P
0 g
s
0 0 0 r
.43048 .35889 m .43643 .35869 L p .43642 .35836 L F P
0 g
s
0 0 0 r
.43642 .35828 m .43048 .35889 L .43642 .35836 L F
.115 .667 .768 r
.44261 .35781 m .433 .35862 L p .4399 .35806 L F P
0 g
s
.115 .667 .768 r
.44025 .35803 m .4407 .35799 L p .4399 .35806 L F P
0 g
s
.115 .667 .768 r
.4407 .35799 m .44261 .35781 L p .4399 .35806 L F P
0 g
s
.115 .667 .768 r
.43642 .35828 m .44025 .35803 L p .433 .35862 L F P
0 g
s
.509 .733 .975 r
.21613 .33421 m .21319 .33455 L .20979 .33175 L p F P
0 g
s
.492 .306 .556 r
.66423 .39199 m .66037 .39382 L .65912 .38912 L p F P
0 g
s
.492 .306 .556 r
.65912 .38912 m .66392 .38684 L .66423 .39199 L p F P
0 g
s
.376 0 .104 r
.56089 .46358 m .56136 .46281 L .54995 .46562 L p F P
0 g
s
.376 0 .104 r
.54995 .46562 m .54991 .46568 L .56089 .46358 L p F P
0 g
s
.802 .42 .332 r
.19027 .43711 m .19654 .43928 L .19444 .43499 L p F P
0 g
s
.802 .42 .332 r
.19444 .43499 m .18814 .43284 L .19027 .43711 L p F P
0 g
s
.474 .267 .518 r
.65918 .39929 m .65427 .40158 L .65422 .39671 L p F P
0 g
s
.474 .267 .518 r
.65422 .39671 m .66037 .39382 L .65918 .39929 L p F P
0 g
s
.502 .339 .592 r
.67378 .38187 m .67318 .3764 L .66333 .38137 L p F P
0 g
s
.502 .339 .592 r
.66333 .38137 m .66392 .38684 L .67378 .38187 L p F P
0 g
s
.376 0 .102 r
.55949 .46584 m .56089 .46358 L .54991 .46568 L p F P
0 g
s
.376 0 .102 r
.54991 .46568 m .54804 .46864 L .55949 .46584 L p F P
0 g
s
.069 .623 .817 r
.37037 .35836 m .3736 .35857 L .3689 .35839 L p F P
0 g
s
.069 .623 .817 r
.35985 .35758 m .37037 .35836 L p .3689 .35839 L F P
0 g
s
.069 .623 .817 r
.3689 .35839 m .36042 .35768 L .35985 .35758 L p F P
0 g
s
.417 0 0 r
.44808 .48824 m .44487 .48847 L .44236 .49038 L p F P
0 g
s
.341 .706 .984 r
.25749 .34185 m .25947 .34193 L .25529 .3405 L closepath p F P
0 g
s
.534 .016 0 r
.36057 .48842 m .35961 .48892 L .35751 .48819 L closepath p F P
0 g
s
.403 0 .062 r
.51147 .47735 m .52121 .47669 L .51049 .4786 L closepath p F P
0 g
s
.828 .486 .41 r
.16847 .42162 m .17443 .42391 L .1732 .41939 L p F P
0 g
s
.828 .486 .41 r
.16729 .41735 m .16847 .42162 L p .1732 .41939 L F P
0 g
s
.828 .486 .41 r
.1732 .41939 m .16744 .41718 L .16729 .41735 L p F P
0 g
s
.419 0 0 r
.45794 .48749 m .4562 .48888 L .44808 .48824 L closepath p F P
0 g
s
.417 0 0 r
.45505 .48979 m .4562 .48888 L .44808 .48824 L p F P
0 g
s
.417 0 0 r
.44438 .49056 m .45505 .48979 L p .44808 .48824 L F P
0 g
s
.417 0 0 r
.44236 .49038 m .44438 .49056 L p .44808 .48824 L F P
0 g
s
.433 .16 .398 r
.64312 .41812 m .64354 .41509 L .63322 .41936 L p F P
0 g
s
.433 .16 .398 r
.64019 .42044 m .64312 .41812 L p .63322 .41936 L F P
0 g
s
.433 .16 .398 r
.63322 .41936 m .63262 .42355 L .64019 .42044 L p F P
0 g
s
.569 .069 .028 r
.3459 .4869 m .34713 .4874 L .34531 .48725 L closepath p F P
0 g
s
.708 .243 .145 r
.2547 .46524 m .25421 .46546 L .25369 .465 L closepath p F P
0 g
s
.533 .014 0 r
.35487 .49011 m .34713 .4874 L .35751 .48819 L p F P
0 g
s
.533 .014 0 r
.35697 .49027 m .35487 .49011 L p .35751 .48819 L F P
0 g
s
.533 .014 0 r
.35751 .48819 m .35961 .48892 L .35697 .49027 L p F P
0 g
s
.382 0 0 r
.50856 .48068 m .51049 .4786 L .49831 .48054 L p F P
0 g
s
.382 0 0 r
.49831 .48054 m .49767 .48121 L .50856 .48068 L p F P
0 g
s
.563 .472 .71 r
.66804 .35807 m .66922 .35745 L .6694 .35811 L closepath p F P
0 g
s
.39 .021 .213 r
.59661 .44918 m .59772 .44647 L .58679 .44991 L p F P
0 g
s
.39 .021 .213 r
.58679 .44991 m .58558 .45283 L .59661 .44918 L p F P
0 g
s
.509 .886 .969 r
.53641 .34302 m .52549 .34621 L .5226 .34561 L p F P
0 g
s
.482 .876 .964 r
.5117 .34854 m .5226 .34561 L .52549 .34621 L p F P
0 g
s
.74 .297 .199 r
.23212 .45949 m .22861 .4556 L .23555 .45752 L p F P
0 g
s
.74 .297 .199 r
.23539 .4604 m .23212 .45949 L p .23555 .45752 L F P
0 g
s
.74 .297 .199 r
.23555 .45752 m .23731 .45945 L .23539 .4604 L p F P
0 g
s
.79 .39 .294 r
.20508 .44215 m .20378 .44295 L .20287 .44142 L closepath p F P
0 g
s
0 .549 .74 r
.34612 .35632 m .34866 .35653 L .3586 .35753 L p F P
0 g
s
.019 .583 .796 r
.34612 .35632 m .34866 .35653 L .34477 .35605 L closepath p F P
0 g
s
.408 .037 .219 r
.58537 .45334 m .58558 .45283 L .57458 .45584 L p F P
0 g
s
.408 .037 .219 r
.57458 .45584 m .57428 .45656 L .58537 .45334 L p F P
0 g
s
.717 .735 .866 r
.16222 .33491 m .16856 .33145 L .16514 .32798 L p F P
0 g
s
.717 .735 .866 r
.16514 .32798 m .15671 .33236 L .16222 .33491 L p F P
0 g
s
.73 .727 .848 r
.15464 .33351 m .15671 .33236 L .16222 .33491 L p F P
0 g
s
.852 .604 .565 r
.1438 .39298 m .14563 .39384 L .14571 .38849 L p F P
0 g
s
.852 .604 .565 r
.14571 .38849 m .14444 .38789 L .1438 .39298 L p F P
0 g
s
.667 .766 .924 r
.60535 .33275 m .61639 .32904 L .61915 .33202 L p F P
0 g
s
.669 .795 .942 r
.61639 .32904 m .60535 .33275 L .60258 .33028 L p F P
0 g
s
.666 .804 .948 r
.59156 .33407 m .60258 .33028 L .60535 .33275 L p F P
0 g
s
.812 .453 .377 r
.18731 .43073 m .18814 .43284 L .18592 .43206 L closepath p F P
0 g
s
.661 .725 .897 r
.61915 .33202 m .63022 .3285 L .63297 .33206 L p F P
0 g
s
.667 .754 .916 r
.63022 .3285 m .61915 .33202 L .61639 .32904 L p F P
0 g
s
.708 .242 .143 r
.25049 .46693 m .24642 .46319 L .25369 .465 L p F P
0 g
s
.708 .242 .143 r
.25076 .467 m .25049 .46693 L p .25369 .465 L F P
0 g
s
.708 .242 .143 r
.25369 .465 m .25421 .46546 L .25076 .467 L p F P
0 g
s
.768 .346 .249 r
.215 .45166 m .21203 .44762 L .21866 .44965 L p F P
0 g
s
.768 .346 .249 r
.21905 .45291 m .215 .45166 L p .21866 .44965 L F P
0 g
s
.768 .346 .249 r
.21866 .44965 m .22049 .45212 L .21905 .45291 L p F P
0 g
s
.166 .705 .795 r
.45027 .35723 m .44479 .35779 L .44261 .35781 L p F P
0 g
s
.82 .681 .71 r
.13765 .35771 m .13355 .35569 L .13606 .36019 L closepath p F P
0 g
s
.129 .634 .903 r
.30176 .34991 m .30193 .34993 L .30162 .34986 L closepath p F P
0 g
s
.067 .622 .816 r
.36042 .35768 m .35985 .35758 L .3586 .35753 L closepath p F P
0 g
s
.112 .624 .893 r
.31138 .35077 m .31211 .35097 L .30193 .34993 L p F P
0 g
s
.112 .624 .893 r
.30488 .34956 m .31138 .35077 L p .30193 .34993 L F P
0 g
s
.112 .624 .893 r
.29843 .34865 m .30488 .34956 L p .30193 .34993 L F P
0 g
s
.112 .624 .893 r
.30193 .34993 m .30162 .34986 L .29843 .34865 L p F P
0 g
s
.66 .84 .969 r
.60112 .32916 m .60258 .33028 L .59156 .33407 L p F P
0 g
s
.66 .84 .969 r
.59156 .33407 m .5908 .33353 L .60112 .32916 L p F P
0 g
s
.023 .593 .77 r
.3566 .3572 m .34866 .35653 L .3586 .35753 L p F P
0 g
s
.023 .593 .77 r
.3586 .35753 m .35985 .35758 L .3566 .3572 L p F P
0 g
s
.172 .664 .92 r
.30162 .34986 m .29843 .34865 L .29385 .34831 L closepath p F P
0 g
s
.583 .524 .755 r
.66646 .34894 m .66863 .34878 L .66677 .3498 L closepath p F P
0 g
s
.573 .503 .738 r
.67885 .35214 m .66922 .35745 L .66677 .3498 L p F P
0 g
s
.573 .503 .738 r
.67775 .34853 m .67885 .35214 L p .66677 .3498 L F P
0 g
s
.573 .503 .738 r
.66677 .3498 m .66863 .34878 L .67775 .34853 L p F P
0 g
s
.606 .577 .795 r
.66078 .34214 m .66322 .34083 L .6636 .34169 L closepath p F P
0 g
s
.547 .463 .711 r
.68067 .35904 m .67885 .35214 L .66922 .35745 L p F P
0 g
s
.547 .463 .711 r
.68008 .35937 m .68067 .35904 L p .66922 .35745 L F P
0 g
s
.547 .463 .711 r
.66922 .35745 m .6694 .35811 L .68008 .35937 L p F P
0 g
s
.453 .743 .99 r
.22684 .33586 m .23709 .33537 L .24048 .33765 L p F P
0 g
s
.423 .733 .99 r
.23709 .33537 m .22684 .33586 L .22345 .33333 L p F P
0 g
s
.649 .681 .867 r
.63297 .33206 m .64408 .32884 L .64684 .33311 L p F P
0 g
s
.657 .711 .887 r
.64408 .32884 m .63297 .33206 L .63022 .3285 L p F P
0 g
s
.55 .451 .695 r
.6694 .35811 m .68008 .35937 L .67097 .36427 L closepath p F P
0 g
s
.593 .539 .763 r
.66863 .34878 m .66646 .34894 L .6636 .34169 L p F P
0 g
s
.398 0 0 r
.46599 .48675 m .45794 .48749 L .4562 .48888 L p F P
0 g
s
.602 .09 .005 r
.30065 .48169 m .30936 .48302 L .30333 .47983 L p F P
0 g
s
.602 .09 .005 r
.29817 .48037 m .30065 .48169 L p .30333 .47983 L F P
0 g
s
.602 .09 .005 r
.30333 .47983 m .30051 .4794 L .29817 .48037 L p F P
0 g
s
.696 .226 .13 r
.25421 .46546 m .25803 .46865 L .25076 .467 L closepath p F P
0 g
s
.823 .464 .377 r
.17604 .42834 m .18202 .43061 L .18043 .42619 L p F P
0 g
s
.823 .464 .377 r
.18043 .42619 m .17443 .42391 L .17604 .42834 L p F P
0 g
s
.855 .608 .565 r
.13847 .39043 m .1438 .39298 L .14444 .38789 L p F P
0 g
s
.855 .608 .565 r
.14444 .38789 m .13912 .38534 L .13847 .39043 L p F P
0 g
s
.328 .701 .982 r
.26437 .34049 m .26775 .34222 L .25947 .34193 L p F P
0 g
s
.328 .701 .982 r
.25412 .33979 m .26437 .34049 L p .25947 .34193 L F P
0 g
s
.328 .701 .982 r
.25947 .34193 m .25529 .3405 L .25412 .33979 L p F P
0 g
s
.527 .001 0 r
.34463 .48926 m .35487 .49011 L .34713 .4874 L p F P
0 g
s
.527 .001 0 r
.34256 .48852 m .34463 .48926 L p .34713 .4874 L F P
0 g
s
.527 .001 0 r
.34713 .4874 m .34531 .48725 L .34256 .48852 L p F P
0 g
s
.175 .711 .807 r
.45764 .35651 m .45644 .3565 L .45027 .35723 L closepath p F P
0 g
s
.166 .705 .795 r
.45339 .35675 m .45644 .3565 L .45027 .35723 L p F P
0 g
s
.166 .705 .795 r
.44261 .35781 m .45339 .35675 L p .45027 .35723 L F P
0 g
s
.791 .39 .292 r
.19899 .44346 m .19654 .43928 L .20287 .44142 L p F P
0 g
s
.791 .39 .292 r
.20152 .44432 m .19899 .44346 L p .20287 .44142 L F P
0 g
s
.791 .39 .292 r
.20287 .44142 m .20378 .44295 L .20152 .44432 L p F P
0 g
s
.434 .864 .932 r
.52253 .3456 m .5226 .34561 L .5117 .34854 L p F P
0 g
s
.434 .864 .932 r
.5117 .34854 m .51105 .34847 L .52253 .3456 L p F P
0 g
s
.509 .733 .975 r
.20979 .33175 m .21064 .33168 L .21613 .33421 L p F P
0 g
s
.526 .756 .981 r
.22004 .33084 m .21064 .33168 L .21613 .33421 L p F P
0 g
s
.526 .756 .981 r
.21613 .33421 m .22345 .33333 L .22004 .33084 L p F P
0 g
s
.847 .577 .53 r
.14472 .39844 m .14917 .4004 L .14932 .39546 L p F P
0 g
s
.847 .577 .53 r
.14932 .39546 m .14563 .39384 L .14472 .39844 L p F P
0 g
s
.38 0 .055 r
.53644 .47125 m .53616 .47161 L .5326 .47203 L closepath p F P
0 g
s
.383 0 .056 r
.5343 .47407 m .53616 .47161 L .5326 .47203 L p F P
0 g
s
.383 0 .056 r
.52249 .47646 m .5343 .47407 L p .5326 .47203 L F P
0 g
s
.655 .161 .063 r
.27049 .47386 m .27839 .47546 L .2734 .47198 L p F P
0 g
s
.655 .161 .063 r
.26761 .47186 m .27049 .47386 L p .2734 .47198 L F P
0 g
s
.655 .161 .063 r
.2734 .47198 m .26934 .47117 L .26761 .47186 L p F P
0 g
s
.852 .629 .599 r
.13385 .38276 m .13912 .38534 L .14029 .38008 L p F P
0 g
s
.852 .629 .599 r
.14029 .38008 m .13505 .37749 L .13385 .38276 L p F P
0 g
s
.834 .683 .696 r
.13415 .36372 m .13606 .36019 L .13355 .35569 L p F P
0 g
s
.442 .193 .439 r
.65399 .4076 m .65411 .40621 L .64393 .41069 L p F P
0 g
s
.442 .193 .439 r
.64956 .41245 m .65399 .4076 L p .64393 .41069 L F P
0 g
s
.442 .193 .439 r
.64393 .41069 m .64354 .41509 L .64956 .41245 L p F P
0 g
s
.551 .029 0 r
.34531 .48725 m .34256 .48852 L .33725 .48645 L closepath p F P
0 g
s
.372 0 .153 r
.58374 .45656 m .58537 .45334 L .57428 .45656 L p F P
0 g
s
.372 0 .153 r
.57428 .45656 m .57263 .45979 L .58374 .45656 L p F P
0 g
s
.649 .866 .981 r
.58878 .33208 m .57778 .33589 L .57499 .33432 L p F P
0 g
s
.638 .868 .985 r
.564 .33805 m .57499 .33432 L .57778 .33589 L p F P
0 g
s
.846 .554 .493 r
.14949 .4052 m .15512 .40763 L .1548 .40283 L p F P
0 g
s
.846 .554 .493 r
.1548 .40283 m .14917 .4004 L .14949 .4052 L p F P
0 g
s
.624 .118 .029 r
.30051 .4794 m .29817 .48037 L .29482 .47844 L closepath p F P
0 g
s
.167 0 0 r
.37037 .35836 m .35985 .35758 L .3566 .3572 L p F P
0 g
s
.773 .716 .8 r
.14408 .34148 m .14368 .34129 L .14393 .34161 L closepath p F P
0 g
s
.799 .717 .775 r
.13744 .34856 m .14393 .34161 L .14368 .34129 L p F P
0 g
s
.76 .735 .83 r
.14408 .34148 m .15464 .33351 L .15158 .33014 L p F P
0 g
s
.76 .735 .83 r
.14368 .34129 m .14408 .34148 L p .15158 .33014 L F P
0 g
s
.635 .652 .849 r
.64684 .33311 m .65019 .33227 L .64725 .33381 L closepath p F P
0 g
s
.623 .638 .844 r
.65799 .33037 m .65019 .33227 L .64725 .33381 L p F P
0 g
s
.623 .638 .844 r
.66078 .33565 m .65799 .33037 L p .64725 .33381 L F P
0 g
s
.193 .667 .935 r
.28329 .34562 m .28477 .34628 L p .27112 .34399 L F P
0 g
s
.193 .667 .935 r
.27112 .34399 m .279 .34462 L .28329 .34562 L p F P
0 g
s
.142 .633 .915 r
.279 .34462 m .27112 .34399 L .26775 .34222 L p F P
0 g
s
.848 .649 .633 r
.12985 .37487 m .13505 .37749 L .13683 .37203 L p F P
0 g
s
.848 .649 .633 r
.13683 .37203 m .13166 .36941 L .12985 .37487 L p F P
0 g
s
.381 0 0 r
.50806 .48121 m .50856 .48068 L .49767 .48121 L p F P
0 g
s
.381 0 0 r
.49767 .48121 m .49583 .48313 L .50806 .48121 L p F P
0 g
s
.411 .09 .307 r
.62034 .43538 m .62116 .43231 L .61016 .43759 L p F P
0 g
s
.411 .09 .307 r
.61016 .43759 m .60972 .43924 L .62034 .43538 L p F P
0 g
s
.517 0 0 r
.35961 .48892 m .36563 .4908 L .35697 .49027 L closepath p F P
0 g
s
.535 .42 .669 r
.68196 .36532 m .67228 .37057 L .67097 .36427 L p F P
0 g
s
.535 .42 .669 r
.68078 .35954 m .68196 .36532 L p .67097 .36427 L F P
0 g
s
.535 .42 .669 r
.67097 .36427 m .68008 .35937 L .68078 .35954 L p F P
0 g
s
.76 .735 .83 r
.14055 .33743 m .14368 .34129 L p .15158 .33014 L F P
0 g
s
.787 .723 .792 r
.14055 .33743 m .13913 .33875 L .14368 .34129 L closepath p F P
0 g
s
.799 .717 .775 r
.1323 .34589 m .13744 .34856 L p .14368 .34129 L F P
0 g
s
.799 .717 .775 r
.14368 .34129 m .13913 .33875 L .1323 .34589 L p F P
0 g
s
.399 0 0 r
.47079 .48628 m .47003 .4869 L .46599 .48675 L closepath p F P
0 g
s
.398 0 0 r
.46796 .4886 m .47003 .4869 L .46599 .48675 L p F P
0 g
s
.398 0 0 r
.46198 .48917 m .46796 .4886 L p .46599 .48675 L F P
0 g
s
.398 0 0 r
.4562 .48888 m .46198 .48917 L p .46599 .48675 L F P
0 g
s
.004 .572 .783 r
.35475 .35707 m .3566 .3572 L .34866 .35653 L p F P
0 g
s
.004 .572 .783 r
.35042 .35663 m .35475 .35707 L p .34866 .35653 L F P
0 g
s
.004 .572 .783 r
.34285 .3557 m .35042 .35663 L p .34866 .35653 L F P
0 g
s
.004 .572 .783 r
.34866 .35653 m .34477 .35605 L .34285 .3557 L p F P
0 g
s
.631 .754 .936 r
.18237 .33066 m .19269 .32784 L .1961 .33083 L p F P
0 g
s
.617 .753 .943 r
.19269 .32784 m .18237 .33066 L .17895 .32743 L p F P
0 g
s
.679 .751 .906 r
.16856 .33145 m .17895 .32743 L .18237 .33066 L p F P
0 g
s
.198 .726 .817 r
.46725 .35505 m .47016 .35485 L .45764 .35651 L p F P
0 g
s
.198 .726 .817 r
.45764 .35651 m .45644 .3565 L .46725 .35505 L p F P
0 g
s
.662 .841 .969 r
.59982 .32818 m .60112 .32916 L .5908 .33353 L p F P
0 g
s
.662 .841 .969 r
.5908 .33353 m .58878 .33208 L .59982 .32818 L p F P
0 g
s
.668 .752 .913 r
.17895 .32743 m .16856 .33145 L .16514 .32798 L p F P
0 g
s
.593 .539 .763 r
.67637 .34444 m .66863 .34878 L p .6636 .34169 L F P
0 g
s
.573 .508 .744 r
.66863 .34878 m .67637 .34444 L .67775 .34853 L closepath p F P
0 g
s
.643 .666 .857 r
.65019 .33227 m .64684 .33311 L .64408 .32884 L p F P
0 g
s
.844 .53 .457 r
.15585 .4123 m .16152 .41471 L .16079 .41003 L p F P
0 g
s
.844 .53 .457 r
.16079 .41003 m .15512 .40763 L .15585 .4123 L p F P
0 g
s
.341 .818 .882 r
.50878 .34823 m .4979 .35082 L .49495 .3507 L p F P
0 g
s
.319 .805 .878 r
.48408 .35295 m .49495 .3507 L .4979 .35082 L p F P
0 g
s
.359 0 .042 r
.54713 .46988 m .54804 .46864 L .53644 .47125 L p F P
0 g
s
.359 0 .042 r
.53644 .47125 m .53616 .47161 L .54713 .46988 L p F P
0 g
s
.593 .539 .763 r
.6636 .34169 m .67484 .34035 L .67637 .34444 L p F P
0 g
s
.594 .571 .797 r
.66322 .34083 m .6636 .34169 L .67484 .34035 L p F P
0 g
s
.595 .088 .018 r
.31522 .48272 m .31836 .48426 L .31334 .48361 L closepath p F P
0 g
s
.675 .188 .086 r
.26934 .47117 m .26761 .47186 L .2656 .47036 L closepath p F P
0 g
s
.619 .89 .989 r
.57218 .33304 m .57499 .33432 L .564 .33805 L p F P
0 g
s
.619 .89 .989 r
.56799 .33448 m .57218 .33304 L p .564 .33805 L F P
0 g
s
.619 .89 .989 r
.564 .33805 m .56141 .33693 L .56799 .33448 L p F P
0 g
s
.804 .418 .324 r
.18403 .43492 m .19027 .43711 L .18814 .43284 L p F P
0 g
s
.804 .418 .324 r
.18344 .43372 m .18403 .43492 L p .18814 .43284 L F P
0 g
s
.804 .418 .324 r
.18814 .43284 m .18592 .43206 L .18344 .43372 L p F P
0 g
s
.538 .009 0 r
.34154 .48899 m .34256 .48852 L .33725 .48645 L p F P
0 g
s
.538 .009 0 r
.33481 .48828 m .34154 .48899 L p .33725 .48645 L F P
0 g
s
.538 .009 0 r
.32886 .48596 m .33481 .48828 L p .33725 .48645 L F P
0 g
s
.538 .009 0 r
.33725 .48645 m .32958 .48566 L .32886 .48596 L p F P
0 g
s
.808 .694 .739 r
.12949 .34934 m .1323 .34589 L .13744 .34856 L p F P
0 g
s
.808 .694 .739 r
.13744 .34856 m .13281 .35448 L .12949 .34934 L p F P
0 g
s
.48 .297 .555 r
.6741 .38702 m .67378 .38187 L .66392 .38684 L p F P
0 g
s
.48 .297 .555 r
.66392 .38684 m .66423 .39199 L .6741 .38702 L p F P
0 g
s
0 .514 .757 r
.32138 .3527 m .31543 .35199 L .31211 .35097 L p F P
0 g
s
0 .551 .775 r
.32845 .35377 m .32913 .35392 L p .31543 .35199 L F P
0 g
s
0 .551 .775 r
.31543 .35199 m .32138 .3527 L .32845 .35377 L p F P
0 g
s
.594 .571 .797 r
.67484 .34035 m .67279 .33541 L .66322 .34083 L p F P
0 g
s
.609 .592 .809 r
.66078 .33565 m .66322 .34083 L .67279 .33541 L p F P
0 g
s
.423 .858 .928 r
.51971 .34538 m .52253 .3456 L .51105 .34847 L p F P
0 g
s
.423 .858 .928 r
.51105 .34847 m .50878 .34823 L .51971 .34538 L p F P
0 g
s
.522 .383 .633 r
.67069 .37139 m .67228 .37057 L .67256 .37227 L closepath p F P
0 g
s
.834 .683 .696 r
.12908 .36105 m .13415 .36372 L p .13355 .35569 L F P
0 g
s
.843 .668 .666 r
.12654 .36676 m .13166 .36941 L .13415 .36372 L p F P
0 g
s
.843 .668 .666 r
.13415 .36372 m .12908 .36105 L .12654 .36676 L p F P
0 g
s
.017 .582 .791 r
.34477 .35605 m .34285 .3557 L .33917 .35539 L closepath p F P
0 g
s
.73 .282 .187 r
.23731 .45945 m .23918 .46138 L .23539 .4604 L closepath p F P
0 g
s
.38 0 0 r
.48086 .48701 m .48342 .48482 L .47079 .48628 L p F P
0 g
s
.38 0 0 r
.47079 .48628 m .47003 .4869 L .48086 .48701 L p F P
0 g
s
.357 .72 .987 r
.24048 .33765 m .24597 .33776 L .2528 .33982 L p F P
0 g
s
.327 .698 .981 r
.24597 .33776 m .24048 .33765 L .23709 .33537 L p F P
0 g
s
.362 0 0 r
.52121 .47669 m .51049 .4786 L .50856 .48068 L p F P
0 g
s
.741 .292 .185 r
.22526 .45754 m .23212 .45949 L .22861 .4556 L p F P
0 g
s
.741 .292 .185 r
.22861 .4556 m .2217 .45367 L .22526 .45754 L p F P
0 g
s
.573 .755 .964 r
.20829 .33054 m .20979 .33175 L p .1961 .33083 L F P
0 g
s
.573 .755 .964 r
.1961 .33083 m .20459 .32933 L .20829 .33054 L p F P
0 g
s
.554 .748 .967 r
.20459 .32933 m .1961 .33083 L .19269 .32784 L p F P
0 g
s
.121 .625 .901 r
.28477 .34628 m .28642 .34647 L .29385 .34831 L p F P
0 g
s
.157 .659 .91 r
.29508 .34745 m .28642 .34647 L .29385 .34831 L p F P
0 g
s
.157 .659 .91 r
.29385 .34831 m .29843 .34865 L .29508 .34745 L p F P
0 g
s
.71 .241 .134 r
.24331 .46509 m .25049 .46693 L .24642 .46319 L p F P
0 g
s
.71 .241 .134 r
.24642 .46319 m .23918 .46138 L .24331 .46509 L p F P
0 g
s
.16 0 0 r
.38203 .35905 m .3736 .35857 L .37037 .35836 L p F P
0 g
s
.65 .162 .08 r
.28462 .47579 m .28647 .477 L .28326 .47642 L closepath p F P
0 g
s
.606 .888 .99 r
.56118 .33683 m .56141 .33693 L .55057 .34058 L p F P
0 g
s
.606 .888 .99 r
.55057 .34058 m .55021 .34044 L .56118 .33683 L p F P
0 g
s
.836 .499 .418 r
.16744 .41718 m .16729 .41735 L .16723 .4171 L closepath p F P
0 g
s
.783 .378 .283 r
.20378 .44295 m .20544 .44557 L .20152 .44432 L closepath p F P
0 g
s
.623 .117 .027 r
.29218 .48028 m .28647 .477 L .29482 .47844 L p F P
0 g
s
.623 .117 .027 r
.29652 .48104 m .29218 .48028 L p .29482 .47844 L F P
0 g
s
.623 .117 .027 r
.29482 .47844 m .29817 .48037 L .29652 .48104 L p F P
0 g
s
.409 .742 .993 r
.25529 .3405 m .25412 .33979 L .2528 .33982 L closepath p F P
0 g
s
.837 .5 .417 r
.16263 .41928 m .16152 .41471 L .16723 .4171 L p F P
0 g
s
.837 .5 .417 r
.16472 .42015 m .16263 .41928 L p .16723 .4171 L F P
0 g
s
.837 .5 .417 r
.16723 .4171 m .16729 .41735 L .16472 .42015 L p F P
0 g
s
.723 .731 .857 r
.15671 .33236 m .15158 .33014 L .15464 .33351 L closepath p F P
0 g
s
.358 0 .04 r
.54594 .47149 m .54713 .46988 L .53616 .47161 L p F P
0 g
s
.358 0 .04 r
.53616 .47161 m .5343 .47407 L .54594 .47149 L p F P
0 g
s
.825 .692 .717 r
.13281 .35448 m .13241 .35509 L .13355 .35569 L closepath p F P
0 g
s
.834 .683 .696 r
.13355 .35569 m .13241 .35509 L .12908 .36105 L p F P
0 g
s
.769 .342 .236 r
.20845 .44959 m .215 .45166 L .21203 .44762 L p F P
0 g
s
.769 .342 .236 r
.21203 .44762 m .20544 .44557 L .20845 .44959 L p F P
0 g
s
.278 .781 .841 r
.49451 .35073 m .49495 .3507 L .48408 .35295 L p F P
0 g
s
.278 .781 .841 r
.48408 .35295 m .48249 .35298 L .49451 .35073 L p F P
0 g
s
.247 .76 .836 r
.48249 .35298 m .48408 .35295 L p .47026 .35485 L F P
0 g
s
.832 .492 .412 r
.16729 .41735 m .16847 .42162 L .16472 .42015 L closepath p F P
0 g
s
.452 .225 .478 r
.65577 .40544 m .65411 .40621 L .65427 .40158 L p F P
0 g
s
.452 .225 .478 r
.65427 .40158 m .65918 .39929 L .65577 .40544 L p F P
0 g
s
.356 0 .096 r
.5719 .461 m .57263 .45979 L .56136 .46281 L p F P
0 g
s
.356 0 .096 r
.56136 .46281 m .56089 .46358 L .5719 .461 L p F P
0 g
s
.854 .585 .53 r
.14363 .39793 m .14472 .39844 L .14563 .39384 L p F P
0 g
s
.854 .585 .53 r
.14563 .39384 m .1438 .39298 L .14363 .39793 L p F P
0 g
s
.47 .264 .517 r
.6643 .39686 m .65918 .39929 L .66037 .39382 L p F P
0 g
s
.47 .264 .517 r
.66037 .39382 m .66423 .39199 L .6643 .39686 L p F P
0 g
s
.503 0 0 r
.37335 .49039 m .37682 .49135 L .37197 .49116 L closepath p F P
0 g
s
.759 .332 .238 r
.22049 .45212 m .2217 .45367 L .21905 .45291 L closepath p F P
0 g
s
.815 .435 .336 r
.18592 .43206 m .18344 .43372 L .18202 .43061 L closepath p F P
0 g
s
.404 0 .003 r
.48386 .48438 m .48684 .48437 L .48342 .48482 L closepath p F P
0 g
s
.675 .188 .084 r
.26274 .47221 m .25803 .46865 L .2656 .47036 L p F P
0 g
s
.675 .188 .084 r
.26525 .47278 m .26274 .47221 L p .2656 .47036 L F P
0 g
s
.675 .188 .084 r
.2656 .47036 m .26761 .47186 L .26525 .47278 L p F P
0 g
s
0 .529 .748 r
.32913 .35392 m .33023 .35406 L .33917 .35539 L p F P
0 g
s
0 .562 .758 r
.33956 .35522 m .33023 .35406 L .33917 .35539 L p F P
0 g
s
0 .562 .758 r
.33917 .35539 m .34285 .3557 L .33956 .35522 L p F P
0 g
s
.562 .038 0 r
.32958 .48566 m .32886 .48596 L .32759 .48542 L closepath p F P
0 g
s
.573 .9 .982 r
.56118 .33683 m .55021 .34044 L .54737 .33961 L p F P
0 g
s
.555 .894 .982 r
.53641 .34302 m .54737 .33961 L .55021 .34044 L p F P
0 g
s
.719 .732 .861 r
.15671 .33236 m .16514 .32798 L p .15123 .32976 L F P
0 g
s
.719 .732 .861 r
.15123 .32976 m .15158 .33014 L .15671 .33236 L p F P
0 g
s
.643 .666 .857 r
.65689 .32851 m .65019 .33227 L p .64408 .32884 L F P
0 g
s
.633 .654 .853 r
.65019 .33227 m .65689 .32851 L .65799 .33037 L closepath p F P
0 g
s
.504 .371 .632 r
.68289 .37118 m .68196 .36532 L .67228 .37057 L p F P
0 g
s
.504 .371 .632 r
.67638 .3747 m .68289 .37118 L p .67228 .37057 L F P
0 g
s
.504 .371 .632 r
.67228 .37057 m .67256 .37227 L .67638 .3747 L p F P
0 g
s
.825 .697 .723 r
.13241 .35509 m .13281 .35448 L .12949 .34934 L p F P
0 g
s
.043 0 0 r
.38737 .3592 m .39388 .35943 L .38499 .35918 L closepath p F P
0 g
s
.402 .743 .993 r
.25073 .3378 m .24597 .33776 L .2528 .33982 L p F P
0 g
s
.402 .743 .993 r
.2528 .33982 m .25412 .33979 L .25073 .3378 L p F P
0 g
s
.562 .037 0 r
.32519 .48723 m .31836 .48426 L .32759 .48542 L p F P
0 g
s
.562 .037 0 r
.32564 .48729 m .32519 .48723 L p .32759 .48542 L F P
0 g
s
.562 .037 0 r
.32759 .48542 m .32886 .48596 L .32564 .48729 L p F P
0 g
s
.151 .636 .92 r
.28477 .34628 m .28642 .34647 L .28329 .34562 L closepath p F P
0 g
s
.511 .731 .973 r
.20979 .33175 m .21064 .33168 L .20829 .33054 L closepath p F P
0 g
s
.825 .697 .723 r
.12949 .34934 m .12745 .35237 L .13241 .35509 L p F P
0 g
s
.835 .687 .699 r
.12404 .35836 m .12908 .36105 L .13241 .35509 L p F P
0 g
s
.835 .687 .699 r
.13241 .35509 m .12745 .35237 L .12404 .35836 L p F P
0 g
s
.2 .729 .788 r
.47026 .35485 m .47109 .3547 L .47016 .35485 L closepath p F P
0 g
s
.247 .76 .836 r
.47026 .35485 m .47109 .3547 L .48249 .35298 L p F P
0 g
s
.795 .39 .285 r
.19274 .44129 m .19899 .44346 L .19654 .43928 L p F P
0 g
s
.795 .39 .285 r
.19654 .43928 m .19027 .43711 L .19274 .44129 L p F P
0 g
s
.393 .073 .3 r
.62135 .4316 m .62116 .43231 L .62513 .43014 L closepath p F P
0 g
s
.824 .463 .372 r
.1701 .42603 m .17604 .42834 L .17443 .42391 L p F P
0 g
s
.824 .463 .372 r
.17443 .42391 m .16847 .42162 L .1701 .42603 L p F P
0 g
s
.38 .036 .251 r
.61916 .43898 m .62034 .43538 L .60972 .43924 L p F P
0 g
s
.38 .036 .251 r
.60972 .43924 m .60851 .44283 L .61916 .43898 L p F P
0 g
s
.195 .726 .783 r
.47109 .3547 m .47016 .35485 L .46725 .35505 L p F P
0 g
s
.51 .368 .624 r
.67256 .37227 m .67638 .3747 L .67318 .3764 L closepath p F P
0 g
s
0 .55 .782 r
.32913 .35392 m .33023 .35406 L .32845 .35377 L closepath p F P
0 g
s
.224 .745 .816 r
.48249 .35298 m .4811 .35301 L .47109 .3547 L closepath p F P
0 g
s
.195 .726 .783 r
.46725 .35505 m .47738 .35347 L p .47109 .3547 L F P
0 g
s
0 0 0 r
.46422 .35555 m .46453 .35551 L p .47738 .35347 L F P
0 g
s
.195 .726 .783 r
.4811 .35301 m .47109 .3547 L p .4782 .35335 L F P
0 g
s
.195 .726 .783 r
.47738 .35347 m .47821 .35335 L p .47109 .3547 L F P
0 g
s
0 0 0 r
.46453 .35551 m .47509 .35408 L p .4773 .35349 L F P
0 g
s
0 0 0 r
.47738 .35347 m .46453 .35551 L .4773 .35349 L F
.195 .726 .783 r
.47821 .35335 m .47821 .35335 L p .4782 .35335 L F P
0 g
s
.195 .726 .783 r
.47821 .35335 m .4811 .35301 L p .4782 .35335 L F P
0 g
s
.505 .729 .974 r
.21661 .32838 m .22004 .33084 L .21064 .33168 L p F P
0 g
s
.505 .729 .974 r
.20638 .32901 m .21661 .32838 L p .21064 .33168 L F P
0 g
s
.505 .729 .974 r
.21064 .33168 m .20829 .33054 L .20638 .32901 L p F P
0 g
s
.857 .61 .565 r
.13319 .38786 m .13847 .39043 L .13912 .38534 L p F P
0 g
s
.857 .61 .565 r
.13912 .38534 m .13385 .38276 L .13319 .38786 L p F P
0 g
s
.858 .588 .53 r
.13829 .39539 m .14363 .39793 L .1438 .39298 L p F P
0 g
s
.858 .588 .53 r
.1438 .39298 m .13847 .39043 L .13829 .39539 L p F P
0 g
s
.609 .592 .809 r
.67279 .33541 m .672 .33364 L .66078 .33565 L p F P
0 g
s
.622 .61 .817 r
.672 .33364 m .66078 .33565 L .65799 .33037 L p F P
0 g
s
.059 0 0 r
.41339 .35941 m .41497 .3593 L p .40116 .35945 L F P
0 g
s
.059 0 0 r
.40116 .35945 m .4067 .35949 L .41339 .35941 L p F P
0 g
s
.035 0 0 r
.40116 .35945 m .4067 .35949 L .3994 .35951 L closepath p F P
0 g
s
.488 0 0 r
.38711 .49139 m .38855 .49173 L .3866 .4917 L closepath p F P
0 g
s
0 0 0 r
.46725 .35505 m .45644 .3565 L .45339 .35675 L p F P
0 g
s
.406 .111 .348 r
.63262 .42355 m .63216 .42589 L .64019 .42044 L closepath p F P
0 g
s
.378 0 0 r
.48066 .48718 m .48086 .48701 L .47003 .4869 L p F P
0 g
s
.378 0 0 r
.47003 .4869 m .46796 .4886 L .48066 .48718 L p F P
0 g
s
.359 0 0 r
.48684 .48437 m .48342 .48482 L .48086 .48701 L p F P
0 g
s
.854 .631 .6 r
.12863 .38015 m .13385 .38276 L .13505 .37749 L p F P
0 g
s
.854 .631 .6 r
.13505 .37749 m .12985 .37487 L .12863 .38015 L p F P
0 g
s
.667 .754 .916 r
.61639 .32904 m .62747 .32535 L .63022 .3285 L p F P
0 g
s
.671 .784 .934 r
.62747 .32535 m .61639 .32904 L .61363 .32644 L p F P
0 g
s
.669 .795 .942 r
.60258 .33028 m .61363 .32644 L .61639 .32904 L p F P
0 g
s
.369 .002 .203 r
.60766 .44493 m .60851 .44283 L .59772 .44647 L p F P
0 g
s
.369 .002 .203 r
.59772 .44647 m .59661 .44918 L .60766 .44493 L p F P
0 g
s
.186 .653 .937 r
.26437 .34049 m .25412 .33979 L .25073 .3378 L p F P
0 g
s
.849 .554 .49 r
.14391 .40274 m .14949 .4052 L .14917 .4004 L p F P
0 g
s
.849 .554 .49 r
.14377 .4006 m .14391 .40274 L p .14917 .4004 L F P
0 g
s
.849 .554 .49 r
.14917 .4004 m .14472 .39844 L .14377 .4006 L p F P
0 g
s
.517 .894 .964 r
.54495 .33914 m .54737 .33961 L .53641 .34302 L p F P
0 g
s
.517 .894 .964 r
.53641 .34302 m .53385 .34252 L .54495 .33914 L p F P
0 g
s
.509 .886 .969 r
.53385 .34252 m .53641 .34302 L p .5226 .34561 L F P
0 g
s
.657 .711 .887 r
.63022 .3285 m .64133 .32505 L .64408 .32884 L p F P
0 g
s
.665 .741 .907 r
.64133 .32505 m .63022 .3285 L .62747 .32535 L p F P
0 g
s
.613 .096 0 r
.28394 .47879 m .29218 .48028 L .28647 .477 L p F P
0 g
s
.613 .096 0 r
.28112 .47716 m .28394 .47879 L p .28647 .477 L F P
0 g
s
.613 .096 0 r
.28647 .477 m .28326 .47642 L .28112 .47716 L p F P
0 g
s
.388 .019 .211 r
.59632 .4499 m .59661 .44918 L .58558 .45283 L p F P
0 g
s
.388 .019 .211 r
.58558 .45283 m .58537 .45334 L .59632 .4499 L p F P
0 g
s
.024 0 0 r
.427 .35891 m .42879 .35875 L p .41497 .3593 L F P
0 g
s
.013 0 0 r
.41497 .3593 m .42073 .35915 L .41339 .35941 L closepath p F P
0 g
s
.355 0 .093 r
.57078 .46282 m .5719 .461 L .56089 .46358 L p F P
0 g
s
.355 0 .093 r
.56089 .46358 m .55949 .46584 L .57078 .46282 L p F P
0 g
s
.071 .633 .708 r
.45318 .35679 m .45339 .35675 L .44261 .35781 L p F P
0 g
s
.071 .633 .708 r
.44261 .35781 m .44025 .35803 L .45318 .35679 L p F P
0 g
s
.667 .833 .963 r
.61114 .3244 m .61363 .32644 L .60258 .33028 L p F P
0 g
s
.667 .833 .963 r
.60258 .33028 m .60112 .32916 L .61114 .3244 L p F P
0 g
s
.545 .016 0 r
.32886 .48596 m .33481 .48828 L .32564 .48729 L closepath p F P
0 g
s
.392 .071 .298 r
.62513 .43014 m .62116 .43231 L .62034 .43538 L p F P
0 g
s
0 0 0 r
.42879 .35875 m .43642 .35828 L .427 .35891 L closepath p F P
0 g
s
.132 .626 .911 r
.29338 .34688 m .29508 .34745 L .28642 .34647 L p F P
0 g
s
.132 .626 .911 r
.28949 .34603 m .29338 .34688 L p .28642 .34647 L F P
0 g
s
.132 .626 .911 r
.28141 .34479 m .28949 .34603 L p .28642 .34647 L F P
0 g
s
.132 .626 .911 r
.28642 .34647 m .28329 .34562 L .28141 .34479 L p F P
0 g
s
.755 .723 .822 r
.15108 .32985 m .14055 .33743 L .13714 .33337 L p F P
0 g
s
.784 .725 .798 r
.13913 .33875 m .14055 .33743 L .13714 .33337 L p F P
0 g
s
.76 .735 .83 r
.15158 .33014 m .15108 .32985 L .14055 .33743 L p F P
0 g
s
.784 .725 .798 r
.13714 .33337 m .13423 .33598 L .13913 .33875 L p F P
0 g
s
.797 .719 .778 r
.12717 .34321 m .1323 .34589 L .13913 .33875 L p F P
0 g
s
.797 .719 .778 r
.13913 .33875 m .13423 .33598 L .12717 .34321 L p F P
0 g
s
.85 .652 .634 r
.12469 .37223 m .12985 .37487 L .13166 .36941 L p F P
0 g
s
.85 .652 .634 r
.13166 .36941 m .12654 .36676 L .12469 .37223 L p F P
0 g
s
0 .537 .768 r
.33875 .35514 m .33956 .35522 L .33023 .35406 L p F P
0 g
s
.183 0 0 r
.33242 .35464 m .32703 .35353 L p .33178 .3542 L F P
0 g
s
0 .537 .768 r
.32582 .35321 m .33178 .3542 L p .33023 .35406 L F P
0 g
s
0 .537 .768 r
.33023 .35406 m .32845 .35377 L .32582 .35321 L p F P
0 g
s
.183 0 0 r
.32703 .35353 m .32319 .35274 L .33178 .3542 L p F P
0 g
s
0 .537 .768 r
.33178 .3542 m .33875 .35514 L p .33576 .35476 L F P
0 g
s
0 .537 .768 r
.33023 .35406 m .33178 .3542 L .33576 .35476 L F
.704 .226 .111 r
.23617 .46323 m .24331 .46509 L .23918 .46138 L p F P
0 g
s
.704 .226 .111 r
.23369 .461 m .23617 .46323 L p .23918 .46138 L F P
0 g
s
.704 .226 .111 r
.23918 .46138 m .23539 .4604 L .23369 .461 L p F P
0 g
s
.359 0 0 r
.49583 .48313 m .49472 .48411 L .48684 .48437 L closepath p F P
0 g
s
.359 0 0 r
.49312 .4855 m .49472 .48411 L .48684 .48437 L p F P
0 g
s
.359 0 0 r
.48225 .48697 m .49312 .4855 L p .48684 .48437 L F P
0 g
s
.359 0 0 r
.48086 .48701 m .48225 .48697 L p .48684 .48437 L F P
0 g
s
.36 0 0 r
.52249 .47646 m .52238 .47658 L .52121 .47669 L closepath p F P
0 g
s
.362 0 0 r
.5201 .47907 m .52238 .47658 L .52121 .47669 L p F P
0 g
s
.362 0 0 r
.51339 .48028 m .5201 .47907 L p .52121 .47669 L F P
0 g
s
.362 0 0 r
.50856 .48068 m .51339 .48028 L p .52121 .47669 L F P
0 g
s
.738 .282 .168 r
.21844 .45556 m .22526 .45754 L .2217 .45367 L p F P
0 g
s
.738 .282 .168 r
.21681 .45377 m .21844 .45556 L p .2217 .45367 L F P
0 g
s
.738 .282 .168 r
.2217 .45367 m .21905 .45291 L .21681 .45377 L p F P
0 g
s
.846 .53 .454 r
.15024 .40987 m .15585 .4123 L .15512 .40763 L p F P
0 g
s
.846 .53 .454 r
.15512 .40763 m .14949 .4052 L .15024 .40987 L p F P
0 g
s
.815 .435 .335 r
.178 .43266 m .17604 .42834 L .18202 .43061 L p F P
0 g
s
.815 .435 .335 r
.18247 .43436 m .178 .43266 L p .18202 .43061 L F P
0 g
s
.815 .435 .335 r
.18202 .43061 m .18344 .43372 L .18247 .43436 L p F P
0 g
s
.473 0 0 r
.4009 .4919 m .40096 .49191 L .40088 .49191 L closepath p F P
0 g
s
.477 0 0 r
.4009 .4919 m .40096 .49191 L .41428 .49181 L p F P
0 g
s
.552 .018 0 r
.31609 .48602 m .32519 .48723 L .31836 .48426 L p F P
0 g
s
.552 .018 0 r
.3118 .48416 m .31609 .48602 L p .31836 .48426 L F P
0 g
s
.552 .018 0 r
.31836 .48426 m .31334 .48361 L .3118 .48416 L p F P
0 g
s
.4 0 0 r
.4562 .48888 m .46198 .48917 L .45505 .48979 L closepath p F P
0 g
s
.423 0 0 r
.40096 .49191 m .40088 .49191 L .3977 .49355 L p F P
0 g
s
.448 0 0 r
.40088 .49191 m .3977 .49355 L .38855 .49173 L closepath p F P
0 g
s
.423 0 0 r
.41142 .4937 m .41154 .49364 L .40096 .49191 L p F P
0 g
s
.423 0 0 r
.39878 .49374 m .41142 .4937 L p .40096 .49191 L F P
0 g
s
.423 0 0 r
.3977 .49355 m .39878 .49374 L p .40096 .49191 L F P
0 g
s
.427 0 0 r
.41154 .49364 m .40096 .49191 L .41428 .49181 L p F P
0 g
s
.423 .733 .99 r
.22345 .33333 m .23368 .33313 L .23709 .33537 L p F P
0 g
s
.377 .72 .988 r
.23368 .33313 m .22345 .33333 L .22004 .33084 L p F P
0 g
s
0 .561 .787 r
.32845 .35377 m .32582 .35321 L .32138 .3527 L closepath p F P
0 g
s
.428 0 0 r
.41484 .4918 m .41471 .49187 L .41428 .49181 L closepath p F P
0 g
s
.427 0 0 r
.41428 .49181 m .41471 .49187 L .41154 .49364 L p F P
0 g
s
.408 0 0 r
.4254 .49324 m .42852 .49141 L .41484 .4918 L p F P
0 g
s
.408 0 0 r
.41484 .4918 m .41471 .49187 L .4254 .49324 L p F P
0 g
s
.643 .666 .857 r
.64408 .32884 m .65523 .32578 L .65689 .32851 L p F P
0 g
s
.652 .695 .877 r
.65523 .32578 m .64408 .32884 L .64133 .32505 L p F P
0 g
s
.337 0 0 r
.53333 .47516 m .5343 .47407 L .52249 .47646 L p F P
0 g
s
.337 0 0 r
.52249 .47646 m .52238 .47658 L .53333 .47516 L p F P
0 g
s
.417 .146 .393 r
.64354 .41509 m .64312 .41812 L .64956 .41245 L closepath p F P
0 g
s
.636 .127 .02 r
.28326 .47642 m .28112 .47716 L .27839 .47546 L closepath p F P
0 g
s
.439 0 0 r
.39734 .49374 m .3977 .49355 L .38855 .49173 L p F P
0 g
s
.439 0 0 r
.38644 .49353 m .39734 .49374 L p .38855 .49173 L F P
0 g
s
.439 0 0 r
.38387 .493 m .38644 .49353 L p .38855 .49173 L F P
0 g
s
.439 0 0 r
.38855 .49173 m .3866 .4917 L .38387 .493 L p F P
0 g
s
.659 .861 .976 r
.59982 .32818 m .58878 .33208 L .586 .33044 L p F P
0 g
s
.649 .866 .981 r
.57499 .33432 m .586 .33044 L .58878 .33208 L p F P
0 g
s
.464 0 0 r
.3866 .4917 m .38387 .493 L .37682 .49135 L closepath p F P
0 g
s
.457 .254 .515 r
.67418 .3919 m .6741 .38702 L .66423 .39199 L p F P
0 g
s
.457 .254 .515 r
.66423 .39199 m .6643 .39686 L .67418 .3919 L p F P
0 g
s
.35 0 .142 r
.59471 .45312 m .59632 .4499 L .58537 .45334 L p F P
0 g
s
.35 0 .142 r
.58537 .45334 m .58374 .45656 L .59471 .45312 L p F P
0 g
s
.665 .165 .049 r
.25526 .47047 m .26274 .47221 L .25803 .46865 L p F P
0 g
s
.665 .165 .049 r
.25063 .46704 m .25526 .47047 L p .25803 .46865 L F P
0 g
s
.665 .165 .049 r
.25803 .46865 m .25076 .467 L .25063 .46704 L p F P
0 g
s
.338 0 .034 r
.55814 .46771 m .55949 .46584 L .54804 .46864 L p F P
0 g
s
.338 0 .034 r
.54804 .46864 m .54713 .46988 L .55814 .46771 L p F P
0 g
s
.662 .169 .069 r
.26761 .47186 m .27049 .47386 L .26525 .47278 L closepath p F P
0 g
s
.808 .701 .747 r
.12615 .34442 m .12717 .34321 L .1323 .34589 L p F P
0 g
s
.808 .701 .747 r
.1323 .34589 m .12949 .34934 L .12615 .34442 L p F P
0 g
s
.576 .755 .963 r
.20829 .33054 m .20638 .32901 L .20459 .32933 L closepath p F P
0 g
s
.767 .332 .218 r
.20194 .4475 m .20845 .44959 L .20544 .44557 L p F P
0 g
s
.767 .332 .218 r
.20003 .44494 m .20194 .4475 L p .20544 .44557 L F P
0 g
s
.767 .332 .218 r
.20544 .44557 m .20152 .44432 L .20003 .44494 L p F P
0 g
s
.416 0 0 r
.4254 .49324 m .41471 .49187 L .41154 .49364 L p F P
0 g
s
.419 0 0 r
.44236 .49038 m .44438 .49056 L .44191 .49073 L closepath p F P
0 g
s
.336 0 0 r
.53195 .47671 m .53333 .47516 L .52238 .47658 L p F P
0 g
s
.336 0 0 r
.52238 .47658 m .5201 .47907 L .53195 .47671 L p F P
0 g
s
.392 .071 .298 r
.63083 .43131 m .63183 .42754 L .62513 .43014 L p F P
0 g
s
.392 .071 .298 r
.62034 .43538 m .63083 .43131 L p .62513 .43014 L F P
0 g
s
.42 .122 .352 r
.63216 .42589 m .62513 .43014 L .63183 .42754 L closepath p F P
0 g
s
0 .509 .77 r
.30488 .34956 m .29843 .34865 L .29508 .34745 L p F P
0 g
s
.509 .886 .969 r
.5226 .34561 m .52505 .3449 L .53385 .34252 L p F P
0 g
s
.441 .87 .924 r
.5226 .34561 m .52505 .3449 L .52253 .3456 L closepath p F P
0 g
s
.668 .752 .913 r
.16514 .32798 m .17552 .32424 L .17895 .32743 L p F P
0 g
s
.658 .752 .919 r
.17552 .32424 m .16514 .32798 L .16171 .32456 L p F P
0 g
s
.719 .732 .861 r
.16514 .32798 m .16171 .32456 L .15123 .32976 L p F P
0 g
s
.491 .33 .59 r
.6795 .37883 m .67378 .38187 L .67318 .3764 L p F P
0 g
s
.491 .33 .59 r
.67318 .3764 m .67638 .3747 L .6795 .37883 L p F P
0 g
s
.844 .671 .668 r
.12146 .36408 m .12654 .36676 L .12908 .36105 L p F P
0 g
s
.844 .671 .668 r
.12908 .36105 m .12404 .35836 L .12146 .36408 L p F P
0 g
s
.438 0 0 r
.42853 .49139 m .4286 .4914 L .42852 .49141 L closepath p F P
0 g
s
.842 .505 .416 r
.15698 .41687 m .16263 .41928 L .16152 .41471 L p F P
0 g
s
.842 .505 .416 r
.16152 .41471 m .15585 .4123 L .15698 .41687 L p F P
0 g
s
.388 0 0 r
.4286 .4914 m .42852 .49141 L .4254 .49324 L p F P
0 g
s
.196 0 0 r
.35042 .35663 m .34285 .3557 L .33956 .35522 L p F P
0 g
s
.393 0 0 r
.44191 .49073 m .43926 .49237 L .4286 .4914 L closepath p F P
0 g
s
.388 0 0 r
.43867 .49274 m .43926 .49237 L .4286 .4914 L p F P
0 g
s
.388 0 0 r
.4262 .49332 m .43867 .49274 L p .4286 .4914 L F P
0 g
s
.388 0 0 r
.4254 .49324 m .4262 .49332 L p .4286 .4914 L F P
0 g
s
.21 .676 .942 r
.28329 .34562 m .28141 .34479 L .279 .34462 L closepath p F P
0 g
s
.454 0 0 r
.38293 .49345 m .38387 .493 L .37682 .49135 L p F P
0 g
s
.454 0 0 r
.37477 .49311 m .38293 .49345 L p .37682 .49135 L F P
0 g
s
.454 0 0 r
.37007 .49199 m .37477 .49311 L p .37682 .49135 L F P
0 g
s
.454 0 0 r
.37682 .49135 m .37197 .49116 L .37007 .49199 L p F P
0 g
s
.617 .753 .943 r
.17895 .32743 m .18926 .32488 L .19269 .32784 L p F P
0 g
s
.603 .751 .949 r
.18926 .32488 m .17895 .32743 L .17552 .32424 L p F P
0 g
s
.439 .869 .923 r
.52505 .3449 m .52253 .3456 L .51971 .34538 L p F P
0 g
s
.447 .22 .475 r
.66413 .40148 m .65577 .40544 L .65918 .39929 L p F P
0 g
s
.447 .22 .475 r
.65918 .39929 m .6643 .39686 L .66413 .40148 L p F P
0 g
s
.576 .049 0 r
.31334 .48361 m .3118 .48416 L .30936 .48302 L closepath p F P
0 g
s
.754 .307 .189 r
.21905 .45291 m .21681 .45377 L .215 .45166 L closepath p F P
0 g
s
.749 .738 .842 r
.15123 .32976 m .15108 .32985 L .15158 .33014 L closepath p F P
0 g
s
.608 .097 .011 r
.29817 .48037 m .30065 .48169 L .29652 .48104 L closepath p F P
0 g
s
.327 .698 .981 r
.23709 .33537 m .23965 .33551 L .24597 .33776 L p F P
0 g
s
.358 .725 .987 r
.24732 .33586 m .23965 .33551 L .24597 .33776 L p F P
0 g
s
.358 .725 .987 r
.24597 .33776 m .25073 .3378 L .24732 .33586 L p F P
0 g
s
.479 0 0 r
.37197 .49116 m .37007 .49199 L .36563 .4908 L closepath p F P
0 g
s
.824 .701 .728 r
.12745 .35237 m .12949 .34934 L .12615 .34442 L p F P
0 g
s
.723 .253 .134 r
.23539 .4604 m .23369 .461 L .23212 .45949 L closepath p F P
0 g
s
.256 .766 .83 r
.49199 .35092 m .49451 .35073 L .48249 .35298 L p F P
0 g
s
.256 .766 .83 r
.48249 .35298 m .4811 .35301 L .49199 .35092 L p F P
0 g
s
.637 .887 .986 r
.586 .33044 m .57499 .33432 L .57218 .33304 L p F P
0 g
s
.745 .74 .848 r
.15108 .32985 m .15123 .32976 L .14779 .3261 L p F P
0 g
s
.745 .74 .848 r
.14779 .3261 m .14633 .32703 L .15108 .32985 L p F P
0 g
s
.755 .723 .822 r
.13714 .33337 m .14633 .32703 L .15108 .32985 L p F P
0 g
s
.705 .749 .886 r
.16171 .32456 m .15123 .32976 L .14779 .3261 L p F P
0 g
s
.142 .633 .915 r
.26775 .34222 m .27176 .3427 L .279 .34462 L p F P
0 g
s
.107 .603 .903 r
.27176 .3427 m .26775 .34222 L .26437 .34049 L p F P
0 g
s
.795 .386 .276 r
.18654 .43909 m .19274 .44129 L .19027 .43711 L p F P
0 g
s
.795 .386 .276 r
.19027 .43711 m .18403 .43492 L .18654 .43909 L p F P
0 g
s
0 .514 .757 r
.31211 .35097 m .31313 .35113 L .32138 .3527 L p F P
0 g
s
0 .547 .764 r
.3225 .35259 m .31313 .35113 L .32138 .3527 L p F P
0 g
s
0 .547 .764 r
.32138 .3527 m .32582 .35321 L .3225 .35259 L p F P
0 g
s
.636 .126 .018 r
.27589 .47723 m .27049 .47386 L .27839 .47546 L p F P
0 g
s
.636 .126 .018 r
.27902 .47787 m .27589 .47723 L p .27839 .47546 L F P
0 g
s
.636 .126 .018 r
.27839 .47546 m .28112 .47716 L .27902 .47787 L p F P
0 g
s
.338 0 0 r
.50563 .48341 m .50806 .48121 L .49583 .48313 L p F P
0 g
s
.338 0 0 r
.49583 .48313 m .49472 .48411 L .50563 .48341 L p F P
0 g
s
.468 0 0 r
.36817 .49282 m .37007 .49199 L .36563 .4908 L p F P
0 g
s
.468 0 0 r
.36362 .49254 m .36817 .49282 L p .36563 .4908 L F P
0 g
s
.468 0 0 r
.3563 .49054 m .36362 .49254 L p .36563 .4908 L F P
0 g
s
.468 0 0 r
.36563 .4908 m .35697 .49027 L .3563 .49054 L p F P
0 g
s
.554 .748 .967 r
.19269 .32784 m .19851 .32698 L .20459 .32933 L p F P
0 g
s
.536 .738 .969 r
.19851 .32698 m .19269 .32784 L .18926 .32488 L p F P
0 g
s
.369 0 0 r
.44438 .49056 m .44191 .49073 L .43926 .49237 L p F P
0 g
s
.576 .048 0 r
.30712 .48476 m .30065 .48169 L .30936 .48302 L p F P
0 g
s
.576 .048 0 r
.30919 .48508 m .30712 .48476 L p .30936 .48302 L F P
0 g
s
.576 .048 0 r
.30936 .48302 m .3118 .48416 L .30919 .48508 L p F P
0 g
s
.492 .883 .961 r
.53385 .34252 m .53355 .34246 L .52505 .3449 L closepath p F P
0 g
s
.439 .869 .923 r
.53067 .34227 m .53355 .34246 L .52505 .3449 L p F P
0 g
s
.439 .869 .923 r
.51971 .34538 m .53067 .34227 L p .52505 .3449 L F P
0 g
s
.826 .46 .362 r
.16421 .42371 m .1701 .42603 L .16847 .42162 L p F P
0 g
s
.826 .46 .362 r
.16329 .42119 m .16421 .42371 L p .16847 .42162 L F P
0 g
s
.826 .46 .362 r
.16847 .42162 m .16472 .42015 L .16329 .42119 L p F P
0 g
s
.622 .61 .817 r
.65799 .33037 m .6692 .32795 L .672 .33364 L p F P
0 g
s
.624 .65 .856 r
.65689 .32851 m .65799 .33037 L .6692 .32795 L p F P
0 g
s
.426 .178 .433 r
.65411 .40621 m .65399 .4076 L .65577 .40544 L closepath p F P
0 g
s
.533 .007 0 r
.34256 .48852 m .34463 .48926 L .34154 .48899 L closepath p F P
0 g
s
.369 0 0 r
.45189 .49184 m .45313 .49104 L .44438 .49056 L p F P
0 g
s
.369 0 0 r
.44183 .49254 m .45189 .49184 L p .44438 .49056 L F P
0 g
s
.369 0 0 r
.43926 .49237 m .44183 .49254 L p .44438 .49056 L F P
0 g
s
.373 0 0 r
.45505 .48979 m .45313 .49104 L .44438 .49056 L closepath p F P
0 g
s
.357 .829 .877 r
.51791 .34542 m .51971 .34538 L .50878 .34823 L p F P
0 g
s
.357 .829 .877 r
.50878 .34823 m .50631 .34821 L .51791 .34542 L p F P
0 g
s
.341 .818 .882 r
.50631 .34821 m .50878 .34823 L p .49495 .3507 L F P
0 g
s
.856 .564 .493 r
.14472 .39844 m .14377 .4006 L .14363 .39793 L closepath p F P
0 g
s
.824 .701 .728 r
.12615 .34442 m .12252 .34962 L .12745 .35237 L p F P
0 g
s
.836 .69 .701 r
.11905 .35564 m .12404 .35836 L .12745 .35237 L p F P
0 g
s
.836 .69 .701 r
.12745 .35237 m .12252 .34962 L .11905 .35564 L p F P
0 g
s
.575 .758 .965 r
.20295 .32631 m .19851 .32698 L .20459 .32933 L p F P
0 g
s
.575 .758 .965 r
.20459 .32933 m .20638 .32901 L .20295 .32631 L p F P
0 g
s
.335 0 .086 r
.58293 .45791 m .58374 .45656 L .57263 .45979 L p F P
0 g
s
.335 0 .086 r
.57263 .45979 m .5719 .461 L .58293 .45791 L p F P
0 g
s
.405 .109 .347 r
.64019 .42044 m .63216 .42589 L .63183 .42754 L p F P
0 g
s
.295 .676 .974 r
.23965 .33551 m .23709 .33537 L .23368 .33313 L p F P
0 g
s
.196 .672 .935 r
.27803 .34339 m .27176 .3427 L .279 .34462 L p F P
0 g
s
.196 .672 .935 r
.279 .34462 m .28141 .34479 L .27803 .34339 L p F P
0 g
s
.619 .891 .989 r
.56141 .33693 m .56118 .33683 L .56799 .33448 L closepath p F P
0 g
s
.559 .483 .727 r
.67775 .34853 m .68455 .34884 L .67885 .35214 L closepath p F P
0 g
s
.557 .498 .746 r
.67637 .34444 m .67775 .34853 L .68455 .34884 L p F P
0 g
s
.781 .354 .237 r
.20152 .44432 m .20003 .44494 L .19899 .44346 L closepath p F P
0 g
s
.668 .834 .963 r
.61088 .32419 m .61114 .3244 L .60112 .32916 L p F P
0 g
s
.668 .834 .963 r
.60112 .32916 m .59982 .32818 L .61088 .32419 L p F P
0 g
s
.545 .456 .704 r
.69018 .3535 m .68067 .35904 L .67885 .35214 L p F P
0 g
s
.545 .456 .704 r
.68915 .34945 m .69018 .3535 L p .67885 .35214 L F P
0 g
s
.545 .456 .704 r
.67885 .35214 m .68455 .34884 L .68915 .34945 L p F P
0 g
s
.494 0 0 r
.35697 .49027 m .3563 .49054 L .35487 .49011 L closepath p F P
0 g
s
.167 0 0 r
.37011 .35836 m .37037 .35836 L p .3566 .3572 L F P
0 g
s
.167 0 0 r
.3566 .3572 m .36037 .35763 L .37011 .35836 L p F P
0 g
s
.111 0 0 r
.3566 .3572 m .36037 .35763 L .35475 .35707 L closepath p F P
0 g
s
.58 .531 .765 r
.67484 .34035 m .68439 .33975 L .67637 .34444 L closepath p F P
0 g
s
.557 .498 .746 r
.68617 .33972 m .68439 .33975 L .67637 .34444 L p F P
0 g
s
.557 .498 .746 r
.68836 .34659 m .68617 .33972 L p .67637 .34444 L F P
0 g
s
.557 .498 .746 r
.68455 .34884 m .68836 .34659 L p .67637 .34444 L F P
0 g
s
.86 .59 .529 r
.133 .39281 m .13829 .39539 L .13847 .39043 L p F P
0 g
s
.86 .59 .529 r
.13847 .39043 m .13319 .38786 L .133 .39281 L p F P
0 g
s
.859 .613 .565 r
.12796 .38526 m .13319 .38786 L .13385 .38276 L p F P
0 g
s
.859 .613 .565 r
.13385 .38276 m .12863 .38015 L .12796 .38526 L p F P
0 g
s
.723 .253 .132 r
.22914 .46133 m .22526 .45754 L .23212 .45949 L p F P
0 g
s
.723 .253 .132 r
.23109 .46189 m .22914 .46133 L p .23212 .45949 L F P
0 g
s
.723 .253 .132 r
.23212 .45949 m .23369 .461 L .23109 .46189 L p F P
0 g
s
.493 0 0 r
.3529 .49183 m .34463 .48926 L .35487 .49011 L p F P
0 g
s
.493 0 0 r
.35302 .49184 m .3529 .49183 L p .35487 .49011 L F P
0 g
s
.493 0 0 r
.35487 .49011 m .3563 .49054 L .35302 .49184 L p F P
0 g
s
.586 .905 .982 r
.56799 .33448 m .56118 .33683 L .55836 .33598 L p F P
0 g
s
.573 .9 .982 r
.54737 .33961 m .55836 .33598 L .56118 .33683 L p F P
0 g
s
.857 .565 .493 r
.13854 .40021 m .13829 .39539 L .14363 .39793 L p F P
0 g
s
.857 .565 .493 r
.14301 .40233 m .13854 .40021 L p .14363 .39793 L F P
0 g
s
.857 .565 .493 r
.14363 .39793 m .14377 .4006 L .14301 .40233 L p F P
0 g
s
.755 .306 .187 r
.21179 .45353 m .20845 .44959 L .215 .45166 L p F P
0 g
s
.755 .306 .187 r
.21485 .4545 m .21179 .45353 L p .215 .45166 L F P
0 g
s
.755 .306 .187 r
.215 .45166 m .21681 .45377 L .21485 .4545 L p F P
0 g
s
.685 .194 .074 r
.25076 .467 m .25063 .46704 L .25049 .46693 L closepath p F P
0 g
s
.856 .634 .6 r
.12346 .37752 m .12863 .38015 L .12985 .37487 L p F P
0 g
s
.856 .634 .6 r
.12985 .37487 m .12469 .37223 L .12346 .37752 L p F P
0 g
s
.046 0 0 r
.4067 .35949 m .3994 .35951 L .39799 .35958 L p F P
0 g
s
.082 0 0 r
.3994 .35951 m .39799 .35958 L .39388 .35943 L closepath p F P
0 g
s
.067 0 0 r
.41339 .35941 m .41182 .35953 L .4067 .35949 L closepath p F P
0 g
s
.046 0 0 r
.40901 .35996 m .41182 .35953 L .4067 .35949 L p F P
0 g
s
.046 0 0 r
.40752 .35997 m .40901 .35996 L p .4067 .35949 L F P
0 g
s
.046 0 0 r
.39799 .35958 m .40752 .35997 L p .4067 .35949 L F P
0 g
s
.685 .192 .07 r
.24705 .46813 m .24331 .46509 L .25049 .46693 L p F P
0 g
s
.685 .192 .07 r
.25049 .46693 m .25063 .46704 L .24705 .46813 L p F P
0 g
s
.362 0 0 r
.50856 .48068 m .51339 .48028 L .50806 .48121 L closepath p F P
0 g
s
0 .533 .788 r
.31211 .35097 m .31313 .35113 L .31138 .35077 L closepath p F P
0 g
s
.055 0 0 r
.39485 .35993 m .39799 .35958 L .39388 .35943 L p F P
0 g
s
.055 0 0 r
.39462 .35992 m .39485 .35993 L p .39388 .35943 L F P
0 g
s
.055 0 0 r
.38417 .35918 m .39462 .35992 L p .39388 .35943 L F P
0 g
s
.055 0 0 r
.39388 .35943 m .38499 .35918 L .38417 .35918 L p F P
0 g
s
.022 0 0 r
.42073 .35915 m .41339 .35941 L .41182 .35953 L p F P
0 g
s
.424 .176 .432 r
.66376 .40587 m .66413 .40148 L .65577 .40544 L p F P
0 g
s
.424 .176 .432 r
.65373 .4106 m .66376 .40587 L p .65577 .40544 L F P
0 g
s
.424 .176 .432 r
.65577 .40544 m .65399 .4076 L .65373 .4106 L p F P
0 g
s
.534 .422 .673 r
.68008 .35937 m .68067 .35904 L .68078 .35954 L closepath p F P
0 g
s
.579 .551 .787 r
.67279 .33541 m .67484 .34035 L .68439 .33975 L p F P
0 g
s
.488 .329 .592 r
.68351 .37666 m .6795 .37883 L .67638 .3747 L p F P
0 g
s
.488 .329 .592 r
.67638 .3747 m .68289 .37118 L .68351 .37666 L p F P
0 g
s
.677 .182 .066 r
.25526 .47047 m .25063 .46704 L .24705 .46813 L p F P
0 g
s
.349 0 0 r
.46198 .48917 m .45505 .48979 L .45313 .49104 L p F P
0 g
s
.452 .731 .987 r
.21661 .32838 m .20638 .32901 L .20295 .32631 L p F P
0 g
s
.819 .434 .326 r
.17209 .43035 m .178 .43266 L .17604 .42834 L p F P
0 g
s
.819 .434 .326 r
.17604 .42834 m .1701 .42603 L .17209 .43035 L p F P
0 g
s
.636 .663 .86 r
.65523 .32578 m .65689 .32851 L .66651 .3231 L p F P
0 g
s
.624 .65 .856 r
.6692 .32795 m .66651 .3231 L .65689 .32851 L p F P
0 g
s
.081 0 0 r
.38499 .35918 m .38417 .35918 L .38203 .35905 L closepath p F P
0 g
s
.341 .818 .882 r
.49495 .3507 m .50051 .34942 L .50631 .34821 L p F P
0 g
s
.271 .777 .815 r
.49495 .3507 m .50051 .34942 L .49451 .35073 L closepath p F P
0 g
s
.036 0 0 r
.427 .35891 m .42567 .35904 L .42073 .35915 L closepath p F P
0 g
s
.022 0 0 r
.42276 .35955 m .42567 .35904 L .42073 .35915 L p F P
0 g
s
.022 0 0 r
.42173 .35959 m .42276 .35955 L p .42073 .35915 L F P
0 g
s
.022 0 0 r
.41182 .35953 m .42173 .35959 L p .42073 .35915 L F P
0 g
s
.848 .531 .45 r
.14467 .40741 m .15024 .40987 L .14949 .4052 L p F P
0 g
s
.848 .531 .45 r
.14949 .4052 m .14391 .40274 L .14467 .40741 L p F P
0 g
s
.438 .187 .435 r
.65399 .4076 m .64956 .41245 L .65373 .4106 L closepath p F P
0 g
s
.809 .424 .327 r
.18344 .43372 m .18403 .43492 L .18247 .43436 L closepath p F P
0 g
s
.852 .655 .635 r
.11958 .36957 m .12469 .37223 L .12654 .36676 L p F P
0 g
s
.852 .655 .635 r
.12654 .36676 m .12146 .36408 L .11958 .36957 L p F P
0 g
s
.337 0 .031 r
.55742 .46869 m .55814 .46771 L .54713 .46988 L p F P
0 g
s
.337 0 .031 r
.54713 .46988 m .54594 .47149 L .55742 .46869 L p F P
0 g
s
.16 0 0 r
.37037 .35836 m .37097 .35842 L .38203 .35905 L p F P
0 g
s
.124 0 0 r
.38094 .35939 m .37097 .35842 L .38203 .35905 L p F P
0 g
s
.124 0 0 r
.38203 .35905 m .38417 .35918 L .38094 .35939 L p F P
0 g
s
.515 .41 .673 r
.69151 .35984 m .69018 .3535 L .68067 .35904 L p F P
0 g
s
.515 .41 .673 r
.68763 .36209 m .69151 .35984 L p .68067 .35904 L F P
0 g
s
.515 .41 .673 r
.68067 .35904 m .68078 .35954 L .68763 .36209 L p F P
0 g
s
.43 .156 .395 r
.64312 .41812 m .64019 .42044 L .64296 .41928 L closepath p F P
0 g
s
.405 .109 .347 r
.64216 .42325 m .64296 .41928 L .64019 .42044 L p F P
0 g
s
.405 .109 .347 r
.63183 .42754 m .64216 .42325 L p .64019 .42044 L F P
0 g
s
.795 .722 .783 r
.12414 .3416 m .12717 .34321 L .13423 .33598 L p F P
0 g
s
.795 .722 .783 r
.12277 .33976 m .12414 .3416 L p .13423 .33598 L F P
0 g
s
.795 .722 .783 r
.13423 .33598 m .12936 .3332 L .12277 .33976 L p F P
0 g
s
.781 .728 .803 r
.13423 .33598 m .13714 .33337 L .13371 .32941 L p F P
0 g
s
.781 .728 .803 r
.13371 .32941 m .12936 .3332 L .13423 .33598 L p F P
0 g
s
.781 .354 .235 r
.19555 .44537 m .19274 .44129 L .19899 .44346 L p F P
0 g
s
.781 .354 .235 r
.1974 .44602 m .19555 .44537 L p .19899 .44346 L F P
0 g
s
.781 .354 .235 r
.19899 .44346 m .20003 .44494 L .1974 .44602 L p F P
0 g
s
.751 .727 .83 r
.14633 .32703 m .13714 .33337 L .13371 .32941 L p F P
0 g
s
.52 .404 .661 r
.68078 .35954 m .68763 .36209 L .68196 .36532 L closepath p F P
0 g
s
0 0 0 r
.43642 .35828 m .427 .35891 L .42567 .35904 L p F P
0 g
s
.316 0 0 r
.54432 .47334 m .54594 .47149 L .5343 .47407 L p F P
0 g
s
.316 0 0 r
.5343 .47407 m .53333 .47516 L .54432 .47334 L p F P
0 g
s
.564 .026 0 r
.29853 .48338 m .30712 .48476 L .30065 .48169 L p F P
0 g
s
.564 .026 0 r
.29472 .48158 m .29853 .48338 L p .30065 .48169 L F P
0 g
s
.564 .026 0 r
.30065 .48169 m .29652 .48104 L .29472 .48158 L p F P
0 g
s
.469 .288 .553 r
.68054 .38361 m .6741 .38702 L .67378 .38187 L p F P
0 g
s
.469 .288 .553 r
.67378 .38187 m .6795 .37883 L .68054 .38361 L p F P
0 g
s
.415 .144 .391 r
.64956 .41245 m .64312 .41812 L .64296 .41928 L p F P
0 g
s
0 .519 .772 r
.32203 .35252 m .3225 .35259 L .31313 .35113 L p F P
0 g
s
0 .519 .772 r
.30877 .35009 m .31462 .35126 L p .31313 .35113 L F P
0 g
s
.189 0 0 r
.31531 .35166 m .31044 .3505 L p .31462 .35126 L F P
0 g
s
.224 0 0 r
.31462 .35126 m .30877 .35009 L .30541 .34929 L p F P
0 g
s
.189 0 0 r
.31044 .3505 m .30663 .34959 L .31462 .35126 L p F P
0 g
s
0 .519 .772 r
.31462 .35126 m .32203 .35252 L p .31844 .35196 L F P
0 g
s
0 .519 .772 r
.31313 .35113 m .31462 .35126 L .31844 .35196 L F
.31313 .35113 m .31138 .35077 L .30877 .35009 L p F P
0 g
s
.135 0 0 r
.37037 .35836 m .37097 .35842 L .37011 .35836 L closepath p F P
0 g
s
.671 .77 .925 r
.63858 .3217 m .62747 .32535 L .62472 .32258 L p F P
0 g
s
.671 .784 .934 r
.61363 .32644 m .62472 .32258 L .62747 .32535 L p F P
0 g
s
.665 .741 .907 r
.62747 .32535 m .63858 .3217 L .64133 .32505 L p F P
0 g
s
.482 0 0 r
.34281 .49092 m .3529 .49183 L .34463 .48926 L p F P
0 g
s
.482 0 0 r
.33921 .4898 m .34281 .49092 L p .34463 .48926 L F P
0 g
s
.482 0 0 r
.34463 .48926 m .34154 .48899 L .33921 .4898 L p F P
0 g
s
.835 .475 .373 r
.16472 .42015 m .16329 .42119 L .16263 .41928 L closepath p F P
0 g
s
.415 .144 .391 r
.65314 .41477 m .65373 .4106 L .64956 .41245 L p F P
0 g
s
.415 .144 .391 r
.64296 .41928 m .65314 .41477 L p .64956 .41245 L F P
0 g
s
.474 0 0 r
.3563 .49054 m .36362 .49254 L .35302 .49184 L closepath p F P
0 g
s
.624 .102 0 r
.2681 .47559 m .27589 .47723 L .27049 .47386 L p F P
0 g
s
.624 .102 0 r
.26408 .4731 m .2681 .47559 L p .27049 .47386 L F P
0 g
s
.624 .102 0 r
.27049 .47386 m .26525 .47278 L .26408 .4731 L p F P
0 g
s
.367 0 .201 r
.60712 .44625 m .60766 .44493 L .59661 .44918 L p F P
0 g
s
.367 0 .201 r
.59661 .44918 m .59632 .4499 L .60712 .44625 L p F P
0 g
s
.352 0 0 r
.46796 .4886 m .467 .48926 L .46198 .48917 L closepath p F P
0 g
s
.349 0 0 r
.46488 .4907 m .467 .48926 L .46198 .48917 L p F P
0 g
s
.349 0 0 r
.45925 .49121 m .46488 .4907 L p .46198 .48917 L F P
0 g
s
.349 0 0 r
.45313 .49104 m .45925 .49121 L p .46198 .48917 L F P
0 g
s
0 .515 .789 r
.28949 .34603 m .28141 .34479 L .27803 .34339 L p F P
0 g
s
.361 .02 .245 r
.62978 .43456 m .63083 .43131 L .62034 .43538 L p F P
0 g
s
.361 .02 .245 r
.62749 .43576 m .62978 .43456 L p .62034 .43538 L F P
0 g
s
.361 .02 .245 r
.62034 .43538 m .61916 .43898 L .62749 .43576 L p F P
0 g
s
.672 .823 .956 r
.62198 .32016 m .62472 .32258 L .61363 .32644 L p F P
0 g
s
.672 .823 .956 r
.61311 .32337 m .62198 .32016 L p .61363 .32644 L F P
0 g
s
.672 .823 .956 r
.61363 .32644 m .61114 .3244 L .61311 .32337 L p F P
0 g
s
.807 .706 .754 r
.12717 .34321 m .12414 .3416 L .12615 .34442 L closepath p F P
0 g
s
.845 .505 .412 r
.15137 .41443 m .15698 .41687 L .15585 .4123 L p F P
0 g
s
.845 .505 .412 r
.15585 .4123 m .15024 .40987 L .15137 .41443 L p F P
0 g
s
.314 .705 .979 r
.24391 .33393 m .23371 .33313 L .23965 .33551 L p F P
0 g
s
.314 .705 .979 r
.23965 .33551 m .24732 .33586 L .24391 .33393 L p F P
0 g
s
.295 .676 .974 r
.23368 .33313 m .23371 .33313 L .23965 .33551 L p F P
0 g
s
.536 .903 .964 r
.55583 .33547 m .55836 .33598 L .54737 .33961 L p F P
0 g
s
.536 .903 .964 r
.54737 .33961 m .54495 .33914 L .55583 .33547 L p F P
0 g
s
.652 .695 .877 r
.64133 .32505 m .65248 .32173 L .65523 .32578 L p F P
0 g
s
.661 .725 .896 r
.65248 .32173 m .64133 .32505 L .63858 .3217 L p F P
0 g
s
.433 .209 .472 r
.67404 .39653 m .67418 .3919 L .6643 .39686 L p F P
0 g
s
.433 .209 .472 r
.6643 .39686 m .66413 .40148 L .67404 .39653 L p F P
0 g
s
0 .559 .803 r
.31138 .35077 m .30877 .35009 L .30488 .34956 L closepath p F P
0 g
s
.579 .551 .787 r
.68329 .33222 m .67696 .33294 L .67279 .33541 L p F P
0 g
s
.579 .551 .787 r
.68587 .33886 m .68329 .33222 L p .67279 .33541 L F P
0 g
s
.579 .551 .787 r
.68439 .33975 m .68587 .33886 L p .67279 .33541 L F P
0 g
s
.6 .577 .8 r
.672 .33364 m .67696 .33294 L .67279 .33541 L closepath p F P
0 g
s
.51 0 0 r
.34154 .48899 m .33921 .4898 L .33481 .48828 L closepath p F P
0 g
s
.559 .026 0 r
.3118 .48416 m .31609 .48602 L .30919 .48508 L closepath p F P
0 g
s
.371 .053 .29 r
.64119 .42703 m .64216 .42325 L .63183 .42754 L p F P
0 g
s
.371 .053 .29 r
.63183 .42754 m .63083 .43131 L .64119 .42703 L p F P
0 g
s
.148 0 0 r
.38028 .35947 m .38094 .35939 L .37097 .35842 L p F P
0 g
s
.148 0 0 r
.37141 .35898 m .38028 .35947 L p .37097 .35842 L F P
0 g
s
.148 0 0 r
.36712 .3584 m .37141 .35898 L p .37097 .35842 L F P
0 g
s
.148 0 0 r
.37097 .35842 m .37011 .35836 L .36712 .3584 L p F P
0 g
s
.267 .775 .811 r
.50051 .34942 m .49451 .35073 L .49199 .35092 L p F P
0 g
s
.826 .707 .733 r
.12252 .34962 m .12615 .34442 L .12414 .3416 L p F P
0 g
s
.162 0 0 r
.37011 .35836 m .36712 .3584 L .36037 .35763 L closepath p F P
0 g
s
.845 .674 .67 r
.11642 .36137 m .12146 .36408 L .12404 .35836 L p F P
0 g
s
.845 .674 .67 r
.12404 .35836 m .11905 .35564 L .11642 .36137 L p F P
0 g
s
.346 0 .192 r
.61871 .44007 m .61916 .43898 L .60851 .44283 L p F P
0 g
s
.346 0 .192 r
.60851 .44283 m .60766 .44493 L .61871 .44007 L p F P
0 g
s
.315 0 0 r
.51339 .48028 m .50806 .48121 L .50563 .48341 L p F P
0 g
s
.174 .709 .75 r
.49037 .35121 m .49199 .35092 L .4811 .35301 L p F P
0 g
s
.174 .709 .75 r
.4811 .35301 m .47821 .35335 L .49037 .35121 L p F P
0 g
s
.316 0 .024 r
.56917 .46508 m .57078 .46282 L .55949 .46584 L p F P
0 g
s
.316 0 .024 r
.55949 .46584 m .55814 .46771 L .56917 .46508 L p F P
0 g
s
0 0 0 r
.44025 .35803 m .43953 .3581 L .43642 .35828 L closepath p F P
0 g
s
0 0 0 r
.43643 .35869 m .43953 .3581 L .43642 .35828 L p F P
0 g
s
.186 .653 .937 r
.26365 .34014 m .26437 .34049 L p .25073 .3378 L F P
0 g
s
.186 .653 .937 r
.25073 .3378 m .25806 .33857 L .26365 .34014 L p F P
0 g
s
.147 .623 .924 r
.25806 .33857 m .25073 .3378 L .24732 .33586 L p F P
0 g
s
.59 .059 0 r
.29652 .48104 m .29472 .48158 L .29218 .48028 L closepath p F P
0 g
s
.796 .383 .265 r
.18038 .43686 m .18654 .43909 L .18403 .43492 L p F P
0 g
s
.796 .383 .265 r
.17964 .4356 m .18038 .43686 L p .18403 .43492 L F P
0 g
s
.796 .383 .265 r
.18403 .43492 m .18247 .43436 L .17964 .4356 L p F P
0 g
s
.333 0 .083 r
.58192 .45959 m .58293 .45791 L .5719 .461 L p F P
0 g
s
.333 0 .083 r
.5719 .461 m .57078 .46282 L .58192 .45959 L p F P
0 g
s
.711 .235 .117 r
.23369 .461 m .23617 .46323 L .23109 .46189 L closepath p F P
0 g
s
.62 .105 .001 r
.28112 .47716 m .28394 .47879 L .27902 .47787 L closepath p F P
0 g
s
.107 .603 .903 r
.26437 .34049 m .26504 .3406 L .27176 .3427 L p F P
0 g
s
.133 .634 .907 r
.27464 .34203 m .26504 .3406 L .27176 .3427 L p F P
0 g
s
.133 .634 .907 r
.27176 .3427 m .27803 .34339 L .27464 .34203 L p F P
0 g
s
.668 .853 .971 r
.61088 .32419 m .59982 .32818 L .59705 .32642 L p F P
0 g
s
.659 .861 .976 r
.586 .33044 m .59705 .32642 L .59982 .32818 L p F P
0 g
s
.336 0 0 r
.50541 .48362 m .50563 .48341 L .49472 .48411 L p F P
0 g
s
.336 0 0 r
.49472 .48411 m .49312 .4855 L .50541 .48362 L p F P
0 g
s
0 0 0 r
.45032 .35734 m .45318 .35679 L .44025 .35803 L p F P
0 g
s
0 0 0 r
.44025 .35803 m .43953 .3581 L .45032 .35734 L p F P
0 g
s
.331 0 0 r
.47786 .48915 m .48066 .48718 L .46796 .4886 L p F P
0 g
s
.331 0 0 r
.46796 .4886 m .467 .48926 L .47786 .48915 L p F P
0 g
s
.611 .591 .806 r
.67696 .33294 m .672 .33364 L .6692 .32795 L p F P
0 g
s
.852 .559 .491 r
.14377 .4006 m .14391 .40274 L .14301 .40233 L closepath p F P
0 g
s
.658 .752 .919 r
.16171 .32456 m .17207 .32109 L .17552 .32424 L p F P
0 g
s
.648 .752 .925 r
.17207 .32109 m .16171 .32456 L .15826 .32119 L p F P
0 g
s
.705 .749 .886 r
.14779 .3261 m .15826 .32119 L .16171 .32456 L p F P
0 g
s
.259 0 0 r
.39462 .35992 m .38417 .35918 L .38094 .35939 L p F P
0 g
s
.515 .893 .963 r
.54452 .33906 m .54495 .33914 L .53385 .34252 L p F P
0 g
s
.515 .893 .963 r
.53385 .34252 m .53355 .34246 L .54452 .33906 L p F P
0 g
s
.377 .72 .988 r
.23364 .3331 m .23368 .33313 L p .22004 .33084 L F P
0 g
s
.377 .72 .988 r
.22004 .33084 m .22719 .33094 L .23364 .3331 L p F P
0 g
s
.351 .7 .984 r
.22719 .33094 m .22004 .33084 L .21661 .32838 L p F P
0 g
s
.383 .089 .337 r
.65237 .41875 m .65314 .41477 L .64296 .41928 L p F P
0 g
s
.383 .089 .337 r
.64296 .41928 m .64216 .42325 L .65237 .41875 L p F P
0 g
s
.836 .476 .372 r
.15847 .42132 m .15698 .41687 L .16263 .41928 L p F P
0 g
s
.836 .476 .372 r
.16136 .42255 m .15847 .42132 L p .16263 .41928 L F P
0 g
s
.836 .476 .372 r
.16263 .41928 m .16329 .42119 L .16136 .42255 L p F P
0 g
s
.214 0 0 r
.33178 .3542 m .32582 .35321 L .3225 .35259 L p F P
0 g
s
.74 .741 .853 r
.14633 .32703 m .14779 .3261 L .14434 .32251 L p F P
0 g
s
.74 .741 .853 r
.14434 .32251 m .14159 .32419 L .14633 .32703 L p F P
0 g
s
.751 .727 .83 r
.13371 .32941 m .14159 .32419 L .14633 .32703 L p F P
0 g
s
.328 0 .132 r
.60553 .44947 m .60712 .44625 L .59632 .4499 L p F P
0 g
s
.328 0 .132 r
.59632 .4499 m .59471 .45312 L .60553 .44947 L p F P
0 g
s
.536 .738 .969 r
.18926 .32488 m .19297 .32444 L .19851 .32698 L p F P
0 g
s
.555 .754 .97 r
.19951 .32362 m .19297 .32444 L .19851 .32698 L p F P
0 g
s
.555 .754 .97 r
.19851 .32698 m .20295 .32631 L .19951 .32362 L p F P
0 g
s
.603 .751 .949 r
.17552 .32424 m .18582 .32195 L .18926 .32488 L p F P
0 g
s
.59 .749 .953 r
.18582 .32195 m .17552 .32424 L .17207 .32109 L p F P
0 g
s
.636 .663 .86 r
.66651 .3231 m .66643 .32295 L .65523 .32578 L p F P
0 g
s
.646 .677 .865 r
.66643 .32295 m .65523 .32578 L .65248 .32173 L p F P
0 g
s
.494 0 0 r
.3374 .49042 m .33921 .4898 L .33481 .48828 L p F P
0 g
s
.494 0 0 r
.333 .48993 m .3374 .49042 L p .33481 .48828 L F P
0 g
s
.494 0 0 r
.32548 .48734 m .333 .48993 L p .33481 .48828 L F P
0 g
s
.494 0 0 r
.33481 .48828 m .32564 .48729 L .32548 .48734 L p F P
0 g
s
.723 .248 .119 r
.22237 .45933 m .22914 .46133 L .22526 .45754 L p F P
0 g
s
.723 .248 .119 r
.22526 .45754 m .21844 .45556 L .22237 .45933 L p F P
0 g
s
0 0 0 r
.46725 .35505 m .47738 .35347 L .46587 .35527 L closepath p F P
0 g
s
0 0 0 r
.46587 .35527 m .46725 .35505 L p .45339 .35675 L F P
0 g
s
.773 .34 .223 r
.20003 .44494 m .20194 .4475 L .1974 .44602 L closepath p F P
0 g
s
.5 .365 .627 r
.69248 .36573 m .68289 .37118 L .68196 .36532 L p F P
0 g
s
.5 .365 .627 r
.69243 .36543 m .69248 .36573 L p .68196 .36532 L F P
0 g
s
.5 .365 .627 r
.68196 .36532 m .68763 .36209 L .69243 .36543 L p F P
0 g
s
.126 0 0 r
.36521 .35851 m .36712 .3584 L .36037 .35763 L p F P
0 g
s
.126 0 0 r
.36089 .35816 m .36521 .35851 L p .36037 .35763 L F P
0 g
s
.126 0 0 r
.35333 .35698 m .36089 .35816 L p .36037 .35763 L F P
0 g
s
.126 0 0 r
.36037 .35763 m .35475 .35707 L .35333 .35698 L p F P
0 g
s
.459 0 0 r
.37007 .49199 m .37477 .49311 L .36817 .49282 L closepath p F P
0 g
s
.647 .134 .009 r
.26525 .47278 m .26408 .4731 L .26274 .47221 L closepath p F P
0 g
s
.691 .199 .074 r
.24067 .46685 m .23617 .46323 L .24331 .46509 L p F P
0 g
s
.691 .199 .074 r
.24633 .46834 m .24067 .46685 L p .24331 .46509 L F P
0 g
s
.691 .199 .074 r
.24331 .46509 m .24705 .46813 L .24633 .46834 L p F P
0 g
s
.808 .403 .283 r
.18247 .43436 m .17964 .4356 L .178 .43266 L closepath p F P
0 g
s
.591 .903 .984 r
.57218 .33304 m .56799 .33448 L .57207 .333 L closepath p F P
0 g
s
.586 .905 .982 r
.56938 .33214 m .57207 .333 L .56799 .33448 L p F P
0 g
s
.586 .905 .982 r
.55836 .33598 m .56938 .33214 L p .56799 .33448 L F P
0 g
s
.697 .75 .893 r
.15826 .32119 m .14779 .3261 L .14434 .32251 L p F P
0 g
s
.744 .29 .173 r
.21681 .45377 m .21844 .45556 L .21485 .4545 L closepath p F P
0 g
s
.755 .302 .173 r
.20532 .45143 m .21179 .45353 L .20845 .44959 L p F P
0 g
s
.755 .302 .173 r
.20845 .44959 m .20194 .4475 L .20532 .45143 L p F P
0 g
s
.451 .877 .919 r
.54452 .33906 m .53355 .34246 L .53067 .34227 L p F P
0 g
s
.589 .057 0 r
.29007 .48195 m .28394 .47879 L .29218 .48028 L p F P
0 g
s
.589 .057 0 r
.29212 .48233 m .29007 .48195 L p .29218 .48028 L F P
0 g
s
.589 .057 0 r
.29218 .48028 m .29472 .48158 L .29212 .48233 L p F P
0 g
s
.314 0 0 r
.5201 .47907 m .51949 .47963 L .51339 .48028 L closepath p F P
0 g
s
.315 0 0 r
.51748 .48148 m .51949 .47963 L .51339 .48028 L p F P
0 g
s
.315 0 0 r
.50778 .4832 m .51748 .48148 L p .51339 .48028 L F P
0 g
s
.315 0 0 r
.50563 .48341 m .50778 .4832 L p .51339 .48028 L F P
0 g
s
.826 .707 .733 r
.11764 .34685 m .12252 .34962 L p .12414 .3416 L F P
0 g
s
.837 .693 .704 r
.1141 .35289 m .11905 .35564 L .12252 .34962 L p F P
0 g
s
.837 .693 .704 r
.12252 .34962 m .11764 .34685 L .1141 .35289 L p F P
0 g
s
.13 0 0 r
.39799 .35958 m .40752 .35997 L .39485 .35993 L closepath p F P
0 g
s
.65 .883 .983 r
.59705 .32642 m .586 .33044 L .58322 .32908 L p F P
0 g
s
.637 .887 .986 r
.57218 .33304 m .58322 .32908 L .586 .33044 L p F P
0 g
s
0 .509 .77 r
.29508 .34745 m .29711 .34782 L .30488 .34956 L p F P
0 g
s
0 .548 .786 r
.30541 .34929 m .29711 .34782 L .30488 .34956 L p F P
0 g
s
0 .548 .786 r
.30488 .34956 m .30877 .35009 L .30541 .34929 L p F P
0 g
s
0 0 0 r
.45339 .35675 m .45462 .35661 L .46587 .35527 L p F P
0 g
s
0 0 0 r
.45339 .35675 m .45462 .35661 L .45318 .35679 L closepath p F P
0 g
s
.863 .593 .528 r
.12777 .39021 m .133 .39281 L .13319 .38786 L p F P
0 g
s
.863 .593 .528 r
.13319 .38786 m .12796 .38526 L .12777 .39021 L p F P
0 g
s
.316 .805 .861 r
.50631 .34821 m .50585 .34821 L .50051 .34942 L closepath p F P
0 g
s
.267 .775 .811 r
.50291 .34854 m .50585 .34821 L .50051 .34942 L p F P
0 g
s
.267 .775 .811 r
.49199 .35092 m .50291 .34854 L p .50051 .34942 L F P
0 g
s
.862 .615 .565 r
.12278 .38262 m .12796 .38526 L .12863 .38015 L p F P
0 g
s
.862 .615 .565 r
.12863 .38015 m .12346 .37752 L .12278 .38262 L p F P
0 g
s
.126 0 0 r
.35475 .35707 m .35333 .35698 L .35042 .35663 L closepath p F P
0 g
s
.815 .714 .753 r
.12277 .33976 m .1222 .34046 L .12414 .3416 L closepath p F P
0 g
s
.826 .707 .733 r
.12414 .3416 m .1222 .34046 L .11764 .34685 L p F P
0 g
s
.862 .569 .491 r
.13325 .39763 m .13854 .40021 L .13829 .39539 L p F P
0 g
s
.862 .569 .491 r
.13829 .39539 m .133 .39281 L .13325 .39763 L p F P
0 g
s
.647 .133 .007 r
.26036 .47392 m .25526 .47047 L .26274 .47221 L p F P
0 g
s
.647 .133 .007 r
.26071 .47401 m .26036 .47392 L p .26274 .47221 L F P
0 g
s
.647 .133 .007 r
.26274 .47221 m .26408 .4731 L .26071 .47401 L p F P
0 g
s
.36 0 0 r
.48086 .48701 m .48225 .48697 L .48066 .48718 L closepath p F P
0 g
s
.518 .729 .97 r
.19297 .32444 m .18926 .32488 L .18582 .32195 L p F P
0 g
s
.109 0 0 r
.41182 .35953 m .42173 .35959 L .40901 .35996 L closepath p F P
0 g
s
.82 .432 .319 r
.16622 .42801 m .17209 .43035 L .1701 .42603 L p F P
0 g
s
.82 .432 .319 r
.1701 .42603 m .16421 .42371 L .16622 .42801 L p F P
0 g
s
.859 .637 .601 r
.11834 .37485 m .12346 .37752 L .12469 .37223 L p F P
0 g
s
.859 .637 .601 r
.12469 .37223 m .11958 .36957 L .11834 .37485 L p F P
0 g
s
.113 0 0 r
.45032 .35734 m .43953 .3581 L .43643 .35869 L p F P
0 g
s
.395 .125 .383 r
.6632 .41006 m .66376 .40587 L .65373 .4106 L p F P
0 g
s
.395 .125 .383 r
.65373 .4106 m .65314 .41477 L .6632 .41006 L p F P
0 g
s
0 0 0 r
.45462 .35661 m .45318 .35679 L .45032 .35734 L p F P
0 g
s
0 .534 .811 r
.29508 .34745 m .29711 .34782 L .29338 .34688 L closepath p F P
0 g
s
.785 .354 .227 r
.18937 .44316 m .19555 .44537 L .19274 .44129 L p F P
0 g
s
.785 .354 .227 r
.19274 .44129 m .18654 .43909 L .18937 .44316 L p F P
0 g
s
.079 0 0 r
.43615 .35877 m .43643 .35869 L .42567 .35904 L p F P
0 g
s
.079 0 0 r
.42567 .35904 m .42276 .35955 L .43615 .35877 L p F P
0 g
s
.315 0 0 r
.54363 .47413 m .54432 .47334 L .53333 .47516 L p F P
0 g
s
.315 0 0 r
.53333 .47516 m .53195 .47671 L .54363 .47413 L p F P
0 g
s
.311 0 .074 r
.594 .45433 m .59471 .45312 L .58374 .45656 L p F P
0 g
s
.311 0 .074 r
.58374 .45656 m .58293 .45791 L .594 .45433 L p F P
0 g
s
.196 0 0 r
.33956 .35522 m .34098 .35546 L .35042 .35663 L p F P
0 g
s
.156 0 0 r
.35004 .35693 m .34098 .35546 L .35042 .35663 L p F P
0 g
s
.156 0 0 r
.35042 .35663 m .35333 .35698 L .35004 .35693 L p F P
0 g
s
.522 0 0 r
.32564 .48729 m .32548 .48734 L .32519 .48723 L closepath p F P
0 g
s
.852 .533 .448 r
.14051 .40553 m .14467 .40741 L .14391 .40274 L p F P
0 g
s
.852 .533 .448 r
.14391 .40274 m .14301 .40233 L .14051 .40553 L p F P
0 g
s
.444 0 0 r
.38387 .493 m .38644 .49353 L .38293 .49345 L closepath p F P
0 g
s
0 0 0 r
.46587 .35527 m .46422 .35555 L .45462 .35661 L closepath p F P
0 g
s
0 0 0 r
.46198 .35614 m .46422 .35555 L .45462 .35661 L p F P
0 g
s
0 0 0 r
.45659 .35676 m .46198 .35614 L p .45462 .35661 L F P
0 g
s
0 0 0 r
.45032 .35734 m .45659 .35676 L p .45462 .35661 L F P
0 g
s
.52 0 0 r
.3221 .48833 m .31609 .48602 L .32519 .48723 L p F P
0 g
s
.52 0 0 r
.32519 .48723 m .32548 .48734 L .3221 .48833 L p F P
0 g
s
.545 .459 .709 r
.68455 .34884 m .68836 .34659 L .68915 .34945 L closepath p F P
0 g
s
.307 0 0 r
.48225 .48697 m .48066 .48718 L .47786 .48915 L p F P
0 g
s
.83 .466 .365 r
.16329 .42119 m .16421 .42371 L .16136 .42255 L closepath p F P
0 g
s
.854 .657 .637 r
.11452 .36687 m .11958 .36957 L .12146 .36408 L p F P
0 g
s
.854 .657 .637 r
.12146 .36408 m .11642 .36137 L .11452 .36687 L p F P
0 g
s
.125 .609 .914 r
.26437 .34049 m .26504 .3406 L .26365 .34014 L closepath p F P
0 g
s
.507 0 0 r
.333 .48993 m .32548 .48734 L .3221 .48833 L p F P
0 g
s
.162 0 0 r
.33956 .35522 m .34098 .35546 L .33875 .35514 L closepath p F P
0 g
s
.309 0 0 r
.49312 .4855 m .49175 .4865 L .48225 .48697 L closepath p F P
0 g
s
.307 0 0 r
.49016 .48765 m .49175 .4865 L .48225 .48697 L p F P
0 g
s
.307 0 0 r
.47929 .4891 m .49016 .48765 L p .48225 .48697 L F P
0 g
s
.307 0 0 r
.47786 .48915 m .47929 .4891 L p .48225 .48697 L F P
0 g
s
.445 .244 .513 r
.67969 .38899 m .67418 .3919 L .6741 .38702 L p F P
0 g
s
.445 .244 .513 r
.6741 .38702 m .68054 .38361 L .67969 .38899 L p F P
0 g
s
.792 .715 .78 r
.11937 .33536 m .12452 .33039 L .12936 .3332 L p F P
0 g
s
.792 .715 .78 r
.12936 .3332 m .12277 .33976 L .11937 .33536 L p F P
0 g
s
.779 .73 .808 r
.12936 .3332 m .13371 .32941 L .13027 .32552 L p F P
0 g
s
.779 .73 .808 r
.13027 .32552 m .12452 .33039 L .12936 .3332 L p F P
0 g
s
.604 .908 .983 r
.58258 .32885 m .58322 .32908 L .57218 .33304 L p F P
0 g
s
.604 .908 .983 r
.57218 .33304 m .57207 .333 L .58258 .32885 L p F P
0 g
s
.37 .837 .869 r
.52926 .34233 m .53067 .34227 L .51971 .34538 L p F P
0 g
s
.37 .837 .869 r
.51971 .34538 m .51791 .34542 L .52926 .34233 L p F P
0 g
s
.301 .676 .975 r
.23368 .33313 m .23371 .33313 L .23364 .3331 L closepath p F P
0 g
s
.859 .544 .454 r
.1392 .40491 m .14051 .40553 L .14301 .40233 L p F P
0 g
s
.859 .544 .454 r
.14301 .40233 m .13854 .40021 L .1392 .40491 L p F P
0 g
s
.284 .669 .972 r
.24229 .33304 m .24391 .33393 L .23371 .33313 L p F P
0 g
s
.284 .669 .972 r
.2388 .33189 m .24229 .33304 L p .23371 .33313 L F P
0 g
s
.284 .669 .972 r
.23026 .33095 m .2388 .33189 L p .23371 .33313 L F P
0 g
s
.284 .669 .972 r
.23371 .33313 m .23364 .3331 L .23026 .33095 L p F P
0 g
s
.294 0 0 r
.55536 .47111 m .55742 .46869 L .54594 .47149 L p F P
0 g
s
.294 0 0 r
.54594 .47149 m .54432 .47334 L .55536 .47111 L p F P
0 g
s
.329 0 0 r
.47764 .48931 m .47786 .48915 L .467 .48926 L p F P
0 g
s
.329 0 0 r
.467 .48926 m .46488 .4907 L .47764 .48931 L p F P
0 g
s
.39 .723 .989 r
.23364 .3331 m .23026 .33095 L .22719 .33094 L closepath p F P
0 g
s
.747 .73 .837 r
.14159 .32419 m .13371 .32941 L .13027 .32552 L p F P
0 g
s
.612 .631 .846 r
.66651 .3231 m .6692 .32795 L .68047 .32593 L p F P
0 g
s
.611 .591 .806 r
.68222 .32973 m .67696 .33294 L p .6692 .32795 L F P
0 g
s
.611 .591 .806 r
.6692 .32795 m .68047 .32593 L .68222 .32973 L p F P
0 g
s
.29 0 0 r
.53047 .4781 m .53195 .47671 L .5201 .47907 L p F P
0 g
s
.29 0 0 r
.5201 .47907 m .51949 .47963 L .53047 .4781 L p F P
0 g
s
.607 .909 .982 r
.58043 .32809 m .58258 .32885 L .57207 .333 L p F P
0 g
s
.607 .909 .982 r
.57207 .333 m .56938 .33214 L .58043 .32809 L p F P
0 g
s
.847 .505 .407 r
.14582 .41196 m .15137 .41443 L .15024 .40987 L p F P
0 g
s
.847 .505 .407 r
.15024 .40987 m .14467 .40741 L .14582 .41196 L p F P
0 g
s
.593 .567 .794 r
.67696 .33294 m .68222 .32973 L .68329 .33222 L closepath p F P
0 g
s
.104 .597 .904 r
.27418 .34185 m .27464 .34203 L .26504 .3406 L p F P
0 g
s
.104 .597 .904 r
.26792 .34017 m .27418 .34185 L p .26504 .3406 L F P
0 g
s
.104 .597 .904 r
.26097 .33885 m .26792 .34017 L p .26504 .3406 L F P
0 g
s
.104 .597 .904 r
.26504 .3406 m .26365 .34014 L .26097 .33885 L p F P
0 g
s
.815 .718 .758 r
.1222 .34046 m .12277 .33976 L .11937 .33536 L p F P
0 g
s
.427 0 0 r
.3977 .49355 m .39878 .49374 L .39734 .49374 L closepath p F P
0 g
s
.349 .824 .872 r
.5168 .34545 m .51791 .34542 L .50631 .34821 L p F P
0 g
s
.349 .824 .872 r
.50631 .34821 m .50585 .34821 L .5168 .34545 L p F P
0 g
s
.815 .718 .758 r
.11937 .33536 m .11747 .33763 L .1222 .34046 L p F P
0 g
s
.826 .71 .737 r
.11281 .34405 m .11764 .34685 L .1222 .34046 L p F P
0 g
s
.826 .71 .737 r
.1222 .34046 m .11747 .33763 L .11281 .34405 L p F P
0 g
s
.477 .322 .591 r
.69309 .37121 m .69248 .36573 L .68289 .37118 L p F P
0 g
s
.477 .322 .591 r
.68289 .37118 m .68351 .37666 L .69309 .37121 L p F P
0 g
s
.631 .111 0 r
.26408 .4731 m .2681 .47559 L .26071 .47401 L closepath p F P
0 g
s
.809 .403 .281 r
.17441 .43457 m .17209 .43035 L .178 .43266 L p F P
0 g
s
.809 .403 .281 r
.1784 .43613 m .17441 .43457 L p .178 .43266 L F P
0 g
s
.809 .403 .281 r
.178 .43266 m .17964 .4356 L .1784 .43613 L p F P
0 g
s
.575 .032 0 r
.28196 .48041 m .29007 .48195 L .28394 .47879 L p F P
0 g
s
.575 .032 0 r
.27763 .4782 m .28196 .48041 L p .28394 .47879 L F P
0 g
s
.575 .032 0 r
.28394 .47879 m .27902 .47787 L .27763 .4782 L p F P
0 g
s
.465 .286 .553 r
.68384 .38183 m .68054 .38361 L .6795 .37883 L p F P
0 g
s
.465 .286 .553 r
.6795 .37883 m .68351 .37666 L .68384 .38183 L p F P
0 g
s
.452 .731 .987 r
.20295 .32631 m .21318 .32593 L .21661 .32838 L p F P
0 g
s
.429 .722 .987 r
.21318 .32593 m .20295 .32631 L .19951 .32362 L p F P
0 g
s
.351 0 0 r
.45313 .49104 m .45925 .49121 L .45189 .49184 L closepath p F P
0 g
s
.847 .677 .672 r
.11143 .35864 m .11642 .36137 L .11905 .35564 L p F P
0 g
s
.847 .677 .672 r
.11905 .35564 m .1141 .35289 L .11143 .35864 L p F P
0 g
s
.344 0 .189 r
.61777 .44238 m .61871 .44007 L .60766 .44493 L p F P
0 g
s
.344 0 .189 r
.60766 .44493 m .60712 .44625 L .61777 .44238 L p F P
0 g
s
.717 .232 .093 r
.21564 .45732 m .22237 .45933 L .21844 .45556 L p F P
0 g
s
.717 .232 .093 r
.21314 .45492 m .21564 .45732 L p .21844 .45556 L F P
0 g
s
.717 .232 .093 r
.21844 .45556 m .21485 .4545 L .21314 .45492 L p F P
0 g
s
.677 .171 .032 r
.23363 .46494 m .24067 .46685 L .23617 .46323 L p F P
0 g
s
.677 .171 .032 r
.23007 .46211 m .23363 .46494 L p .23617 .46323 L F P
0 g
s
.677 .171 .032 r
.23617 .46323 m .23109 .46189 L .23007 .46211 L p F P
0 g
s
.206 .663 .945 r
.26365 .34014 m .26097 .33885 L .25806 .33857 L closepath p F P
0 g
s
0 .518 .795 r
.30447 .34909 m .30541 .34929 L .29711 .34782 L p F P
0 g
s
0 .518 .795 r
.29867 .3479 m .30447 .34909 L p .29711 .34782 L F P
0 g
s
0 .518 .795 r
.29171 .34635 m .29867 .3479 L p .29711 .34782 L F P
0 g
s
0 .518 .795 r
.29711 .34782 m .29338 .34688 L .29171 .34635 L p F P
0 g
s
.416 0 0 r
.42518 .49336 m .4254 .49324 L p .41154 .49364 L F P
0 g
s
.416 0 0 r
.41154 .49364 m .41196 .49369 L .42518 .49336 L p F P
0 g
s
.409 0 0 r
.41154 .49364 m .41196 .49369 L .41142 .4937 L closepath p F P
0 g
s
.179 0 0 r
.34954 .35695 m .35004 .35693 L .34098 .35546 L p F P
0 g
s
.179 0 0 r
.34137 .35599 m .34954 .35695 L p .34098 .35546 L F P
0 g
s
.179 0 0 r
.33625 .35492 m .34137 .35599 L p .34098 .35546 L F P
0 g
s
.179 0 0 r
.34098 .35546 m .33875 .35514 L .33625 .35492 L p F P
0 g
s
.571 .035 0 r
.29472 .48158 m .29853 .48338 L .29212 .48233 L closepath p F P
0 g
s
.371 0 0 r
.43926 .49237 m .44183 .49254 L .43867 .49274 L closepath p F P
0 g
s
.841 .479 .368 r
.15287 .41888 m .15847 .42132 L .15698 .41687 L p F P
0 g
s
.841 .479 .368 r
.15698 .41687 m .15137 .41443 L .15287 .41888 L p F P
0 g
s
.407 .162 .428 r
.67375 .40009 m .67404 .39653 L .66413 .40148 L p F P
0 g
s
.407 .162 .428 r
.67286 .40135 m .67375 .40009 L p .66413 .40148 L F P
0 g
s
.407 .162 .428 r
.66413 .40148 m .66376 .40587 L .67286 .40135 L p F P
0 g
s
.661 .725 .896 r
.63858 .3217 m .64974 .31813 L .65248 .32173 L p F P
0 g
s
.669 .754 .914 r
.64974 .31813 m .63858 .3217 L .63584 .31873 L p F P
0 g
s
.671 .77 .925 r
.62472 .32258 m .63584 .31873 L .63858 .3217 L p F P
0 g
s
.379 0 0 r
.41142 .4937 m .40836 .49502 L .39878 .49374 L closepath p F P
0 g
s
.369 0 0 r
.40767 .49532 m .40836 .49502 L .39878 .49374 L p F P
0 g
s
.369 0 0 r
.39749 .4953 m .40767 .49532 L p .39878 .49374 L F P
0 g
s
.369 0 0 r
.39448 .49488 m .39749 .4953 L p .39878 .49374 L F P
0 g
s
.369 0 0 r
.39878 .49374 m .39734 .49374 L .39448 .49488 L p F P
0 g
s
.397 0 0 r
.39734 .49374 m .39448 .49488 L .38644 .49353 L closepath p F P
0 g
s
.391 0 0 r
.4254 .49324 m .4262 .49332 L .42518 .49336 L closepath p F P
0 g
s
.507 0 0 r
.3213 .48856 m .3221 .48833 L .31609 .48602 L p F P
0 g
s
.507 0 0 r
.31443 .4876 m .3213 .48856 L p .31609 .48602 L F P
0 g
s
.507 0 0 r
.30838 .48528 m .31443 .4876 L p .31609 .48602 L F P
0 g
s
.507 0 0 r
.31609 .48602 m .30919 .48508 L .30838 .48528 L p F P
0 g
s
0 0 0 r
.47738 .35347 m .46587 .35527 L .46422 .35555 L p F P
0 g
s
.351 0 0 r
.41196 .49369 m .41142 .4937 L .40836 .49502 L p F P
0 g
s
.351 0 0 r
.42155 .49505 m .42225 .49473 L .41196 .49369 L p F P
0 g
s
.351 0 0 r
.41065 .49527 m .42155 .49505 L p .41196 .49369 L F P
0 g
s
.351 0 0 r
.40836 .49502 m .41065 .49527 L p .41196 .49369 L F P
0 g
s
.36 0 0 r
.42518 .49336 m .42225 .49473 L .41196 .49369 L closepath p F P
0 g
s
.676 .798 .94 r
.63584 .31873 m .62472 .32258 L .62198 .32016 L p F P
0 g
s
.75 .287 .148 r
.1989 .4493 m .20532 .45143 L .20194 .4475 L p F P
0 g
s
.75 .287 .148 r
.19631 .4463 m .1989 .4493 L p .20194 .4475 L F P
0 g
s
.75 .287 .148 r
.20194 .4475 m .1974 .44602 L .19631 .4463 L p F P
0 g
s
.518 .729 .97 r
.18582 .32195 m .18777 .32177 L .19297 .32444 L p F P
0 g
s
.535 .748 .974 r
.19606 .32095 m .18777 .32177 L .19297 .32444 L p F P
0 g
s
.535 .748 .974 r
.19297 .32444 m .19951 .32362 L .19606 .32095 L p F P
0 g
s
.672 .824 .956 r
.61114 .3244 m .61088 .32419 L .61311 .32337 L closepath p F P
0 g
s
.292 0 .012 r
.58024 .46198 m .58192 .45959 L .57078 .46282 L p F P
0 g
s
.292 0 .012 r
.57078 .46282 m .56917 .46508 L .58024 .46198 L p F P
0 g
s
.163 0 0 r
.33875 .35514 m .33625 .35492 L .33178 .3542 L closepath p F P
0 g
s
.57 .514 .753 r
.68439 .33975 m .68587 .33886 L .68617 .33972 L closepath p F P
0 g
s
.247 .76 .775 r
.5168 .34545 m .50585 .34821 L .50291 .34854 L p F P
0 g
s
.677 .182 .066 r
.24705 .46813 m .24782 .46871 L .25526 .47047 L p F P
0 g
s
.645 .125 0 r
.25299 .47213 m .26036 .47392 L .25526 .47047 L p F P
0 g
s
.645 .125 0 r
.25526 .47047 m .24782 .46871 L .25299 .47213 L p F P
0 g
s
.385 0 0 r
.39347 .49528 m .39448 .49488 L .38644 .49353 L p F P
0 g
s
.385 0 0 r
.38517 .49508 m .39347 .49528 L p .38644 .49353 L F P
0 g
s
.385 0 0 r
.38063 .49429 m .38517 .49508 L p .38644 .49353 L F P
0 g
s
.385 0 0 r
.38644 .49353 m .38293 .49345 L .38063 .49429 L p F P
0 g
s
.559 .911 .966 r
.56657 .33151 m .56938 .33214 L .55836 .33598 L p F P
0 g
s
.559 .911 .966 r
.5641 .33238 m .56657 .33151 L p .55836 .33598 L F P
0 g
s
.559 .911 .966 r
.55836 .33598 m .55583 .33547 L .5641 .33238 L p F P
0 g
s
.414 0 0 r
.38293 .49345 m .38063 .49429 L .37477 .49311 L closepath p F P
0 g
s
.314 0 .021 r
.56875 .46568 m .56917 .46508 L .55814 .46771 L p F P
0 g
s
.314 0 .021 r
.55814 .46771 m .55742 .46869 L .56875 .46568 L p F P
0 g
s
.735 .742 .857 r
.14159 .32419 m .14434 .32251 L .14088 .31896 L p F P
0 g
s
.735 .742 .857 r
.14088 .31896 m .13684 .32134 L .14159 .32419 L p F P
0 g
s
.747 .73 .837 r
.13027 .32552 m .13684 .32134 L .14159 .32419 L p F P
0 g
s
.304 0 0 r
.36089 .35816 m .35333 .35698 L .35004 .35693 L p F P
0 g
s
.333 0 0 r
.4262 .49332 m .42518 .49336 L .42225 .49473 L p F P
0 g
s
.646 .677 .865 r
.65248 .32173 m .66367 .31859 L .66643 .32295 L p F P
0 g
s
.655 .707 .885 r
.66367 .31859 m .65248 .32173 L .64974 .31813 L p F P
0 g
s
.34 0 0 r
.43867 .49274 m .43615 .49399 L .4262 .49332 L closepath p F P
0 g
s
.333 0 0 r
.43513 .49448 m .43615 .49399 L .4262 .49332 L p F P
0 g
s
.333 0 0 r
.42487 .49492 m .43513 .49448 L p .4262 .49332 L F P
0 g
s
.333 0 0 r
.42225 .49473 m .42487 .49492 L p .4262 .49332 L F P
0 g
s
.663 .852 .972 r
.61311 .32337 m .61088 .32419 L .60813 .3223 L p F P
0 g
s
.668 .853 .971 r
.59705 .32642 m .60813 .3223 L .61088 .32419 L p F P
0 g
s
.602 .067 0 r
.27902 .47787 m .27763 .4782 L .27589 .47723 L closepath p F P
0 g
s
.288 0 0 r
.52938 .47913 m .53047 .4781 L .51949 .47963 L p F P
0 g
s
.288 0 0 r
.51949 .47963 m .51748 .48148 L .52938 .47913 L p F P
0 g
s
.648 .752 .925 r
.15826 .32119 m .16861 .31797 L .17207 .32109 L p F P
0 g
s
.637 .751 .93 r
.16861 .31797 m .15826 .32119 L .1548 .31786 L p F P
0 g
s
.697 .75 .893 r
.14434 .32251 m .1548 .31786 L .15826 .32119 L p F P
0 g
s
.286 0 0 r
.50269 .48565 m .50541 .48362 L .49312 .4855 L p F P
0 g
s
.286 0 0 r
.49312 .4855 m .49175 .4865 L .50269 .48565 L p F P
0 g
s
.489 0 0 r
.33921 .4898 m .34281 .49092 L .3374 .49042 L closepath p F P
0 g
s
.401 0 0 r
.37893 .4949 m .38063 .49429 L .37477 .49311 L p F P
0 g
s
.401 0 0 r
.37349 .49465 m .37893 .4949 L p .37477 .49311 L F P
0 g
s
.401 0 0 r
.36679 .49328 m .37349 .49465 L p .37477 .49311 L F P
0 g
s
.401 0 0 r
.37477 .49311 m .36817 .49282 L .36679 .49328 L p F P
0 g
s
.028 .574 .838 r
.29338 .34688 m .29171 .34635 L .28949 .34603 L closepath p F P
0 g
s
.838 .696 .706 r
.1092 .35011 m .1141 .35289 L .11764 .34685 L p F P
0 g
s
.838 .696 .706 r
.11764 .34685 m .11281 .34405 L .1092 .35011 L p F P
0 g
s
.534 .902 .963 r
.55553 .33541 m .55583 .33547 L .54495 .33914 L p F P
0 g
s
.534 .902 .963 r
.54495 .33914 m .54452 .33906 L .55553 .33541 L p F P
0 g
s
.736 .261 .119 r
.21485 .4545 m .21314 .45492 L .21179 .45353 L closepath p F P
0 g
s
.865 .595 .527 r
.12259 .38758 m .12777 .39021 L .12796 .38526 L p F P
0 g
s
.865 .595 .527 r
.12796 .38526 m .12278 .38262 L .12259 .38758 L p F P
0 g
s
.821 .428 .307 r
.1604 .42565 m .16622 .42801 L .16421 .42371 L p F P
0 g
s
.821 .428 .307 r
.15939 .42345 m .1604 .42565 L p .16421 .42371 L F P
0 g
s
.821 .428 .307 r
.16421 .42371 m .16136 .42255 L .15939 .42345 L p F P
0 g
s
.69 .751 .898 r
.1548 .31786 m .14434 .32251 L .14088 .31896 L p F P
0 g
s
.309 0 .071 r
.59291 .45615 m .594 .45433 L .58293 .45791 L p F P
0 g
s
.309 0 .071 r
.58293 .45791 m .58192 .45959 L .59291 .45615 L p F P
0 g
s
.784 .349 .216 r
.18325 .44092 m .18937 .44316 L .18654 .43909 L p F P
0 g
s
.784 .349 .216 r
.18654 .43909 m .18038 .43686 L .18325 .44092 L p F P
0 g
s
.864 .618 .565 r
.11765 .37997 m .12278 .38262 L .12346 .37752 L p F P
0 g
s
.864 .618 .565 r
.12346 .37752 m .11834 .37485 L .11765 .37997 L p F P
0 g
s
0 .515 .789 r
.27803 .34339 m .28204 .34417 L .28949 .34603 L p F P
0 g
s
0 .484 .779 r
.28204 .34417 m .27803 .34339 L .27464 .34203 L p F P
0 g
s
.498 .365 .63 r
.68763 .36209 m .69151 .35984 L .69243 .36543 L closepath p F P
0 g
s
.59 .749 .953 r
.17207 .32109 m .18236 .31904 L .18582 .32195 L p F P
0 g
s
.574 .748 .959 r
.18236 .31904 m .17207 .32109 L .16861 .31797 L p F P
0 g
s
.34 .001 .237 r
.64084 .42811 m .64119 .42703 L .63083 .43131 L p F P
0 g
s
.34 .001 .237 r
.63083 .43131 m .62978 .43456 L .64084 .42811 L p F P
0 g
s
.323 0 .179 r
.61916 .43898 m .61871 .44007 L .62749 .43576 L closepath p F P
0 g
s
.865 .571 .489 r
.12802 .39503 m .13325 .39763 L .133 .39281 L p F P
0 g
s
.865 .571 .489 r
.133 .39281 m .12777 .39021 L .12802 .39503 L p F P
0 g
s
.43 0 0 r
.36817 .49282 m .36679 .49328 L .36362 .49254 L closepath p F P
0 g
s
.147 .623 .924 r
.24732 .33586 m .25139 .33644 L .25806 .33857 L p F P
0 g
s
.114 .595 .912 r
.25139 .33644 m .24732 .33586 L .24391 .33393 L p F P
0 g
s
.554 .488 .735 r
.69773 .34079 m .69761 .34039 L .68617 .33972 L p F P
0 g
s
.554 .488 .735 r
.68617 .33972 m .68836 .34659 L .69773 .34079 L p F P
0 g
s
.552 .504 .755 r
.68587 .33886 m .68617 .33972 L .69761 .34039 L p F P
0 g
s
.525 .447 .71 r
.69956 .34772 m .69773 .34079 L .68836 .34659 L p F P
0 g
s
.525 .447 .71 r
.69471 .35074 m .69956 .34772 L p .68836 .34659 L F P
0 g
s
.525 .447 .71 r
.68836 .34659 m .68915 .34945 L .69471 .35074 L p F P
0 g
s
.536 0 0 r
.30919 .48508 m .30838 .48528 L .30712 .48476 L closepath p F P
0 g
s
.576 .536 .773 r
.68329 .33222 m .68587 .33886 L .69518 .33298 L p F P
0 g
s
.552 .504 .755 r
.69761 .34039 m .69518 .33298 L .68587 .33886 L p F P
0 g
s
.313 0 0 r
.44183 .49254 m .43867 .49274 L .43615 .49399 L p F P
0 g
s
.214 0 0 r
.3225 .35259 m .32319 .35274 L .33178 .3542 L p F P
0 g
s
.183 0 0 r
.33321 .35476 m .33242 .35464 L p .33178 .3542 L F P
0 g
s
.183 0 0 r
.33178 .3542 m .33625 .35492 L .33321 .35476 L p F P
0 g
s
.324 .681 .978 r
.22111 .32858 m .21661 .32838 L .21318 .32593 L p F P
0 g
s
.351 .7 .984 r
.21661 .32838 m .22111 .32858 L .22719 .33094 L p F P
0 g
s
.861 .64 .603 r
.1143 .37271 m .11834 .37485 L .11958 .36957 L p F P
0 g
s
.861 .64 .603 r
.11378 .36995 m .1143 .37271 L p .11958 .36957 L F P
0 g
s
.861 .64 .603 r
.11958 .36957 m .11452 .36687 L .11378 .36995 L p F P
0 g
s
.699 .203 .06 r
.23109 .46189 m .23007 .46211 L .22914 .46133 L closepath p F P
0 g
s
.668 .839 .965 r
.62198 .32016 m .61311 .32337 L .62114 .31953 L closepath p F P
0 g
s
.663 .852 .972 r
.61924 .3181 m .62114 .31953 L .61311 .32337 L p F P
0 g
s
.663 .852 .972 r
.60813 .3223 m .61924 .3181 L p .61311 .32337 L F P
0 g
s
.601 .065 0 r
.27389 .47885 m .2681 .47559 L .27589 .47723 L p F P
0 g
s
.601 .065 0 r
.27433 .47894 m .27389 .47885 L p .27589 .47723 L F P
0 g
s
.601 .065 0 r
.27589 .47723 m .27763 .4782 L .27433 .47894 L p F P
0 g
s
.175 .708 .723 r
.50222 .3487 m .50291 .34854 L .49199 .35092 L p F P
0 g
s
.175 .708 .723 r
.49199 .35092 m .49037 .35121 L .50222 .3487 L p F P
0 g
s
.53 .437 .694 r
.68915 .34945 m .69471 .35074 L .69018 .3535 L closepath p F P
0 g
s
.862 .546 .451 r
.13391 .40233 m .1392 .40491 L .13854 .40021 L p F P
0 g
s
.862 .546 .451 r
.13854 .40021 m .13325 .39763 L .13391 .40233 L p F P
0 g
s
.416 0 0 r
.36402 .49418 m .36679 .49328 L .36362 .49254 L p F P
0 g
s
.416 0 0 r
.36234 .49406 m .36402 .49418 L p .36362 .49254 L F P
0 g
s
.416 0 0 r
.35298 .49185 m .36234 .49406 L p .36362 .49254 L F P
0 g
s
.416 0 0 r
.36362 .49254 m .35302 .49184 L .35298 .49185 L p F P
0 g
s
.319 0 0 r
.45189 .49184 m .45005 .49281 L .44183 .49254 L closepath p F P
0 g
s
.313 0 0 r
.44845 .49364 m .45005 .49281 L .44183 .49254 L p F P
0 g
s
.313 0 0 r
.44044 .49416 m .44845 .49364 L p .44183 .49254 L F P
0 g
s
.313 0 0 r
.43615 .49399 m .44044 .49416 L p .44183 .49254 L F P
0 g
s
.387 .724 .989 r
.22682 .32879 m .22111 .32858 L .22719 .33094 L p F P
0 g
s
.387 .724 .989 r
.22719 .33094 m .23026 .33095 L .22682 .32879 L p F P
0 g
s
.663 .877 .979 r
.60813 .3223 m .59705 .32642 L .59428 .32497 L p F P
0 g
s
.65 .883 .983 r
.58322 .32908 m .59428 .32497 L .59705 .32642 L p F P
0 g
s
.354 .039 .286 r
.65188 .42067 m .65237 .41875 L .64216 .42325 L p F P
0 g
s
.354 .039 .286 r
.6455 .42514 m .65188 .42067 L p .64216 .42325 L F P
0 g
s
.354 .039 .286 r
.64216 .42325 m .64119 .42703 L .6455 .42514 L p F P
0 g
s
.199 .661 .942 r
.25756 .33725 m .25139 .33644 L .25806 .33857 L p F P
0 g
s
.199 .661 .942 r
.25806 .33857 m .26097 .33885 L .25756 .33725 L p F P
0 g
s
.676 .179 .056 r
.24705 .46813 m .24782 .46871 L .24633 .46834 L closepath p F P
0 g
s
.534 0 0 r
.30495 .48611 m .29853 .48338 L .30712 .48476 L p F P
0 g
s
.534 0 0 r
.30712 .48476 m .30838 .48528 L .30495 .48611 L p F P
0 g
s
.306 0 .122 r
.61622 .44561 m .61777 .44238 L .60712 .44625 L p F P
0 g
s
.306 0 .122 r
.60712 .44625 m .60553 .44947 L .61622 .44561 L p F P
0 g
s
.628 .647 .85 r
.66643 .32295 m .66697 .32282 L .66651 .3231 L closepath p F P
0 g
s
.612 .631 .846 r
.67768 .32049 m .66697 .32282 L .66651 .3231 L p F P
0 g
s
.612 .631 .846 r
.68047 .32593 m .67768 .32049 L p .66651 .3231 L F P
0 g
s
.481 .891 .926 r
.55553 .33541 m .54452 .33906 L .54166 .33888 L p F P
0 g
s
.451 .877 .919 r
.53067 .34227 m .54166 .33888 L .54452 .33906 L p F P
0 g
s
.637 .659 .855 r
.66697 .32282 m .66643 .32295 L .66367 .31859 L p F P
0 g
s
.221 0 0 r
.36712 .3584 m .37141 .35898 L .36521 .35851 L closepath p F P
0 g
s
.012 .565 .823 r
.28832 .34533 m .28204 .34417 L .28949 .34603 L p F P
0 g
s
.012 .565 .823 r
.28949 .34603 m .29171 .34635 L .28832 .34533 L p F P
0 g
s
.855 .662 .641 r
.11293 .36601 m .11452 .36687 L .11642 .36137 L p F P
0 g
s
.855 .662 .641 r
.11087 .36023 m .11293 .36601 L p .11642 .36137 L F P
0 g
s
.855 .662 .641 r
.11642 .36137 m .11143 .35864 L .11087 .36023 L p F P
0 g
s
.767 .313 .172 r
.1974 .44602 m .19631 .4463 L .19555 .44537 L closepath p F P
0 g
s
.637 .659 .855 r
.6758 .3172 m .66697 .32282 L p .66367 .31859 L F P
0 g
s
.624 .645 .851 r
.66697 .32282 m .6758 .3172 L .67768 .32049 L closepath p F P
0 g
s
.699 .202 .057 r
.22645 .46289 m .22237 .45933 L .22914 .46133 L p F P
0 g
s
.699 .202 .057 r
.22914 .46133 m .23007 .46211 L .22645 .46289 L p F P
0 g
s
.453 .277 .551 r
.69344 .37638 m .69309 .37121 L .68351 .37666 L p F P
0 g
s
.453 .277 .551 r
.68351 .37666 m .68384 .38183 L .69344 .37638 L p F P
0 g
s
.267 0 0 r
.54149 .47619 m .54363 .47413 L .53195 .47671 L p F P
0 g
s
.267 0 0 r
.53195 .47671 m .53047 .4781 L .54149 .47619 L p F P
0 g
s
.849 .503 .399 r
.14032 .40947 m .14582 .41196 L .14467 .40741 L p F P
0 g
s
.849 .503 .399 r
.13952 .40629 m .14032 .40947 L p .14467 .40741 L F P
0 g
s
.849 .503 .399 r
.14467 .40741 m .14051 .40553 L .13952 .40629 L p F P
0 g
s
.5 .72 .971 r
.18777 .32177 m .18582 .32195 L .18236 .31904 L p F P
0 g
s
.512 .401 .665 r
.70093 .3541 m .69151 .35984 L .69018 .3535 L p F P
0 g
s
.512 .401 .665 r
.70076 .35325 m .70093 .3541 L p .69018 .3535 L F P
0 g
s
.512 .401 .665 r
.69018 .3535 m .69471 .35074 L .70076 .35325 L p F P
0 g
s
.776 .732 .812 r
.12452 .33039 m .13027 .32552 L .12681 .32172 L p F P
0 g
s
.776 .732 .812 r
.12681 .32172 m .11971 .32756 L .12452 .33039 L p F P
0 g
s
.791 .72 .786 r
.11594 .33108 m .11971 .32756 L .12452 .33039 L p F P
0 g
s
.791 .72 .786 r
.12452 .33039 m .11937 .33536 L .11594 .33108 L p F P
0 g
s
.125 .673 .722 r
.47821 .35335 m .47811 .35336 L .47738 .35347 L closepath p F P
0 g
s
0 0 0 r
.47509 .35408 m .47811 .35336 L .47738 .35347 L p F P
0 g
s
.736 .26 .117 r
.209 .45527 m .20532 .45143 L .21179 .45353 L p F P
0 g
s
.736 .26 .117 r
.2101 .45563 m .209 .45527 L p .21179 .45353 L F P
0 g
s
.736 .26 .117 r
.21179 .45353 m .21314 .45492 L .2101 .45563 L p F P
0 g
s
.419 .199 .47 r
.67713 .3949 m .67404 .39653 L .67418 .3919 L p F P
0 g
s
.419 .199 .47 r
.67418 .3919 m .67969 .38899 L .67713 .3949 L p F P
0 g
s
.812 .401 .27 r
.16857 .43222 m .17441 .43457 L .17209 .43035 L p F P
0 g
s
.812 .401 .27 r
.17209 .43035 m .16622 .42801 L .16857 .43222 L p F P
0 g
s
.576 .536 .773 r
.69518 .33298 m .69467 .33158 L .68329 .33222 L p F P
0 g
s
.577 .558 .797 r
.68222 .32973 m .68329 .33222 L .69467 .33158 L p F P
0 g
s
.158 .698 .739 r
.48901 .35146 m .49037 .35121 L .47821 .35335 L p F P
0 g
s
.158 .698 .739 r
.47821 .35335 m .47811 .35336 L .48901 .35146 L p F P
0 g
s
.813 .721 .763 r
.11747 .33763 m .11937 .33536 L .11594 .33108 L p F P
0 g
s
.293 0 0 r
.45925 .49121 m .45189 .49184 L .45005 .49281 L p F P
0 g
s
.445 0 0 r
.35302 .49184 m .35298 .49185 L .3529 .49183 L closepath p F P
0 g
s
.832 .446 .322 r
.16136 .42255 m .15939 .42345 L .15847 .42132 L closepath p F P
0 g
s
.442 0 0 r
.34966 .49278 m .34281 .49092 L .3529 .49183 L p F P
0 g
s
.442 0 0 r
.3529 .49183 m .35298 .49185 L .34966 .49278 L p F P
0 g
s
.801 .39 .27 r
.17964 .4356 m .18038 .43686 L .1784 .43613 L closepath p F P
0 g
s
.743 .733 .843 r
.13684 .32134 m .13027 .32552 L .12681 .32172 L p F P
0 g
s
.636 .108 0 r
.24566 .47033 m .25299 .47213 L .24782 .46871 L p F P
0 g
s
.636 .108 0 r
.24349 .46887 m .24566 .47033 L p .24782 .46871 L F P
0 g
s
.636 .108 0 r
.24782 .46871 m .24633 .46834 L .24349 .46887 L p F P
0 g
s
.269 0 0 r
.5665 .46833 m .56875 .46568 L .55742 .46869 L p F P
0 g
s
.269 0 0 r
.56311 .46923 m .5665 .46833 L p .55742 .46869 L F P
0 g
s
.269 0 0 r
.55742 .46869 m .55536 .47111 L .56311 .46923 L p F P
0 g
s
.427 0 0 r
.36234 .49406 m .35298 .49185 L .34966 .49278 L p F P
0 g
s
.315 0 0 r
.50563 .48341 m .50778 .4832 L .50541 .48362 L closepath p F P
0 g
s
.366 .076 .334 r
.66287 .41176 m .6632 .41006 L .65314 .41477 L p F P
0 g
s
.366 .076 .334 r
.6576 .4163 m .66287 .41176 L p .65314 .41477 L F P
0 g
s
.366 .076 .334 r
.65314 .41477 m .65237 .41875 L .6576 .4163 L p F P
0 g
s
.19 0 0 r
.3225 .35259 m .32319 .35274 L .32203 .35252 L closepath p F P
0 g
s
0 0 0 r
.48901 .35146 m .47811 .35336 L .47509 .35408 L p F P
0 g
s
.363 .834 .865 r
.52778 .34239 m .52926 .34233 L .51791 .34542 L p F P
0 g
s
.363 .834 .865 r
.51791 .34542 m .5168 .34545 L .52778 .34239 L p F P
0 g
s
.286 0 .061 r
.60508 .45024 m .60553 .44947 L .59471 .45312 L p F P
0 g
s
.286 0 .061 r
.59471 .45312 m .594 .45433 L .60508 .45024 L p F P
0 g
s
.52 0 0 r
.31443 .4876 m .30838 .48528 L .30495 .48611 L p F P
0 g
s
.813 .721 .763 r
.11594 .33108 m .11278 .33476 L .11747 .33763 L p F P
0 g
s
.826 .713 .74 r
.10802 .34122 m .11281 .34405 L .11747 .33763 L p F P
0 g
s
.826 .713 .74 r
.11747 .33763 m .11278 .33476 L .10802 .34122 L p F P
0 g
s
.767 .313 .17 r
.19253 .44715 m .18937 .44316 L .19555 .44537 L p F P
0 g
s
.767 .313 .17 r
.1927 .44721 m .19253 .44715 L p .19555 .44537 L F P
0 g
s
.767 .313 .17 r
.19555 .44537 m .19631 .4463 L .1927 .44721 L p F P
0 g
s
.624 .909 .983 r
.59289 .3244 m .59428 .32497 L .58322 .32908 L p F P
0 g
s
.624 .909 .983 r
.58322 .32908 m .58258 .32885 L .59289 .3244 L p F P
0 g
s
.321 0 .177 r
.62749 .43576 m .61871 .44007 L .61777 .44238 L p F P
0 g
s
.847 .681 .676 r
.1099 .35778 m .11143 .35864 L .1141 .35289 L p F P
0 g
s
.847 .681 .676 r
.10768 .3533 m .1099 .35778 L p .1141 .35289 L F P
0 g
s
.847 .681 .676 r
.1141 .35289 m .1092 .35011 L .10768 .3533 L p F P
0 g
s
.661 .143 0 r
.24633 .46834 m .24349 .46887 L .24067 .46685 L closepath p F P
0 g
s
.843 .478 .362 r
.14734 .41641 m .15287 .41888 L .15137 .41443 L p F P
0 g
s
.843 .478 .362 r
.15137 .41443 m .14582 .41196 L .14734 .41641 L p F P
0 g
s
.259 0 0 r
.38094 .35939 m .38263 .35958 L .39462 .35992 L p F P
0 g
s
.228 0 0 r
.38094 .35939 m .38263 .35958 L .38028 .35947 L closepath p F P
0 g
s
.577 .558 .797 r
.69181 .32445 m .69029 .32461 L .68222 .32973 L p F P
0 g
s
.577 .558 .797 r
.69467 .33158 m .69181 .32445 L p .68222 .32973 L F P
0 g
s
.598 .584 .808 r
.68047 .32593 m .69029 .32461 L .68222 .32973 L closepath p F P
0 g
s
.44 .24 .511 r
.68393 .38671 m .67969 .38899 L .68054 .38361 L p F P
0 g
s
.44 .24 .511 r
.68054 .38361 m .68384 .38183 L .68393 .38671 L p F P
0 g
s
.208 0 0 r
.32355 .35326 m .33242 .35464 L .32319 .35274 L p F P
0 g
s
.208 0 0 r
.31915 .35214 m .32355 .35326 L p .32319 .35274 L F P
0 g
s
.208 0 0 r
.32319 .35274 m .32203 .35252 L .31915 .35214 L p F P
0 g
s
.26 0 0 r
.50778 .4832 m .50541 .48362 L .50269 .48565 L p F P
0 g
s
.583 .042 0 r
.27763 .4782 m .28196 .48041 L .27433 .47894 L closepath p F P
0 g
s
.69 .189 .05 r
.23363 .46494 m .23007 .46211 L .22645 .46289 L p F P
0 g
s
.298 0 0 r
.46488 .4907 m .46396 .4912 L .45925 .49121 L closepath p F P
0 g
s
.293 0 0 r
.46152 .49254 m .46396 .4912 L .45925 .49121 L p F P
0 g
s
.293 0 0 r
.4578 .49287 m .46152 .49254 L p .45925 .49121 L F P
0 g
s
.293 0 0 r
.45005 .49281 m .4578 .49287 L p .45925 .49121 L F P
0 g
s
.5 .72 .971 r
.18236 .31904 m .18281 .31901 L .18777 .32177 L p F P
0 g
s
.514 .741 .977 r
.19259 .31829 m .18281 .31901 L .18777 .32177 L p F P
0 g
s
.514 .741 .977 r
.18777 .32177 m .19606 .32095 L .19259 .31829 L p F P
0 g
s
.175 0 0 r
.32203 .35252 m .31915 .35214 L .31462 .35126 L closepath p F P
0 g
s
.39 .849 .867 r
.54038 .33893 m .54166 .33888 L .53067 .34227 L p F P
0 g
s
.39 .849 .867 r
.53067 .34227 m .52926 .34233 L .54038 .33893 L p F P
0 g
s
.518 0 0 r
.30462 .48619 m .30495 .48611 L .29853 .48338 L p F P
0 g
s
.518 0 0 r
.29698 .4849 m .30462 .48619 L p .29853 .48338 L F P
0 g
s
.518 0 0 r
.29126 .4825 m .29698 .4849 L p .29853 .48338 L F P
0 g
s
.518 0 0 r
.29853 .48338 m .29212 .48233 L .29126 .4825 L p F P
0 g
s
.292 0 0 r
.55515 .47134 m .55536 .47111 L .54432 .47334 L p F P
0 g
s
.292 0 0 r
.54432 .47334 m .54363 .47413 L .55515 .47134 L p F P
0 g
s
.001 0 0 r
.47443 .35431 m .47509 .35408 L .46422 .35555 L p F P
0 g
s
.001 0 0 r
.46422 .35555 m .46198 .35614 L .47443 .35431 L p F P
0 g
s
.22 0 0 r
.29867 .3479 m .29171 .34635 L .28832 .34533 L p F P
0 g
s
.175 .629 .938 r
.2388 .33189 m .23026 .33095 L .22682 .32879 L p F P
0 g
s
.584 .036 0 r
.26622 .47716 m .27389 .47885 L .2681 .47559 L p F P
0 g
s
.584 .036 0 r
.26055 .47403 m .26622 .47716 L p .2681 .47559 L F P
0 g
s
.584 .036 0 r
.2681 .47559 m .26071 .47401 L .26055 .47403 L p F P
0 g
s
.429 0 0 r
.34868 .49305 m .34966 .49278 L .34281 .49092 L p F P
0 g
s
.429 0 0 r
.34167 .49238 m .34868 .49305 L p .34281 .49092 L F P
0 g
s
.429 0 0 r
.33586 .49079 m .34167 .49238 L p .34281 .49092 L F P
0 g
s
.429 0 0 r
.34281 .49092 m .3374 .49042 L .33586 .49079 L p F P
0 g
s
.261 0 0 r
.51748 .48148 m .51659 .48217 L .50778 .4832 L closepath p F P
0 g
s
.26 0 0 r
.51463 .48367 m .51659 .48217 L .50778 .4832 L p F P
0 g
s
.26 0 0 r
.5044 .48547 m .51463 .48367 L p .50778 .4832 L F P
0 g
s
.26 0 0 r
.50269 .48565 m .5044 .48547 L p .50778 .4832 L F P
0 g
s
0 .505 .808 r
.26792 .34017 m .26097 .33885 L .25756 .33725 L p F P
0 g
s
.162 0 0 r
.40901 .35996 m .40866 .36002 L .40752 .35997 L closepath p F P
0 g
s
.141 0 0 r
.40547 .36079 m .40866 .36002 L .40752 .35997 L p F P
0 g
s
.141 0 0 r
.39479 .35993 m .40547 .36079 L p .40752 .35997 L F P
0 g
s
.141 0 0 r
.40752 .35997 m .39485 .35993 L .39479 .35993 L p F P
0 g
s
.119 0 0 r
.42173 .35959 m .40901 .35996 L .40866 .36002 L p F P
0 g
s
.176 0 0 r
.39485 .35993 m .39479 .35993 L .39462 .35992 L closepath p F P
0 g
s
.219 0 0 r
.39157 .36057 m .38263 .35958 L .39462 .35992 L p F P
0 g
s
.219 0 0 r
.39462 .35992 m .39479 .35993 L .39157 .36057 L p F P
0 g
s
.429 .722 .987 r
.19951 .32362 m .20972 .32349 L .21318 .32593 L p F P
0 g
s
.394 .712 .986 r
.20972 .32349 m .19951 .32362 L .19606 .32095 L p F P
0 g
s
.73 .743 .862 r
.13684 .32134 m .14088 .31896 L .1374 .31545 L p F P
0 g
s
.73 .743 .862 r
.1374 .31545 m .13208 .31849 L .13684 .32134 L p F P
0 g
s
.743 .733 .843 r
.12681 .32172 m .13208 .31849 L .13684 .32134 L p F P
0 g
s
.783 .341 .199 r
.17717 .43866 m .18325 .44092 L .18038 .43686 L p F P
0 g
s
.783 .341 .199 r
.17586 .43678 m .17717 .43866 L p .18038 .43686 L F P
0 g
s
.783 .341 .199 r
.18038 .43686 m .1784 .43613 L .17586 .43678 L p F P
0 g
s
.476 .35 .629 r
.70188 .35997 m .70093 .3541 L .69151 .35984 L p F P
0 g
s
.476 .35 .629 r
.69265 .36563 m .70188 .35997 L p .69151 .35984 L F P
0 g
s
.476 .35 .629 r
.69151 .35984 m .69243 .36543 L .69265 .36563 L p F P
0 g
s
.319 0 0 r
.40547 .36079 m .39479 .35993 L .39157 .36057 L p F P
0 g
s
.407 0 0 r
.36679 .49328 m .37349 .49465 L .36402 .49418 L closepath p F P
0 g
s
.757 .296 .155 r
.19631 .4463 m .1989 .4493 L .1927 .44721 L closepath p F P
0 g
s
.273 0 0 r
.47484 .4909 m .47764 .48931 L .46488 .4907 L p F P
0 g
s
.273 0 0 r
.46488 .4907 m .46396 .4912 L .47484 .4909 L p F P
0 g
s
.833 .447 .321 r
.15472 .42323 m .15287 .41888 L .15847 .42132 L p F P
0 g
s
.833 .447 .321 r
.1573 .42436 m .15472 .42323 L p .15847 .42132 L F P
0 g
s
.833 .447 .321 r
.15847 .42132 m .15939 .42345 L .1573 .42436 L p F P
0 g
s
.724 .242 .1 r
.21314 .45492 m .21564 .45732 L .2101 .45563 L closepath p F P
0 g
s
.284 0 0 r
.5025 .48579 m .50269 .48565 L .49175 .4865 L p F P
0 g
s
.284 0 0 r
.49175 .4865 m .49016 .48765 L .5025 .48579 L p F P
0 g
s
.627 .91 .982 r
.59151 .32384 m .59289 .3244 L .58258 .32885 L p F P
0 g
s
.627 .91 .982 r
.58258 .32885 m .58043 .32809 L .59151 .32384 L p F P
0 g
s
.379 .113 .38 r
.66639 .40847 m .6632 .41006 L .66376 .40587 L p F P
0 g
s
.379 .113 .38 r
.66376 .40587 m .67286 .40135 L .66639 .40847 L p F P
0 g
s
.669 .754 .914 r
.63584 .31873 m .647 .31494 L .64974 .31813 L p F P
0 g
s
.676 .783 .93 r
.647 .31494 m .63584 .31873 L .63311 .31612 L p F P
0 g
s
.676 .798 .94 r
.62198 .32016 m .63311 .31612 L .63584 .31873 L p F P
0 g
s
.133 0 0 r
.42276 .35955 m .42254 .3596 L .42173 .35959 L closepath p F P
0 g
s
.119 0 0 r
.41938 .36046 m .42254 .3596 L .42173 .35959 L p F P
0 g
s
.119 0 0 r
.40866 .36002 m .41938 .36046 L p .42173 .35959 L F P
0 g
s
.239 0 0 r
.39072 .3608 m .39157 .36057 L .38263 .35958 L p F P
0 g
s
.239 0 0 r
.38202 .3605 m .39072 .3608 L p .38263 .35958 L F P
0 g
s
.239 0 0 r
.3777 .35984 m .38202 .3605 L p .38263 .35958 L F P
0 g
s
.239 0 0 r
.38263 .35958 m .38028 .35947 L .3777 .35984 L p F P
0 g
s
0 .484 .779 r
.27464 .34203 m .27509 .34213 L .28204 .34417 L p F P
0 g
s
0 .513 .776 r
.28384 .34414 m .27509 .34213 L .28204 .34417 L p F P
0 g
s
0 .513 .776 r
.28581 .34462 m .28384 .34414 L p .28204 .34417 L F P
0 g
s
0 .513 .776 r
.28204 .34417 m .28832 .34533 L .28581 .34462 L p F P
0 g
s
.064 0 0 r
.45032 .35734 m .45659 .35676 L .44923 .35765 L closepath p F P
0 g
s
.113 0 0 r
.44923 .35765 m .45032 .35734 L p .43643 .35869 L F P
0 g
s
.124 0 0 r
.43331 .35961 m .43615 .35877 L .42276 .35955 L p F P
0 g
s
.124 0 0 r
.42276 .35955 m .42254 .3596 L .43331 .35961 L p F P
0 g
s
.114 .595 .912 r
.24391 .33393 m .24514 .33415 L .25139 .33644 L p F P
0 g
s
.144 .628 .92 r
.25413 .33566 m .24514 .33415 L .25139 .33644 L p F P
0 g
s
.144 .628 .92 r
.25139 .33644 m .25756 .33725 L .25413 .33566 L p F P
0 g
s
.665 .736 .903 r
.66093 .31471 m .64974 .31813 L .647 .31494 L p F P
0 g
s
.655 .707 .885 r
.64974 .31813 m .66093 .31471 L .66367 .31859 L p F P
0 g
s
.868 .597 .526 r
.11746 .38492 m .12259 .38758 L .12278 .38262 L p F P
0 g
s
.868 .597 .526 r
.12278 .38262 m .11765 .37997 L .11746 .38492 L p F P
0 g
s
.262 0 0 r
.38028 .35947 m .3777 .35984 L .37141 .35898 L closepath p F P
0 g
s
.611 .597 .812 r
.69029 .32461 m .68047 .32593 L .67768 .32049 L p F P
0 g
s
.46 0 0 r
.3374 .49042 m .33586 .49079 L .333 .48993 L closepath p F P
0 g
s
.266 0 0 r
.59134 .45841 m .59291 .45615 L .58192 .45959 L p F P
0 g
s
.266 0 0 r
.58192 .45959 m .58024 .46198 L .59134 .45841 L p F P
0 g
s
.838 .699 .709 r
.10451 .3474 m .1092 .35011 L .11281 .34405 L p F P
0 g
s
.838 .699 .709 r
.10441 .34722 m .10451 .3474 L p .11281 .34405 L F P
0 g
s
.838 .699 .709 r
.11281 .34405 m .10802 .34122 L .10441 .34722 L p F P
0 g
s
.867 .62 .564 r
.11432 .3782 m .11765 .37997 L .11834 .37485 L p F P
0 g
s
.867 .62 .564 r
.11834 .37485 m .1143 .37271 L .11432 .3782 L p F P
0 g
s
.59 .916 .973 r
.58043 .32809 m .56938 .33214 L .56657 .33151 L p F P
0 g
s
.867 .573 .487 r
.12284 .3924 m .12802 .39503 L .12777 .39021 L p F P
0 g
s
.867 .573 .487 r
.12777 .39021 m .12259 .38758 L .12284 .3924 L p F P
0 g
s
.351 .707 .985 r
.22337 .32663 m .21539 .3261 L .22111 .32858 L p F P
0 g
s
.351 .707 .985 r
.22111 .32858 m .22682 .32879 L .22337 .32663 L p F P
0 g
s
.324 .681 .978 r
.21318 .32593 m .21539 .3261 L .22111 .32858 L p F P
0 g
s
.292 0 0 r
.41938 .36046 m .40866 .36002 L .40547 .36079 L p F P
0 g
s
.857 .517 .408 r
.14051 .40553 m .13952 .40629 L .1392 .40491 L closepath p F P
0 g
s
.675 .841 .963 r
.63085 .31425 m .63311 .31612 L .62198 .32016 L p F P
0 g
s
.675 .841 .963 r
.62198 .32016 m .62114 .31953 L .63085 .31425 L p F P
0 g
s
.627 .749 .935 r
.16514 .31486 m .1548 .31786 L .15132 .31455 L p F P
0 g
s
.69 .751 .898 r
.14088 .31896 m .15132 .31455 L .1548 .31786 L p F P
0 g
s
.637 .751 .93 r
.1548 .31786 m .16514 .31486 L .16861 .31797 L p F P
0 g
s
.122 0 0 r
.43643 .35869 m .43774 .35863 L .43615 .35877 L closepath p F P
0 g
s
.113 0 0 r
.43643 .35869 m .43774 .35863 L .44923 .35765 L p F P
0 g
s
.242 0 0 r
.33625 .35492 m .34137 .35599 L .33321 .35476 L closepath p F P
0 g
s
.704 .207 .058 r
.21993 .46099 m .21564 .45732 L .22237 .45933 L p F P
0 g
s
.704 .207 .058 r
.22627 .46292 m .21993 .46099 L p .22237 .45933 L F P
0 g
s
.704 .207 .058 r
.22237 .45933 m .22645 .46289 L .22627 .46292 L p F P
0 g
s
.252 0 0 r
.43331 .35961 m .42254 .3596 L .41938 .36046 L p F P
0 g
s
.863 .643 .603 r
.11452 .36687 m .11293 .36601 L .11378 .36995 L closepath p F P
0 g
s
.865 .548 .448 r
.12868 .39973 m .13391 .40233 L .13325 .39763 L p F P
0 g
s
.865 .548 .448 r
.13325 .39763 m .12802 .39503 L .12868 .39973 L p F P
0 g
s
.798 .366 .221 r
.1784 .43613 m .17586 .43678 L .17441 .43457 L closepath p F P
0 g
s
.682 .751 .903 r
.15132 .31455 m .14088 .31896 L .1374 .31545 L p F P
0 g
s
.548 0 0 r
.29212 .48233 m .29126 .4825 L .29007 .48195 L closepath p F P
0 g
s
.234 0 0 r
.37595 .36019 m .3777 .35984 L .37141 .35898 L p F P
0 g
s
.234 0 0 r
.37086 .35987 m .37595 .36019 L p .37141 .35898 L F P
0 g
s
.234 0 0 r
.36385 .35861 m .37086 .35987 L p .37141 .35898 L F P
0 g
s
.234 0 0 r
.37141 .35898 m .36521 .35851 L .36385 .35861 L p F P
0 g
s
.661 .142 0 r
.23849 .46846 m .23363 .46494 L .24067 .46685 L p F P
0 g
s
.661 .142 0 r
.24139 .46925 m .23849 .46846 L p .24067 .46685 L F P
0 g
s
.661 .142 0 r
.24067 .46685 m .24349 .46887 L .24139 .46925 L p F P
0 g
s
.737 .257 .105 r
.20262 .45313 m .209 .45527 L .20532 .45143 L p F P
0 g
s
.737 .257 .105 r
.20532 .45143 m .1989 .4493 L .20262 .45313 L p F P
0 g
s
.224 0 0 r
.30541 .34929 m .30663 .34959 L .31462 .35126 L p F P
0 g
s
.189 0 0 r
.3161 .3518 m .31531 .35166 L p .31462 .35126 L F P
0 g
s
.189 0 0 r
.31462 .35126 m .31915 .35214 L .3161 .3518 L p F P
0 g
s
.507 0 0 r
.3221 .48833 m .32351 .48883 L .333 .48993 L p F P
0 g
s
.459 0 0 r
.33182 .49138 m .32351 .48883 L .333 .48993 L p F P
0 g
s
.459 0 0 r
.33288 .49151 m .33182 .49138 L p .333 .48993 L F P
0 g
s
.459 0 0 r
.333 .48993 m .33586 .49079 L .33288 .49151 L p F P
0 g
s
.3 .796 .807 r
.52778 .34239 m .5168 .34545 L .51388 .34585 L p F P
0 g
s
.247 .76 .775 r
.50291 .34854 m .51388 .34585 L .5168 .34545 L p F P
0 g
s
.157 .694 .711 r
.49995 .34922 m .50222 .3487 L .49037 .35121 L p F P
0 g
s
.157 .694 .711 r
.49037 .35121 m .48901 .35146 L .49995 .34922 L p F P
0 g
s
.637 .659 .855 r
.66367 .31859 m .67492 .3157 L .6758 .3172 L p F P
0 g
s
.648 .686 .872 r
.67492 .3157 m .66367 .31859 L .66093 .31471 L p F P
0 g
s
.391 0 0 r
.38063 .49429 m .38517 .49508 L .37893 .4949 L closepath p F P
0 g
s
.29 0 .008 r
.57991 .46245 m .58024 .46198 L .56917 .46508 L p F P
0 g
s
.29 0 .008 r
.56917 .46508 m .56875 .46568 L .57991 .46245 L p F P
0 g
s
.284 0 .058 r
.60375 .45249 m .60508 .45024 L .594 .45433 L p F P
0 g
s
.284 0 .058 r
.594 .45433 m .59291 .45615 L .60375 .45249 L p F P
0 g
s
.574 .748 .959 r
.18125 .31811 m .18236 .31904 L p .16861 .31797 L F P
0 g
s
.574 .748 .959 r
.16861 .31797 m .17721 .31645 L .18125 .31811 L p F P
0 g
s
.56 .741 .961 r
.17721 .31645 m .16861 .31797 L .16514 .31486 L p F P
0 g
s
.129 0 0 r
.43774 .35863 m .43615 .35877 L .43331 .35961 L p F P
0 g
s
.503 0 0 r
.3221 .48833 m .32351 .48883 L .3213 .48856 L closepath p F P
0 g
s
.426 .23 .509 r
.69355 .38127 m .69344 .37638 L .68384 .38183 L p F P
0 g
s
.426 .23 .509 r
.68384 .38183 m .68393 .38671 L .69355 .38127 L p F P
0 g
s
.308 0 0 r
.47786 .48915 m .47929 .4891 L .47764 .48931 L closepath p F P
0 g
s
.358 .016 .242 r
.62978 .43456 m .62749 .43576 L .62966 .43492 L closepath p F P
0 g
s
.321 0 .177 r
.62829 .4383 m .62966 .43492 L .62749 .43576 L p F P
0 g
s
.321 0 .177 r
.61777 .44238 m .62829 .4383 L p .62749 .43576 L F P
0 g
s
.858 .518 .407 r
.13494 .40693 m .13391 .40233 L .1392 .40491 L p F P
0 g
s
.858 .518 .407 r
.1372 .40802 m .13494 .40693 L p .1392 .40491 L F P
0 g
s
.858 .518 .407 r
.1392 .40491 m .13952 .40629 L .1372 .40802 L p F P
0 g
s
.546 0 0 r
.2878 .48313 m .28196 .48041 L .29007 .48195 L p F P
0 g
s
.546 0 0 r
.29007 .48195 m .29126 .4825 L .2878 .48313 L p F P
0 g
s
.813 .398 .261 r
.16277 .42985 m .16857 .43222 L .16622 .42801 L p F P
0 g
s
.813 .398 .261 r
.16622 .42801 m .1604 .42565 L .16277 .42985 L p F P
0 g
s
.857 .665 .641 r
.11143 .35864 m .1099 .35778 L .11087 .36023 L closepath p F P
0 g
s
.13 0 0 r
.44923 .35765 m .44724 .35823 L .43774 .35863 L closepath p F P
0 g
s
.129 0 0 r
.4456 .35887 m .44724 .35823 L .43774 .35863 L p F P
0 g
s
.129 0 0 r
.43735 .35953 m .4456 .35887 L p .43774 .35863 L F P
0 g
s
.129 0 0 r
.43331 .35961 m .43735 .35953 L p .43774 .35863 L F P
0 g
s
.557 .911 .965 r
.55583 .33547 m .55553 .33541 L .5641 .33238 L closepath p F P
0 g
s
.241 0 0 r
.55265 .47378 m .55515 .47134 L .54363 .47413 L p F P
0 g
s
.241 0 0 r
.55012 .4744 m .55265 .47378 L p .54363 .47413 L F P
0 g
s
.241 0 0 r
.54363 .47413 m .54149 .47619 L .55012 .4744 L p F P
0 g
s
.673 .868 .973 r
.61924 .3181 m .60813 .3223 L .60537 .32072 L p F P
0 g
s
.663 .877 .979 r
.59428 .32497 m .60537 .32072 L .60813 .3223 L p F P
0 g
s
.246 0 0 r
.36521 .35851 m .36385 .35861 L .36089 .35816 L closepath p F P
0 g
s
.51 .403 .668 r
.69471 .35074 m .69956 .34772 L .70076 .35325 L closepath p F P
0 g
s
.612 .073 0 r
.26071 .47401 m .26055 .47403 L .26036 .47392 L closepath p F P
0 g
s
.789 .725 .793 r
.11249 .32692 m .11492 .32471 L .11971 .32756 L p F P
0 g
s
.789 .725 .793 r
.11971 .32756 m .11594 .33108 L .11249 .32692 L p F P
0 g
s
.773 .734 .817 r
.11971 .32756 m .12681 .32172 L .12333 .31797 L p F P
0 g
s
.773 .734 .817 r
.12333 .31797 m .11492 .32471 L .11971 .32756 L p F P
0 g
s
.771 .314 .162 r
.18643 .4449 m .19253 .44715 L .18937 .44316 L p F P
0 g
s
.771 .314 .162 r
.18937 .44316 m .18325 .44092 L .18643 .4449 L p F P
0 g
s
.812 .724 .767 r
.11278 .33476 m .11594 .33108 L .11249 .32692 L p F P
0 g
s
.61 .069 0 r
.25702 .47457 m .25299 .47213 L .26036 .47392 L p F P
0 g
s
.61 .069 0 r
.26036 .47392 m .26055 .47403 L .25702 .47457 L p F P
0 g
s
.864 .662 .629 r
.11087 .36023 m .10964 .36411 L .11293 .36601 L closepath p F P
0 g
s
.871 .647 .597 r
.1133 .37215 m .11378 .36995 L .11293 .36601 L p F P
0 g
s
.871 .647 .597 r
.10845 .36938 m .1133 .37215 L p .11293 .36601 L F P
0 g
s
.871 .647 .597 r
.11293 .36601 m .10964 .36411 L .10845 .36938 L p F P
0 g
s
.247 0 0 r
.47929 .4891 m .47764 .48931 L .47484 .4909 L p F P
0 g
s
.336 0 .234 r
.64002 .43061 m .64084 .42811 L .62978 .43456 L p F P
0 g
s
.336 0 .234 r
.62978 .43456 m .62966 .43492 L .64002 .43061 L p F P
0 g
s
.296 .662 .972 r
.21539 .3261 m .21318 .32593 L .20972 .32349 L p F P
0 g
s
.597 .054 0 r
.26622 .47716 m .26055 .47403 L .25702 .47457 L p F P
0 g
s
.413 .193 .467 r
.68379 .39133 m .67713 .3949 L .67969 .38899 L p F P
0 g
s
.413 .193 .467 r
.67969 .38899 m .68393 .38671 L .68379 .39133 L p F P
0 g
s
.234 0 0 r
.5276 .48053 m .52938 .47913 L .51748 .48148 L p F P
0 g
s
.234 0 0 r
.51748 .48148 m .51659 .48217 L .5276 .48053 L p F P
0 g
s
.304 0 0 r
.35004 .35693 m .35099 .35712 L .36089 .35816 L p F P
0 g
s
.271 0 0 r
.36047 .35899 m .35099 .35712 L .36089 .35816 L p F P
0 g
s
.271 0 0 r
.3606 .359 m .36047 .35899 L p .36089 .35816 L F P
0 g
s
.271 0 0 r
.36089 .35816 m .36385 .35861 L .3606 .359 L p F P
0 g
s
.373 0 0 r
.39448 .49488 m .39749 .4953 L .39347 .49528 L closepath p F P
0 g
s
.485 .35 .621 r
.69243 .36543 m .69265 .36563 L .69248 .36573 L closepath p F P
0 g
s
.503 .902 .929 r
.5641 .33238 m .55553 .33541 L .55269 .3352 L p F P
0 g
s
.481 .891 .926 r
.54166 .33888 m .55269 .3352 L .55553 .33541 L p F P
0 g
s
.193 0 0 r
.30541 .34929 m .30663 .34959 L .30447 .34909 L closepath p F P
0 g
s
.677 .842 .963 r
.63038 .31385 m .63085 .31425 L .62114 .31953 L p F P
0 g
s
.677 .842 .963 r
.62114 .31953 m .61924 .3181 L .63038 .31385 L p F P
0 g
s
.136 .602 .924 r
.24391 .33393 m .24514 .33415 L .24229 .33304 L closepath p F P
0 g
s
.251 0 0 r
.49016 .48765 m .48877 .48849 L .47929 .4891 L closepath p F P
0 g
s
.247 0 0 r
.48694 .48956 m .48877 .48849 L .47929 .4891 L p F P
0 g
s
.247 0 0 r
.47799 .49073 m .48694 .48956 L p .47929 .4891 L F P
0 g
s
.247 0 0 r
.47484 .4909 m .47799 .49073 L p .47929 .4891 L F P
0 g
s
.271 0 0 r
.47434 .49118 m .47484 .4909 L .46396 .4912 L p F P
0 g
s
.271 0 0 r
.46396 .4912 m .46152 .49254 L .47434 .49118 L p F P
0 g
s
.265 0 0 r
.5411 .47657 m .54149 .47619 L .53047 .4781 L p F P
0 g
s
.265 0 0 r
.53047 .4781 m .52938 .47913 L .5411 .47657 L p F P
0 g
s
.464 .311 .588 r
.69523 .36993 m .69309 .37121 L .69248 .36573 L p F P
0 g
s
.464 .311 .588 r
.69248 .36573 m .69265 .36563 L .69523 .36993 L p F P
0 g
s
.866 .667 .631 r
.10964 .36411 m .11087 .36023 L .1099 .35778 L p F P
0 g
s
.826 .435 .311 r
.15939 .42345 m .1604 .42565 L .1573 .42436 L closepath p F P
0 g
s
.845 .477 .356 r
.14185 .41391 m .14734 .41641 L .14582 .41196 L p F P
0 g
s
.845 .477 .356 r
.14582 .41196 m .14032 .40947 L .14185 .41391 L p F P
0 g
s
.738 .736 .85 r
.13208 .31849 m .12681 .32172 L .12333 .31797 L p F P
0 g
s
.391 .15 .424 r
.67404 .39653 m .67375 .40009 L .67713 .3949 L closepath p F P
0 g
s
.461 .31 .589 r
.70252 .36548 m .69523 .36993 L .69265 .36563 L p F P
0 g
s
.461 .31 .589 r
.69265 .36563 m .70188 .35997 L .70252 .36548 L p F P
0 g
s
.812 .724 .767 r
.11249 .32692 m .10813 .33187 L .11278 .33476 L p F P
0 g
s
.827 .716 .742 r
.10328 .33836 m .10802 .34122 L .11278 .33476 L p F P
0 g
s
.827 .716 .742 r
.11278 .33476 m .10813 .33187 L .10328 .33836 L p F P
0 g
s
0 .496 .799 r
.27464 .34203 m .27509 .34213 L .27418 .34185 L closepath p F P
0 g
s
.295 0 .162 r
.63867 .43401 m .64002 .43061 L .62966 .43492 L p F P
0 g
s
.295 0 .162 r
.62966 .43492 m .62829 .4383 L .63867 .43401 L p F P
0 g
s
.849 .684 .677 r
.1092 .35011 m .10451 .3474 L .10768 .3533 L closepath p F P
0 g
s
.858 .68 .66 r
.10768 .3533 m .10663 .35584 L .1099 .35778 L closepath p F P
0 g
s
.866 .667 .631 r
.10486 .3613 m .10964 .36411 L p .1099 .35778 L F P
0 g
s
.866 .667 .631 r
.1099 .35778 m .10663 .35584 L .10486 .3613 L p F P
0 g
s
.501 .719 .969 r
.18236 .31904 m .18281 .31901 L .18125 .31811 L closepath p F P
0 g
s
.441 0 0 r
.32249 .49022 m .33182 .49138 L .32351 .48883 L p F P
0 g
s
.441 0 0 r
.31871 .48906 m .32249 .49022 L p .32351 .48883 L F P
0 g
s
.441 0 0 r
.32351 .48883 m .3213 .48856 L .31871 .48906 L p F P
0 g
s
.531 0 0 r
.29698 .4849 m .29126 .4825 L .2878 .48313 L p F P
0 g
s
.868 .643 .595 r
.11378 .36995 m .1133 .37215 L .1143 .37271 L closepath p F P
0 g
s
.241 0 0 r
.57769 .46509 m .57991 .46245 L .56875 .46568 L p F P
0 g
s
.241 0 0 r
.56875 .46568 m .5665 .46833 L .57769 .46509 L p F P
0 g
s
.386 .847 .864 r
.5388 .33901 m .54038 .33893 L .52926 .34233 L p F P
0 g
s
.386 .847 .864 r
.52926 .34233 m .52778 .34239 L .5388 .33901 L p F P
0 g
s
.28 0 0 r
.35004 .35693 m .35099 .35712 L .34954 .35695 L closepath p F P
0 g
s
.853 .509 .401 r
.13952 .40629 m .14032 .40947 L .1372 .40802 L closepath p F P
0 g
s
.184 .711 .705 r
.51381 .34586 m .51388 .34585 L .50291 .34854 L p F P
0 g
s
.184 .711 .705 r
.50291 .34854 m .50222 .3487 L .51381 .34586 L p F P
0 g
s
.355 0 0 r
.40836 .49502 m .41065 .49527 L .40767 .49532 L closepath p F P
0 g
s
.315 0 .222 r
.64119 .42703 m .64084 .42811 L .6455 .42514 L closepath p F P
0 g
s
.071 0 0 r
.45659 .35676 m .44923 .35765 L .44724 .35823 L p F P
0 g
s
.294 0 0 r
.45005 .49281 m .4578 .49287 L .44845 .49364 L closepath p F P
0 g
s
.283 0 .114 r
.62729 .44037 m .62829 .4383 L .61777 .44238 L p F P
0 g
s
.283 0 .114 r
.61681 .44538 m .62729 .44037 L p .61777 .44238 L F P
0 g
s
.283 0 .114 r
.61777 .44238 m .61622 .44561 L .61681 .44538 L p F P
0 g
s
.493 .717 .971 r
.18911 .31562 m .19259 .31829 L .18281 .31901 L p F P
0 g
s
.493 .717 .971 r
.17889 .31615 m .18911 .31562 L p .18281 .31901 L F P
0 g
s
.493 .717 .971 r
.18281 .31901 m .18125 .31811 L .17889 .31615 L p F P
0 g
s
0 .478 .78 r
.27652 .34221 m .28384 .34414 L .27509 .34213 L p F P
0 g
s
0 .478 .78 r
.27123 .34076 m .27652 .34221 L p .27509 .34213 L F P
0 g
s
0 .478 .78 r
.27509 .34213 m .27418 .34185 L .27123 .34076 L p F P
0 g
s
.645 .907 .982 r
.60294 .31958 m .60537 .32072 L .59428 .32497 L p F P
0 g
s
.645 .907 .982 r
.59428 .32497 m .59289 .3244 L .60294 .31958 L p F P
0 g
s
.474 0 0 r
.3213 .48856 m .31871 .48906 L .31443 .4876 L closepath p F P
0 g
s
.799 .366 .219 r
.17123 .43634 m .16857 .43222 L .17441 .43457 L p F P
0 g
s
.799 .366 .219 r
.17367 .43732 m .17123 .43634 L p .17441 .43457 L F P
0 g
s
.799 .366 .219 r
.17441 .43457 m .17586 .43678 L .17367 .43732 L p F P
0 g
s
.335 0 0 r
.42225 .49473 m .42487 .49492 L .42155 .49505 L closepath p F P
0 g
s
.611 .597 .812 r
.69153 .32381 m .69029 .32461 L p .67768 .32049 L F P
0 g
s
.611 .597 .812 r
.67768 .32049 m .689 .31847 L .69153 .32381 L p F P
0 g
s
.611 .639 .854 r
.6758 .3172 m .67768 .32049 L .689 .31847 L p F P
0 g
s
.315 0 0 r
.43615 .49399 m .44044 .49416 L .43513 .49448 L closepath p F P
0 g
s
.214 0 0 r
.30705 .35006 m .31531 .35166 L .30663 .34959 L p F P
0 g
s
.214 0 0 r
.30204 .34861 m .30705 .35006 L p .30663 .34959 L F P
0 g
s
.214 0 0 r
.30663 .34959 m .30447 .34909 L .30204 .34861 L p F P
0 g
s
.873 .626 .562 r
.11263 .37726 m .11432 .3782 L .1143 .37271 L p F P
0 g
s
.873 .626 .562 r
.1143 .37271 m .1133 .37215 L .11263 .37726 L p F P
0 g
s
.113 .589 .913 r
.25339 .33533 m .25413 .33566 L .24514 .33415 L p F P
0 g
s
.113 .589 .913 r
.24812 .33364 m .25339 .33533 L p .24514 .33415 L F P
0 g
s
.113 .589 .913 r
.24047 .33206 m .24812 .33364 L p .24514 .33415 L F P
0 g
s
.113 .589 .913 r
.24514 .33415 m .24229 .33304 L .24047 .33206 L p F P
0 g
s
.013 .554 .84 r
.27418 .34185 m .27123 .34076 L .26792 .34017 L closepath p F P
0 g
s
.837 .449 .314 r
.1492 .42076 m .15472 .42323 L .15287 .41888 L p F P
0 g
s
.837 .449 .314 r
.15287 .41888 m .14734 .41641 L .1492 .42076 L p F P
0 g
s
.294 0 0 r
.35041 .358 m .36047 .35899 L .35099 .35712 L p F P
0 g
s
.294 0 0 r
.34672 .35709 m .35041 .358 L p .35099 .35712 L F P
0 g
s
.294 0 0 r
.35099 .35712 m .34954 .35695 L .34672 .35709 L p F P
0 g
s
.688 .174 .009 r
.2133 .45893 m .21993 .46099 L .21564 .45732 L p F P
0 g
s
.688 .174 .009 r
.20948 .4557 m .2133 .45893 L p .21564 .45732 L F P
0 g
s
.688 .174 .009 r
.21564 .45732 m .2101 .45563 L .20948 .4557 L p F P
0 g
s
.437 0 0 r
.33586 .49079 m .34167 .49238 L .33288 .49151 L closepath p F P
0 g
s
.331 .018 .275 r
.65237 .41875 m .65188 .42067 L .6576 .4163 L closepath p F P
0 g
s
.726 .743 .866 r
.13208 .31849 m .1374 .31545 L .13391 .31198 L p F P
0 g
s
.726 .743 .866 r
.13391 .31198 m .1273 .31563 L .13208 .31849 L p F P
0 g
s
.738 .736 .85 r
.12333 .31797 m .1273 .31563 L .13208 .31849 L p F P
0 g
s
.527 0 0 r
.28726 .48322 m .2878 .48313 L .28196 .48041 L p F P
0 g
s
.527 0 0 r
.28051 .48188 m .28726 .48322 L p .28196 .48041 L F P
0 g
s
.527 0 0 r
.27413 .47897 m .28051 .48188 L p .28196 .48041 L F P
0 g
s
.527 0 0 r
.28196 .48041 m .27433 .47894 L .27413 .47897 L p F P
0 g
s
.654 .128 0 r
.23155 .46651 m .23849 .46846 L .23363 .46494 L p F P
0 g
s
.654 .128 0 r
.23363 .46494 m .22662 .46302 L .23155 .46651 L p F P
0 g
s
.69 .189 .05 r
.22645 .46289 m .22662 .46302 L .23363 .46494 L p F P
0 g
s
.292 0 0 r
.34954 .35695 m .34672 .35709 L .34137 .35599 L closepath p F P
0 g
s
.316 .689 .979 r
.21991 .32447 m .20994 .32351 L .21539 .3261 L p F P
0 g
s
.316 .689 .979 r
.21539 .3261 m .22337 .32663 L .21991 .32447 L p F P
0 g
s
.296 .662 .972 r
.20972 .32349 m .20994 .32351 L .21539 .3261 L p F P
0 g
s
.26 0 .046 r
.61618 .44567 m .61622 .44561 L .60553 .44947 L p F P
0 g
s
.26 0 .046 r
.60553 .44947 m .60508 .45024 L .61618 .44567 L p F P
0 g
s
.871 .6 .525 r
.11318 .38266 m .11746 .38492 L .11765 .37997 L p F P
0 g
s
.871 .6 .525 r
.11765 .37997 m .11432 .3782 L .11318 .38266 L p F P
0 g
s
.159 0 0 r
.30447 .34909 m .30204 .34861 L .29867 .3479 L closepath p F P
0 g
s
.86 .685 .664 r
.10663 .35584 m .10768 .3533 L .10451 .3474 L p F P
0 g
s
.062 0 0 r
.46198 .35614 m .46117 .35636 L .45659 .35676 L closepath p F P
0 g
s
.071 0 0 r
.45841 .35739 m .46117 .35636 L .45659 .35676 L p F P
0 g
s
.071 0 0 r
.4564 .35762 m .45841 .35739 L p .45659 .35676 L F P
0 g
s
.071 0 0 r
.44724 .35823 m .4564 .35762 L p .45659 .35676 L F P
0 g
s
.727 .234 .069 r
.1963 .45096 m .20262 .45313 L .1989 .4493 L p F P
0 g
s
.727 .234 .069 r
.1926 .44722 m .1963 .45096 L p .1989 .4493 L F P
0 g
s
.727 .234 .069 r
.1989 .4493 m .1927 .44721 L .1926 .44722 L p F P
0 g
s
.87 .575 .485 r
.11771 .38974 m .12284 .3924 L .12259 .38758 L p F P
0 g
s
.87 .575 .485 r
.12259 .38758 m .11746 .38492 L .11771 .38974 L p F P
0 g
s
.876 .63 .562 r
.10777 .37449 m .11263 .37726 L .1133 .37215 L p F P
0 g
s
.876 .63 .562 r
.1133 .37215 m .10845 .36938 L .10777 .37449 L p F P
0 g
s
.577 .748 .958 r
.18125 .31811 m .17889 .31615 L .17721 .31645 L closepath p F P
0 g
s
.838 .698 .709 r
.10105 .34197 m .10328 .33836 L .10802 .34122 L p F P
0 g
s
.838 .698 .709 r
.10802 .34122 m .10441 .34722 L .10105 .34197 L p F P
0 g
s
.417 .865 .873 r
.5513 .33525 m .55269 .3352 L .54166 .33888 L p F P
0 g
s
.417 .865 .873 r
.54166 .33888 m .54038 .33893 L .5513 .33525 L p F P
0 g
s
.226 0 0 r
.49973 .48748 m .5025 .48579 L .49016 .48765 L p F P
0 g
s
.226 0 0 r
.49016 .48765 m .48877 .48849 L .49973 .48748 L p F P
0 g
s
0 0 0 r
.49855 .34969 m .49995 .34922 L .48901 .35146 L p F P
0 g
s
0 0 0 r
.48901 .35146 m .48661 .35215 L .49855 .34969 L p F P
0 g
s
0 0 0 r
.48661 .35215 m .48901 .35146 L p .47509 .35408 L F P
0 g
s
.288 0 0 r
.41065 .49527 m .40767 .49532 L .40517 .49613 L p F P
0 g
s
.319 0 0 r
.40767 .49532 m .40517 .49613 L .39749 .4953 L closepath p F P
0 g
s
.868 .549 .445 r
.1235 .3971 m .12868 .39973 L .12802 .39503 L p F P
0 g
s
.868 .549 .445 r
.12802 .39503 m .12284 .3924 L .1235 .3971 L p F P
0 g
s
.52 0 0 r
.30495 .48611 m .30548 .48632 L .31443 .4876 L p F P
0 g
s
.473 0 0 r
.31335 .489 m .30548 .48632 L .31443 .4876 L p F P
0 g
s
.473 0 0 r
.31652 .48946 m .31335 .489 L p .31443 .4876 L F P
0 g
s
.473 0 0 r
.31443 .4876 m .31871 .48906 L .31652 .48946 L p F P
0 g
s
.306 0 0 r
.40358 .49663 m .40517 .49613 L .39749 .4953 L p F P
0 g
s
.306 0 0 r
.39712 .49659 m .40358 .49663 L p .39749 .4953 L F P
0 g
s
.306 0 0 r
.39126 .49592 m .39712 .49659 L p .39749 .4953 L F P
0 g
s
.306 0 0 r
.39749 .4953 m .39347 .49528 L .39126 .49592 L p F P
0 g
s
.615 .074 0 r
.2512 .47365 m .24566 .47033 L .25299 .47213 L p F P
0 g
s
.615 .074 0 r
.25564 .47477 m .2512 .47365 L p .25299 .47213 L F P
0 g
s
.615 .074 0 r
.25299 .47213 m .25702 .47457 L .25564 .47477 L p F P
0 g
s
.338 0 0 r
.39347 .49528 m .39126 .49592 L .38517 .49508 L closepath p F P
0 g
s
.644 .119 0 r
.24349 .46887 m .24566 .47033 L .24139 .46925 L closepath p F P
0 g
s
.299 0 0 r
.42155 .49505 m .41909 .49592 L .41065 .49527 L closepath p F P
0 g
s
.288 0 0 r
.41758 .49644 m .41909 .49592 L .41065 .49527 L p F P
0 g
s
.288 0 0 r
.41034 .49656 m .41758 .49644 L p .41065 .49527 L F P
0 g
s
.288 0 0 r
.40517 .49613 m .41034 .49656 L p .41065 .49527 L F P
0 g
s
.167 .699 .694 r
.51094 .34662 m .51381 .34586 L .50222 .3487 L p F P
0 g
s
.167 .699 .694 r
.50222 .3487 m .49995 .34922 L .51094 .34662 L p F P
0 g
s
.299 0 0 r
.36385 .35861 m .37086 .35987 L .3606 .359 L closepath p F P
0 g
s
.873 .651 .598 r
.10366 .36657 m .10845 .36938 L .10964 .36411 L p F P
0 g
s
.873 .651 .598 r
.10964 .36411 m .10486 .3613 L .10366 .36657 L p F P
0 g
s
.313 0 .22 r
.6455 .42514 m .64084 .42811 L .64002 .43061 L p F P
0 g
s
.389 .148 .423 r
.68344 .39572 m .68379 .39133 L .67713 .3949 L p F P
0 g
s
.389 .148 .423 r
.67369 .40093 m .68344 .39572 L p .67713 .3949 L F P
0 g
s
.389 .148 .423 r
.67713 .3949 m .67375 .40009 L .67369 .40093 L p F P
0 g
s
.233 0 0 r
.52657 .48133 m .5276 .48053 L .51659 .48217 L p F P
0 g
s
.233 0 0 r
.51659 .48217 m .51463 .48367 L .52657 .48133 L p F P
0 g
s
.394 .712 .986 r
.20933 .32322 m .20972 .32349 L p .19606 .32095 L F P
0 g
s
.394 .712 .986 r
.19606 .32095 m .20402 .32108 L .20933 .32322 L p F P
0 g
s
.372 .696 .983 r
.20402 .32108 m .19606 .32095 L .19259 .31829 L p F P
0 g
s
.175 .629 .938 r
.22682 .32879 m .23249 .32961 L .2388 .33189 L p F P
0 g
s
.146 .604 .928 r
.23249 .32961 m .22682 .32879 L .22337 .32663 L p F P
0 g
s
.539 .468 .724 r
.69761 .34039 m .69821 .34048 L .69773 .34079 L closepath p F P
0 g
s
.534 .481 .742 r
.69518 .33298 m .69761 .34039 L .69821 .34048 L p F P
0 g
s
.665 .736 .903 r
.647 .31494 m .6582 .31125 L .66093 .31471 L p F P
0 g
s
.673 .765 .92 r
.6582 .31125 m .647 .31494 L .64427 .31211 L p F P
0 g
s
.676 .783 .93 r
.63311 .31612 m .64427 .31211 L .647 .31494 L p F P
0 g
s
.523 .438 .701 r
.70716 .34276 m .69956 .34772 L .69773 .34079 L p F P
0 g
s
.523 .438 .701 r
.69773 .34079 m .69821 .34048 L .70716 .34276 L p F P
0 g
s
.615 .919 .976 r
.59151 .32384 m .58043 .32809 L .57764 .32738 L p F P
0 g
s
.59 .916 .973 r
.56657 .33151 m .57764 .32738 L .58043 .32809 L p F P
0 g
s
.812 .39 .243 r
.15704 .42745 m .16277 .42985 L .1604 .42565 L p F P
0 g
s
.812 .39 .243 r
.15554 .42479 m .15704 .42745 L p .1604 .42565 L F P
0 g
s
.812 .39 .243 r
.1604 .42565 m .1573 .42436 L .15554 .42479 L p F P
0 g
s
.324 0 0 r
.38925 .49651 m .39126 .49592 L .38517 .49508 L p F P
0 g
s
.324 0 0 r
.38473 .49637 m .38925 .49651 L p .38517 .49508 L F P
0 g
s
.324 0 0 r
.37737 .49531 m .38473 .49637 L p .38517 .49508 L F P
0 g
s
.324 0 0 r
.38517 .49508 m .37893 .4949 L .37737 .49531 L p F P
0 g
s
.236 .666 .959 r
.24229 .33304 m .24047 .33206 L .2388 .33189 L closepath p F P
0 g
s
.269 0 0 r
.42487 .49492 m .42155 .49505 L .41909 .49592 L p F P
0 g
s
.264 0 0 r
.31915 .35214 m .32355 .35326 L .3161 .3518 L closepath p F P
0 g
s
.028 0 0 r
.47206 .35513 m .47443 .35431 L .46198 .35614 L p F P
0 g
s
.028 0 0 r
.46198 .35614 m .46117 .35636 L .47206 .35513 L p F P
0 g
s
.563 .517 .762 r
.69467 .33158 m .69726 .3316 L .69518 .33298 L closepath p F P
0 g
s
.534 .481 .742 r
.70617 .33225 m .69726 .3316 L .69518 .33298 L p F P
0 g
s
.534 .481 .742 r
.70692 .33466 m .70617 .33225 L p .69518 .33298 L F P
0 g
s
.534 .481 .742 r
.69821 .34048 m .70692 .33466 L p .69518 .33298 L F P
0 g
s
.266 0 0 r
.55536 .47111 m .56311 .46923 L .55515 .47134 L closepath p F P
0 g
s
.77 .308 .149 r
.18039 .44262 m .18643 .4449 L .18325 .44092 L p F P
0 g
s
.77 .308 .149 r
.18325 .44092 m .17717 .43866 L .18039 .44262 L p F P
0 g
s
.344 .056 .324 r
.6632 .41006 m .66287 .41176 L .66639 .40847 L closepath p F P
0 g
s
.279 0 0 r
.43513 .49448 m .43302 .49529 L .42487 .49492 L closepath p F P
0 g
s
.269 0 0 r
.43128 .49595 m .43302 .49529 L .42487 .49492 L p F P
0 g
s
.269 0 0 r
.42461 .4962 m .43128 .49595 L p .42487 .49492 L F P
0 g
s
.269 0 0 r
.41909 .49592 m .42461 .4962 L p .42487 .49492 L F P
0 g
s
.863 .522 .405 r
.12971 .40432 m .13494 .40693 L .13391 .40233 L p F P
0 g
s
.863 .522 .405 r
.13391 .40233 m .12868 .39973 L .12971 .40432 L p F P
0 g
s
.627 .749 .935 r
.15132 .31455 m .16166 .31177 L .16514 .31486 L p F P
0 g
s
.618 .747 .939 r
.16166 .31177 m .15132 .31455 L .14784 .31127 L p F P
0 g
s
.682 .751 .903 r
.1374 .31545 m .14784 .31127 L .15132 .31455 L p F P
0 g
s
.356 0 0 r
.37893 .4949 m .37737 .49531 L .37349 .49465 L closepath p F P
0 g
s
.679 .826 .954 r
.64155 .30962 m .64427 .31211 L .63311 .31612 L p F P
0 g
s
.679 .826 .954 r
.63346 .31268 m .64155 .30962 L p .63311 .31612 L F P
0 g
s
.679 .826 .954 r
.63311 .31612 m .63085 .31425 L .63346 .31268 L p F P
0 g
s
.576 .53 .766 r
.69726 .3316 m .69467 .33158 L .69181 .32445 L p F P
0 g
s
.26 0 0 r
.34471 .35727 m .34672 .35709 L .34137 .35599 L p F P
0 g
s
.26 0 0 r
.34096 .3568 m .34471 .35727 L p .34137 .35599 L F P
0 g
s
.26 0 0 r
.33292 .35474 m .34096 .3568 L p .34137 .35599 L F P
0 g
s
.26 0 0 r
.34137 .35599 m .33321 .35476 L .33292 .35474 L p F P
0 g
s
.675 .751 .908 r
.14784 .31127 m .1374 .31545 L .13391 .31198 L p F P
0 g
s
.648 .686 .872 r
.66093 .31471 m .67217 .31149 L .67492 .3157 L p F P
0 g
s
.658 .716 .891 r
.67217 .31149 m .66093 .31471 L .6582 .31125 L p F P
0 g
s
.522 .44 .704 r
.7088 .34167 m .70716 .34276 L .69821 .34048 L p F P
0 g
s
.522 .44 .704 r
.69821 .34048 m .70692 .33466 L .7088 .34167 L p F P
0 g
s
0 .505 .808 r
.25756 .33725 m .26112 .33807 L .26792 .34017 L p F P
0 g
s
0 .475 .795 r
.26112 .33807 m .25756 .33725 L .25413 .33566 L p F P
0 g
s
.399 .182 .464 r
.69343 .3859 m .69355 .38127 L .68393 .38671 L p F P
0 g
s
.399 .182 .464 r
.68393 .38671 m .68379 .39133 L .69343 .3859 L p F P
0 g
s
.238 0 0 r
.60245 .45436 m .60375 .45249 L .59291 .45615 L p F P
0 g
s
.238 0 0 r
.59291 .45615 m .59134 .45841 L .60245 .45436 L p F P
0 g
s
.86 .685 .664 r
.10193 .35298 m .10663 .35584 L p .10451 .3474 L F P
0 g
s
.869 .671 .632 r
.10014 .35845 m .10486 .3613 L .10663 .35584 L p F P
0 g
s
.869 .671 .632 r
.10663 .35584 m .10193 .35298 L .10014 .35845 L p F P
0 g
s
.628 .655 .857 r
.67492 .3157 m .67986 .31458 L .6758 .3172 L closepath p F P
0 g
s
.611 .639 .854 r
.68622 .31319 m .67986 .31458 L .6758 .3172 L p F P
0 g
s
.611 .639 .854 r
.689 .31847 m .68622 .31319 L p .6758 .3172 L F P
0 g
s
.439 .267 .549 r
.69613 .37478 m .69344 .37638 L .69309 .37121 L p F P
0 g
s
.439 .267 .549 r
.69309 .37121 m .69523 .36993 L .69613 .37478 L p F P
0 g
s
.34 0 0 r
.37456 .49604 m .37737 .49531 L .37349 .49465 L p F P
0 g
s
.34 0 0 r
.37299 .49596 m .37456 .49604 L p .37349 .49465 L F P
0 g
s
.34 0 0 r
.3635 .4943 m .37299 .49596 L p .37349 .49465 L F P
0 g
s
.34 0 0 r
.37349 .49465 m .36402 .49418 L .3635 .4943 L p F P
0 g
s
.347 .031 .28 r
.65188 .42067 m .6455 .42514 L .6514 .42252 L closepath p F P
0 g
s
.313 0 .22 r
.65024 .42609 m .6514 .42252 L .6455 .42514 L p F P
0 g
s
.313 0 .22 r
.64002 .43061 m .65024 .42609 L p .6455 .42514 L F P
0 g
s
.257 0 .042 r
.61444 .44862 m .61618 .44567 L .60508 .45024 L p F P
0 g
s
.257 0 .042 r
.60508 .45024 m .60375 .45249 L .61444 .44862 L p F P
0 g
s
.209 0 0 r
.53864 .47854 m .5411 .47657 L .52938 .47913 L p F P
0 g
s
.209 0 0 r
.52938 .47913 m .5276 .48053 L .53864 .47854 L p F P
0 g
s
.22 0 0 r
.28832 .34533 m .2911 .34607 L .29867 .3479 L p F P
0 g
s
0 .418 .698 r
.28832 .34533 m .2911 .34607 L .28581 .34462 L closepath p F P
0 g
s
.422 0 0 r
.34966 .49278 m .35178 .49329 L .34868 .49305 L closepath p F P
0 g
s
.427 0 0 r
.34966 .49278 m .35178 .49329 L .36234 .49406 L p F P
0 g
s
.17 0 0 r
.29864 .348 m .2911 .34607 L .29867 .3479 L p F P
0 g
s
.17 0 0 r
.29867 .3479 m .30204 .34861 L .29864 .348 L p F P
0 g
s
.007 .551 .835 r
.2678 .33952 m .26112 .33807 L .26792 .34017 L p F P
0 g
s
.007 .551 .835 r
.26792 .34017 m .27123 .34076 L .2678 .33952 L p F P
0 g
s
.787 .729 .799 r
.11492 .32471 m .11249 .32692 L .10902 .32286 L p F P
0 g
s
.811 .727 .771 r
.10813 .33187 m .11249 .32692 L .10902 .32286 L p F P
0 g
s
.212 0 0 r
.56311 .46923 m .55515 .47134 L .55265 .47378 L p F P
0 g
s
.771 .736 .821 r
.11492 .32471 m .12333 .31797 L .11984 .31428 L p F P
0 g
s
.771 .736 .821 r
.11984 .31428 m .11017 .32184 L .11492 .32471 L p F P
0 g
s
.787 .729 .799 r
.10902 .32286 m .11017 .32184 L .11492 .32471 L p F P
0 g
s
.249 0 0 r
.44044 .49416 m .43513 .49448 L .43302 .49529 L p F P
0 g
s
.511 .904 .936 r
.56657 .33151 m .5641 .33238 L .56649 .3315 L closepath p F P
0 g
s
.503 .902 .929 r
.56375 .33124 m .56649 .3315 L .5641 .33238 L p F P
0 g
s
.503 .902 .929 r
.55269 .3352 m .56375 .33124 L p .5641 .33238 L F P
0 g
s
0 0 0 r
.47509 .35408 m .48096 .35313 L .48661 .35215 L p F P
0 g
s
.007 0 0 r
.47509 .35408 m .48096 .35313 L .47443 .35431 L closepath p F P
0 g
s
.591 .572 .802 r
.69029 .32461 m .69153 .32381 L .69181 .32445 L closepath p F P
0 g
s
.516 0 0 r
.30495 .48611 m .30548 .48632 L .30462 .48619 L closepath p F P
0 g
s
.559 0 0 r
.27433 .47894 m .27413 .47897 L .27389 .47885 L closepath p F P
0 g
s
.79 .35 .205 r
.17586 .43678 m .17717 .43866 L .17367 .43732 L closepath p F P
0 g
s
.847 .474 .345 r
.13642 .41138 m .14185 .41391 L .14032 .40947 L p F P
0 g
s
.847 .474 .345 r
.13552 .40874 m .13642 .41138 L p .14032 .40947 L F P
0 g
s
.847 .474 .345 r
.14032 .40947 m .1372 .40802 L .13552 .40874 L p F P
0 g
s
.56 .741 .961 r
.16514 .31486 m .17169 .31386 L .17721 .31645 L p F P
0 g
s
.547 .733 .962 r
.17169 .31386 m .16514 .31486 L .16166 .31177 L p F P
0 g
s
.487 .388 .668 r
.70926 .34369 m .70716 .34276 L .69956 .34772 L p F P
0 g
s
.487 .388 .668 r
.71017 .34805 m .70926 .34369 L p .69956 .34772 L F P
0 g
s
.487 .388 .668 r
.70156 .35369 m .71017 .34805 L p .69956 .34772 L F P
0 g
s
.487 .388 .668 r
.69956 .34772 m .70076 .35325 L .70156 .35369 L p F P
0 g
s
.556 0 0 r
.27064 .47938 m .26622 .47716 L .27389 .47885 L p F P
0 g
s
.556 0 0 r
.27389 .47885 m .27413 .47897 L .27064 .47938 L p F P
0 g
s
.681 .856 .966 r
.63038 .31385 m .61924 .3181 L .61649 .31636 L p F P
0 g
s
.673 .868 .973 r
.60537 .32072 m .61649 .31636 L .61924 .3181 L p F P
0 g
s
.305 0 0 r
.3777 .35984 m .38202 .3605 L .37595 .36019 L closepath p F P
0 g
s
.711 .209 .041 r
.2101 .45563 m .20948 .4557 L .209 .45527 L closepath p F P
0 g
s
.646 .908 .982 r
.60262 .31943 m .60294 .31958 L .59289 .3244 L p F P
0 g
s
.646 .908 .982 r
.59289 .3244 m .59151 .32384 L .60262 .31943 L p F P
0 g
s
.403 .159 .426 r
.67375 .40009 m .67286 .40135 L .67369 .40093 L closepath p F P
0 g
s
.373 0 0 r
.36402 .49418 m .3635 .4943 L .36234 .49406 L closepath p F P
0 g
s
.258 0 0 r
.44845 .49364 m .44696 .49425 L .44044 .49416 L closepath p F P
0 g
s
.249 0 0 r
.4447 .49517 m .44696 .49425 L .44044 .49416 L p F P
0 g
s
.249 0 0 r
.44024 .49544 m .4447 .49517 L p .44044 .49416 L F P
0 g
s
.249 0 0 r
.43302 .49529 m .44024 .49544 L p .44044 .49416 L F P
0 g
s
.263 0 0 r
.59092 .459 m .59134 .45841 L .58024 .46198 L p F P
0 g
s
.263 0 0 r
.58024 .46198 m .57991 .46245 L .59092 .459 L p F P
0 g
s
.541 0 0 r
.28051 .48188 m .27413 .47897 L .27064 .47938 L p F P
0 g
s
.312 .802 .794 r
.53639 .33939 m .5388 .33901 L .52778 .34239 L p F P
0 g
s
.312 .802 .794 r
.52778 .34239 m .52522 .34278 L .53639 .33939 L p F P
0 g
s
.3 .796 .807 r
.52522 .34278 m .52778 .34239 L p .51388 .34585 L F P
0 g
s
.369 0 0 r
.36021 .49502 m .35178 .49329 L .36234 .49406 L p F P
0 g
s
.369 0 0 r
.36234 .49406 m .3635 .4943 L .36021 .49502 L p F P
0 g
s
.851 .695 .688 r
.10441 .34722 m .10436 .34731 L .10451 .3474 L closepath p F P
0 g
s
.86 .685 .664 r
.10451 .3474 m .10436 .34731 L .10193 .35298 L p F P
0 g
s
.689 .185 .038 r
.22645 .46289 m .22662 .46302 L .22627 .46292 L closepath p F P
0 g
s
.451 0 0 r
.30457 .48766 m .31335 .489 L .30548 .48632 L p F P
0 g
s
.451 0 0 r
.30153 .48661 m .30457 .48766 L p .30548 .48632 L F P
0 g
s
.451 0 0 r
.30548 .48632 m .30462 .48619 L .30153 .48661 L p F P
0 g
s
.852 .699 .693 r
.10436 .34731 m .10441 .34722 L .10105 .34197 L p F P
0 g
s
.577 .749 .959 r
.17541 .31327 m .17169 .31386 L .17721 .31645 L p F P
0 g
s
.577 .749 .959 r
.17721 .31645 m .17889 .31615 L .17541 .31327 L p F P
0 g
s
.232 .665 .957 r
.23702 .33021 m .23249 .32961 L .2388 .33189 L p F P
0 g
s
.232 .665 .957 r
.2388 .33189 m .24047 .33206 L .23702 .33021 L p F P
0 g
s
.877 .607 .525 r
.11241 .38223 m .11318 .38266 L .11432 .3782 L p F P
0 g
s
.877 .607 .525 r
.11432 .3782 m .11263 .37726 L .11241 .38223 L p F P
0 g
s
.37 .103 .372 r
.67311 .40509 m .66639 .40847 L .67286 .40135 L p F P
0 g
s
.37 .103 .372 r
.67286 .40135 m .67369 .40093 L .67311 .40509 L p F P
0 g
s
.801 .364 .208 r
.16546 .43396 m .17123 .43634 L .16857 .43222 L p F P
0 g
s
.801 .364 .208 r
.16857 .43222 m .16277 .42985 L .16546 .43396 L p F P
0 g
s
.811 .727 .771 r
.10902 .32286 m .10354 .32895 L .10813 .33187 L p F P
0 g
s
.827 .719 .745 r
.0986 .33548 m .10328 .33836 L .10813 .33187 L p F P
0 g
s
.827 .719 .745 r
.10813 .33187 m .10354 .32895 L .0986 .33548 L p F P
0 g
s
.852 .699 .693 r
.10105 .34197 m .09976 .34441 L .10436 .34731 L p F P
0 g
s
.862 .689 .666 r
.09729 .3501 m .10193 .35298 L .10436 .34731 L p F P
0 g
s
.862 .689 .666 r
.10436 .34731 m .09976 .34441 L .09729 .3501 L p F P
0 g
s
.734 .739 .855 r
.1273 .31563 m .12333 .31797 L .11984 .31428 L p F P
0 g
s
.329 .016 .273 r
.6576 .4163 m .65188 .42067 L .6514 .42252 L p F P
0 g
s
.638 .665 .86 r
.67986 .31458 m .67492 .3157 L .67217 .31149 L p F P
0 g
s
.487 0 0 r
.30462 .48619 m .30153 .48661 L .29698 .4849 L closepath p F P
0 g
s
.645 .111 0 r
.22466 .46454 m .23155 .46651 L .22662 .46302 L p F P
0 g
s
.645 .111 0 r
.22285 .46324 m .22466 .46454 L p .22662 .46302 L F P
0 g
s
.645 .111 0 r
.22662 .46302 m .22627 .46292 L .22285 .46324 L p F P
0 g
s
.711 .207 .036 r
.20584 .45609 m .20262 .45313 L .209 .45527 L p F P
0 g
s
.711 .207 .036 r
.209 .45527 m .20948 .4557 L .20584 .45609 L p F P
0 g
s
.259 0 0 r
.50269 .48565 m .5044 .48547 L .5025 .48579 L closepath p F P
0 g
s
.824 .412 .264 r
.1573 .42436 m .15554 .42479 L .15472 .42323 L closepath p F P
0 g
s
.673 .149 0 r
.22627 .46292 m .22285 .46324 L .21993 .46099 L closepath p F P
0 g
s
.576 .53 .766 r
.70433 .3268 m .69726 .3316 L p .69181 .32445 L F P
0 g
s
.576 .53 .766 r
.69181 .32445 m .70325 .32389 L .70433 .3268 L p F P
0 g
s
.574 .563 .804 r
.69153 .32381 m .69181 .32445 L .70325 .32389 L p F P
0 g
s
.533 .913 .938 r
.57701 .3273 m .57764 .32738 L .56657 .33151 L p F P
0 g
s
.533 .913 .938 r
.56657 .33151 m .56649 .3315 L .57701 .3273 L p F P
0 g
s
.549 .495 .747 r
.69726 .3316 m .70433 .3268 L .70617 .33225 L closepath p F P
0 g
s
.242 0 0 r
.33321 .35476 m .33292 .35474 L .33242 .35464 L closepath p F P
0 g
s
.099 0 0 r
.47097 .35563 m .47206 .35513 L .46117 .35636 L p F P
0 g
s
.099 0 0 r
.46117 .35636 m .45841 .35739 L .47097 .35563 L p F P
0 g
s
.595 .589 .815 r
.689 .31847 m .69153 .32381 L .70064 .31755 L p F P
0 g
s
.574 .563 .804 r
.70325 .32389 m .70064 .31755 L .69153 .32381 L p F P
0 g
s
.228 0 0 r
.4578 .49287 m .44845 .49364 L .44696 .49425 L p F P
0 g
s
.537 .916 .938 r
.57484 .32702 m .57701 .3273 L .56649 .3315 L p F P
0 g
s
.537 .916 .938 r
.56649 .3315 m .56375 .33124 L .57484 .32702 L p F P
0 g
s
.839 .448 .307 r
.14373 .41825 m .1492 .42076 L .14734 .41641 L p F P
0 g
s
.839 .448 .307 r
.14734 .41641 m .14185 .41391 L .14373 .41825 L p F P
0 g
s
.266 0 0 r
.32957 .35475 m .32355 .35326 L .33242 .35464 L p F P
0 g
s
.266 0 0 r
.33242 .35464 m .33292 .35474 L .32957 .35475 L p F P
0 g
s
.353 .089 .367 r
.6829 .39989 m .68344 .39572 L .67369 .40093 L p F P
0 g
s
.353 .089 .367 r
.67369 .40093 m .67311 .40509 L .6829 .39989 L p F P
0 g
s
.747 .266 .099 r
.1927 .44721 m .1926 .44722 L .19253 .44715 L closepath p F P
0 g
s
.197 0 0 r
.5044 .48547 m .5025 .48579 L .49973 .48748 L p F P
0 g
s
.359 .068 .328 r
.66287 .41176 m .6576 .4163 L .66243 .41402 L closepath p F P
0 g
s
.329 .016 .273 r
.66147 .41777 m .66243 .41402 L .6576 .4163 L p F P
0 g
s
.329 .016 .273 r
.6514 .42252 m .66147 .41777 L p .6576 .4163 L F P
0 g
s
.302 .661 .972 r
.20972 .32349 m .20994 .32351 L .20933 .32322 L closepath p F P
0 g
s
.593 .039 0 r
.24399 .4718 m .2512 .47365 L .24566 .47033 L p F P
0 g
s
.593 .039 0 r
.23992 .46937 m .24399 .4718 L p .24566 .47033 L F P
0 g
s
.593 .039 0 r
.24566 .47033 m .24139 .46925 L .23992 .46937 L p F P
0 g
s
.319 0 0 r
.40502 .36093 m .40547 .36079 L p .39157 .36057 L F P
0 g
s
.319 0 0 r
.39157 .36057 m .394 .36086 L .40502 .36093 L p F P
0 g
s
.297 0 0 r
.39157 .36057 m .394 .36086 L .39072 .3608 L closepath p F P
0 g
s
.747 .264 .093 r
.18891 .44762 m .18643 .4449 L .19253 .44715 L p F P
0 g
s
.747 .264 .093 r
.19253 .44715 m .1926 .44722 L .18891 .44762 L p F P
0 g
s
.435 .264 .549 r
.70289 .37066 m .69613 .37478 L .69523 .36993 L p F P
0 g
s
.435 .264 .549 r
.69523 .36993 m .70252 .36548 L .70289 .37066 L p F P
0 g
s
.349 0 0 r
.37299 .49596 m .3635 .4943 L .36021 .49502 L p F P
0 g
s
.7 .193 .026 r
.2133 .45893 m .20948 .4557 L .20584 .45609 L p F P
0 g
s
.343 .054 .322 r
.67236 .40904 m .67311 .40509 L .66639 .40847 L p F P
0 g
s
.343 .054 .322 r
.66243 .41402 m .67236 .40904 L p .66639 .40847 L F P
0 g
s
.343 .054 .322 r
.66639 .40847 m .66287 .41176 L .66243 .41402 L p F P
0 g
s
.738 .252 .086 r
.1963 .45096 m .1926 .44722 L .18891 .44762 L p F P
0 g
s
.284 .654 .969 r
.21828 .32346 m .21991 .32447 L .20994 .32351 L p F P
0 g
s
.284 .654 .969 r
.21509 .32218 m .21828 .32346 L p .20994 .32351 L F P
0 g
s
.284 .654 .969 r
.20626 .32109 m .21509 .32218 L p .20994 .32351 L F P
0 g
s
.284 .654 .969 r
.20994 .32351 m .20933 .32322 L .20626 .32109 L p F P
0 g
s
.416 .864 .87 r
.54985 .33531 m .5513 .33525 L .54038 .33893 L p F P
0 g
s
.416 .864 .87 r
.54038 .33893 m .5388 .33901 L .54985 .33531 L p F P
0 g
s
.662 .9 .98 r
.61375 .31491 m .61649 .31636 L .60537 .32072 L p F P
0 g
s
.662 .9 .98 r
.60534 .31832 m .61375 .31491 L p .60537 .32072 L F P
0 g
s
.662 .9 .98 r
.60537 .32072 m .60294 .31958 L .60534 .31832 L p F P
0 g
s
.212 0 0 r
.58872 .46164 m .59092 .459 L .57991 .46245 L p F P
0 g
s
.212 0 0 r
.57991 .46245 m .57769 .46509 L .58872 .46164 L p F P
0 g
s
.413 0 0 r
.34096 .3568 m .33292 .35474 L .32957 .35475 L p F P
0 g
s
.459 .719 .981 r
.18911 .31562 m .17889 .31615 L .17541 .31327 L p F P
0 g
s
.352 0 0 r
.35946 .49518 m .36021 .49502 L .35178 .49329 L p F P
0 g
s
.352 0 0 r
.35141 .49453 m .35946 .49518 L p .35178 .49329 L F P
0 g
s
.352 0 0 r
.34634 .49348 m .35141 .49453 L p .35178 .49329 L F P
0 g
s
.352 0 0 r
.35178 .49329 m .34868 .49305 L .34634 .49348 L p F P
0 g
s
.012 0 0 r
.48096 .35313 m .47443 .35431 L .47206 .35513 L p F P
0 g
s
.495 .384 .656 r
.70076 .35325 m .70156 .35369 L .70093 .3541 L closepath p F P
0 g
s
.721 .744 .869 r
.1273 .31563 m .13391 .31198 L .13041 .30853 L p F P
0 g
s
.721 .744 .869 r
.13041 .30853 m .1225 .31277 L .1273 .31563 L p F P
0 g
s
.734 .739 .855 r
.11984 .31428 m .1225 .31277 L .1273 .31563 L p F P
0 g
s
.201 0 0 r
.51463 .48367 m .51367 .48428 L .5044 .48547 L closepath p F P
0 g
s
.197 0 0 r
.51152 .48563 m .51367 .48428 L .5044 .48547 L p F P
0 g
s
.197 0 0 r
.50329 .48705 m .51152 .48563 L p .5044 .48547 L F P
0 g
s
.197 0 0 r
.49973 .48748 m .50329 .48705 L p .5044 .48547 L F P
0 g
s
.152 0 0 r
.44724 .35823 m .4564 .35762 L .4456 .35887 L closepath p F P
0 g
s
.407 .716 .987 r
.20933 .32322 m .20626 .32109 L .20402 .32108 L closepath p F P
0 g
s
.475 .347 .626 r
.70573 .3575 m .70188 .35997 L .70093 .3541 L p F P
0 g
s
.475 .347 .626 r
.70093 .3541 m .70156 .35369 L .70573 .3575 L p F P
0 g
s
.88 .61 .525 r
.10754 .37946 m .11241 .38223 L .11263 .37726 L p F P
0 g
s
.88 .61 .525 r
.11263 .37726 m .10777 .37449 L .10754 .37946 L p F P
0 g
s
0 .513 .835 r
.24812 .33364 m .24047 .33206 L .23702 .33021 L p F P
0 g
s
.387 0 0 r
.34868 .49305 m .34634 .49348 L .34167 .49238 L closepath p F P
0 g
s
.873 .576 .481 r
.11264 .38706 m .11771 .38974 L .11746 .38492 L p F P
0 g
s
.873 .576 .481 r
.11247 .38377 m .11264 .38706 L p .11746 .38492 L F P
0 g
s
.873 .576 .481 r
.11746 .38492 m .11318 .38266 L .11247 .38377 L p F P
0 g
s
.292 0 0 r
.41891 .36063 m .41938 .36046 L p .40547 .36079 L F P
0 g
s
.292 0 0 r
.40547 .36079 m .40696 .3609 L .41891 .36063 L p F P
0 g
s
.277 0 0 r
.40547 .36079 m .40696 .3609 L .40502 .36093 L closepath p F P
0 g
s
.856 .491 .359 r
.1372 .40802 m .13552 .40874 L .13494 .40693 L closepath p F P
0 g
s
.879 .633 .562 r
.10296 .37169 m .10777 .37449 L .10845 .36938 L p F P
0 g
s
.879 .633 .562 r
.10845 .36938 m .10366 .36657 L .10296 .37169 L p F P
0 g
s
.236 0 0 r
.46152 .49254 m .4609 .49281 L .4578 .49287 L closepath p F P
0 g
s
.228 0 0 r
.45786 .49412 m .4609 .49281 L .4578 .49287 L p F P
0 g
s
.228 0 0 r
.45766 .49414 m .45786 .49412 L p .4578 .49287 L F P
0 g
s
.228 0 0 r
.44696 .49425 m .45766 .49414 L p .4578 .49287 L F P
0 g
s
.223 0 0 r
.49934 .48772 m .49973 .48748 L .48877 .48849 L p F P
0 g
s
.223 0 0 r
.48877 .48849 m .48694 .48956 L .49934 .48772 L p F P
0 g
s
.839 .704 .714 r
.09765 .33696 m .0986 .33548 L .10328 .33836 L p F P
0 g
s
.839 .704 .714 r
.10328 .33836 m .10105 .34197 L .09765 .33696 L p F P
0 g
s
.238 0 0 r
.54149 .47619 m .55012 .4744 L .5411 .47657 L closepath p F P
0 g
s
.195 0 0 r
.29801 .34791 m .29864 .348 L .2911 .34607 L p F P
0 g
s
.195 0 0 r
.29168 .34646 m .29801 .34791 L p .2911 .34607 L F P
0 g
s
.195 0 0 r
.28492 .34437 m .29168 .34646 L p .2911 .34607 L F P
0 g
s
.195 0 0 r
.2911 .34607 m .28581 .34462 L .28492 .34437 L p F P
0 g
s
.205 0 0 r
.43331 .35961 m .43735 .35953 L .43243 .35994 L closepath p F P
0 g
s
.252 0 0 r
.43243 .35994 m .43331 .35961 L p .41938 .36046 L F P
0 g
s
.871 .55 .442 r
.11838 .39444 m .1235 .3971 L .12284 .3924 L p F P
0 g
s
.871 .55 .442 r
.12284 .3924 m .11771 .38974 L .11838 .39444 L p F P
0 g
s
.252 0 0 r
.41938 .36046 m .42122 .36052 L .43243 .35994 L p F P
0 g
s
.247 0 0 r
.41938 .36046 m .42122 .36052 L .41891 .36063 L closepath p F P
0 g
s
.825 .413 .262 r
.15139 .42501 m .1492 .42076 L .15472 .42323 L p F P
0 g
s
.825 .413 .262 r
.15247 .4255 m .15139 .42501 L p .15472 .42323 L F P
0 g
s
.825 .413 .262 r
.15472 .42323 m .15554 .42479 L .15247 .4255 L p F P
0 g
s
.199 .719 .695 r
.51388 .34585 m .51584 .34531 L .51381 .34586 L closepath p F P
0 g
s
.3 .796 .807 r
.51388 .34585 m .51584 .34531 L .52522 .34278 L p F P
0 g
s
.764 .293 .122 r
.17441 .44032 m .18039 .44262 L .17717 .43866 L p F P
0 g
s
.764 .293 .122 r
.17211 .43749 m .17441 .44032 L p .17717 .43866 L F P
0 g
s
.764 .293 .122 r
.17717 .43866 m .17367 .43732 L .17211 .43749 L p F P
0 g
s
.473 .347 .628 r
.71115 .35396 m .70573 .3575 L .70156 .35369 L p F P
0 g
s
.473 .347 .628 r
.70156 .35369 m .71017 .34805 L .71115 .35396 L p F P
0 g
s
.531 0 0 r
.2878 .48313 m .28855 .48345 L .29698 .4849 L p F P
0 g
s
.486 0 0 r
.296 .48625 m .28855 .48345 L .29698 .4849 L p F P
0 g
s
.486 0 0 r
.29956 .48688 m .296 .48625 L p .29698 .4849 L F P
0 g
s
.486 0 0 r
.29698 .4849 m .30153 .48661 L .29956 .48688 L p F P
0 g
s
.195 .716 .691 r
.51584 .34531 m .51381 .34586 L .51094 .34662 L p F P
0 g
s
.597 .054 0 r
.25702 .47457 m .25859 .47545 L .26622 .47716 L p F P
0 g
s
.56 0 0 r
.26485 .47858 m .25859 .47545 L .26622 .47716 L p F P
0 g
s
.56 0 0 r
.26911 .47955 m .26485 .47858 L p .26622 .47716 L F P
0 g
s
.56 0 0 r
.26622 .47716 m .27064 .47938 L .26911 .47955 L p F P
0 g
s
.876 .654 .598 r
.09892 .36374 m .10366 .36657 L .10486 .3613 L p F P
0 g
s
.876 .654 .598 r
.10486 .3613 m .10014 .35845 L .09892 .36374 L p F P
0 g
s
.449 0 0 r
.31871 .48906 m .32249 .49022 L .31652 .48946 L closepath p F P
0 g
s
.227 0 0 r
.27652 .34221 m .27123 .34076 L .2678 .33952 L p F P
0 g
s
0 .475 .795 r
.25413 .33566 m .25473 .33582 L .26112 .33807 L p F P
0 g
s
0 .505 .796 r
.26296 .33798 m .25473 .33582 L .26112 .33807 L p F P
0 g
s
0 .505 .796 r
.26572 .33879 m .26296 .33798 L p .26112 .33807 L F P
0 g
s
0 .505 .796 r
.26112 .33807 m .2678 .33952 L .26572 .33879 L p F P
0 g
s
.208 0 0 r
.4718 .49232 m .47434 .49118 L .46152 .49254 L p F P
0 g
s
.208 0 0 r
.46152 .49254 m .4609 .49281 L .4718 .49232 L p F P
0 g
s
.329 0 0 r
.37737 .49531 m .38473 .49637 L .37456 .49604 L closepath p F P
0 g
s
.352 0 0 r
.30705 .35006 m .30204 .34861 L .29864 .348 L p F P
0 g
s
.866 .523 .4 r
.12454 .40169 m .12971 .40432 L .12868 .39973 L p F P
0 g
s
.866 .523 .4 r
.12868 .39973 m .1235 .3971 L .12454 .40169 L p F P
0 g
s
.624 .08 0 r
.24139 .46925 m .23992 .46937 L .23849 .46846 L closepath p F P
0 g
s
.274 0 .157 r
.64952 .42791 m .65024 .42609 L .64002 .43061 L p F P
0 g
s
.274 0 .157 r
.64172 .43266 m .64952 .42791 L p .64002 .43061 L F P
0 g
s
.274 0 .157 r
.64002 .43061 m .63867 .43401 L .64172 .43266 L p F P
0 g
s
.212 0 0 r
.5665 .46833 m .56642 .46841 L .56311 .46923 L closepath p F P
0 g
s
.212 0 0 r
.56403 .47076 m .56642 .46841 L .56311 .46923 L p F P
0 g
s
.212 0 0 r
.55265 .47378 m .56403 .47076 L p .56311 .46923 L F P
0 g
s
.367 0 0 r
.34392 .49391 m .34634 .49348 L .34167 .49238 L p F P
0 g
s
.367 0 0 r
.34121 .49364 m .34392 .49391 L p .34167 .49238 L F P
0 g
s
.367 0 0 r
.3325 .49157 m .34121 .49364 L p .34167 .49238 L F P
0 g
s
.367 0 0 r
.34167 .49238 m .33288 .49151 L .3325 .49157 L p F P
0 g
s
.254 0 .097 r
.63841 .43455 m .63867 .43401 L .62829 .4383 L p F P
0 g
s
.254 0 .097 r
.62829 .4383 m .62729 .44037 L .63841 .43455 L p F P
0 g
s
.284 0 0 r
.32805 .35479 m .32957 .35475 L .32355 .35326 L p F P
0 g
s
.284 0 0 r
.32321 .35401 m .32805 .35479 L p .32355 .35326 L F P
0 g
s
.284 0 0 r
.31578 .35177 m .32321 .35401 L p .32355 .35326 L F P
0 g
s
.284 0 0 r
.32355 .35326 m .3161 .3518 L .31578 .35177 L p F P
0 g
s
.412 .22 .507 r
.69551 .3801 m .69355 .38127 L .69344 .37638 L p F P
0 g
s
.412 .22 .507 r
.69344 .37638 m .69613 .37478 L .69551 .3801 L p F P
0 g
s
.285 0 0 r
.40696 .3609 m .40502 .36093 L .40226 .36184 L p F P
0 g
s
.323 0 0 r
.40502 .36093 m .40226 .36184 L .394 .36086 L closepath p F P
0 g
s
.638 .665 .86 r
.68499 .31108 m .67986 .31458 L p .67217 .31149 L F P
0 g
s
.624 .652 .857 r
.67986 .31458 m .68499 .31108 L .68622 .31319 L closepath p F P
0 g
s
.452 .883 .884 r
.562 .33127 m .56375 .33124 L .55269 .3352 L p F P
0 g
s
.452 .883 .884 r
.55269 .3352 m .5513 .33525 L .562 .33127 L p F P
0 g
s
.299 0 0 r
.41891 .36063 m .4162 .36163 L .40696 .3609 L closepath p F P
0 g
s
.285 0 0 r
.41533 .36203 m .4162 .36163 L .40696 .3609 L p F P
0 g
s
.285 0 0 r
.4053 .36219 m .41533 .36203 L p .40696 .3609 L F P
0 g
s
.285 0 0 r
.40226 .36184 m .4053 .36219 L p .40696 .3609 L F P
0 g
s
.306 0 0 r
.4013 .36223 m .40226 .36184 L .394 .36086 L p F P
0 g
s
.306 0 0 r
.39241 .36211 m .4013 .36223 L p .394 .36086 L F P
0 g
s
.306 0 0 r
.38833 .36146 m .39241 .36211 L p .394 .36086 L F P
0 g
s
.306 0 0 r
.394 .36086 m .39072 .3608 L .38833 .36146 L p F P
0 g
s
0 0 0 r
.48661 .35215 m .48601 .35232 L .48096 .35313 L closepath p F P
0 g
s
.012 0 0 r
.48319 .35347 m .48601 .35232 L .48096 .35313 L p F P
0 g
s
.012 0 0 r
.48149 .35376 m .48319 .35347 L p .48096 .35313 L F P
0 g
s
.012 0 0 r
.47206 .35513 m .48149 .35376 L p .48096 .35313 L F P
0 g
s
.638 .919 .978 r
.60262 .31943 m .59151 .32384 L .58873 .32303 L p F P
0 g
s
.615 .919 .976 r
.57764 .32738 m .58873 .32303 L .59151 .32384 L p F P
0 g
s
.336 0 0 r
.39072 .3608 m .38833 .36146 L .38202 .3605 L closepath p F P
0 g
s
.595 .589 .815 r
.70064 .31755 m .7004 .317 L .689 .31847 L p F P
0 g
s
.61 .601 .818 r
.7004 .317 m .689 .31847 L .68622 .31319 L p F P
0 g
s
.595 .048 0 r
.25702 .47457 m .25859 .47545 L .25564 .47477 L closepath p F P
0 g
s
.266 .772 .772 r
.52522 .34278 m .52488 .34284 L .51584 .34531 L closepath p F P
0 g
s
.195 .716 .691 r
.52197 .34365 m .52488 .34284 L .51584 .34531 L p F P
0 g
s
.195 .716 .691 r
.51094 .34662 m .52197 .34365 L p .51584 .34531 L F P
0 g
s
.288 0 .209 r
.66062 .42045 m .66147 .41777 L .6514 .42252 L p F P
0 g
s
.288 0 .209 r
.65746 .42271 m .66062 .42045 L p .6514 .42252 L F P
0 g
s
.288 0 .209 r
.6514 .42252 m .65024 .42609 L .65746 .42271 L p F P
0 g
s
.871 .674 .634 r
.09548 .35558 m .10014 .35845 L .10193 .35298 L p F P
0 g
s
.871 .674 .634 r
.10193 .35298 m .09729 .3501 L .09548 .35558 L p F P
0 g
s
.247 0 0 r
.47484 .4909 m .47799 .49073 L .47434 .49118 L closepath p F P
0 g
s
.18 0 0 r
.55012 .4744 m .5411 .47657 L .53864 .47854 L p F P
0 g
s
.254 0 0 r
.42122 .36052 m .41891 .36063 L .4162 .36163 L p F P
0 g
s
.231 0 .029 r
.61622 .44561 m .61618 .44567 L .61681 .44538 L closepath p F P
0 g
s
.852 .704 .697 r
.09976 .34441 m .10105 .34197 L .09765 .33696 L p F P
0 g
s
.679 .827 .954 r
.63085 .31425 m .63038 .31385 L .63346 .31268 L closepath p F P
0 g
s
.857 .491 .357 r
.1311 .40881 m .12971 .40432 L .13494 .40693 L p F P
0 g
s
.857 .491 .357 r
.13303 .40977 m .1311 .40881 L p .13494 .40693 L F P
0 g
s
.857 .491 .357 r
.13494 .40693 m .13552 .40874 L .13303 .40977 L p F P
0 g
s
.673 .148 0 r
.21793 .46251 m .2133 .45893 L .21993 .46099 L p F P
0 g
s
.673 .148 0 r
.22081 .46342 m .21793 .46251 L p .21993 .46099 L F P
0 g
s
.673 .148 0 r
.21993 .46099 m .22285 .46324 L .22081 .46342 L p F P
0 g
s
.675 .751 .908 r
.13391 .31198 m .14434 .308 L .14784 .31127 L p F P
0 g
s
.668 .751 .912 r
.14434 .308 m .13391 .31198 L .13041 .30853 L p F P
0 g
s
.229 0 .026 r
.61681 .44538 m .61618 .44567 L .61444 .44862 L p F P
0 g
s
.264 0 0 r
.43243 .35994 m .43016 .36083 L .42122 .36052 L closepath p F P
0 g
s
.254 0 0 r
.42896 .36141 m .43016 .36083 L .42122 .36052 L p F P
0 g
s
.254 0 0 r
.41948 .36185 m .42896 .36141 L p .42122 .36052 L F P
0 g
s
.254 0 0 r
.4162 .36163 m .41948 .36185 L p .42122 .36052 L F P
0 g
s
.146 .604 .928 r
.22337 .32663 m .22653 .3272 L .23249 .32961 L p F P
0 g
s
.187 .638 .942 r
.23356 .32836 m .22653 .3272 L .23249 .32961 L p F P
0 g
s
.187 .638 .942 r
.23249 .32961 m .23702 .33021 L .23356 .32836 L p F P
0 g
s
.658 .716 .891 r
.6582 .31125 m .66944 .30773 L .67217 .31149 L p F P
0 g
s
.668 .745 .908 r
.66944 .30773 m .6582 .31125 L .65548 .30817 L p F P
0 g
s
.673 .765 .92 r
.64427 .31211 m .65548 .30817 L .6582 .31125 L p F P
0 g
s
.311 0 0 r
.39126 .49592 m .39712 .49659 L .38925 .49651 L closepath p F P
0 g
s
.618 .747 .939 r
.14784 .31127 m .15816 .30868 L .16166 .31177 L p F P
0 g
s
.608 .745 .942 r
.15816 .30868 m .14784 .31127 L .14434 .308 L p F P
0 g
s
.785 .733 .804 r
.11017 .32184 m .10572 .3191 L .10902 .32286 L closepath p F P
0 g
s
.812 .733 .777 r
.10354 .32895 m .10902 .32286 L .10572 .3191 L p F P
0 g
s
.316 0 0 r
.38684 .36197 m .38833 .36146 L .38202 .3605 L p F P
0 g
s
.316 0 0 r
.38053 .36171 m .38684 .36197 L p .38202 .3605 L F P
0 g
s
.316 0 0 r
.37443 .36051 m .38053 .36171 L p .38202 .3605 L F P
0 g
s
.316 0 0 r
.38202 .3605 m .37595 .36019 L .37443 .36051 L p F P
0 g
s
.778 .735 .813 r
.11017 .32184 m .11984 .31428 L p .10553 .31889 L F P
0 g
s
.778 .735 .813 r
.10553 .31889 m .10572 .3191 L .11017 .32184 L p F P
0 g
s
.35 .681 .979 r
.19837 .31854 m .19259 .31829 L .18911 .31562 L p F P
0 g
s
.372 .696 .983 r
.19259 .31829 m .19837 .31854 L .20402 .32108 L p F P
0 g
s
.68 .793 .934 r
.65548 .30817 m .64427 .31211 L .64155 .30962 L p F P
0 g
s
.368 .13 .416 r
.69342 .386 m .69343 .3859 L .68379 .39133 L p F P
0 g
s
.368 .13 .416 r
.68977 .39216 m .69342 .386 L p .68379 .39133 L F P
0 g
s
.368 .13 .416 r
.68379 .39133 m .68344 .39572 L .68977 .39216 L p F P
0 g
s
.715 .212 .038 r
.20036 .45469 m .1963 .45096 L .20262 .45313 L p F P
0 g
s
.715 .212 .038 r
.2047 .4562 m .20036 .45469 L p .20262 .45313 L F P
0 g
s
.715 .212 .038 r
.20262 .45313 m .20584 .45609 L .2047 .4562 L p F P
0 g
s
.275 0 .104 r
.62729 .44037 m .61681 .44538 L .62674 .44151 L closepath p F P
0 g
s
.229 0 .026 r
.62499 .44452 m .62674 .44151 L .61681 .44538 L p F P
0 g
s
.229 0 .026 r
.61444 .44862 m .62499 .44452 L p .61681 .44538 L F P
0 g
s
.351 0 0 r
.34672 .35709 m .35041 .358 L .34471 .35727 L closepath p F P
0 g
s
.527 0 0 r
.2878 .48313 m .28855 .48345 L .28726 .48322 L closepath p F P
0 g
s
.801 .36 .197 r
.15975 .43155 m .16546 .43396 L .16277 .42985 L p F P
0 g
s
.801 .36 .197 r
.16277 .42985 m .15704 .42745 L .15975 .43155 L p F P
0 g
s
.623 .078 0 r
.23635 .46964 m .23155 .46651 L .23849 .46846 L p F P
0 g
s
.623 .078 0 r
.23849 .46846 m .23992 .46937 L .23635 .46964 L p F P
0 g
s
.547 .733 .962 r
.16166 .31177 m .16655 .31113 L .17169 .31386 L p F P
0 g
s
.562 .744 .962 r
.17192 .31039 m .16655 .31113 L .17169 .31386 L p F P
0 g
s
.562 .744 .962 r
.17169 .31386 m .17541 .31327 L .17192 .31039 L p F P
0 g
s
.336 0 0 r
.37595 .36019 m .37443 .36051 L .37086 .35987 L closepath p F P
0 g
s
.182 0 0 r
.57752 .46527 m .57769 .46509 L .5665 .46833 L p F P
0 g
s
.182 0 0 r
.5665 .46833 m .56642 .46841 L .57752 .46527 L p F P
0 g
s
.117 .579 .917 r
.22653 .3272 m .22337 .32663 L .21991 .32447 L p F P
0 g
s
.403 0 0 r
.33288 .49151 m .3325 .49157 L .33182 .49138 L closepath p F P
0 g
s
.818 .399 .249 r
.15554 .42479 m .15704 .42745 L .15247 .4255 L closepath p F P
0 g
s
.205 0 0 r
.47075 .49279 m .4718 .49232 L .4609 .49281 L p F P
0 g
s
.205 0 0 r
.4609 .49281 m .45786 .49412 L .47075 .49279 L p F P
0 g
s
0 .466 .734 r
.28581 .34462 m .28492 .34437 L .28384 .34414 L closepath p F P
0 g
s
0 0 0 r
.51022 .34689 m .51094 .34662 L .49995 .34922 L p F P
0 g
s
0 0 0 r
.49995 .34922 m .49855 .34969 L .51022 .34689 L p F P
0 g
s
.782 .322 .151 r
.17367 .43732 m .17211 .43749 L .17123 .43634 L closepath p F P
0 g
s
.172 0 0 r
.5247 .48254 m .52657 .48133 L .51463 .48367 L p F P
0 g
s
.172 0 0 r
.51463 .48367 m .51367 .48428 L .5247 .48254 L p F P
0 g
s
.292 0 0 r
.40517 .49613 m .41034 .49656 L .40358 .49663 L closepath p F P
0 g
s
.398 0 0 r
.32914 .49203 m .32249 .49022 L .33182 .49138 L p F P
0 g
s
.398 0 0 r
.33182 .49138 m .3325 .49157 L .32914 .49203 L p F P
0 g
s
.45 .302 .588 r
.70817 .36187 m .70252 .36548 L .70188 .35997 L p F P
0 g
s
.45 .302 .588 r
.70188 .35997 m .70573 .3575 L .70817 .36187 L p F P
0 g
s
.638 .665 .86 r
.67217 .31149 m .68347 .30856 L .68499 .31108 L p F P
0 g
s
.65 .693 .877 r
.68347 .30856 m .67217 .31149 L .66944 .30773 L p F P
0 g
s
.18 0 0 r
.57524 .46752 m .57752 .46527 L .56642 .46841 L p F P
0 g
s
.18 0 0 r
.56642 .46841 m .56403 .47076 L .57524 .46752 L p F P
0 g
s
.212 0 0 r
.43735 .35953 m .43243 .35994 L .43016 .36083 L p F P
0 g
s
.672 .854 .969 r
.63346 .31268 m .63038 .31385 L .62765 .31193 L p F P
0 g
s
.681 .856 .966 r
.61649 .31636 m .62765 .31193 L .63038 .31385 L p F P
0 g
s
.304 0 .262 r
.67168 .41175 m .67236 .40904 L .66243 .41402 L p F P
0 g
s
.304 0 .262 r
.66902 .41401 m .67168 .41175 L p .66243 .41402 L F P
0 g
s
.304 0 .262 r
.66243 .41402 m .66147 .41777 L .66902 .41401 L p F P
0 g
s
.752 .27 .096 r
.18391 .44651 m .18039 .44262 L .18643 .4449 L p F P
0 g
s
.752 .27 .096 r
.18727 .44778 m .18391 .44651 L p .18643 .4449 L F P
0 g
s
.752 .27 .096 r
.18643 .4449 m .18891 .44762 L .18727 .44778 L p F P
0 g
s
0 0 0 r
.49698 .35023 m .49855 .34969 L .48661 .35215 L p F P
0 g
s
0 0 0 r
.48661 .35215 m .48601 .35232 L .49698 .35023 L p F P
0 g
s
.313 0 0 r
.37186 .3612 m .37443 .36051 L .37086 .35987 L p F P
0 g
s
.313 0 0 r
.36949 .36103 m .37186 .3612 L p .37086 .35987 L F P
0 g
s
.313 0 0 r
.36056 .35901 m .36949 .36103 L p .37086 .35987 L F P
0 g
s
.313 0 0 r
.37086 .35987 m .3606 .359 L .36056 .35901 L p F P
0 g
s
.852 .704 .697 r
.09765 .33696 m .09521 .34148 L .09976 .34441 L p F P
0 g
s
.864 .692 .668 r
.09271 .34718 m .09729 .3501 L .09976 .34441 L p F P
0 g
s
.864 .692 .668 r
.09976 .34441 m .09521 .34148 L .09271 .34718 L p F P
0 g
s
.812 .733 .777 r
.099 .326 m .10354 .32895 L p .10572 .3191 L F P
0 g
s
.827 .722 .748 r
.09495 .33317 m .0986 .33548 L .10354 .32895 L p F P
0 g
s
.827 .722 .748 r
.09423 .33221 m .09495 .33317 L p .10354 .32895 L F P
0 g
s
.827 .722 .748 r
.10354 .32895 m .099 .326 L .09423 .33221 L p F P
0 g
s
.534 .726 .963 r
.16655 .31113 m .16166 .31177 L .15816 .30868 L p F P
0 g
s
.841 .446 .299 r
.13832 .41572 m .14373 .41825 L .14185 .41391 L p F P
0 g
s
.841 .446 .299 r
.14185 .41391 m .13642 .41138 L .13832 .41572 L p F P
0 g
s
.18 0 0 r
.47799 .49073 m .47434 .49118 L .4718 .49232 L p F P
0 g
s
.46 0 0 r
.28772 .48474 m .296 .48625 L .28855 .48345 L p F P
0 g
s
.46 0 0 r
.28434 .48346 m .28772 .48474 L p .28855 .48345 L F P
0 g
s
.46 0 0 r
.28855 .48345 m .28726 .48322 L .28434 .48346 L p F P
0 g
s
.23 0 0 r
.44696 .49425 m .45766 .49414 L .4447 .49517 L closepath p F P
0 g
s
.209 0 0 r
.61359 .44984 m .61444 .44862 L .60375 .45249 L p F P
0 g
s
.209 0 0 r
.60375 .45249 m .60245 .45436 L .61359 .44984 L p F P
0 g
s
.407 .716 .987 r
.20278 .31868 m .19837 .31854 L .20402 .32108 L p F P
0 g
s
.407 .716 .987 r
.20402 .32108 m .20626 .32109 L .20278 .31868 L p F P
0 g
s
.272 0 0 r
.41909 .49592 m .42461 .4962 L .41758 .49644 L closepath p F P
0 g
s
.729 .741 .861 r
.1225 .31277 m .11984 .31428 L .11633 .31064 L p F P
0 g
s
.778 .735 .813 r
.11984 .31428 m .11633 .31064 L .10553 .31889 L p F P
0 g
s
.206 0 0 r
.53834 .47878 m .53864 .47854 L .5276 .48053 L p F P
0 g
s
.206 0 0 r
.5276 .48053 m .52657 .48133 L .53834 .47878 L p F P
0 g
s
.251 0 0 r
.43302 .49529 m .44024 .49544 L .43128 .49595 L closepath p F P
0 g
s
0 .457 .719 r
.2815 .34351 m .27652 .34221 L .28384 .34414 L p F P
0 g
s
0 .457 .719 r
.28384 .34414 m .28492 .34437 L .2815 .34351 L p F P
0 g
s
.377 0 0 r
.34121 .49364 m .3325 .49157 L .32914 .49203 L p F P
0 g
s
.498 0 0 r
.28726 .48322 m .28434 .48346 L .28051 .48188 L closepath p F P
0 g
s
.216 0 0 r
.4456 .35887 m .44413 .35945 L .43735 .35953 L closepath p F P
0 g
s
.212 0 0 r
.44222 .36039 m .44413 .35945 L .43735 .35953 L p F P
0 g
s
.212 0 0 r
.43554 .3609 m .44222 .36039 L p .43735 .35953 L F P
0 g
s
.212 0 0 r
.43016 .36083 m .43554 .3609 L p .43735 .35953 L F P
0 g
s
.248 0 0 r
.3161 .3518 m .31578 .35177 L .31531 .35166 L closepath p F P
0 g
s
.235 0 0 r
.60177 .45533 m .60245 .45436 L .59134 .45841 L p F P
0 g
s
.235 0 0 r
.59134 .45841 m .59092 .459 L .60177 .45533 L p F P
0 g
s
.535 0 0 r
.25735 .47681 m .26485 .47858 L .25859 .47545 L p F P
0 g
s
.535 0 0 r
.25349 .47489 m .25735 .47681 L p .25859 .47545 L F P
0 g
s
.535 0 0 r
.25859 .47545 m .25564 .47477 L .25349 .47489 L p F P
0 g
s
.879 .585 .485 r
.11318 .38266 m .11247 .38377 L .11241 .38223 L closepath p F P
0 g
s
0 .486 .814 r
.25413 .33566 m .25473 .33582 L .25339 .33533 L closepath p F P
0 g
s
.267 0 0 r
.3124 .35155 m .30705 .35006 L .31531 .35166 L p F P
0 g
s
.267 0 0 r
.31531 .35166 m .31578 .35177 L .3124 .35155 L p F P
0 g
s
.407 .215 .506 r
.703 .37555 m .69551 .3801 L .69613 .37478 L p F P
0 g
s
.407 .215 .506 r
.69613 .37478 m .70289 .37066 L .703 .37555 L p F P
0 g
s
.567 .924 .949 r
.58731 .32278 m .58873 .32303 L .57764 .32738 L p F P
0 g
s
.567 .924 .949 r
.57764 .32738 m .57701 .3273 L .58731 .32278 L p F P
0 g
s
.187 0 0 r
.48694 .48956 m .48577 .49012 L .47799 .49073 L closepath p F P
0 g
s
.18 0 0 r
.48343 .49121 m .48577 .49012 L .47799 .49073 L p F P
0 g
s
.18 0 0 r
.47836 .49186 m .48343 .49121 L p .47799 .49073 L F P
0 g
s
.18 0 0 r
.4718 .49232 m .47836 .49186 L p .47799 .49073 L F P
0 g
s
.348 .824 .803 r
.54732 .33568 m .54985 .33531 L .5388 .33901 L p F P
0 g
s
.348 .824 .803 r
.5388 .33901 m .53639 .33939 L .54732 .33568 L p F P
0 g
s
.852 .481 .349 r
.13552 .40874 m .13642 .41138 L .13303 .40977 L closepath p F P
0 g
s
.717 .744 .873 r
.1225 .31277 m .13041 .30853 L .12689 .30511 L p F P
0 g
s
.717 .744 .873 r
.12689 .30511 m .11767 .3099 L .1225 .31277 L p F P
0 g
s
.729 .741 .861 r
.11633 .31064 m .11767 .3099 L .1225 .31277 L p F P
0 g
s
.428 0 0 r
.32321 .35401 m .31578 .35177 L .3124 .35155 L p F P
0 g
s
.676 .836 .96 r
.64155 .30962 m .63346 .31268 L .64047 .30876 L closepath p F P
0 g
s
.672 .854 .969 r
.63883 .30746 m .64047 .30876 L .63346 .31268 L p F P
0 g
s
.672 .854 .969 r
.62765 .31193 m .63883 .30746 L p .63346 .31268 L F P
0 g
s
.608 .059 0 r
.24399 .4718 m .23992 .46937 L .23635 .46964 L p F P
0 g
s
.881 .586 .484 r
.10772 .38431 m .10754 .37946 L .11241 .38223 L p F P
0 g
s
.881 .586 .484 r
.11092 .38612 m .10772 .38431 L p .11241 .38223 L F P
0 g
s
.881 .586 .484 r
.11241 .38223 m .11247 .38377 L .11092 .38612 L p F P
0 g
s
.884 .613 .524 r
.10272 .37666 m .10754 .37946 L .10777 .37449 L p F P
0 g
s
.884 .613 .524 r
.10777 .37449 m .10296 .37169 L .10272 .37666 L p F P
0 g
s
.783 .321 .148 r
.16837 .43786 m .16546 .43396 L .17123 .43634 L p F P
0 g
s
.783 .321 .148 r
.17123 .43634 m .17211 .43749 L .16837 .43786 L p F P
0 g
s
0 .466 .795 r
.25624 .33583 m .26296 .33798 L .25473 .33582 L p F P
0 g
s
0 .466 .795 r
.25068 .33414 m .25624 .33583 L p .25473 .33582 L F P
0 g
s
0 .466 .795 r
.25473 .33582 m .25339 .33533 L .25068 .33414 L p F P
0 g
s
.322 0 0 r
.3606 .359 m .36056 .35901 L .36047 .35899 L closepath p F P
0 g
s
.68 .88 .973 r
.62765 .31193 m .61649 .31636 L .61375 .31491 L p F P
0 g
s
.346 0 0 r
.35724 .35965 m .35041 .358 L .36047 .35899 L p F P
0 g
s
.346 0 0 r
.36047 .35899 m .36056 .35901 L .35724 .35965 L p F P
0 g
s
.447 0 0 r
.36949 .36103 m .36056 .35901 L .35724 .35965 L p F P
0 g
s
.346 0 0 r
.29168 .34646 m .28492 .34437 L .2815 .34351 L p F P
0 g
s
.83 .415 .256 r
.14593 .4225 m .15139 .42501 L .1492 .42076 L p F P
0 g
s
.83 .415 .256 r
.1492 .42076 m .14373 .41825 L .14593 .4225 L p F P
0 g
s
.159 0 0 r
.4564 .35762 m .4456 .35887 L .44413 .35945 L p F P
0 g
s
.882 .636 .562 r
.09821 .36886 m .10296 .37169 L .10366 .36657 L p F P
0 g
s
.882 .636 .562 r
.10366 .36657 m .09892 .36374 L .09821 .36886 L p F P
0 g
s
.874 .552 .438 r
.11332 .39175 m .11838 .39444 L .11771 .38974 L p F P
0 g
s
.874 .552 .438 r
.11771 .38974 m .11264 .38706 L .11332 .39175 L p F P
0 g
s
.022 0 0 r
.4952 .35106 m .49698 .35023 L .48601 .35232 L p F P
0 g
s
.022 0 0 r
.48601 .35232 m .48319 .35347 L .4952 .35106 L p F P
0 g
s
.57 .006 0 r
.25564 .47477 m .25349 .47489 L .2512 .47365 L closepath p F P
0 g
s
.377 0 0 r
.32788 .49219 m .32914 .49203 L .32249 .49022 L p F P
0 g
s
.377 0 0 r
.32212 .49143 m .32788 .49219 L p .32249 .49022 L F P
0 g
s
.377 0 0 r
.31531 .48959 m .32212 .49143 L p .32249 .49022 L F P
0 g
s
.377 0 0 r
.32249 .49022 m .31652 .48946 L .31531 .48959 L p F P
0 g
s
.32 .035 .314 r
.68266 .40114 m .6829 .39989 L .67311 .40509 L p F P
0 g
s
.32 .035 .314 r
.67783 .40615 m .68266 .40114 L p .67311 .40509 L F P
0 g
s
.32 .035 .314 r
.67311 .40509 m .67236 .40904 L .67783 .40615 L p F P
0 g
s
.84 .71 .72 r
.0986 .33548 m .09495 .33317 L .09765 .33696 L closepath p F P
0 g
s
.61 .601 .818 r
.68622 .31319 m .6976 .31119 L .7004 .317 L p F P
0 g
s
.61 .645 .86 r
.68499 .31108 m .68622 .31319 L .6976 .31119 L p F P
0 g
s
.459 .719 .981 r
.17541 .31327 m .18562 .31295 L .18911 .31562 L p F P
0 g
s
.443 .712 .981 r
.18562 .31295 m .17541 .31327 L .17192 .31039 L p F P
0 g
s
.041 .562 .868 r
.25339 .33533 m .25068 .33414 L .24812 .33364 L closepath p F P
0 g
s
.204 .628 .95 r
.21509 .32218 m .20626 .32109 L .20278 .31868 L p F P
0 g
s
.183 0 0 r
.59979 .45773 m .60177 .45533 L .59092 .459 L p F P
0 g
s
.183 0 0 r
.59197 .46055 m .59979 .45773 L p .59092 .459 L F P
0 g
s
.183 0 0 r
.59092 .459 m .58872 .46164 L .59197 .46055 L p F P
0 g
s
.452 .883 .882 r
.56092 .33128 m .562 .33127 L .5513 .33525 L p F P
0 g
s
.452 .883 .882 r
.5513 .33525 m .54985 .33531 L .56092 .33128 L p F P
0 g
s
.879 .657 .599 r
.09424 .36087 m .09892 .36374 L .10014 .35845 L p F P
0 g
s
.879 .657 .599 r
.10014 .35845 m .09548 .35558 L .09424 .36087 L p F P
0 g
s
.869 .524 .396 r
.11943 .39902 m .12454 .40169 L .1235 .3971 L p F P
0 g
s
.869 .524 .396 r
.1235 .3971 m .11838 .39444 L .11943 .39902 L p F P
0 g
s
.666 .134 0 r
.21141 .46041 m .21793 .46251 L .2133 .45893 L p F P
0 g
s
.666 .134 0 r
.2133 .45893 m .20672 .45685 L .21141 .46041 L p F P
0 g
s
.7 .193 .026 r
.20584 .45609 m .20672 .45685 L .2133 .45893 L p F P
0 g
s
.181 0 0 r
.55265 .47378 m .55255 .47387 L .55012 .4744 L closepath p F P
0 g
s
.18 0 0 r
.54992 .47599 m .55255 .47387 L .55012 .4744 L p F P
0 g
s
.18 0 0 r
.54521 .47713 m .54992 .47599 L p .55012 .4744 L F P
0 g
s
.18 0 0 r
.53864 .47854 m .54521 .47713 L p .55012 .4744 L F P
0 g
s
.854 .709 .701 r
.09521 .34148 m .09765 .33696 L .09495 .33317 L p F P
0 g
s
.662 .901 .98 r
.60294 .31958 m .60262 .31943 L .60534 .31832 L closepath p F P
0 g
s
.308 .799 .789 r
.53592 .33947 m .53639 .33939 L .52522 .34278 L p F P
0 g
s
.308 .799 .789 r
.52522 .34278 m .52488 .34284 L .53592 .33947 L p F P
0 g
s
.571 .926 .948 r
.58595 .32254 m .58731 .32278 L .57701 .3273 L p F P
0 g
s
.571 .926 .948 r
.57701 .3273 m .57484 .32702 L .58595 .32254 L p F P
0 g
s
.502 .402 .674 r
.70716 .34276 m .7088 .34167 L .70926 .34369 L closepath p F P
0 g
s
.626 .081 0 r
.22995 .46794 m .22466 .46454 L .23155 .46651 L p F P
0 g
s
.626 .081 0 r
.23587 .46967 m .22995 .46794 L p .23155 .46651 L F P
0 g
s
.626 .081 0 r
.23155 .46651 m .23635 .46964 L .23587 .46967 L p F P
0 g
s
.36 0 0 r
.34634 .49348 m .35141 .49453 L .34392 .49391 L closepath p F P
0 g
s
.117 .579 .917 r
.21991 .32447 m .22086 .32468 L .22653 .3272 L p F P
0 g
s
.144 .611 .926 r
.22998 .32648 m .22086 .32468 L .22653 .3272 L p F P
0 g
s
.144 .611 .926 r
.23022 .32657 m .22998 .32648 L p .22653 .3272 L F P
0 g
s
.144 .611 .926 r
.22653 .3272 m .23356 .32836 L .23022 .32657 L p F P
0 g
s
.738 .252 .086 r
.18891 .44762 m .19002 .44877 L .1963 .45096 L p F P
0 g
s
.709 .198 .012 r
.19413 .45248 m .20036 .45469 L .1963 .45096 L p F P
0 g
s
.709 .198 .012 r
.1963 .45096 m .19002 .44877 L .19413 .45248 L p F P
0 g
s
.169 0 0 r
.5235 .4833 m .5247 .48254 L .51367 .48428 L p F P
0 g
s
.169 0 0 r
.51367 .48428 m .51152 .48563 L .5235 .4833 L p F P
0 g
s
.461 0 0 r
.30153 .48661 m .30457 .48766 L .29956 .48688 L closepath p F P
0 g
s
.541 0 0 r
.27064 .47938 m .27256 .48027 L .28051 .48188 L p F P
0 g
s
.497 0 0 r
.27959 .48318 m .27256 .48027 L .28051 .48188 L p F P
0 g
s
.497 0 0 r
.28187 .48365 m .27959 .48318 L p .28051 .48188 L F P
0 g
s
.497 0 0 r
.28051 .48188 m .28434 .48346 L .28187 .48365 L p F P
0 g
s
.877 .581 .482 r
.11247 .38377 m .11264 .38706 L .11092 .38612 L closepath p F P
0 g
s
.383 .17 .462 r
.6935 .38586 m .69343 .3859 L .69355 .38127 L p F P
0 g
s
.383 .17 .462 r
.69355 .38127 m .69551 .3801 L .6935 .38586 L p F P
0 g
s
.158 0 0 r
.49675 .48897 m .49934 .48772 L .48694 .48956 L p F P
0 g
s
.158 0 0 r
.48694 .48956 m .48577 .49012 L .49675 .48897 L p F P
0 g
s
.25 0 .093 r
.63712 .43719 m .63841 .43455 L .62729 .44037 L p F P
0 g
s
.25 0 .093 r
.62729 .44037 m .62674 .44151 L .63712 .43719 L p F P
0 g
s
.365 0 0 r
.35633 .35986 m .35724 .35965 L .35041 .358 L p F P
0 g
s
.365 0 0 r
.34914 .3591 m .35633 .35986 L p .35041 .358 L F P
0 g
s
.365 0 0 r
.34339 .3574 m .34914 .3591 L p .35041 .358 L F P
0 g
s
.365 0 0 r
.35041 .358 m .34471 .35727 L .34339 .3574 L p F P
0 g
s
.415 0 0 r
.31652 .48946 m .31531 .48959 L .31335 .489 L closepath p F P
0 g
s
.532 .469 .73 r
.70617 .33225 m .70957 .33281 L .70692 .33466 L closepath p F P
0 g
s
.527 .481 .749 r
.70433 .3268 m .70617 .33225 L .70957 .33281 L p F P
0 g
s
.775 .31 .139 r
.17441 .44032 m .17211 .43749 L .16837 .43786 L p F P
0 g
s
.862 .495 .353 r
.12594 .40617 m .1311 .40881 L .12971 .40432 L p F P
0 g
s
.862 .495 .353 r
.12971 .40432 m .12454 .40169 L .12594 .40617 L p F P
0 g
s
.514 .435 .704 r
.71789 .33533 m .7088 .34167 L .70692 .33466 L p F P
0 g
s
.514 .435 .704 r
.71786 .33523 m .71789 .33533 L p .70692 .33466 L F P
0 g
s
.514 .435 .704 r
.70692 .33466 m .70957 .33281 L .71786 .33523 L p F P
0 g
s
.537 0 0 r
.27064 .47938 m .27256 .48027 L .26911 .47955 L closepath p F P
0 g
s
.873 .677 .635 r
.09087 .35267 m .09548 .35558 L .09729 .3501 L p F P
0 g
s
.873 .677 .635 r
.09729 .3501 m .09271 .34718 L .09087 .35267 L p F P
0 g
s
.797 .346 .17 r
.1541 .42912 m .15975 .43155 L .15704 .42745 L p F P
0 g
s
.797 .346 .17 r
.15173 .42556 m .1541 .42912 L p .15704 .42745 L F P
0 g
s
.797 .346 .17 r
.15704 .42745 m .15247 .4255 L .15173 .42556 L p F P
0 g
s
.655 .123 0 r
.22285 .46324 m .22466 .46454 L .22081 .46342 L closepath p F P
0 g
s
.352 0 0 r
.29864 .348 m .29939 .34826 L .30705 .35006 L p F P
0 g
s
.327 0 0 r
.30686 .35074 m .29939 .34826 L .30705 .35006 L p F P
0 g
s
.327 0 0 r
.31052 .35147 m .30686 .35074 L p .30705 .35006 L F P
0 g
s
.327 0 0 r
.30705 .35006 m .3124 .35155 L .31052 .35147 L p F P
0 g
s
.812 .733 .777 r
.10572 .3191 m .10548 .31894 L .099 .326 L p F P
0 g
s
.8 .737 .793 r
.10553 .31889 m .10548 .31894 L .10572 .3191 L closepath p F P
0 g
s
0 .485 .823 r
.24176 .33137 m .23702 .33021 L .23356 .32836 L p F P
0 g
s
0 .513 .835 r
.23702 .33021 m .24176 .33137 L .24812 .33364 L p F P
0 g
s
.638 .919 .978 r
.60534 .31832 m .60262 .31943 L .59986 .31849 L p F P
0 g
s
.638 .919 .978 r
.58873 .32303 m .59986 .31849 L .60262 .31943 L p F P
0 g
s
.423 .255 .547 r
.70904 .36673 m .70289 .37066 L .70252 .36548 L p F P
0 g
s
.423 .255 .547 r
.70252 .36548 m .70817 .36187 L .70904 .36673 L p F P
0 g
s
.558 .519 .768 r
.70325 .32389 m .70825 .32401 L .70433 .3268 L closepath p F P
0 g
s
.527 .481 .749 r
.71481 .32462 m .70825 .32401 L .70433 .3268 L p F P
0 g
s
.527 .481 .749 r
.71595 .32825 m .71481 .32462 L p .70433 .3268 L F P
0 g
s
.527 .481 .749 r
.70957 .33281 m .71595 .32825 L p .70433 .3268 L F P
0 g
s
.15 0 0 r
.56364 .47108 m .56403 .47076 L .55265 .47378 L p F P
0 g
s
.15 0 0 r
.55265 .47378 m .55255 .47387 L .56364 .47108 L p F P
0 g
s
.373 0 0 r
.37443 .36051 m .38053 .36171 L .37186 .3612 L closepath p F P
0 g
s
.095 0 0 r
.47206 .35513 m .48149 .35376 L .47097 .35563 L closepath p F P
0 g
s
.227 0 0 r
.2678 .33952 m .26968 .34012 L .27652 .34221 L p F P
0 g
s
.188 0 0 r
.2774 .34247 m .26968 .34012 L .27652 .34221 L p F P
0 g
s
.188 0 0 r
.27864 .3428 m .2774 .34247 L p .27652 .34221 L F P
0 g
s
.188 0 0 r
.27652 .34221 m .2815 .34351 L .27864 .3428 L p F P
0 g
s
.22 .732 .693 r
.53592 .33947 m .52488 .34284 L .52197 .34365 L p F P
0 g
s
.493 .903 .899 r
.57247 .32696 m .57484 .32702 L .56375 .33124 L p F P
0 g
s
.493 .903 .899 r
.56375 .33124 m .562 .33127 L .57247 .32696 L p F P
0 g
s
.768 .748 .834 r
.10553 .31889 m .11633 .31064 L .11281 .30704 L p F P
0 g
s
.768 .748 .834 r
.10202 .31505 m .10553 .31889 L p .11281 .30704 L F P
0 g
s
.8 .74 .797 r
.10548 .31894 m .10553 .31889 L .10202 .31505 L p F P
0 g
s
.812 .736 .78 r
.09451 .32302 m .099 .326 L .10548 .31894 L p F P
0 g
s
.812 .736 .78 r
.10548 .31894 m .10112 .31591 L .09451 .32302 L p F P
0 g
s
.8 .74 .797 r
.10202 .31505 m .10112 .31591 L .10548 .31894 L p F P
0 g
s
.154 0 0 r
.45841 .35739 m .4581 .35751 L .4564 .35762 L closepath p F P
0 g
s
.159 0 0 r
.45511 .35897 m .4581 .35751 L .4564 .35762 L p F P
0 g
s
.159 0 0 r
.45447 .35903 m .45511 .35897 L p .4564 .35762 L F P
0 g
s
.159 0 0 r
.44413 .35945 m .45447 .35903 L p .4564 .35762 L F P
0 g
s
.569 .005 0 r
.24989 .47503 m .24399 .4718 L .2512 .47365 L p F P
0 g
s
.569 .005 0 r
.25001 .47506 m .24989 .47503 L p .2512 .47365 L F P
0 g
s
.569 .005 0 r
.2512 .47365 m .25349 .47489 L .25001 .47506 L p F P
0 g
s
.534 .726 .963 r
.15816 .30868 m .16167 .30829 L .16655 .31113 L p F P
0 g
s
.548 .739 .965 r
.16841 .3075 m .16167 .30829 L .16655 .31113 L p F P
0 g
s
.548 .739 .965 r
.16655 .31113 m .17192 .31039 L .16841 .3075 L p F P
0 g
s
.144 0 0 r
.53577 .48046 m .53834 .47878 L .52657 .48133 L p F P
0 g
s
.144 0 0 r
.52657 .48133 m .5247 .48254 L .53577 .48046 L p F P
0 g
s
.75 .262 .077 r
.17796 .44419 m .18391 .44651 L .18039 .44262 L p F P
0 g
s
.75 .262 .077 r
.18039 .44262 m .17441 .44032 L .17796 .44419 L p F P
0 g
s
.627 .66 .863 r
.68347 .30856 m .69106 .30684 L .68499 .31108 L closepath p F P
0 g
s
.61 .645 .86 r
.69482 .30603 m .69106 .30684 L .68499 .31108 L p F P
0 g
s
.61 .645 .86 r
.6976 .31119 m .69482 .30603 L p .68499 .31108 L F P
0 g
s
.148 0 0 r
.56133 .47298 m .56364 .47108 L .55255 .47387 L p F P
0 g
s
.148 0 0 r
.55255 .47387 m .54992 .47599 L .56133 .47298 L p F P
0 g
s
.447 .301 .589 r
.71182 .35949 m .70817 .36187 L .70573 .3575 L p F P
0 g
s
.447 .301 .589 r
.70573 .3575 m .71115 .35396 L .71182 .35949 L p F P
0 g
s
.412 0 0 r
.31191 .4899 m .30457 .48766 L .31335 .489 L p F P
0 g
s
.412 0 0 r
.31335 .489 m .31531 .48959 L .31191 .4899 L p F P
0 g
s
.554 .537 .791 r
.70064 .31755 m .70325 .32389 L .70825 .32401 L p F P
0 g
s
0 0 0 r
.50799 .34775 m .51022 .34689 L .49855 .34969 L p F P
0 g
s
0 0 0 r
.49855 .34969 m .49698 .35023 L .50799 .34775 L p F P
0 g
s
.122 0 0 r
.46901 .35653 m .47097 .35563 L .45841 .35739 L p F P
0 g
s
.122 0 0 r
.45841 .35739 m .4581 .35751 L .46901 .35653 L p F P
0 g
s
.668 .751 .912 r
.13041 .30853 m .14082 .30473 L .14434 .308 L p F P
0 g
s
.662 .75 .915 r
.14082 .30473 m .13041 .30853 L .12689 .30511 L p F P
0 g
s
.218 0 0 r
.41034 .49656 m .40358 .49663 L .40196 .497 L p F P
0 g
s
.251 0 0 r
.40358 .49663 m .40196 .497 L .39712 .49659 L closepath p F P
0 g
s
.237 0 0 r
.39912 .49763 m .40196 .497 L .39712 .49659 L p F P
0 g
s
.237 0 0 r
.39766 .49761 m .39912 .49763 L p .39712 .49659 L F P
0 g
s
.237 0 0 r
.38803 .49675 m .39766 .49761 L p .39712 .49659 L F P
0 g
s
.237 0 0 r
.39712 .49659 m .38925 .49651 L .38803 .49675 L p F P
0 g
s
.361 0 0 r
.34471 .35727 m .34339 .3574 L .34096 .3568 L closepath p F P
0 g
s
.231 0 0 r
.41758 .49644 m .41592 .49686 L .41034 .49656 L closepath p F P
0 g
s
.218 0 0 r
.41326 .49752 m .41592 .49686 L .41034 .49656 L p F P
0 g
s
.218 0 0 r
.41102 .49755 m .41326 .49752 L p .41034 .49656 L F P
0 g
s
.218 0 0 r
.40196 .497 m .41102 .49755 L p .41034 .49656 L F P
0 g
s
.608 .745 .942 r
.14434 .308 m .15466 .30559 L .15816 .30868 L p F P
0 g
s
.599 .743 .945 r
.15466 .30559 m .14434 .308 L .14082 .30473 L p F P
0 g
s
.35 .681 .979 r
.18911 .31562 m .193 .3159 L .19837 .31854 L p F P
0 g
s
.38 .703 .984 r
.19929 .31626 m .193 .3159 L .19837 .31854 L p F P
0 g
s
.38 .703 .984 r
.19837 .31854 m .20278 .31868 L .19929 .31626 L p F P
0 g
s
.841 .439 .282 r
.13296 .41315 m .13832 .41572 L .13642 .41138 L p F P
0 g
s
.841 .439 .282 r
.1316 .41004 m .13296 .41315 L p .13642 .41138 L F P
0 g
s
.841 .439 .282 r
.13642 .41138 m .13303 .40977 L .1316 .41004 L p F P
0 g
s
.271 0 0 r
.38925 .49651 m .38803 .49675 L .38473 .49637 L closepath p F P
0 g
s
.476 .385 .674 r
.71927 .34172 m .71789 .33533 L .7088 .34167 L p F P
0 g
s
.476 .385 .674 r
.71317 .34599 m .71927 .34172 L p .7088 .34167 L F P
0 g
s
.476 .385 .674 r
.7088 .34167 m .70926 .34369 L .71317 .34599 L p F P
0 g
s
.198 0 0 r
.42461 .4962 m .41758 .49644 L .41592 .49686 L p F P
0 g
s
.668 .745 .908 r
.65548 .30817 m .66672 .30436 L .66944 .30773 L p F P
0 g
s
.677 .773 .923 r
.66672 .30436 m .65548 .30817 L .65276 .30544 L p F P
0 g
s
.68 .793 .934 r
.64155 .30962 m .65276 .30544 L .65548 .30817 L p F P
0 g
s
.7 .189 .016 r
.20584 .45609 m .20672 .45685 L .2047 .4562 L closepath p F P
0 g
s
.255 0 0 r
.38478 .49738 m .38803 .49675 L .38473 .49637 L p F P
0 g
s
.255 0 0 r
.3741 .49612 m .38478 .49738 L p .38473 .49637 L F P
0 g
s
.255 0 0 r
.38473 .49637 m .37456 .49604 L .3741 .49612 L p F P
0 g
s
.413 0 0 r
.32957 .35475 m .33192 .35546 L .34096 .3568 L p F P
0 g
s
.383 0 0 r
.32957 .35475 m .33192 .35546 L .32805 .35479 L closepath p F P
0 g
s
.739 .25 .076 r
.18891 .44762 m .19002 .44877 L .18727 .44778 L closepath p F P
0 g
s
.336 .077 .365 r
.68471 .39887 m .6829 .39989 L .68344 .39572 L p F P
0 g
s
.336 .077 .365 r
.68344 .39572 m .68977 .39216 L .68471 .39887 L p F P
0 g
s
.638 .919 .978 r
.61101 .31379 m .61287 .31455 L .60534 .31832 L p F P
0 g
s
.638 .919 .978 r
.59986 .31849 m .61101 .31379 L p .60534 .31832 L F P
0 g
s
.65 .91 .981 r
.61375 .31491 m .60534 .31832 L .61287 .31455 L closepath p F P
0 g
s
.65 .693 .877 r
.66944 .30773 m .68073 .30444 L .68347 .30856 L p F P
0 g
s
.661 .722 .895 r
.68073 .30444 m .66944 .30773 L .66672 .30436 L p F P
0 g
s
.342 0 0 r
.36021 .49502 m .36193 .49533 L .35946 .49518 L closepath p F P
0 g
s
.349 0 0 r
.36021 .49502 m .36193 .49533 L .37299 .49596 L p F P
0 g
s
.854 .709 .701 r
.09071 .33852 m .09521 .34148 L p .09495 .33317 L F P
0 g
s
.866 .696 .67 r
.08818 .34424 m .09271 .34718 L .09521 .34148 L p F P
0 g
s
.866 .696 .67 r
.09521 .34148 m .09071 .33852 L .08818 .34424 L p F P
0 g
s
.826 .72 .748 r
.09076 .3278 m .09451 .32302 L .099 .326 L p F P
0 g
s
.826 .72 .748 r
.099 .326 m .09423 .33221 L .09076 .3278 L p F P
0 g
s
0 .394 .703 r
.2678 .33952 m .26968 .34012 L .26572 .33879 L closepath p F P
0 g
s
.21 0 0 r
.43128 .49595 m .42988 .49634 L .42461 .4962 L closepath p F P
0 g
s
.198 0 0 r
.42708 .49711 m .42988 .49634 L .42461 .4962 L p F P
0 g
s
.198 0 0 r
.42544 .49716 m .42708 .49711 L p .42461 .4962 L F P
0 g
s
.198 0 0 r
.41592 .49686 m .42544 .49716 L p .42461 .4962 L F P
0 g
s
.377 .164 .459 r
.70289 .38018 m .6935 .38586 L .69551 .3801 L p F P
0 g
s
.377 .164 .459 r
.69551 .3801 m .703 .37555 L .70289 .38018 L p F P
0 g
s
.329 .666 .974 r
.193 .3159 m .18911 .31562 L .18562 .31295 L p F P
0 g
s
.039 .561 .867 r
.24722 .33262 m .24176 .33137 L .24812 .33364 L p F P
0 g
s
.039 .561 .867 r
.24812 .33364 m .25068 .33414 L .24722 .33262 L p F P
0 g
s
.196 0 0 r
.49973 .48748 m .50329 .48705 L .49934 .48772 L closepath p F P
0 g
s
.185 0 0 r
.46776 .35725 m .46901 .35653 L .4581 .35751 L p F P
0 g
s
.185 0 0 r
.4581 .35751 m .45511 .35897 L .46776 .35725 L p F P
0 g
s
.375 0 0 r
.33988 .35782 m .33192 .35546 L .34096 .3568 L p F P
0 g
s
.375 0 0 r
.34011 .35786 m .33988 .35782 L p .34096 .3568 L F P
0 g
s
.375 0 0 r
.34096 .3568 m .34339 .3574 L .34011 .35786 L p F P
0 g
s
.364 0 0 r
.38833 .36146 m .39241 .36211 L .38684 .36197 L closepath p F P
0 g
s
.685 .838 .957 r
.65004 .30302 m .65276 .30544 L .64155 .30962 L p F P
0 g
s
.685 .838 .957 r
.64829 .30371 m .65004 .30302 L p .64155 .30962 L F P
0 g
s
.685 .838 .957 r
.64155 .30962 m .64047 .30876 L .64829 .30371 L p F P
0 g
s
.486 .382 .661 r
.70926 .34369 m .71317 .34599 L .71017 .34805 L closepath p F P
0 g
s
.152 0 0 r
.58864 .46173 m .58872 .46164 L .57769 .46509 L p F P
0 g
s
.152 0 0 r
.57769 .46509 m .57752 .46527 L .58864 .46173 L p F P
0 g
s
.29 0 0 r
.37456 .49604 m .3741 .49612 L .37299 .49596 L closepath p F P
0 g
s
.725 .743 .866 r
.11767 .3099 m .11281 .30704 L .11633 .31064 L closepath p F P
0 g
s
.283 0 0 r
.37083 .49663 m .36193 .49533 L .37299 .49596 L p F P
0 g
s
.283 0 0 r
.37299 .49596 m .3741 .49612 L .37083 .49663 L p F P
0 g
s
.178 0 0 r
.44024 .49544 m .43128 .49595 L .42988 .49634 L p F P
0 g
s
.224 0 .077 r
.63867 .43401 m .63841 .43455 L .64172 .43266 L closepath p F P
0 g
s
.787 .327 .149 r
.16277 .43558 m .15975 .43155 L .16546 .43396 L p F P
0 g
s
.787 .327 .149 r
.16818 .43788 m .16277 .43558 L p .16546 .43396 L F P
0 g
s
.787 .327 .149 r
.16546 .43396 m .16837 .43786 L .16818 .43788 L p F P
0 g
s
.331 0 0 r
.29864 .348 m .29939 .34826 L .29801 .34791 L closepath p F P
0 g
s
.521 .72 .963 r
.16167 .30829 m .15816 .30868 L .15466 .30559 L p F P
0 g
s
.246 0 .141 r
.65024 .42609 m .64952 .42791 L .65746 .42271 L closepath p F P
0 g
s
.468 0 0 r
.27179 .48152 m .27959 .48318 L .27256 .48027 L p F P
0 g
s
.468 0 0 r
.26714 .4796 m .27179 .48152 L p .27256 .48027 L F P
0 g
s
.468 0 0 r
.27256 .48027 m .26911 .47955 L .26714 .4796 L p F P
0 g
s
.844 .716 .723 r
.09423 .33221 m .09401 .33255 L .09495 .33317 L closepath p F P
0 g
s
.854 .709 .701 r
.09495 .33317 m .09401 .33255 L .09071 .33852 L p F P
0 g
s
.205 0 0 r
.61248 .45144 m .61359 .44984 L .60245 .45436 L p F P
0 g
s
.205 0 0 r
.60245 .45436 m .60177 .45533 L .61248 .45144 L p F P
0 g
s
.721 .743 .869 r
.11767 .3099 m .12689 .30511 L p .11281 .30703 L F P
0 g
s
.721 .743 .869 r
.11281 .30703 m .11281 .30704 L .11767 .3099 L p F P
0 g
s
.203 0 .016 r
.63591 .43929 m .63712 .43719 L .62674 .44151 L p F P
0 g
s
.203 0 .016 r
.62838 .44312 m .63591 .43929 L p .62674 .44151 L F P
0 g
s
.203 0 .016 r
.62674 .44151 m .62499 .44452 L .62838 .44312 L p F P
0 g
s
.149 0 0 r
.5863 .46407 m .58864 .46173 L .57752 .46527 L p F P
0 g
s
.149 0 0 r
.57752 .46527 m .57524 .46752 L .5863 .46407 L p F P
0 g
s
.831 .413 .246 r
.14054 .41996 m .14593 .4225 L .14373 .41825 L p F P
0 g
s
.831 .413 .246 r
.14373 .41825 m .13832 .41572 L .14054 .41996 L p F P
0 g
s
.134 .583 .925 r
.21991 .32447 m .22086 .32468 L .21828 .32346 L closepath p F P
0 g
s
.581 .567 .803 r
.7004 .317 m .70152 .31692 L .70064 .31755 L closepath p F P
0 g
s
.554 .537 .791 r
.71189 .31654 m .70152 .31692 L .70064 .31755 L p F P
0 g
s
.554 .537 .791 r
.71333 .32032 m .71189 .31654 L p .70064 .31755 L F P
0 g
s
.554 .537 .791 r
.70825 .32401 m .71333 .32032 L p .70064 .31755 L F P
0 g
s
.886 .591 .483 r
.10291 .38151 m .10772 .38431 L .10754 .37946 L p F P
0 g
s
.886 .591 .483 r
.10754 .37946 m .10272 .37666 L .10291 .38151 L p F P
0 g
s
.604 .932 .959 r
.59736 .31789 m .59986 .31849 L .58873 .32303 L p F P
0 g
s
.604 .932 .959 r
.58873 .32303 m .58731 .32278 L .59736 .31789 L p F P
0 g
s
.887 .616 .523 r
.09797 .37383 m .10272 .37666 L .10296 .37169 L p F P
0 g
s
.887 .616 .523 r
.10296 .37169 m .09821 .36886 L .09797 .37383 L p F P
0 g
s
.652 .11 0 r
.20494 .45828 m .21141 .46041 L .20672 .45685 L p F P
0 g
s
.652 .11 0 r
.20219 .45619 m .20494 .45828 L p .20672 .45685 L F P
0 g
s
.652 .11 0 r
.20672 .45685 m .2047 .4562 L .20219 .45619 L p F P
0 g
s
.23 0 0 r
.44413 .35945 m .45447 .35903 L .44222 .36039 L closepath p F P
0 g
s
.389 0 0 r
.32212 .49143 m .31531 .48959 L .31191 .4899 L p F P
0 g
s
.345 0 0 r
.40226 .36184 m .4053 .36219 L .4013 .36223 L closepath p F P
0 g
s
.599 .04 0 r
.22317 .46592 m .22995 .46794 L .22466 .46454 L p F P
0 g
s
.599 .04 0 r
.21924 .46341 m .22317 .46592 L p .22466 .46454 L F P
0 g
s
.599 .04 0 r
.22466 .46454 m .22081 .46342 L .21924 .46341 L p F P
0 g
s
.593 .577 .805 r
.70152 .31692 m .7004 .317 L .6976 .31119 L p F P
0 g
s
.127 0 0 r
.50329 .48705 m .49934 .48772 L .49675 .48897 L p F P
0 g
s
.638 .669 .863 r
.69106 .30684 m .68347 .30856 L .68073 .30444 L p F P
0 g
s
.877 .554 .434 r
.10832 .38903 m .11332 .39175 L .11264 .38706 L p F P
0 g
s
.877 .554 .434 r
.1082 .38812 m .10832 .38903 L p .11264 .38706 L F P
0 g
s
.877 .554 .434 r
.11264 .38706 m .11092 .38612 L .1082 .38812 L p F P
0 g
s
.178 0 0 r
.44074 .49636 m .44385 .49543 L .44024 .49544 L p F P
0 g
s
.178 0 0 r
.42988 .49634 m .44074 .49636 L p .44024 .49544 L F P
0 g
s
.189 0 0 r
.4447 .49517 m .44385 .49543 L .44024 .49544 L closepath p F P
0 g
s
.513 .437 .707 r
.70957 .33281 m .71595 .32825 L .71786 .33523 L closepath p F P
0 g
s
.386 0 0 r
.31126 .48995 m .31191 .4899 L .30457 .48766 L p F P
0 g
s
.386 0 0 r
.30426 .48882 m .31126 .48995 L p .30457 .48766 L F P
0 g
s
.386 0 0 r
.2981 .48695 m .30426 .48882 L p .30457 .48766 L F P
0 g
s
.386 0 0 r
.30457 .48766 m .29956 .48688 L .2981 .48695 L p F P
0 g
s
0 0 0 r
.52163 .34378 m .52197 .34365 L .51094 .34662 L p F P
0 g
s
0 0 0 r
.51094 .34662 m .51022 .34689 L .52163 .34378 L p F P
0 g
s
.351 0 0 r
.29903 .34897 m .30686 .35074 L .29939 .34826 L p F P
0 g
s
.351 0 0 r
.29522 .34751 m .29903 .34897 L p .29939 .34826 L F P
0 g
s
.351 0 0 r
.29939 .34826 m .29801 .34791 L .29522 .34751 L p F P
0 g
s
.885 .639 .561 r
.09353 .36599 m .09821 .36886 L .09892 .36374 L p F P
0 g
s
.885 .639 .561 r
.09892 .36374 m .09424 .36087 L .09353 .36599 L p F P
0 g
s
.259 0 0 r
.38478 .49738 m .3741 .49612 L .37083 .49663 L p F P
0 g
s
.264 0 0 r
.36976 .49679 m .37083 .49663 L .36193 .49533 L p F P
0 g
s
.264 0 0 r
.36243 .49632 m .36976 .49679 L p .36193 .49533 L F P
0 g
s
.264 0 0 r
.3569 .4955 m .36243 .49632 L p .36193 .49533 L F P
0 g
s
.264 0 0 r
.36193 .49533 m .35946 .49518 L .3569 .4955 L p F P
0 g
s
.688 .866 .966 r
.63883 .30746 m .62765 .31193 L .62492 .3103 L p F P
0 g
s
.68 .88 .973 r
.61375 .31491 m .62492 .3103 L .62765 .31193 L p F P
0 g
s
.155 0 0 r
.49588 .48939 m .49675 .48897 L .48577 .49012 L p F P
0 g
s
.155 0 0 r
.48577 .49012 m .48343 .49121 L .49588 .48939 L p F P
0 g
s
.279 0 0 r
.43016 .36083 m .43554 .3609 L .42896 .36141 L closepath p F P
0 g
s
.317 0 0 r
.4162 .36163 m .41948 .36185 L .41533 .36203 L closepath p F P
0 g
s
.391 .85 .821 r
.55809 .33165 m .56092 .33128 L .54985 .33531 L p F P
0 g
s
.391 .85 .821 r
.5561 .33238 m .55809 .33165 L p .54985 .33531 L F P
0 g
s
.391 .85 .821 r
.54985 .33531 m .54732 .33568 L .5561 .33238 L p F P
0 g
s
.844 .72 .726 r
.09401 .33255 m .09423 .33221 L .09076 .3278 L p F P
0 g
s
.698 .176 0 r
.18795 .45025 m .19413 .45248 L .19002 .44877 L p F P
0 g
s
.698 .176 0 r
.18522 .44777 m .18795 .45025 L p .19002 .44877 L F P
0 g
s
.698 .176 0 r
.19002 .44877 m .18727 .44778 L .18522 .44777 L p F P
0 g
s
.265 0 .2 r
.66147 .41777 m .66062 .42045 L .66902 .41401 L closepath p F P
0 g
s
.812 .372 .197 r
.15247 .4255 m .15173 .42556 L .15139 .42501 L closepath p F P
0 g
s
.462 .34 .627 r
.7171 .34988 m .71115 .35396 L .71017 .34805 L p F P
0 g
s
.462 .34 .627 r
.71017 .34805 m .71317 .34599 L .7171 .34988 L p F P
0 g
s
.222 0 .074 r
.64172 .43266 m .63841 .43455 L .63712 .43719 L p F P
0 g
s
.302 0 0 r
.35946 .49518 m .3569 .4955 L .35141 .49453 L closepath p F P
0 g
s
.158 0 0 r
.45766 .49414 m .4447 .49517 L .44385 .49543 L p F P
0 g
s
.844 .72 .726 r
.09076 .3278 m .08962 .32953 L .09401 .33255 L p F P
0 g
s
.856 .712 .703 r
.08628 .33553 m .09071 .33852 L .09401 .33255 L p F P
0 g
s
.856 .712 .703 r
.09401 .33255 m .08962 .32953 L .08628 .33553 L p F P
0 g
s
.546 0 0 r
.25349 .47489 m .25735 .47681 L .25001 .47506 L closepath p F P
0 g
s
.872 .525 .391 r
.11438 .39633 m .11943 .39902 L .11838 .39444 L p F P
0 g
s
.872 .525 .391 r
.11838 .39444 m .11332 .39175 L .11438 .39633 L p F P
0 g
s
.178 0 0 r
.62474 .44488 m .62499 .44452 L .61444 .44862 L p F P
0 g
s
.178 0 0 r
.61444 .44862 m .61359 .44984 L .62474 .44488 L p F P
0 g
s
.108 .569 .915 r
.2239 .32408 m .22998 .32648 L .22086 .32468 L p F P
0 g
s
.108 .569 .915 r
.21644 .32233 m .2239 .32408 L p .22086 .32468 L F P
0 g
s
.108 .569 .915 r
.22086 .32468 m .21828 .32346 L .21644 .32233 L p F P
0 g
s
.296 0 0 r
.29801 .34791 m .29522 .34751 L .29168 .34646 L closepath p F P
0 g
s
.508 0 0 r
.26911 .47955 m .26714 .4796 L .26485 .47858 L closepath p F P
0 g
s
.571 .55 .793 r
.70152 .31692 m .70956 .31096 L .71189 .31654 L closepath p F P
0 g
s
.593 .577 .805 r
.70956 .31096 m .70152 .31692 L p .6976 .31119 L F P
0 g
s
.608 .059 0 r
.23635 .46964 m .23681 .46992 L .24399 .4718 L p F P
0 g
s
.56 0 0 r
.2428 .47312 m .24989 .47503 L .24399 .4718 L p F P
0 g
s
.56 0 0 r
.24399 .4718 m .23681 .46992 L .2428 .47312 L p F P
0 g
s
.1 0 0 r
.48149 .35376 m .47097 .35563 L .46901 .35653 L p F P
0 g
s
0 .371 .678 r
.27031 .34045 m .2774 .34247 L .26968 .34012 L p F P
0 g
s
0 .371 .678 r
.26968 .34012 m .26572 .33879 L .26436 .33833 L p F P
0 g
s
0 .371 .678 r
.26436 .33833 m .27031 .34045 L p .26968 .34012 L F P
0 g
s
.882 .661 .599 r
.08963 .35797 m .09424 .36087 L .09548 .35558 L p F P
0 g
s
.882 .661 .599 r
.09548 .35558 m .09087 .35267 L .08963 .35797 L p F P
0 g
s
.851 .459 .302 r
.13303 .40977 m .1316 .41004 L .1311 .40881 L closepath p F P
0 g
s
.682 .152 0 r
.2047 .4562 m .20219 .45619 L .20036 .45469 L closepath p F P
0 g
s
.177 0 0 r
.53864 .47854 m .54521 .47713 L .53834 .47878 L closepath p F P
0 g
s
.398 0 0 r
.33076 .3565 m .33988 .35782 L .33192 .35546 L p F P
0 g
s
.398 0 0 r
.32619 .35488 m .33076 .3565 L p .33192 .35546 L F P
0 g
s
.398 0 0 r
.33192 .35546 m .32805 .35479 L .32619 .35488 L p F P
0 g
s
.134 0 0 r
.51152 .48563 m .51073 .48602 L .50329 .48705 L closepath p F P
0 g
s
.127 0 0 r
.50813 .48733 m .51073 .48602 L .50329 .48705 L p F P
0 g
s
.127 0 0 r
.50449 .48795 m .50813 .48733 L p .50329 .48705 L F P
0 g
s
.127 0 0 r
.49675 .48897 m .50449 .48795 L p .50329 .48705 L F P
0 g
s
.471 0 0 r
.28434 .48346 m .28772 .48474 L .28187 .48365 L closepath p F P
0 g
s
.813 .372 .192 r
.14794 .42579 m .14593 .4225 L .15139 .42501 L p F P
0 g
s
.813 .372 .192 r
.15139 .42501 m .15173 .42556 L .14794 .42579 L p F P
0 g
s
.243 0 0 r
.39766 .49761 m .38803 .49675 L .38478 .49738 L p F P
0 g
s
0 .371 .691 r
.25624 .33583 m .25068 .33414 L .24722 .33262 L p F P
0 g
s
.685 .839 .957 r
.64047 .30876 m .63883 .30746 L .64829 .30371 L closepath p F P
0 g
s
.414 0 0 r
.34339 .3574 m .34914 .3591 L .34011 .35786 L closepath p F P
0 g
s
.865 .496 .347 r
.12084 .4035 m .12594 .40617 L .12454 .40169 L p F P
0 g
s
.865 .496 .347 r
.12454 .40169 m .11943 .39902 L .12084 .4035 L p F P
0 g
s
.265 0 .147 r
.64952 .42791 m .64172 .43266 L .6489 .42947 L closepath p F P
0 g
s
.222 0 .074 r
.64737 .43265 m .6489 .42947 L .64172 .43266 L p F P
0 g
s
.222 0 .074 r
.63712 .43719 m .64737 .43265 L p .64172 .43266 L F P
0 g
s
.427 0 0 r
.29956 .48688 m .2981 .48695 L .296 .48625 L closepath p F P
0 g
s
.393 .205 .503 r
.7085 .37205 m .703 .37555 L .70289 .37066 L p F P
0 g
s
.393 .205 .503 r
.70289 .37066 m .70904 .36673 L .7085 .37205 L p F P
0 g
s
.18 0 0 r
.4718 .49232 m .47836 .49186 L .47075 .49279 L closepath p F P
0 g
s
.883 .565 .441 r
.11092 .38612 m .1082 .38812 L .10772 .38431 L closepath p F P
0 g
s
.775 .31 .139 r
.16837 .43786 m .16847 .43799 L .17441 .44032 L p F P
0 g
s
.747 .253 .06 r
.17206 .44185 m .17796 .44419 L .17441 .44032 L p F P
0 g
s
.747 .253 .06 r
.17441 .44032 m .16847 .43799 L .17206 .44185 L p F P
0 g
s
.282 0 0 r
.35446 .49579 m .3569 .4955 L .35141 .49453 L p F P
0 g
s
.282 0 0 r
.35176 .49556 m .35446 .49579 L p .35141 .49453 L F P
0 g
s
.282 0 0 r
.343 .494 m .35176 .49556 L p .35141 .49453 L F P
0 g
s
.282 0 0 r
.35141 .49453 m .34392 .49391 L .343 .494 L p F P
0 g
s
.443 .712 .981 r
.17192 .31039 m .18212 .31026 L .18562 .31295 L p F P
0 g
s
.423 .705 .981 r
.18212 .31026 m .17192 .31039 L .16841 .3075 L p F P
0 g
s
.543 .495 .752 r
.70825 .32401 m .71333 .32032 L .71481 .32462 L closepath p F P
0 g
s
.633 .084 0 r
.22081 .46342 m .21924 .46341 L .21793 .46251 L closepath p F P
0 g
s
.876 .681 .636 r
.08633 .34973 m .09087 .35267 L .09271 .34718 L p F P
0 g
s
.876 .681 .636 r
.09271 .34718 m .08818 .34424 L .08633 .34973 L p F P
0 g
s
.348 .112 .408 r
.69343 .3859 m .69342 .386 L .6935 .38586 L closepath p F P
0 g
s
.344 .822 .8 r
.54699 .33574 m .54732 .33568 L .53639 .33939 L p F P
0 g
s
.344 .822 .8 r
.53639 .33939 m .53592 .33947 L .54699 .33574 L p F P
0 g
s
.346 .11 .407 r
.70256 .38457 m .70289 .38018 L .6935 .38586 L p F P
0 g
s
.346 .11 .407 r
.69307 .39027 m .70256 .38457 L p .6935 .38586 L F P
0 g
s
.346 .11 .407 r
.6935 .38586 m .69342 .386 L .69307 .39027 L p F P
0 g
s
.361 .122 .411 r
.69342 .386 m .68977 .39216 L .69307 .39027 L closepath p F P
0 g
s
.112 0 0 r
.54521 .47713 m .53834 .47878 L .53577 .48046 L p F P
0 g
s
.724 .215 .015 r
.18727 .44778 m .18522 .44777 L .18391 .44651 L closepath p F P
0 g
s
.282 0 .255 r
.67236 .40904 m .67168 .41175 L .67783 .40615 L closepath p F P
0 g
s
.807 .362 .185 r
.1541 .42912 m .15173 .42556 L .14794 .42579 L p F P
0 g
s
.181 .608 .942 r
.2093 .31969 m .20278 .31868 L .19929 .31626 L p F P
0 g
s
.204 .628 .95 r
.20278 .31868 m .2093 .31969 L .21509 .32218 L p F P
0 g
s
.38 0 0 r
.32805 .35479 m .32619 .35488 L .32321 .35401 L closepath p F P
0 g
s
.521 .72 .963 r
.15466 .30559 m .15699 .30538 L .16167 .30829 L p F P
0 g
s
.535 .734 .967 r
.1649 .3046 m .15699 .30538 L .16167 .30829 L p F P
0 g
s
.535 .734 .967 r
.16167 .30829 m .16841 .3075 L .1649 .3046 L p F P
0 g
s
.666 .914 .977 r
.62254 .30912 m .62492 .3103 L .61375 .31491 L p F P
0 g
s
.666 .914 .977 r
.61375 .31491 m .61287 .31455 L .62254 .30912 L p F P
0 g
s
.222 0 0 r
.40196 .497 m .41102 .49755 L .39912 .49763 L closepath p F P
0 g
s
.168 0 0 r
.45786 .49412 m .45783 .49414 L .45766 .49414 L closepath p F P
0 g
s
.158 0 0 r
.45475 .4951 m .45783 .49414 L .45766 .49414 L p F P
0 g
s
.158 0 0 r
.44385 .49543 m .45475 .4951 L p .45766 .49414 L F P
0 g
s
.768 .748 .834 r
.11281 .30704 m .11281 .30703 L .10202 .31505 L p F P
0 g
s
.766 .74 .83 r
.11281 .30703 m .10202 .31505 L .09849 .31127 L p F P
0 g
s
.798 .742 .801 r
.10112 .31591 m .10202 .31505 L .09849 .31127 L p F P
0 g
s
.135 0 0 r
.46875 .49347 m .47075 .49279 L .45786 .49412 L p F P
0 g
s
.135 0 0 r
.45786 .49412 m .45783 .49414 L .46875 .49347 L p F P
0 g
s
.812 .739 .783 r
.09008 .32 m .09451 .32302 L .10112 .31591 L p F P
0 g
s
.812 .739 .783 r
.10112 .31591 m .09682 .31284 L .09008 .32 L p F P
0 g
s
.798 .742 .801 r
.09849 .31127 m .09682 .31284 L .10112 .31591 L p F P
0 g
s
0 0 0 r
.51904 .34483 m .52163 .34378 L .51022 .34689 L p F P
0 g
s
0 0 0 r
.51022 .34689 m .50799 .34775 L .51904 .34483 L p F P
0 g
s
.329 .666 .974 r
.18562 .31295 m .18786 .31316 L .193 .3159 L p F P
0 g
s
.354 .689 .981 r
.19579 .31382 m .18786 .31316 L .193 .3159 L p F P
0 g
s
.354 .689 .981 r
.193 .3159 m .19929 .31626 L .19579 .31382 L p F P
0 g
s
0 .485 .823 r
.23356 .32836 m .23574 .32897 L .24176 .33137 L p F P
0 g
s
0 .524 .84 r
.24375 .3311 m .23574 .32897 L .24176 .33137 L p F P
0 g
s
0 .524 .84 r
.24176 .33137 m .24722 .33262 L .24375 .3311 L p F P
0 g
s
.506 0 0 r
.26364 .47967 m .25735 .47681 L .26485 .47858 L p F P
0 g
s
.506 0 0 r
.26485 .47858 m .26714 .4796 L .26364 .47967 L p F P
0 g
s
.15 0 0 r
.61096 .45328 m .61248 .45144 L .60177 .45533 L p F P
0 g
s
.15 0 0 r
.60177 .45533 m .59979 .45773 L .61096 .45328 L p F P
0 g
s
.15 0 0 r
.46875 .49347 m .45783 .49414 L .45475 .4951 L p F P
0 g
s
.853 .46 .299 r
.12767 .41056 m .12594 .40617 L .1311 .40881 L p F P
0 g
s
.853 .46 .299 r
.12789 .41067 m .12767 .41056 L p .1311 .40881 L F P
0 g
s
.853 .46 .299 r
.1311 .40881 m .1316 .41004 L .12789 .41067 L p F P
0 g
s
.12 0 0 r
.57476 .46792 m .57524 .46752 L .56403 .47076 L p F P
0 g
s
.12 0 0 r
.56403 .47076 m .56364 .47108 L .57476 .46792 L p F P
0 g
s
.424 0 0 r
.29466 .4871 m .28772 .48474 L .296 .48625 L p F P
0 g
s
.424 0 0 r
.296 .48625 m .2981 .48695 L .29466 .4871 L p F P
0 g
s
.492 .903 .897 r
.57203 .32695 m .57247 .32696 L .562 .33127 L p F P
0 g
s
.492 .903 .897 r
.562 .33127 m .56092 .33128 L .57203 .32695 L p F P
0 g
s
.377 0 0 r
.32914 .49203 m .33148 .49259 L .34121 .49364 L p F P
0 g
s
.371 0 0 r
.32914 .49203 m .33148 .49259 L .32788 .49219 L closepath p F P
0 g
s
.003 0 0 r
.50692 .34828 m .50799 .34775 L .49698 .35023 L p F P
0 g
s
.003 0 0 r
.49698 .35023 m .4952 .35106 L .50692 .34828 L p F P
0 g
s
.353 0 0 r
.4053 .36219 m .4013 .36223 L .39902 .36318 L p F P
0 g
s
.387 0 0 r
.4013 .36223 m .39902 .36318 L .39241 .36211 L closepath p F P
0 g
s
.537 .921 .917 r
.58317 .32234 m .58595 .32254 L .57484 .32702 L p F P
0 g
s
.537 .921 .917 r
.57748 .32469 m .58317 .32234 L p .57484 .32702 L F P
0 g
s
.537 .921 .917 r
.57484 .32702 m .57247 .32696 L .57748 .32469 L p F P
0 g
s
.257 .66 .965 r
.21828 .32346 m .21644 .32233 L .21509 .32218 L closepath p F P
0 g
s
.365 0 0 r
.41533 .36203 m .413 .36311 L .4053 .36219 L closepath p F P
0 g
s
.353 0 0 r
.41196 .36368 m .413 .36311 L .4053 .36219 L p F P
0 g
s
.353 0 0 r
.40276 .36377 m .41196 .36368 L p .4053 .36219 L F P
0 g
s
.353 0 0 r
.39902 .36318 m .40276 .36377 L p .4053 .36219 L F P
0 g
s
.321 0 0 r
.34392 .49391 m .343 .494 L .34121 .49364 L closepath p F P
0 g
s
.201 0 0 r
.41592 .49686 m .42544 .49716 L .41326 .49752 L closepath p F P
0 g
s
.373 0 0 r
.39781 .36378 m .39902 .36318 L .39241 .36211 L p F P
0 g
s
.373 0 0 r
.39004 .36363 m .39781 .36378 L p .39241 .36211 L F P
0 g
s
.373 0 0 r
.38507 .36261 m .39004 .36363 L p .39241 .36211 L F P
0 g
s
.373 0 0 r
.39241 .36211 m .38684 .36197 L .38507 .36261 L p F P
0 g
s
.346 0 0 r
.2815 .34351 m .28437 .34453 L .29168 .34646 L p F P
0 g
s
.302 0 0 r
.2815 .34351 m .28437 .34453 L .27864 .3428 L closepath p F P
0 g
s
.168 0 0 r
.45475 .4951 m .44385 .49543 L .44074 .49636 L p F P
0 g
s
0 .463 .757 r
.26572 .33879 m .26436 .33833 L .26296 .33798 L closepath p F P
0 g
s
.324 0 0 r
.41948 .36185 m .41533 .36203 L .413 .36311 L p F P
0 g
s
.18 0 0 r
.44061 .49639 m .44074 .49636 L .42988 .49634 L p F P
0 g
s
.18 0 0 r
.42988 .49634 m .42708 .49711 L .44061 .49639 L p F P
0 g
s
.593 .577 .805 r
.6976 .31119 m .70905 .30981 L .70956 .31096 L p F P
0 g
s
.608 .604 .822 r
.70905 .30981 m .6976 .31119 L .69482 .30603 L p F P
0 g
s
.399 0 0 r
.38684 .36197 m .38507 .36261 L .38053 .36171 L closepath p F P
0 g
s
.3 0 0 r
.29172 .34704 m .28437 .34453 L .29168 .34646 L p F P
0 g
s
.3 0 0 r
.29185 .34707 m .29172 .34704 L p .29168 .34646 L F P
0 g
s
.3 0 0 r
.29168 .34646 m .29522 .34751 L .29185 .34707 L p F P
0 g
s
.428 0 0 r
.3124 .35155 m .31489 .35242 L .32321 .35401 L p F P
0 g
s
.397 0 0 r
.3124 .35155 m .31489 .35242 L .31052 .35147 L closepath p F P
0 g
s
.662 .75 .915 r
.12689 .30511 m .1373 .30148 L .14082 .30473 L p F P
0 g
s
.656 .749 .918 r
.1373 .30148 m .12689 .30511 L .12336 .3017 L p F P
0 g
s
.721 .743 .869 r
.12689 .30511 m .12336 .3017 L .11281 .30703 L p F P
0 g
s
.315 0 0 r
.33966 .49429 m .33148 .49259 L .34121 .49364 L p F P
0 g
s
.315 0 0 r
.34121 .49364 m .343 .494 L .33966 .49429 L p F P
0 g
s
.418 .252 .547 r
.7122 .36468 m .70904 .36673 L .70817 .36187 L p F P
0 g
s
.418 .252 .547 r
.70817 .36187 m .71182 .35949 L .7122 .36468 L p F P
0 g
s
.324 0 0 r
.42571 .36314 m .427 .36238 L .41948 .36185 L p F P
0 g
s
.324 0 0 r
.41676 .3635 m .42571 .36314 L p .41948 .36185 L F P
0 g
s
.324 0 0 r
.413 .36311 m .41676 .3635 L p .41948 .36185 L F P
0 g
s
.333 0 0 r
.42896 .36141 m .427 .36238 L .41948 .36185 L closepath p F P
0 g
s
.785 .317 .127 r
.15714 .43313 m .16277 .43558 L .15975 .43155 L p F P
0 g
s
.785 .317 .127 r
.15975 .43155 m .1541 .42912 L .15714 .43313 L p F P
0 g
s
.605 .052 0 r
.23635 .46964 m .23681 .46992 L .23587 .46967 L closepath p F P
0 g
s
.268 .766 .717 r
.54699 .33574 m .53592 .33947 L .53303 .34029 L p F P
0 g
s
.22 .732 .693 r
.52197 .34365 m .53303 .34029 L .53592 .33947 L p F P
0 g
s
.868 .699 .671 r
.08372 .34125 m .08818 .34424 L .09071 .33852 L p F P
0 g
s
.868 .699 .671 r
.09071 .33852 m .08628 .33553 L .08372 .34125 L p F P
0 g
s
.827 .725 .752 r
.08726 .32352 m .09008 .32 L .09451 .32302 L p F P
0 g
s
.827 .725 .752 r
.09451 .32302 m .09076 .3278 L .08726 .32352 L p F P
0 g
s
.631 .081 0 r
.21563 .46336 m .21141 .46041 L .21793 .46251 L p F P
0 g
s
.631 .081 0 r
.21793 .46251 m .21924 .46341 L .21563 .46336 L p F P
0 g
s
.39 0 0 r
.32229 .35496 m .31489 .35242 L .32321 .35401 L p F P
0 g
s
.39 0 0 r
.32313 .3551 m .32229 .35496 L p .32321 .35401 L F P
0 g
s
.39 0 0 r
.32321 .35401 m .32619 .35488 L .32313 .3551 L p F P
0 g
s
.244 0 .138 r
.65746 .42271 m .64952 .42791 L .6489 .42947 L p F P
0 g
s
.435 .292 .588 r
.7194 .3543 m .71182 .35949 L .71115 .35396 L p F P
0 g
s
.435 .292 .588 r
.71115 .35396 m .7171 .34988 L .7194 .3543 L p F P
0 g
s
.384 0 0 r
.38318 .3634 m .38507 .36261 L .38053 .36171 L p F P
0 g
s
.384 0 0 r
.37831 .36317 m .38318 .3634 L p .38053 .36171 L F P
0 g
s
.384 0 0 r
.37114 .3614 m .37831 .36317 L p .38053 .36171 L F P
0 g
s
.384 0 0 r
.38053 .36171 m .37186 .3612 L .37114 .3614 L p F P
0 g
s
.599 .743 .945 r
.14082 .30473 m .15114 .30249 L .15466 .30559 L p F P
0 g
s
.591 .74 .947 r
.15114 .30249 m .14082 .30473 L .1373 .30148 L p F P
0 g
s
.681 .151 0 r
.19851 .45613 m .19413 .45248 L .20036 .45469 L p F P
0 g
s
.681 .151 0 r
.19858 .45615 m .19851 .45613 L p .20036 .45469 L F P
0 g
s
.681 .151 0 r
.20036 .45469 m .20219 .45619 L .19858 .45615 L p F P
0 g
s
.102 0 0 r
.52178 .48419 m .5235 .4833 L .51152 .48563 L p F P
0 g
s
.102 0 0 r
.51152 .48563 m .51073 .48602 L .52178 .48419 L p F P
0 g
s
.14 0 0 r
.53531 .48075 m .53577 .48046 L .5247 .48254 L p F P
0 g
s
.14 0 0 r
.5247 .48254 m .5235 .4833 L .53531 .48075 L p F P
0 g
s
.604 .933 .958 r
.59709 .31782 m .59736 .31789 L .58731 .32278 L p F P
0 g
s
.604 .933 .958 r
.58731 .32278 m .58595 .32254 L .59709 .31782 L p F P
0 g
s
.077 0 0 r
.48319 .35347 m .48301 .35355 L .48149 .35376 L closepath p F P
0 g
s
.1 0 0 r
.48004 .35512 m .48301 .35355 L .48149 .35376 L p F P
0 g
s
.1 0 0 r
.47951 .35521 m .48004 .35512 L p .48149 .35376 L F P
0 g
s
.1 0 0 r
.46901 .35653 m .47951 .35521 L p .48149 .35376 L F P
0 g
s
0 .501 .85 r
.23356 .32836 m .23574 .32897 L .23022 .32657 L closepath p F P
0 g
s
.46 .339 .629 r
.72028 .34767 m .7171 .34988 L .71317 .34599 L p F P
0 g
s
.46 .339 .629 r
.71317 .34599 m .71927 .34172 L .72028 .34767 L p F P
0 g
s
.661 .722 .895 r
.66672 .30436 m .67801 .30075 L .68073 .30444 L p F P
0 g
s
.671 .75 .91 r
.67801 .30075 m .66672 .30436 L .664 .30135 L p F P
0 g
s
.677 .773 .923 r
.65276 .30544 m .664 .30135 L .66672 .30436 L p F P
0 g
s
.832 .41 .236 r
.1352 .41739 m .14054 .41996 L .13832 .41572 L p F P
0 g
s
.832 .41 .236 r
.13832 .41572 m .13296 .41315 L .1352 .41739 L p F P
0 g
s
.117 0 0 r
.57257 .46973 m .57476 .46792 L .56364 .47108 L p F P
0 g
s
.117 0 0 r
.56364 .47108 m .56133 .47298 L .57257 .46973 L p F P
0 g
s
.285 0 0 r
.43554 .3609 m .42896 .36141 L .427 .36238 L p F P
0 g
s
.54 0 0 r
.23576 .47119 m .2428 .47312 L .23681 .46992 L p F P
0 g
s
.54 0 0 r
.23278 .46959 m .23576 .47119 L p .23681 .46992 L F P
0 g
s
.54 0 0 r
.23681 .46992 m .23587 .46967 L .23278 .46959 L p F P
0 g
s
.427 0 0 r
.35724 .35965 m .35907 .36015 L .35633 .35986 L closepath p F P
0 g
s
.447 0 0 r
.35724 .35965 m .35907 .36015 L .36949 .36103 L p F P
0 g
s
.847 .448 .288 r
.1316 .41004 m .13296 .41315 L .12789 .41067 L closepath p F P
0 g
s
.685 .8 .936 r
.664 .30135 m .65276 .30544 L .65004 .30302 L p F P
0 g
s
.756 .749 .846 r
.11281 .30703 m .11281 .30703 L .11281 .30704 L closepath p F P
0 g
s
.754 .75 .849 r
.11281 .30703 m .11281 .30703 L .10927 .30348 L p F P
0 g
s
.754 .75 .849 r
.10927 .30348 m .10859 .30393 L .11281 .30703 L p F P
0 g
s
.766 .74 .83 r
.09849 .31127 m .10859 .30393 L .11281 .30703 L p F P
0 g
s
.711 .753 .885 r
.12336 .3017 m .11281 .30703 L .10927 .30348 L p F P
0 g
s
.724 .213 .011 r
.18153 .44772 m .17796 .44419 L .18391 .44651 L p F P
0 g
s
.724 .213 .011 r
.18391 .44651 m .18522 .44777 L .18153 .44772 L p F P
0 g
s
0 .46 .752 r
.2609 .33718 m .25624 .33583 L .26296 .33798 L p F P
0 g
s
0 .46 .752 r
.26296 .33798 m .26436 .33833 L .2609 .33718 L p F P
0 g
s
.035 0 0 r
.494 .35162 m .4952 .35106 L .48319 .35347 L p F P
0 g
s
.035 0 0 r
.48319 .35347 m .48301 .35355 L .494 .35162 L p F P
0 g
s
.174 0 0 r
.62304 .44732 m .62474 .44488 L .61359 .44984 L p F P
0 g
s
.174 0 0 r
.61359 .44984 m .61248 .45144 L .62304 .44732 L p F P
0 g
s
.401 0 0 r
.37186 .3612 m .37114 .3614 L .36949 .36103 L closepath p F P
0 g
s
.889 .594 .481 r
.09815 .37868 m .10291 .38151 L .10272 .37666 L p F P
0 g
s
.889 .594 .481 r
.10272 .37666 m .09797 .37383 L .09815 .37868 L p F P
0 g
s
.327 .066 .358 r
.69252 .39442 m .68471 .39887 L .68977 .39216 L p F P
0 g
s
.327 .066 .358 r
.68977 .39216 m .69307 .39027 L .69252 .39442 L p F P
0 g
s
.578 .011 0 r
.23587 .46967 m .23278 .46959 L .22995 .46794 L closepath p F P
0 g
s
.296 .014 .304 r
.6829 .39989 m .68266 .40114 L .68471 .39887 L closepath p F P
0 g
s
.638 .669 .863 r
.69403 .30468 m .69106 .30684 L p .68073 .30444 L F P
0 g
s
.623 .656 .861 r
.69106 .30684 m .69403 .30468 L .69482 .30603 L closepath p F P
0 g
s
.89 .619 .521 r
.09328 .37097 m .09797 .37383 L .09821 .36886 L p F P
0 g
s
.89 .619 .521 r
.09821 .36886 m .09353 .36599 L .09328 .37097 L p F P
0 g
s
.667 .915 .977 r
.62218 .30895 m .62254 .30912 L .61287 .31455 L p F P
0 g
s
.667 .915 .977 r
.61287 .31455 m .61101 .31379 L .62218 .30895 L p F P
0 g
s
.885 .566 .44 r
.10348 .38624 m .10291 .38151 L .10772 .38431 L p F P
0 g
s
.885 .566 .44 r
.10753 .38858 m .10348 .38624 L p .10772 .38431 L F P
0 g
s
.885 .566 .44 r
.10772 .38431 m .1082 .38812 L .10753 .38858 L p F P
0 g
s
.417 0 0 r
.36743 .36242 m .35907 .36015 L .36949 .36103 L p F P
0 g
s
.417 0 0 r
.368 .36247 m .36743 .36242 L p .36949 .36103 L F P
0 g
s
.417 0 0 r
.36949 .36103 m .37114 .3614 L .368 .36247 L p F P
0 g
s
.309 .651 .97 r
.18786 .31316 m .18562 .31295 L .18212 .31026 L p F P
0 g
s
.638 .669 .863 r
.68073 .30444 m .69208 .30148 L .69403 .30468 L p F P
0 g
s
.651 .698 .88 r
.69208 .30148 m .68073 .30444 L .67801 .30075 L p F P
0 g
s
.107 0 0 r
.47836 .49186 m .47075 .49279 L .46875 .49347 L p F P
0 g
s
.845 .724 .73 r
.08962 .32953 m .09076 .3278 L .08726 .32352 L p F P
0 g
s
.634 .934 .966 r
.60826 .31295 m .61101 .31379 L .59986 .31849 L p F P
0 g
s
.634 .934 .966 r
.59927 .31687 m .60826 .31295 L p .59986 .31849 L F P
0 g
s
.634 .934 .966 r
.59986 .31849 m .59736 .31789 L .59927 .31687 L p F P
0 g
s
.257 .66 .965 r
.21295 .3202 m .2093 .31969 L .21509 .32218 L p F P
0 g
s
.257 .66 .965 r
.21509 .32218 m .21644 .32233 L .21295 .3202 L p F P
0 g
s
.29 0 0 r
.44222 .36039 m .441 .36101 L .43554 .3609 L closepath p F P
0 g
s
.285 0 0 r
.43907 .36218 m .441 .36101 L .43554 .3609 L p F P
0 g
s
.285 0 0 r
.43257 .36265 m .43907 .36218 L p .43554 .3609 L F P
0 g
s
.285 0 0 r
.427 .36238 m .43257 .36265 L p .43554 .3609 L F P
0 g
s
.109 0 0 r
.49211 .35273 m .494 .35162 L .48301 .35355 L p F P
0 g
s
.109 0 0 r
.48301 .35355 m .48004 .35512 L .49211 .35273 L p F P
0 g
s
.888 .643 .561 r
.0889 .3631 m .09353 .36599 L .09424 .36087 L p F P
0 g
s
.888 .643 .561 r
.09424 .36087 m .08963 .35797 L .0889 .3631 L p F P
0 g
s
.399 0 0 r
.30426 .48882 m .2981 .48695 L .29466 .4871 L p F P
0 g
s
.121 0 0 r
.58872 .46164 m .58864 .46173 L .59197 .46055 L closepath p F P
0 g
s
.116 0 0 r
.54992 .47599 m .54972 .47613 L .54521 .47713 L closepath p F P
0 g
s
.112 0 0 r
.54694 .47798 m .54972 .47613 L .54521 .47713 L p F P
0 g
s
.112 0 0 r
.54533 .47837 m .54694 .47798 L p .54521 .47713 L F P
0 g
s
.112 0 0 r
.53577 .48046 m .54533 .47837 L p .54521 .47713 L F P
0 g
s
.509 .713 .964 r
.15699 .30538 m .15466 .30559 L .15114 .30249 L p F P
0 g
s
.288 0 0 r
.35176 .49556 m .343 .494 L .33966 .49429 L p F P
0 g
s
.29 0 0 r
.33869 .49436 m .33966 .49429 L .33148 .49259 L p F P
0 g
s
.29 0 0 r
.33191 .49357 m .33869 .49436 L p .33148 .49259 L F P
0 g
s
.29 0 0 r
.32577 .49229 m .33191 .49357 L p .33148 .49259 L F P
0 g
s
.29 0 0 r
.33148 .49259 m .32788 .49219 L .32577 .49229 L p F P
0 g
s
.875 .526 .385 r
.10939 .3936 m .11438 .39633 L .11332 .39175 L p F P
0 g
s
.875 .526 .385 r
.11332 .39175 m .10832 .38903 L .10939 .3936 L p F P
0 g
s
.394 0 0 r
.29397 .48712 m .29466 .4871 L .28772 .48474 L p F P
0 g
s
.394 0 0 r
.28746 .48586 m .29397 .48712 L p .28772 .48474 L F P
0 g
s
.394 0 0 r
.28087 .48365 m .28746 .48586 L p .28772 .48474 L F P
0 g
s
.394 0 0 r
.28772 .48474 m .28187 .48365 L .28087 .48365 L p F P
0 g
s
.283 0 .206 r
.66062 .42045 m .65746 .42271 L .66033 .42134 L closepath p F P
0 g
s
.244 0 .138 r
.65899 .4247 m .66033 .42134 L .65746 .42271 L p F P
0 g
s
.244 0 .138 r
.6489 .42947 m .65899 .4247 L p .65746 .42271 L F P
0 g
s
.118 0 0 r
.59197 .46055 m .58864 .46173 L .5863 .46407 L p F P
0 g
s
.484 0 0 r
.27179 .48152 m .26714 .4796 L .26364 .47967 L p F P
0 g
s
.678 .863 .97 r
.64829 .30371 m .63883 .30746 L .63611 .30563 L p F P
0 g
s
.688 .866 .966 r
.62492 .3103 m .63611 .30563 L .63883 .30746 L p F P
0 g
s
.615 .06 0 r
.22317 .46592 m .21924 .46341 L .21563 .46336 L p F P
0 g
s
.776 .308 .13 r
.16837 .43786 m .16847 .43799 L .16818 .43788 L closepath p F P
0 g
s
.845 .724 .73 r
.08726 .32352 m .08528 .32649 L .08962 .32953 L p F P
0 g
s
.857 .716 .705 r
.08191 .3325 m .08628 .33553 L .08962 .32953 L p F P
0 g
s
.857 .716 .705 r
.08962 .32953 m .08528 .32649 L .08191 .3325 L p F P
0 g
s
.475 0 0 r
.26332 .47968 m .26364 .47967 L .25735 .47681 L p F P
0 g
s
.475 0 0 r
.25662 .47802 m .26332 .47968 L p .25735 .47681 L F P
0 g
s
.475 0 0 r
.24995 .47506 m .25662 .47802 L p .25735 .47681 L F P
0 g
s
.475 0 0 r
.25735 .47681 m .25001 .47506 L .24995 .47506 L p F P
0 g
s
.818 .378 .194 r
.14307 .42412 m .14054 .41996 L .14593 .4225 L p F P
0 g
s
.818 .378 .194 r
.14671 .42585 m .14307 .42412 L p .14593 .4225 L F P
0 g
s
.818 .378 .194 r
.14593 .4225 m .14794 .42579 L .14671 .42585 L p F P
0 g
s
.741 .239 .033 r
.16622 .43948 m .17206 .44185 L .16847 .43799 L p F P
0 g
s
.741 .239 .033 r
.16464 .43776 m .16622 .43948 L p .16847 .43799 L F P
0 g
s
.741 .239 .033 r
.16847 .43799 m .16818 .43788 L .16464 .43776 L p F P
0 g
s
.884 .665 .6 r
.08507 .35503 m .08963 .35797 L .09087 .35267 L p F P
0 g
s
.884 .665 .6 r
.09087 .35267 m .08633 .34973 L .08507 .35503 L p F P
0 g
s
.237 0 0 r
.45447 .35903 m .44222 .36039 L .441 .36101 L p F P
0 g
s
.332 0 0 r
.32788 .49219 m .32577 .49229 L .32212 .49143 L closepath p F P
0 g
s
.263 0 .198 r
.66902 .41401 m .66062 .42045 L .66033 .42134 L p F P
0 g
s
.45 .883 .856 r
.57203 .32695 m .56092 .33128 L .55809 .33165 L p F P
0 g
s
.764 .275 .07 r
.16818 .43788 m .16464 .43776 L .16277 .43558 L closepath p F P
0 g
s
.346 0 0 r
.27031 .34045 m .26436 .33833 L .2609 .33718 L p F P
0 g
s
.867 .496 .341 r
.11579 .4008 m .12084 .4035 L .11943 .39902 L p F P
0 g
s
.867 .496 .341 r
.11943 .39902 m .11438 .39633 L .11579 .4008 L p F P
0 g
s
.414 0 0 r
.31387 .35339 m .32229 .35496 L .31489 .35242 L p F P
0 g
s
.414 0 0 r
.30899 .35143 m .31387 .35339 L p .31489 .35242 L F P
0 g
s
.414 0 0 r
.31489 .35242 m .31052 .35147 L .30899 .35143 L p F P
0 g
s
.009 .517 .863 r
.2239 .32408 m .21644 .32233 L .21295 .3202 L p F P
0 g
s
.438 0 0 r
.35705 .36151 m .36743 .36242 L .35907 .36015 L p F P
0 g
s
.438 0 0 r
.35391 .36048 m .35705 .36151 L p .35907 .36015 L F P
0 g
s
.438 0 0 r
.35907 .36015 m .35633 .35986 L .35391 .36048 L p F P
0 g
s
.099 0 0 r
.52017 .48501 m .52178 .48419 L .51073 .48602 L p F P
0 g
s
.099 0 0 r
.51073 .48602 m .50813 .48733 L .52017 .48501 L p F P
0 g
s
.294 .011 .302 r
.69179 .39837 m .69252 .39442 L .68471 .39887 L p F P
0 g
s
.294 .011 .302 r
.68214 .40383 m .69179 .39837 L p .68471 .39887 L F P
0 g
s
.294 .011 .302 r
.68471 .39887 m .68266 .40114 L .68214 .40383 L p F P
0 g
s
.361 .152 .455 r
.70668 .37777 m .70289 .38018 L .703 .37555 L p F P
0 g
s
.361 .152 .455 r
.703 .37555 m .7085 .37205 L .70668 .37777 L p F P
0 g
s
.327 0 0 r
.28424 .34515 m .29172 .34704 L .28437 .34453 L p F P
0 g
s
.327 0 0 r
.27806 .34267 m .28424 .34515 L p .28437 .34453 L F P
0 g
s
.327 0 0 r
.28437 .34453 m .27864 .3428 L .27806 .34267 L p F P
0 g
s
.116 0 0 r
.48343 .49121 m .48276 .49146 L .47836 .49186 L closepath p F P
0 g
s
.107 0 0 r
.47973 .49254 m .48276 .49146 L .47836 .49186 L p F P
0 g
s
.107 0 0 r
.46875 .49347 m .47973 .49254 L p .47836 .49186 L F P
0 g
s
0 .481 .832 r
.24357 .33102 m .24375 .3311 L .23574 .32897 L p F P
0 g
s
0 .481 .832 r
.23757 .32883 m .24357 .33102 L p .23574 .32897 L F P
0 g
s
0 .481 .832 r
.23009 .3265 m .23757 .32883 L p .23574 .32897 L F P
0 g
s
0 .481 .832 r
.23574 .32897 m .23022 .32657 L .23009 .3265 L p F P
0 g
s
.432 0 0 r
.37114 .3614 m .37831 .36317 L .368 .36247 L closepath p F P
0 g
s
0 0 0 r
.53282 .34037 m .53303 .34029 L .52197 .34365 L p F P
0 g
s
0 0 0 r
.52197 .34365 m .52163 .34378 L .53282 .34037 L p F P
0 g
s
.663 .125 0 r
.20219 .45619 m .20494 .45828 L .19858 .45615 L closepath p F P
0 g
s
.311 .025 .307 r
.68266 .40114 m .67783 .40615 L .68214 .40383 L closepath p F P
0 g
s
.444 0 0 r
.35633 .35986 m .35391 .36048 L .34914 .3591 L closepath p F P
0 g
s
.712 .196 0 r
.18795 .45025 m .18522 .44777 L .18153 .44772 L p F P
0 g
s
.878 .685 .637 r
.08185 .34676 m .08633 .34973 L .08818 .34424 L p F P
0 g
s
.878 .685 .637 r
.08818 .34424 m .08372 .34125 L .08185 .34676 L p F P
0 g
s
.442 0 0 r
.32619 .35488 m .33076 .3565 L .32313 .3551 L closepath p F P
0 g
s
.608 .604 .822 r
.69482 .30603 m .70625 .30408 L .70905 .30981 L p F P
0 g
s
.607 .648 .865 r
.69403 .30468 m .69482 .30603 L .70625 .30408 L p F P
0 g
s
.309 .651 .97 r
.18212 .31026 m .1829 .31035 L .18786 .31316 L p F P
0 g
s
.33 .675 .977 r
.19228 .31135 m .1829 .31035 L .18786 .31316 L p F P
0 g
s
.33 .675 .977 r
.18786 .31316 m .19579 .31382 L .19228 .31135 L p F P
0 g
s
.298 0 .259 r
.67168 .41175 m .66902 .41401 L .67141 .4128 L closepath p F P
0 g
s
.263 0 .198 r
.67026 .41634 m .67141 .4128 L .66902 .41401 L p F P
0 g
s
.263 0 .198 r
.66033 .42134 m .67026 .41634 L p .66902 .41401 L F P
0 g
s
.178 0 0 r
.59979 .45773 m .59197 .46055 L .5996 .45797 L closepath p F P
0 g
s
.118 0 0 r
.5972 .46039 m .5996 .45797 L .59197 .46055 L p F P
0 g
s
.118 0 0 r
.5863 .46407 m .5972 .46039 L p .59197 .46055 L F P
0 g
s
.174 0 0 r
.46901 .35653 m .47951 .35521 L .46776 .35725 L closepath p F P
0 g
s
.509 .713 .964 r
.15114 .30249 m .15247 .3024 L .15699 .30538 L p F P
0 g
s
.522 .728 .968 r
.16137 .30167 m .15247 .3024 L .15699 .30538 L p F P
0 g
s
.522 .728 .968 r
.15699 .30538 m .1649 .3046 L .16137 .30167 L p F P
0 g
s
.194 0 .063 r
.65823 .42627 m .65899 .4247 L .6489 .42947 L p F P
0 g
s
.194 0 .063 r
.65019 .43132 m .65823 .42627 L p .6489 .42947 L F P
0 g
s
.194 0 .063 r
.6489 .42947 m .64737 .43265 L .65019 .43132 L p F P
0 g
s
.271 0 0 r
.3569 .4955 m .36243 .49632 L .35446 .49579 L closepath p F P
0 g
s
.083 0 0 r
.56084 .47331 m .56133 .47298 L .54992 .47599 L p F P
0 g
s
.083 0 0 r
.54992 .47599 m .54972 .47613 L .56084 .47331 L p F P
0 g
s
.858 .465 .296 r
.12258 .40789 m .12767 .41056 L .12594 .40617 L p F P
0 g
s
.858 .465 .296 r
.12594 .40617 m .12084 .4035 L .12258 .40789 L p F P
0 g
s
.28 0 .252 r
.67783 .40615 m .67168 .41175 L .67141 .4128 L p F P
0 g
s
.172 0 0 r
.64707 .43316 m .64737 .43265 L .63712 .43719 L p F P
0 g
s
.172 0 0 r
.63712 .43719 m .63591 .43929 L .64707 .43316 L p F P
0 g
s
.28 0 .252 r
.6812 .40756 m .68214 .40383 L .67783 .40615 L p F P
0 g
s
.28 0 .252 r
.67141 .4128 m .6812 .40756 L p .67783 .40615 L F P
0 g
s
.634 .084 0 r
.20995 .46175 m .20494 .45828 L .21141 .46041 L p F P
0 g
s
.634 .084 0 r
.21467 .46333 m .20995 .46175 L p .21141 .46041 L F P
0 g
s
.634 .084 0 r
.21141 .46041 m .21563 .46336 L .21467 .46333 L p F P
0 g
s
.389 0 0 r
.31191 .4899 m .31297 .49019 L .32212 .49143 L p F P
0 g
s
.33 0 0 r
.32238 .49245 m .31297 .49019 L .32212 .49143 L p F P
0 g
s
.33 0 0 r
.32239 .49245 m .32238 .49245 L p .32212 .49143 L F P
0 g
s
.33 0 0 r
.32212 .49143 m .32577 .49229 L .32239 .49245 L p F P
0 g
s
.39 0 0 r
.29522 .34751 m .29903 .34897 L .29185 .34707 L closepath p F P
0 g
s
.437 0 0 r
.28187 .48365 m .28087 .48365 L .27959 .48318 L closepath p F P
0 g
s
.681 .903 .975 r
.63339 .30407 m .63611 .30563 L .62492 .3103 L p F P
0 g
s
.681 .903 .975 r
.62443 .30797 m .63339 .30407 L p .62492 .3103 L F P
0 g
s
.681 .903 .975 r
.62492 .3103 m .62254 .30912 L .62443 .30797 L p F P
0 g
s
.405 .242 .545 r
.72025 .35919 m .7122 .36468 L .71182 .35949 L p F P
0 g
s
.405 .242 .545 r
.71182 .35949 m .7194 .3543 L .72025 .35919 L p F P
0 g
s
.763 .743 .834 r
.10859 .30393 m .09849 .31127 L .09495 .30754 L p F P
0 g
s
.798 .745 .804 r
.09682 .31284 m .09849 .31127 L .09495 .30754 L p F P
0 g
s
.812 .741 .785 r
.08572 .31695 m .09008 .32 L .09682 .31284 L p F P
0 g
s
.812 .741 .785 r
.09682 .31284 m .09257 .30975 L .08572 .31695 L p F P
0 g
s
.798 .745 .804 r
.09495 .30754 m .09257 .30975 L .09682 .31284 L p F P
0 g
s
.679 .144 0 r
.19238 .45388 m .19851 .45613 L .19413 .45248 L p F P
0 g
s
.679 .144 0 r
.19413 .45248 m .18795 .45025 L .19238 .45388 L p F P
0 g
s
.406 .695 .979 r
.17787 .30756 m .16841 .3075 L .1649 .3046 L p F P
0 g
s
.423 .705 .981 r
.18001 .30864 m .18212 .31026 L p .16841 .3075 L F P
0 g
s
.423 .705 .981 r
.16841 .3075 m .17787 .30756 L .18001 .30864 L p F P
0 g
s
.524 .467 .735 r
.71481 .32462 m .71957 .32553 L .71595 .32825 L closepath p F P
0 g
s
.518 .48 .754 r
.71333 .32032 m .71481 .32462 L .71957 .32553 L p F P
0 g
s
.577 .009 0 r
.22879 .46923 m .22317 .46592 L .22995 .46794 L p F P
0 g
s
.577 .009 0 r
.22966 .46949 m .22879 .46923 L p .22995 .46794 L F P
0 g
s
.577 .009 0 r
.22995 .46794 m .23278 .46959 L .22966 .46949 L p F P
0 g
s
.084 0 0 r
.49376 .49017 m .49588 .48939 L .48343 .49121 L p F P
0 g
s
.084 0 0 r
.48343 .49121 m .48276 .49146 L .49376 .49017 L p F P
0 g
s
0 0 0 r
.53013 .34149 m .53282 .34037 L .52163 .34378 L p F P
0 g
s
0 0 0 r
.52163 .34378 m .51904 .34483 L .53013 .34149 L p F P
0 g
s
.486 .42 .707 r
.72657 .32783 m .71957 .32553 L .71595 .32825 L p F P
0 g
s
.486 .42 .707 r
.72679 .32865 m .72657 .32783 L p .71595 .32825 L F P
0 g
s
.486 .42 .707 r
.71796 .33527 m .72679 .32865 L p .71595 .32825 L F P
0 g
s
.486 .42 .707 r
.71595 .32825 m .71786 .33523 L .71796 .33527 L p F P
0 g
s
.807 .362 .185 r
.14794 .42579 m .1485 .42665 L .1541 .42912 L p F P
0 g
s
.784 .311 .112 r
.15157 .43065 m .15714 .43313 L .1541 .42912 L p F P
0 g
s
.784 .311 .112 r
.1541 .42912 m .1485 .42665 L .15157 .43065 L p F P
0 g
s
.212 0 .12 r
.66937 .41859 m .67026 .41634 L .66033 .42134 L p F P
0 g
s
.212 0 .12 r
.6653 .42153 m .66937 .41859 L p .66033 .42134 L F P
0 g
s
.212 0 .12 r
.66033 .42134 m .65899 .4247 L .6653 .42153 L p F P
0 g
s
.308 .051 .352 r
.7024 .38581 m .70256 .38457 L .69307 .39027 L p F P
0 g
s
.308 .051 .352 r
.69922 .39041 m .7024 .38581 L p .69307 .39027 L F P
0 g
s
.308 .051 .352 r
.69307 .39027 m .69252 .39442 L .69922 .39041 L p F P
0 g
s
.379 0 0 r
.31052 .35147 m .30899 .35143 L .30686 .35074 L closepath p F P
0 g
s
.08 0 0 r
.55838 .47496 m .56084 .47331 L .54972 .47613 L p F P
0 g
s
.08 0 0 r
.54972 .47613 m .54694 .47798 L .55838 .47496 L p F P
0 g
s
.589 .935 .943 r
.59709 .31782 m .58595 .32254 L .58317 .32234 L p F P
0 g
s
.146 0 0 r
.62499 .44452 m .62474 .44488 L .62838 .44312 L closepath p F P
0 g
s
.072 0 0 r
.53287 .48203 m .53531 .48075 L .5235 .4833 L p F P
0 g
s
.072 0 0 r
.5235 .4833 m .52178 .48419 L .53287 .48203 L p F P
0 g
s
.551 .519 .773 r
.71189 .31654 m .71793 .3168 L .71333 .32032 L closepath p F P
0 g
s
.518 .48 .754 r
.72353 .31747 m .71793 .3168 L .71333 .32032 L p F P
0 g
s
.518 .48 .754 r
.72482 .32153 m .72353 .31747 L p .71333 .32032 L F P
0 g
s
.518 .48 .754 r
.71957 .32553 m .72482 .32153 L p .71333 .32032 L F P
0 g
s
0 .371 .691 r
.24722 .33262 m .24989 .33354 L .25624 .33583 L p F P
0 g
s
0 .416 .716 r
.25753 .33605 m .25732 .33598 L p .25624 .33583 L F P
0 g
s
.223 0 0 r
.25732 .33598 m .25742 .33601 L .25742 .33601 L p F P
0 g
s
0 .416 .716 r
.25073 .33384 m .25624 .33583 L p .25732 .33598 L F P
0 g
s
.223 0 0 r
.25742 .33601 m .25393 .33491 L p .25732 .33598 L F P
0 g
s
0 .416 .716 r
.25732 .33598 m .24989 .33354 L .25073 .33384 L p F P
0 g
s
0 .416 .716 r
.25624 .33583 m .2609 .33718 L .25753 .33605 L p F P
0 g
s
.428 0 0 r
.35227 .36097 m .35391 .36048 L .34914 .3591 L p F P
0 g
s
.428 0 0 r
.34728 .3604 m .35227 .36097 L p .34914 .3591 L F P
0 g
s
.428 0 0 r
.34003 .35787 m .34728 .3604 L p .34914 .3591 L F P
0 g
s
.428 0 0 r
.34914 .3591 m .34011 .35786 L .34003 .35787 L p F P
0 g
s
.236 0 0 r
.45511 .35897 m .45501 .35902 L .45447 .35903 L closepath p F P
0 g
s
.237 0 0 r
.45205 .36081 m .45501 .35902 L .45447 .35903 L p F P
0 g
s
.237 0 0 r
.45115 .36091 m .45205 .36081 L p .45447 .35903 L F P
0 g
s
.237 0 0 r
.441 .36101 m .45115 .36091 L p .45447 .35903 L F P
0 g
s
.432 0 0 r
.2774 .48361 m .27179 .48152 L .27959 .48318 L p F P
0 g
s
.432 0 0 r
.27959 .48318 m .28087 .48365 L .2774 .48361 L p F P
0 g
s
.626 .664 .867 r
.69208 .30148 m .70082 .29953 L .69403 .30468 L closepath p F P
0 g
s
.607 .648 .865 r
.70348 .29897 m .70082 .29953 L .69403 .30468 L p F P
0 g
s
.607 .648 .865 r
.70625 .30408 m .70348 .29897 L p .69403 .30468 L F P
0 g
s
.126 0 0 r
.49675 .48897 m .50449 .48795 L .49588 .48939 L closepath p F P
0 g
s
.388 .2 .501 r
.71232 .36957 m .7085 .37205 L .70904 .36673 L p F P
0 g
s
.388 .2 .501 r
.70904 .36673 m .7122 .36468 L .71232 .36957 L p F P
0 g
s
.205 0 0 r
.46595 .35831 m .46776 .35725 L .45511 .35897 L p F P
0 g
s
.205 0 0 r
.45511 .35897 m .45501 .35902 L .46595 .35831 L p F P
0 g
s
.388 .848 .818 r
.54732 .33568 m .54699 .33574 L .5561 .33238 L closepath p F P
0 g
s
.422 0 0 r
.38507 .36261 m .39004 .36363 L .38318 .3634 L closepath p F P
0 g
s
.382 0 0 r
.31191 .4899 m .31297 .49019 L .31126 .48995 L closepath p F P
0 g
s
.088 0 0 r
.58592 .46438 m .5863 .46407 L .57524 .46752 L p F P
0 g
s
.088 0 0 r
.57524 .46752 m .57476 .46792 L .58592 .46438 L p F P
0 g
s
.83 .397 .21 r
.12993 .41479 m .1352 .41739 L .13296 .41315 L p F P
0 g
s
.83 .397 .21 r
.12773 .41067 m .12993 .41479 L p .13296 .41315 L F P
0 g
s
.83 .397 .21 r
.13296 .41315 m .12789 .41067 L .12773 .41067 L p F P
0 g
s
.727 .217 .009 r
.17593 .44564 m .17206 .44185 L .17796 .44419 L p F P
0 g
s
.727 .217 .009 r
.18107 .4477 m .17593 .44564 L p .17796 .44419 L F P
0 g
s
.727 .217 .009 r
.17796 .44419 m .18153 .44772 L .18107 .4477 L p F P
0 g
s
.016 0 0 r
.50503 .34924 m .50692 .34828 L .4952 .35106 L p F P
0 g
s
.016 0 0 r
.4952 .35106 m .494 .35162 L .50503 .34924 L p F P
0 g
s
.181 .608 .942 r
.19929 .31626 m .20379 .31708 L .2093 .31969 L p F P
0 g
s
.158 .588 .934 r
.20379 .31708 m .19929 .31626 L .19579 .31382 L p F P
0 g
s
.87 .703 .673 r
.07932 .33824 m .08372 .34125 L .08628 .33553 L p F P
0 g
s
.87 .703 .673 r
.08628 .33553 m .08191 .3325 L .07932 .33824 L p F P
0 g
s
.827 .729 .757 r
.08375 .31937 m .08572 .31695 L .09008 .32 L p F P
0 g
s
.827 .729 .757 r
.09008 .32 m .08726 .32352 L .08375 .31937 L p F P
0 g
s
0 .344 .68 r
.24989 .33354 m .24722 .33262 L .24375 .3311 L p F P
0 g
s
.257 0 0 r
.46476 .35914 m .46595 .35831 L .45501 .35902 L p F P
0 g
s
.257 0 0 r
.45501 .35902 m .45205 .36081 L .46476 .35914 L p F P
0 g
s
.656 .749 .918 r
.12336 .3017 m .13376 .29822 L .1373 .30148 L p F P
0 g
s
.65 .748 .921 r
.13376 .29822 m .12336 .3017 L .11982 .2983 L p F P
0 g
s
.711 .753 .885 r
.10927 .30348 m .11982 .2983 L .12336 .3017 L p F P
0 g
s
.547 .537 .795 r
.70956 .31096 m .71189 .31654 L .71793 .3168 L p F P
0 g
s
.252 0 0 r
.37083 .49663 m .37353 .49695 L .36976 .49679 L closepath p F P
0 g
s
.259 0 0 r
.38464 .4974 m .38478 .49738 L p .37083 .49663 L F P
0 g
s
.259 0 0 r
.37083 .49663 m .37353 .49695 L .38464 .4974 L p F P
0 g
s
.516 0 0 r
.25001 .47506 m .24995 .47506 L .24989 .47503 L closepath p F P
0 g
s
.495 .413 .692 r
.71786 .33523 m .71796 .33527 L .71789 .33533 L closepath p F P
0 g
s
.475 .378 .665 r
.72339 .33869 m .71927 .34172 L .71789 .33533 L p F P
0 g
s
.475 .378 .665 r
.71789 .33533 m .71796 .33527 L .72339 .33869 L p F P
0 g
s
.51 0 0 r
.24641 .47489 m .2428 .47312 L .24989 .47503 L p F P
0 g
s
.51 0 0 r
.24989 .47503 m .24995 .47506 L .24641 .47489 L p F P
0 g
s
.881 .559 .435 r
.1082 .38812 m .10832 .38903 L .10753 .38858 L closepath p F P
0 g
s
.488 0 0 r
.25662 .47802 m .24995 .47506 L .24641 .47489 L p F P
0 g
s
.473 .378 .667 r
.7282 .33509 m .72339 .33869 L .71796 .33527 L p F P
0 g
s
.473 .378 .667 r
.71796 .33527 m .72679 .32865 L .7282 .33509 L p F P
0 g
s
.143 0 0 r
.62838 .44312 m .62474 .44488 L .62304 .44732 L p F P
0 g
s
.387 0 0 r
.30556 .3514 m .29903 .34897 L .30686 .35074 L p F P
0 g
s
.387 0 0 r
.30686 .35074 m .30899 .35143 L .30556 .3514 L p F P
0 g
s
.224 .639 .956 r
.20944 .31803 m .20379 .31708 L .2093 .31969 L p F P
0 g
s
.224 .639 .956 r
.2093 .31969 m .21295 .3202 L .20944 .31803 L p F P
0 g
s
.23 0 .179 r
.68048 .4098 m .6812 .40756 L .67141 .4128 L p F P
0 g
s
.23 0 .179 r
.67691 .4128 m .68048 .4098 L p .67141 .4128 L F P
0 g
s
.23 0 .179 r
.67141 .4128 m .67026 .41634 L .67691 .4128 L p F P
0 g
s
.591 .74 .947 r
.1373 .30148 m .14761 .29939 L .15114 .30249 L p F P
0 g
s
.583 .738 .949 r
.14761 .29939 m .1373 .30148 L .13376 .29822 L p F P
0 g
s
.307 .791 .733 r
.5561 .33238 m .54699 .33574 L .54412 .33653 L p F P
0 g
s
.268 .766 .717 r
.53303 .34029 m .54412 .33653 L .54699 .33574 L p F P
0 g
s
.245 0 0 r
.27864 .3428 m .27806 .34267 L .2774 .34247 L closepath p F P
0 g
s
.893 .597 .479 r
.09346 .37582 m .09815 .37868 L .09797 .37383 L p F P
0 g
s
.893 .597 .479 r
.09797 .37383 m .09328 .37097 L .09346 .37582 L p F P
0 g
s
.117 0 0 r
.62215 .4484 m .62304 .44732 L .61248 .45144 L p F P
0 g
s
.117 0 0 r
.61248 .45144 m .61096 .45328 L .62215 .4484 L p F P
0 g
s
.751 .752 .852 r
.10859 .30393 m .10927 .30348 L .10572 .29995 L p F P
0 g
s
.751 .752 .852 r
.10572 .29995 m .10442 .3008 L .10859 .30393 L p F P
0 g
s
.763 .743 .834 r
.09495 .30754 m .10442 .3008 L .10859 .30393 L p F P
0 g
s
.846 .727 .733 r
.08528 .32649 m .08726 .32352 L .08375 .31937 L p F P
0 g
s
.893 .622 .52 r
.08865 .36808 m .09328 .37097 L .09353 .36599 L p F P
0 g
s
.893 .622 .52 r
.09353 .36599 m .0889 .3631 L .08865 .36808 L p F P
0 g
s
.298 0 0 r
.31344 .49113 m .32238 .49245 L .31297 .49019 L p F P
0 g
s
.298 0 0 r
.3085 .48996 m .31344 .49113 L p .31297 .49019 L F P
0 g
s
.298 0 0 r
.31297 .49019 m .31126 .48995 L .3085 .48996 L p F P
0 g
s
.89 .57 .436 r
.09873 .38341 m .10348 .38624 L .10291 .38151 L p F P
0 g
s
.89 .57 .436 r
.10291 .38151 m .09815 .37868 L .09873 .38341 L p F P
0 g
s
.404 0 0 r
.39902 .36318 m .40276 .36377 L .39781 .36378 L closepath p F P
0 g
s
.707 .753 .888 r
.11982 .2983 m .10927 .30348 L .10572 .29995 L p F P
0 g
s
0 0 0 r
.51838 .34518 m .51904 .34483 L .50799 .34775 L p F P
0 g
s
0 0 0 r
.50799 .34775 m .50692 .34828 L .51838 .34518 L p F P
0 g
s
.406 0 0 r
.28746 .48586 m .28087 .48365 L .2774 .48361 L p F P
0 g
s
.298 0 0 r
.441 .36101 m .45115 .36091 L .43907 .36218 L closepath p F P
0 g
s
.101 0 0 r
.49376 .49017 m .48276 .49146 L .47973 .49254 L p F P
0 g
s
.681 .778 .924 r
.67529 .29743 m .664 .30135 L .66129 .29867 L p F P
0 g
s
.685 .8 .936 r
.65004 .30302 m .66129 .29867 L .664 .30135 L p F P
0 g
s
.671 .75 .91 r
.664 .30135 m .67529 .29743 L .67801 .30075 L p F P
0 g
s
.683 .846 .961 r
.65004 .30302 m .64829 .30371 L .64977 .30281 L closepath p F P
0 g
s
.678 .863 .97 r
.64733 .30095 m .64977 .30281 L .64829 .30371 L p F P
0 g
s
.678 .863 .97 r
.63611 .30563 m .64733 .30095 L p .64829 .30371 L F P
0 g
s
.668 .924 .973 r
.62218 .30895 m .61101 .31379 L .60826 .31295 L p F P
0 g
s
.534 .92 .915 r
.57247 .32696 m .57203 .32695 L .57748 .32469 L closepath p F P
0 g
s
.253 0 0 r
.2746 .34191 m .27031 .34045 L .2774 .34247 L p F P
0 g
s
.253 0 0 r
.2774 .34247 m .27806 .34267 L .2746 .34191 L p F P
0 g
s
.343 0 0 r
.31126 .48995 m .3085 .48996 L .30426 .48882 L closepath p F P
0 g
s
.878 .526 .378 r
.10446 .39084 m .10939 .3936 L .10832 .38903 L p F P
0 g
s
.878 .526 .378 r
.10417 .38957 m .10446 .39084 L p .10832 .38903 L F P
0 g
s
.878 .526 .378 r
.10832 .38903 m .10753 .38858 L .10417 .38957 L p F P
0 g
s
.891 .646 .561 r
.08434 .36017 m .0889 .3631 L .08963 .35797 L p F P
0 g
s
.891 .646 .561 r
.08963 .35797 m .08507 .35503 L .08434 .36017 L p F P
0 g
s
.651 .698 .88 r
.67801 .30075 m .68934 .29742 L .69208 .30148 L p F P
0 g
s
.662 .726 .897 r
.68934 .29742 m .67801 .30075 L .67529 .29743 L p F P
0 g
s
.764 .274 .067 r
.16048 .43707 m .15714 .43313 L .16277 .43558 L p F P
0 g
s
.764 .274 .067 r
.16176 .43762 m .16048 .43707 L p .16277 .43558 L F P
0 g
s
.764 .274 .067 r
.16277 .43558 m .16464 .43776 L .16176 .43762 L p F P
0 g
s
.143 0 0 r
.41102 .49755 m .39912 .49763 L .39875 .49768 L p F P
0 g
s
.178 0 0 r
.39912 .49763 m .39875 .49768 L .39766 .49761 L closepath p F P
0 g
s
.243 0 0 r
.38478 .49738 m .38517 .49741 L .39766 .49761 L p F P
0 g
s
.167 0 0 r
.39553 .49807 m .38517 .49741 L .39766 .49761 L p F P
0 g
s
.167 0 0 r
.39766 .49761 m .39875 .49768 L .39553 .49807 L p F P
0 g
s
.232 0 0 r
.38478 .49738 m .38517 .49741 L .38464 .4974 L closepath p F P
0 g
s
.423 0 0 r
.34011 .35786 m .34003 .35787 L .33988 .35782 L closepath p F P
0 g
s
.819 .374 .18 r
.13775 .42154 m .14307 .42412 L .14054 .41996 L p F P
0 g
s
.819 .374 .18 r
.14054 .41996 m .1352 .41739 L .13775 .42154 L p F P
0 g
s
.084 0 0 r
.58365 .46627 m .58592 .46438 L .57476 .46792 L p F P
0 g
s
.084 0 0 r
.57476 .46792 m .57257 .46973 L .58365 .46627 L p F P
0 g
s
.377 0 0 r
.413 .36311 m .41676 .3635 L .41196 .36368 L closepath p F P
0 g
s
.436 0 0 r
.33665 .35854 m .33076 .3565 L .33988 .35782 L p F P
0 g
s
.436 0 0 r
.33988 .35782 m .34003 .35787 L .33665 .35854 L p F P
0 g
s
.342 0 0 r
.427 .36238 m .43257 .36265 L .42571 .36314 L closepath p F P
0 g
s
.158 0 0 r
.41326 .49752 m .41274 .49761 L .41102 .49755 L closepath p F P
0 g
s
.143 0 0 r
.40955 .49808 m .41274 .49761 L .41102 .49755 L p F P
0 g
s
.143 0 0 r
.39875 .49768 m .40955 .49808 L p .41102 .49755 L F P
0 g
s
.123 0 0 r
.42544 .49716 m .41326 .49752 L .41274 .49761 L p F P
0 g
s
.525 0 0 r
.34728 .3604 m .34003 .35787 L .33665 .35854 L p F P
0 g
s
.195 0 .007 r
.63591 .43929 m .62838 .44312 L .63539 .44019 L closepath p F P
0 g
s
.143 0 0 r
.63345 .44299 m .63539 .44019 L .62838 .44312 L p F P
0 g
s
.143 0 0 r
.62304 .44732 m .63345 .44299 L p .62838 .44312 L F P
0 g
s
.431 .291 .589 r
.72096 .35322 m .7194 .3543 L .7171 .34988 L p F P
0 g
s
.431 .291 .589 r
.7171 .34988 m .72028 .34767 L .72096 .35322 L p F P
0 g
s
.149 0 0 r
.39421 .49822 m .39553 .49807 L .38517 .49741 L p F P
0 g
s
.149 0 0 r
.38694 .49805 m .39421 .49822 L p .38517 .49741 L F P
0 g
s
.149 0 0 r
.38153 .49769 m .38694 .49805 L p .38517 .49741 L F P
0 g
s
.149 0 0 r
.38517 .49741 m .38464 .4974 L .38153 .49769 L p F P
0 g
s
.187 0 0 r
.38464 .4974 m .38153 .49769 L .37353 .49695 L closepath p F P
0 g
s
.108 .59 .91 r
.23022 .32657 m .23009 .3265 L .22998 .32648 L closepath p F P
0 g
s
.689 .847 .959 r
.65895 .29662 m .66129 .29867 L .65004 .30302 L p F P
0 g
s
.689 .847 .959 r
.65004 .30302 m .64977 .30281 L .65895 .29662 L p F P
0 g
s
.547 .537 .795 r
.72061 .3095 m .71121 .30968 L .70956 .31096 L p F P
0 g
s
.547 .537 .795 r
.72215 .31353 m .72061 .3095 L p .70956 .31096 L F P
0 g
s
.547 .537 .795 r
.71793 .3168 m .72215 .31353 L p .70956 .31096 L F P
0 g
s
.576 .568 .807 r
.70905 .30981 m .71121 .30968 L .70956 .31096 L closepath p F P
0 g
s
.846 .727 .733 r
.08375 .31937 m .08101 .32341 L .08528 .32649 L p F P
0 g
s
.859 .719 .707 r
.07759 .32944 m .08191 .3325 L .08528 .32649 L p F P
0 g
s
.859 .719 .707 r
.08528 .32649 m .08101 .32341 L .07759 .32944 L p F P
0 g
s
.446 0 0 r
.28424 .34515 m .27806 .34267 L .2746 .34191 L p F P
0 g
s
.106 .589 .909 r
.2266 .32468 m .2239 .32408 L .22998 .32648 L p F P
0 g
s
.106 .589 .909 r
.22998 .32648 m .23009 .3265 L .2266 .32468 L p F P
0 g
s
.808 .361 .177 r
.14794 .42579 m .1485 .42665 L .14671 .42585 L closepath p F P
0 g
s
.885 .54 .391 r
.10753 .38858 m .10417 .38957 L .10348 .38624 L closepath p F P
0 g
s
.87 .496 .334 r
.11081 .39807 m .11579 .4008 L .11438 .39633 L p F P
0 g
s
.87 .496 .334 r
.11438 .39633 m .10939 .3936 L .11081 .39807 L p F P
0 g
s
.887 .668 .6 r
.08058 .35207 m .08507 .35503 L .08633 .34973 L p F P
0 g
s
.887 .668 .6 r
.08633 .34973 m .08185 .34676 L .08058 .35207 L p F P
0 g
s
.147 0 0 r
.61031 .45406 m .61096 .45328 L .59979 .45773 L p F P
0 g
s
.147 0 0 r
.59979 .45773 m .5996 .45797 L .61031 .45406 L p F P
0 g
s
0 .399 .74 r
.23757 .32883 m .23009 .3265 L .2266 .32468 L p F P
0 g
s
.106 0 0 r
.47961 .49258 m .47973 .49254 L .46875 .49347 L p F P
0 g
s
.106 0 0 r
.46875 .49347 m .46684 .4941 L .47961 .49258 L p F P
0 g
s
.15 0 0 r
.46684 .4941 m .46875 .49347 L p .45475 .4951 L F P
0 g
s
.497 .707 .964 r
.15247 .3024 m .15114 .30249 L .14761 .29939 L p F P
0 g
s
.316 .65 .969 r
.18212 .31026 m .1829 .31035 L .18001 .30864 L closepath p F P
0 g
s
.137 0 0 r
.42708 .49711 m .42673 .49717 L .42544 .49716 L closepath p F P
0 g
s
.123 0 0 r
.42357 .49771 m .42673 .49717 L .42544 .49716 L p F P
0 g
s
.123 0 0 r
.41274 .49761 m .42357 .49771 L p .42544 .49716 L F P
0 g
s
.052 0 0 r
.50449 .48795 m .49588 .48939 L .49376 .49017 L p F P
0 g
s
.109 0 0 r
.53577 .48046 m .54533 .47837 L .53531 .48075 L closepath p F P
0 g
s
.602 .037 0 r
.20359 .45958 m .20995 .46175 L .20494 .45828 L p F P
0 g
s
.602 .037 0 r
.19854 .45615 m .20359 .45958 L p .20494 .45828 L F P
0 g
s
.602 .037 0 r
.20494 .45828 m .19858 .45615 L .19854 .45615 L p F P
0 g
s
.103 0 0 r
.43761 .49697 m .44061 .49639 L .42708 .49711 L p F P
0 g
s
.103 0 0 r
.42708 .49711 m .42673 .49717 L .43761 .49697 L p F P
0 g
s
.145 0 0 r
.40955 .49808 m .39875 .49768 L .39553 .49807 L p F P
0 g
s
.3 0 0 r
.32577 .49229 m .33191 .49357 L .32239 .49245 L closepath p F P
0 g
s
.432 0 0 r
.27155 .4826 m .26401 .47983 L .27179 .48152 L p F P
0 g
s
.432 0 0 r
.27588 .48357 m .27155 .4826 L p .27179 .48152 L F P
0 g
s
.432 0 0 r
.27179 .48152 m .2774 .48361 L .27588 .48357 L p F P
0 g
s
.484 0 0 r
.26364 .47967 m .26401 .47983 L .27179 .48152 L p F P
0 g
s
.448 .331 .628 r
.72709 .34267 m .72028 .34767 L .71927 .34172 L p F P
0 g
s
.448 .331 .628 r
.71927 .34172 m .72339 .33869 L .72709 .34267 L p F P
0 g
s
.59 .577 .807 r
.71121 .30968 m .70905 .30981 L .70625 .30408 L p F P
0 g
s
.179 0 0 r
.47951 .35521 m .46776 .35725 L .46595 .35831 L p F P
0 g
s
.25 0 .238 r
.69152 .39941 m .69179 .39837 L .68214 .40383 L p F P
0 g
s
.25 0 .238 r
.68608 .4048 m .69152 .39941 L p .68214 .40383 L F P
0 g
s
.25 0 .238 r
.68214 .40383 m .6812 .40756 L .68608 .4048 L p F P
0 g
s
.471 .894 .861 r
.57748 .32469 m .57203 .32695 L .56922 .32723 L p F P
0 g
s
.45 .883 .856 r
.55809 .33165 m .56922 .32723 L .57203 .32695 L p F P
0 g
s
.615 .06 0 r
.21563 .46336 m .21644 .46388 L .22317 .46592 L p F P
0 g
s
.567 0 0 r
.22214 .46716 m .22879 .46923 L .22317 .46592 L p F P
0 g
s
.567 0 0 r
.22317 .46592 m .21644 .46388 L .22214 .46716 L p F P
0 g
s
.69 .848 .959 r
.65859 .2963 m .65895 .29662 L .64977 .30281 L p F P
0 g
s
.69 .848 .959 r
.64977 .30281 m .64733 .30095 L .65859 .2963 L p F P
0 g
s
.168 0 0 r
.37955 .49786 m .38153 .49769 L .37353 .49695 L p F P
0 g
s
.168 0 0 r
.37505 .49765 m .37955 .49786 L p .37353 .49695 L F P
0 g
s
.168 0 0 r
.36755 .49694 m .37505 .49765 L p .37353 .49695 L F P
0 g
s
.168 0 0 r
.37353 .49695 m .36976 .49679 L .36755 .49694 L p F P
0 g
s
.638 .671 .866 r
.70082 .29953 m .69208 .30148 L .68934 .29742 L p F P
0 g
s
.671 .131 0 r
.18631 .45159 m .19238 .45388 L .18795 .45025 L p F P
0 g
s
.671 .131 0 r
.18795 .45025 m .18182 .44798 L .18631 .45159 L p F P
0 g
s
.712 .196 0 r
.18153 .44772 m .18182 .44798 L .18795 .45025 L p F P
0 g
s
.127 0 0 r
.45475 .4951 m .45942 .49485 L .45385 .49538 L closepath p F P
0 g
s
.168 0 0 r
.45385 .49538 m .45475 .4951 L p .44074 .49636 L F P
0 g
s
.15 0 0 r
.45475 .4951 m .45942 .49485 L .46684 .4941 L p F P
0 g
s
.51 0 0 r
.31387 .35339 m .30899 .35143 L .30556 .3514 L p F P
0 g
s
.086 0 0 r
.6083 .4561 m .61031 .45406 L .5996 .45797 L p F P
0 g
s
.086 0 0 r
.59956 .45953 m .6083 .4561 L p .5996 .45797 L F P
0 g
s
.086 0 0 r
.5996 .45797 m .5972 .46039 L .59956 .45953 L p F P
0 g
s
.208 0 0 r
.36976 .49679 m .36755 .49694 L .36243 .49632 L closepath p F P
0 g
s
.552 0 0 r
.23278 .46959 m .23576 .47119 L .22966 .46949 L closepath p F P
0 g
s
.297 .641 .967 r
.18942 .30931 m .19228 .31135 L .1829 .31035 L p F P
0 g
s
.297 .641 .967 r
.18841 .30881 m .18942 .30931 L p .1829 .31035 L F P
0 g
s
.297 .641 .967 r
.17861 .30756 m .18841 .30881 L p .1829 .31035 L F P
0 g
s
.297 .641 .967 r
.1829 .31035 m .18001 .30864 L .17861 .30756 L p F P
0 g
s
.127 0 0 r
.42357 .49771 m .41274 .49761 L .40955 .49808 L p F P
0 g
s
.372 .189 .498 r
.71978 .36449 m .71232 .36957 L .7122 .36468 L p F P
0 g
s
.372 .189 .498 r
.7122 .36468 m .72025 .35919 L .71978 .36449 L p F P
0 g
s
.86 .464 .289 r
.11754 .40519 m .12258 .40789 L .12084 .4035 L p F P
0 g
s
.86 .464 .289 r
.12084 .4035 m .11579 .4008 L .11754 .40519 L p F P
0 g
s
.326 .097 .404 r
.70367 .38386 m .70256 .38457 L .70289 .38018 L p F P
0 g
s
.326 .097 .404 r
.70289 .38018 m .70668 .37777 L .70367 .38386 L p F P
0 g
s
0 .344 .68 r
.24375 .3311 m .24387 .33114 L .24989 .33354 L p F P
0 g
s
0 .348 .685 r
.25074 .33376 m .25732 .33598 L .24989 .33354 L p F P
0 g
s
0 .348 .685 r
.24989 .33354 m .24387 .33114 L .25074 .33376 L p F P
0 g
s
.881 .688 .638 r
.07743 .34375 m .08185 .34676 L .08372 .34125 L p F P
0 g
s
.881 .688 .638 r
.08372 .34125 m .07932 .33824 L .07743 .34375 L p F P
0 g
s
.497 .707 .964 r
.14761 .29939 m .14807 .29936 L .15247 .3024 L p F P
0 g
s
.51 .722 .969 r
.15783 .29872 m .14807 .29936 L .15247 .3024 L p F P
0 g
s
.51 .722 .969 r
.15247 .3024 m .16137 .30167 L .15783 .29872 L p F P
0 g
s
.168 0 0 r
.44074 .49636 m .4413 .49634 L .45385 .49538 L p F P
0 g
s
.149 0 0 r
.44074 .49636 m .4413 .49634 L .44061 .49639 L closepath p F P
0 g
s
.399 0 0 r
.29466 .4871 m .29567 .48741 L .30426 .48882 L p F P
0 g
s
.341 0 0 r
.30455 .4898 m .29567 .48741 L .30426 .48882 L p F P
0 g
s
.341 0 0 r
.30544 .48995 m .30455 .4898 L p .30426 .48882 L F P
0 g
s
.341 0 0 r
.30426 .48882 m .3085 .48996 L .30544 .48995 L p F P
0 g
s
.109 0 0 r
.43761 .49697 m .42673 .49717 L .42357 .49771 L p F P
0 g
s
.411 0 0 r
.30516 .3514 m .30556 .3514 L .29903 .34897 L p F P
0 g
s
.411 0 0 r
.29821 .34985 m .30516 .3514 L p .29903 .34897 L F P
0 g
s
.411 0 0 r
.29179 .34706 m .29821 .34985 L p .29903 .34897 L F P
0 g
s
.411 0 0 r
.29903 .34897 m .29185 .34707 L .29179 .34706 L p F P
0 g
s
.778 .296 .084 r
.14606 .42815 m .15157 .43065 L .1485 .42665 L p F P
0 g
s
.778 .296 .084 r
.14417 .42566 m .14606 .42815 L p .1485 .42665 L F P
0 g
s
.778 .296 .084 r
.1485 .42665 m .14671 .42585 L .14417 .42566 L p F P
0 g
s
.634 .935 .966 r
.59736 .31789 m .59709 .31782 L .59927 .31687 L closepath p F P
0 g
s
.503 .433 .71 r
.71957 .32553 m .72482 .32153 L .72657 .32783 L closepath p F P
0 g
s
.514 0 0 r
.24208 .4743 m .23576 .47119 L .2428 .47312 L p F P
0 g
s
.514 0 0 r
.24367 .47474 m .24208 .4743 L p .2428 .47312 L F P
0 g
s
.514 0 0 r
.2428 .47312 m .24641 .47489 L .24367 .47474 L p F P
0 g
s
.696 .873 .965 r
.64733 .30095 m .63611 .30563 L .63339 .30407 L p F P
0 g
s
.07 0 0 r
.4413 .49634 m .44061 .49639 L .43761 .49697 L p F P
0 g
s
.354 .146 .452 r
.71221 .37419 m .70668 .37777 L .7085 .37205 L p F P
0 g
s
.354 .146 .452 r
.7085 .37205 m .71232 .36957 L .71221 .37419 L p F P
0 g
s
.082 0 0 r
.45385 .49538 m .45165 .49586 L .4413 .49634 L closepath p F P
0 g
s
.07 0 0 r
.44948 .49631 m .45165 .49586 L .4413 .49634 L p F P
0 g
s
.07 0 0 r
.44423 .49669 m .44948 .49631 L p .4413 .49634 L F P
0 g
s
.07 0 0 r
.43761 .49697 m .44423 .49669 L p .4413 .49634 L F P
0 g
s
.457 0 0 r
.33578 .35875 m .33665 .35854 L .33076 .3565 L p F P
0 g
s
.457 0 0 r
.32908 .35772 m .33578 .35875 L p .33076 .3565 L F P
0 g
s
.457 0 0 r
.3228 .35513 m .32908 .35772 L p .33076 .3565 L F P
0 g
s
.457 0 0 r
.33076 .3565 m .32313 .3551 L .3228 .35513 L p F P
0 g
s
.087 0 0 r
.50388 .34997 m .50503 .34924 L .494 .35162 L p F P
0 g
s
.087 0 0 r
.494 .35162 m .49211 .35273 L .50388 .34997 L p F P
0 g
s
.188 0 0 r
.36449 .49713 m .36755 .49694 L .36243 .49632 L p F P
0 g
s
.188 0 0 r
.36373 .49708 m .36449 .49713 L p .36243 .49632 L F P
0 g
s
.188 0 0 r
.35359 .49583 m .36373 .49708 L p .36243 .49632 L F P
0 g
s
.188 0 0 r
.36243 .49632 m .35446 .49579 L .35359 .49583 L p F P
0 g
s
.039 0 0 r
.54533 .47837 m .53531 .48075 L .53287 .48203 L p F P
0 g
s
.051 0 0 r
.57199 .47013 m .57257 .46973 L .56133 .47298 L p F P
0 g
s
.051 0 0 r
.56133 .47298 m .56084 .47331 L .57199 .47013 L p F P
0 g
s
.72 .202 0 r
.17013 .44325 m .17593 .44564 L .17206 .44185 L p F P
0 g
s
.72 .202 0 r
.17206 .44185 m .16622 .43948 L .17013 .44325 L p F P
0 g
s
.762 .746 .838 r
.10442 .3008 m .09495 .30754 L .09138 .30386 L p F P
0 g
s
.797 .747 .807 r
.09257 .30975 m .09495 .30754 L .09138 .30386 L p F P
0 g
s
.797 .747 .807 r
.09138 .30386 m .08837 .30662 L .09257 .30975 L p F P
0 g
s
.812 .744 .788 r
.08142 .31386 m .08572 .31695 L .09257 .30975 L p F P
0 g
s
.812 .744 .788 r
.09257 .30975 m .08837 .30662 L .08142 .31386 L p F P
0 g
s
0 0 0 r
.5438 .33666 m .54412 .33653 L .53303 .34029 L p F P
0 g
s
0 0 0 r
.53303 .34029 m .53282 .34037 L .5438 .33666 L p F P
0 g
s
.565 .549 .796 r
.71121 .30968 m .71832 .30405 L .72061 .3095 L closepath p F P
0 g
s
.59 .577 .807 r
.71832 .30405 m .71121 .30968 L p .70625 .30408 L F P
0 g
s
.842 .422 .236 r
.12789 .41067 m .12773 .41067 L .12767 .41056 L closepath p F P
0 g
s
.593 .937 .943 r
.59927 .31687 m .59709 .31782 L .59432 .3175 L p F P
0 g
s
.589 .935 .943 r
.58317 .32234 m .59432 .3175 L .59709 .31782 L p F P
0 g
s
0 .493 .853 r
.21812 .32158 m .21295 .3202 L .20944 .31803 L p F P
0 g
s
.009 .517 .863 r
.21295 .3202 m .21812 .32158 L .2239 .32408 L p F P
0 g
s
.844 .422 .231 r
.1239 .41059 m .12258 .40789 L .12767 .41056 L p F P
0 g
s
.844 .422 .231 r
.12767 .41056 m .12773 .41067 L .1239 .41059 L p F P
0 g
s
.166 0 0 r
.64563 .43562 m .64707 .43316 L .63591 .43929 L p F P
0 g
s
.166 0 0 r
.63591 .43929 m .63539 .44019 L .64563 .43562 L p F P
0 g
s
.838 .412 .224 r
.12993 .41479 m .12773 .41067 L .1239 .41059 L p F P
0 g
s
0 0 0 r
.51611 .3464 m .51838 .34518 L .50692 .34828 L p F P
0 g
s
0 0 0 r
.50692 .34828 m .50503 .34924 L .51611 .3464 L p F P
0 g
s
.411 0 0 r
.40276 .36377 m .39781 .36378 L .39576 .36482 L p F P
0 g
s
.441 0 0 r
.39781 .36378 m .39576 .36482 L .39004 .36363 L closepath p F P
0 g
s
.42 0 0 r
.41196 .36368 m .40978 .36491 L .40276 .36377 L closepath p F P
0 g
s
.411 0 0 r
.40879 .36555 m .40978 .36491 L .40276 .36377 L p F P
0 g
s
.411 0 0 r
.39951 .36559 m .40879 .36555 L p .40276 .36377 L F P
0 g
s
.411 0 0 r
.39576 .36482 m .39951 .36559 L p .40276 .36377 L F P
0 g
s
.346 0 0 r
.2609 .33718 m .26365 .33828 L .27031 .34045 L p F P
0 g
s
.302 0 0 r
.27051 .34093 m .26365 .33828 L .27031 .34045 L p F P
0 g
s
.302 0 0 r
.27173 .34128 m .27051 .34093 L p .27031 .34045 L F P
0 g
s
.302 0 0 r
.27031 .34045 m .2746 .34191 L .27173 .34128 L p F P
0 g
s
.158 .588 .934 r
.19579 .31382 m .19851 .31439 L .20379 .31708 L p F P
0 g
s
.193 .619 .946 r
.20593 .31583 m .19851 .31439 L .20379 .31708 L p F P
0 g
s
.193 .619 .946 r
.20379 .31708 m .20944 .31803 L .20593 .31583 L p F P
0 g
s
.391 0 0 r
.29466 .4871 m .29567 .48741 L .29397 .48712 L closepath p F P
0 g
s
.229 0 0 r
.35446 .49579 m .35359 .49583 L .35176 .49556 L closepath p F P
0 g
s
0 0 0 r
.54125 .3377 m .5438 .33666 L .53282 .34037 L p F P
0 g
s
0 0 0 r
.53282 .34037 m .53013 .34149 L .54125 .3377 L p F P
0 g
s
.383 0 0 r
.41676 .3635 m .41196 .36368 L .40978 .36491 L p F P
0 g
s
.798 .33 .119 r
.14671 .42585 m .14417 .42566 L .14307 .42412 L closepath p F P
0 g
s
.479 0 0 r
.35391 .36048 m .35705 .36151 L .35227 .36097 L closepath p F P
0 g
s
.302 0 0 r
.2609 .33718 m .26365 .33828 L .25753 .33605 L closepath p F P
0 g
s
.406 .695 .979 r
.1649 .3046 m .17268 .30481 L .17787 .30756 L p F P
0 g
s
.392 .684 .977 r
.17268 .30481 m .1649 .3046 L .16137 .30167 L p F P
0 g
s
.431 0 0 r
.3945 .36556 m .39576 .36482 L .39004 .36363 L p F P
0 g
s
.431 0 0 r
.38701 .36536 m .3945 .36556 L p .39004 .36363 L F P
0 g
s
.431 0 0 r
.38178 .36402 m .38701 .36536 L p .39004 .36363 L F P
0 g
s
.431 0 0 r
.39004 .36363 m .38318 .3634 L .38178 .36402 L p F P
0 g
s
.052 0 0 r
.50481 .4886 m .50778 .48747 L .50449 .48795 L p F P
0 g
s
.052 0 0 r
.49376 .49017 m .50481 .4886 L p .50449 .48795 L F P
0 g
s
.062 0 0 r
.50813 .48733 m .50778 .48747 L .50449 .48795 L closepath p F P
0 g
s
.288 0 0 r
.33966 .49429 m .34161 .49464 L .35176 .49556 L p F P
0 g
s
.281 0 0 r
.33966 .49429 m .34161 .49464 L .33869 .49436 L closepath p F P
0 g
s
.068 0 0 r
.53202 .48247 m .53287 .48203 L .52178 .48419 L p F P
0 g
s
.068 0 0 r
.52178 .48419 m .52017 .48501 L .53202 .48247 L p F P
0 g
s
.872 .707 .674 r
.07499 .33519 m .07932 .33824 L .08191 .3325 L p F P
0 g
s
.872 .707 .674 r
.08191 .3325 m .07759 .32944 L .07499 .33519 L p F P
0 g
s
.827 .734 .761 r
.08021 .31533 m .08142 .31386 L .08572 .31695 L p F P
0 g
s
.827 .734 .761 r
.08572 .31695 m .08375 .31937 L .08021 .31533 L p F P
0 g
s
.493 .904 .882 r
.58317 .32234 m .57748 .32469 L .58275 .32237 L closepath p F P
0 g
s
.471 .894 .861 r
.58037 .3225 m .58275 .32237 L .57748 .32469 L p F P
0 g
s
.471 .894 .861 r
.56922 .32723 m .58037 .3225 L p .57748 .32469 L F P
0 g
s
.681 .904 .975 r
.62254 .30912 m .62218 .30895 L .62443 .30797 L closepath p F P
0 g
s
.477 0 0 r
.26364 .47967 m .26401 .47983 L .26332 .47968 L closepath p F P
0 g
s
.612 .053 0 r
.21563 .46336 m .21644 .46388 L .21467 .46333 L closepath p F P
0 g
s
.391 0 0 r
.42571 .36314 m .42381 .36428 L .41676 .3635 L closepath p F P
0 g
s
.383 0 0 r
.42264 .36509 m .42381 .36428 L .41676 .3635 L p F P
0 g
s
.383 0 0 r
.41323 .36542 m .42264 .36509 L p .41676 .3635 L F P
0 g
s
.383 0 0 r
.40978 .36491 m .41323 .36542 L p .41676 .3635 L F P
0 g
s
.616 .936 .958 r
.60826 .31295 m .59927 .31687 L .60726 .31276 L closepath p F P
0 g
s
.593 .937 .943 r
.60551 .31243 m .60726 .31276 L .59927 .31687 L p F P
0 g
s
.593 .937 .943 r
.59432 .3175 m .60551 .31243 L p .59927 .31687 L F P
0 g
s
.75 .252 .044 r
.16464 .43776 m .16622 .43948 L .16176 .43762 L closepath p F P
0 g
s
.318 .801 .747 r
.55809 .33165 m .5561 .33238 L .55803 .33166 L closepath p F P
0 g
s
.307 .791 .733 r
.55525 .33239 m .55803 .33166 L .5561 .33238 L p F P
0 g
s
.307 .791 .733 r
.54412 .33653 m .55525 .33239 L p .5561 .33238 L F P
0 g
s
.22 0 0 r
.35027 .49593 m .34161 .49464 L .35176 .49556 L p F P
0 g
s
.22 0 0 r
.35176 .49556 m .35359 .49583 L .35027 .49593 L p F P
0 g
s
.536 .493 .756 r
.71793 .3168 m .72215 .31353 L .72353 .31747 L closepath p F P
0 g
s
.453 0 0 r
.38318 .3634 m .38178 .36402 L .37831 .36317 L closepath p F P
0 g
s
.27 0 .295 r
.69348 .39735 m .69179 .39837 L .69252 .39442 L p F P
0 g
s
.27 0 .295 r
.69252 .39442 m .69922 .39041 L .69348 .39735 L p F P
0 g
s
.65 .748 .921 r
.11982 .2983 m .13022 .29495 L .13376 .29822 L p F P
0 g
s
.645 .746 .923 r
.13022 .29495 m .11982 .2983 L .11626 .29491 L p F P
0 g
s
.707 .753 .888 r
.10572 .29995 m .11626 .29491 L .11982 .2983 L p F P
0 g
s
.05 0 0 r
.45942 .49485 m .45385 .49538 L .45165 .49586 L p F P
0 g
s
.394 0 0 r
.26394 .48086 m .27155 .4826 L .26401 .47983 L p F P
0 g
s
.394 0 0 r
.26013 .47945 m .26394 .48086 L p .26401 .47983 L F P
0 g
s
.394 0 0 r
.26401 .47983 m .26332 .47968 L .26013 .47945 L p F P
0 g
s
.846 .731 .736 r
.08101 .32341 m .08375 .31937 L .08021 .31533 L p F P
0 g
s
.418 .281 .587 r
.72928 .34713 m .72096 .35322 L .72028 .34767 L p F P
0 g
s
.418 .281 .587 r
.72028 .34767 m .72709 .34267 L .72928 .34713 L p F P
0 g
s
.896 .6 .476 r
.08883 .37293 m .09346 .37582 L .09328 .37097 L p F P
0 g
s
.896 .6 .476 r
.09328 .37097 m .08865 .36808 L .08883 .37293 L p F P
0 g
s
.047 0 0 r
.56965 .47171 m .57199 .47013 L .56084 .47331 L p F P
0 g
s
.047 0 0 r
.56084 .47331 m .55838 .47496 L .56965 .47171 L p F P
0 g
s
.764 .271 .052 r
.15494 .43458 m .16048 .43707 L .15714 .43313 L p F P
0 g
s
.764 .271 .052 r
.15714 .43313 m .15157 .43065 L .15494 .43458 L p F P
0 g
s
.442 0 0 r
.37972 .36506 m .38178 .36402 L .37831 .36317 L p F P
0 g
s
.442 0 0 r
.37547 .36482 m .37972 .36506 L p .37831 .36317 L F P
0 g
s
.442 0 0 r
.36782 .36253 m .37547 .36482 L p .37831 .36317 L F P
0 g
s
.442 0 0 r
.37831 .36317 m .368 .36247 L .36782 .36253 L p F P
0 g
s
.348 0 0 r
.43257 .36265 m .42571 .36314 L .42381 .36428 L p F P
0 g
s
.893 .572 .433 r
.09403 .38055 m .09873 .38341 L .09815 .37868 L p F P
0 g
s
.893 .572 .433 r
.09815 .37868 m .09346 .37582 L .09403 .38055 L p F P
0 g
s
.897 .625 .519 r
.08408 .36515 m .08865 .36808 L .0889 .3631 L p F P
0 g
s
.897 .625 .519 r
.0889 .3631 m .08434 .36017 L .08408 .36515 L p F P
0 g
s
.442 0 0 r
.26332 .47968 m .26013 .47945 L .25662 .47802 L closepath p F P
0 g
s
.59 .577 .807 r
.70625 .30408 m .71777 .30283 L .71832 .30405 L p F P
0 g
s
.605 .604 .824 r
.71777 .30283 m .70625 .30408 L .70348 .29897 L p F P
0 g
s
.434 .709 .981 r
.18001 .30864 m .17861 .30756 L .17787 .30756 L closepath p F P
0 g
s
.305 0 0 r
.29615 .48831 m .30455 .4898 L .29567 .48741 L p F P
0 g
s
.305 0 0 r
.29122 .48699 m .29615 .48831 L p .29567 .48741 L F P
0 g
s
.305 0 0 r
.29567 .48741 m .29397 .48712 L .29122 .48699 L p F P
0 g
s
.054 0 0 r
.5971 .46047 m .5972 .46039 L .5863 .46407 L p F P
0 g
s
.054 0 0 r
.5863 .46407 m .58592 .46438 L .5971 .46047 L p F P
0 g
s
.749 .753 .855 r
.10442 .3008 m .10572 .29995 L .10215 .29645 L p F P
0 g
s
.749 .753 .855 r
.10215 .29645 m .10029 .29764 L .10442 .3008 L p F P
0 g
s
.762 .746 .838 r
.09138 .30386 m .10029 .29764 L .10442 .3008 L p F P
0 g
s
.179 0 0 r
.47711 .35704 m .47998 .35515 L .47951 .35521 L p F P
0 g
s
.179 0 0 r
.47554 .3573 m .47711 .35704 L p .47951 .35521 L F P
0 g
s
.179 0 0 r
.46595 .35831 m .47554 .3573 L p .47951 .35521 L F P
0 g
s
.162 0 0 r
.48004 .35512 m .47998 .35515 L .47951 .35521 L closepath p F P
0 g
s
.819 .37 .168 r
.13249 .41894 m .13775 .42154 L .1352 .41739 L p F P
0 g
s
.819 .37 .168 r
.1352 .41739 m .12993 .41479 L .13249 .41894 L p F P
0 g
s
.662 .923 .975 r
.62443 .30797 m .62218 .30895 L .61945 .30794 L p F P
0 g
s
.668 .924 .973 r
.60826 .31295 m .61945 .30794 L .62218 .30895 L p F P
0 g
s
.067 .56 .892 r
.22309 .32282 m .21812 .32158 L .2239 .32408 L p F P
0 g
s
.067 .56 .892 r
.2239 .32408 m .2266 .32468 L .22309 .32282 L p F P
0 g
s
.028 0 0 r
.51885 .48554 m .52017 .48501 L .50813 .48733 L p F P
0 g
s
.028 0 0 r
.50813 .48733 m .50778 .48747 L .51885 .48554 L p F P
0 g
s
.886 .541 .389 r
.09967 .38803 m .09873 .38341 L .10348 .38624 L p F P
0 g
s
.886 .541 .389 r
.10284 .38992 m .09967 .38803 L p .10348 .38624 L F P
0 g
s
.886 .541 .389 r
.10348 .38624 m .10417 .38957 L .10284 .38992 L p F P
0 g
s
.121 0 0 r
.49099 .3534 m .49211 .35273 L .48004 .35512 L p F P
0 g
s
.121 0 0 r
.48004 .35512 m .47998 .35515 L .49099 .3534 L p F P
0 g
s
.357 .825 .762 r
.56856 .32738 m .56922 .32723 L .55809 .33165 L p F P
0 g
s
.357 .825 .762 r
.55809 .33165 m .55803 .33166 L .56856 .32738 L p F P
0 g
s
.583 .738 .949 r
.1455 .29752 m .14761 .29939 L p .13376 .29822 L F P
0 g
s
.583 .738 .949 r
.13376 .29822 m .14345 .29639 L .1455 .29752 L p F P
0 g
s
.575 .734 .951 r
.14345 .29639 m .13376 .29822 L .13022 .29495 L p F P
0 g
s
.438 0 0 r
.32313 .3551 m .3228 .35513 L .32229 .35496 L closepath p F P
0 g
s
.638 .085 0 r
.19858 .45615 m .19854 .45615 L .19851 .45613 L closepath p F P
0 g
s
.136 .569 .926 r
.19851 .31439 m .19579 .31382 L .19228 .31135 L p F P
0 g
s
.635 .079 0 r
.1949 .45574 m .19238 .45388 L .19851 .45613 L p F P
0 g
s
.635 .079 0 r
.19851 .45613 m .19854 .45615 L .1949 .45574 L p F P
0 g
s
.618 .057 0 r
.20359 .45958 m .19854 .45615 L .1949 .45574 L p F P
0 g
s
.541 0 0 r
.21553 .46507 m .22214 .46716 L .21644 .46388 L p F P
0 g
s
.541 0 0 r
.21203 .46304 m .21553 .46507 L p .21644 .46388 L F P
0 g
s
.541 0 0 r
.21644 .46388 m .21467 .46333 L .21203 .46304 L p F P
0 g
s
.895 .65 .56 r
.07984 .3572 m .08434 .36017 L .08507 .35503 L p F P
0 g
s
.895 .65 .56 r
.08507 .35503 m .08058 .35207 L .07984 .3572 L p F P
0 g
s
.703 .753 .891 r
.11626 .29491 m .10572 .29995 L .10215 .29645 L p F P
0 g
s
.184 0 0 r
.48923 .35467 m .49099 .3534 L .47998 .35515 L p F P
0 g
s
.184 0 0 r
.47998 .35515 m .47711 .35704 L .48923 .35467 L p F P
0 g
s
.362 .828 .761 r
.5664 .32786 m .56856 .32738 L .55803 .33166 L p F P
0 g
s
.362 .828 .761 r
.55803 .33166 m .55525 .33239 L .5664 .32786 L p F P
0 g
s
.711 .192 0 r
.18153 .44772 m .18182 .44798 L .18107 .4477 L closepath p F P
0 g
s
.448 0 0 r
.31938 .35555 m .31387 .35339 L .32229 .35496 L p F P
0 g
s
.448 0 0 r
.32229 .35496 m .3228 .35513 L .31938 .35555 L p F P
0 g
s
.353 0 0 r
.29397 .48712 m .29122 .48699 L .28746 .48586 L closepath p F P
0 g
s
.05 0 0 r
.46262 .4951 m .46569 .49438 L .45942 .49485 L p F P
0 g
s
.05 0 0 r
.45165 .49586 m .46262 .4951 L p .45942 .49485 L F P
0 g
s
.062 0 0 r
.46684 .4941 m .46569 .49438 L .45942 .49485 L closepath p F P
0 g
s
.137 0 0 r
.64737 .43265 m .64707 .43316 L .65019 .43132 L closepath p F P
0 g
s
.348 0 0 r
.4361 .36421 m .43785 .36294 L .43257 .36265 L p F P
0 g
s
.348 0 0 r
.42867 .3647 m .4361 .36421 L p .43257 .36265 L F P
0 g
s
.348 0 0 r
.42381 .36428 m .42867 .3647 L p .43257 .36265 L F P
0 g
s
.354 0 0 r
.43907 .36218 m .43785 .36294 L .43257 .36265 L closepath p F P
0 g
s
.355 0 0 r
.29185 .34707 m .29179 .34706 L .29172 .34704 L closepath p F P
0 g
s
.364 0 0 r
.28834 .34673 m .28424 .34515 L .29172 .34704 L p F P
0 g
s
.364 0 0 r
.29172 .34704 m .29179 .34706 L .28834 .34673 L p F P
0 g
s
.515 0 0 r
.29821 .34985 m .29179 .34706 L .28834 .34673 L p F P
0 g
s
.873 .496 .327 r
.1059 .39531 m .11081 .39807 L .10939 .3936 L p F P
0 g
s
.873 .496 .327 r
.10939 .3936 m .10446 .39084 L .1059 .39531 L p F P
0 g
s
.162 0 .044 r
.65899 .4247 m .65823 .42627 L .6653 .42153 L closepath p F P
0 g
s
.457 0 0 r
.368 .36247 m .36782 .36253 L .36743 .36242 L closepath p F P
0 g
s
.673 .754 .911 r
.68663 .29375 m .67529 .29743 L .67258 .29446 L p F P
0 g
s
.681 .778 .924 r
.66129 .29867 m .67258 .29446 L .67529 .29743 L p F P
0 g
s
.662 .726 .897 r
.67529 .29743 m .68663 .29375 L .68934 .29742 L p F P
0 g
s
.656 .107 0 r
.18029 .44928 m .18631 .45159 L .18182 .44798 L p F P
0 g
s
.656 .107 0 r
.17785 .44731 m .18029 .44928 L p .18182 .44798 L F P
0 g
s
.656 .107 0 r
.18182 .44798 m .18107 .4477 L .17785 .44731 L p F P
0 g
s
.194 0 0 r
.34894 .49595 m .35027 .49593 L .34161 .49464 L p F P
0 g
s
.194 0 0 r
.34295 .49535 m .34894 .49595 L p .34161 .49464 L F P
0 g
s
.194 0 0 r
.33631 .49435 m .34295 .49535 L p .34161 .49464 L F P
0 g
s
.194 0 0 r
.34161 .49464 m .33869 .49436 L .33631 .49435 L p F P
0 g
s
.112 0 0 r
.64456 .43716 m .64563 .43562 L .63539 .44019 L p F P
0 g
s
.112 0 0 r
.63455 .4425 m .64456 .43716 L p .63539 .44019 L F P
0 g
s
.112 0 0 r
.63539 .44019 m .63345 .44299 L .63455 .4425 L p F P
0 g
s
.468 0 0 r
.36448 .36392 m .35705 .36151 L .36743 .36242 L p F P
0 g
s
.468 0 0 r
.36743 .36242 m .36782 .36253 L .36448 .36392 L p F P
0 g
s
.187 0 0 r
.36373 .49708 m .35359 .49583 L .35027 .49593 L p F P
0 g
s
.675 .909 .976 r
.63339 .30407 m .62443 .30797 L .63207 .30345 L closepath p F P
0 g
s
.662 .923 .975 r
.63067 .30281 m .63207 .30345 L .62443 .30797 L p F P
0 g
s
.662 .923 .975 r
.61945 .30794 m .63067 .30281 L p .62443 .30797 L F P
0 g
s
.546 0 0 r
.32908 .35772 m .3228 .35513 L .31938 .35555 L p F P
0 g
s
0 .356 .7 r
.24375 .3311 m .24387 .33114 L .24357 .33102 L closepath p F P
0 g
s
.475 0 0 r
.23518 .47232 m .24208 .4743 L .23576 .47119 L p F P
0 g
s
.475 0 0 r
.2292 .46944 m .23518 .47232 L p .23576 .47119 L F P
0 g
s
.475 0 0 r
.23576 .47119 m .22966 .46949 L .2292 .46944 L p F P
0 g
s
.89 .672 .6 r
.07615 .34906 m .08058 .35207 L .08185 .34676 L p F P
0 g
s
.89 .672 .6 r
.08185 .34676 m .07743 .34375 L .07615 .34906 L p F P
0 g
s
.05 0 0 r
.51885 .48554 m .50778 .48747 L .50481 .4886 L p F P
0 g
s
.846 .731 .736 r
.08021 .31533 m .0768 .3203 L .08101 .32341 L p F P
0 g
s
.861 .723 .709 r
.07335 .32634 m .07759 .32944 L .08101 .32341 L p F P
0 g
s
.861 .723 .709 r
.08101 .32341 m .0768 .3203 L .07335 .32634 L p F P
0 g
s
.113 0 0 r
.62088 .44992 m .62215 .4484 L .61096 .45328 L p F P
0 g
s
.113 0 0 r
.61096 .45328 m .61031 .45406 L .62088 .44992 L p F P
0 g
s
0 .33 .672 r
.24452 .33141 m .25074 .33376 L .24387 .33114 L p F P
0 g
s
0 .33 .672 r
.24025 .32961 m .24452 .33141 L p .24387 .33114 L F P
0 g
s
0 .33 .672 r
.24387 .33114 m .24357 .33102 L .24025 .32961 L p F P
0 g
s
.584 .012 0 r
.21467 .46333 m .21203 .46304 L .20995 .46175 L closepath p F P
0 g
s
.318 .088 .399 r
.71188 .37857 m .70367 .38386 L .70668 .37777 L p F P
0 g
s
.318 .088 .399 r
.70668 .37777 m .71221 .37419 L .71188 .37857 L p F P
0 g
s
.688 .825 .949 r
.66988 .2918 m .67258 .29446 L .66129 .29867 L p F P
0 g
s
.688 .825 .949 r
.66032 .29561 m .66988 .2918 L p .66129 .29867 L F P
0 g
s
.688 .825 .949 r
.66129 .29867 m .65895 .29662 L .66032 .29561 L p F P
0 g
s
.304 0 0 r
.45115 .36091 m .43907 .36218 L .43785 .36294 L p F P
0 g
s
.05 0 0 r
.59457 .46258 m .5971 .46047 L .58592 .46438 L p F P
0 g
s
.05 0 0 r
.58592 .46438 m .58365 .46627 L .59457 .46258 L p F P
0 g
s
.526 .001 0 r
.37547 .36482 m .36782 .36253 L .36448 .36392 L p F P
0 g
s
.69 .154 0 r
.18107 .4477 m .17785 .44731 L .17593 .44564 L closepath p F P
0 g
s
.238 0 0 r
.33869 .49436 m .33631 .49435 L .33191 .49357 L closepath p F P
0 g
s
0 .45 .776 r
.24357 .33102 m .24025 .32961 L .23757 .32883 L closepath p F P
0 g
s
.4 .239 .544 r
.72135 .35842 m .72025 .35919 L .7194 .3543 L p F P
0 g
s
.4 .239 .544 r
.7194 .3543 m .72096 .35322 L .72135 .35842 L p F P
0 g
s
0 0 0 r
.52961 .34177 m .53013 .34149 L .51904 .34483 L p F P
0 g
s
0 0 0 r
.51904 .34483 m .51838 .34518 L .52961 .34177 L p F P
0 g
s
.638 .671 .866 r
.70287 .29794 m .70082 .29953 L p .68934 .29742 L F P
0 g
s
.638 .671 .866 r
.68934 .29742 m .70074 .29446 L .70287 .29794 L p F P
0 g
s
.651 .699 .882 r
.70074 .29446 m .68934 .29742 L .68663 .29375 L p F P
0 g
s
.524 .919 .888 r
.59284 .31748 m .59432 .3175 L .58317 .32234 L p F P
0 g
s
.524 .919 .888 r
.58317 .32234 m .58275 .32237 L .59284 .31748 L p F P
0 g
s
.446 .331 .629 r
.72924 .34107 m .72709 .34267 L .72339 .33869 L p F P
0 g
s
.446 .331 .629 r
.72339 .33869 m .7282 .33509 L .72924 .34107 L p F P
0 g
s
.435 .708 .98 r
.17508 .30485 m .17268 .30481 L .17787 .30756 L p F P
0 g
s
.435 .708 .98 r
.17787 .30756 m .17861 .30756 L .17508 .30485 L p F P
0 g
s
.862 .463 .28 r
.11257 .40245 m .11754 .40519 L .11579 .4008 L p F P
0 g
s
.862 .463 .28 r
.11579 .4008 m .11081 .39807 L .11257 .40245 L p F P
0 g
s
.798 .329 .115 r
.14039 .42531 m .13775 .42154 L .14307 .42412 L p F P
0 g
s
.798 .329 .115 r
.14307 .42412 m .14417 .42566 L .14039 .42531 L p F P
0 g
s
.185 0 .109 r
.67026 .41634 m .66937 .41859 L .67691 .4128 L closepath p F P
0 g
s
.03 0 0 r
.47669 .49329 m .47961 .49258 L .46684 .4941 L p F P
0 g
s
.03 0 0 r
.46684 .4941 m .46569 .49438 L .47669 .49329 L p F P
0 g
s
.134 0 0 r
.65019 .43132 m .64707 .43316 L .64563 .43562 L p F P
0 g
s
.499 .706 .963 r
.14761 .29939 m .14807 .29936 L .1455 .29752 L closepath p F P
0 g
s
.309 0 0 r
.3085 .48996 m .31344 .49113 L .30544 .48995 L closepath p F P
0 g
s
.337 .132 .448 r
.71811 .37018 m .71221 .37419 L .71232 .36957 L p F P
0 g
s
.337 .132 .448 r
.71232 .36957 m .71978 .36449 L .71811 .37018 L p F P
0 g
s
.083 0 0 r
.63335 .44311 m .63345 .44299 L .62304 .44732 L p F P
0 g
s
.083 0 0 r
.62304 .44732 m .62215 .4484 L .63335 .44311 L p F P
0 g
s
.622 .657 .864 r
.70082 .29953 m .70287 .29794 L .70348 .29897 L closepath p F P
0 g
s
.703 .173 0 r
.16439 .44083 m .17013 .44325 L .16622 .43948 L p F P
0 g
s
.703 .173 0 r
.16092 .43751 m .16439 .44083 L p .16622 .43948 L F P
0 g
s
.703 .173 0 r
.16622 .43948 m .16176 .43762 L .16092 .43751 L p F P
0 g
s
.046 0 0 r
.54694 .47798 m .54687 .47802 L .54533 .47837 L closepath p F P
0 g
s
.039 0 0 r
.544 .47954 m .54687 .47802 L .54533 .47837 L p F P
0 g
s
.039 0 0 r
.53287 .48203 m .544 .47954 L p .54533 .47837 L F P
0 g
s
.331 0 0 r
.26368 .33879 m .27051 .34093 L .26365 .33828 L p F P
0 g
s
.331 0 0 r
.25742 .33601 m .26368 .33879 L p .26365 .33828 L F P
0 g
s
.331 0 0 r
.26365 .33828 m .25753 .33605 L .25742 .33601 L p F P
0 g
s
.253 .633 .961 r
.18841 .30881 m .17861 .30756 L .17508 .30485 L p F P
0 g
s
.489 .702 .964 r
.15429 .29574 m .15783 .29872 L .14807 .29936 L p F P
0 g
s
.489 .702 .964 r
.14407 .29627 m .15429 .29574 L p .14807 .29936 L F P
0 g
s
.489 .702 .964 r
.14807 .29936 m .1455 .29752 L .14407 .29627 L p F P
0 g
s
.884 .692 .639 r
.07308 .34071 m .07743 .34375 L .07932 .33824 L p F P
0 g
s
.884 .692 .639 r
.07932 .33824 m .07499 .33519 L .07308 .34071 L p F P
0 g
s
.484 0 0 r
.24641 .47489 m .2493 .47618 L .24367 .47474 L closepath p F P
0 g
s
.488 0 0 r
.24641 .47489 m .2493 .47618 L .25662 .47802 L p F P
0 g
s
.489 0 0 r
.36435 .36398 m .36448 .36392 L .35705 .36151 L p F P
0 g
s
.489 0 0 r
.35451 .36305 m .36435 .36398 L p .35705 .36151 L F P
0 g
s
.489 0 0 r
.35054 .36152 m .35451 .36305 L p .35705 .36151 L F P
0 g
s
.489 0 0 r
.35705 .36151 m .35227 .36097 L .35054 .36152 L p F P
0 g
s
.242 0 0 r
.46595 .35831 m .47554 .3573 L .46476 .35914 L closepath p F P
0 g
s
.175 0 0 r
.36755 .49694 m .37505 .49765 L .36449 .49713 L closepath p F P
0 g
s
.7 .855 .957 r
.65859 .2963 m .64733 .30095 L .64462 .29916 L p F P
0 g
s
.696 .873 .965 r
.63339 .30407 m .64462 .29916 L .64733 .30095 L p F P
0 g
s
.406 0 0 r
.2774 .48361 m .27937 .48428 L .28746 .48586 L p F P
0 g
s
.351 0 0 r
.28775 .48682 m .27937 .48428 L .28746 .48586 L p F P
0 g
s
.351 0 0 r
.28777 .48682 m .28775 .48682 L p .28746 .48586 L F P
0 g
s
.351 0 0 r
.28746 .48586 m .29122 .48699 L .28777 .48682 L p F P
0 g
s
.441 0 0 r
.25638 .47909 m .2493 .47618 L .25662 .47802 L p F P
0 g
s
.441 0 0 r
.25683 .4792 m .25638 .47909 L p .25662 .47802 L F P
0 g
s
.441 0 0 r
.25662 .47802 m .26013 .47945 L .25683 .4792 L p F P
0 g
s
.213 0 0 r
.33295 .49433 m .33631 .49435 L .33191 .49357 L p F P
0 g
s
.213 0 0 r
.32239 .49245 m .33295 .49433 L p .33191 .49357 L F P
0 g
s
.213 0 0 r
.33191 .49357 m .32239 .49245 L .32239 .49245 L p F P
0 g
s
.183 0 .051 r
.65823 .42627 m .65019 .43132 L .65746 .42786 L closepath p F P
0 g
s
.134 0 0 r
.65577 .43078 m .65746 .42786 L .65019 .43132 L p F P
0 g
s
.134 0 0 r
.6555 .43094 m .65577 .43078 L p .65019 .43132 L F P
0 g
s
.134 0 0 r
.64563 .43562 m .6555 .43094 L p .65019 .43132 L F P
0 g
s
.049 0 0 r
.50444 .48874 m .50481 .4886 L .49376 .49017 L p F P
0 g
s
.049 0 0 r
.49376 .49017 m .49212 .49077 L .50444 .48874 L p F P
0 g
s
.101 0 0 r
.49212 .49077 m .49376 .49017 L p .47973 .49254 L F P
0 g
s
.011 0 0 r
.55801 .47516 m .55838 .47496 L .54694 .47798 L p F P
0 g
s
.011 0 0 r
.54694 .47798 m .54687 .47802 L .55801 .47516 L p F P
0 g
s
.529 .921 .886 r
.59155 .31748 m .59284 .31748 L .58275 .32237 L p F P
0 g
s
.529 .921 .886 r
.58275 .32237 m .58037 .3225 L .59155 .31748 L p F P
0 g
s
.285 .032 .344 r
.70256 .38457 m .7024 .38581 L .70367 .38386 L closepath p F P
0 g
s
.64 .944 .956 r
.61688 .30722 m .61945 .30794 L .60826 .31295 L p F P
0 g
s
.64 .944 .956 r
.60826 .31295 m .60726 .31276 L .61688 .30722 L p F P
0 g
s
.848 .427 .233 r
.11961 .40948 m .11754 .40519 L .12258 .40789 L p F P
0 g
s
.848 .427 .233 r
.1215 .4105 m .11961 .40948 L p .12258 .40789 L F P
0 g
s
.848 .427 .233 r
.12258 .40789 m .1239 .41059 L .1215 .4105 L p F P
0 g
s
0 .399 .74 r
.2266 .32468 m .23156 .3264 L .23757 .32883 L p F P
0 g
s
0 .375 .731 r
.23156 .3264 m .2266 .32468 L .22309 .32282 L p F P
0 g
s
.488 0 0 r
.31239 .35452 m .30606 .35162 L .31387 .35339 L p F P
0 g
s
.488 0 0 r
.31844 .35569 m .31239 .35452 L p .31387 .35339 L F P
0 g
s
.488 0 0 r
.31387 .35339 m .31938 .35555 L .31844 .35569 L p F P
0 g
s
.51 0 0 r
.30556 .3514 m .30606 .35162 L .31387 .35339 L p F P
0 g
s
.041 0 0 r
.55801 .47516 m .54687 .47802 L .544 .47954 L p F P
0 g
s
.796 .749 .81 r
.08837 .30662 m .09138 .30386 L .08781 .30023 L p F P
0 g
s
.796 .749 .81 r
.08781 .30023 m .08424 .30346 L .08837 .30662 L p F P
0 g
s
.813 .746 .79 r
.0772 .31074 m .08142 .31386 L .08837 .30662 L p F P
0 g
s
.813 .746 .79 r
.08837 .30662 m .08424 .30346 L .0772 .31074 L p F P
0 g
s
.76 .748 .842 r
.10029 .29764 m .09138 .30386 L .08781 .30023 L p F P
0 g
s
.136 .569 .926 r
.19228 .31135 m .19342 .31162 L .19851 .31439 L p F P
0 g
s
.164 .598 .936 r
.20211 .31354 m .19342 .31162 L .19851 .31439 L p F P
0 g
s
.164 .598 .936 r
.20294 .31393 m .20211 .31354 L p .19851 .31439 L F P
0 g
s
.164 .598 .936 r
.19851 .31439 m .20593 .31583 L .20294 .31393 L p F P
0 g
s
.4 0 0 r
.2774 .48361 m .27937 .48428 L .27588 .48357 L closepath p F P
0 g
s
.385 .228 .542 r
.7301 .35204 m .72135 .35842 L .72096 .35322 L p F P
0 g
s
.385 .228 .542 r
.72096 .35322 m .72928 .34713 L .7301 .35204 L p F P
0 g
s
.493 0 0 r
.35227 .36097 m .35054 .36152 L .34728 .3604 L closepath p F P
0 g
s
.472 0 0 r
.38178 .36402 m .38701 .36536 L .37972 .36506 L closepath p F P
0 g
s
.306 0 0 r
.45205 .36081 m .4519 .3609 L .45115 .36091 L closepath p F P
0 g
s
.304 0 0 r
.44918 .3629 m .4519 .3609 L .45115 .36091 L p F P
0 g
s
.304 0 0 r
.44672 .36314 m .44918 .3629 L p .45115 .36091 L F P
0 g
s
.304 0 0 r
.43785 .36294 m .44672 .36314 L p .45115 .36091 L F P
0 g
s
.205 0 .169 r
.6812 .40756 m .68048 .4098 L .68608 .4048 L closepath p F P
0 g
s
.276 0 0 r
.46286 .36049 m .46476 .35914 L .45205 .36081 L p F P
0 g
s
.276 0 0 r
.45205 .36081 m .4519 .3609 L .46286 .36049 L p F P
0 g
s
.017 0 0 r
.58317 .4666 m .58365 .46627 L .57257 .46973 L p F P
0 g
s
.017 0 0 r
.57257 .46973 m .57199 .47013 L .58317 .4666 L p F P
0 g
s
.605 .604 .824 r
.70348 .29897 m .71497 .29712 L .71777 .30283 L p F P
0 g
s
.604 .649 .868 r
.70287 .29794 m .70348 .29897 L .71497 .29712 L p F P
0 g
s
0 0 0 r
.52722 .34307 m .52961 .34177 L .51838 .34518 L p F P
0 g
s
0 0 0 r
.51838 .34518 m .51611 .3464 L .52722 .34307 L p F P
0 g
s
.446 0 0 r
.2746 .34191 m .27723 .34309 L .28424 .34515 L p F P
0 g
s
.408 0 0 r
.28368 .34591 m .27723 .34309 L .28424 .34515 L p F P
0 g
s
.408 0 0 r
.28592 .3465 m .28368 .34591 L p .28424 .34515 L F P
0 g
s
.408 0 0 r
.28424 .34515 m .28834 .34673 L .28592 .3465 L p F P
0 g
s
.412 0 0 r
.2746 .34191 m .27723 .34309 L .27173 .34128 L closepath p F P
0 g
s
.049 0 0 r
.61952 .4513 m .62088 .44992 L .61031 .45406 L p F P
0 g
s
.049 0 0 r
.61031 .45406 m .6083 .4561 L .61952 .4513 L p F P
0 g
s
0 0 0 r
.5524 .33348 m .55455 .33265 L .5438 .33666 L p F P
0 g
s
.292 .772 .676 r
.55455 .33265 m .5524 .33348 L .5527 .33335 L p F P
0 g
s
.292 .772 .676 r
.5527 .33335 m .56357 .32884 L p .55455 .33265 L F P
0 g
s
0 0 0 r
.55455 .33265 m .55525 .33239 L .55515 .33242 L p F P
0 g
s
0 0 0 r
.55515 .33242 m .54412 .33653 L p .55455 .33265 L F P
0 g
s
0 0 0 r
.54412 .33653 m .5438 .33666 L .55455 .33265 L p F P
0 g
s
.153 0 0 r
.38153 .49769 m .38694 .49805 L .37955 .49786 L closepath p F P
0 g
s
.761 .263 .035 r
.14945 .43206 m .15494 .43458 L .15157 .43065 L p F P
0 g
s
.761 .263 .035 r
.15157 .43065 m .14606 .42815 L .14945 .43206 L p F P
0 g
s
.883 .533 .382 r
.10417 .38957 m .10446 .39084 L .10284 .38992 L closepath p F P
0 g
s
.582 .009 0 r
.20841 .46262 m .20359 .45958 L .20995 .46175 L p F P
0 g
s
.582 .009 0 r
.20995 .46175 m .21203 .46304 L .20841 .46262 L p F P
0 g
s
.874 .71 .676 r
.07072 .3321 m .07499 .33519 L .07759 .32944 L p F P
0 g
s
.874 .71 .676 r
.07759 .32944 m .07335 .32634 L .07072 .3321 L p F P
0 g
s
.828 .738 .765 r
.07665 .31139 m .0772 .31074 L .08142 .31386 L p F P
0 g
s
.828 .738 .765 r
.08142 .31386 m .08021 .31533 L .07665 .31139 L p F P
0 g
s
.521 0 0 r
.22966 .46949 m .2292 .46944 L .22879 .46923 L closepath p F P
0 g
s
.317 0 0 r
.46195 .36125 m .46286 .36049 L .4519 .3609 L p F P
0 g
s
.317 0 0 r
.4519 .3609 m .44918 .3629 L .46195 .36125 L p F P
0 g
s
.283 .03 .342 r
.71136 .38271 m .71188 .37857 L .70367 .38386 L p F P
0 g
s
.283 .03 .342 r
.70201 .3887 m .71136 .38271 L p .70367 .38386 L F P
0 g
s
.283 .03 .342 r
.70367 .38386 m .7024 .38581 L .70201 .3887 L p F P
0 g
s
.099 0 0 r
.50205 .35115 m .50388 .34997 L .49211 .35273 L p F P
0 g
s
.099 0 0 r
.49211 .35273 m .49099 .3534 L .50205 .35115 L p F P
0 g
s
0 0 0 r
.52997 .4833 m .53202 .48247 L .52017 .48501 L p F P
0 g
s
0 0 0 r
.52017 .48501 m .51885 .48554 L .52997 .4833 L p F P
0 g
s
0 .493 .853 r
.20944 .31803 m .2126 .31897 L .21812 .32158 L p F P
0 g
s
.03 .533 .874 r
.21958 .32092 m .2126 .31897 L .21812 .32158 L p F P
0 g
s
.03 .533 .874 r
.21812 .32158 m .22309 .32282 L .21958 .32092 L p F P
0 g
s
.639 .084 0 r
.19105 .45514 m .18631 .45159 L .19238 .45388 L p F P
0 g
s
.639 .084 0 r
.19155 .45533 m .19105 .45514 L p .19238 .45388 L F P
0 g
s
.639 .084 0 r
.19238 .45388 m .1949 .45574 L .19155 .45533 L p F P
0 g
s
.101 0 0 r
.47973 .49254 m .48056 .49245 L .49212 .49077 L p F P
0 g
s
.072 0 0 r
.47973 .49254 m .48056 .49245 L .47961 .49258 L closepath p F P
0 g
s
.515 .464 .738 r
.72353 .31747 m .72849 .31858 L .72482 .32153 L closepath p F P
0 g
s
.508 .476 .757 r
.72215 .31353 m .72353 .31747 L .72849 .31858 L p F P
0 g
s
.79 .314 .102 r
.14606 .42815 m .14417 .42566 L .14039 .42531 L p F P
0 g
s
.474 .414 .71 r
.73538 .32114 m .72849 .31858 L .72482 .32153 L p F P
0 g
s
.474 .414 .71 r
.73552 .32166 m .73538 .32114 L p .72482 .32153 L F P
0 g
s
.474 .414 .71 r
.72737 .32819 m .73552 .32166 L p .72482 .32153 L F P
0 g
s
.474 .414 .71 r
.72482 .32153 m .72657 .32783 L .72737 .32819 L p F P
0 g
s
.525 0 0 r
.33665 .35854 m .33805 .3591 L .34728 .3604 L p F P
0 g
s
.501 0 0 r
.34491 .36187 m .33805 .3591 L .34728 .3604 L p F P
0 g
s
.501 0 0 r
.34839 .3623 m .34491 .36187 L p .34728 .3604 L F P
0 g
s
.501 0 0 r
.34728 .3604 m .35054 .36152 L .34839 .3623 L p F P
0 g
s
.847 .735 .739 r
.0768 .3203 m .08021 .31533 L .07665 .31139 L p F P
0 g
s
.838 .412 .224 r
.1239 .41059 m .12471 .41216 L .12993 .41479 L p F P
0 g
s
.819 .366 .155 r
.1273 .41629 m .13249 .41894 L .12993 .41479 L p F P
0 g
s
.819 .366 .155 r
.12993 .41479 m .12471 .41216 L .1273 .41629 L p F P
0 g
s
.9 .602 .474 r
.08426 .37 m .08883 .37293 L .08865 .36808 L p F P
0 g
s
.9 .602 .474 r
.08865 .36808 m .08408 .36515 L .08426 .37 L p F P
0 g
s
0 0 0 r
.48056 .49245 m .47961 .49258 L .47669 .49329 L p F P
0 g
s
.515 0 0 r
.22563 .469 m .22214 .46716 L .22879 .46923 L p F P
0 g
s
.515 0 0 r
.22879 .46923 m .2292 .46944 L .22563 .469 L p F P
0 g
s
.897 .574 .43 r
.0894 .37766 m .09403 .38055 L .09346 .37582 L p F P
0 g
s
.897 .574 .43 r
.09346 .37582 m .08883 .37293 L .0894 .37766 L p F P
0 g
s
.544 .517 .776 r
.72061 .3095 m .72655 .30991 L .72215 .31353 L closepath p F P
0 g
s
.508 .476 .757 r
.73232 .31077 m .72655 .30991 L .72215 .31353 L p F P
0 g
s
.508 .476 .757 r
.73351 .31447 m .73232 .31077 L p .72215 .31353 L F P
0 g
s
.508 .476 .757 r
.72849 .31858 m .73351 .31447 L p .72215 .31353 L F P
0 g
s
.623 .665 .87 r
.70074 .29446 m .70935 .29259 L .70287 .29794 L closepath p F P
0 g
s
.604 .649 .868 r
.71221 .29201 m .70935 .29259 L .70287 .29794 L p F P
0 g
s
.604 .649 .868 r
.71497 .29712 m .71221 .29201 L p .70287 .29794 L F P
0 g
s
.9 .629 .517 r
.07958 .36219 m .08408 .36515 L .08434 .36017 L p F P
0 g
s
.9 .629 .517 r
.08434 .36017 m .07984 .3572 L .07958 .36219 L p F P
0 g
s
.392 .684 .977 r
.16137 .30167 m .16772 .30197 L .17268 .30481 L p F P
0 g
s
.379 .674 .974 r
.16772 .30197 m .16137 .30167 L .15783 .29872 L p F P
0 g
s
0 .471 .843 r
.2126 .31897 m .20944 .31803 L .20593 .31583 L p F P
0 g
s
.513 0 0 r
.33665 .35854 m .33805 .3591 L .33578 .35875 L closepath p F P
0 g
s
.159 0 .041 r
.6653 .42153 m .65823 .42627 L .65746 .42786 L p F P
0 g
s
.007 0 0 r
.49212 .49077 m .49075 .49114 L .48056 .49245 L closepath p F P
0 g
s
0 0 0 r
.48803 .49185 m .49075 .49114 L .48056 .49245 L p F P
0 g
s
0 0 0 r
.48558 .4922 m .48803 .49185 L p .48056 .49245 L F P
0 g
s
0 0 0 r
.47669 .49329 m .48558 .4922 L p .48056 .49245 L F P
0 g
s
.69 .912 .972 r
.64191 .29763 m .64462 .29916 L .63339 .30407 L p F P
0 g
s
.69 .912 .972 r
.63852 .29918 m .64191 .29763 L p .63339 .30407 L F P
0 g
s
.69 .912 .972 r
.63339 .30407 m .63207 .30345 L .63852 .29918 L p F P
0 g
s
.259 0 0 r
.32239 .49245 m .32239 .49245 L .32238 .49245 L closepath p F P
0 g
s
.246 0 0 r
.319 .49229 m .31344 .49113 L .32238 .49245 L p F P
0 g
s
.246 0 0 r
.32238 .49245 m .32239 .49245 L .319 .49229 L p F P
0 g
s
.212 0 0 r
.33295 .49433 m .32239 .49245 L .319 .49229 L p F P
0 g
s
.3 .043 .347 r
.7024 .38581 m .69922 .39041 L .70201 .3887 L closepath p F P
0 g
s
.059 0 0 r
.51538 .34688 m .51611 .3464 L .50503 .34924 L p F P
0 g
s
.059 0 0 r
.50503 .34924 m .50388 .34997 L .51538 .34688 L p F P
0 g
s
.453 0 0 r
.39576 .36482 m .39951 .36559 L .3945 .36556 L closepath p F P
0 g
s
.891 .545 .384 r
.09497 .38517 m .09967 .38803 L .09873 .38341 L p F P
0 g
s
.891 .545 .384 r
.09873 .38341 m .09403 .38055 L .09497 .38517 L p F P
0 g
s
.145 0 0 r
.40851 .49822 m .40955 .49808 L p .39553 .49807 L F P
0 g
s
.145 0 0 r
.39553 .49807 m .39955 .49823 L .40851 .49822 L p F P
0 g
s
.132 0 0 r
.39553 .49807 m .39955 .49823 L .39421 .49822 L closepath p F P
0 g
s
.645 .746 .923 r
.11626 .29491 m .12666 .29168 L .13022 .29495 L p F P
0 g
s
.64 .745 .925 r
.12666 .29168 m .11626 .29491 L .11269 .29152 L p F P
0 g
s
.703 .753 .891 r
.10215 .29645 m .11269 .29152 L .11626 .29491 L p F P
0 g
s
0 0 0 r
.5438 .33666 m .54125 .3377 L .5524 .33348 L p F P
0 g
s
.689 .152 0 r
.17417 .44682 m .17013 .44325 L .17593 .44564 L p F P
0 g
s
.689 .152 0 r
.17593 .44564 m .17785 .44731 L .17417 .44682 L p F P
0 g
s
0 .453 .781 r
.23675 .3281 m .23156 .3264 L .23757 .32883 L p F P
0 g
s
0 .453 .781 r
.23757 .32883 m .24025 .32961 L .23675 .3281 L p F P
0 g
s
.491 0 0 r
.23518 .47232 m .2292 .46944 L .22563 .469 L p F P
0 g
s
.04 0 0 r
.47669 .49329 m .46569 .49438 L .46262 .4951 L p F P
0 g
s
.747 .754 .857 r
.10029 .29764 m .10215 .29645 L .09857 .29296 L p F P
0 g
s
.747 .754 .857 r
.09857 .29296 m .09622 .29445 L .10029 .29764 L p F P
0 g
s
.76 .748 .842 r
.08781 .30023 m .09622 .29445 L .10029 .29764 L p F P
0 g
s
.484 .408 .695 r
.72657 .32783 m .72737 .32819 L .72679 .32865 L closepath p F P
0 g
s
.356 0 0 r
.43785 .36294 m .44672 .36314 L .4361 .36421 L closepath p F P
0 g
s
.898 .653 .559 r
.07541 .3542 m .07984 .3572 L .08058 .35207 L p F P
0 g
s
.898 .653 .559 r
.08058 .35207 m .07615 .34906 L .07541 .3542 L p F P
0 g
s
.586 .739 .948 r
.1455 .29752 m .14407 .29627 L .14345 .29639 L closepath p F P
0 g
s
.419 .863 .798 r
.57885 .32276 m .58037 .3225 L .56922 .32723 L p F P
0 g
s
.419 .863 .798 r
.56922 .32723 m .56856 .32738 L .57885 .32276 L p F P
0 g
s
.462 .371 .666 r
.73248 .33172 m .7282 .33509 L .72679 .32865 L p F P
0 g
s
.462 .371 .666 r
.72679 .32865 m .72737 .32819 L .73248 .33172 L p F P
0 g
s
.498 0 0 r
.30556 .3514 m .30606 .35162 L .30516 .3514 L closepath p F P
0 g
s
.732 .216 0 r
.16176 .43762 m .16092 .43751 L .16048 .43707 L closepath p F P
0 g
s
.311 0 0 r
.27985 .48516 m .28775 .48682 L .27937 .48428 L p F P
0 g
s
.311 0 0 r
.27392 .48339 m .27985 .48516 L p .27937 .48428 L F P
0 g
s
.311 0 0 r
.27937 .48428 m .27588 .48357 L .27392 .48339 L p F P
0 g
s
.539 .534 .798 r
.71832 .30405 m .72061 .3095 L .72655 .30991 L p F P
0 g
s
.875 .493 .314 r
.10104 .39252 m .1059 .39531 L .10446 .39084 L p F P
0 g
s
.875 .493 .314 r
.10023 .38996 m .10104 .39252 L p .10446 .39084 L F P
0 g
s
.875 .493 .314 r
.10446 .39084 m .10284 .38992 L .10023 .38996 L p F P
0 g
s
.428 0 0 r
.40978 .36491 m .41323 .36542 L .40879 .36555 L closepath p F P
0 g
s
.127 0 0 r
.42247 .49789 m .42357 .49771 L p .40955 .49808 L F P
0 g
s
.127 0 0 r
.40955 .49808 m .4131 .49813 L .42247 .49789 L p F P
0 g
s
.111 0 0 r
.40955 .49808 m .4131 .49813 L .40851 .49822 L closepath p F P
0 g
s
.7 .753 .893 r
.11269 .29152 m .10215 .29645 L .09857 .29296 L p F P
0 g
s
.013 0 0 r
.58076 .46824 m .58317 .4666 L .57199 .47013 L p F P
0 g
s
.013 0 0 r
.57199 .47013 m .56965 .47171 L .58076 .46824 L p F P
0 g
s
.575 .734 .951 r
.13022 .29495 m .1386 .29348 L .14345 .29639 L p F P
0 g
s
.568 .73 .951 r
.1386 .29348 m .13022 .29495 L .12666 .29168 L p F P
0 g
s
.049 0 0 r
.46259 .49511 m .46262 .4951 L .45165 .49586 L p F P
0 g
s
.049 0 0 r
.45165 .49586 m .44948 .49631 L .46259 .49511 L p F P
0 g
s
.395 0 0 r
.42381 .36428 m .42867 .3647 L .42264 .36509 L closepath p F P
0 g
s
.077 0 0 r
.6313 .44556 m .63335 .44311 L .62215 .4484 L p F P
0 g
s
.077 0 0 r
.62215 .4484 m .62088 .44992 L .6313 .44556 L p F P
0 g
s
.64 .945 .955 r
.61671 .30718 m .61688 .30722 L .60726 .31276 L p F P
0 g
s
.64 .945 .955 r
.60726 .31276 m .60551 .31243 L .61671 .30718 L p F P
0 g
s
.034 0 0 r
.54369 .4797 m .544 .47954 L .53287 .48203 L p F P
0 g
s
.034 0 0 r
.53287 .48203 m .53202 .48247 L .54369 .4797 L p F P
0 g
s
.222 0 .224 r
.69179 .39837 m .69152 .39941 L .69348 .39735 L closepath p F P
0 g
s
.22 0 0 r
.25753 .33605 m .25742 .33601 L .25732 .33598 L closepath p F P
0 g
s
.514 0 0 r
.30455 .35274 m .31239 .35452 L .30606 .35162 L p F P
0 g
s
.514 0 0 r
.30211 .3515 m .30455 .35274 L p .30606 .35162 L F P
0 g
s
.514 0 0 r
.30606 .35162 m .30516 .3514 L .30211 .3515 L p F P
0 g
s
.109 0 0 r
.43612 .49724 m .43761 .49697 L p .42357 .49771 L F P
0 g
s
.109 0 0 r
.42357 .49771 m .42786 .49765 L .43612 .49724 L p F P
0 g
s
.09 0 0 r
.42357 .49771 m .42786 .49765 L .42247 .49789 L closepath p F P
0 g
s
.399 0 0 r
.24921 .47719 m .25638 .47909 L .2493 .47618 L p F P
0 g
s
.399 0 0 r
.24287 .47464 m .24921 .47719 L p .2493 .47618 L F P
0 g
s
.399 0 0 r
.2493 .47618 m .24367 .47474 L .24287 .47464 L p F P
0 g
s
.07 0 0 r
.43761 .49697 m .44423 .49669 L .43612 .49724 L closepath p F P
0 g
s
.461 .371 .668 r
.73696 .32814 m .73248 .33172 L .72737 .32819 L p F P
0 g
s
.461 .371 .668 r
.72737 .32819 m .73552 .32166 L .73696 .32814 L p F P
0 g
s
.223 0 0 r
.25393 .33491 m .25074 .33376 L .25732 .33598 L p F P
0 g
s
.894 .676 .6 r
.07179 .34603 m .07615 .34906 L .07743 .34375 L p F P
0 g
s
.894 .676 .6 r
.07743 .34375 m .07308 .34071 L .07179 .34603 L p F P
0 g
s
.419 .699 .979 r
.17155 .3021 m .16772 .30197 L .17268 .30481 L p F P
0 g
s
.419 .699 .979 r
.17268 .30481 m .17508 .30485 L .17155 .3021 L p F P
0 g
s
.44 0 0 r
.26368 .33879 m .25742 .33601 L .25393 .33491 L p F P
0 g
s
.258 0 .285 r
.70127 .39262 m .69348 .39735 L .69922 .39041 L p F P
0 g
s
.258 0 .285 r
.69922 .39041 m .70201 .3887 L .70127 .39262 L p F P
0 g
s
.802 .333 .114 r
.13535 .423 m .13249 .41894 L .13775 .42154 L p F P
0 g
s
.802 .333 .114 r
.13987 .42525 m .13535 .423 L p .13775 .42154 L F P
0 g
s
.802 .333 .114 r
.13775 .42154 m .14039 .42531 L .13987 .42525 L p F P
0 g
s
.847 .735 .739 r
.07665 .31139 m .07265 .31716 L .0768 .3203 L p F P
0 g
s
.863 .726 .71 r
.06917 .32321 m .07335 .32634 L .0768 .3203 L p F P
0 g
s
.863 .726 .71 r
.0768 .3203 m .07265 .31716 L .06917 .32321 L p F P
0 g
s
.204 0 .115 r
.66937 .41859 m .6653 .42153 L .66894 .41969 L closepath p F P
0 g
s
.159 0 .041 r
.66741 .42283 m .66894 .41969 L .6653 .42153 L p F P
0 g
s
.159 0 .041 r
.65746 .42786 m .66741 .42283 L p .6653 .42153 L F P
0 g
s
.731 .213 0 r
.1572 .43693 m .15494 .43458 L .16048 .43707 L p F P
0 g
s
.731 .213 0 r
.16048 .43707 m .16092 .43751 L .1572 .43693 L p F P
0 g
s
.48 0 0 r
.30516 .3514 m .30211 .3515 L .29821 .34985 L closepath p F P
0 g
s
.367 .184 .497 r
.72149 .36331 m .71978 .36449 L .72025 .35919 L p F P
0 g
s
.367 .184 .497 r
.72025 .35919 m .72135 .35842 L .72149 .36331 L p F P
0 g
s
.58 .94 .914 r
.60275 .31219 m .60551 .31243 L .59432 .3175 L p F P
0 g
s
.58 .94 .914 r
.6019 .31259 m .60275 .31219 L p .59432 .3175 L F P
0 g
s
.58 .94 .914 r
.59432 .3175 m .59284 .31748 L .6019 .31259 L p F P
0 g
s
.019 0 0 r
.5972 .46039 m .5971 .46047 L .59956 .45953 L closepath p F P
0 g
s
.247 0 0 r
.47554 .3573 m .46476 .35914 L .46286 .36049 L p F P
0 g
s
.864 .463 .272 r
.10766 .39969 m .11257 .40245 L .11081 .39807 L p F P
0 g
s
.864 .463 .272 r
.11081 .39807 m .1059 .39531 L .10766 .39969 L p F P
0 g
s
.152 .571 .931 r
.19228 .31135 m .19342 .31162 L .18942 .30931 L closepath p F P
0 g
s
.524 0 0 r
.33574 .36054 m .34491 .36187 L .33805 .3591 L p F P
0 g
s
.524 0 0 r
.33324 .35939 m .33574 .36054 L p .33805 .3591 L F P
0 g
s
.524 0 0 r
.33805 .3591 m .33578 .35875 L .33324 .35939 L p F P
0 g
s
.673 .754 .911 r
.67258 .29446 m .68392 .29045 L .68663 .29375 L p F P
0 g
s
.684 .78 .924 r
.68392 .29045 m .67258 .29446 L .66988 .2918 L p F P
0 g
s
.362 0 0 r
.27588 .48357 m .27392 .48339 L .27155 .4826 L closepath p F P
0 g
s
.663 .727 .897 r
.69801 .2904 m .68663 .29375 L .68392 .29045 L p F P
0 g
s
.651 .699 .882 r
.68663 .29375 m .69801 .2904 L .70074 .29446 L p F P
0 g
s
.84 .412 .217 r
.1239 .41059 m .12471 .41216 L .1215 .4105 L closepath p F P
0 g
s
.688 .826 .949 r
.65895 .29662 m .65859 .2963 L .66032 .29561 L closepath p F P
0 g
s
.015 0 0 r
.59956 .45953 m .5971 .46047 L .59457 .46258 L p F P
0 g
s
.317 0 0 r
.29122 .48699 m .29615 .48831 L .28777 .48682 L closepath p F P
0 g
s
.182 0 .106 r
.67691 .4128 m .66937 .41859 L .66894 .41969 L p F P
0 g
s
.559 0 0 r
.21553 .46507 m .21203 .46304 L .20841 .46262 L p F P
0 g
s
.408 0 0 r
.26013 .47945 m .26394 .48086 L .25683 .4792 L closepath p F P
0 g
s
.882 .51 .333 r
.10284 .38992 m .10023 .38996 L .09967 .38803 L closepath p F P
0 g
s
.517 0 0 r
.33578 .35875 m .33324 .35939 L .32908 .35772 L closepath p F P
0 g
s
.219 0 0 r
.31627 .49215 m .319 .49229 L .31344 .49113 L p F P
0 g
s
.219 0 0 r
.31454 .49188 m .31627 .49215 L p .31344 .49113 L F P
0 g
s
.219 0 0 r
.30508 .48993 m .31454 .49188 L p .31344 .49113 L F P
0 g
s
.219 0 0 r
.31344 .49113 m .30544 .48995 L .30508 .48993 L p F P
0 g
s
.2 0 0 r
.34295 .49535 m .33631 .49435 L .33295 .49433 L p F P
0 g
s
.718 .194 0 r
.16439 .44083 m .16092 .43751 L .1572 .43693 L p F P
0 g
s
.586 .738 .948 r
.14052 .29314 m .1386 .29348 L .14345 .29639 L p F P
0 g
s
.586 .738 .948 r
.14345 .29639 m .14407 .29627 L .14052 .29314 L p F P
0 g
s
.436 0 0 r
.27657 .34387 m .28368 .34591 L .27723 .34309 L p F P
0 g
s
.436 0 0 r
.27113 .34116 m .27657 .34387 L p .27723 .34309 L F P
0 g
s
.436 0 0 r
.27723 .34309 m .27173 .34128 L .27113 .34116 L p F P
0 g
s
.299 .074 .394 r
.71535 .37621 m .71188 .37857 L .71221 .37419 L p F P
0 g
s
.299 .074 .394 r
.71221 .37419 m .71811 .37018 L .71535 .37621 L p F P
0 g
s
.539 .534 .798 r
.7294 .30277 m .71988 .30274 L .71832 .30405 L p F P
0 g
s
.539 .534 .798 r
.73079 .30639 m .7294 .30277 L p .71832 .30405 L F P
0 g
s
.539 .534 .798 r
.72655 .30991 m .73079 .30639 L p .71832 .30405 L F P
0 g
s
.57 .567 .81 r
.71777 .30283 m .71988 .30274 L .71832 .30405 L closepath p F P
0 g
s
.886 .696 .64 r
.0688 .33763 m .07308 .34071 L .07499 .33519 L p F P
0 g
s
.886 .696 .64 r
.07499 .33519 m .07072 .3321 L .0688 .33763 L p F P
0 g
s
.422 .865 .797 r
.57757 .32297 m .57885 .32276 L .56856 .32738 L p F P
0 g
s
.422 .865 .797 r
.56856 .32738 m .5664 .32786 L .57757 .32297 L p F P
0 g
s
.433 .322 .628 r
.73598 .33576 m .72924 .34107 L .7282 .33509 L p F P
0 g
s
.433 .322 .628 r
.7282 .33509 m .73248 .33172 L .73598 .33576 L p F P
0 g
s
.851 .428 .224 r
.11465 .40674 m .11961 .40948 L .11754 .40519 L p F P
0 g
s
.851 .428 .224 r
.11754 .40519 m .11257 .40245 L .11465 .40674 L p F P
0 g
s
.668 .94 .964 r
.62794 .30184 m .63067 .30281 L .61945 .30794 L p F P
0 g
s
.668 .94 .964 r
.61776 .30668 m .62794 .30184 L p .61945 .30794 L F P
0 g
s
.668 .94 .964 r
.61945 .30794 m .61688 .30722 L .61776 .30668 L p F P
0 g
s
.479 .707 .969 r
.15429 .29574 m .14407 .29627 L .14052 .29314 L p F P
0 g
s
.35 .172 .493 r
.72969 .35734 m .72149 .36331 L .72135 .35842 L p F P
0 g
s
.35 .172 .493 r
.72135 .35842 m .7301 .35204 L .72969 .35734 L p F P
0 g
s
.683 .851 .963 r
.66032 .29561 m .65859 .2963 L .65589 .29426 L p F P
0 g
s
.7 .855 .957 r
.64462 .29916 m .65589 .29426 L .65859 .2963 L p F P
0 g
s
0 0 0 r
.5406 .33805 m .54125 .3377 L .53013 .34149 L p F P
0 g
s
0 0 0 r
.53013 .34149 m .52961 .34177 L .5406 .33805 L p F P
0 g
s
.22 0 .221 r
.70039 .39616 m .70127 .39262 L .69348 .39735 L p F P
0 g
s
.22 0 .221 r
.70007 .3965 m .70039 .39616 L p .69348 .39735 L F P
0 g
s
.22 0 .221 r
.69084 .40208 m .70007 .3965 L p .69348 .39735 L F P
0 g
s
.22 0 .221 r
.69348 .39735 m .69152 .39941 L .69084 .40208 L p F P
0 g
s
.124 .556 .921 r
.19672 .31085 m .20211 .31354 L .19342 .31162 L p F P
0 g
s
.124 .556 .921 r
.18876 .30885 m .19672 .31085 L p .19342 .31162 L F P
0 g
s
.124 .556 .921 r
.19342 .31162 m .18942 .30931 L .18876 .30885 L p F P
0 g
s
0 0 0 r
.50183 .48945 m .50444 .48874 L .49212 .49077 L p F P
0 g
s
0 0 0 r
.49212 .49077 m .49075 .49114 L .50183 .48945 L p F P
0 g
s
.618 .057 0 r
.1949 .45574 m .19729 .45737 L .20359 .45958 L p F P
0 g
s
.583 .009 0 r
.20268 .46074 m .19729 .45737 L .20359 .45958 L p F P
0 g
s
.583 .009 0 r
.20769 .46252 m .20268 .46074 L p .20359 .45958 L F P
0 g
s
.583 .009 0 r
.20359 .45958 m .20841 .46262 L .20769 .46252 L p F P
0 g
s
.16 0 0 r
.50104 .35192 m .50205 .35115 L .49099 .3534 L p F P
0 g
s
.16 0 0 r
.49099 .3534 m .48923 .35467 L .50104 .35192 L p F P
0 g
s
.239 0 .229 r
.69152 .39941 m .68608 .4048 L .69084 .40208 L closepath p F P
0 g
s
.223 0 .174 r
.68048 .4098 m .67691 .4128 L .68006 .4111 L closepath p F P
0 g
s
.182 0 .106 r
.67873 .41442 m .68006 .4111 L .67691 .4128 L p F P
0 g
s
.182 0 .106 r
.66894 .41969 m .67873 .41442 L p .67691 .4128 L F P
0 g
s
.078 0 0 r
.6083 .4561 m .59956 .45953 L .60793 .45647 L closepath p F P
0 g
s
.015 0 0 r
.60561 .45841 m .60793 .45647 L .59956 .45953 L p F P
0 g
s
.015 0 0 r
.59894 .46099 m .60561 .45841 L p .59956 .45953 L F P
0 g
s
.015 0 0 r
.59457 .46258 m .59894 .46099 L p .59956 .45953 L F P
0 g
s
.584 .575 .809 r
.71988 .30274 m .71777 .30283 L .71497 .29712 L p F P
0 g
s
.415 .28 .588 r
.72994 .34664 m .72928 .34713 L .72709 .34267 L p F P
0 g
s
.415 .28 .588 r
.72709 .34267 m .72924 .34107 L .72994 .34664 L p F P
0 g
s
.636 .671 .866 r
.70935 .29259 m .70074 .29446 L .69801 .2904 L p F P
0 g
s
.615 .052 0 r
.1949 .45574 m .19729 .45737 L .19155 .45533 L closepath p F P
0 g
s
.202 0 .166 r
.68608 .4048 m .68048 .4098 L .68006 .4111 L p F P
0 g
s
.524 0 0 r
.35054 .36152 m .35451 .36305 L .34839 .3623 L closepath p F P
0 g
s
.632 .073 0 r
.18508 .45281 m .19105 .45514 L .18631 .45159 L p F P
0 g
s
.632 .073 0 r
.18631 .45159 m .18029 .44928 L .18508 .45281 L p F P
0 g
s
.34 0 0 r
.24452 .33141 m .24025 .32961 L .23675 .3281 L p F P
0 g
s
0 0 0 r
.56919 .47197 m .56965 .47171 L .55838 .47496 L p F P
0 g
s
0 0 0 r
.55838 .47496 m .55801 .47516 L .56919 .47197 L p F P
0 g
s
.518 0 0 r
.22155 .46826 m .21553 .46507 L .22214 .46716 L p F P
0 g
s
.518 0 0 r
.22263 .46861 m .22155 .46826 L p .22214 .46716 L F P
0 g
s
.518 0 0 r
.22214 .46716 m .22563 .469 L .22263 .46861 L p F P
0 g
s
.672 .129 0 r
.18029 .44928 m .17785 .44731 L .17417 .44682 L p F P
0 g
s
.202 0 .166 r
.68971 .40559 m .69084 .40208 L .68608 .4048 L p F P
0 g
s
.202 0 .166 r
.68006 .4111 m .68971 .40559 L p .68608 .4048 L F P
0 g
s
0 0 0 r
.52843 .48391 m .52997 .4833 L .51885 .48554 L p F P
0 g
s
0 0 0 r
.51885 .48554 m .51653 .48645 L .52843 .48391 L p F P
0 g
s
.05 0 0 r
.51653 .48645 m .51885 .48554 L p .50481 .4886 L F P
0 g
s
.79 .314 .102 r
.14039 .42531 m .14061 .42561 L .14606 .42815 L p F P
0 g
s
.757 .254 .017 r
.14403 .42951 m .14945 .43206 L .14606 .42815 L p F P
0 g
s
.757 .254 .017 r
.14606 .42815 m .14061 .42561 L .14403 .42951 L p F P
0 g
s
.253 .633 .961 r
.17508 .30485 m .18319 .30606 L .18841 .30881 L p F P
0 g
s
.238 .619 .956 r
.18319 .30606 m .17508 .30485 L .17155 .3021 L p F P
0 g
s
.813 .749 .792 r
.0732 .3077 m .0772 .31074 L .08424 .30346 L p F P
0 g
s
.813 .749 .792 r
.07307 .30756 m .0732 .3077 L p .08424 .30346 L F P
0 g
s
.813 .749 .792 r
.08424 .30346 m .08017 .30026 L .07307 .30756 L p F P
0 g
s
.796 .752 .812 r
.08424 .30346 m .08781 .30023 L .08422 .29664 L p F P
0 g
s
.796 .752 .812 r
.08422 .29664 m .08017 .30026 L .08424 .30346 L p F P
0 g
s
.689 .913 .972 r
.63207 .30345 m .63067 .30281 L .63852 .29918 L closepath p F P
0 g
s
.065 0 0 r
.40851 .49822 m .40635 .49835 L .39955 .49823 L closepath p F P
0 g
s
.048 0 0 r
.4033 .49851 m .40635 .49835 L .39955 .49823 L p F P
0 g
s
.048 0 0 r
.40261 .4985 m .4033 .49851 L p .39955 .49823 L F P
0 g
s
.048 0 0 r
.3923 .49829 m .40261 .4985 L p .39955 .49823 L F P
0 g
s
.048 0 0 r
.39955 .49823 m .39421 .49822 L .3923 .49829 L p F P
0 g
s
.029 0 0 r
.4131 .49813 m .40851 .49822 L .40635 .49835 L p F P
0 g
s
.758 .751 .846 r
.09622 .29445 m .08781 .30023 L .08422 .29664 L p F P
0 g
s
.087 0 0 r
.39421 .49822 m .3923 .49829 L .38694 .49805 L closepath p F P
0 g
s
.688 .827 .95 r
.66988 .2918 m .66032 .29561 L .66796 .29012 L closepath p F P
0 g
s
.683 .851 .963 r
.66718 .28944 m .66796 .29012 L .66032 .29561 L p F P
0 g
s
.683 .851 .963 r
.65589 .29426 m .66718 .28944 L p .66032 .29561 L F P
0 g
s
.357 0 0 r
.27043 .48303 m .26394 .48086 L .27155 .4826 L p F P
0 g
s
.357 0 0 r
.27155 .4826 m .27392 .48339 L .27043 .48303 L p F P
0 g
s
0 .471 .843 r
.20593 .31583 m .20729 .31628 L .2126 .31897 L p F P
0 g
s
0 .505 .856 r
.21479 .31863 m .20729 .31628 L .2126 .31897 L p F P
0 g
s
0 .505 .856 r
.21809 .32011 m .21479 .31863 L p .2126 .31897 L F P
0 g
s
0 .505 .856 r
.2126 .31897 m .21958 .32092 L .21809 .32011 L p F P
0 g
s
.044 0 0 r
.42247 .49789 m .4204 .49806 L .4131 .49813 L closepath p F P
0 g
s
.029 0 0 r
.41742 .49828 m .4204 .49806 L .4131 .49813 L p F P
0 g
s
.029 0 0 r
.41654 .4983 m .41742 .49828 L p .4131 .49813 L F P
0 g
s
.029 0 0 r
.40635 .49835 m .41654 .4983 L p .4131 .49813 L F P
0 g
s
.449 0 0 r
.24367 .47474 m .24287 .47464 L .24208 .4743 L closepath p F P
0 g
s
.467 0 0 r
.40879 .36555 m .40653 .36706 L .39951 .36559 L closepath p F P
0 g
s
.46 0 0 r
.40578 .36763 m .40653 .36706 L .39951 .36559 L p F P
0 g
s
.46 0 0 r
.39567 .3676 m .40578 .36763 L p .39951 .36559 L F P
0 g
s
.46 0 0 r
.39248 .36678 m .39567 .3676 L p .39951 .36559 L F P
0 g
s
.46 0 0 r
.39951 .36559 m .3945 .36556 L .39248 .36678 L p F P
0 g
s
.069 0 0 r
.38906 .49838 m .3923 .49829 L .38694 .49805 L p F P
0 g
s
.069 0 0 r
.37827 .49788 m .38906 .49838 L p .38694 .49805 L F P
0 g
s
.069 0 0 r
.38694 .49805 m .37955 .49786 L .37827 .49788 L p F P
0 g
s
0 0 0 r
.54112 .48075 m .54369 .4797 L .53202 .48247 L p F P
0 g
s
0 0 0 r
.53202 .48247 m .52997 .4833 L .54112 .48075 L p F P
0 g
s
.486 0 0 r
.3945 .36556 m .39248 .36678 L .38701 .36536 L closepath p F P
0 g
s
.068 0 0 r
.51315 .34837 m .51538 .34688 L .50388 .34997 L p F P
0 g
s
.068 0 0 r
.50388 .34997 m .50205 .35115 L .51315 .34837 L p F P
0 g
s
.434 0 0 r
.41323 .36542 m .40879 .36555 L .40653 .36706 L p F P
0 g
s
.101 0 0 r
.66697 .42357 m .66741 .42283 L .65746 .42786 L p F P
0 g
s
.101 0 0 r
.65746 .42786 m .65577 .43078 L .66697 .42357 L p F P
0 g
s
.546 0 0 r
.31938 .35555 m .32066 .35614 L .32908 .35772 L p F P
0 g
s
.522 0 0 r
.32697 .35908 m .32066 .35614 L .32908 .35772 L p F P
0 g
s
.522 0 0 r
.33163 .35984 m .32697 .35908 L p .32908 .35772 L F P
0 g
s
.522 0 0 r
.32908 .35772 m .33324 .35939 L .33163 .35984 L p F P
0 g
s
.075 0 0 r
.64563 .43562 m .64456 .43716 L .6555 .43094 L closepath p F P
0 g
s
.515 0 0 r
.28834 .34673 m .29081 .34793 L .29821 .34985 L p F P
0 g
s
.49 0 0 r
.28834 .34673 m .29081 .34793 L .28592 .3465 L closepath p F P
0 g
s
.482 0 0 r
.29697 .35087 m .29081 .34793 L .29821 .34985 L p F P
0 g
s
.482 0 0 r
.30001 .35158 m .29697 .35087 L p .29821 .34985 L F P
0 g
s
.482 0 0 r
.29821 .34985 m .30211 .3515 L .30001 .35158 L p F P
0 g
s
.44 0 0 r
.42264 .36509 m .4206 .36655 L .41323 .36542 L closepath p F P
0 g
s
.434 0 0 r
.41974 .36725 m .4206 .36655 L .41323 .36542 L p F P
0 g
s
.434 0 0 r
.40905 .36755 m .41974 .36725 L p .41323 .36542 L F P
0 g
s
.434 0 0 r
.40653 .36706 m .40905 .36755 L p .41323 .36542 L F P
0 g
s
.009 0 0 r
.42786 .49765 m .42247 .49789 L .4204 .49806 L p F P
0 g
s
.814 .351 .125 r
.12217 .41362 m .1273 .41629 L .12471 .41216 L p F P
0 g
s
.814 .351 .125 r
.12007 .41027 m .12217 .41362 L p .12471 .41216 L F P
0 g
s
.814 .351 .125 r
.12471 .41216 m .1215 .4105 L .12007 .41027 L p F P
0 g
s
.108 0 0 r
.37955 .49786 m .37827 .49788 L .37505 .49765 L closepath p F P
0 g
s
.479 0 0 r
.39136 .36754 m .39248 .36678 L .38701 .36536 L p F P
0 g
s
.479 0 0 r
.38344 .36728 m .39136 .36754 L p .38701 .36536 L F P
0 g
s
.479 0 0 r
.37846 .36572 m .38344 .36728 L p .38701 .36536 L F P
0 g
s
.479 0 0 r
.38701 .36536 m .37972 .36506 L .37846 .36572 L p F P
0 g
s
0 .375 .731 r
.22309 .32282 m .22583 .32387 L .23156 .3264 L p F P
0 g
s
0 .418 .756 r
.23285 .32642 m .22583 .32387 L .23156 .3264 L p F P
0 g
s
0 .418 .756 r
.23376 .32678 m .23285 .32642 L p .23156 .3264 L F P
0 g
s
0 .418 .756 r
.23156 .3264 m .23675 .3281 L .23376 .32678 L p F P
0 g
s
.492 .427 .712 r
.72849 .31858 m .73351 .31447 L .73538 .32114 L closepath p F P
0 g
s
.236 0 .277 r
.71132 .38292 m .71136 .38271 L .70201 .3887 L p F P
0 g
s
.236 0 .277 r
.70634 .38938 m .71132 .38292 L p .70201 .3887 L F P
0 g
s
.236 0 .277 r
.70201 .3887 m .70127 .39262 L .70634 .38938 L p F P
0 g
s
.691 .154 0 r
.1686 .44452 m .16439 .44083 L .17013 .44325 L p F P
0 g
s
.691 .154 0 r
.1739 .44678 m .1686 .44452 L p .17013 .44325 L F P
0 g
s
.691 .154 0 r
.17013 .44325 m .17417 .44682 L .1739 .44678 L p F P
0 g
s
.877 .714 .677 r
.06652 .32898 m .07072 .3321 L .07335 .32634 L p F P
0 g
s
.877 .714 .677 r
.07335 .32634 m .06917 .32321 L .06652 .32898 L p F P
0 g
s
.828 .742 .769 r
.0772 .31074 m .0732 .3077 L .07665 .31139 L closepath p F P
0 g
s
.187 0 0 r
.35027 .49593 m .35314 .49628 L .36373 .49708 L p F P
0 g
s
.181 0 0 r
.35027 .49593 m .35314 .49628 L .34894 .49595 L closepath p F P
0 g
s
.268 0 0 r
.30544 .48995 m .30508 .48993 L .30455 .4898 L closepath p F P
0 g
s
.289 .771 .678 r
.56507 .32832 m .5664 .32786 L .55525 .33239 L p F P
0 g
s
.289 .771 .678 r
.55525 .33239 m .55455 .33265 L .56507 .32832 L p F P
0 g
s
.849 .739 .742 r
.07265 .31716 m .07665 .31139 L .0732 .3077 L p F P
0 g
s
.443 0 0 r
.23932 .47415 m .23518 .47232 L .24208 .4743 L p F P
0 g
s
.443 0 0 r
.24208 .4743 m .24287 .47464 L .23932 .47415 L p F P
0 g
s
.089 0 0 r
.375 .49788 m .37827 .49788 L .37505 .49765 L p F P
0 g
s
.089 0 0 r
.36426 .49713 m .375 .49788 L p .37505 .49765 L F P
0 g
s
.089 0 0 r
.37505 .49765 m .36449 .49713 L .36426 .49713 L p F P
0 g
s
.024 0 0 r
.43612 .49724 m .43447 .49742 L .42786 .49765 L closepath p F P
0 g
s
.009 0 0 r
.43132 .49772 m .43447 .49742 L .42786 .49765 L p F P
0 g
s
.009 0 0 r
.4204 .49806 m .43132 .49772 L p .42786 .49765 L F P
0 g
s
0 0 0 r
.56647 .47344 m .56919 .47197 L .55801 .47516 L p F P
0 g
s
0 0 0 r
.55801 .47516 m .55517 .47669 L .56647 .47344 L p F P
0 g
s
.041 0 0 r
.55517 .47669 m .55801 .47516 L p .544 .47954 L F P
0 g
s
.903 .605 .471 r
.07976 .36704 m .08426 .37 L .08408 .36515 L p F P
0 g
s
.903 .605 .471 r
.08408 .36515 m .07958 .36219 L .07976 .36704 L p F P
0 g
s
0 0 0 r
.53836 .33925 m .5406 .33805 L .52961 .34177 L p F P
0 g
s
0 0 0 r
.52961 .34177 m .52722 .34307 L .53836 .33925 L p F P
0 g
s
.9 .577 .426 r
.08484 .37473 m .0894 .37766 L .08883 .37293 L p F P
0 g
s
.9 .577 .426 r
.08883 .37293 m .08426 .37 L .08484 .37473 L p F P
0 g
s
.124 0 .021 r
.67816 .4156 m .67873 .41442 L .66894 .41969 L p F P
0 g
s
.124 0 .021 r
.67051 .42117 m .67816 .4156 L p .66894 .41969 L F P
0 g
s
.124 0 .021 r
.66894 .41969 m .66741 .42283 L .67051 .42117 L p F P
0 g
s
.257 0 0 r
.30166 .48962 m .29615 .48831 L .30455 .4898 L p F P
0 g
s
.257 0 0 r
.30455 .4898 m .30508 .48993 L .30166 .48962 L p F P
0 g
s
.236 0 0 r
.47711 .35704 m .47693 .35716 L .47554 .3573 L closepath p F P
0 g
s
.247 0 0 r
.47438 .3592 m .47693 .35716 L .47554 .3573 L p F P
0 g
s
.247 0 0 r
.46999 .35991 m .47438 .3592 L p .47554 .3573 L F P
0 g
s
.247 0 0 r
.46286 .36049 m .46999 .35991 L p .47554 .3573 L F P
0 g
s
.401 0 0 r
.42867 .3647 m .42264 .36509 L .4206 .36655 L p F P
0 g
s
.584 .575 .809 r
.72689 .2968 m .71988 .30274 L p .71497 .29712 L F P
0 g
s
.558 .546 .797 r
.71988 .30274 m .72689 .2968 L .7294 .30277 L closepath p F P
0 g
s
.704 .878 .962 r
.65589 .29426 m .64462 .29916 L .64191 .29763 L p F P
0 g
s
.499 0 0 r
.37972 .36506 m .37846 .36572 L .37547 .36482 L closepath p F P
0 g
s
.046 0 0 r
.63345 .44299 m .63335 .44311 L .63455 .4425 L closepath p F P
0 g
s
.904 .632 .515 r
.07515 .35919 m .07958 .36219 L .07984 .3572 L p F P
0 g
s
.904 .632 .515 r
.07984 .3572 m .07541 .3542 L .07515 .35919 L p F P
0 g
s
.894 .547 .38 r
.09034 .38227 m .09497 .38517 L .09403 .38055 L p F P
0 g
s
.894 .547 .38 r
.09403 .38055 m .0894 .37766 L .09034 .38227 L p F P
0 g
s
0 0 0 r
.59438 .46271 m .59457 .46258 L .58365 .46627 L p F P
0 g
s
0 0 0 r
.58365 .46627 m .58317 .4666 L .59438 .46271 L p F P
0 g
s
.265 0 0 r
.25043 .33378 m .24452 .33141 L .25074 .33376 L p F P
0 g
s
.265 0 0 r
.25074 .33376 m .25393 .33491 L .25043 .33378 L p F P
0 g
s
.534 0 0 r
.31938 .35555 m .32066 .35614 L .31844 .35569 L closepath p F P
0 g
s
0 .351 .721 r
.22583 .32387 m .22309 .32282 L .21958 .32092 L p F P
0 g
s
.196 0 0 r
.48797 .3556 m .48923 .35467 L .47711 .35704 L p F P
0 g
s
.196 0 0 r
.47711 .35704 m .47693 .35716 L .48797 .3556 L p F P
0 g
s
.526 .001 0 r
.36448 .36392 m .36476 .36401 L .37547 .36482 L p F P
0 g
s
.507 0 0 r
.37213 .36665 m .36476 .36401 L .37547 .36482 L p F P
0 g
s
.507 0 0 r
.37642 .36693 m .37213 .36665 L p .37547 .36482 L F P
0 g
s
.507 0 0 r
.37547 .36482 m .37846 .36572 L .37642 .36693 L p F P
0 g
s
.043 0 0 r
.63455 .4425 m .63335 .44311 L .6313 .44556 L p F P
0 g
s
.22 0 0 r
.31454 .49188 m .30508 .48993 L .30166 .48962 L p F P
0 g
s
0 0 0 r
.44423 .49669 m .43612 .49724 L .43447 .49742 L p F P
0 g
s
.407 0 0 r
.4361 .36421 m .43468 .36526 L .42867 .3647 L closepath p F P
0 g
s
.401 0 0 r
.4333 .36643 m .43468 .36526 L .42867 .3647 L p F P
0 g
s
.401 0 0 r
.42403 .36699 m .4333 .36643 L p .42867 .3647 L F P
0 g
s
.401 0 0 r
.4206 .36655 m .42403 .36699 L p .42867 .3647 L F P
0 g
s
.486 .901 .837 r
.58887 .31774 m .59155 .31748 L .58037 .3225 L p F P
0 g
s
.486 .901 .837 r
.58037 .3225 m .57885 .32276 L .58887 .31774 L p F P
0 g
s
.355 0 0 r
.27173 .34128 m .27113 .34116 L .27051 .34093 L closepath p F P
0 g
s
.902 .657 .559 r
.07104 .35117 m .07541 .3542 L .07615 .34906 L p F P
0 g
s
.902 .657 .559 r
.07615 .34906 m .07179 .34603 L .07104 .35117 L p F P
0 g
s
.05 0 0 r
.50481 .4886 m .50879 .48792 L .51653 .48645 L p F P
0 g
s
.015 0 0 r
.50481 .4886 m .50879 .48792 L .50444 .48874 L closepath p F P
0 g
s
.884 .511 .33 r
.09626 .38969 m .09497 .38517 L .09967 .38803 L p F P
0 g
s
.884 .511 .33 r
.09663 .38991 m .09626 .38969 L p .09967 .38803 L F P
0 g
s
.884 .511 .33 r
.09967 .38803 m .10023 .38996 L .09663 .38991 L p F P
0 g
s
.746 .755 .86 r
.09622 .29445 m .09857 .29296 L .09498 .28948 L p F P
0 g
s
.746 .755 .86 r
.09498 .28948 m .09219 .29123 L .09622 .29445 L p F P
0 g
s
.758 .751 .846 r
.08422 .29664 m .09219 .29123 L .09622 .29445 L p F P
0 g
s
.413 0 0 r
.24921 .47719 m .24287 .47464 L .23932 .47415 L p F P
0 g
s
.131 0 0 r
.36449 .49713 m .36426 .49713 L .36373 .49708 L closepath p F P
0 g
s
.64 .745 .925 r
.11269 .29152 m .12309 .28839 L .12666 .29168 L p F P
0 g
s
.636 .743 .926 r
.12309 .28839 m .11269 .29152 L .10911 .28813 L p F P
0 g
s
.7 .753 .893 r
.09857 .29296 m .10911 .28813 L .11269 .29152 L p F P
0 g
s
.116 0 0 r
.36096 .49703 m .35314 .49628 L .36373 .49708 L p F P
0 g
s
.116 0 0 r
.36373 .49708 m .36426 .49713 L .36096 .49703 L p F P
0 g
s
.099 0 0 r
.64456 .43716 m .63455 .4425 L .6437 .43839 L closepath p F P
0 g
s
.043 0 0 r
.642 .44043 m .6437 .43839 L .63455 .4425 L p F P
0 g
s
.043 0 0 r
.63703 .44301 m .642 .44043 L p .63455 .4425 L F P
0 g
s
.043 0 0 r
.6313 .44556 m .63703 .44301 L p .63455 .4425 L F P
0 g
s
.33 .126 .445 r
.72138 .36793 m .71811 .37018 L .71978 .36449 L p F P
0 g
s
.33 .126 .445 r
.71978 .36449 m .72149 .36331 L .72138 .36793 L p F P
0 g
s
.248 0 0 r
.48654 .35684 m .48797 .3556 L .47693 .35716 L p F P
0 g
s
.248 0 0 r
.47693 .35716 m .47438 .3592 L .48654 .35684 L p F P
0 g
s
.527 .489 .757 r
.72655 .30991 m .73079 .30639 L .73232 .31077 L closepath p F P
0 g
s
.379 .674 .974 r
.15783 .29872 m .16294 .29906 L .16772 .30197 L p F P
0 g
s
.367 .664 .971 r
.16294 .29906 m .15783 .29872 L .15429 .29574 L p F P
0 g
s
.4 .27 .586 r
.73806 .34027 m .72994 .34664 L .72924 .34107 L p F P
0 g
s
.4 .27 .586 r
.72924 .34107 m .73598 .33576 L .73806 .34027 L p F P
0 g
s
.734 .217 0 r
.15312 .4359 m .14945 .43206 L .15494 .43458 L p F P
0 g
s
.734 .217 0 r
.15423 .43642 m .15312 .4359 L p .15494 .43458 L F P
0 g
s
.734 .217 0 r
.15494 .43458 m .1572 .43693 L .15423 .43642 L p F P
0 g
s
.801 .326 .093 r
.13018 .42035 m .13535 .423 L .13249 .41894 L p F P
0 g
s
.801 .326 .093 r
.13249 .41894 m .1273 .41629 L .13018 .42035 L p F P
0 g
s
.404 .689 .977 r
.168 .29932 m .16294 .29906 L .16772 .30197 L p F P
0 g
s
.404 .689 .977 r
.16772 .30197 m .17155 .3021 L .168 .29932 L p F P
0 g
s
.146 0 .085 r
.6893 .4066 m .68971 .40559 L .68006 .4111 L p F P
0 g
s
.146 0 .085 r
.68242 .41232 m .6893 .4066 L p .68006 .4111 L F P
0 g
s
.146 0 .085 r
.68006 .4111 m .67873 .41442 L .68242 .41232 L p F P
0 g
s
.358 0 0 r
.26763 .34047 m .26368 .33879 L .27051 .34093 L p F P
0 g
s
.358 0 0 r
.27051 .34093 m .27113 .34116 L .26763 .34047 L p F P
0 g
s
.083 0 0 r
.375 .49788 m .36426 .49713 L .36096 .49703 L p F P
0 g
s
.578 .94 .912 r
.59284 .31748 m .59155 .31748 L .6019 .31259 L closepath p F P
0 g
s
.64 .949 .947 r
.61671 .30718 m .60551 .31243 L .60275 .31219 L p F P
0 g
s
.697 .753 .895 r
.10911 .28813 m .09857 .29296 L .09498 .28948 L p F P
0 g
s
.519 0 0 r
.36448 .36392 m .36476 .36401 L .36435 .36398 L closepath p F P
0 g
s
.361 0 0 r
.44672 .36314 m .4361 .36421 L .43468 .36526 L p F P
0 g
s
.013 0 0 r
.63076 .44611 m .6313 .44556 L .62088 .44992 L p F P
0 g
s
.013 0 0 r
.62088 .44992 m .61952 .4513 L .63076 .44611 L p F P
0 g
s
.004 0 0 r
.44948 .49631 m .44854 .49643 L .44423 .49669 L closepath p F P
0 g
s
0 0 0 r
.44542 .49678 m .44854 .49643 L .44423 .49669 L p F P
0 g
s
0 0 0 r
.43447 .49742 m .44542 .49678 L p .44423 .49669 L F P
0 g
s
.866 .462 .263 r
.10282 .39689 m .10766 .39969 L .1059 .39531 L p F P
0 g
s
.866 .462 .263 r
.1059 .39531 m .10104 .39252 L .10282 .39689 L p F P
0 g
s
.323 0 0 r
.27985 .48516 m .27392 .48339 L .27043 .48303 L p F P
0 g
s
.897 .68 .6 r
.0675 .34295 m .07179 .34603 L .07308 .34071 L p F P
0 g
s
.897 .68 .6 r
.07308 .34071 m .0688 .33763 L .0675 .34295 L p F P
0 g
s
0 .48 .858 r
.20593 .31583 m .20729 .31628 L .20294 .31393 L closepath p F P
0 g
s
.584 .575 .809 r
.71497 .29712 m .72656 .29606 L .72689 .2968 L p F P
0 g
s
.6 .601 .824 r
.72656 .29606 m .71497 .29712 L .71221 .29201 L p F P
0 g
s
.568 .73 .951 r
.12666 .29168 m .13399 .29048 L .1386 .29348 L p F P
0 g
s
.562 .726 .951 r
.13399 .29048 m .12666 .29168 L .12309 .28839 L p F P
0 g
s
.527 0 0 r
.36161 .36577 m .37213 .36665 L .36476 .36401 L p F P
0 g
s
.527 0 0 r
.36112 .36556 m .36161 .36577 L p .36476 .36401 L F P
0 g
s
.527 0 0 r
.36476 .36401 m .36435 .36398 L .36112 .36556 L p F P
0 g
s
.023 0 0 r
.52663 .34346 m .52722 .34307 L .51611 .3464 L p F P
0 g
s
.023 0 0 r
.51611 .3464 m .51538 .34688 L .52663 .34346 L p F P
0 g
s
.537 .011 0 r
.36435 .36398 m .36112 .36556 L .35451 .36305 L closepath p F P
0 g
s
0 0 0 r
.50879 .48792 m .50444 .48874 L .50183 .48945 L p F P
0 g
s
.849 .739 .742 r
.06856 .31398 m .07265 .31716 L p .0732 .3077 L F P
0 g
s
.865 .73 .712 r
.06506 .32004 m .06917 .32321 L .07265 .31716 L p F P
0 g
s
.865 .73 .712 r
.07265 .31716 m .06856 .31398 L .06506 .32004 L p F P
0 g
s
.547 0 0 r
.31857 .35749 m .32697 .35908 L .32066 .35614 L p F P
0 g
s
.547 0 0 r
.31594 .3561 m .31857 .35749 L p .32066 .35614 L F P
0 g
s
.547 0 0 r
.32066 .35614 m .31844 .35569 L .31594 .3561 L p F P
0 g
s
0 0 0 r
.5917 .46454 m .59438 .46271 L .58317 .4666 L p F P
0 g
s
0 0 0 r
.58317 .4666 m .58076 .46824 L .5917 .46454 L p F P
0 g
s
.295 .657 .971 r
.18942 .30931 m .18876 .30885 L .18841 .30881 L closepath p F P
0 g
s
.317 0 0 r
.26918 .48288 m .27043 .48303 L .26394 .48086 L p F P
0 g
s
.317 0 0 r
.26439 .48172 m .26918 .48288 L p .26394 .48086 L F P
0 g
s
.317 0 0 r
.25661 .47917 m .26439 .48172 L p .26394 .48086 L F P
0 g
s
.317 0 0 r
.26394 .48086 m .25683 .4792 L .25661 .47917 L p F P
0 g
s
.524 0 0 r
.27657 .34387 m .27113 .34116 L .26763 .34047 L p F P
0 g
s
.292 .772 .676 r
.56357 .32884 m .56507 .32832 L .55455 .33265 L p F P
0 g
s
.539 0 0 r
.19649 .45849 m .20268 .46074 L .19729 .45737 L p F P
0 g
s
.539 0 0 r
.19125 .45527 m .19649 .45849 L p .19729 .45737 L F P
0 g
s
.539 0 0 r
.19729 .45737 m .19155 .45533 L .19125 .45527 L p F P
0 g
s
0 0 0 r
.50039 .48982 m .50183 .48945 L .49075 .49114 L p F P
0 g
s
0 0 0 r
.49075 .49114 m .48803 .49185 L .50039 .48982 L p F P
0 g
s
0 0 0 r
.45953 .49549 m .46259 .49511 L .44948 .49631 L p F P
0 g
s
0 0 0 r
.44948 .49631 m .44854 .49643 L .45953 .49549 L p F P
0 g
s
.044 0 0 r
.61851 .45231 m .61952 .4513 L .6083 .4561 L p F P
0 g
s
.044 0 0 r
.6083 .4561 m .60793 .45647 L .61851 .45231 L p F P
0 g
s
.831 .382 .159 r
.1215 .4105 m .12007 .41027 L .11961 .40948 L closepath p F P
0 g
s
.092 0 0 r
.35863 .49695 m .36096 .49703 L .35314 .49628 L p F P
0 g
s
.092 0 0 r
.35554 .4967 m .35863 .49695 L p .35314 .49628 L F P
0 g
s
.092 0 0 r
.34694 .49585 m .35554 .4967 L p .35314 .49628 L F P
0 g
s
.092 0 0 r
.35314 .49628 m .34894 .49595 L .34694 .49585 L p F P
0 g
s
.559 0 0 r
.20841 .46262 m .20898 .46295 L .21553 .46507 L p F P
0 g
s
.501 0 0 r
.21507 .46612 m .22155 .46826 L .21553 .46507 L p F P
0 g
s
.501 0 0 r
.21553 .46507 m .20898 .46295 L .21507 .46612 L p F P
0 g
s
.579 .734 .949 r
.13695 .28998 m .13399 .29048 L .1386 .29348 L p F P
0 g
s
.579 .734 .949 r
.1386 .29348 m .14052 .29314 L .13695 .28998 L p F P
0 g
s
.51 0 0 r
.28953 .34895 m .29697 .35087 L .29081 .34793 L p F P
0 g
s
.51 0 0 r
.28486 .34642 m .28953 .34895 L p .29081 .34793 L F P
0 g
s
.51 0 0 r
.29081 .34793 m .28592 .3465 L .28486 .34642 L p F P
0 g
s
.225 0 0 r
.29894 .48936 m .30166 .48962 L .29615 .48831 L p F P
0 g
s
.225 0 0 r
.29723 .48904 m .29894 .48936 L p .29615 .48831 L F P
0 g
s
.225 0 0 r
.28776 .48682 m .29723 .48904 L p .29615 .48831 L F P
0 g
s
.225 0 0 r
.29615 .48831 m .28777 .48682 L .28776 .48682 L p F P
0 g
s
.672 .929 .971 r
.63852 .29918 m .63067 .30281 L .62794 .30184 L p F P
0 g
s
.79 .312 .091 r
.14039 .42531 m .14061 .42561 L .13987 .42525 L closepath p F P
0 g
s
.672 .129 0 r
.17417 .44682 m .17433 .44695 L .18029 .44928 L p F P
0 g
s
.621 .057 0 r
.17917 .45046 m .18508 .45281 L .18029 .44928 L p F P
0 g
s
.621 .057 0 r
.18029 .44928 m .17433 .44695 L .17917 .45046 L p F P
0 g
s
.527 0 0 r
.31844 .35569 m .31594 .3561 L .31239 .35452 L closepath p F P
0 g
s
.062 0 0 r
.38906 .49838 m .37827 .49788 L .375 .49788 L p F P
0 g
s
.853 .427 .214 r
.10975 .40397 m .11465 .40674 L .11257 .40245 L p F P
0 g
s
.853 .427 .214 r
.11257 .40245 m .10766 .39969 L .10975 .40397 L p F P
0 g
s
.663 .727 .897 r
.68392 .29045 m .6953 .28673 L .69801 .2904 L p F P
0 g
s
.675 .754 .91 r
.6953 .28673 m .68392 .29045 L .68122 .28748 L p F P
0 g
s
.684 .78 .924 r
.66988 .2918 m .68122 .28748 L .68392 .29045 L p F P
0 g
s
.299 .657 .971 r
.18522 .30634 m .18319 .30606 L .18841 .30881 L p F P
0 g
s
.299 .657 .971 r
.18841 .30881 m .18876 .30885 L .18522 .30634 L p F P
0 g
s
.137 0 0 r
.34894 .49595 m .34694 .49585 L .34295 .49535 L closepath p F P
0 g
s
.311 .112 .44 r
.72817 .36299 m .72138 .36793 L .72149 .36331 L p F P
0 g
s
.311 .112 .44 r
.72149 .36331 m .72969 .35734 L .72817 .36299 L p F P
0 g
s
.889 .7 .641 r
.06458 .33451 m .0688 .33763 L .07072 .3321 L p F P
0 g
s
.889 .7 .641 r
.07072 .3321 m .06652 .32898 L .06458 .33451 L p F P
0 g
s
.041 0 0 r
.544 .47954 m .555 .47674 L .55517 .47669 L p F P
0 g
s
0 0 0 r
.544 .47954 m .555 .47674 L .54369 .4797 L closepath p F P
0 g
s
.88 .501 .319 r
.10023 .38996 m .10104 .39252 L .09663 .38991 L closepath p F P
0 g
s
.747 .235 0 r
.13868 .42693 m .14403 .42951 L .14061 .42561 L p F P
0 g
s
.747 .235 0 r
.13664 .42458 m .13868 .42693 L p .14061 .42561 L F P
0 g
s
.747 .235 0 r
.14061 .42561 m .13987 .42525 L .13664 .42458 L p F P
0 g
s
.067 .531 .897 r
.19672 .31085 m .18876 .30885 L .18522 .30634 L p F P
0 g
s
.692 .828 .948 r
.67852 .2848 m .68122 .28748 L .66988 .2918 L p F P
0 g
s
.692 .828 .948 r
.67057 .28806 m .67852 .2848 L p .66988 .2918 L F P
0 g
s
.692 .828 .948 r
.66988 .2918 m .66796 .29012 L .67057 .28806 L p F P
0 g
s
.212 0 0 r
.33292 .49433 m .33295 .49433 L p .319 .49229 L F P
0 g
s
.212 0 0 r
.319 .49229 m .32373 .49313 L .33292 .49433 L p F P
0 g
s
.21 0 0 r
.319 .49229 m .32373 .49313 L .31627 .49215 L closepath p F P
0 g
s
.364 0 0 r
.44918 .3629 m .44877 .3632 L .44672 .36314 L closepath p F P
0 g
s
.361 0 0 r
.44647 .36518 m .44877 .3632 L .44672 .36314 L p F P
0 g
s
.361 0 0 r
.44142 .36565 m .44647 .36518 L p .44672 .36314 L F P
0 g
s
.361 0 0 r
.43468 .36526 m .44142 .36565 L p .44672 .36314 L F P
0 g
s
.301 0 0 r
.46286 .36049 m .46999 .35991 L .46195 .36125 L closepath p F P
0 g
s
0 0 0 r
.51653 .48645 m .5159 .48663 L .50879 .48792 L closepath p F P
0 g
s
0 0 0 r
.51294 .48747 m .5159 .48663 L .50879 .48792 L p F P
0 g
s
0 0 0 r
.50183 .48945 m .51294 .48747 L p .50879 .48792 L F P
0 g
s
.444 0 0 r
.23506 .4733 m .22832 .47031 L .23518 .47232 L p F P
0 g
s
.444 0 0 r
.23653 .47374 m .23506 .4733 L p .23518 .47232 L F P
0 g
s
.444 0 0 r
.23518 .47232 m .23932 .47415 L .23653 .47374 L p F P
0 g
s
.491 0 0 r
.22563 .469 m .22832 .47031 L .23518 .47232 L p F P
0 g
s
0 .457 .839 r
.20926 .316 m .21479 .31863 L .20729 .31628 L p F P
0 g
s
0 .457 .839 r
.20241 .3136 m .20926 .316 L p .20729 .31628 L F P
0 g
s
0 .457 .839 r
.20729 .31628 m .20294 .31393 L .20241 .3136 L p F P
0 g
s
.486 0 0 r
.22563 .469 m .22832 .47031 L .22263 .46861 L closepath p F P
0 g
s
.169 0 .15 r
.69209 .40415 m .68971 .40559 L .69084 .40208 L p F P
0 g
s
.169 0 .15 r
.69084 .40208 m .70007 .3965 L .69209 .40415 L p F P
0 g
s
.649 .698 .882 r
.70947 .28748 m .69801 .2904 L .6953 .28673 L p F P
0 g
s
.636 .671 .866 r
.7115 .29081 m .70935 .29259 L p .69801 .2904 L F P
0 g
s
.636 .671 .866 r
.69801 .2904 m .70947 .28748 L .7115 .29081 L p F P
0 g
s
.534 0 0 r
.36087 .3657 m .36112 .36556 L .35451 .36305 L p F P
0 g
s
.534 0 0 r
.35154 .36473 m .36087 .3657 L p .35451 .36305 L F P
0 g
s
.534 0 0 r
.34716 .36277 m .35154 .36473 L p .35451 .36305 L F P
0 g
s
.534 0 0 r
.35451 .36305 m .34839 .3623 L .34716 .36277 L p F P
0 g
s
0 0 0 r
.47669 .49329 m .48558 .4922 L .47541 .49359 L closepath p F P
0 g
s
.04 0 0 r
.47541 .49359 m .47669 .49329 L p .46262 .4951 L F P
0 g
s
.259 .012 .337 r
.71157 .38257 m .71136 .38271 L .71188 .37857 L p F P
0 g
s
.259 .012 .337 r
.71188 .37857 m .71535 .37621 L .71157 .38257 L p F P
0 g
s
.431 .322 .629 r
.73802 .33414 m .73598 .33576 L .73248 .33172 L p F P
0 g
s
.431 .322 .629 r
.73248 .33172 m .73696 .32814 L .73802 .33414 L p F P
0 g
s
.336 0 0 r
.45975 .3631 m .46195 .36125 L .44918 .3629 L p F P
0 g
s
.336 0 0 r
.44918 .3629 m .44877 .3632 L .45975 .3631 L p F P
0 g
s
0 .351 .721 r
.21958 .32092 m .22035 .32124 L .22583 .32387 L p F P
0 g
s
0 .36 .73 r
.22693 .32394 m .23285 .32642 L .22583 .32387 L p F P
0 g
s
0 .36 .73 r
.22583 .32387 m .22035 .32124 L .22693 .32394 L p F P
0 g
s
.043 0 0 r
.40261 .4985 m .3923 .49829 L .38906 .49838 L p F P
0 g
s
0 0 0 r
.61686 .45368 m .61851 .45231 L .60793 .45647 L p F P
0 g
s
0 0 0 r
.60793 .45647 m .60561 .45841 L .61686 .45368 L p F P
0 g
s
.479 .707 .969 r
.14052 .29314 m .15073 .29273 L .15429 .29574 L p F P
0 g
s
.472 .702 .969 r
.15073 .29273 m .14052 .29314 L .13695 .28998 L p F P
0 g
s
.774 .277 .028 r
.13987 .42525 m .13664 .42458 L .13535 .423 L closepath p F P
0 g
s
.514 0 0 r
.37846 .36572 m .38344 .36728 L .37642 .36693 L closepath p F P
0 g
s
.679 .134 0 r
.16296 .44206 m .1686 .44452 L .16439 .44083 L p F P
0 g
s
.679 .134 0 r
.16439 .44083 m .15871 .43839 L .16296 .44206 L p F P
0 g
s
.718 .194 0 r
.1572 .43693 m .15871 .43839 L .16439 .44083 L p F P
0 g
s
.619 .656 .865 r
.70935 .29259 m .7115 .29081 L .71221 .29201 L closepath p F P
0 g
s
0 0 0 r
.55136 .33401 m .5524 .33348 L .54125 .3377 L p F P
0 g
s
0 0 0 r
.54125 .3377 m .5406 .33805 L .55136 .33401 L p F P
0 g
s
.381 .225 .542 r
.73035 .35185 m .7301 .35204 L .72928 .34713 L p F P
0 g
s
.381 .225 .542 r
.72928 .34713 m .72994 .34664 L .73035 .35185 L p F P
0 g
s
.131 0 0 r
.3436 .49565 m .33302 .49434 L .34295 .49535 L p F P
0 g
s
.131 0 0 r
.34295 .49535 m .34694 .49585 L .3436 .49565 L p F P
0 g
s
.2 0 0 r
.33295 .49433 m .33302 .49434 L .34295 .49535 L p F P
0 g
s
.796 .754 .815 r
.08017 .30026 m .08422 .29664 L .08061 .29309 L p F P
0 g
s
.796 .754 .815 r
.08061 .29309 m .07617 .29703 L .08017 .30026 L p F P
0 g
s
.813 .748 .792 r
.06946 .30385 m .07617 .29703 L .08017 .30026 L p F P
0 g
s
.813 .748 .792 r
.08017 .30026 m .07307 .30756 L .06946 .30385 L p F P
0 g
s
.832 .381 .153 r
.11627 .40956 m .11465 .40674 L .11961 .40948 L p F P
0 g
s
.832 .381 .153 r
.11961 .40948 m .12007 .41027 L .11627 .40956 L p F P
0 g
s
0 0 0 r
.555 .47674 m .54369 .4797 L .54112 .48075 L p F P
0 g
s
.757 .753 .849 r
.09219 .29123 m .08422 .29664 L .08061 .29309 L p F P
0 g
s
.34 0 0 r
.23675 .3281 m .2386 .32895 L .24452 .33141 L p F P
0 g
s
.307 0 0 r
.24488 .33177 m .2386 .32895 L .24452 .33141 L p F P
0 g
s
.307 0 0 r
.24944 .33345 m .24488 .33177 L p .24452 .33141 L F P
0 g
s
.307 0 0 r
.24452 .33141 m .25043 .33378 L .24944 .33345 L p F P
0 g
s
.44 0 0 r
.25393 .33491 m .25723 .33652 L .26368 .33879 L p F P
0 g
s
.457 0 0 r
.25723 .33652 m .25393 .33491 L .25043 .33378 L p F P
0 g
s
.072 0 0 r
.6555 .43094 m .64456 .43716 L .6437 .43839 L p F P
0 g
s
.543 0 0 r
.30211 .3515 m .30455 .35274 L .30001 .35158 L closepath p F P
0 g
s
.04 0 0 r
.46262 .4951 m .46276 .49509 L .47541 .49359 L p F P
0 g
s
.012 0 0 r
.46262 .4951 m .46276 .49509 L .46259 .49511 L closepath p F P
0 g
s
.029 0 0 r
.52429 .34506 m .52663 .34346 L .51538 .34688 L p F P
0 g
s
.029 0 0 r
.51538 .34688 m .51315 .34837 L .52429 .34506 L p F P
0 g
s
.172 0 0 r
.49906 .35348 m .50104 .35192 L .48923 .35467 L p F P
0 g
s
.172 0 0 r
.48923 .35467 m .48797 .3556 L .49906 .35348 L p F P
0 g
s
0 0 0 r
.58039 .46844 m .58076 .46824 L .56965 .47171 L p F P
0 g
s
0 0 0 r
.56965 .47171 m .56919 .47197 L .58039 .46844 L p F P
0 g
s
.554 .007 0 r
.33324 .35939 m .33574 .36054 L .33163 .35984 L closepath p F P
0 g
s
0 0 0 r
.46276 .49509 m .46259 .49511 L .45953 .49549 L p F P
0 g
s
0 0 0 r
.47541 .49359 m .47363 .49386 L .46276 .49509 L closepath p F P
0 g
s
0 0 0 r
.47084 .49426 m .47363 .49386 L .46276 .49509 L p F P
0 g
s
0 0 0 r
.46895 .49448 m .47084 .49426 L p .46276 .49509 L F P
0 g
s
0 0 0 r
.45953 .49549 m .46895 .49448 L p .46276 .49509 L F P
0 g
s
.031 0 0 r
.40635 .49835 m .41654 .4983 L .4033 .49851 L closepath p F P
0 g
s
.291 .065 .389 r
.72105 .37229 m .71535 .37621 L .71811 .37018 L p F P
0 g
s
.291 .065 .389 r
.71811 .37018 m .72138 .36793 L .72105 .37229 L p F P
0 g
s
.837 .744 .761 r
.07307 .30756 m .07305 .30758 L .0732 .3077 L closepath p F P
0 g
s
.849 .739 .742 r
.0732 .3077 m .07305 .30758 L .06856 .31398 L p F P
0 g
s
.531 0 0 r
.31052 .35577 m .30455 .35274 L .31239 .35452 L p F P
0 g
s
.531 0 0 r
.31392 .35647 m .31052 .35577 L p .31239 .35452 L F P
0 g
s
.531 0 0 r
.31239 .35452 m .31594 .3561 L .31392 .35647 L p F P
0 g
s
.536 0 0 r
.34839 .3623 m .34716 .36277 L .34491 .36187 L closepath p F P
0 g
s
.365 .213 .539 r
.73886 .3452 m .73035 .35185 L .72994 .34664 L p F P
0 g
s
.365 .213 .539 r
.72994 .34664 m .73806 .34027 L .73886 .3452 L p F P
0 g
s
.879 .718 .678 r
.06239 .32582 m .06652 .32898 L .06917 .32321 L p F P
0 g
s
.879 .718 .678 r
.06917 .32321 m .06506 .32004 L .06239 .32582 L p F P
0 g
s
.706 .857 .954 r
.66718 .28944 m .65589 .29426 L .65318 .29249 L p F P
0 g
s
.704 .878 .962 r
.64191 .29763 m .65318 .29249 L .65589 .29426 L p F P
0 g
s
.837 .747 .764 r
.07305 .30758 m .07307 .30756 L .06946 .30385 L p F P
0 g
s
.837 .747 .764 r
.06946 .30385 m .06906 .30434 L .07305 .30758 L p F P
0 g
s
.85 .742 .744 r
.06455 .31076 m .06856 .31398 L .07305 .30758 L p F P
0 g
s
.85 .742 .744 r
.07305 .30758 m .06906 .30434 L .06455 .31076 L p F P
0 g
s
.397 0 0 r
.26339 .33943 m .25723 .33652 L .26368 .33879 L p F P
0 g
s
.397 0 0 r
.26492 .33992 m .26339 .33943 L p .26368 .33879 L F P
0 g
s
.397 0 0 r
.26368 .33879 m .26763 .34047 L .26492 .33992 L p F P
0 g
s
0 0 0 r
.45953 .49549 m .44854 .49643 L .44542 .49678 L p F P
0 g
s
.238 .619 .956 r
.17155 .3021 m .17817 .30324 L .18319 .30606 L p F P
0 g
s
.225 .605 .951 r
.17817 .30324 m .17155 .3021 L .168 .29932 L p F P
0 g
s
.36 .82 .723 r
.57533 .32362 m .57757 .32297 L .5664 .32786 L p F P
0 g
s
.36 .82 .723 r
.5664 .32786 m .56507 .32832 L .57533 .32362 L p F P
0 g
s
.904 .579 .422 r
.08033 .37177 m .08484 .37473 L .08426 .37 L p F P
0 g
s
.904 .579 .422 r
.08426 .37 m .07976 .36704 L .08033 .37177 L p F P
0 g
s
.907 .608 .468 r
.07532 .36404 m .07976 .36704 L .07958 .36219 L p F P
0 g
s
.907 .608 .468 r
.07958 .36219 m .07515 .35919 L .07532 .36404 L p F P
0 g
s
.071 .634 .748 r
.41742 .49828 m .41722 .49828 L .41744 .49827 L p F P
0 g
s
.01 0 0 r
.43073 .49774 m .4204 .49806 L p .43031 .49775 L F P
0 g
s
.01 0 0 r
.4204 .49806 m .41742 .49828 L .43121 .49773 L p F P
0 g
s
.071 .634 .748 r
.41744 .49827 m .42816 .49772 L p .4182 .49824 L F P
0 g
s
.071 .634 .748 r
.41742 .49828 m .41744 .49827 L .4182 .49824 L F
.01 0 0 r
.43121 .49773 m .43132 .49772 L .43073 .49774 L p F P
0 g
s
.01 0 0 r
.43031 .49775 m .43121 .49773 L .43073 .49774 L F
.37 0 0 r
.25683 .4792 m .25661 .47917 L .25638 .47909 L closepath p F P
0 g
s
.456 0 0 r
.28592 .3465 m .28486 .34642 L .28368 .34591 L closepath p F P
0 g
s
0 0 0 r
.44542 .49678 m .43447 .49742 L .43132 .49772 L p F P
0 g
s
.365 0 0 r
.45929 .36354 m .45975 .3631 L .44877 .3632 L p F P
0 g
s
.365 0 0 r
.44877 .3632 m .44647 .36518 L .45929 .36354 L p F P
0 g
s
.898 .549 .375 r
.08578 .37935 m .09034 .38227 L .0894 .37766 L p F P
0 g
s
.898 .549 .375 r
.0894 .37766 m .08484 .37473 L .08578 .37935 L p F P
0 g
s
.361 0 0 r
.2531 .47861 m .24921 .47719 L .25638 .47909 L p F P
0 g
s
.361 0 0 r
.25638 .47909 m .25661 .47917 L .2531 .47861 L p F P
0 g
s
.908 .636 .514 r
.07078 .35616 m .07515 .35919 L .07541 .3542 L p F P
0 g
s
.908 .636 .514 r
.07541 .3542 m .07104 .35117 L .07078 .35616 L p F P
0 g
s
.824 .368 .14 r
.12217 .41362 m .12007 .41027 L .11627 .40956 L p F P
0 g
s
.277 0 0 r
.28777 .48682 m .28776 .48682 L .28775 .48682 L closepath p F P
0 g
s
.265 0 0 r
.28431 .48635 m .27985 .48516 L .28775 .48682 L p F P
0 g
s
.265 0 0 r
.28775 .48682 m .28776 .48682 L .28431 .48635 L p F P
0 g
s
.553 0 0 r
.20841 .46262 m .20898 .46295 L .20769 .46252 L closepath p F P
0 g
s
.226 0 0 r
.29723 .48904 m .28776 .48682 L .28431 .48635 L p F P
0 g
s
.528 .921 .87 r
.6019 .31259 m .59155 .31748 L .58887 .31774 L p F P
0 g
s
.716 .189 0 r
.1572 .43693 m .15871 .43839 L .15423 .43642 L closepath p F P
0 g
s
.54 .007 0 r
.34212 .36348 m .33574 .36054 L .34491 .36187 L p F P
0 g
s
.54 .007 0 r
.34467 .36382 m .34212 .36348 L p .34491 .36187 L F P
0 g
s
.54 .007 0 r
.34491 .36187 m .34716 .36277 L .34467 .36382 L p F P
0 g
s
.667 .941 .964 r
.61688 .30722 m .61671 .30718 L .61776 .30668 L closepath p F P
0 g
s
.13 0 0 r
.51258 .34883 m .51315 .34837 L .50205 .35115 L p F P
0 g
s
.13 0 0 r
.50205 .35115 m .50104 .35192 L .51258 .34883 L p F P
0 g
s
.326 0 0 r
.26439 .48172 m .25661 .47917 L .2531 .47861 L p F P
0 g
s
.495 0 0 r
.39248 .36678 m .39567 .3676 L .39136 .36754 L closepath p F P
0 g
s
.732 .21 0 r
.14772 .43335 m .15312 .4359 L .14945 .43206 L p F P
0 g
s
.732 .21 0 r
.14945 .43206 m .14403 .42951 L .14772 .43335 L p F P
0 g
s
.484 .899 .834 r
.58877 .31775 m .58887 .31774 L .57885 .32276 L p F P
0 g
s
.484 .899 .834 r
.57885 .32276 m .57757 .32297 L .58877 .31775 L p F P
0 g
s
.6 .601 .824 r
.71221 .29201 m .72376 .29031 L .72656 .29606 L p F P
0 g
s
.598 .647 .87 r
.7115 .29081 m .71221 .29201 L .72376 .29031 L p F P
0 g
s
.889 .516 .327 r
.09163 .38679 m .09626 .38969 L .09497 .38517 L p F P
0 g
s
.889 .516 .327 r
.09497 .38517 m .09034 .38227 L .09163 .38679 L p F P
0 g
s
0 0 0 r
.54013 .48114 m .54112 .48075 L .52997 .4833 L p F P
0 g
s
0 0 0 r
.52997 .4833 m .52843 .48391 L .54013 .48114 L p F P
0 g
s
.187 0 0 r
.33295 .49433 m .33302 .49434 L .33292 .49433 L closepath p F P
0 g
s
.585 .01 0 r
.19155 .45533 m .19125 .45527 L .19105 .45514 L closepath p F P
0 g
s
.307 0 0 r
.23675 .3281 m .2386 .32895 L .23376 .32678 L closepath p F P
0 g
s
.799 .32 .078 r
.12507 .41767 m .13018 .42035 L .1273 .41629 L p F P
0 g
s
.799 .32 .078 r
.1273 .41629 m .12217 .41362 L .12507 .41767 L p F P
0 g
s
.905 .661 .558 r
.06675 .34811 m .07104 .35117 L .07179 .34603 L p F P
0 g
s
.905 .661 .558 r
.06675 .34805 m .06675 .34811 L p .07179 .34603 L F P
0 g
s
.905 .661 .558 r
.07179 .34603 m .0675 .34295 L .06675 .34805 L p F P
0 g
s
.095 0 0 r
.34283 .49558 m .3436 .49565 L .33302 .49434 L p F P
0 g
s
.095 0 0 r
.3354 .49474 m .34283 .49558 L p .33302 .49434 L F P
0 g
s
.095 0 0 r
.32959 .49402 m .3354 .49474 L p .33302 .49434 L F P
0 g
s
.095 0 0 r
.33302 .49434 m .33292 .49433 L .32959 .49402 L p F P
0 g
s
.686 .915 .972 r
.64191 .29763 m .63852 .29918 L .64133 .29737 L closepath p F P
0 g
s
.672 .929 .971 r
.6392 .29641 m .64133 .29737 L .63852 .29918 L p F P
0 g
s
.672 .929 .971 r
.62794 .30184 m .6392 .29641 L p .63852 .29918 L F P
0 g
s
.145 0 0 r
.33292 .49433 m .32959 .49402 L .32373 .49313 L closepath p F P
0 g
s
.635 .948 .948 r
.61776 .30668 m .61671 .30718 L .61397 .30675 L p F P
0 g
s
.64 .949 .947 r
.60275 .31219 m .61397 .30675 L .61671 .30718 L p F P
0 g
s
0 0 0 r
.52704 .48432 m .52843 .48391 L .51653 .48645 L p F P
0 g
s
0 0 0 r
.51653 .48645 m .5159 .48663 L .52704 .48432 L p F P
0 g
s
0 0 0 r
.57761 .46996 m .58039 .46844 L .56919 .47197 L p F P
0 g
s
0 0 0 r
.56919 .47197 m .56647 .47344 L .57761 .46996 L p F P
0 g
s
.458 0 0 r
.28137 .34617 m .27657 .34387 L .28368 .34591 L p F P
0 g
s
.458 0 0 r
.28368 .34591 m .28486 .34642 L .28137 .34617 L p F P
0 g
s
.39 .68 .975 r
.16445 .29649 m .15832 .29607 L .16294 .29906 L p F P
0 g
s
.39 .68 .975 r
.16294 .29906 m .168 .29932 L .16445 .29649 L p F P
0 g
s
.367 .664 .971 r
.15429 .29574 m .15832 .29607 L .16294 .29906 L p F P
0 g
s
.745 .756 .861 r
.09219 .29123 m .09498 .28948 L .09138 .28602 L p F P
0 g
s
.745 .756 .861 r
.09138 .28602 m .08823 .28797 L .09219 .29123 L p F P
0 g
s
.757 .753 .849 r
.08061 .29309 m .08823 .28797 L .09219 .29123 L p F P
0 g
s
0 0 0 r
.54953 .33495 m .55136 .33401 L .5406 .33805 L p F P
0 g
s
0 0 0 r
.5406 .33805 m .53836 .33925 L .54953 .33495 L p F P
0 g
s
.58 .004 0 r
.18761 .4545 m .18508 .45281 L .19105 .45514 L p F P
0 g
s
.58 .004 0 r
.19105 .45514 m .19125 .45527 L .18761 .4545 L p F P
0 g
s
.467 0 0 r
.20866 .46394 m .21507 .46612 L .20898 .46295 L p F P
0 g
s
.467 0 0 r
.2048 .46194 m .20866 .46394 L p .20898 .46295 L F P
0 g
s
.467 0 0 r
.20898 .46295 m .20769 .46252 L .2048 .46194 L p F P
0 g
s
.404 0 0 r
.43468 .36526 m .44142 .36565 L .4333 .36643 L closepath p F P
0 g
s
.192 0 .213 r
.70127 .39262 m .70039 .39616 L .70634 .38938 L closepath p F P
0 g
s
.66 .942 .962 r
.62794 .30184 m .61776 .30668 L .62637 .30143 L closepath p F P
0 g
s
.635 .948 .948 r
.62522 .30114 m .62637 .30143 L .61776 .30668 L p F P
0 g
s
.635 .948 .948 r
.61397 .30675 m .62522 .30114 L p .61776 .30668 L F P
0 g
s
.504 .459 .739 r
.73232 .31077 m .73652 .31187 L .73351 .31447 L closepath p F P
0 g
s
.46 .407 .711 r
.74349 .3148 m .73652 .31187 L .73351 .31447 L p F P
0 g
s
.46 .407 .711 r
.73585 .32138 m .74349 .3148 L p .73351 .31447 L F P
0 g
s
.46 .407 .711 r
.73351 .31447 m .73538 .32114 L .73585 .32138 L p F P
0 g
s
.636 .743 .926 r
.10911 .28813 m .11951 .28509 L .12309 .28839 L p F P
0 g
s
.632 .742 .927 r
.11951 .28509 m .10911 .28813 L .10552 .28474 L p F P
0 g
s
.697 .753 .895 r
.09498 .28948 m .10552 .28474 L .10911 .28813 L p F P
0 g
s
.496 .47 .758 r
.73079 .30639 m .73232 .31077 L .73652 .31187 L p F P
0 g
s
.865 .451 .239 r
.09804 .39405 m .10282 .39689 L .10104 .39252 L p F P
0 g
s
.865 .451 .239 r
.09632 .38986 m .09804 .39405 L p .10104 .39252 L F P
0 g
s
.865 .451 .239 r
.10104 .39252 m .09663 .38991 L .09632 .38986 L p F P
0 g
s
.557 0 0 r
.19649 .45849 m .19125 .45527 L .18761 .4545 L p F P
0 g
s
.471 0 0 r
.40653 .36706 m .40905 .36755 L .40578 .36763 L closepath p F P
0 g
s
.306 0 0 r
.46999 .35991 m .46195 .36125 L .45975 .3631 L p F P
0 g
s
.669 .123 0 r
.17417 .44682 m .17433 .44695 L .1739 .44678 L closepath p F P
0 g
s
.44 0 0 r
.4206 .36655 m .42403 .36699 L .41974 .36725 L closepath p F P
0 g
s
.619 .663 .871 r
.70947 .28748 m .71691 .28593 L .7115 .29081 L closepath p F P
0 g
s
.598 .647 .87 r
.72099 .28515 m .71691 .28593 L .7115 .29081 L p F P
0 g
s
.598 .647 .87 r
.72376 .29031 m .72099 .28515 L p .7115 .29081 L F P
0 g
s
0 0 0 r
.59457 .46258 m .59438 .46271 L .59894 .46099 L closepath p F P
0 g
s
.598 .026 0 r
.17332 .44807 m .17917 .45046 L .17433 .44695 L p F P
0 g
s
.598 .026 0 r
.17049 .446 m .17332 .44807 L p .17433 .44695 L F P
0 g
s
.598 .026 0 r
.17433 .44695 m .1739 .44678 L .17049 .446 L p F P
0 g
s
.9 .684 .602 r
.06592 .34179 m .0675 .34295 L .0688 .33763 L p F P
0 g
s
.9 .684 .602 r
.06389 .33731 m .06592 .34179 L p .0688 .33763 L F P
0 g
s
.9 .684 .602 r
.0688 .33763 m .06458 .33451 L .06389 .33731 L p F P
0 g
s
.535 .513 .778 r
.7294 .30277 m .73433 .30325 L .73079 .30639 L closepath p F P
0 g
s
.496 .47 .758 r
.74121 .30455 m .73433 .30325 L .73079 .30639 L p F P
0 g
s
.496 .47 .758 r
.74202 .30706 m .74121 .30455 L p .73079 .30639 L F P
0 g
s
.496 .47 .758 r
.73652 .31187 m .74202 .30706 L p .73079 .30639 L F P
0 g
s
.52 0 0 r
.20769 .46252 m .2048 .46194 L .20268 .46074 L closepath p F P
0 g
s
.695 .753 .896 r
.10552 .28474 m .09498 .28948 L .09138 .28602 L p F P
0 g
s
.356 .655 .969 r
.15832 .29607 m .15429 .29574 L .15073 .29273 L p F P
0 g
s
.395 0 0 r
.22835 .47123 m .23506 .4733 L .22832 .47031 L p F P
0 g
s
.395 0 0 r
.22204 .4685 m .22835 .47123 L p .22832 .47031 L F P
0 g
s
.395 0 0 r
.22832 .47031 m .22263 .46861 L .22204 .4685 L p F P
0 g
s
.007 0 0 r
.62893 .44792 m .63076 .44611 L .61952 .4513 L p F P
0 g
s
.007 0 0 r
.61952 .4513 m .61851 .45231 L .62893 .44792 L p F P
0 g
s
0 .365 .743 r
.21958 .32092 m .22035 .32124 L .21809 .32011 L closepath p F P
0 g
s
.642 .082 0 r
.1739 .44678 m .17049 .446 L .1686 .44452 L closepath p F P
0 g
s
0 0 0 r
.48558 .4922 m .47541 .49359 L .47363 .49386 L p F P
0 g
s
.867 .733 .713 r
.06102 .31683 m .06506 .32004 L .06856 .31398 L p F P
0 g
s
.867 .733 .713 r
.06856 .31398 m .06455 .31076 L .06102 .31683 L p F P
0 g
s
.699 .918 .968 r
.65048 .29096 m .65318 .29249 L .64191 .29763 L p F P
0 g
s
.699 .918 .968 r
.64985 .29126 m .65048 .29096 L p .64191 .29763 L F P
0 g
s
.699 .918 .968 r
.64191 .29763 m .64133 .29737 L .64985 .29126 L p F P
0 g
s
.14 .586 .927 r
.20294 .31393 m .20241 .3136 L .20211 .31354 L closepath p F P
0 g
s
.472 .401 .696 r
.73538 .32114 m .73585 .32138 L .73552 .32166 L closepath p F P
0 g
s
.562 .726 .951 r
.12309 .28839 m .12957 .28741 L .13399 .29048 L p F P
0 g
s
.572 .731 .95 r
.13338 .2868 m .12957 .28741 L .13399 .29048 L p F P
0 g
s
.572 .731 .95 r
.13399 .29048 m .13695 .28998 L .13338 .2868 L p F P
0 g
s
.557 .722 .951 r
.12957 .28741 m .12309 .28839 L .11951 .28509 L p F P
0 g
s
.279 .643 .966 r
.18168 .30378 m .17817 .30324 L .18319 .30606 L p F P
0 g
s
.279 .643 .966 r
.18319 .30606 m .18522 .30634 L .18168 .30378 L p F P
0 g
s
.448 .363 .667 r
.74067 .325 m .73696 .32814 L .73552 .32166 L p F P
0 g
s
.448 .363 .667 r
.73552 .32166 m .73585 .32138 L .74067 .325 L p F P
0 g
s
0 0 0 r
.59894 .46099 m .59438 .46271 L .5917 .46454 L p F P
0 g
s
.125 0 0 r
.65577 .43078 m .6555 .43094 L .65575 .43083 L closepath p F P
0 g
s
.072 0 0 r
.65381 .43356 m .65575 .43083 L .6555 .43094 L p F P
0 g
s
.072 0 0 r
.6437 .43839 m .65381 .43356 L p .6555 .43094 L F P
0 g
s
.854 .425 .203 r
.10492 .40117 m .10975 .40397 L .10766 .39969 L p F P
0 g
s
.854 .425 .203 r
.10766 .39969 m .10282 .39689 L .10492 .40117 L p F P
0 g
s
.58 .012 0 r
.28953 .34895 m .28486 .34642 L .28137 .34617 L p F P
0 g
s
.094 0 0 r
.66568 .42575 m .66697 .42357 L .65577 .43078 L p F P
0 g
s
.094 0 0 r
.65577 .43078 m .65575 .43083 L .66568 .42575 L p F P
0 g
s
.249 .002 .329 r
.72053 .37641 m .71157 .38257 L .71535 .37621 L p F P
0 g
s
.249 .002 .329 r
.71535 .37621 m .72105 .37229 L .72053 .37641 L p F P
0 g
s
.529 .529 .8 r
.72689 .2968 m .7294 .30277 L .73433 .30325 L p F P
0 g
s
.558 0 0 r
.30268 .35398 m .31052 .35577 L .30455 .35274 L p F P
0 g
s
.558 0 0 r
.29865 .35166 m .30268 .35398 L p .30455 .35274 L F P
0 g
s
.558 0 0 r
.30455 .35274 m .30001 .35158 L .29865 .35166 L p F P
0 g
s
.565 .022 0 r
.33306 .36211 m .34212 .36348 L .33574 .36054 L p F P
0 g
s
.565 .022 0 r
.32981 .36039 m .33306 .36211 L p .33574 .36054 L F P
0 g
s
.565 .022 0 r
.33574 .36054 m .33163 .35984 L .32981 .36039 L p F P
0 g
s
.029 0 0 r
.66451 .42742 m .66568 .42575 L .65575 .43083 L p F P
0 g
s
.029 0 0 r
.65806 .43141 m .66451 .42742 L p .65575 .43083 L F P
0 g
s
.029 0 0 r
.65575 .43083 m .65381 .43356 L .65806 .43141 L p F P
0 g
s
.773 .275 .021 r
.13288 .42373 m .13018 .42035 L .13535 .423 L p F P
0 g
s
.773 .275 .021 r
.13535 .423 m .13664 .42458 L .13288 .42373 L p F P
0 g
s
.088 0 0 r
.35554 .4967 m .34694 .49585 L .3436 .49565 L p F P
0 g
s
.455 .377 .68 r
.74554 .32084 m .74067 .325 L .73585 .32138 L p F P
0 g
s
.455 .377 .68 r
.74431 .31534 m .74554 .32084 L p .73585 .32138 L F P
0 g
s
.455 .377 .68 r
.73585 .32138 m .74349 .3148 L .74431 .31534 L p F P
0 g
s
.693 .829 .948 r
.66796 .29012 m .66718 .28944 L .67057 .28806 L closepath p F P
0 g
s
0 0 0 r
.52704 .48432 m .5159 .48663 L .51294 .48747 L p F P
0 g
s
.145 .587 .929 r
.19888 .31136 m .19672 .31085 L .20211 .31354 L p F P
0 g
s
.145 .587 .929 r
.20211 .31354 m .20241 .3136 L .19888 .31136 L p F P
0 g
s
.118 0 0 r
.32647 .49371 m .32959 .49402 L .32373 .49313 L p F P
0 g
s
.118 0 0 r
.32578 .49361 m .32647 .49371 L p .32373 .49313 L F P
0 g
s
.118 0 0 r
.31561 .49207 m .32578 .49361 L p .32373 .49313 L F P
0 g
s
.118 0 0 r
.32373 .49313 m .31627 .49215 L .31561 .49207 L p F P
0 g
s
.062 0 0 r
.66741 .42283 m .66697 .42357 L .67051 .42117 L closepath p F P
0 g
s
0 0 0 r
.53765 .33973 m .53836 .33925 L .52722 .34307 L p F P
0 g
s
0 0 0 r
.52722 .34307 m .52663 .34346 L .53765 .33973 L p F P
0 g
s
0 .337 .715 r
.22128 .32135 m .22693 .32394 L .22035 .32124 L p F P
0 g
s
0 .337 .715 r
.21606 .31902 m .22128 .32135 L p .22035 .32124 L F P
0 g
s
0 .337 .715 r
.22035 .32124 m .21809 .32011 L .21606 .31902 L p F P
0 g
s
.004 0 0 r
.65326 .43422 m .65381 .43356 L .6437 .43839 L p F P
0 g
s
.004 0 0 r
.6437 .43839 m .642 .44043 L .65326 .43422 L p F P
0 g
s
.653 .098 0 r
.15738 .43957 m .16296 .44206 L .15871 .43839 L p F P
0 g
s
.653 .098 0 r
.15347 .43623 m .15738 .43957 L p .15871 .43839 L F P
0 g
s
.653 .098 0 r
.15871 .43839 m .15423 .43642 L .15347 .43623 L p F P
0 g
s
.563 .035 0 r
.34716 .36277 m .35154 .36473 L .34467 .36382 L closepath p F P
0 g
s
.892 .705 .641 r
.06102 .3318 m .06458 .33451 L .06652 .32898 L p F P
0 g
s
.892 .705 .641 r
.06054 .33108 m .06102 .3318 L p .06652 .32898 L F P
0 g
s
.892 .705 .641 r
.06652 .32898 m .06239 .32582 L .06054 .33108 L p F P
0 g
s
0 .413 .792 r
.20926 .316 m .20241 .3136 L .19888 .31136 L p F P
0 g
s
.34 0 0 r
.23882 .32935 m .24488 .33177 L .2386 .32895 L p F P
0 g
s
.34 0 0 r
.23324 .32655 m .23882 .32935 L p .2386 .32895 L F P
0 g
s
.34 0 0 r
.2386 .32895 m .23376 .32678 L .23324 .32655 L p F P
0 g
s
.323 0 0 r
.27043 .48303 m .27198 .48349 L .27985 .48516 L p F P
0 g
s
.265 0 0 r
.28084 .48586 m .27198 .48349 L .27985 .48516 L p F P
0 g
s
.265 0 0 r
.27985 .48516 m .28431 .48635 L .28084 .48586 L p F P
0 g
s
.27 .049 .383 r
.72562 .36897 m .72105 .37229 L .72138 .36793 L p F P
0 g
s
.27 .049 .383 r
.72138 .36793 m .72817 .36299 L .72562 .36897 L p F P
0 g
s
.22 0 0 r
.30166 .48962 m .30584 .49048 L .31454 .49188 L p F P
0 g
s
.217 0 0 r
.30166 .48962 m .30584 .49048 L .29894 .48936 L closepath p F P
0 g
s
.413 0 0 r
.23932 .47415 m .24208 .47526 L .24921 .47719 L p F P
0 g
s
.361 0 0 r
.24957 .47802 m .24208 .47526 L .24921 .47719 L p F P
0 g
s
.361 0 0 r
.24921 .47719 m .2531 .47861 L .24957 .47802 L p F P
0 g
s
.408 0 0 r
.23932 .47415 m .24208 .47526 L .23653 .47374 L closepath p F P
0 g
s
.675 .754 .91 r
.68122 .28748 m .6926 .2834 L .6953 .28673 L p F P
0 g
s
.686 .78 .922 r
.6926 .2834 m .68122 .28748 L .67852 .2848 L p F P
0 g
s
.457 0 0 r
.25043 .33378 m .25111 .33414 L .25723 .33652 L p F P
0 g
s
.457 0 0 r
.25683 .33718 m .26339 .33943 L .25723 .33652 L p F P
0 g
s
.457 0 0 r
.25723 .33652 m .25111 .33414 L .25683 .33718 L p F P
0 g
s
.649 .698 .882 r
.6953 .28673 m .70674 .28338 L .70947 .28748 L p F P
0 g
s
.662 .725 .896 r
.70674 .28338 m .6953 .28673 L .6926 .2834 L p F P
0 g
s
.299 0 0 r
.47438 .3592 m .47387 .35962 L .46999 .35991 L closepath p F P
0 g
s
.306 0 0 r
.47181 .36156 m .47387 .35962 L .46999 .35991 L p F P
0 g
s
.306 0 0 r
.46323 .36291 m .47181 .36156 L p .46999 .35991 L F P
0 g
s
.306 0 0 r
.45975 .3631 m .46323 .36291 L p .46999 .35991 L F P
0 g
s
.222 0 0 r
.49838 .35409 m .49906 .35348 L .48797 .3556 L p F P
0 g
s
.222 0 0 r
.48797 .3556 m .48654 .35684 L .49838 .35409 L p F P
0 g
s
.699 .919 .968 r
.64133 .29737 m .6392 .29641 L .64985 .29126 L closepath p F P
0 g
s
.835 .385 .152 r
.11214 .40817 m .10975 .40397 L .11465 .40674 L p F P
0 g
s
.835 .385 .152 r
.11358 .40899 m .11214 .40817 L p .11465 .40674 L F P
0 g
s
.835 .385 .152 r
.11465 .40674 m .11627 .40956 L .11358 .40899 L p F P
0 g
s
.344 .167 .491 r
.73049 .35675 m .72969 .35734 L .7301 .35204 L p F P
0 g
s
.344 .167 .491 r
.7301 .35204 m .73035 .35185 L .73049 .35675 L p F P
0 g
s
.556 .012 0 r
.33163 .35984 m .32981 .36039 L .32697 .35908 L closepath p F P
0 g
s
.476 0 0 r
.40905 .36755 m .40578 .36763 L .40325 .36958 L p F P
0 g
s
.506 .008 .008 r
.40578 .36763 m .40325 .36958 L .39567 .3676 L closepath p F P
0 g
s
.501 0 0 r
.40291 .36988 m .40325 .36958 L .39567 .3676 L p F P
0 g
s
.501 0 0 r
.39137 .36977 m .40291 .36988 L p .39567 .3676 L F P
0 g
s
.501 0 0 r
.38917 .36908 m .39137 .36977 L p .39567 .3676 L F P
0 g
s
.501 0 0 r
.39567 .3676 m .39136 .36754 L .38917 .36908 L p F P
0 g
s
.481 0 .003 r
.41974 .36725 m .41736 .36922 L .40905 .36755 L closepath p F P
0 g
s
.476 0 0 r
.41698 .36957 m .41736 .36922 L .40905 .36755 L p F P
0 g
s
.476 0 0 r
.40436 .36986 m .41698 .36957 L p .40905 .36755 L F P
0 g
s
.476 0 0 r
.40325 .36958 m .40436 .36986 L p .40905 .36755 L F P
0 g
s
.14 0 0 r
.51018 .35078 m .51258 .34883 L .50104 .35192 L p F P
0 g
s
.14 0 0 r
.50104 .35192 m .49906 .35348 L .51018 .35078 L p F P
0 g
s
.525 .021 .003 r
.39136 .36754 m .38917 .36908 L .38344 .36728 L closepath p F P
0 g
s
.088 0 0 r
.67873 .41442 m .67816 .4156 L .68242 .41232 L closepath p F P
0 g
s
.326 .154 .487 r
.73851 .35049 m .73049 .35675 L .73035 .35185 L p F P
0 g
s
.326 .154 .487 r
.73035 .35185 m .73886 .3452 L .73851 .35049 L p F P
0 g
s
.574 .021 0 r
.31594 .3561 m .31857 .35749 L .31392 .35647 L closepath p F P
0 g
s
0 0 0 r
.6313 .44556 m .63076 .44611 L .63703 .44301 L closepath p F P
0 g
s
0 0 0 r
.56188 .32963 m .56357 .32884 L .5524 .33348 L p F P
0 g
s
0 0 0 r
.5524 .33348 m .55136 .33401 L .56188 .32963 L p F P
0 g
s
.359 .819 .72 r
.57477 .32378 m .57533 .32362 L .56507 .32832 L p F P
0 g
s
.359 .819 .72 r
.56507 .32832 m .56357 .32884 L .57477 .32378 L p F P
0 g
s
.813 .752 .795 r
.06583 .30022 m .07224 .29376 L .07617 .29703 L p F P
0 g
s
.813 .752 .795 r
.07617 .29703 m .06946 .30385 L .06583 .30022 L p F P
0 g
s
.796 .756 .817 r
.07617 .29703 m .08061 .29309 L .07699 .28956 L p F P
0 g
s
.796 .756 .817 r
.07699 .28956 m .07224 .29376 L .07617 .29703 L p F P
0 g
s
0 0 0 r
.55517 .47669 m .55517 .4767 L .555 .47674 L closepath p F P
0 g
s
0 0 0 r
.55231 .47787 m .55517 .4767 L .555 .47674 L p F P
0 g
s
0 0 0 r
.54112 .48075 m .55231 .47787 L p .555 .47674 L F P
0 g
s
.493 0 0 r
.27558 .34477 m .26987 .34169 L .27657 .34387 L p F P
0 g
s
.493 0 0 r
.28012 .34609 m .27558 .34477 L p .27657 .34387 L F P
0 g
s
.493 0 0 r
.27657 .34387 m .28137 .34617 L .28012 .34609 L p F P
0 g
s
.524 0 0 r
.26763 .34047 m .26987 .34169 L .27657 .34387 L p F P
0 g
s
0 0 0 r
.56637 .47349 m .56647 .47344 L .55517 .47669 L p F P
0 g
s
0 0 0 r
.55517 .47669 m .55517 .4767 L .56637 .47349 L p F P
0 g
s
.067 .531 .897 r
.18522 .30634 m .19154 .30808 L .19672 .31085 L p F P
0 g
s
.053 .515 .891 r
.19154 .30808 m .18522 .30634 L .18168 .30378 L p F P
0 g
s
.555 .932 .896 r
.60275 .31219 m .6019 .31259 L .60265 .31219 L closepath p F P
0 g
s
.528 .921 .87 r
.59999 .3123 m .60265 .31219 L .6019 .31259 L p F P
0 g
s
.528 .921 .87 r
.58952 .31738 m .59999 .3123 L p .6019 .31259 L F P
0 g
s
.528 .921 .87 r
.58887 .31774 m .58952 .31738 L p .6019 .31259 L F P
0 g
s
0 0 0 r
.56637 .47349 m .55517 .4767 L .55231 .47787 L p F P
0 g
s
.083 0 0 r
.37394 .49786 m .375 .49788 L p .36096 .49703 L F P
0 g
s
.083 0 0 r
.36096 .49703 m .36641 .49743 L .37394 .49786 L p F P
0 g
s
.076 0 0 r
.36096 .49703 m .36641 .49743 L .35863 .49695 L closepath p F P
0 g
s
.521 .007 0 r
.38837 .3697 m .38917 .36908 L .38344 .36728 L p F P
0 g
s
.521 .007 0 r
.37943 .36934 m .38837 .3697 L p .38344 .36728 L F P
0 g
s
.521 .007 0 r
.37512 .36772 m .37943 .36934 L p .38344 .36728 L F P
0 g
s
.521 .007 0 r
.38344 .36728 m .37642 .36693 L .37512 .36772 L p F P
0 g
s
.756 .755 .851 r
.08823 .28797 m .08061 .29309 L .07699 .28956 L p F P
0 g
s
.472 .702 .969 r
.13695 .28998 m .14717 .28968 L .15073 .29273 L p F P
0 g
s
.466 .697 .968 r
.14717 .28968 m .13695 .28998 L .13338 .2868 L p F P
0 g
s
.314 0 0 r
.27043 .48303 m .27198 .48349 L .26918 .48288 L closepath p F P
0 g
s
.446 0 0 r
.42403 .36699 m .41974 .36725 L .41736 .36922 L p F P
0 g
s
.005 0 0 r
.60561 .45841 m .59894 .46099 L .60532 .45865 L closepath p F P
0 g
s
0 0 0 r
.60289 .4603 m .60532 .45865 L .59894 .46099 L p F P
0 g
s
0 0 0 r
.59319 .46399 m .60289 .4603 L p .59894 .46099 L F P
0 g
s
0 0 0 r
.5917 .46454 m .59319 .46399 L p .59894 .46099 L F P
0 g
s
.416 .312 .628 r
.74398 .32912 m .73802 .33414 L .73696 .32814 L p F P
0 g
s
.416 .312 .628 r
.73696 .32814 m .74067 .325 L .74398 .32912 L p F P
0 g
s
.524 0 0 r
.30001 .35158 m .29865 .35166 L .29697 .35087 L closepath p F P
0 g
s
.433 .867 .772 r
.58599 .31839 m .58877 .31775 L .57757 .32297 L p F P
0 g
s
.433 .867 .772 r
.57996 .32128 m .58599 .31839 L p .57757 .32297 L F P
0 g
s
.433 .867 .772 r
.57757 .32297 m .57533 .32362 L .57996 .32128 L p F P
0 g
s
0 0 0 r
.48803 .49185 m .48773 .4919 L .48558 .4922 L closepath p F P
0 g
s
0 0 0 r
.4847 .49237 m .48773 .4919 L .48558 .4922 L p F P
0 g
s
0 0 0 r
.47363 .49386 m .4847 .49237 L p .48558 .4922 L F P
0 g
s
0 0 0 r
.51257 .48756 m .51294 .48747 L .50183 .48945 L p F P
0 g
s
0 0 0 r
.50183 .48945 m .50039 .48982 L .51257 .48756 L p F P
0 g
s
.688 .853 .961 r
.67057 .28806 m .66718 .28944 L .66449 .28739 L p F P
0 g
s
.706 .857 .954 r
.65318 .29249 m .66449 .28739 L .66718 .28944 L p F P
0 g
s
.563 .563 .812 r
.72656 .29606 m .72773 .29604 L .72689 .2968 L closepath p F P
0 g
s
.529 .529 .8 r
.73828 .29637 m .72773 .29604 L .72689 .2968 L p F P
0 g
s
.529 .529 .8 r
.73924 .29888 m .73828 .29637 L p .72689 .2968 L F P
0 g
s
.529 .529 .8 r
.73433 .30325 m .73924 .29888 L p .72689 .2968 L F P
0 g
s
.169 0 0 r
.31627 .49215 m .31561 .49207 L .31454 .49188 L closepath p F P
0 g
s
.582 .943 .898 r
.61232 .30665 m .61397 .30675 L .60275 .31219 L p F P
0 g
s
.582 .943 .898 r
.60275 .31219 m .60265 .31219 L .61232 .30665 L p F P
0 g
s
.207 0 .263 r
.71136 .38271 m .71132 .38292 L .71157 .38257 L closepath p F P
0 g
s
.907 .582 .418 r
.0759 .36877 m .08033 .37177 L .07976 .36704 L p F P
0 g
s
.907 .582 .418 r
.07976 .36704 m .07532 .36404 L .0759 .36877 L p F P
0 g
s
.397 .268 .586 r
.73874 .33973 m .73806 .34027 L .73598 .33576 L p F P
0 g
s
.397 .268 .586 r
.73598 .33576 m .73802 .33414 L .73874 .33973 L p F P
0 g
s
.26 0 0 r
.48493 .35825 m .48654 .35684 L .47438 .3592 L p F P
0 g
s
.26 0 0 r
.47438 .3592 m .47387 .35962 L .48493 .35825 L p F P
0 g
s
.45 0 0 r
.22263 .46861 m .22204 .4685 L .22155 .46826 L closepath p F P
0 g
s
.5 0 0 r
.26763 .34047 m .26987 .34169 L .26492 .33992 L closepath p F P
0 g
s
.911 .611 .465 r
.07095 .36101 m .07532 .36404 L .07515 .35919 L p F P
0 g
s
.911 .611 .465 r
.07515 .35919 m .07078 .35616 L .07095 .36101 L p F P
0 g
s
0 .48 .834 r
.21809 .32011 m .21606 .31902 L .21479 .31863 L closepath p F P
0 g
s
.451 0 0 r
.4333 .36643 m .43148 .368 L .42403 .36699 L closepath p F P
0 g
s
.446 0 0 r
.43065 .36882 m .43148 .368 L .42403 .36699 L p F P
0 g
s
.446 0 0 r
.41881 .36948 m .43065 .36882 L p .42403 .36699 L F P
0 g
s
.446 0 0 r
.41736 .36922 m .41881 .36948 L p .42403 .36699 L F P
0 g
s
.726 .201 0 r
.1424 .43076 m .14772 .43335 L .14403 .42951 L p F P
0 g
s
.726 .201 0 r
.14403 .42951 m .13868 .42693 L .1424 .43076 L p F P
0 g
s
.516 0 0 r
.20118 .46116 m .19649 .45849 L .20268 .46074 L p F P
0 g
s
.516 0 0 r
.20268 .46074 m .2048 .46194 L .20118 .46116 L p F P
0 g
s
.838 .75 .766 r
.06906 .30434 m .06946 .30385 L .06583 .30022 L p F P
0 g
s
.205 0 .261 r
.72021 .37808 m .72053 .37641 L .71157 .38257 L p F P
0 g
s
.205 0 .261 r
.71748 .38189 m .72021 .37808 L p .71157 .38257 L F P
0 g
s
.205 0 .261 r
.7106 .3866 m .71748 .38189 L p .71157 .38257 L F P
0 g
s
.205 0 .261 r
.71157 .38257 m .71132 .38292 L .7106 .3866 L p F P
0 g
s
.576 .587 .827 r
.72773 .29604 m .72656 .29606 L .72376 .29031 L p F P
0 g
s
.882 .722 .68 r
.05833 .32262 m .06239 .32582 L .06506 .32004 L p F P
0 g
s
.882 .722 .68 r
.06506 .32004 m .06102 .31683 L .05833 .32262 L p F P
0 g
s
.633 .668 .866 r
.71691 .28593 m .70947 .28748 L .70674 .28338 L p F P
0 g
s
.538 .027 0 r
.37642 .36693 m .37512 .36772 L .37213 .36665 L closepath p F P
0 g
s
.901 .55 .369 r
.08128 .37638 m .08578 .37935 L .08484 .37473 L p F P
0 g
s
.901 .55 .369 r
.08484 .37473 m .08033 .37177 L .08128 .37638 L p F P
0 g
s
0 0 0 r
.53546 .34121 m .53765 .33973 L .52663 .34346 L p F P
0 g
s
0 0 0 r
.52663 .34346 m .52429 .34506 L .53546 .34121 L p F P
0 g
s
.587 .945 .896 r
.61123 .3066 m .61232 .30665 L .60265 .31219 L p F P
0 g
s
.587 .945 .896 r
.60265 .31219 m .59999 .3123 L .61123 .3066 L p F P
0 g
s
.56 .019 0 r
.32447 .36057 m .31857 .35749 L .32697 .35908 L p F P
0 g
s
.56 .019 0 r
.32762 .36112 m .32447 .36057 L p .32697 .35908 L F P
0 g
s
.56 .019 0 r
.32697 .35908 m .32981 .36039 L .32762 .36112 L p F P
0 g
s
.225 0 .268 r
.71132 .38292 m .70634 .38938 L .7106 .3866 L closepath p F P
0 g
s
.059 0 0 r
.67051 .42117 m .66697 .42357 L .66568 .42575 L p F P
0 g
s
.838 .75 .766 r
.06583 .30022 m .06514 .30107 L .06906 .30434 L p F P
0 g
s
.852 .746 .745 r
.0606 .3075 m .06455 .31076 L .06906 .30434 L p F P
0 g
s
.852 .746 .745 r
.06906 .30434 m .06514 .30107 L .0606 .3075 L p F P
0 g
s
.582 .006 0 r
.18395 .45369 m .17917 .45046 L .18508 .45281 L p F P
0 g
s
.582 .006 0 r
.18508 .45281 m .18761 .4545 L .18395 .45369 L p F P
0 g
s
.156 0 0 r
.31221 .49162 m .30584 .49048 L .31454 .49188 L p F P
0 g
s
.156 0 0 r
.31454 .49188 m .31561 .49207 L .31221 .49162 L p F P
0 g
s
.911 .638 .51 r
.06648 .35309 m .07078 .35616 L .07104 .35117 L p F P
0 g
s
.911 .638 .51 r
.06674 .34813 m .06648 .35309 L p .07104 .35117 L F P
0 g
s
.911 .638 .51 r
.07104 .35117 m .06675 .34811 L .06674 .34813 L p F P
0 g
s
0 0 0 r
.49883 .49009 m .50039 .48982 L .48803 .49185 L p F P
0 g
s
0 0 0 r
.48803 .49185 m .48773 .4919 L .49883 .49009 L p F P
0 g
s
.68 .947 .958 r
.63649 .29545 m .6392 .29641 L .62794 .30184 L p F P
0 g
s
.68 .947 .958 r
.63141 .298 m .63649 .29545 L p .62794 .30184 L F P
0 g
s
.68 .947 .958 r
.62794 .30184 m .62637 .30143 L .63141 .298 L p F P
0 g
s
.761 .256 .002 r
.13868 .42693 m .13664 .42458 L .13288 .42373 L p F P
0 g
s
.824 .368 .14 r
.11627 .40956 m .1171 .41092 L .12217 .41362 L p F P
0 g
s
.798 .314 .062 r
.12002 .41496 m .12507 .41767 L .12217 .41362 L p F P
0 g
s
.798 .314 .062 r
.12217 .41362 m .1171 .41092 L .12002 .41496 L p F P
0 g
s
0 0 0 r
.53821 .48171 m .54013 .48114 L .52843 .48391 L p F P
0 g
s
0 0 0 r
.52843 .48391 m .52704 .48432 L .53821 .48171 L p F P
0 g
s
.543 .041 .014 r
.36837 .36862 m .36161 .36577 L .37213 .36665 L p F P
0 g
s
.543 .041 .014 r
.37328 .36897 m .36837 .36862 L p .37213 .36665 L F P
0 g
s
.543 .041 .014 r
.37213 .36665 m .37512 .36772 L .37328 .36897 L p F P
0 g
s
.442 0 0 r
.21846 .46773 m .21507 .46612 L .22155 .46826 L p F P
0 g
s
.442 0 0 r
.22155 .46826 m .22204 .4685 L .21846 .46773 L p F P
0 g
s
.892 .517 .32 r
.08707 .38386 m .09163 .38679 L .09034 .38227 L p F P
0 g
s
.892 .517 .32 r
.09034 .38227 m .08578 .37935 L .08707 .38386 L p F P
0 g
s
0 0 0 r
.59163 .46458 m .5917 .46454 L .58076 .46824 L p F P
0 g
s
0 0 0 r
.58076 .46824 m .58039 .46844 L .59163 .46458 L p F P
0 g
s
.48 .42 .712 r
.74406 .3143 m .74349 .3148 L .73652 .31187 L p F P
0 g
s
.48 .42 .712 r
.73652 .31187 m .74202 .30706 L .74406 .3143 L p F P
0 g
s
.111 0 .065 r
.68971 .40559 m .6893 .4066 L .69209 .40415 L closepath p F P
0 g
s
.525 0 0 r
.29516 .3519 m .28953 .34895 L .29697 .35087 L p F P
0 g
s
.525 0 0 r
.29697 .35087 m .29865 .35166 L .29516 .3519 L p F P
0 g
s
.875 .474 .265 r
.09663 .38991 m .09632 .38986 L .09626 .38969 L closepath p F P
0 g
s
.109 0 .008 r
.67816 .4156 m .67051 .42117 L .6772 .41753 L closepath p F P
0 g
s
.059 0 0 r
.67575 .42001 m .6772 .41753 L .67051 .42117 L p F P
0 g
s
.059 0 0 r
.67371 .42142 m .67575 .42001 L p .67051 .42117 L F P
0 g
s
.059 0 0 r
.66568 .42575 m .67371 .42142 L p .67051 .42117 L F P
0 g
s
.225 .605 .951 r
.168 .29932 m .17333 .30033 L .17817 .30324 L p F P
0 g
s
.212 .593 .947 r
.17333 .30033 m .168 .29932 L .16445 .29649 L p F P
0 g
s
.062 0 0 r
.38882 .49838 m .38906 .49838 L p .375 .49788 L F P
0 g
s
.062 0 0 r
.375 .49788 m .37775 .49801 L .38882 .49838 L p F P
0 g
s
.053 0 0 r
.375 .49788 m .37775 .49801 L .37394 .49786 L closepath p F P
0 g
s
.356 .655 .969 r
.15073 .29273 m .15384 .29303 L .15832 .29607 L p F P
0 g
s
.378 .671 .973 r
.16089 .29361 m .15384 .29303 L .15832 .29607 L p F P
0 g
s
.378 .671 .973 r
.15832 .29607 m .16445 .29649 L .16089 .29361 L p F P
0 g
s
.409 0 0 r
.44142 .36565 m .4333 .36643 L .43148 .368 L p F P
0 g
s
.909 .665 .557 r
.0675 .34295 m .06592 .34179 L .06675 .34805 L closepath p F P
0 g
s
.549 .54 .797 r
.73542 .28953 m .73484 .28954 L .72773 .29604 L p F P
0 g
s
.549 .54 .797 r
.72773 .29604 m .73828 .29637 L .73542 .28953 L p F P
0 g
s
.576 .587 .827 r
.72376 .29031 m .73484 .28954 L .72773 .29604 L p F P
0 g
s
.639 .079 0 r
.1668 .44511 m .16296 .44206 L .1686 .44452 L p F P
0 g
s
.639 .079 0 r
.1686 .44452 m .17049 .446 L .1668 .44511 L p F P
0 g
s
0 0 0 r
.62813 .44859 m .62893 .44792 L .61851 .45231 L p F P
0 g
s
0 0 0 r
.61851 .45231 m .61686 .45368 L .62813 .44859 L p F P
0 g
s
0 0 0 r
.49883 .49009 m .48773 .4919 L .4847 .49237 L p F P
0 g
s
.41 0 0 r
.22835 .47123 m .22204 .4685 L .21846 .46773 L p F P
0 g
s
.692 .828 .948 r
.67852 .2848 m .67057 .28806 L .6767 .28319 L closepath p F P
0 g
s
.688 .853 .961 r
.67583 .28242 m .6767 .28319 L .67057 .28806 L p F P
0 g
s
.688 .853 .961 r
.66449 .28739 m .67583 .28242 L p .67057 .28806 L F P
0 g
s
.878 .475 .26 r
.09247 .38903 m .09163 .38679 L .09626 .38969 L p F P
0 g
s
.878 .475 .26 r
.09626 .38969 m .09632 .38986 L .09247 .38903 L p F P
0 g
s
.217 0 0 r
.2808 .48586 m .28084 .48586 L .27198 .48349 L p F P
0 g
s
.217 0 0 r
.27322 .48413 m .2808 .48586 L p .27198 .48349 L F P
0 g
s
.217 0 0 r
.26694 .48248 m .27322 .48413 L p .27198 .48349 L F P
0 g
s
.217 0 0 r
.27198 .48349 m .26918 .48288 L .26694 .48248 L p F P
0 g
s
.111 0 0 r
.32578 .49361 m .31561 .49207 L .31221 .49162 L p F P
0 g
s
.744 .757 .863 r
.08823 .28797 m .09138 .28602 L .08776 .28257 L p F P
0 g
s
.744 .757 .863 r
.08776 .28257 m .08433 .28468 L .08823 .28797 L p F P
0 g
s
.756 .755 .851 r
.07699 .28956 m .08433 .28468 L .08823 .28797 L p F P
0 g
s
.556 .041 0 r
.36112 .36556 m .36161 .36577 L .36087 .3657 L closepath p F P
0 g
s
0 0 0 r
.63703 .44301 m .63076 .44611 L .62893 .44792 L p F P
0 g
s
.873 .465 .25 r
.09804 .39405 m .09632 .38986 L .09247 .38903 L p F P
0 g
s
.691 .149 0 r
.15423 .43642 m .15347 .43623 L .15312 .4359 L closepath p F P
0 g
s
.438 0 0 r
.25043 .33378 m .25111 .33414 L .24944 .33345 L closepath p F P
0 g
s
.3 0 0 r
.484 .3592 m .48493 .35825 L .47387 .35962 L p F P
0 g
s
.3 0 0 r
.47387 .35962 m .47181 .36156 L .484 .3592 L p F P
0 g
s
.189 0 .211 r
.70967 .39029 m .7106 .3866 L .70634 .38938 L p F P
0 g
s
.189 0 .211 r
.70034 .39634 m .70967 .39029 L p .70634 .38938 L F P
0 g
s
.189 0 .211 r
.70634 .38938 m .70039 .39616 L .70034 .39634 L p F P
0 g
s
.712 .879 .959 r
.66449 .28739 m .65318 .29249 L .65048 .29096 L p F P
0 g
s
0 0 0 r
.58886 .46607 m .59163 .46458 L .58039 .46844 L p F P
0 g
s
0 0 0 r
.57777 .46991 m .58886 .46607 L p .58039 .46844 L F P
0 g
s
0 0 0 r
.58039 .46844 m .57761 .46996 L .57777 .46991 L p F P
0 g
s
0 .384 .724 r
.23285 .32642 m .23324 .32655 L .22971 .32502 L p F P
0 g
s
.422 0 0 r
.23324 .32655 m .22971 .32502 L p .22998 .32515 L F P
0 g
s
0 .381 .719 r
.23324 .32655 m .23285 .32642 L .2337 .32676 L p F P
0 g
s
.422 0 0 r
.23882 .32935 m .23324 .32655 L p .22998 .32515 L F P
0 g
s
0 .381 .719 r
.2337 .32676 m .23376 .32678 L .23324 .32655 L p F P
0 g
s
.632 .742 .927 r
.10552 .28474 m .11592 .28177 L .11951 .28509 L p F P
0 g
s
.63 .74 .927 r
.11592 .28177 m .10552 .28474 L .10192 .28134 L p F P
0 g
s
.695 .753 .896 r
.09138 .28602 m .10192 .28134 L .10552 .28474 L p F P
0 g
s
.516 .482 .757 r
.73433 .30325 m .73924 .29888 L .74121 .30455 L closepath p F P
0 g
s
.261 .629 .961 r
.17813 .30117 m .17333 .30033 L .17817 .30324 L p F P
0 g
s
.261 .629 .961 r
.17817 .30324 m .18168 .30378 L .17813 .30117 L p F P
0 g
s
.903 .689 .602 r
.06458 .33451 m .06102 .3318 L .06389 .33731 L closepath p F P
0 g
s
.311 0 0 r
.24951 .47801 m .24957 .47802 L .24208 .47526 L p F P
0 g
s
.311 0 0 r
.24266 .47605 m .24951 .47801 L p .24208 .47526 L F P
0 g
s
.311 0 0 r
.23576 .47358 m .24266 .47605 L p .24208 .47526 L F P
0 g
s
.311 0 0 r
.24208 .47526 m .23653 .47374 L .23576 .47358 L p F P
0 g
s
.043 0 0 r
.38906 .49838 m .38974 .49839 L .40261 .4985 L p F P
0 g
s
.03 0 0 r
.38906 .49838 m .38974 .49839 L .38882 .49838 L closepath p F P
0 g
s
.563 .052 0 r
.35808 .36765 m .36837 .36862 L .36161 .36577 L p F P
0 g
s
.563 .052 0 r
.35772 .36748 m .35808 .36765 L p .36161 .36577 L F P
0 g
s
.563 .052 0 r
.36161 .36577 m .36087 .3657 L .35772 .36748 L p F P
0 g
s
.085 0 0 r
.68242 .41232 m .67816 .4156 L .6772 .41753 L p F P
0 g
s
.094 0 0 r
.52386 .34541 m .52429 .34506 L .51315 .34837 L p F P
0 g
s
.094 0 0 r
.51315 .34837 m .51258 .34883 L .52386 .34541 L p F P
0 g
s
.571 .062 .004 r
.36087 .3657 m .35772 .36748 L .35154 .36473 L closepath p F P
0 g
s
0 0 0 r
.48351 .49253 m .4847 .49237 L .47363 .49386 L p F P
0 g
s
0 0 0 r
.47363 .49386 m .47084 .49426 L .48351 .49253 L p F P
0 g
s
.413 0 0 r
.44647 .36518 m .44562 .36594 L .44142 .36565 L closepath p F P
0 g
s
.409 0 0 r
.44391 .36765 m .44562 .36594 L .44142 .36565 L p F P
0 g
s
.409 0 0 r
.43544 .36839 m .44391 .36765 L p .44142 .36565 L F P
0 g
s
.409 0 0 r
.43148 .368 m .43544 .36839 L p .44142 .36565 L F P
0 g
s
.776 .278 .018 r
.12824 .42165 m .12507 .41767 L .13018 .42035 L p F P
0 g
s
.776 .278 .018 r
.13156 .42339 m .12824 .42165 L p .13018 .42035 L F P
0 g
s
.776 .278 .018 r
.13018 .42035 m .13288 .42373 L .13156 .42339 L p F P
0 g
s
.557 .722 .951 r
.11951 .28509 m .12529 .28426 L .12957 .28741 L p F P
0 g
s
.566 .727 .95 r
.1298 .28358 m .12529 .28426 L .12957 .28741 L p F P
0 g
s
.566 .727 .95 r
.12957 .28741 m .13338 .2868 L .1298 .28358 L p F P
0 g
s
.855 .423 .192 r
.10015 .39833 m .10492 .40117 L .10282 .39689 L p F P
0 g
s
.855 .423 .192 r
.10282 .39689 m .09804 .39405 L .10015 .39833 L p F P
0 g
s
.12 .568 .92 r
.19533 .30906 m .19154 .30808 L .19672 .31085 L p F P
0 g
s
.12 .568 .92 r
.19672 .31085 m .19888 .31136 L .19533 .30906 L p F P
0 g
s
.693 .752 .897 r
.10192 .28134 m .09138 .28602 L .08776 .28257 L p F P
0 g
s
0 0 0 r
.55166 .47813 m .55231 .47787 L .54112 .48075 L p F P
0 g
s
0 0 0 r
.54112 .48075 m .54013 .48114 L .55166 .47813 L p F P
0 g
s
.276 0 0 r
.26918 .48288 m .26694 .48248 L .26439 .48172 L closepath p F P
0 g
s
.049 .617 .744 r
.41654 .4983 m .4033 .49851 L .40313 .4985 L p F P
0 g
s
.013 .588 .723 r
.4033 .49851 m .40313 .4985 L .40261 .4985 L closepath p F P
0 g
s
0 .484 .84 r
.21252 .31708 m .20926 .316 L .21479 .31863 L p F P
0 g
s
0 .484 .84 r
.21479 .31863 m .21606 .31902 L .21252 .31708 L p F P
0 g
s
.032 .603 .745 r
.39991 .49836 m .38974 .49839 L .40261 .4985 L p F P
0 g
s
.032 .603 .745 r
.40261 .4985 m .40313 .4985 L .39991 .49836 L p F P
0 g
s
0 .384 .724 r
.22971 .32502 m .22693 .32394 L .23285 .32642 L p F P
0 g
s
.688 .145 0 r
.14976 .43523 m .14772 .43335 L .15312 .4359 L p F P
0 g
s
.688 .145 0 r
.15312 .4359 m .15347 .43623 L .14976 .43523 L p F P
0 g
s
.869 .737 .715 r
.05705 .31359 m .06102 .31683 L .06455 .31076 L p F P
0 g
s
.869 .737 .715 r
.06455 .31076 m .0606 .3075 L .05705 .31359 L p F P
0 g
s
.053 .618 .766 r
.39749 .49824 m .39991 .49836 L .38974 .49839 L p F P
0 g
s
.053 .618 .766 r
.39432 .4982 m .39749 .49824 L p .38974 .49839 L F P
0 g
s
.053 .618 .766 r
.38581 .49819 m .39432 .4982 L p .38974 .49839 L F P
0 g
s
.053 .618 .766 r
.38974 .49839 m .38882 .49838 L .38581 .49819 L p F P
0 g
s
.381 .257 .584 r
.74595 .33367 m .73874 .33973 L .73802 .33414 L p F P
0 g
s
.381 .257 .584 r
.73802 .33414 m .74398 .32912 L .74595 .33367 L p F P
0 g
s
.014 .588 .743 r
.38882 .49838 m .38581 .49819 L .37775 .49801 L closepath p F P
0 g
s
.466 0 0 r
.25062 .33481 m .25683 .33718 L .25111 .33414 L p F P
0 g
s
.466 0 0 r
.24691 .33266 m .25062 .33481 L p .25111 .33414 L F P
0 g
s
.466 0 0 r
.25111 .33414 m .24944 .33345 L .24691 .33266 L p F P
0 g
s
0 0 0 r
.6159 .45447 m .61686 .45368 L .60561 .45841 L p F P
0 g
s
0 0 0 r
.60561 .45841 m .60532 .45865 L .6159 .45447 L p F P
0 g
s
.132 0 .072 r
.6893 .4066 m .68242 .41232 L .68837 .40889 L closepath p F P
0 g
s
.085 0 0 r
.68697 .41176 m .68837 .40889 L .68242 .41232 L p F P
0 g
s
.085 0 0 r
.68617 .41239 m .68697 .41176 L p .68242 .41232 L F P
0 g
s
.085 0 0 r
.6772 .41753 m .68617 .41239 L p .68242 .41232 L F P
0 g
s
.347 .646 .966 r
.15384 .29303 m .15073 .29273 L .14717 .28968 L p F P
0 g
s
.123 0 0 r
.30943 .49123 m .31221 .49162 L .30584 .49048 L p F P
0 g
s
.123 0 0 r
.30783 .49095 m .30943 .49123 L p .30584 .49048 L F P
0 g
s
.123 0 0 r
.29823 .48925 m .30783 .49095 L p .30584 .49048 L F P
0 g
s
.123 0 0 r
.30584 .49048 m .29894 .48936 L .29823 .48925 L p F P
0 g
s
.034 .604 .726 r
.41742 .49828 m .41722 .49828 L .41654 .4983 L closepath p F P
0 g
s
.049 .617 .744 r
.41403 .49821 m .41722 .49828 L .41654 .4983 L p F P
0 g
s
.049 .617 .744 r
.40313 .4985 m .41403 .49821 L p .41654 .4983 L F P
0 g
s
.071 .634 .748 r
.42816 .49772 m .43121 .49773 L .41742 .49828 L p F P
0 g
s
.586 .039 0 r
.31614 .35894 m .32447 .36057 L .31857 .35749 L p F P
0 g
s
.586 .039 0 r
.31248 .35676 m .31614 .35894 L p .31857 .35749 L F P
0 g
s
.586 .039 0 r
.31857 .35749 m .31392 .35647 L .31248 .35676 L p F P
0 g
s
.058 .623 .756 r
.41403 .49821 m .40313 .4985 L .39991 .49836 L p F P
0 g
s
0 0 0 r
.56073 .33018 m .56188 .32963 L .55136 .33401 L p F P
0 g
s
0 0 0 r
.55136 .33401 m .54953 .33495 L .56073 .33018 L p F P
0 g
s
.912 .667 .554 r
.06674 .3481 m .06675 .34805 L .06592 .34179 L p F P
0 g
s
.912 .667 .554 r
.06258 .34497 m .06674 .3481 L p .06592 .34179 L F P
0 g
s
.912 .667 .554 r
.06592 .34179 m .06331 .33983 L .06258 .34497 L p F P
0 g
s
.905 .684 .593 r
.06389 .33731 m .06331 .33983 L .06592 .34179 L closepath p F P
0 g
s
.552 .719 .95 r
.12529 .28426 m .11951 .28509 L .11592 .28177 L p F P
0 g
s
0 0 0 r
.45953 .49549 m .46895 .49448 L .45788 .49569 L closepath p F P
0 g
s
0 0 0 r
.45788 .49569 m .45953 .49549 L p .44542 .49678 L F P
0 g
s
.21 0 .218 r
.70039 .39616 m .70007 .3965 L .70034 .39634 L closepath p F P
0 g
s
.152 0 .133 r
.69919 .39981 m .69209 .40415 L .70007 .3965 L p F P
0 g
s
.152 0 .133 r
.70007 .3965 m .70034 .39634 L .69919 .39981 L p F P
0 g
s
.487 0 0 r
.20866 .46394 m .2048 .46194 L .20118 .46116 L p F P
0 g
s
.615 .069 0 r
.30268 .35398 m .29865 .35166 L .29516 .3519 L p F P
0 g
s
.825 .367 .131 r
.11627 .40956 m .1171 .41092 L .11358 .40899 L closepath p F P
0 g
s
.386 0 0 r
.45678 .36603 m .45929 .36354 L .44647 .36518 L p F P
0 g
s
.386 0 0 r
.45567 .36616 m .45678 .36603 L p .44647 .36518 L F P
0 g
s
.386 0 0 r
.44647 .36518 m .44562 .36594 L .45567 .36616 L p F P
0 g
s
.305 .106 .437 r
.73039 .36135 m .72817 .36299 L .72969 .35734 L p F P
0 g
s
.305 .106 .437 r
.72969 .35734 m .73049 .35675 L .73039 .36135 L p F P
0 g
s
.523 0 0 r
.26882 .34259 m .27558 .34477 L .26987 .34169 L p F P
0 g
s
.523 0 0 r
.26413 .33977 m .26882 .34259 L p .26987 .34169 L F P
0 g
s
.523 0 0 r
.26987 .34169 m .26492 .33992 L .26413 .33977 L p F P
0 g
s
.67 .12 0 r
.15738 .43957 m .15347 .43623 L .14976 .43523 L p F P
0 g
s
.226 0 0 r
.28431 .48635 m .28906 .48746 L .29723 .48904 L p F P
0 g
s
.221 0 0 r
.28906 .48746 m .28431 .48635 L .28084 .48586 L p F P
0 g
s
.108 0 .062 r
.69209 .40415 m .6893 .4066 L .68837 .40889 L p F P
0 g
s
.326 0 0 r
.2531 .47861 m .25699 .47989 L .26439 .48172 L p F P
0 g
s
.322 0 0 r
.25699 .47989 m .2531 .47861 L .24957 .47802 L p F P
0 g
s
.125 0 .122 r
.70925 .39156 m .70967 .39029 L .70034 .39634 L p F P
0 g
s
.125 0 .122 r
.70468 .39627 m .70925 .39156 L p .70034 .39634 L F P
0 g
s
.125 0 .122 r
.70034 .39634 m .69919 .39981 L .70468 .39627 L p F P
0 g
s
.108 0 .062 r
.69815 .40241 m .69919 .39981 L .69209 .40415 L p F P
0 g
s
.108 0 .062 r
.69629 .40407 m .69815 .40241 L p .69209 .40415 L F P
0 g
s
.108 0 .062 r
.68837 .40889 m .69629 .40407 L p .69209 .40415 L F P
0 g
s
.032 .601 .761 r
.38281 .49798 m .38581 .49819 L .37775 .49801 L p F P
0 g
s
.032 .601 .761 r
.38185 .49794 m .38281 .49798 L p .37775 .49801 L F P
0 g
s
.032 .601 .761 r
.37172 .49768 m .38185 .49794 L p .37775 .49801 L F P
0 g
s
.032 .601 .761 r
.37775 .49801 m .37394 .49786 L .37172 .49768 L p F P
0 g
s
.074 .636 .755 r
.42816 .49772 m .41722 .49828 L .41403 .49821 L p F P
0 g
s
0 0 0 r
.44542 .49678 m .44904 .49648 L .45788 .49569 L p F P
0 g
s
0 0 0 r
.44542 .49678 m .44904 .49648 L .44468 .49685 L closepath p F P
0 g
s
0 0 0 r
.44468 .49685 m .44542 .49678 L p .43132 .49772 L F P
0 g
s
.594 .596 .824 r
.73484 .28954 m .72376 .29031 L .72099 .28515 L p F P
0 g
s
.895 .708 .642 r
.05702 .32628 m .05833 .32262 L .06239 .32582 L p F P
0 g
s
.895 .708 .642 r
.06239 .32582 m .06054 .33108 L .05702 .32628 L p F P
0 g
s
0 0 0 r
.43132 .49772 m .43178 .49769 L .44468 .49685 L p F P
0 g
s
0 0 0 r
.43132 .49772 m .43178 .49769 L .43121 .49773 L closepath p F P
0 g
s
0 .568 .736 r
.37394 .49786 m .37172 .49768 L .36641 .49743 L closepath p F P
0 g
s
.837 .385 .141 r
.10731 .40536 m .11214 .40817 L .10975 .40397 L p F P
0 g
s
.837 .385 .141 r
.10975 .40397 m .10492 .40117 L .10731 .40536 L p F P
0 g
s
.104 0 0 r
.32959 .49402 m .3354 .49474 L .32647 .49371 L closepath p F P
0 g
s
.031 0 0 r
.642 .44043 m .63703 .44301 L .64156 .44096 L closepath p F P
0 g
s
0 0 0 r
.63941 .4431 m .64156 .44096 L .63703 .44301 L p F P
0 g
s
0 0 0 r
.6372 .44422 m .63941 .4431 L p .63703 .44301 L F P
0 g
s
0 0 0 r
.62893 .44792 m .6372 .44422 L p .63703 .44301 L F P
0 g
s
0 0 0 r
.61417 .45564 m .6159 .45447 L .60532 .45865 L p F P
0 g
s
0 0 0 r
.60532 .45865 m .60289 .4603 L .61417 .45564 L p F P
0 g
s
.356 0 0 r
.24944 .33345 m .24691 .33266 L .24488 .33177 L closepath p F P
0 g
s
.572 .049 0 r
.35754 .36759 m .35772 .36748 L .35154 .36473 L p F P
0 g
s
.572 .049 0 r
.34819 .36654 m .35754 .36759 L p .35154 .36473 L F P
0 g
s
.572 .049 0 r
.34374 .36423 m .34819 .36654 L p .35154 .36473 L F P
0 g
s
.572 .049 0 r
.35154 .36473 m .34467 .36382 L .34374 .36423 L p F P
0 g
s
.109 .663 .772 r
.43178 .49769 m .43121 .49773 L .42816 .49772 L p F P
0 g
s
0 0 0 r
.54842 .33567 m .54953 .33495 L .53836 .33925 L p F P
0 g
s
0 0 0 r
.53836 .33925 m .53765 .33973 L .54842 .33567 L p F P
0 g
s
.591 .059 0 r
.32981 .36039 m .33306 .36211 L .32762 .36112 L closepath p F P
0 g
s
.094 .652 .754 r
.44468 .49685 m .44229 .4969 L .43178 .49769 L closepath p F P
0 g
s
.109 .663 .772 r
.43938 .49693 m .44229 .4969 L .43178 .49769 L p F P
0 g
s
.109 .663 .772 r
.43814 .49701 m .43938 .49693 L p .43178 .49769 L F P
0 g
s
.109 .663 .772 r
.42816 .49772 m .43814 .49701 L p .43178 .49769 L F P
0 g
s
.542 .928 .869 r
.58887 .31774 m .58877 .31775 L .58952 .31738 L closepath p F P
0 g
s
0 .279 .652 r
.22128 .32135 m .21606 .31902 L .21252 .31708 L p F P
0 g
s
.234 0 0 r
.49604 .35627 m .49838 .35409 L .48654 .35684 L p F P
0 g
s
.234 0 0 r
.48654 .35684 m .48493 .35825 L .49604 .35627 L p F P
0 g
s
.138 .68 .705 r
.50996 .48802 m .51257 .48756 L .50039 .48982 L p F P
0 g
s
.138 .68 .705 r
.50039 .48982 m .49883 .49009 L .50996 .48802 L p F P
0 g
s
.557 0 0 r
.18761 .4545 m .19036 .45621 L .19649 .45849 L p F P
0 g
s
.515 0 0 r
.19612 .45947 m .19036 .45621 L .19649 .45849 L p F P
0 g
s
.515 0 0 r
.19966 .46081 m .19612 .45947 L p .19649 .45849 L F P
0 g
s
.515 0 0 r
.19649 .45849 m .20118 .46116 L .19966 .46081 L p F P
0 g
s
.58 .012 0 r
.28137 .34617 m .28254 .34687 L .28953 .34895 L p F P
0 g
s
.556 0 0 r
.28792 .35008 m .28254 .34687 L .28953 .34895 L p F P
0 g
s
.556 0 0 r
.29497 .35191 m .28792 .35008 L p .28953 .34895 L F P
0 g
s
.556 0 0 r
.28953 .34895 m .29516 .3519 L .29497 .35191 L p F P
0 g
s
.556 0 0 r
.19036 .45621 m .18761 .4545 L .18395 .45369 L p F P
0 g
s
.284 .09 .432 r
.73711 .35612 m .73039 .36135 L .73049 .35675 L p F P
0 g
s
.284 .09 .432 r
.73049 .35675 m .73851 .35049 L .73711 .35612 L p F P
0 g
s
.55 .049 .02 r
.37512 .36772 m .37943 .36934 L .37328 .36897 L closepath p F P
0 g
s
.617 .05 0 r
.17332 .44807 m .17049 .446 L .1668 .44511 L p F P
0 g
s
.635 .957 .925 r
.62249 .30073 m .62522 .30114 L .61397 .30675 L p F P
0 g
s
.635 .957 .925 r
.61767 .30323 m .62249 .30073 L p .61397 .30675 L F P
0 g
s
.635 .957 .925 r
.61397 .30675 m .61232 .30665 L .61767 .30323 L p F P
0 g
s
.35 0 0 r
.45975 .3631 m .46323 .36291 L .45929 .36354 L closepath p F P
0 g
s
.908 .688 .594 r
.06331 .33983 m .06389 .33731 L .06102 .3318 L p F P
0 g
s
.474 .892 .807 r
.58952 .31738 m .58877 .31775 L .58599 .31839 L p F P
0 g
s
.1 0 0 r
.52135 .34749 m .52386 .34541 L .51258 .34883 L p F P
0 g
s
.1 0 0 r
.51258 .34883 m .51018 .35078 L .52135 .34749 L p F P
0 g
s
.227 0 .322 r
.72213 .37525 m .72053 .37641 L .72105 .37229 L p F P
0 g
s
.227 0 .322 r
.72105 .37229 m .72562 .36897 L .72213 .37525 L p F P
0 g
s
.662 .725 .896 r
.6926 .2834 m .70403 .27967 L .70674 .28338 L p F P
0 g
s
.675 .752 .909 r
.70403 .27967 m .6926 .2834 L .6899 .28039 L p F P
0 g
s
.686 .78 .922 r
.67852 .2848 m .6899 .28039 L .6926 .2834 L p F P
0 g
s
0 0 0 r
.57213 .32487 m .57477 .32378 L .56357 .32884 L p F P
0 g
s
0 0 0 r
.56357 .32884 m .56188 .32963 L .57213 .32487 L p F P
0 g
s
.01 .583 .755 r
.36843 .49738 m .37172 .49768 L .36641 .49743 L p F P
0 g
s
.01 .583 .755 r
.35765 .49685 m .36843 .49738 L p .36641 .49743 L F P
0 g
s
.01 .583 .755 r
.36641 .49743 m .35863 .49695 L .35765 .49685 L p F P
0 g
s
.443 0 0 r
.21486 .46693 m .20866 .46394 L .21507 .46612 L p F P
0 g
s
.443 0 0 r
.21507 .46612 m .21846 .46773 L .21486 .46693 L p F P
0 g
s
.581 .005 0 r
.17846 .4515 m .17332 .44807 L .17917 .45046 L p F P
0 g
s
.581 .005 0 r
.18341 .45356 m .17846 .4515 L p .17917 .45046 L F P
0 g
s
.581 .005 0 r
.17917 .45046 m .18395 .45369 L .18341 .45356 L p F P
0 g
s
.269 0 0 r
.26344 .48181 m .25699 .47989 L .26439 .48172 L p F P
0 g
s
.269 0 0 r
.26439 .48172 m .26694 .48248 L .26344 .48181 L p F P
0 g
s
.761 .256 .002 r
.13288 .42373 m .13339 .42432 L .13868 .42693 L p F P
0 g
s
.72 .19 0 r
.13713 .42813 m .1424 .43076 L .13868 .42693 L p F P
0 g
s
.72 .19 0 r
.13868 .42693 m .13339 .42432 L .13713 .42813 L p F P
0 g
s
.517 .916 .85 r
.59999 .3123 m .58952 .31738 L .59874 .31248 L closepath p F P
0 g
s
.474 .892 .807 r
.59723 .3127 m .59874 .31248 L .58952 .31738 L p F P
0 g
s
.474 .892 .807 r
.58599 .31839 m .59723 .3127 L p .58952 .31738 L F P
0 g
s
.566 .014 0 r
.31392 .35647 m .31248 .35676 L .31052 .35577 L closepath p F P
0 g
s
.685 .934 .967 r
.64985 .29126 m .6392 .29641 L .63649 .29545 L p F P
0 g
s
.633 .668 .866 r
.7199 .28328 m .71691 .28593 L p .70674 .28338 L F P
0 g
s
.614 .653 .864 r
.71691 .28593 m .7199 .28328 L .72099 .28515 L closepath p F P
0 g
s
.796 .759 .819 r
.07224 .29376 m .07699 .28956 L .07335 .28608 L p F P
0 g
s
.796 .759 .819 r
.07335 .28608 m .06837 .29045 L .07224 .29376 L p F P
0 g
s
.814 .755 .798 r
.06219 .29665 m .06837 .29045 L .07224 .29376 L p F P
0 g
s
.814 .755 .798 r
.07224 .29376 m .06583 .30022 L .06219 .29665 L p F P
0 g
s
.37 0 0 r
.23653 .47374 m .23576 .47358 L .23506 .4733 L closepath p F P
0 g
s
.177 0 0 r
.29894 .48936 m .29823 .48925 L .29723 .48904 L closepath p F P
0 g
s
0 .413 .792 r
.19888 .31136 m .20396 .31328 L .20926 .316 L p F P
0 g
s
0 .395 .786 r
.20396 .31328 m .19888 .31136 L .19533 .30906 L p F P
0 g
s
0 0 0 r
.53626 .48227 m .53821 .48171 L .52704 .48432 L p F P
0 g
s
0 0 0 r
.52704 .48432 m .52452 .48505 L .53626 .48227 L p F P
0 g
s
0 0 0 r
.52452 .48505 m .52704 .48432 L p .51294 .48747 L F P
0 g
s
.414 .311 .629 r
.74662 .32687 m .74398 .32912 L .74067 .325 L p F P
0 g
s
.414 .311 .629 r
.74067 .325 m .74554 .32084 L .74662 .32687 L p F P
0 g
s
.695 .829 .947 r
.68721 .27767 m .6899 .28039 L .67852 .2848 L p F P
0 g
s
.695 .829 .947 r
.67937 .28094 m .68721 .27767 L p .67852 .2848 L F P
0 g
s
.695 .829 .947 r
.67852 .2848 m .6767 .28319 L .67937 .28094 L p F P
0 g
s
.756 .757 .854 r
.08433 .28468 m .07699 .28956 L .07335 .28608 L p F P
0 g
s
.633 .668 .866 r
.70674 .28338 m .71825 .28054 L .7199 .28328 L p F P
0 g
s
.647 .695 .88 r
.71825 .28054 m .70674 .28338 L .70403 .27967 L p F P
0 g
s
.911 .584 .413 r
.07153 .36574 m .0759 .36877 L .07532 .36404 L p F P
0 g
s
.911 .584 .413 r
.07532 .36404 m .07095 .36101 L .07153 .36574 L p F P
0 g
s
.679 .948 .958 r
.62637 .30143 m .62522 .30114 L .63141 .298 L closepath p F P
0 g
s
.915 .615 .462 r
.06665 .35794 m .07095 .36101 L .07078 .35616 L p F P
0 g
s
.915 .615 .462 r
.07078 .35616 m .06648 .35309 L .06665 .35794 L p F P
0 g
s
.786 .292 .022 r
.11504 .41221 m .12002 .41496 L .1171 .41092 L p F P
0 g
s
.786 .292 .022 r
.11246 .40865 m .11504 .41221 L p .1171 .41092 L F P
0 g
s
.786 .292 .022 r
.1171 .41092 m .11358 .40899 L .11246 .40865 L p F P
0 g
s
.904 .552 .364 r
.07685 .37339 m .08128 .37638 L .08033 .37177 L p F P
0 g
s
.904 .552 .364 r
.08033 .37177 m .0759 .36877 L .07685 .37339 L p F P
0 g
s
0 .547 .728 r
.35863 .49695 m .35765 .49685 L .35554 .4967 L closepath p F P
0 g
s
.466 .697 .968 r
.13338 .2868 m .1436 .28659 L .14717 .28968 L p F P
0 g
s
.461 .692 .967 r
.1436 .28659 m .13338 .2868 L .1298 .28358 L p F P
0 g
s
0 0 0 r
.5776 .46996 m .57761 .46996 L .56647 .47344 L p F P
0 g
s
0 0 0 r
.56647 .47344 m .56637 .47349 L .5776 .46996 L p F P
0 g
s
.839 .753 .768 r
.06514 .30107 m .06583 .30022 L .06219 .29665 L p F P
0 g
s
.572 .049 0 r
.34467 .36382 m .34374 .36423 L .34212 .36348 L closepath p F P
0 g
s
.165 0 0 r
.2948 .48865 m .28906 .48746 L .29723 .48904 L p F P
0 g
s
.165 0 0 r
.29723 .48904 m .29823 .48925 L .2948 .48865 L p F P
0 g
s
.64 .079 0 r
.16192 .44317 m .15738 .43957 L .16296 .44206 L p F P
0 g
s
.64 .079 0 r
.16546 .44476 m .16192 .44317 L p .16296 .44206 L F P
0 g
s
.64 .079 0 r
.16296 .44206 m .1668 .44511 L .16546 .44476 L p F P
0 g
s
.126 .676 .771 r
.44904 .49648 m .44468 .49685 L .44229 .4969 L p F P
0 g
s
.884 .726 .681 r
.05435 .31939 m .05833 .32262 L .06102 .31683 L p F P
0 g
s
.884 .726 .681 r
.06102 .31683 m .05705 .31359 L .05435 .31939 L p F P
0 g
s
.909 .663 .554 r
.06675 .34805 m .06674 .3481 L .06675 .34811 L closepath p F P
0 g
s
0 0 0 r
.65167 .43609 m .65326 .43422 L .642 .44043 L p F P
0 g
s
0 0 0 r
.642 .44043 m .64156 .44096 L .65167 .43609 L p F P
0 g
s
.914 .643 .512 r
.06675 .34811 m .06674 .34813 L .06674 .3481 L closepath p F P
0 g
s
.361 .211 .538 r
.73916 .34495 m .73886 .3452 L .73806 .34027 L p F P
0 g
s
.361 .211 .538 r
.73806 .34027 m .73874 .33973 L .73916 .34495 L p F P
0 g
s
.917 .646 .511 r
.06228 .34997 m .06258 .34497 L .06674 .3481 L p F P
0 g
s
.917 .646 .511 r
.06438 .35155 m .06228 .34997 L p .06674 .3481 L F P
0 g
s
.917 .646 .511 r
.06674 .3481 m .06674 .34813 L .06438 .35155 L p F P
0 g
s
.915 .643 .51 r
.06674 .34813 m .06648 .35309 L .06438 .35155 L closepath p F P
0 g
s
0 0 0 r
.54943 .4788 m .55166 .47813 L .54013 .48114 L p F P
0 g
s
0 0 0 r
.54013 .48114 m .53821 .48171 L .54943 .4788 L p F P
0 g
s
.361 0 0 r
.23221 .47277 m .22835 .47123 L .23506 .4733 L p F P
0 g
s
.361 0 0 r
.23506 .4733 m .23576 .47358 L .23221 .47277 L p F P
0 g
s
.895 .518 .314 r
.08257 .3809 m .08707 .38386 L .08578 .37935 L p F P
0 g
s
.895 .518 .314 r
.08578 .37935 m .08128 .37638 L .08257 .3809 L p F P
0 g
s
.839 .753 .768 r
.06219 .29665 m .06128 .29777 L .06514 .30107 L p F P
0 g
s
.853 .749 .747 r
.05672 .30421 m .0606 .3075 L .06514 .30107 L p F P
0 g
s
.853 .749 .747 r
.06514 .30107 m .06128 .29777 L .05672 .30421 L p F P
0 g
s
0 0 0 r
.5776 .46996 m .56637 .47349 L .56353 .47466 L p F P
0 g
s
0 0 0 r
.55231 .47787 m .56353 .47466 L .56637 .47349 L p F P
0 g
s
.088 0 0 r
.3436 .49565 m .34521 .4958 L .35554 .4967 L p F P
0 g
s
0 .558 .744 r
.35433 .49646 m .34521 .4958 L .35554 .4967 L p F P
0 g
s
0 .558 .744 r
.35554 .4967 m .35765 .49685 L .35433 .49646 L p F P
0 g
s
.568 .017 0 r
.30831 .35715 m .30268 .35398 L .31052 .35577 L p F P
0 g
s
.568 .017 0 r
.30952 .35741 m .30831 .35715 L p .31052 .35577 L F P
0 g
s
.568 .017 0 r
.31052 .35577 m .31248 .35676 L .30952 .35741 L p F P
0 g
s
.053 .515 .891 r
.18168 .30378 m .18656 .30524 L .19154 .30808 L p F P
0 g
s
.04 .5 .885 r
.18656 .30524 m .18168 .30378 L .17813 .30117 L p F P
0 g
s
.356 0 0 r
.46323 .36291 m .45929 .36354 L .45678 .36603 L p F P
0 g
s
.079 0 0 r
.3436 .49565 m .34521 .4958 L .34283 .49558 L closepath p F P
0 g
s
.568 0 0 r
.28137 .34617 m .28254 .34687 L .28012 .34609 L closepath p F P
0 g
s
.347 .646 .966 r
.14717 .28968 m .14947 .28994 L .15384 .29303 L p F P
0 g
s
.367 .663 .971 r
.15732 .29068 m .14947 .28994 L .15384 .29303 L p F P
0 g
s
.367 .663 .971 r
.15384 .29303 m .16089 .29361 L .15732 .29068 L p F P
0 g
s
.575 .058 0 r
.33897 .36521 m .33306 .36211 L .34212 .36348 L p F P
0 g
s
.575 .058 0 r
.3411 .36552 m .33897 .36521 L p .34212 .36348 L F P
0 g
s
.575 .058 0 r
.34212 .36348 m .34374 .36423 L .3411 .36552 L p F P
0 g
s
.405 0 0 r
.44562 .36594 m .45567 .36616 L .44391 .36765 L closepath p F P
0 g
s
.53 .038 .032 r
.38917 .36908 m .39137 .36977 L .38837 .3697 L closepath p F P
0 g
s
.111 .664 .752 r
.45788 .49569 m .45643 .49575 L .44904 .49648 L closepath p F P
0 g
s
.126 .676 .771 r
.45332 .49584 m .45643 .49575 L .44904 .49648 L p F P
0 g
s
.126 .676 .771 r
.44229 .4969 m .45332 .49584 L p .44904 .49648 L F P
0 g
s
.445 0 0 r
.26492 .33992 m .26413 .33977 L .26339 .33943 L closepath p F P
0 g
s
.191 0 0 r
.50995 .351 m .51018 .35078 L .49906 .35348 L p F P
0 g
s
.191 0 0 r
.49906 .35348 m .49838 .35409 L .50995 .351 L p F P
0 g
s
.908 .688 .594 r
.05922 .33666 m .06331 .33983 L p .06102 .3318 L F P
0 g
s
.916 .671 .554 r
.05847 .34181 m .06258 .34497 L .06331 .33983 L p F P
0 g
s
.916 .671 .554 r
.06331 .33983 m .05922 .33666 L .05847 .34181 L p F P
0 g
s
.881 .479 .259 r
.08861 .38808 m .08707 .38386 L .09163 .38679 L p F P
0 g
s
.881 .479 .259 r
.09163 .38679 m .09247 .38903 L .08861 .38808 L p F P
0 g
s
0 0 0 r
.54666 .33683 m .54842 .33567 L .53765 .33973 L p F P
0 g
s
0 0 0 r
.53765 .33973 m .53546 .34121 L .54666 .33683 L p F P
0 g
s
.343 .198 .535 r
.74673 .33861 m .73916 .34495 L .73874 .33973 L p F P
0 g
s
.343 .198 .535 r
.73874 .33973 m .74595 .33367 L .74673 .33861 L p F P
0 g
s
.322 0 0 r
.24266 .47605 m .23576 .47358 L .23221 .47277 L p F P
0 g
s
0 .473 .702 r
.30783 .49095 m .29823 .48925 L .2948 .48865 L p F P
0 g
s
.713 .857 .951 r
.67583 .28242 m .66449 .28739 L .66179 .28559 L p F P
0 g
s
.712 .879 .959 r
.65048 .29096 m .66179 .28559 L .66449 .28739 L p F P
0 g
s
0 0 0 r
.66568 .42575 m .66451 .42742 L .67371 .42142 L closepath p F P
0 g
s
.899 .702 .627 r
.06054 .33108 m .06045 .33136 L .06102 .3318 L closepath p F P
0 g
s
.908 .688 .594 r
.06102 .3318 m .06045 .33136 L .05922 .33666 L p F P
0 g
s
.153 0 .192 r
.71173 .38888 m .70967 .39029 L .7106 .3866 L p F P
0 g
s
.153 0 .192 r
.7106 .3866 m .71748 .38189 L .71173 .38888 L p F P
0 g
s
0 0 0 r
.65381 .43356 m .65326 .43422 L .65806 .43141 L closepath p F P
0 g
s
.349 0 0 r
.24337 .33151 m .23882 .32935 L .24488 .33177 L p F P
0 g
s
.349 0 0 r
.24488 .33177 m .24691 .33266 L .24337 .33151 L p F P
0 g
s
0 .354 .703 r
.22617 .32342 m .22128 .32135 L .22693 .32394 L p F P
0 g
s
0 .354 .703 r
.22693 .32394 m .22971 .32502 L .22617 .32342 L p F P
0 g
s
.262 .041 .378 r
.73006 .3657 m .72562 .36897 L .72817 .36299 L p F P
0 g
s
.262 .041 .378 r
.72817 .36299 m .73039 .36135 L .73006 .3657 L p F P
0 g
s
0 .459 .826 r
.20897 .31507 m .20396 .31328 L .20926 .316 L p F P
0 g
s
0 .459 .826 r
.20926 .316 m .21252 .31708 L .20897 .31507 L p F P
0 g
s
.743 .758 .864 r
.08433 .28468 m .08776 .28257 L .08413 .27912 L p F P
0 g
s
.743 .758 .864 r
.08413 .27912 m .08049 .28135 L .08433 .28468 L p F P
0 g
s
.756 .757 .854 r
.07335 .28608 m .08049 .28135 L .08433 .28468 L p F P
0 g
s
.212 .593 .947 r
.16445 .29649 m .16865 .29737 L .17333 .30033 L p F P
0 g
s
.245 .617 .957 r
.17457 .29849 m .16865 .29737 L .17333 .30033 L p F P
0 g
s
.245 .617 .957 r
.17333 .30033 m .17813 .30117 L .17457 .29849 L p F P
0 g
s
.444 0 0 r
.2606 .33911 m .25683 .33718 L .26339 .33943 L p F P
0 g
s
.444 0 0 r
.26339 .33943 m .26413 .33977 L .2606 .33911 L p F P
0 g
s
0 0 0 r
.51294 .48747 m .51805 .48642 L .52452 .48505 L p F P
0 g
s
0 0 0 r
.51294 .48747 m .51805 .48642 L .51257 .48756 L closepath p F P
0 g
s
.356 0 0 r
.46937 .36409 m .47078 .36254 L .46323 .36291 L p F P
0 g
s
.356 0 0 r
.45678 .36603 m .46937 .36409 L p .46323 .36291 L F P
0 g
s
.352 0 0 r
.47181 .36156 m .47078 .36254 L .46323 .36291 L closepath p F P
0 g
s
.099 .549 .911 r
.19178 .30669 m .18656 .30524 L .19154 .30808 L p F P
0 g
s
.099 .549 .911 r
.19154 .30808 m .19533 .30906 L .19178 .30669 L p F P
0 g
s
.69 .147 0 r
.14604 .43417 m .1424 .43076 L .14772 .43335 L p F P
0 g
s
.69 .147 0 r
.14772 .43335 m .14976 .43523 L .14604 .43417 L p F P
0 g
s
.202 .582 .942 r
.16865 .29737 m .16445 .29649 L .16089 .29361 L p F P
0 g
s
.773 .27 0 r
.12322 .41893 m .12824 .42165 L .12507 .41767 L p F P
0 g
s
.773 .27 0 r
.12507 .41767 m .12002 .41496 L .12322 .41893 L p F P
0 g
s
.901 .706 .629 r
.06045 .33136 m .06054 .33108 L .05702 .32628 L p F P
0 g
s
.429 .864 .767 r
.57533 .32362 m .57477 .32378 L .57996 .32128 L closepath p F P
0 g
s
0 0 0 r
.5917 .46454 m .59163 .46458 L .59319 .46399 L closepath p F P
0 g
s
.445 0 .017 r
.43148 .368 m .43544 .36839 L .43065 .36882 L closepath p F P
0 g
s
.873 .465 .25 r
.09247 .38903 m .09333 .39119 L .09804 .39405 L p F P
0 g
s
.856 .42 .18 r
.09545 .39546 m .10015 .39833 L .09804 .39405 L p F P
0 g
s
.856 .42 .18 r
.09804 .39405 m .09333 .39119 L .09545 .39546 L p F P
0 g
s
.507 .02 .036 r
.40325 .36958 m .40436 .36986 L .40291 .36988 L closepath p F P
0 g
s
.022 0 0 r
.6772 .41753 m .67575 .42001 L .68617 .41239 L closepath p F P
0 g
s
.901 .706 .629 r
.05702 .32628 m .05643 .32815 L .06045 .33136 L p F P
0 g
s
.911 .692 .594 r
.05519 .33346 m .05922 .33666 L .06045 .33136 L p F P
0 g
s
.911 .692 .594 r
.06045 .33136 m .05643 .32815 L .05519 .33346 L p F P
0 g
s
.01 .58 .772 r
.35209 .49616 m .35433 .49646 L .34521 .4958 L p F P
0 g
s
.01 .58 .772 r
.34879 .49585 m .35209 .49616 L p .34521 .4958 L F P
0 g
s
.01 .58 .772 r
.34026 .49522 m .34879 .49585 L p .34521 .4958 L F P
0 g
s
.01 .58 .772 r
.34521 .4958 m .34283 .49558 L .34026 .49522 L p F P
0 g
s
.225 0 0 r
.27322 .48413 m .26694 .48248 L .26344 .48181 L p F P
0 g
s
.59 .641 .87 r
.7199 .28328 m .72099 .28515 L .73262 .28367 L p F P
0 g
s
.594 .596 .824 r
.73525 .28916 m .73484 .28954 L p .72099 .28515 L F P
0 g
s
.594 .596 .824 r
.72099 .28515 m .73262 .28367 L .73525 .28916 L p F P
0 g
s
0 0 0 r
.6507 .43704 m .65167 .43609 L .64156 .44096 L p F P
0 g
s
0 0 0 r
.64156 .44096 m .63941 .4431 L .6507 .43704 L p F P
0 g
s
0 0 0 r
.59319 .46399 m .59163 .46458 L .58886 .46607 L p F P
0 g
s
.63 .74 .927 r
.10192 .28134 m .11232 .27843 L .11592 .28177 L p F P
0 g
s
.627 .739 .927 r
.11232 .27843 m .10192 .28134 L .09831 .27794 L p F P
0 g
s
.693 .752 .897 r
.08776 .28257 m .09831 .27794 L .10192 .28134 L p F P
0 g
s
.552 .719 .95 r
.11592 .28177 m .12115 .28106 L .12529 .28426 L p F P
0 g
s
.561 .724 .95 r
.12621 .28034 m .12115 .28106 L .12529 .28426 L p F P
0 g
s
.561 .724 .95 r
.12529 .28426 m .1298 .28358 L .12621 .28034 L p F P
0 g
s
0 0 0 r
.62634 .45006 m .62813 .44859 L .61686 .45368 L p F P
0 g
s
0 0 0 r
.61686 .45368 m .6159 .45447 L .62634 .45006 L p F P
0 g
s
.142 .687 .769 r
.46895 .49448 m .45788 .49569 L .45643 .49575 L p F P
0 g
s
.585 .015 0 r
.28092 .34799 m .28792 .35008 L .28254 .34687 L p F P
0 g
s
.585 .015 0 r
.27786 .34598 m .28092 .34799 L p .28254 .34687 L F P
0 g
s
.585 .015 0 r
.28254 .34687 m .28012 .34609 L .27786 .34598 L p F P
0 g
s
.024 .593 .774 r
.36843 .49738 m .35765 .49685 L .35433 .49646 L p F P
0 g
s
.478 0 .031 r
.41736 .36922 m .41881 .36948 L .41698 .36957 L closepath p F P
0 g
s
0 .542 .741 r
.34283 .49558 m .34026 .49522 L .3354 .49474 L closepath p F P
0 g
s
.322 0 0 r
.24957 .47802 m .24962 .47804 L .25699 .47989 L p F P
0 g
s
.262 0 0 r
.25815 .48053 m .24962 .47804 L .25699 .47989 L p F P
0 g
s
.262 0 0 r
.2616 .48143 m .25815 .48053 L p .25699 .47989 L F P
0 g
s
.262 0 0 r
.25699 .47989 m .26344 .48181 L .2616 .48143 L p F P
0 g
s
.692 .752 .898 r
.09831 .27794 m .08776 .28257 L .08413 .27912 L p F P
0 g
s
.586 .014 0 r
.26882 .34259 m .26413 .33977 L .2606 .33911 L p F P
0 g
s
.871 .741 .716 r
.05315 .3103 m .05705 .31359 L .0606 .3075 L p F P
0 g
s
.871 .741 .716 r
.0606 .3075 m .05672 .30421 L .05315 .3103 L p F P
0 g
s
.76 .252 0 r
.13288 .42373 m .13339 .42432 L .13156 .42339 L closepath p F P
0 g
s
.173 .706 .724 r
.51805 .48642 m .51257 .48756 L .50996 .48802 L p F P
0 g
s
.597 .085 .005 r
.34374 .36423 m .34819 .36654 L .3411 .36552 L closepath p F P
0 g
s
.556 0 0 r
.18395 .45369 m .18429 .4539 L .19036 .45621 L p F P
0 g
s
.492 0 0 r
.19012 .45714 m .19612 .45947 L .19036 .45621 L p F P
0 g
s
.492 0 0 r
.19036 .45621 m .18429 .4539 L .19012 .45714 L p F P
0 g
s
0 0 0 r
.60015 .46183 m .60246 .46058 L .59319 .46399 L p F P
0 g
s
0 0 0 r
.58886 .46607 m .60015 .46183 L p .59319 .46399 L F P
0 g
s
0 0 0 r
.60289 .4603 m .59319 .46399 L .60246 .46058 L closepath p F P
0 g
s
.16 0 0 r
.29096 .48793 m .28089 .48588 L .28906 .48746 L p F P
0 g
s
.16 0 0 r
.29164 .48807 m .29096 .48793 L p .28906 .48746 L F P
0 g
s
.16 0 0 r
.28906 .48746 m .2948 .48865 L .29164 .48807 L p F P
0 g
s
.221 0 0 r
.28084 .48586 m .28089 .48588 L .28906 .48746 L p F P
0 g
s
.487 0 0 r
.20118 .46116 m .20229 .46174 L .20866 .46394 L p F P
0 g
s
.438 0 0 r
.20877 .4648 m .20229 .46174 L .20866 .46394 L p F P
0 g
s
.438 0 0 r
.2146 .46687 m .20877 .4648 L p .20866 .46394 L F P
0 g
s
.438 0 0 r
.20866 .46394 m .21486 .46693 L .2146 .46687 L p F P
0 g
s
.6 .074 0 r
.33004 .36378 m .33897 .36521 L .33306 .36211 L p F P
0 g
s
.6 .074 0 r
.32636 .36157 m .33004 .36378 L p .33306 .36211 L F P
0 g
s
.6 .074 0 r
.33306 .36211 m .32762 .36112 L .32636 .36157 L p F P
0 g
s
.652 .954 .944 r
.63141 .298 m .62522 .30114 L .62249 .30073 L p F P
0 g
s
.513 .031 .048 r
.40436 .36986 m .40291 .36988 L .40018 .37231 L p F P
0 g
s
.54 .061 .068 r
.39926 .3723 m .40018 .37231 L .40291 .36988 L p F P
0 g
s
.54 .061 .068 r
.40291 .36988 m .39137 .36977 L .39926 .3723 L p F P
0 g
s
.609 .07 0 r
.31248 .35676 m .31614 .35894 L .30952 .35741 L closepath p F P
0 g
s
.517 .042 .066 r
.41698 .36957 m .40436 .36986 L .41315 .3721 L p F P
0 g
s
.513 .031 .048 r
.40018 .37231 m .41315 .3721 L .40436 .36986 L p F P
0 g
s
.049 0 0 r
.5349 .34167 m .53546 .34121 L .52429 .34506 L p F P
0 g
s
.049 0 0 r
.52429 .34506 m .52386 .34541 L .5349 .34167 L p F P
0 g
s
.838 .382 .129 r
.10255 .40252 m .10731 .40536 L .10492 .40117 L p F P
0 g
s
.838 .382 .129 r
.10492 .40117 m .10015 .39833 L .10255 .40252 L p F P
0 g
s
.809 .331 .068 r
.11358 .40899 m .11246 .40865 L .11214 .40817 L closepath p F P
0 g
s
.145 .686 .713 r
.5082 .48831 m .50996 .48802 L .49883 .49009 L p F P
0 g
s
.145 .686 .713 r
.49883 .49009 m .49598 .49057 L .5082 .48831 L p F P
0 g
s
0 0 0 r
.49598 .49057 m .49883 .49009 L p .4847 .49237 L F P
0 g
s
.559 .935 .857 r
.60848 .30673 m .61123 .3066 L .59999 .3123 L p F P
0 g
s
.559 .935 .857 r
.6072 .30741 m .60848 .30673 L p .59999 .3123 L F P
0 g
s
.559 .935 .857 r
.59999 .3123 m .59874 .31248 L .6072 .30741 L p F P
0 g
s
.536 .048 .044 r
.38669 .37206 m .39926 .3723 L .39137 .36977 L p F P
0 g
s
.536 .048 .044 r
.38583 .37174 m .38669 .37206 L p .39137 .36977 L F P
0 g
s
.536 .048 .044 r
.39137 .36977 m .38837 .3697 L .38583 .37174 L p F P
0 g
s
.549 .716 .95 r
.12115 .28106 m .11592 .28177 L .11232 .27843 L p F P
0 g
s
.201 0 0 r
.5075 .35339 m .50995 .351 L .49838 .35409 L p F P
0 g
s
.201 0 0 r
.50029 .35528 m .5075 .35339 L p .49838 .35409 L F P
0 g
s
.201 0 0 r
.49838 .35409 m .49604 .35627 L .50029 .35528 L p F P
0 g
s
.617 .05 0 r
.1668 .44511 m .16753 .44565 L .17332 .44807 L p F P
0 g
s
.559 0 0 r
.17272 .44907 m .17846 .4515 L .17332 .44807 L p F P
0 g
s
.559 0 0 r
.17332 .44807 m .16753 .44565 L .17272 .44907 L p F P
0 g
s
.492 .451 .74 r
.74121 .30455 m .74384 .30536 L .74202 .30706 L closepath p F P
0 g
s
.467 .412 .712 r
.75037 .30844 m .74406 .3143 L .74202 .30706 L p F P
0 g
s
.467 .412 .712 r
.74202 .30706 m .74384 .30536 L .75037 .30844 L p F P
0 g
s
.482 .461 .758 r
.73924 .29888 m .74121 .30455 L .74384 .30536 L p F P
0 g
s
.339 .639 .964 r
.14947 .28994 m .14717 .28968 L .1436 .28659 L p F P
0 g
s
.048 0 0 r
.68837 .40889 m .68697 .41176 L .69629 .40407 L closepath p F P
0 g
s
.557 .072 .06 r
.38837 .3697 m .38583 .37174 L .37943 .36934 L closepath p F P
0 g
s
.615 .069 0 r
.29516 .3519 m .29535 .35202 L .30268 .35398 L p F P
0 g
s
.622 .079 0 r
.30051 .35533 m .30831 .35715 L .30268 .35398 L p F P
0 g
s
.622 .079 0 r
.30268 .35398 m .29535 .35202 L .30051 .35533 L p F P
0 g
s
.454 .378 .681 r
.74349 .3148 m .74406 .3143 L .74431 .31534 L closepath p F P
0 g
s
0 0 0 r
.56299 .47488 m .56353 .47466 L .55231 .47787 L p F P
0 g
s
0 0 0 r
.55231 .47787 m .55166 .47813 L .56299 .47488 L p F P
0 g
s
.898 .713 .644 r
.05346 .32183 m .05435 .31939 L .05833 .32262 L p F P
0 g
s
.898 .713 .644 r
.05833 .32262 m .05702 .32628 L .05346 .32183 L p F P
0 g
s
.41 0 0 r
.21846 .46773 m .22169 .46914 L .22835 .47123 L p F P
0 g
s
.406 0 0 r
.22169 .46914 m .21846 .46773 L .21486 .46693 L p F P
0 g
s
.685 .934 .967 r
.64778 .28974 m .65036 .2909 L .64985 .29126 L p F P
0 g
s
.685 .934 .967 r
.63649 .29545 m .64778 .28974 L p .64985 .29126 L F P
0 g
s
.698 .919 .968 r
.65048 .29096 m .64985 .29126 L .65036 .2909 L closepath p F P
0 g
s
.534 0 0 r
.28012 .34609 m .27786 .34598 L .27558 .34477 L closepath p F P
0 g
s
0 0 0 r
.62893 .44792 m .62813 .44859 L .6372 .44422 L closepath p F P
0 g
s
.484 .006 .043 r
.41881 .36948 m .41698 .36957 L .41437 .37208 L p F P
0 g
s
.517 .042 .066 r
.41315 .3721 m .41437 .37208 L .41698 .36957 L p F P
0 g
s
0 0 0 r
.65806 .43141 m .65326 .43422 L .65167 .43609 L p F P
0 g
s
.046 .611 .778 r
.38185 .49794 m .37172 .49768 L .36843 .49738 L p F P
0 g
s
.353 .808 .687 r
.57996 .32128 m .57477 .32378 L .57213 .32487 L p F P
0 g
s
.701 .161 0 r
.13194 .42548 m .13713 .42813 L .13339 .42432 L p F P
0 g
s
.701 .161 0 r
.12912 .42261 m .13194 .42548 L p .13339 .42432 L F P
0 g
s
.701 .161 0 r
.13339 .42432 m .13156 .42339 L .12912 .42261 L p F P
0 g
s
.487 .012 .052 r
.43065 .36882 m .42826 .3712 L .41881 .36948 L closepath p F P
0 g
s
.484 .006 .043 r
.42811 .37137 m .42826 .3712 L .41881 .36948 L p F P
0 g
s
.484 .006 .043 r
.41437 .37208 m .42811 .37137 L p .41881 .36948 L F P
0 g
s
.614 .66 .871 r
.71825 .28054 m .72377 .27948 L .7199 .28328 L closepath p F P
0 g
s
.59 .641 .87 r
.72985 .27841 m .72377 .27948 L .7199 .28328 L p F P
0 g
s
.59 .641 .87 r
.73262 .28367 m .72985 .27841 L p .7199 .28328 L F P
0 g
s
.709 .921 .965 r
.65918 .28408 m .66179 .28559 L .65048 .29096 L p F P
0 g
s
.709 .921 .965 r
.65048 .29096 m .65036 .2909 L .65918 .28408 L p F P
0 g
s
.111 0 0 r
.31221 .49162 m .31676 .4923 L .32578 .49361 L p F P
0 g
s
.11 0 0 r
.31221 .49162 m .31676 .4923 L .30943 .49123 L closepath p F P
0 g
s
.314 0 0 r
.48187 .36139 m .484 .3592 L .47181 .36156 L p F P
0 g
s
.314 0 0 r
.47181 .36156 m .47078 .36254 L .48187 .36139 L p F P
0 g
s
.524 .506 .778 r
.73828 .29637 m .74142 .29679 L .73924 .29888 L closepath p F P
0 g
s
.482 .461 .758 r
.7502 .29886 m .74142 .29679 L .73924 .29888 L p F P
0 g
s
.482 .461 .758 r
.75033 .29928 m .7502 .29886 L p .73924 .29888 L F P
0 g
s
.482 .461 .758 r
.74384 .30536 m .75033 .29928 L p .73924 .29888 L F P
0 g
s
0 0 0 r
.55894 .33126 m .56073 .33018 L .54953 .33495 L p F P
0 g
s
0 0 0 r
.54953 .33495 m .54842 .33567 L .55894 .33126 L p F P
0 g
s
.876 .469 .248 r
.09333 .39119 m .09247 .38903 L .08861 .38808 L p F P
0 g
s
.36 0 0 r
.22864 .47193 m .22169 .46914 L .22835 .47123 L p F P
0 g
s
.36 0 0 r
.22835 .47123 m .23221 .47277 L .22864 .47193 L p F P
0 g
s
0 .559 .763 r
.3369 .49471 m .34026 .49522 L .3354 .49474 L p F P
0 g
s
0 .559 .763 r
.32621 .49367 m .3369 .49471 L p .3354 .49474 L F P
0 g
s
0 .559 .763 r
.3354 .49474 m .32647 .49371 L .32621 .49367 L p F P
0 g
s
.696 .83 .947 r
.6767 .28319 m .67583 .28242 L .67937 .28094 L closepath p F P
0 g
s
.528 0 0 r
.25062 .33481 m .24691 .33266 L .24337 .33151 L p F P
0 g
s
.556 .06 .033 r
.3855 .37202 m .38583 .37174 L .37943 .36934 L p F P
0 g
s
.556 .06 .033 r
.37507 .37151 m .3855 .37202 L p .37943 .36934 L F P
0 g
s
.556 .06 .033 r
.37175 .37005 m .37507 .37151 L p .37943 .36934 L F P
0 g
s
.556 .06 .033 r
.37943 .36934 m .37328 .36897 L .37175 .37005 L p F P
0 g
s
.634 .957 .923 r
.61232 .30665 m .61123 .3066 L .61767 .30323 L closepath p F P
0 g
s
.709 .923 .964 r
.6591 .28403 m .65918 .28408 L .65036 .2909 L p F P
0 g
s
.709 .923 .964 r
.65036 .2909 m .64778 .28974 L .6591 .28403 L p F P
0 g
s
.24 .024 .372 r
.73476 .36205 m .73006 .3657 L .73039 .36135 L p F P
0 g
s
.24 .024 .372 r
.73039 .36135 m .73711 .35612 L .73476 .36205 L p F P
0 g
s
.415 .352 .678 r
.75337 .31065 m .75037 .30844 L .74406 .3143 L p F P
0 g
s
.415 .352 .678 r
.75393 .31317 m .75337 .31065 L p .74406 .3143 L F P
0 g
s
.415 .352 .678 r
.74812 .31849 m .75393 .31317 L p .74406 .3143 L F P
0 g
s
.415 .352 .678 r
.74406 .3143 m .74431 .31534 L .74812 .31849 L p F P
0 g
s
.127 .676 .75 r
.47084 .49426 m .47057 .49428 L .46895 .49448 L closepath p F P
0 g
s
.142 .687 .769 r
.46749 .4944 m .47057 .49428 L .46895 .49448 L p F P
0 g
s
.142 .687 .769 r
.45643 .49575 m .46749 .4944 L p .46895 .49448 L F P
0 g
s
.273 0 0 r
.49587 .35645 m .49604 .35627 L .48493 .35825 L p F P
0 g
s
.273 0 0 r
.48493 .35825 m .484 .3592 L .49587 .35645 L p F P
0 g
s
.543 .515 .775 r
.74142 .29679 m .73828 .29637 L .73542 .28953 L p F P
0 g
s
.67 .12 0 r
.14976 .43523 m .15186 .43705 L .15738 .43957 L p F P
0 g
s
.626 .061 0 r
.15645 .44064 m .16192 .44317 L .15738 .43957 L p F P
0 g
s
.626 .061 0 r
.15738 .43957 m .15186 .43705 L .15645 .44064 L p F P
0 g
s
0 0 0 r
.4847 .49237 m .49434 .49083 L .49598 .49057 L p F P
0 g
s
.125 .673 .715 r
.4847 .49237 m .49434 .49083 L .48351 .49253 L closepath p F P
0 g
s
.809 .329 .059 r
.10868 .4074 m .10731 .40536 L .11214 .40817 L p F P
0 g
s
.809 .329 .059 r
.11214 .40817 m .11246 .40865 L .10868 .4074 L p F P
0 g
s
.432 .352 .666 r
.74431 .31534 m .74812 .31849 L .74554 .32084 L closepath p F P
0 g
s
.57 .077 .046 r
.37328 .36897 m .37175 .37005 L .36837 .36862 L closepath p F P
0 g
s
.217 0 .315 r
.72953 .36981 m .72213 .37525 L .72562 .36897 L p F P
0 g
s
.217 0 .315 r
.72562 .36897 m .73006 .3657 L .72953 .36981 L p F P
0 g
s
.591 .062 0 r
.32762 .36112 m .32636 .36157 L .32447 .36057 L closepath p F P
0 g
s
.052 0 0 r
.53255 .34361 m .5349 .34167 L .52386 .34541 L p F P
0 g
s
.052 0 0 r
.52386 .34541 m .52135 .34749 L .53255 .34361 L p F P
0 g
s
.162 .702 .768 r
.48165 .49265 m .48351 .49253 L .47084 .49426 L p F P
0 g
s
.162 .702 .768 r
.47084 .49426 m .47057 .49428 L .48165 .49265 L p F P
0 g
s
.157 .693 .703 r
.52452 .48505 m .5241 .48513 L .51805 .48642 L closepath p F P
0 g
s
.173 .706 .724 r
.52114 .48566 m .5241 .48513 L .51805 .48642 L p F P
0 g
s
.173 .706 .724 r
.50996 .48802 m .52114 .48566 L p .51805 .48642 L F P
0 g
s
.915 .587 .409 r
.06723 .36267 m .07153 .36574 L .07095 .36101 L p F P
0 g
s
.915 .587 .409 r
.07095 .36101 m .06665 .35794 L .06723 .36267 L p F P
0 g
s
.05 .616 .767 r
.38581 .49819 m .39432 .4982 L .38281 .49798 L closepath p F P
0 g
s
.422 0 0 r
.22971 .32502 m .23304 .32681 L .23882 .32935 L p F P
0 g
s
.436 0 0 r
.23304 .32681 m .22971 .32502 L .22617 .32342 L p F P
0 g
s
.449 0 .026 r
.43544 .36839 m .43065 .36882 L .42826 .3712 L p F P
0 g
s
.815 .759 .8 r
.05852 .29315 m .06458 .2871 L .06837 .29045 L p F P
0 g
s
.815 .759 .8 r
.06837 .29045 m .06219 .29665 L .05852 .29315 L p F P
0 g
s
.797 .761 .82 r
.06837 .29045 m .07335 .28608 L .0697 .28262 L p F P
0 g
s
.797 .761 .82 r
.0697 .28262 m .06458 .2871 L .06837 .29045 L p F P
0 g
s
0 0 0 r
.57195 .32495 m .57213 .32487 L .56188 .32963 L p F P
0 g
s
0 0 0 r
.56188 .32963 m .56073 .33018 L .57195 .32495 L p F P
0 g
s
.675 .752 .909 r
.6899 .28039 m .70133 .27629 L .70403 .27967 L p F P
0 g
s
.687 .777 .92 r
.70133 .27629 m .6899 .28039 L .68721 .27767 L p F P
0 g
s
.647 .695 .88 r
.70403 .27967 m .71553 .27638 L .71825 .28054 L p F P
0 g
s
.66 .721 .894 r
.71553 .27638 m .70403 .27967 L .70133 .27629 L p F P
0 g
s
.908 .554 .358 r
.07248 .37036 m .07685 .37339 L .0759 .36877 L p F P
0 g
s
.908 .554 .358 r
.0759 .36877 m .07153 .36574 L .07248 .37036 L p F P
0 g
s
.919 .617 .456 r
.06242 .35484 m .06665 .35794 L .06648 .35309 L p F P
0 g
s
.919 .617 .456 r
.06232 .35181 m .06242 .35484 L p .06648 .35309 L F P
0 g
s
.919 .617 .456 r
.06648 .35309 m .06438 .35155 L .06232 .35181 L p F P
0 g
s
.321 .149 .486 r
.73931 .34985 m .73851 .35049 L .73886 .3452 L p F P
0 g
s
.321 .149 .486 r
.73886 .3452 m .73916 .34495 L .73931 .34985 L p F P
0 g
s
.017 0 0 r
.66451 .42742 m .65806 .43141 L .66376 .42848 L closepath p F P
0 g
s
0 0 0 r
.662 .43055 m .66376 .42848 L .65806 .43141 L p F P
0 g
s
0 0 0 r
.65889 .4324 m .662 .43055 L p .65806 .43141 L F P
0 g
s
0 0 0 r
.65167 .43609 m .65889 .4324 L p .65806 .43141 L F P
0 g
s
.755 .759 .856 r
.08049 .28135 m .07335 .28608 L .0697 .28262 L p F P
0 g
s
.573 .089 .067 r
.36427 .3707 m .35808 .36765 L .36837 .36862 L p F P
0 g
s
.573 .089 .067 r
.37027 .37119 m .36427 .3707 L p .36837 .36862 L F P
0 g
s
.573 .089 .067 r
.36837 .36862 m .37175 .37005 L .37027 .37119 L p F P
0 g
s
.174 0 .25 r
.72053 .37641 m .72021 .37808 L .72213 .37525 L closepath p F P
0 g
s
.67 .12 0 r
.15186 .43705 m .14976 .43523 L .14604 .43417 L p F P
0 g
s
.898 .519 .307 r
.07814 .3779 m .08257 .3809 L .08128 .37638 L p F P
0 g
s
.898 .519 .307 r
.08128 .37638 m .07685 .37339 L .07814 .3779 L p F P
0 g
s
.676 .948 .957 r
.63649 .29545 m .63141 .298 L .63557 .29522 L closepath p F P
0 g
s
.652 .954 .944 r
.63377 .29477 m .63557 .29522 L .63141 .298 L p F P
0 g
s
.652 .954 .944 r
.62249 .30073 m .63377 .29477 L p .63141 .298 L F P
0 g
s
.479 0 0 r
.20118 .46116 m .20229 .46174 L .19966 .46081 L closepath p F P
0 g
s
.799 .311 .04 r
.11504 .41221 m .11246 .40865 L .10868 .4074 L p F P
0 g
s
.379 0 0 r
.23884 .32982 m .23304 .32681 L .23882 .32935 L p F P
0 g
s
.379 0 0 r
.24122 .33078 m .23884 .32982 L p .23882 .32935 L F P
0 g
s
.379 0 0 r
.23882 .32935 m .24337 .33151 L .24122 .33078 L p F P
0 g
s
.473 0 0 r
.25618 .33792 m .25062 .33481 L .25683 .33718 L p F P
0 g
s
.473 0 0 r
.25813 .33861 m .25618 .33792 L p .25683 .33718 L F P
0 g
s
.473 0 0 r
.25683 .33718 m .2606 .33911 L .25813 .33861 L p F P
0 g
s
.736 .212 0 r
.13156 .42339 m .12912 .42261 L .12824 .42165 L closepath p F P
0 g
s
.841 .756 .769 r
.06128 .29777 m .06219 .29665 L .05852 .29315 L p F P
0 g
s
.921 .651 .51 r
.05817 .34681 m .06228 .34997 L .06258 .34497 L p F P
0 g
s
.921 .651 .51 r
.06258 .34497 m .05847 .34181 L .05817 .34681 L p F P
0 g
s
.301 .135 .481 r
.74644 .34389 m .73931 .34985 L .73916 .34495 L p F P
0 g
s
.301 .135 .481 r
.73916 .34495 m .74673 .33861 L .74644 .34389 L p F P
0 g
s
0 .279 .652 r
.21252 .31708 m .21586 .31868 L .22128 .32135 L p F P
0 g
s
0 .261 .647 r
.21586 .31868 m .21252 .31708 L .20897 .31507 L p F P
0 g
s
.887 .731 .682 r
.05044 .31611 m .05435 .31939 L .05705 .31359 L p F P
0 g
s
.887 .731 .682 r
.05705 .31359 m .05315 .3103 L .05044 .31611 L p F P
0 g
s
.073 0 .046 r
.69919 .39981 m .69815 .40241 L .70468 .39627 L closepath p F P
0 g
s
.166 .705 .776 r
.48165 .49265 m .47057 .49428 L .46749 .4944 L p F P
0 g
s
.593 .068 0 r
.32164 .36218 m .31614 .35894 L .32447 .36057 L p F P
0 g
s
.593 .068 0 r
.32374 .36256 m .32164 .36218 L p .32447 .36057 L F P
0 g
s
.593 .068 0 r
.32447 .36057 m .32636 .36157 L .32374 .36256 L p F P
0 g
s
.453 0 .032 r
.44391 .36765 m .44244 .36915 L .43544 .36839 L closepath p F P
0 g
s
.449 0 .026 r
.44147 .37026 m .44244 .36915 L .43544 .36839 L p F P
0 g
s
.449 0 .026 r
.42895 .3713 m .44147 .37026 L p .43544 .36839 L F P
0 g
s
.449 0 .026 r
.42826 .3712 m .42895 .3713 L p .43544 .36839 L F P
0 g
s
0 0 0 r
.56067 .47557 m .56299 .47488 L .55166 .47813 L p F P
0 g
s
0 0 0 r
.55166 .47813 m .54943 .4788 L .56067 .47557 L p F P
0 g
s
0 .326 .684 r
.22206 .32152 m .21586 .31868 L .22128 .32135 L p F P
0 g
s
0 .326 .684 r
.22353 .32219 m .22206 .32152 L p .22128 .32135 L F P
0 g
s
0 .326 .684 r
.22128 .32135 m .22617 .32342 L .22353 .32219 L p F P
0 g
s
.461 .692 .967 r
.1298 .28358 m .14001 .28345 L .1436 .28659 L p F P
0 g
s
.458 .688 .965 r
.14001 .28345 m .1298 .28358 L .12621 .28034 L p F P
0 g
s
.058 .623 .756 r
.41179 .49814 m .41403 .49821 L p .39991 .49836 L F P
0 g
s
.058 .623 .756 r
.39991 .49836 m .40766 .49818 L .41179 .49814 L p F P
0 g
s
.072 .633 .772 r
.39991 .49836 m .40766 .49818 L .39749 .49824 L closepath p F P
0 g
s
.31 0 0 r
.24957 .47802 m .24962 .47804 L .24951 .47801 L closepath p F P
0 g
s
.209 0 0 r
.28084 .48586 m .28089 .48588 L .2808 .48586 L closepath p F P
0 g
s
.339 .639 .964 r
.1436 .28659 m .14522 .28679 L .14947 .28994 L p F P
0 g
s
.358 .655 .969 r
.15375 .2877 m .14522 .28679 L .14947 .28994 L p F P
0 g
s
.358 .655 .969 r
.14947 .28994 m .15732 .29068 L .15375 .2877 L p F P
0 g
s
.841 .756 .769 r
.05852 .29315 m .05749 .29443 L .06128 .29777 L p F P
0 g
s
.855 .752 .748 r
.0529 .30088 m .05672 .30421 L .06128 .29777 L p F P
0 g
s
.855 .752 .748 r
.06128 .29777 m .05749 .29443 L .0529 .30088 L p F P
0 g
s
.379 .256 .584 r
.74736 .33247 m .74595 .33367 L .74398 .32912 L p F P
0 g
s
.379 .256 .584 r
.74398 .32912 m .74662 .32687 L .74736 .33247 L p F P
0 g
s
.392 .839 .732 r
.58599 .31839 m .57996 .32128 L .58538 .3186 L closepath p F P
0 g
s
.353 .808 .687 r
.5832 .31936 m .58538 .3186 L .57996 .32128 L p F P
0 g
s
.353 .808 .687 r
.57351 .32417 m .5832 .31936 L p .57996 .32128 L F P
0 g
s
.353 .808 .687 r
.57213 .32487 m .57351 .32417 L p .57996 .32128 L F P
0 g
s
0 .477 .722 r
.28305 .48625 m .29096 .48793 L .28089 .48588 L p F P
0 g
s
0 .477 .722 r
.27737 .4851 m .28305 .48625 L p .28089 .48588 L F P
0 g
s
.172 0 0 r
.2808 .48586 m .27737 .4851 L .27322 .48413 L closepath p F P
0 g
s
0 .477 .722 r
.28089 .48588 m .2808 .48586 L .27737 .4851 L p F P
0 g
s
.207 0 0 r
.25098 .4786 m .25815 .48053 L .24962 .47804 L p F P
0 g
s
.207 0 0 r
.24604 .47716 m .25098 .4786 L p .24962 .47804 L F P
0 g
s
.207 0 0 r
.24962 .47804 m .24951 .47801 L .24604 .47716 L p F P
0 g
s
0 .519 .73 r
.32647 .49371 m .32621 .49367 L .32578 .49361 L closepath p F P
0 g
s
.532 0 0 r
.2743 .34576 m .26882 .34259 L .27558 .34477 L p F P
0 g
s
.532 0 0 r
.27437 .34578 m .2743 .34576 L p .27558 .34477 L F P
0 g
s
.532 0 0 r
.27558 .34477 m .27786 .34598 L .27437 .34578 L p F P
0 g
s
.274 0 0 r
.24951 .47801 m .24604 .47716 L .24266 .47605 L closepath p F P
0 g
s
0 0 0 r
.62547 .45064 m .62634 .45006 L .6159 .45447 L p F P
0 g
s
0 0 0 r
.6159 .45447 m .61417 .45564 L .62547 .45064 L p F P
0 g
s
.885 .483 .257 r
.08419 .38532 m .08257 .3809 L .08707 .38386 L p F P
0 g
s
.885 .483 .257 r
.08817 .38795 m .08419 .38532 L p .08707 .38386 L F P
0 g
s
.885 .483 .257 r
.08707 .38386 m .08861 .38808 L .08817 .38795 L p F P
0 g
s
0 .531 .75 r
.32283 .49305 m .31676 .4923 L .32578 .49361 L p F P
0 g
s
0 .531 .75 r
.32578 .49361 m .32621 .49367 L .32283 .49305 L p F P
0 g
s
0 .395 .786 r
.19533 .30906 m .19885 .31049 L .20396 .31328 L p F P
0 g
s
0 .437 .813 r
.20542 .313 m .19885 .31049 L .20396 .31328 L p F P
0 g
s
0 .437 .813 r
.20396 .31328 m .20897 .31507 L .20542 .313 L p F P
0 g
s
.904 .71 .63 r
.05643 .32815 m .05702 .32628 L .05346 .32183 L p F P
0 g
s
0 .378 .78 r
.19885 .31049 m .19533 .30906 L .19178 .30669 L p F P
0 g
s
.692 .852 .959 r
.67937 .28094 m .67583 .28242 L .67314 .28033 L p F P
0 g
s
.713 .857 .951 r
.66179 .28559 m .67314 .28033 L .67583 .28242 L p F P
0 g
s
.143 .688 .77 r
.46749 .4944 m .45643 .49575 L .45332 .49584 L p F P
0 g
s
.467 .412 .713 r
.75239 .30656 m .75037 .30844 L .74384 .30536 L p F P
0 g
s
.467 .412 .713 r
.74384 .30536 m .75033 .29928 L .75239 .30656 L p F P
0 g
s
0 0 0 r
.57761 .46996 m .5776 .46996 L .57777 .46991 L closepath p F P
0 g
s
0 0 0 r
.54782 .47926 m .54943 .4788 L .53821 .48171 L p F P
0 g
s
0 0 0 r
.53821 .48171 m .53626 .48227 L .54782 .47926 L p F P
0 g
s
.691 .148 0 r
.14114 .43188 m .13713 .42813 L .1424 .43076 L p F P
0 g
s
.691 .148 0 r
.14519 .43391 m .14114 .43188 L p .1424 .43076 L F P
0 g
s
.691 .148 0 r
.1424 .43076 m .14604 .43417 L .14519 .43391 L p F P
0 g
s
0 0 0 r
.57777 .46991 m .5776 .46996 L .57478 .47112 L p F P
0 g
s
0 0 0 r
.56353 .47466 m .57478 .47112 L .5776 .46996 L p F P
0 g
s
.092 .649 .775 r
.41403 .49821 m .42214 .49782 L .41179 .49814 L closepath p F P
0 g
s
.074 .636 .755 r
.42574 .49769 m .42816 .49772 L p .41403 .49821 L F P
0 g
s
.074 .636 .755 r
.41403 .49821 m .42214 .49782 L .42574 .49769 L p F P
0 g
s
.919 .675 .553 r
.05443 .33861 m .05847 .34181 L .05922 .33666 L p F P
0 g
s
.919 .675 .553 r
.05922 .33666 m .05519 .33346 L .05443 .33861 L p F P
0 g
s
0 0 0 r
.58886 .46607 m .57777 .46991 L .58855 .46623 L closepath p F P
0 g
s
0 0 0 r
.58607 .46725 m .58855 .46623 L .57777 .46991 L p F P
0 g
s
0 0 0 r
.57478 .47112 m .58607 .46725 L p .57777 .46991 L F P
0 g
s
.04 .5 .885 r
.17813 .30117 m .18174 .30232 L .18656 .30524 L p F P
0 g
s
.08 .533 .903 r
.18822 .30426 m .18174 .30232 L .18656 .30524 L p F P
0 g
s
.08 .533 .903 r
.18656 .30524 m .19178 .30669 L .18822 .30426 L p F P
0 g
s
.564 .567 .815 r
.73484 .28954 m .73525 .28916 L .73542 .28953 L closepath p F P
0 g
s
0 .568 .782 r
.3369 .49471 m .32621 .49367 L .32283 .49305 L p F P
0 g
s
.549 0 0 r
.18395 .45369 m .18429 .4539 L .18341 .45356 L closepath p F P
0 g
s
.202 .582 .942 r
.16089 .29361 m .16411 .29434 L .16865 .29737 L p F P
0 g
s
.232 .605 .952 r
.171 .29576 m .16411 .29434 L .16865 .29737 L p F P
0 g
s
.232 .605 .952 r
.16865 .29737 m .17457 .29849 L .171 .29576 L p F P
0 g
s
.588 .089 .036 r
.35772 .36748 m .35808 .36765 L .35754 .36759 L closepath p F P
0 g
s
.769 .262 0 r
.11826 .41618 m .12322 .41893 L .12002 .41496 L p F P
0 g
s
.769 .262 0 r
.12002 .41496 m .11504 .41221 L .11826 .41618 L p F P
0 g
s
.612 .043 0 r
.1668 .44511 m .16753 .44565 L .16546 .44476 L closepath p F P
0 g
s
.131 .679 .777 r
.4527 .49584 m .45332 .49584 L .44229 .4969 L p F P
0 g
s
.131 .679 .777 r
.44229 .4969 m .43938 .49693 L .4527 .49584 L p F P
0 g
s
.398 .301 .627 r
.75125 .32267 m .74662 .32687 L .74554 .32084 L p F P
0 g
s
.398 .301 .627 r
.74554 .32084 m .74812 .31849 L .75125 .32267 L p F P
0 g
s
.111 .664 .776 r
.42816 .49772 m .43814 .49701 L .42574 .49769 L closepath p F P
0 g
s
.628 .663 .865 r
.72377 .27948 m .71825 .28054 L .71553 .27638 L p F P
0 g
s
.61 .057 0 r
.29516 .3519 m .29535 .35202 L .29497 .35191 L closepath p F P
0 g
s
.029 .486 .88 r
.18174 .30232 m .17813 .30117 L .17457 .29849 L p F P
0 g
s
0 0 0 r
.6372 .44422 m .62813 .44859 L .62634 .45006 L p F P
0 g
s
0 0 0 r
.67371 .42142 m .66451 .42742 L .66376 .42848 L p F P
0 g
s
.623 .076 0 r
.29321 .35334 m .30051 .35533 L .29535 .35202 L p F P
0 g
s
.623 .076 0 r
.29165 .35225 m .29321 .35334 L p .29535 .35202 L F P
0 g
s
.623 .076 0 r
.29535 .35202 m .29497 .35191 L .29165 .35225 L p F P
0 g
s
.543 .515 .775 r
.74748 .291 m .74142 .29679 L p .73542 .28953 L F P
0 g
s
.543 .515 .775 r
.73542 .28953 m .74723 .29033 L .74748 .291 L p F P
0 g
s
.532 .549 .819 r
.73525 .28916 m .73542 .28953 L .74723 .29033 L p F P
0 g
s
.876 .469 .248 r
.08861 .38808 m .08869 .38828 L .09333 .39119 L p F P
0 g
s
.857 .418 .168 r
.09082 .39255 m .09545 .39546 L .09333 .39119 L p F P
0 g
s
.857 .418 .168 r
.09333 .39119 m .08869 .38828 L .09082 .39255 L p F P
0 g
s
.594 .1 .051 r
.35433 .36965 m .36427 .3707 L .35808 .36765 L p F P
0 g
s
.594 .1 .051 r
.35808 .36765 m .35754 .36759 L .35433 .36965 L p F P
0 g
s
.379 0 0 r
.20255 .46254 m .20877 .4648 L .20229 .46174 L p F P
0 g
s
.379 0 0 r
.19755 .4602 m .20255 .46254 L p .20229 .46174 L F P
0 g
s
.379 0 0 r
.20229 .46174 m .19966 .46081 L .19755 .4602 L p F P
0 g
s
.453 0 0 r
.18418 .45477 m .19012 .45714 L .18429 .4539 L p F P
0 g
s
.453 0 0 r
.1803 .45261 m .18418 .45477 L p .18429 .4539 L F P
0 g
s
.453 0 0 r
.18429 .4539 m .18341 .45356 L .1803 .45261 L p F P
0 g
s
.41 0 .002 r
.45567 .36616 m .44391 .36765 L .44244 .36915 L p F P
0 g
s
.743 .759 .866 r
.08049 .28135 m .08413 .27912 L .08048 .27568 L p F P
0 g
s
.743 .759 .866 r
.08048 .27568 m .07672 .27798 L .08049 .28135 L p F P
0 g
s
.755 .759 .856 r
.0697 .28262 m .07672 .27798 L .08049 .28135 L p F P
0 g
s
.59 .034 0 r
.29497 .35191 m .29165 .35225 L .28792 .35008 L closepath p F P
0 g
s
.6 .108 .056 r
.35423 .36964 m .35433 .36965 L .35754 .36759 L p F P
0 g
s
.6 .108 .056 r
.35754 .36759 m .34819 .36654 L .35423 .36964 L p F P
0 g
s
.532 .549 .819 r
.74436 .28332 m .74108 .2833 L .73525 .28916 L p F P
0 g
s
.532 .549 .819 r
.74723 .29033 m .74436 .28332 L p .73525 .28916 L F P
0 g
s
.567 .582 .828 r
.73262 .28367 m .74108 .2833 L .73525 .28916 L closepath p F P
0 g
s
.694 .953 .953 r
.64508 .28875 m .64778 .28974 L .63649 .29545 L p F P
0 g
s
.694 .953 .953 r
.64244 .29015 m .64508 .28875 L p .63649 .29545 L F P
0 g
s
.694 .953 .953 r
.63649 .29545 m .63557 .29522 L .64244 .29015 L p F P
0 g
s
.191 .718 .72 r
.53529 .48247 m .53626 .48227 L .52452 .48505 L p F P
0 g
s
.191 .718 .72 r
.52452 .48505 m .5241 .48513 L .53529 .48247 L p F P
0 g
s
.172 0 .248 r
.7291 .37208 m .72953 .36981 L .72213 .37525 L p F P
0 g
s
.172 0 .248 r
.72729 .3748 m .7291 .37208 L p .72213 .37525 L F P
0 g
s
.172 0 .248 r
.71978 .3803 m .72729 .3748 L p .72213 .37525 L F P
0 g
s
.172 0 .248 r
.72213 .37525 m .72021 .37808 L .71978 .3803 L p F P
0 g
s
.503 .472 .756 r
.74142 .29679 m .74748 .291 L .7502 .29886 L closepath p F P
0 g
s
.556 .934 .853 r
.59874 .31248 m .59723 .3127 L .6072 .30741 L closepath p F P
0 g
s
.904 .71 .63 r
.05346 .32183 m .05247 .3249 L .05643 .32815 L p F P
0 g
s
.914 .696 .594 r
.05122 .33022 m .05519 .33346 L .05643 .32815 L p F P
0 g
s
.914 .696 .594 r
.05643 .32815 m .05247 .3249 L .05122 .33022 L p F P
0 g
s
0 0 0 r
.61306 .45638 m .61417 .45564 L .60289 .4603 L p F P
0 g
s
0 0 0 r
.60289 .4603 m .60246 .46058 L .61306 .45638 L p F P
0 g
s
.594 .948 .891 r
.61767 .30323 m .61123 .3066 L .60848 .30673 L p F P
0 g
s
.549 .716 .95 r
.11232 .27843 m .11711 .27781 L .12115 .28106 L p F P
0 g
s
.556 .721 .95 r
.12262 .27705 m .11711 .27781 L .12115 .28106 L p F P
0 g
s
.556 .721 .95 r
.12115 .28106 m .12621 .28034 L .12262 .27705 L p F P
0 g
s
.514 0 0 r
.18341 .45356 m .1803 .45261 L .17846 .4515 L closepath p F P
0 g
s
.921 .624 .464 r
.06438 .35155 m .06232 .35181 L .06228 .34997 L closepath p F P
0 g
s
.523 0 0 r
.16706 .4466 m .17272 .44907 L .16753 .44565 L p F P
0 g
s
.523 0 0 r
.16311 .44401 m .16706 .4466 L p .16753 .44565 L F P
0 g
s
.523 0 0 r
.16753 .44565 m .16546 .44476 L .16311 .44401 L p F P
0 g
s
.343 0 0 r
.48159 .36172 m .48187 .36139 L .47078 .36254 L p F P
0 g
s
.343 0 0 r
.47078 .36254 m .46937 .36409 L .48159 .36172 L p F P
0 g
s
.696 .825 .945 r
.68721 .27767 m .67937 .28094 L .68519 .27583 L closepath p F P
0 g
s
.692 .852 .959 r
.68452 .27522 m .68519 .27583 L .67937 .28094 L p F P
0 g
s
.692 .852 .959 r
.67314 .28033 m .68452 .27522 L p .67937 .28094 L F P
0 g
s
.155 0 0 r
.52126 .34758 m .52135 .34749 L .51018 .35078 L p F P
0 g
s
.155 0 0 r
.51018 .35078 m .50995 .351 L .52126 .34758 L p F P
0 g
s
.406 0 0 r
.21486 .46693 m .21507 .46703 L .22169 .46914 L p F P
0 g
s
.351 0 0 r
.22234 .46986 m .21507 .46703 L .22169 .46914 L p F P
0 g
s
.351 0 0 r
.22838 .47187 m .22234 .46986 L p .22169 .46914 L F P
0 g
s
.351 0 0 r
.22169 .46914 m .22864 .47193 L .22838 .47187 L p F P
0 g
s
.193 .571 .938 r
.16411 .29434 m .16089 .29361 L .15732 .29068 L p F P
0 g
s
.627 .739 .927 r
.09831 .27794 m .10871 .27507 L .11232 .27843 L p F P
0 g
s
.626 .737 .927 r
.10871 .27507 m .09831 .27794 L .09468 .27452 L p F P
0 g
s
.692 .752 .898 r
.08413 .27912 m .09468 .27452 L .09831 .27794 L p F P
0 g
s
0 0 0 r
.55789 .33191 m .55894 .33126 L .54842 .33567 L p F P
0 g
s
0 0 0 r
.54842 .33567 m .54666 .33683 L .55789 .33191 L p F P
0 g
s
.287 0 0 r
.49354 .35903 m .49587 .35645 L .484 .3592 L p F P
0 g
s
.287 0 0 r
.48592 .36073 m .49354 .35903 L p .484 .3592 L F P
0 g
s
.287 0 0 r
.484 .3592 m .48187 .36139 L .48592 .36073 L p F P
0 g
s
.195 .725 .785 r
.49434 .49083 m .48351 .49253 L .48165 .49265 L p F P
0 g
s
.873 .745 .718 r
.04933 .30698 m .05315 .3103 L .05672 .30421 L p F P
0 g
s
.873 .745 .718 r
.05672 .30421 m .0529 .30088 L .04933 .30698 L p F P
0 g
s
.837 .379 .116 r
.09787 .39964 m .10255 .40252 L .10015 .39833 L p F P
0 g
s
.837 .379 .116 r
.10015 .39833 m .09545 .39546 L .09787 .39964 L p F P
0 g
s
.691 .752 .898 r
.09468 .27452 m .08413 .27912 L .08048 .27568 L p F P
0 g
s
.439 .866 .747 r
.59519 .31323 m .59723 .3127 L .58599 .31839 L p F P
0 g
s
.439 .866 .747 r
.58599 .31839 m .58538 .3186 L .59519 .31323 L p F P
0 g
s
.623 .106 0 r
.32636 .36157 m .33004 .36378 L .32374 .36256 L closepath p F P
0 g
s
.193 0 .255 r
.72021 .37808 m .71748 .38189 L .71978 .3803 L closepath p F P
0 g
s
.714 .899 .962 r
.67045 .27847 m .67314 .28033 L .66179 .28559 L p F P
0 g
s
.714 .899 .962 r
.65943 .28387 m .67045 .27847 L p .66179 .28559 L F P
0 g
s
.714 .899 .962 r
.66179 .28559 m .65918 .28408 L .65943 .28387 L p F P
0 g
s
0 .553 .775 r
.31944 .49241 m .32283 .49305 L .31676 .4923 L p F P
0 g
s
0 .553 .775 r
.30879 .4911 m .31944 .49241 L p .31676 .4923 L F P
0 g
s
0 .553 .775 r
.31676 .4923 m .30943 .49123 L .30879 .4911 L p F P
0 g
s
.621 .088 0 r
.31341 .3605 m .32164 .36218 L .31614 .35894 L p F P
0 g
s
.621 .088 0 r
.30899 .35754 m .31341 .3605 L p .31614 .35894 L F P
0 g
s
.621 .088 0 r
.31614 .35894 m .30952 .35741 L .30899 .35754 L p F P
0 g
s
.094 0 .108 r
.70967 .39029 m .70925 .39156 L .71173 .38888 L closepath p F P
0 g
s
.734 .208 0 r
.12537 .42131 m .12322 .41893 L .12824 .42165 L p F P
0 g
s
.734 .208 0 r
.12824 .42165 m .12912 .42261 L .12537 .42131 L p F P
0 g
s
.021 .587 .786 r
.34879 .49585 m .34026 .49522 L .3369 .49471 L p F P
0 g
s
.165 0 0 r
.51885 .34998 m .52126 .34758 L .50995 .351 L p F P
0 g
s
.165 0 0 r
.50995 .351 m .5075 .35339 L .51885 .34998 L p F P
0 g
s
.199 .724 .73 r
.53529 .48247 m .5241 .48513 L .52114 .48566 L p F P
0 g
s
.443 0 0 r
.19966 .46081 m .19755 .4602 L .19612 .45947 L closepath p F P
0 g
s
.322 0 0 r
.23221 .47277 m .23574 .47404 L .24266 .47605 L p F P
0 g
s
.317 0 0 r
.23574 .47404 m .23221 .47277 L .22864 .47193 L p F P
0 g
s
.605 .099 .022 r
.34454 .36845 m .35423 .36964 L .34819 .36654 L p F P
0 g
s
.605 .099 .022 r
.3403 .36593 m .34454 .36845 L p .34819 .36654 L F P
0 g
s
.605 .099 .022 r
.34819 .36654 m .3411 .36552 L .3403 .36593 L p F P
0 g
s
.045 0 0 r
.67575 .42001 m .67371 .42142 L .67549 .42045 L closepath p F P
0 g
s
0 0 0 r
.67356 .42314 m .67549 .42045 L .67371 .42142 L p F P
0 g
s
0 0 0 r
.66376 .42848 m .67356 .42314 L p .67371 .42142 L F P
0 g
s
0 .473 .702 r
.2948 .48865 m .29938 .48945 L .30783 .49095 L p F P
0 g
s
0 .473 .703 r
.2948 .48865 m .29938 .48945 L .29164 .48807 L closepath p F P
0 g
s
0 0 0 r
.56919 .32646 m .57195 .32495 L .56073 .33018 L p F P
0 g
s
0 0 0 r
.56073 .33018 m .55894 .33126 L .56919 .32646 L p F P
0 g
s
.901 .718 .646 r
.04985 .31771 m .05044 .31611 L .05435 .31939 L p F P
0 g
s
.901 .718 .646 r
.05435 .31939 m .05346 .32183 L .04985 .31771 L p F P
0 g
s
.546 .713 .95 r
.11711 .27781 m .11232 .27843 L .10871 .27507 L p F P
0 g
s
0 0 0 r
.54569 .3376 m .54666 .33683 L .53546 .34121 L p F P
0 g
s
0 0 0 r
.53546 .34121 m .5349 .34167 L .54569 .3376 L p F P
0 g
s
.167 0 0 r
.27389 .48431 m .26557 .48237 L .27322 .48413 L p F P
0 g
s
.167 0 0 r
.27322 .48413 m .27737 .4851 L .27389 .48431 L p F P
0 g
s
.225 0 0 r
.26344 .48181 m .26557 .48237 L .27322 .48413 L p F P
0 g
s
.67 .12 0 r
.14604 .43417 m .14641 .4345 L .15186 .43705 L p F P
0 g
s
.614 .045 0 r
.15103 .43807 m .15645 .44064 L .15186 .43705 L p F P
0 g
s
.614 .045 0 r
.15186 .43705 m .14641 .4345 L .15103 .43807 L p F P
0 g
s
0 0 0 r
.61145 .45724 m .61306 .45638 L .60246 .46058 L p F P
0 g
s
0 0 0 r
.60246 .46058 m .60015 .46183 L .61145 .45724 L p F P
0 g
s
.604 .039 0 r
.27786 .34598 m .28092 .34799 L .27437 .34578 L closepath p F P
0 g
s
.578 .001 0 r
.16546 .44476 m .16311 .44401 L .16192 .44317 L closepath p F P
0 g
s
.333 .632 .961 r
.14522 .28679 m .1436 .28659 L .14001 .28345 L p F P
0 g
s
.018 0 0 r
.68617 .41239 m .67575 .42001 L .67549 .42045 L p F P
0 g
s
.268 0 0 r
.2425 .47626 m .23574 .47404 L .24266 .47605 L p F P
0 g
s
.268 0 0 r
.24266 .47605 m .24604 .47716 L .2425 .47626 L p F P
0 g
s
.139 0 .179 r
.71884 .38395 m .71173 .38888 L .71748 .38189 L p F P
0 g
s
.139 0 .179 r
.71748 .38189 m .71978 .3803 L .71884 .38395 L p F P
0 g
s
.526 0 0 r
.2499 .33556 m .25618 .33792 L .25062 .33481 L p F P
0 g
s
.526 0 0 r
.25062 .33481 m .24469 .33233 L .2499 .33556 L p F P
0 g
s
.528 0 0 r
.24337 .33151 m .24469 .33233 L .25062 .33481 L p F P
0 g
s
.278 .084 .429 r
.73922 .35446 m .73711 .35612 L .73851 .35049 L p F P
0 g
s
.278 .084 .429 r
.73851 .35049 m .73931 .34985 L .73922 .35446 L p F P
0 g
s
.412 0 .001 r
.45678 .36603 m .45662 .36619 L .45567 .36616 L closepath p F P
0 g
s
.41 0 .002 r
.45443 .36871 m .45662 .36619 L .45567 .36616 L p F P
0 g
s
.41 0 .002 r
.44795 .36948 m .45443 .36871 L p .45567 .36616 L F P
0 g
s
.41 0 .002 r
.44244 .36915 m .44795 .36948 L p .45567 .36616 L F P
0 g
s
.58 .097 .073 r
.37175 .37005 m .37507 .37151 L .37027 .37119 L closepath p F P
0 g
s
.586 .014 0 r
.2606 .33911 m .26242 .34029 L .26882 .34259 L p F P
0 g
s
.585 .011 0 r
.26751 .34358 m .2743 .34576 L .26882 .34259 L p F P
0 g
s
.585 .011 0 r
.26882 .34259 m .26242 .34029 L .26751 .34358 L p F P
0 g
s
.812 .332 .056 r
.10488 .40605 m .10255 .40252 L .10731 .40536 L p F P
0 g
s
.812 .332 .056 r
.10731 .40536 m .10868 .4074 L .10488 .40605 L p F P
0 g
s
.361 .243 .582 r
.75313 .32726 m .74736 .33247 L .74662 .32687 L p F P
0 g
s
.361 .243 .582 r
.74662 .32687 m .75125 .32267 L .75313 .32726 L p F P
0 g
s
.436 0 0 r
.22617 .32342 m .2275 .32419 L .23304 .32681 L p F P
0 g
s
.43 0 0 r
.23297 .3273 m .23884 .32982 L .23304 .32681 L p F P
0 g
s
.43 0 0 r
.23304 .32681 m .2275 .32419 L .23297 .3273 L p F P
0 g
s
.382 0 0 r
.46767 .36598 m .46937 .36409 L .45678 .36603 L p F P
0 g
s
.382 0 0 r
.45678 .36603 m .45662 .36619 L .46767 .36598 L p F P
0 g
s
.627 .956 .92 r
.62249 .30073 m .61767 .30323 L .62171 .3007 L closepath p F P
0 g
s
.594 .948 .891 r
.61976 .30062 m .62171 .3007 L .61767 .30323 L p F P
0 g
s
.594 .948 .891 r
.60848 .30673 m .61976 .30062 L p .61767 .30323 L F P
0 g
s
0 0 0 r
.57415 .47138 m .57478 .47112 L .56353 .47466 L p F P
0 g
s
0 0 0 r
.56353 .47466 m .56299 .47488 L .57415 .47138 L p F P
0 g
s
.217 0 0 r
.26344 .48181 m .26557 .48237 L .2616 .48143 L closepath p F P
0 g
s
.693 .953 .953 r
.63557 .29522 m .63377 .29477 L .64244 .29015 L closepath p F P
0 g
s
.628 .663 .865 r
.7281 .27537 m .72377 .27948 L p .71553 .27638 L F P
0 g
s
.608 .647 .863 r
.72377 .27948 m .7281 .27537 L .72985 .27841 L closepath p F P
0 g
s
.918 .59 .404 r
.063 .35957 m .06723 .36267 L .06665 .35794 L p F P
0 g
s
.918 .59 .404 r
.06665 .35794 m .06242 .35484 L .063 .35957 L p F P
0 g
s
.59 .033 0 r
.28604 .35131 m .28092 .34799 L .28792 .35008 L p F P
0 g
s
.59 .033 0 r
.29007 .35241 m .28604 .35131 L p .28792 .35008 L F P
0 g
s
.59 .033 0 r
.28792 .35008 m .29165 .35225 L .29007 .35241 L p F P
0 g
s
0 .261 .647 r
.20897 .31507 m .21065 .31593 L .21586 .31868 L p F P
0 g
s
0 .274 .66 r
.21653 .31887 m .22206 .32152 L .21586 .31868 L p F P
0 g
s
0 .274 .66 r
.21586 .31868 m .21065 .31593 L .21653 .31887 L p F P
0 g
s
.585 .589 .822 r
.74108 .2833 m .73262 .28367 L .72985 .27841 L p F P
0 g
s
.911 .556 .352 r
.06818 .36729 m .07248 .37036 L .07153 .36574 L p F P
0 g
s
.911 .556 .352 r
.07153 .36574 m .06723 .36267 L .06818 .36729 L p F P
0 g
s
0 0 0 r
.63941 .4431 m .6372 .44422 L .63921 .4433 L closepath p F P
0 g
s
0 0 0 r
.63679 .44527 m .63921 .4433 L .6372 .44422 L p F P
0 g
s
0 0 0 r
.63502 .44614 m .63679 .44527 L p .6372 .44422 L F P
0 g
s
0 0 0 r
.62634 .45006 m .63502 .44614 L p .6372 .44422 L F P
0 g
s
.717 .184 0 r
.13194 .42548 m .12912 .42261 L .12537 .42131 L p F P
0 g
s
.192 0 .307 r
.73152 .36827 m .72953 .36981 L .73006 .3657 L p F P
0 g
s
.192 0 .307 r
.73006 .3657 m .73476 .36205 L .73152 .36827 L p F P
0 g
s
0 0 0 r
.67329 .42345 m .67356 .42314 L .66376 .42848 L p F P
0 g
s
0 0 0 r
.66376 .42848 m .662 .43055 L .67329 .42345 L p F P
0 g
s
.441 .866 .744 r
.59445 .31342 m .59519 .31323 L .58538 .3186 L p F P
0 g
s
.441 .866 .744 r
.58538 .3186 m .5832 .31936 L .59445 .31342 L p F P
0 g
s
.024 .593 .774 r
.36768 .49729 m .36843 .49738 L p .35433 .49646 L F P
0 g
s
.024 .593 .774 r
.35433 .49646 m .35933 .4967 L .36768 .49729 L p F P
0 g
s
.028 .595 .778 r
.35433 .49646 m .35933 .4967 L .35209 .49616 L closepath p F P
0 g
s
.405 0 .032 r
.46705 .36676 m .46767 .36598 L .45662 .36619 L p F P
0 g
s
.405 0 .032 r
.45662 .36619 m .45443 .36871 L .46705 .36676 L p F P
0 g
s
.924 .626 .462 r
.05827 .35169 m .05817 .34681 L .06228 .34997 L p F P
0 g
s
.924 .626 .462 r
.0585 .35187 m .05827 .35169 L p .06228 .34997 L F P
0 g
s
.924 .626 .462 r
.06228 .34997 m .06232 .35181 L .0585 .35187 L p F P
0 g
s
0 .509 .739 r
.30943 .49123 m .30879 .4911 L .30783 .49095 L closepath p F P
0 g
s
.18 .712 .732 r
.52021 .48581 m .52114 .48566 L .50996 .48802 L p F P
0 g
s
.18 .712 .732 r
.50996 .48802 m .5082 .48831 L .52021 .48581 L p F P
0 g
s
.397 .3 .628 r
.75503 .31922 m .75125 .32267 L .74812 .31849 L p F P
0 g
s
.397 .3 .628 r
.74812 .31849 m .75393 .31317 L .75503 .31922 L p F P
0 g
s
.816 .762 .802 r
.05484 .28972 m .06086 .28371 L .06458 .2871 L p F P
0 g
s
.816 .762 .802 r
.06458 .2871 m .05852 .29315 L .05484 .28972 L p F P
0 g
s
.798 .763 .821 r
.06458 .2871 m .0697 .28262 L .06603 .27919 L p F P
0 g
s
.798 .763 .821 r
.06603 .27919 m .06086 .28371 L .06458 .2871 L p F P
0 g
s
.255 .068 .423 r
.74516 .3495 m .73922 .35446 L .73931 .34985 L p F P
0 g
s
.255 .068 .423 r
.73931 .34985 m .74644 .34389 L .74516 .3495 L p F P
0 g
s
.901 .521 .3 r
.07377 .37487 m .07814 .3779 L .07685 .37339 L p F P
0 g
s
.901 .521 .3 r
.07685 .37339 m .07248 .37036 L .07377 .37487 L p F P
0 g
s
.604 .097 .021 r
.3411 .36552 m .3403 .36593 L .33897 .36521 L closepath p F P
0 g
s
.018 0 0 r
.67549 .42045 m .68512 .41485 L p .68617 .41239 L F P
0 g
s
0 0 0 r
.68456 .41563 m .68512 .41485 L .67549 .42045 L p F P
0 g
s
0 0 0 r
.67516 .42221 m .68456 .41563 L p .67549 .42045 L F P
0 g
s
0 0 0 r
.67549 .42045 m .67356 .42314 L .67516 .42221 L p F P
0 g
s
.66 .721 .894 r
.70133 .27629 m .71282 .27259 L .71553 .27638 L p F P
0 g
s
.674 .747 .906 r
.71282 .27259 m .70133 .27629 L .69864 .27321 L p F P
0 g
s
.687 .777 .92 r
.68721 .27767 m .69864 .27321 L .70133 .27629 L p F P
0 g
s
.907 .715 .631 r
.05247 .3249 m .05346 .32183 L .04985 .31771 L p F P
0 g
s
.569 0 0 r
.2606 .33911 m .26242 .34029 L .25813 .33861 L closepath p F P
0 g
s
.755 .761 .858 r
.07672 .27798 m .0697 .28262 L .06603 .27919 L p F P
0 g
s
0 0 0 r
.65167 .43609 m .6507 .43704 L .65889 .4324 L closepath p F P
0 g
s
0 .378 .78 r
.19178 .30669 m .19392 .30762 L .19885 .31049 L p F P
0 g
s
0 .416 .8 r
.20042 .31032 m .19392 .30762 L .19885 .31049 L p F P
0 g
s
0 .416 .8 r
.20491 .3127 m .20042 .31032 L p .19885 .31049 L F P
0 g
s
0 .416 .8 r
.19885 .31049 m .20542 .313 L .20491 .3127 L p F P
0 g
s
0 .52 .756 r
.30538 .49035 m .29938 .48945 L .30783 .49095 L p F P
0 g
s
0 .52 .756 r
.30783 .49095 m .30879 .4911 L .30538 .49035 L p F P
0 g
s
.925 .655 .509 r
.05412 .34362 m .05817 .34681 L .05847 .34181 L p F P
0 g
s
.925 .655 .509 r
.05847 .34181 m .05443 .33861 L .05412 .34362 L p F P
0 g
s
.68 .132 0 r
.13597 .42921 m .14114 .43188 L .13713 .42813 L p F P
0 g
s
.68 .132 0 r
.13713 .42813 m .13194 .42548 L .13597 .42921 L p F P
0 g
s
.091 0 .105 r
.71814 .38607 m .71884 .38395 L .71173 .38888 L p F P
0 g
s
.091 0 .105 r
.71559 .38887 m .71814 .38607 L p .71173 .38888 L F P
0 g
s
.091 0 .105 r
.70853 .39375 m .71559 .38887 L p .71173 .38888 L F P
0 g
s
.091 0 .105 r
.71173 .38888 m .70925 .39156 L .70853 .39375 L p F P
0 g
s
.07 0 0 r
.68697 .41176 m .68617 .41239 L .68686 .41199 L closepath p F P
0 g
s
.018 0 0 r
.68512 .41485 m .68686 .41199 L .68617 .41239 L p F P
0 g
s
.333 .632 .961 r
.14001 .28345 m .14106 .28359 L .14522 .28679 L p F P
0 g
s
.351 .648 .966 r
.15016 .28465 m .14106 .28359 L .14522 .28679 L p F P
0 g
s
.351 .648 .966 r
.14522 .28679 m .15375 .2877 L .15016 .28465 L p F P
0 g
s
.842 .759 .771 r
.05749 .29443 m .05852 .29315 L .05484 .28972 L p F P
0 g
s
.435 0 0 r
.19393 .4591 m .19012 .45714 L .19612 .45947 L p F P
0 g
s
.435 0 0 r
.19612 .45947 m .19755 .4602 L .19393 .4591 L p F P
0 g
s
0 0 0 r
.64931 .4384 m .6507 .43704 L .63941 .4431 L p F P
0 g
s
0 0 0 r
.63941 .4431 m .63921 .4433 L .64931 .4384 L p F P
0 g
s
.601 .062 0 r
.30952 .35741 m .30899 .35754 L .30831 .35715 L closepath p F P
0 g
s
.89 .735 .683 r
.0466 .31279 m .05044 .31611 L .05315 .3103 L p F P
0 g
s
.89 .735 .683 r
.05315 .3103 m .04933 .30698 L .0466 .31279 L p F P
0 g
s
.045 0 0 r
.69629 .40407 m .68697 .41176 L .68686 .41199 L p F P
0 g
s
.179 .714 .766 r
.49598 .49057 m .49581 .49058 L .49434 .49083 L closepath p F P
0 g
s
.195 .725 .785 r
.49278 .49076 m .49581 .49058 L .49434 .49083 L p F P
0 g
s
.195 .725 .785 r
.48165 .49265 m .49278 .49076 L p .49434 .49083 L F P
0 g
s
0 0 0 r
.54378 .33913 m .54569 .3376 L .5349 .34167 L p F P
0 g
s
0 0 0 r
.5349 .34167 m .53255 .34361 L .54378 .33913 L p F P
0 g
s
.605 .104 .034 r
.33551 .36705 m .33004 .36378 L .33897 .36521 L p F P
0 g
s
.605 .104 .034 r
.33766 .36738 m .33551 .36705 L p .33897 .36521 L F P
0 g
s
.605 .104 .034 r
.33897 .36521 m .3403 .36593 L .33766 .36738 L p F P
0 g
s
.887 .484 .246 r
.07976 .38232 m .08419 .38532 L .08257 .3809 L p F P
0 g
s
.887 .484 .246 r
.08257 .3809 m .07814 .3779 L .07976 .38232 L p F P
0 g
s
.697 .826 .944 r
.69595 .27041 m .69864 .27321 L .68721 .27767 L p F P
0 g
s
.697 .826 .944 r
.68705 .27416 m .69595 .27041 L p .68721 .27767 L F P
0 g
s
.697 .826 .944 r
.68721 .27767 m .68519 .27583 L .68705 .27416 L p F P
0 g
s
.508 0 0 r
.17664 .45145 m .17272 .44907 L .17846 .4515 L p F P
0 g
s
.508 0 0 r
.17846 .4515 m .1803 .45261 L .17664 .45145 L p F P
0 g
s
.029 .486 .88 r
.17457 .29849 m .17707 .29935 L .18174 .30232 L p F P
0 g
s
.064 .517 .896 r
.18446 .30171 m .17707 .29935 L .18174 .30232 L p F P
0 g
s
.064 .517 .896 r
.18514 .3021 m .18446 .30171 L p .18174 .30232 L F P
0 g
s
.064 .517 .896 r
.18174 .30232 m .18822 .30426 L .18514 .3021 L p F P
0 g
s
.114 0 .114 r
.70925 .39156 m .70468 .39627 L .70853 .39375 L closepath p F P
0 g
s
.396 0 0 r
.21486 .46693 m .21507 .46703 L .2146 .46687 L closepath p F P
0 g
s
.799 .311 .04 r
.10868 .4074 m .11013 .40943 L .11504 .41221 L p F P
0 g
s
.765 .255 0 r
.11336 .41339 m .11826 .41618 L .11504 .41221 L p F P
0 g
s
.765 .255 0 r
.11504 .41221 m .11013 .40943 L .11336 .41339 L p F P
0 g
s
.842 .759 .771 r
.05484 .28972 m .05376 .29105 L .05749 .29443 L p F P
0 g
s
.857 .755 .75 r
.04916 .29751 m .0529 .30088 L .05749 .29443 L p F P
0 g
s
.857 .755 .75 r
.05749 .29443 m .05376 .29105 L .04916 .29751 L p F P
0 g
s
.339 .195 .535 r
.74779 .33771 m .74673 .33861 L .74595 .33367 L p F P
0 g
s
.339 .195 .535 r
.74595 .33367 m .74736 .33247 L .74779 .33771 L p F P
0 g
s
.628 .663 .865 r
.71553 .27638 m .7271 .27368 L .7281 .27537 L p F P
0 g
s
.643 .688 .878 r
.7271 .27368 m .71553 .27638 L .71282 .27259 L p F P
0 g
s
.722 .923 .96 r
.6591 .28403 m .64778 .28974 L .64508 .28875 L p F P
0 g
s
.654 .964 .918 r
.63106 .29434 m .63377 .29477 L .62249 .30073 L p F P
0 g
s
.654 .964 .918 r
.62988 .29499 m .63106 .29434 L p .62249 .30073 L F P
0 g
s
.654 .964 .918 r
.62249 .30073 m .62171 .3007 L .62988 .29499 L p F P
0 g
s
.602 .065 0 r
.30548 .35844 m .30051 .35533 L .30831 .35715 L p F P
0 g
s
.602 .065 0 r
.30831 .35715 m .30899 .35754 L .30548 .35844 L p F P
0 g
s
.193 .571 .938 r
.15732 .29068 m .1597 .29125 L .16411 .29434 L p F P
0 g
s
.221 .594 .948 r
.16743 .29296 m .1597 .29125 L .16411 .29434 L p F P
0 g
s
.221 .594 .948 r
.16411 .29434 m .171 .29576 L .16743 .29296 L p F P
0 g
s
.458 .688 .965 r
.12621 .28034 m .13643 .28027 L .14001 .28345 L p F P
0 g
s
.455 .684 .964 r
.13643 .28027 m .12621 .28034 L .12262 .27705 L p F P
0 g
s
.222 .732 .686 r
.57195 .47204 m .57415 .47138 L .56299 .47488 L p F P
0 g
s
.222 .732 .686 r
.56299 .47488 m .56067 .47557 L .57195 .47204 L p F P
0 g
s
.29 0 0 r
.21589 .46768 m .22234 .46986 L .21507 .46703 L p F P
0 g
s
.29 0 0 r
.21127 .46588 m .21589 .46768 L p .21507 .46703 L F P
0 g
s
.29 0 0 r
.21507 .46703 m .2146 .46687 L .21127 .46588 L p F P
0 g
s
.212 .737 .782 r
.50697 .48841 m .5082 .48831 L .49598 .49057 L p F P
0 g
s
.212 .737 .782 r
.49598 .49057 m .49581 .49058 L .50697 .48841 L p F P
0 g
s
.507 0 0 r
.24337 .33151 m .24469 .33233 L .24122 .33078 L closepath p F P
0 g
s
.879 .47 .24 r
.08861 .38808 m .08869 .38828 L .08817 .38795 L closepath p F P
0 g
s
.045 0 0 r
.68686 .41199 m .69633 .40615 L p .69629 .40407 L F P
0 g
s
0 0 0 r
.69581 .407 m .69633 .40615 L .68686 .41199 L p F P
0 g
s
0 0 0 r
.68813 .41301 m .69581 .407 L p .68686 .41199 L F P
0 g
s
0 0 0 r
.68686 .41199 m .68512 .41485 L .68813 .41301 L p F P
0 g
s
.069 0 .043 r
.7072 .397 m .70853 .39375 L .70468 .39627 L p F P
0 g
s
.069 0 .043 r
.69787 .40309 m .7072 .397 L p .70468 .39627 L F P
0 g
s
.069 0 .043 r
.70468 .39627 m .69815 .40241 L .69787 .40309 L p F P
0 g
s
.923 .679 .552 r
.05046 .33537 m .05443 .33861 L .05519 .33346 L p F P
0 g
s
.923 .679 .552 r
.05519 .33346 m .05122 .33022 L .05046 .33537 L p F P
0 g
s
.561 .086 .085 r
.38583 .37174 m .38669 .37206 L .3855 .37202 L closepath p F P
0 g
s
.094 0 .053 r
.69815 .40241 m .69629 .40407 L .69787 .40309 L closepath p F P
0 g
s
.045 0 0 r
.69633 .40615 m .69787 .40309 L .69629 .40407 L p F P
0 g
s
.046 .611 .778 r
.36843 .49738 m .37026 .49742 L .38185 .49794 L p F P
0 g
s
.054 .617 .787 r
.36843 .49738 m .37026 .49742 L .36768 .49729 L closepath p F P
0 g
s
0 .562 .794 r
.31944 .49241 m .30879 .4911 L .30538 .49035 L p F P
0 g
s
.36 0 0 r
.2146 .46687 m .21127 .46588 L .20877 .4648 L closepath p F P
0 g
s
0 0 0 r
.64811 .43936 m .64931 .4384 L .63921 .4433 L p F P
0 g
s
0 0 0 r
.63921 .4433 m .63679 .44527 L .64811 .43936 L p F P
0 g
s
.147 .685 .835 r
.40766 .49818 m .39749 .49824 L .39668 .49815 L p F P
0 g
s
.111 .66 .817 r
.39749 .49824 m .39668 .49815 L .39432 .4982 L closepath p F P
0 g
s
0 0 0 r
.59933 .46225 m .60015 .46183 L .58886 .46607 L p F P
0 g
s
0 0 0 r
.58886 .46607 m .58855 .46623 L .59933 .46225 L p F P
0 g
s
.853 .406 .141 r
.08626 .38961 m .09082 .39255 L .08869 .38828 L p F P
0 g
s
.853 .406 .141 r
.08478 .38662 m .08626 .38961 L p .08869 .38828 L F P
0 g
s
.853 .406 .141 r
.08869 .38828 m .08817 .38795 L .08478 .38662 L p F P
0 g
s
.127 .67 .832 r
.39343 .4977 m .39668 .49815 L .39432 .4982 L p F P
0 g
s
.127 .67 .832 r
.38254 .49795 m .39343 .4977 L p .39432 .4982 L F P
0 g
s
.127 .67 .832 r
.39432 .4982 m .38281 .49798 L .38254 .49795 L p F P
0 g
s
.132 .676 .821 r
.41179 .49814 m .41082 .49805 L .40766 .49818 L closepath p F P
0 g
s
.147 .685 .835 r
.40761 .49767 m .41082 .49805 L .40766 .49818 L p F P
0 g
s
.147 .685 .835 r
.39668 .49815 m .40761 .49767 L p .40766 .49818 L F P
0 g
s
.244 0 0 r
.49604 .35627 m .50029 .35528 L .49587 .35645 L closepath p F P
0 g
s
.222 .744 .795 r
.50697 .48841 m .49581 .49058 L .49278 .49076 L p F P
0 g
s
.165 .699 .837 r
.42214 .49782 m .41179 .49814 L .41082 .49805 L p F P
0 g
s
.573 0 0 r
.15943 .44276 m .15645 .44064 L .16192 .44317 L p F P
0 g
s
.573 0 0 r
.16192 .44317 m .16311 .44401 L .15943 .44276 L p F P
0 g
s
.41 0 0 r
.22617 .32342 m .2275 .32419 L .22353 .32219 L closepath p F P
0 g
s
.111 0 .168 r
.72195 .38167 m .71884 .38395 L .71978 .3803 L p F P
0 g
s
.111 0 .168 r
.71978 .3803 m .72729 .3748 L .72195 .38167 L p F P
0 g
s
0 .467 .73 r
.27287 .48406 m .27389 .48431 L .26557 .48237 L p F P
0 g
s
0 .467 .73 r
.2676 .48276 m .27287 .48406 L p .26557 .48237 L F P
0 g
s
0 .467 .73 r
.25993 .481 m .2676 .48276 L p .26557 .48237 L F P
0 g
s
0 .467 .73 r
.26557 .48237 m .2616 .48143 L .25993 .481 L p F P
0 g
s
.923 .622 .457 r
.06232 .35181 m .06242 .35484 L .0585 .35187 L closepath p F P
0 g
s
.443 0 .057 r
.44244 .36915 m .44795 .36948 L .44147 .37026 L closepath p F P
0 g
s
.089 .642 .812 r
.38281 .49798 m .38254 .49795 L .38185 .49794 L closepath p F P
0 g
s
.225 .742 .736 r
.54653 .47952 m .54782 .47926 L .53626 .48227 L p F P
0 g
s
.225 .742 .736 r
.53626 .48227 m .53529 .48247 L .54653 .47952 L p F P
0 g
s
.498 .903 .799 r
.6072 .30741 m .59723 .3127 L .59519 .31323 L p F P
0 g
s
0 .245 .642 r
.21065 .31593 m .20897 .31507 L .20542 .313 L p F P
0 g
s
0 0 0 r
.6235 .45195 m .62547 .45064 L .61417 .45564 L p F P
0 g
s
0 0 0 r
.61417 .45564 m .61306 .45638 L .6235 .45195 L p F P
0 g
s
.52 .043 .064 r
.41315 .3721 m .40018 .37231 L .39994 .37253 L p F P
0 g
s
.546 .073 .083 r
.40018 .37231 m .39994 .37253 L .39926 .3723 L closepath p F P
0 g
s
.11 .655 .833 r
.37927 .49743 m .37026 .49742 L .38185 .49794 L p F P
0 g
s
.11 .655 .833 r
.38185 .49794 m .38254 .49795 L .37927 .49743 L p F P
0 g
s
.55 .088 .11 r
.39382 .37485 m .38669 .37206 L .39926 .3723 L p F P
0 g
s
.55 .088 .11 r
.39761 .37491 m .39382 .37485 L p .39926 .3723 L F P
0 g
s
.55 .088 .11 r
.39926 .3723 m .39994 .37253 L .39761 .37491 L p F P
0 g
s
.662 .154 .025 r
.31341 .3605 m .30899 .35754 L .30548 .35844 L p F P
0 g
s
.868 .437 .18 r
.08817 .38795 m .08478 .38662 L .08419 .38532 L closepath p F P
0 g
s
.743 .76 .867 r
.07672 .27798 m .08048 .27568 L .07683 .27225 L p F P
0 g
s
.743 .76 .867 r
.07683 .27225 m .07302 .27458 L .07672 .27798 L p F P
0 g
s
.755 .761 .858 r
.06603 .27919 m .07302 .27458 L .07672 .27798 L p F P
0 g
s
0 .363 .774 r
.19392 .30762 m .19178 .30669 L .18822 .30426 L p F P
0 g
s
.15 .69 .822 r
.42574 .49769 m .42498 .49764 L .42214 .49782 L closepath p F P
0 g
s
.165 .699 .837 r
.4218 .49731 m .42498 .49764 L .42214 .49782 L p F P
0 g
s
.165 .699 .837 r
.41082 .49805 m .4218 .49731 L p .42214 .49782 L F P
0 g
s
.253 0 0 r
.50029 .35528 m .49587 .35645 L .49354 .35903 L p F P
0 g
s
0 0 0 r
.55919 .476 m .56067 .47557 L .54943 .4788 L p F P
0 g
s
0 0 0 r
.54943 .4788 m .54782 .47926 L .55919 .476 L p F P
0 g
s
.523 .053 .081 r
.41437 .37208 m .41409 .37235 L .41315 .3721 L closepath p F P
0 g
s
.52 .043 .064 r
.41191 .37476 m .41409 .37235 L .41315 .3721 L p F P
0 g
s
.52 .043 .064 r
.40719 .37484 m .41191 .37476 L p .41315 .3721 L F P
0 g
s
.52 .043 .064 r
.39994 .37253 m .40719 .37484 L p .41315 .3721 L F P
0 g
s
.801 .313 .034 r
.11013 .40943 m .10868 .4074 L .10488 .40605 L p F P
0 g
s
.512 .04 .072 r
.42573 .37412 m .42811 .37137 L .41437 .37208 L p F P
0 g
s
.512 .04 .072 r
.42222 .37429 m .42573 .37412 L p .41437 .37208 L F P
0 g
s
.512 .04 .072 r
.41437 .37208 m .41409 .37235 L .42222 .37429 L p F P
0 g
s
.567 .097 .099 r
.38278 .37451 m .39382 .37485 L .38669 .37206 L p F P
0 g
s
.567 .097 .099 r
.38669 .37206 m .3855 .37202 L .38278 .37451 L p F P
0 g
s
.546 .713 .95 r
.10871 .27507 m .11317 .27451 L .11711 .27781 L p F P
0 g
s
.553 .718 .949 r
.11901 .27373 m .11317 .27451 L .11711 .27781 L p F P
0 g
s
.553 .718 .949 r
.11711 .27781 m .12262 .27705 L .11901 .27373 L p F P
0 g
s
.666 .113 0 r
.14604 .43417 m .14641 .4345 L .14519 .43391 L closepath p F P
0 g
s
.181 .712 .837 r
.43814 .49701 m .42574 .49769 L .42498 .49764 L p F P
0 g
s
.907 .715 .631 r
.04985 .31771 m .04858 .32162 L .05247 .3249 L p F P
0 g
s
.917 .7 .593 r
.04732 .32694 m .05122 .33022 L .05247 .3249 L p F P
0 g
s
.917 .7 .593 r
.05247 .3249 m .04858 .32162 L .04732 .32694 L p F P
0 g
s
.585 .119 .113 r
.38168 .37446 m .38278 .37451 L .3855 .37202 L p F P
0 g
s
.585 .119 .113 r
.3855 .37202 m .37507 .37151 L .38168 .37446 L p F P
0 g
s
.367 .816 .688 r
.57213 .32487 m .57195 .32495 L .57351 .32417 L closepath p F P
0 g
s
.626 .13 .055 r
.3403 .36593 m .34454 .36845 L .33766 .36738 L closepath p F P
0 g
s
.718 .854 .947 r
.68452 .27522 m .67314 .28033 L .67045 .27847 L p F P
0 g
s
0 0 0 r
.59738 .46306 m .59933 .46225 L .58855 .46623 L p F P
0 g
s
0 0 0 r
.58855 .46623 m .58607 .46725 L .59738 .46306 L p F P
0 g
s
.398 0 0 r
.20255 .46254 m .19755 .4602 L .19393 .4591 L p F P
0 g
s
.145 .68 .849 r
.39343 .4977 m .38254 .49795 L .37927 .49743 L p F P
0 g
s
.359 0 0 r
.47934 .36444 m .48159 .36172 L .46937 .36409 L p F P
0 g
s
.359 0 0 r
.47373 .36548 m .47934 .36444 L p .46937 .36409 L F P
0 g
s
.359 0 0 r
.46937 .36409 m .46767 .36598 L .47373 .36548 L p F P
0 g
s
.317 0 0 r
.22864 .47193 m .22887 .47201 L .23574 .47404 L p F P
0 g
s
.259 0 0 r
.23697 .47462 m .22887 .47201 L .23574 .47404 L p F P
0 g
s
.259 0 0 r
.24113 .47589 m .23697 .47462 L p .23574 .47404 L F P
0 g
s
.259 0 0 r
.23574 .47404 m .2425 .47626 L .24113 .47589 L p F P
0 g
s
.019 .474 .875 r
.17707 .29935 m .17457 .29849 L .171 .29576 L p F P
0 g
s
.837 .375 .102 r
.09324 .39673 m .09787 .39964 L .09545 .39546 L p F P
0 g
s
.837 .375 .102 r
.09545 .39546 m .09082 .39255 L .09324 .39673 L p F P
0 g
s
.19 .722 .78 r
.49278 .49076 m .48165 .49265 L .47859 .49281 L p F P
0 g
s
.166 .705 .776 r
.46749 .4944 m .47859 .49281 L .48165 .49265 L p F P
0 g
s
.545 .083 .106 r
.39994 .37253 m .40719 .37484 L .39761 .37491 L closepath p F P
0 g
s
.232 .016 .367 r
.7389 .35879 m .73476 .36205 L .73711 .35612 L p F P
0 g
s
.232 .016 .367 r
.73711 .35612 m .73922 .35446 L .7389 .35879 L p F P
0 g
s
.736 .21 0 r
.12161 .41992 m .11826 .41618 L .12322 .41893 L p F P
0 g
s
.736 .21 0 r
.12322 .41893 m .12537 .42131 L .12161 .41992 L p F P
0 g
s
.319 .181 .531 r
.7539 .33221 m .74779 .33771 L .74736 .33247 L p F P
0 g
s
.319 .181 .531 r
.74736 .33247 m .75313 .32726 L .7539 .33221 L p F P
0 g
s
.22 0 0 r
.25098 .4786 m .24604 .47716 L .2425 .47626 L p F P
0 g
s
.133 .67 .85 r
.37604 .49689 m .37927 .49743 L .37026 .49742 L p F P
0 g
s
.133 .67 .85 r
.37587 .49689 m .37604 .49689 L p .37026 .49742 L F P
0 g
s
.133 .67 .85 r
.36513 .49685 m .37587 .49689 L p .37026 .49742 L F P
0 g
s
.133 .67 .85 r
.37026 .49742 m .36768 .49729 L .36513 .49685 L p F P
0 g
s
.626 .737 .927 r
.09468 .27452 m .1051 .27168 L .10871 .27507 L p F P
0 g
s
.625 .736 .927 r
.1051 .27168 m .09468 .27452 L .09105 .2711 L p F P
0 g
s
.691 .752 .898 r
.08048 .27568 m .09105 .2711 L .09468 .27452 L p F P
0 g
s
.591 .017 0 r
.26109 .34127 m .26751 .34358 L .26242 .34029 L p F P
0 g
s
.591 .017 0 r
.25706 .33841 m .26109 .34127 L p .26242 .34029 L F P
0 g
s
.591 .017 0 r
.26242 .34029 m .25813 .33861 L .25706 .33841 L p F P
0 g
s
.479 .016 .076 r
.42826 .3712 m .42895 .3713 L .42811 .37137 L closepath p F P
0 g
s
0 .472 .722 r
.28305 .48625 m .27737 .4851 L .27389 .48431 L p F P
0 g
s
0 0 0 r
.70702 .39736 m .7072 .397 L .69787 .40309 L p F P
0 g
s
0 0 0 r
.69891 .40447 m .70702 .39736 L p .69787 .40309 L F P
0 g
s
0 0 0 r
.69787 .40309 m .69633 .40615 L .69891 .40447 L p F P
0 g
s
.582 .007 0 r
.14569 .43547 m .15103 .43807 L .14641 .4345 L p F P
0 g
s
.582 .007 0 r
.14232 .43286 m .14569 .43547 L p .14641 .4345 L F P
0 g
s
.582 .007 0 r
.14641 .4345 m .14519 .43391 L .14232 .43286 L p F P
0 g
s
0 0 0 r
.57351 .32417 m .57195 .32495 L .56919 .32646 L p F P
0 g
s
.631 .121 .017 r
.32675 .36556 m .33551 .36705 L .33004 .36378 L p F P
0 g
s
.631 .121 .017 r
.32288 .36292 m .32675 .36556 L p .33004 .36378 L F P
0 g
s
.631 .121 .017 r
.33004 .36378 m .32374 .36256 L .32288 .36292 L p F P
0 g
s
0 .546 .784 r
.30195 .48957 m .30538 .49035 L .29938 .48945 L p F P
0 g
s
0 .546 .784 r
.29135 .488 m .30195 .48957 L p .29938 .48945 L F P
0 g
s
0 .546 .784 r
.29938 .48945 m .29164 .48807 L .29135 .488 L p F P
0 g
s
.091 .64 .829 r
.36768 .49729 m .36513 .49685 L .35933 .4967 L closepath p F P
0 g
s
.535 0 0 r
.24392 .33308 m .2499 .33556 L .24469 .33233 L p F P
0 g
s
.535 0 0 r
.23983 .33033 m .24392 .33308 L p .24469 .33233 L F P
0 g
s
.535 0 0 r
.24469 .33233 m .24122 .33078 L .23983 .33033 L p F P
0 g
s
.876 .748 .719 r
.04557 .30362 m .04933 .30698 L .0529 .30088 L p F P
0 g
s
.876 .748 .719 r
.0529 .30088 m .04916 .29751 L .04557 .30362 L p F P
0 g
s
.621 .063 0 r
.27905 .3492 m .28604 .35131 L .28092 .34799 L p F P
0 g
s
.621 .063 0 r
.27434 .34578 m .27905 .3492 L p .28092 .34799 L F P
0 g
s
.621 .063 0 r
.28092 .34799 m .27437 .34578 L .27434 .34578 L p F P
0 g
s
.691 .752 .898 r
.09105 .2711 m .08048 .27568 L .07683 .27225 L p F P
0 g
s
.586 .108 .086 r
.37043 .37379 m .38168 .37446 L .37507 .37151 L p F P
0 g
s
.586 .108 .086 r
.36835 .37272 m .37043 .37379 L p .37507 .37151 L F P
0 g
s
.586 .108 .086 r
.37507 .37151 m .37027 .37119 L .36835 .37272 L p F P
0 g
s
.518 .059 .103 r
.41409 .37235 m .42222 .37429 L .41191 .37476 L closepath p F P
0 g
s
0 0 0 r
.62634 .45006 m .62547 .45064 L .63502 .44614 L closepath p F P
0 g
s
.186 .562 .935 r
.1597 .29125 m .15732 .29068 L .15375 .2877 L p F P
0 g
s
.182 0 0 r
.2616 .48143 m .25993 .481 L .25815 .48053 L closepath p F P
0 g
s
.164 .695 .852 r
.40761 .49767 m .39668 .49815 L .39343 .4977 L p F P
0 g
s
.474 0 0 r
.18418 .45477 m .1803 .45261 L .17664 .45145 L p F P
0 g
s
.544 0 0 r
.16706 .4466 m .16311 .44401 L .15943 .44276 L p F P
0 g
s
.653 .965 .916 r
.62171 .3007 m .61976 .30062 L .62988 .29499 L closepath p F P
0 g
s
.486 .029 .092 r
.42895 .3713 m .42811 .37137 L .42573 .37412 L p F P
0 g
s
.186 .719 .797 r
.47856 .49281 m .47859 .49281 L .46749 .4944 L p F P
0 g
s
.186 .719 .797 r
.46749 .4944 m .46575 .49445 L .47856 .49281 L p F P
0 g
s
.143 .688 .77 r
.46575 .49445 m .46749 .4944 L p .45332 .49584 L F P
0 g
s
.112 0 0 r
.53232 .34383 m .53255 .34361 L .52135 .34749 L p F P
0 g
s
.112 0 0 r
.52135 .34749 m .52126 .34758 L .53232 .34383 L p F P
0 g
s
.445 0 0 r
.22735 .32469 m .23297 .3273 L .2275 .32419 L p F P
0 g
s
.445 0 0 r
.22261 .32177 m .22735 .32469 L p .2275 .32419 L F P
0 g
s
0 .288 .645 r
.22353 .32219 m .22261 .32177 L .22206 .32152 L closepath p F P
0 g
s
.445 0 0 r
.2275 .32419 m .22353 .32219 L .22261 .32177 L p F P
0 g
s
.585 .589 .822 r
.74335 .28105 m .74108 .2833 L p .72985 .27841 L F P
0 g
s
.585 .589 .822 r
.72985 .27841 m .74155 .27723 L .74335 .28105 L p F P
0 g
s
.58 .633 .868 r
.7281 .27537 m .72985 .27841 L .74155 .27723 L p F P
0 g
s
.331 .788 .652 r
.5832 .31936 m .57351 .32417 L .58219 .31983 L closepath p F P
0 g
s
0 0 0 r
.5804 .32069 m .58219 .31983 L .57906 .3214 L p F P
0 g
s
0 0 0 r
.5804 .32069 m .57925 .32138 L .58132 .32021 L p F P
0 g
s
0 0 0 r
.58898 .31585 m .59168 .31448 L .5804 .32069 L p F P
0 g
s
0 0 0 r
.58132 .32021 m .58898 .31585 L p .5804 .32069 L F P
0 g
s
0 0 0 r
.57906 .3214 m .57351 .32417 L p .5804 .32069 L F P
0 g
s
0 0 0 r
.56961 .32625 m .5804 .32069 L p .57351 .32417 L F P
0 g
s
0 0 0 r
.56919 .32646 m .56961 .32625 L p .57351 .32417 L F P
0 g
s
.167 .703 .822 r
.43938 .49693 m .43915 .49692 L .43814 .49701 L closepath p F P
0 g
s
.181 .712 .837 r
.43599 .49665 m .43915 .49692 L .43814 .49701 L p F P
0 g
s
.181 .712 .837 r
.42498 .49764 m .43599 .49665 L p .43814 .49701 L F P
0 g
s
.487 .029 .091 r
.44147 .37026 m .43923 .37287 L .42895 .3713 L closepath p F P
0 g
s
.486 .029 .092 r
.43913 .37301 m .43923 .37287 L .42895 .3713 L p F P
0 g
s
.486 .029 .092 r
.42573 .37412 m .43913 .37301 L p .42895 .3713 L F P
0 g
s
.436 .364 .678 r
.75037 .30844 m .75239 .30656 L .75337 .31065 L closepath p F P
0 g
s
0 .568 .782 r
.33595 .49454 m .3369 .49471 L p .32283 .49305 L F P
0 g
s
0 .568 .782 r
.32283 .49305 m .32923 .49367 L .33595 .49454 L p F P
0 g
s
.014 .579 .794 r
.32923 .49367 m .32283 .49305 L .31944 .49241 L p F P
0 g
s
.202 .728 .839 r
.45019 .49568 m .4527 .49584 L .43938 .49693 L p F P
0 g
s
.202 .728 .839 r
.43938 .49693 m .43915 .49692 L .45019 .49568 L p F P
0 g
s
.598 .123 .096 r
.37027 .37119 m .36835 .37272 L .36427 .3707 L closepath p F P
0 g
s
0 0 0 r
.55622 .33316 m .55789 .33191 L .54666 .33683 L p F P
0 g
s
0 0 0 r
.54666 .33683 m .54569 .3376 L .55622 .33316 L p F P
0 g
s
.118 0 0 r
.52992 .34621 m .53232 .34383 L .52126 .34758 L p F P
0 g
s
.118 0 0 r
.52126 .34758 m .51885 .34998 L .52992 .34621 L p F P
0 g
s
.904 .723 .647 r
.0462 .31389 m .0466 .31279 L .05044 .31611 L p F P
0 g
s
.904 .723 .647 r
.05044 .31611 m .04985 .31771 L .0462 .31389 L p F P
0 g
s
.18 .708 .851 r
.4218 .49731 m .41082 .49805 L .40761 .49767 L p F P
0 g
s
.814 .334 .051 r
.10057 .40375 m .09787 .39964 L .10255 .40252 L p F P
0 g
s
.814 .334 .051 r
.1033 .40543 m .10057 .40375 L p .10255 .40252 L F P
0 g
s
.814 .334 .051 r
.10255 .40252 m .10488 .40605 L .1033 .40543 L p F P
0 g
s
.634 .071 0 r
.14519 .43391 m .14232 .43286 L .14114 .43188 L closepath p F P
0 g
s
.624 .095 0 r
.29806 .35677 m .29321 .35334 L .30051 .35533 L p F P
0 g
s
.624 .095 0 r
.30524 .3585 m .29806 .35677 L p .30051 .35533 L F P
0 g
s
.624 .095 0 r
.30051 .35533 m .30548 .35844 L .30524 .3585 L p F P
0 g
s
.143 .688 .77 r
.45332 .49584 m .45665 .49544 L .46575 .49445 L p F P
0 g
s
.172 .708 .801 r
.45332 .49584 m .45665 .49544 L .4527 .49584 L closepath p F P
0 g
s
.544 .711 .949 r
.11317 .27451 m .10871 .27507 L .1051 .27168 L p F P
0 g
s
.223 0 0 r
.5075 .35339 m .5072 .35369 L .50029 .35528 L closepath p F P
0 g
s
.253 0 0 r
.5052 .35598 m .5072 .35369 L .50029 .35528 L p F P
0 g
s
.253 0 0 r
.49354 .35903 m .5052 .35598 L p .50029 .35528 L F P
0 g
s
.109 .651 .843 r
.36182 .49623 m .36513 .49685 L .35933 .4967 L p F P
0 g
s
.109 .651 .843 r
.351 .49596 m .36182 .49623 L p .35933 .4967 L F P
0 g
s
.109 .651 .843 r
.35933 .4967 m .35209 .49616 L .351 .49596 L p F P
0 g
s
0 0 0 r
.65889 .4324 m .6507 .43704 L .64931 .4384 L p F P
0 g
s
0 .245 .642 r
.20542 .313 m .20561 .3131 L .21065 .31593 L p F P
0 g
s
0 .245 .641 r
.21122 .31613 m .21653 .31887 L .21065 .31593 L p F P
0 g
s
0 .245 .641 r
.21065 .31593 m .20561 .3131 L .21122 .31613 L p F P
0 g
s
.193 .719 .849 r
.43599 .49665 m .42498 .49764 L .4218 .49731 L p F P
0 g
s
.212 .733 .85 r
.45019 .49568 m .43915 .49692 L .43599 .49665 L p F P
0 g
s
.328 .626 .959 r
.14106 .28359 m .14001 .28345 L .13643 .28027 L p F P
0 g
s
.602 .114 .069 r
.36738 .37355 m .36835 .37272 L .36427 .3707 L p F P
0 g
s
.602 .114 .069 r
.35988 .37288 m .36738 .37355 L p .36427 .3707 L F P
0 g
s
.602 .114 .069 r
.3543 .36967 m .35988 .37288 L p .36427 .3707 L F P
0 g
s
.602 .114 .069 r
.36427 .3707 m .35433 .36965 L .3543 .36967 L p F P
0 g
s
.433 0 0 r
.19028 .45794 m .18418 .45477 L .19012 .45714 L p F P
0 g
s
.433 0 0 r
.1903 .45795 m .19028 .45794 L p .19012 .45714 L F P
0 g
s
.433 0 0 r
.19012 .45714 m .19393 .4591 L .1903 .45795 L p F P
0 g
s
.202 .724 .711 r
.54653 .47952 m .53529 .48247 L .53236 .48301 L p F P
0 g
s
.199 .724 .73 r
.52114 .48566 m .53236 .48301 L .53529 .48247 L p F P
0 g
s
0 0 0 r
.56913 .32649 m .56919 .32646 L .55894 .33126 L p F P
0 g
s
0 0 0 r
.55894 .33126 m .55789 .33191 L .56913 .32649 L p F P
0 g
s
.922 .588 .392 r
.05884 .35642 m .063 .35957 L .06242 .35484 L p F P
0 g
s
.922 .588 .392 r
.05828 .3518 m .05884 .35642 L p .06242 .35484 L F P
0 g
s
.922 .588 .392 r
.06242 .35484 m .0585 .35187 L .05828 .3518 L p F P
0 g
s
.672 .96 .942 r
.64244 .29015 m .63377 .29477 L .63106 .29434 L p F P
0 g
s
.914 .558 .346 r
.06395 .36418 m .06818 .36729 L .06723 .36267 L p F P
0 g
s
.914 .558 .346 r
.06723 .36267 m .063 .35957 L .06395 .36418 L p F P
0 g
s
.714 .9 .962 r
.65918 .28408 m .6591 .28403 L .65943 .28387 L closepath p F P
0 g
s
0 .418 .694 r
.25642 .48003 m .25098 .4786 L .25815 .48053 L p F P
0 g
s
0 .418 .694 r
.25815 .48053 m .25993 .481 L .25642 .48003 L p F P
0 g
s
0 .363 .774 r
.18822 .30426 m .18915 .30469 L .19392 .30762 L p F P
0 g
s
0 .373 .782 r
.19538 .30747 m .20042 .31032 L .19392 .30762 L p F P
0 g
s
0 .373 .782 r
.19392 .30762 m .18915 .30469 L .19538 .30747 L p F P
0 g
s
.641 .101 0 r
.29165 .35225 m .29321 .35334 L .29007 .35241 L closepath p F P
0 g
s
.353 0 0 r
.20766 .46476 m .20255 .46254 L .20877 .4648 L p F P
0 g
s
.353 0 0 r
.20877 .4648 m .21127 .46588 L .20766 .46476 L p F P
0 g
s
.506 0 0 r
.17252 .44994 m .16706 .4466 L .17272 .44907 L p F P
0 g
s
.506 0 0 r
.1738 .45051 m .17252 .44994 L p .17272 .44907 L F P
0 g
s
.506 0 0 r
.17272 .44907 m .17664 .45145 L .1738 .45051 L p F P
0 g
s
.91 .719 .632 r
.04858 .32162 m .04985 .31771 L .0462 .31389 L p F P
0 g
s
.717 .184 0 r
.12537 .42131 m .12681 .42279 L .13194 .42548 L p F P
0 g
s
.671 .119 0 r
.13087 .42651 m .13597 .42921 L .13194 .42548 L p F P
0 g
s
.671 .119 0 r
.13194 .42548 m .12681 .42279 L .13087 .42651 L p F P
0 g
s
.621 .108 .006 r
.32374 .36256 m .32288 .36292 L .32164 .36218 L closepath p F P
0 g
s
.246 .76 .798 r
.51817 .48597 m .52021 .48581 L .5082 .48831 L p F P
0 g
s
.246 .76 .798 r
.5082 .48831 m .50697 .48841 L .51817 .48597 L p F P
0 g
s
.064 .618 .819 r
.35209 .49616 m .351 .49596 L .34879 .49585 L closepath p F P
0 g
s
.703 .92 .967 r
.65943 .28387 m .6591 .28403 L .65641 .28277 L p F P
0 g
s
.722 .923 .96 r
.64508 .28875 m .65641 .28277 L .6591 .28403 L p F P
0 g
s
.928 .631 .46 r
.05422 .3485 m .05827 .35169 L .05817 .34681 L p F P
0 g
s
.928 .631 .46 r
.05817 .34681 m .05412 .34362 L .05422 .3485 L p F P
0 g
s
0 0 0 r
.58512 .46764 m .58607 .46725 L .57478 .47112 L p F P
0 g
s
0 0 0 r
.57478 .47112 m .57415 .47138 L .58512 .46764 L p F P
0 g
s
.903 .522 .292 r
.06948 .3718 m .07377 .37487 L .07248 .37036 L p F P
0 g
s
.903 .522 .292 r
.07248 .37036 m .06818 .36729 L .06948 .3718 L p F P
0 g
s
.703 .92 .967 r
.65641 .28277 m .6677 .27688 L .65943 .28387 L p F P
0 g
s
.719 .921 .961 r
.65943 .28387 m .67045 .27847 L .66777 .27684 L p F P
0 g
s
.719 .921 .961 r
.66777 .27684 m .6677 .27688 L .65943 .28387 L p F P
0 g
s
.542 .927 .843 r
.60848 .30673 m .6072 .30741 L .6083 .30677 L closepath p F P
0 g
s
.498 .903 .799 r
.60573 .30721 m .6083 .30677 L .6072 .30741 L p F P
0 g
s
.498 .903 .799 r
.59921 .31079 m .60573 .30721 L p .6072 .30741 L F P
0 g
s
.498 .903 .799 r
.59519 .31323 m .59921 .31079 L p .6072 .30741 L F P
0 g
s
.447 0 .065 r
.44795 .36948 m .44147 .37026 L .43923 .37287 L p F P
0 g
s
.318 0 0 r
.48187 .36139 m .48592 .36073 L .48159 .36172 L closepath p F P
0 g
s
.207 0 .36 r
.74299 .35539 m .7389 .35879 L .73922 .35446 L p F P
0 g
s
.207 0 .36 r
.73922 .35446 m .74516 .3495 L .74299 .35539 L p F P
0 g
s
.027 0 .02 r
.70803 .39643 m .7072 .397 L .70853 .39375 L p F P
0 g
s
.027 0 .02 r
.70853 .39375 m .71559 .38887 L .70803 .39643 L p F P
0 g
s
0 .498 .746 r
.29164 .48807 m .29135 .488 L .29096 .48793 L closepath p F P
0 g
s
.698 .827 .944 r
.68519 .27583 m .68452 .27522 L .68705 .27416 L closepath p F P
0 g
s
.801 .313 .034 r
.10488 .40605 m .10529 .40662 L .11013 .40943 L p F P
0 g
s
.76 .246 0 r
.10854 .41057 m .11336 .41339 L .11013 .40943 L p F P
0 g
s
.76 .246 0 r
.11013 .40943 m .10529 .40662 L .10854 .41057 L p F P
0 g
s
.019 .474 .875 r
.171 .29576 m .17254 .29631 L .17707 .29935 L p F P
0 g
s
.042 .488 .885 r
.17967 .29876 m .18446 .30171 L .17707 .29935 L p F P
0 g
s
.042 .488 .885 r
.17707 .29935 m .17254 .29631 L .17967 .29876 L p F P
0 g
s
.425 0 0 r
.24122 .33078 m .23983 .33033 L .23884 .32982 L closepath p F P
0 g
s
.021 .587 .786 r
.3369 .49471 m .33876 .49484 L .34879 .49585 L p F P
0 g
s
.081 .628 .835 r
.34767 .49526 m .33876 .49484 L .34879 .49585 L p F P
0 g
s
.081 .628 .835 r
.34879 .49585 m .351 .49596 L .34767 .49526 L p F P
0 g
s
.346 .641 .964 r
.14657 .28155 m .137 .28035 L .14106 .28359 L p F P
0 g
s
.346 .641 .964 r
.14106 .28359 m .15016 .28465 L .14657 .28155 L p F P
0 g
s
.328 .626 .959 r
.13643 .28027 m .137 .28035 L .14106 .28359 L p F P
0 g
s
.237 .751 .857 r
.45665 .49544 m .4527 .49584 L .45019 .49568 L p F P
0 g
s
.516 0 0 r
.25813 .33861 m .25706 .33841 L .25618 .33792 L closepath p F P
0 g
s
.929 .659 .507 r
.05014 .34038 m .05412 .34362 L .05443 .33861 L p F P
0 g
s
.929 .659 .507 r
.05443 .33861 m .05046 .33537 L .05014 .34038 L p F P
0 g
s
.296 .131 .48 r
.74795 .34261 m .74644 .34389 L .74673 .33861 L p F P
0 g
s
.296 .131 .48 r
.74673 .33861 m .74779 .33771 L .74795 .34261 L p F P
0 g
s
.889 .484 .238 r
.07539 .37929 m .07976 .38232 L .07814 .3779 L p F P
0 g
s
.889 .484 .238 r
.07814 .3779 m .07377 .37487 L .07539 .37929 L p F P
0 g
s
.622 .112 .014 r
.31853 .36387 m .31341 .3605 L .32164 .36218 L p F P
0 g
s
.622 .112 .014 r
.31999 .36416 m .31853 .36387 L p .32164 .36218 L F P
0 g
s
.622 .112 .014 r
.32164 .36218 m .32288 .36292 L .31999 .36416 L p F P
0 g
s
.477 .44 .738 r
.7502 .29886 m .7506 .29901 L .75033 .29928 L closepath p F P
0 g
s
.465 .449 .756 r
.74748 .291 m .7502 .29886 L .7506 .29901 L p F P
0 g
s
.453 .403 .712 r
.75672 .30222 m .75239 .30656 L .75033 .29928 L p F P
0 g
s
.453 .403 .712 r
.75033 .29928 m .7506 .29901 L .75672 .30222 L p F P
0 g
s
.575 .941 .848 r
.61767 .30074 m .61976 .30062 L .60848 .30673 L p F P
0 g
s
.575 .941 .848 r
.60848 .30673 m .6083 .30677 L .61767 .30074 L p F P
0 g
s
0 .509 .764 r
.2879 .48711 m .28305 .48625 L .29096 .48793 L p F P
0 g
s
0 .509 .764 r
.29096 .48793 m .29135 .488 L .2879 .48711 L p F P
0 g
s
.028 .592 .794 r
.3369 .49471 m .33876 .49484 L .33595 .49454 L closepath p F P
0 g
s
.305 0 0 r
.22864 .47193 m .22887 .47201 L .22838 .47187 L closepath p F P
0 g
s
.182 0 .301 r
.73837 .36289 m .73152 .36827 L .73476 .36205 L p F P
0 g
s
.182 0 .301 r
.73476 .36205 m .7389 .35879 L .73837 .36289 L p F P
0 g
s
0 0 0 r
.62278 .45233 m .6235 .45195 L .61306 .45638 L p F P
0 g
s
0 0 0 r
.61306 .45638 m .61145 .45724 L .62278 .45233 L p F P
0 g
s
.572 0 0 r
.15573 .44145 m .15103 .43807 L .15645 .44064 L p F P
0 g
s
.572 0 0 r
.15645 .44064 m .15943 .44276 L .15573 .44145 L p F P
0 g
s
.674 .747 .906 r
.69864 .27321 m .71012 .26912 L .71282 .27259 L p F P
0 g
s
.686 .771 .916 r
.71012 .26912 m .69864 .27321 L .69595 .27041 L p F P
0 g
s
.893 .739 .683 r
.04284 .30943 m .0466 .31279 L .04933 .30698 L p F P
0 g
s
.893 .739 .683 r
.04933 .30698 m .04557 .30362 L .04284 .30943 L p F P
0 g
s
.186 .562 .935 r
.15375 .2877 m .15539 .28812 L .1597 .29125 L p F P
0 g
s
.212 .585 .944 r
.16381 .29008 m .15539 .28812 L .1597 .29125 L p F P
0 g
s
.212 .585 .944 r
.16398 .29019 m .16381 .29008 L p .1597 .29125 L F P
0 g
s
.212 .585 .944 r
.1597 .29125 m .16743 .29296 L .16398 .29019 L p F P
0 g
s
.358 .242 .582 r
.75578 .32485 m .75313 .32726 L .75125 .32267 L p F P
0 g
s
.358 .242 .582 r
.75125 .32267 m .75503 .31922 L .75578 .32485 L p F P
0 g
s
.137 0 .233 r
.72953 .36981 m .7291 .37208 L .73152 .36827 L closepath p F P
0 g
s
0 .391 .684 r
.23029 .47251 m .23697 .47462 L .22887 .47201 L p F P
0 g
s
.27 0 0 r
.22838 .47187 m .22507 .47084 L .22234 .46986 L closepath p F P
0 g
s
0 .391 .684 r
.22887 .47201 m .22838 .47187 L .22507 .47084 L p F P
0 g
s
0 .391 .684 r
.22507 .47084 m .23029 .47251 L p .22887 .47201 L F P
0 g
s
0 .552 .802 r
.30195 .48957 m .29135 .488 L .2879 .48711 L p F P
0 g
s
.643 .688 .878 r
.71282 .27259 m .72437 .26941 L .7271 .27368 L p F P
0 g
s
.657 .715 .891 r
.72437 .26941 m .71282 .27259 L .71012 .26912 L p F P
0 g
s
.554 .558 .813 r
.74108 .2833 m .74335 .28105 L .74436 .28332 L closepath p F P
0 g
s
.465 .449 .756 r
.7506 .29901 m .75658 .29288 L p .74748 .291 L F P
0 g
s
.462 .42 .726 r
.76051 .29842 m .75672 .30222 L .7506 .29901 L p F P
0 g
s
.462 .42 .726 r
.75931 .2941 m .76051 .29842 L p .7506 .29901 L F P
0 g
s
.462 .42 .726 r
.7506 .29901 m .75658 .29288 L .75931 .2941 L p F P
0 g
s
.607 .653 .87 r
.7271 .27368 m .73016 .27314 L .7281 .27537 L closepath p F P
0 g
s
.58 .633 .868 r
.73877 .27182 m .73016 .27314 L .7281 .27537 L p F P
0 g
s
.58 .633 .868 r
.74155 .27723 m .73877 .27182 L p .7281 .27537 L F P
0 g
s
.577 .942 .845 r
.61702 .30078 m .61767 .30074 L .6083 .30677 L p F P
0 g
s
.577 .942 .845 r
.6083 .30677 m .60573 .30721 L .61702 .30078 L p F P
0 g
s
.608 .121 .074 r
.35433 .36965 m .3543 .36967 L .35423 .36964 L closepath p F P
0 g
s
.609 .129 .089 r
.35008 .37173 m .34454 .36845 L .35423 .36964 L p F P
0 g
s
.609 .129 .089 r
.35127 .37187 m .35008 .37173 L p .35423 .36964 L F P
0 g
s
.609 .129 .089 r
.35423 .36964 m .3543 .36967 L .35127 .37187 L p F P
0 g
s
.222 .742 .841 r
.46575 .49445 m .46439 .49439 L .45665 .49544 L closepath p F P
0 g
s
.237 .751 .857 r
.46129 .4942 m .46439 .49439 L .45665 .49544 L p F P
0 g
s
.237 .751 .857 r
.45019 .49568 m .46129 .4942 L p .45665 .49544 L F P
0 g
s
.511 .497 .777 r
.74723 .29033 m .748 .29047 L .74748 .291 L closepath p F P
0 g
s
.465 .449 .756 r
.75658 .29288 m .748 .29047 L .74748 .291 L p F P
0 g
s
.869 .436 .172 r
.08096 .38498 m .07976 .38232 L .08419 .38532 L p F P
0 g
s
.869 .436 .172 r
.08419 .38532 m .08478 .38662 L .08096 .38498 L p F P
0 g
s
0 0 0 r
.63502 .44614 m .62547 .45064 L .6235 .45195 L p F P
0 g
s
.622 .146 .101 r
.3543 .36967 m .35988 .37288 L .35127 .37187 L closepath p F P
0 g
s
.326 0 0 r
.48592 .36073 m .48159 .36172 L .47934 .36444 L p F P
0 g
s
.525 .521 .793 r
.748 .29047 m .74723 .29033 L .74436 .28332 L p F P
0 g
s
.926 .683 .551 r
.04656 .3321 m .05046 .33537 L .05122 .33022 L p F P
0 g
s
.926 .683 .551 r
.05122 .33022 m .04732 .32694 L .04656 .3321 L p F P
0 g
s
0 0 0 r
.60995 .45804 m .61145 .45724 L .60015 .46183 L p F P
0 g
s
0 0 0 r
.60015 .46183 m .59933 .46225 L .60995 .45804 L p F P
0 g
s
0 0 0 r
.662 .43055 m .65889 .4324 L .66162 .43099 L closepath p F P
0 g
s
0 0 0 r
.65944 .43309 m .66162 .43099 L .65889 .4324 L p F P
0 g
s
0 0 0 r
.658 .43392 m .65944 .43309 L p .65889 .4324 L F P
0 g
s
0 0 0 r
.64931 .4384 m .658 .43392 L p .65889 .4324 L F P
0 g
s
.455 .684 .964 r
.12262 .27705 m .13283 .27704 L .13643 .28027 L p F P
0 g
s
.453 .681 .963 r
.13283 .27704 m .12262 .27705 L .11901 .27373 L p F P
0 g
s
.45 0 .066 r
.45443 .36871 m .45346 .36986 L .44795 .36948 L closepath p F P
0 g
s
.447 0 .065 r
.45219 .37153 m .45346 .36986 L .44795 .36948 L p F P
0 g
s
.447 0 .065 r
.43979 .37293 m .45219 .37153 L p .44795 .36948 L F P
0 g
s
.447 0 .065 r
.43923 .37287 m .43979 .37293 L p .44795 .36948 L F P
0 g
s
.394 .336 .674 r
.76122 .30597 m .75672 .30222 L .75239 .30656 L p F P
0 g
s
.394 .336 .674 r
.75497 .31215 m .76122 .30597 L p .75239 .30656 L F P
0 g
s
.394 .336 .674 r
.75239 .30656 m .75337 .31065 L .75497 .31215 L p F P
0 g
s
.512 0 0 r
.25351 .33773 m .2499 .33556 L .25618 .33792 L p F P
0 g
s
.512 0 0 r
.25618 .33792 m .25706 .33841 L .25351 .33773 L p F P
0 g
s
.216 .738 .75 r
.53203 .48306 m .53236 .48301 L .52114 .48566 L p F P
0 g
s
.216 .738 .75 r
.52114 .48566 m .52021 .48581 L .53203 .48306 L p F P
0 g
s
.57 0 0 r
.27437 .34578 m .27434 .34578 L .2743 .34576 L closepath p F P
0 g
s
.57 0 0 r
.27079 .34566 m .26751 .34358 L .2743 .34576 L p F P
0 g
s
.57 0 0 r
.2743 .34576 m .27434 .34578 L .27079 .34566 L p F P
0 g
s
0 .463 .735 r
.2676 .48276 m .25993 .481 L .25642 .48003 L p F P
0 g
s
.664 .127 0 r
.27905 .3492 m .27434 .34578 L .27079 .34566 L p F P
0 g
s
.717 .183 0 r
.12681 .42279 m .12537 .42131 L .12161 .41992 L p F P
0 g
s
.694 .848 .957 r
.68705 .27416 m .68452 .27522 L .68184 .27306 L p F P
0 g
s
.718 .854 .947 r
.67045 .27847 m .68184 .27306 L .68452 .27522 L p F P
0 g
s
.274 .115 .475 r
.75365 .3375 m .74795 .34261 L .74779 .33771 L p F P
0 g
s
.274 .115 .475 r
.74779 .33771 m .7539 .33221 L .75365 .3375 L p F P
0 g
s
.258 .765 .751 r
.5578 .47627 m .55919 .476 L .54782 .47926 L p F P
0 g
s
.258 .765 .751 r
.54782 .47926 m .54653 .47952 L .5578 .47627 L p F P
0 g
s
.389 .824 .674 r
.59196 .31437 m .59445 .31342 L .5832 .31936 L p F P
0 g
s
.389 .824 .674 r
.5832 .31936 m .58219 .31983 L .59196 .31437 L p F P
0 g
s
.256 .756 .702 r
.58326 .46819 m .58512 .46764 L .57415 .47138 L p F P
0 g
s
.256 .756 .702 r
.57415 .47138 m .57195 .47204 L .58326 .46819 L p F P
0 g
s
.418 0 0 r
.23627 .32912 m .23297 .3273 L .23884 .32982 L p F P
0 g
s
.418 0 0 r
.23884 .32982 m .23983 .33033 L .23627 .32912 L p F P
0 g
s
.173 0 0 r
.5184 .35044 m .51885 .34998 L .5075 .35339 L p F P
0 g
s
.173 0 0 r
.5075 .35339 m .5072 .35369 L .5184 .35044 L p F P
0 g
s
.525 .521 .793 r
.74436 .28332 m .75381 .28437 L .748 .29047 L p F P
0 g
s
.503 .487 .772 r
.75838 .29104 m .75658 .29288 L .748 .29047 L p F P
0 g
s
.503 .487 .772 r
.75629 .28488 m .75838 .29104 L p .748 .29047 L F P
0 g
s
.503 .487 .772 r
.748 .29047 m .75381 .28437 L .75629 .28488 L p F P
0 g
s
.653 .12 0 r
.29082 .35475 m .29806 .35677 L .29321 .35334 L p F P
0 g
s
.653 .12 0 r
.28812 .35265 m .29082 .35475 L p .29321 .35334 L F P
0 g
s
.653 .12 0 r
.29321 .35334 m .29007 .35241 L .28812 .35265 L p F P
0 g
s
0 0 0 r
.55503 .33407 m .55622 .33316 L .54569 .3376 L p F P
0 g
s
0 0 0 r
.54569 .3376 m .54378 .33913 L .55503 .33407 L p F P
0 g
s
.11 .647 .856 r
.34468 .4946 m .34767 .49526 L .33876 .49484 L p F P
0 g
s
.11 .647 .856 r
.34363 .49448 m .34468 .4946 L p .33876 .49484 L F P
0 g
s
.11 .647 .856 r
.33354 .49399 m .34363 .49448 L p .33876 .49484 L F P
0 g
s
.11 .647 .856 r
.33876 .49484 m .33595 .49454 L .33354 .49399 L p F P
0 g
s
0 0 0 r
.67141 .4256 m .67329 .42345 L .662 .43055 L p F P
0 g
s
0 0 0 r
.662 .43055 m .66162 .43099 L .67141 .4256 L p F P
0 g
s
.651 .149 .044 r
.32288 .36292 m .32675 .36556 L .31999 .36416 L closepath p F P
0 g
s
.736 .211 0 r
.11686 .41727 m .11336 .41339 L .11826 .41618 L p F P
0 g
s
.736 .211 0 r
.12119 .41975 m .11686 .41727 L p .11826 .41618 L F P
0 g
s
.736 .211 0 r
.11826 .41618 m .12161 .41992 L .12119 .41975 L p F P
0 g
s
.629 .066 0 r
.1386 .43141 m .13597 .42921 L .14114 .43188 L p F P
0 g
s
.629 .066 0 r
.14114 .43188 m .14232 .43286 L .1386 .43141 L p F P
0 g
s
.836 .372 .088 r
.08869 .39379 m .09324 .39673 L .09082 .39255 L p F P
0 g
s
.836 .372 .088 r
.09082 .39255 m .08626 .38961 L .08869 .39379 L p F P
0 g
s
.131 .663 .864 r
.36182 .49623 m .351 .49596 L .34767 .49526 L p F P
0 g
s
.544 .711 .949 r
.1051 .27168 m .10933 .27116 L .11317 .27451 L p F P
0 g
s
.551 .715 .949 r
.11539 .27037 m .10933 .27116 L .11317 .27451 L p F P
0 g
s
.551 .715 .949 r
.11317 .27451 m .11901 .27373 L .11539 .27037 L p F P
0 g
s
.91 .719 .632 r
.0462 .31389 m .04476 .31831 L .04858 .32162 L p F P
0 g
s
.921 .705 .593 r
.04349 .32363 m .04732 .32694 L .04858 .32162 L p F P
0 g
s
.921 .705 .593 r
.04858 .32162 m .04476 .31831 L .04349 .32363 L p F P
0 g
s
.694 .952 .954 r
.64508 .28875 m .64244 .29015 L .64453 .2886 L closepath p F P
0 g
s
.672 .96 .942 r
.64237 .28805 m .64453 .2886 L .64244 .29015 L p F P
0 g
s
.672 .96 .942 r
.63106 .29434 m .64237 .28805 L p .64244 .29015 L F P
0 g
s
.621 .655 .862 r
.73016 .27314 m .7271 .27368 L .72437 .26941 L p F P
0 g
s
.412 .338 .663 r
.75337 .31065 m .75497 .31215 L .75393 .31317 L closepath p F P
0 g
s
0 .295 .657 r
.21905 .32009 m .21653 .31887 L .22206 .32152 L p F P
0 g
s
0 .295 .657 r
.22206 .32152 m .22261 .32177 L .21905 .32009 L p F P
0 g
s
.42 0 .047 r
.46485 .3696 m .46705 .36676 L .45443 .36871 L p F P
0 g
s
.42 0 .047 r
.46243 .36996 m .46485 .3696 L p .45443 .36871 L F P
0 g
s
.42 0 .047 r
.45443 .36871 m .45346 .36986 L .46243 .36996 L p F P
0 g
s
.061 .612 .83 r
.33595 .49454 m .33354 .49399 L .32923 .49367 L closepath p F P
0 g
s
.637 .078 0 r
.26109 .34127 m .25706 .33841 L .25351 .33773 L p F P
0 g
s
.308 0 0 r
.21589 .46768 m .21127 .46588 L .20766 .46476 L p F P
0 g
s
.311 0 0 r
.49354 .35903 m .49301 .35962 L .48592 .36073 L closepath p F P
0 g
s
.326 0 0 r
.49134 .36177 m .49301 .35962 L .48592 .36073 L p F P
0 g
s
.326 0 0 r
.47934 .36444 m .49134 .36177 L p .48592 .36073 L F P
0 g
s
.253 .762 .854 r
.47552 .49265 m .47856 .49281 L .46575 .49445 L p F P
0 g
s
.253 .762 .854 r
.46575 .49445 m .46439 .49439 L .47552 .49265 L p F P
0 g
s
.698 .82 .941 r
.69595 .27041 m .68705 .27416 L .69338 .26797 L closepath p F P
0 g
s
.694 .848 .957 r
.69327 .26786 m .69338 .26797 L .68705 .27416 L p F P
0 g
s
.694 .848 .957 r
.68184 .27306 m .69327 .26786 L p .68705 .27416 L F P
0 g
s
.862 .422 .155 r
.08626 .38961 m .08478 .38662 L .08096 .38498 L p F P
0 g
s
.229 .738 .695 r
.57037 .47249 m .57195 .47204 L .56067 .47557 L p F P
0 g
s
.229 .738 .695 r
.56067 .47557 m .55919 .476 L .57037 .47249 L p F P
0 g
s
.22 0 0 r
.2425 .47626 m .24385 .47665 L .25098 .4786 L p F P
0 g
s
0 .423 .702 r
.25285 .47901 m .24385 .47665 L .25098 .4786 L p F P
0 g
s
0 .423 .702 r
.25295 .47904 m .25285 .47901 L p .25098 .4786 L F P
0 g
s
0 .423 .702 r
.25098 .4786 m .25642 .48003 L .25295 .47904 L p F P
0 g
s
.221 0 0 r
.51658 .35257 m .5184 .35044 L .5072 .35369 L p F P
0 g
s
.221 0 0 r
.5072 .35369 m .5052 .35598 L .51658 .35257 L p F P
0 g
s
.625 .736 .927 r
.09105 .2711 m .10147 .26827 L .1051 .27168 L p F P
0 g
s
.625 .735 .926 r
.10147 .26827 m .09105 .2711 L .0874 .26766 L p F P
0 g
s
.691 .752 .898 r
.07683 .27225 m .0874 .26766 L .09105 .2711 L p F P
0 g
s
.633 .144 .072 r
.34064 .37045 m .35008 .37173 L .34454 .36845 L p F P
0 g
s
.633 .144 .072 r
.33683 .36786 m .34064 .37045 L p .34454 .36845 L F P
0 g
s
.633 .144 .072 r
.34454 .36845 m .33766 .36738 L .33683 .36786 L p F P
0 g
s
0 .373 .789 r
.18822 .30426 m .18915 .30469 L .18514 .3021 L closepath p F P
0 g
s
.662 .154 .025 r
.30548 .35844 m .30575 .35864 L .31341 .3605 L p F P
0 g
s
.669 .166 .041 r
.31043 .36215 m .31853 .36387 L .31341 .3605 L p F P
0 g
s
.669 .166 .041 r
.31341 .3605 m .30575 .35864 L .31043 .36215 L p F P
0 g
s
.232 .751 .785 r
.51817 .48597 m .50697 .48841 L .50396 .48861 L p F P
0 g
s
.222 .744 .795 r
.49278 .49076 m .50396 .48861 L .50697 .48841 L p F P
0 g
s
0 .256 .662 r
.20542 .313 m .20561 .3131 L .20491 .3127 L closepath p F P
0 g
s
.584 .008 0 r
.24392 .33308 m .23983 .33033 L .23627 .32912 L p F P
0 g
s
0 0 0 r
.56647 .32833 m .56913 .32649 L .55789 .33191 L p F P
0 g
s
0 0 0 r
.55789 .33191 m .55622 .33316 L .56647 .32833 L p F P
0 g
s
.012 .463 .871 r
.17254 .29631 m .171 .29576 L .16743 .29296 L p F P
0 g
s
.516 .911 .799 r
.59519 .31323 m .59445 .31342 L .59921 .31079 L closepath p F P
0 g
s
.496 0 0 r
.22735 .32469 m .22261 .32177 L .21905 .32009 L p F P
0 g
s
.709 .955 .95 r
.65371 .28172 m .65641 .28277 L .64508 .28875 L p F P
0 g
s
.709 .955 .95 r
.65173 .28282 m .65371 .28172 L p .64508 .28875 L F P
0 g
s
.709 .955 .95 r
.64508 .28875 m .64453 .2886 L .65173 .28282 L p F P
0 g
s
.134 0 .231 r
.73798 .36488 m .73837 .36289 L .73152 .36827 L p F P
0 g
s
.134 0 .231 r
.73602 .36801 m .73798 .36488 L p .73152 .36827 L F P
0 g
s
.134 0 .231 r
.72879 .37368 m .73602 .36801 L p .73152 .36827 L F P
0 g
s
.134 0 .231 r
.73152 .36827 m .7291 .37208 L .72879 .37368 L p F P
0 g
s
.379 .288 .625 r
.75794 .31639 m .75503 .31922 L .75393 .31317 L p F P
0 g
s
.379 .288 .625 r
.75393 .31317 m .75497 .31215 L .75794 .31639 L p F P
0 g
s
0 .472 .722 r
.27389 .48431 m .27515 .48456 L .28305 .48625 L p F P
0 g
s
0 .515 .772 r
.28443 .48618 m .27515 .48456 L .28305 .48625 L p F P
0 g
s
0 .515 .772 r
.28305 .48625 m .2879 .48711 L .28443 .48618 L p F P
0 g
s
.414 0 0 r
.18447 .45552 m .19028 .45794 L .18418 .45477 L p F P
0 g
s
.414 0 0 r
.18418 .45477 m .1783 .45238 L .18447 .45552 L p F P
0 g
s
.474 0 0 r
.17664 .45145 m .1783 .45238 L .18418 .45477 L p F P
0 g
s
.517 .538 .816 r
.74335 .28105 m .74436 .28332 L .75381 .28437 L p F P
0 g
s
.052 0 .086 r
.71884 .38395 m .71814 .38607 L .72195 .38167 L closepath p F P
0 g
s
.381 0 .039 r
.46767 .36598 m .47373 .36548 L .46705 .36676 L closepath p F P
0 g
s
0 .223 .627 r
.20611 .31332 m .21122 .31613 L .20561 .3131 L p F P
0 g
s
0 .223 .627 r
.20185 .31089 m .20611 .31332 L p .20561 .3131 L F P
0 g
s
0 .223 .627 r
.20561 .3131 m .20491 .3127 L .20185 .31089 L p F P
0 g
s
.813 .33 .034 r
.09595 .40084 m .10057 .40375 L .09787 .39964 L p F P
0 g
s
.813 .33 .034 r
.09787 .39964 m .09324 .39673 L .09595 .40084 L p F P
0 g
s
0 .562 .794 r
.3192 .49236 m .31944 .49241 L p .30538 .49035 L F P
0 g
s
0 .562 .794 r
.30538 .49035 m .31109 .49104 L .3192 .49236 L p F P
0 g
s
.008 .57 .803 r
.31109 .49104 m .30538 .49035 L .30195 .48957 L p F P
0 g
s
.622 .077 0 r
.29007 .35241 m .28812 .35265 L .28604 .35131 L closepath p F P
0 g
s
.398 0 0 r
.19393 .4591 m .19639 .46025 L .20255 .46254 L p F P
0 g
s
.348 0 0 r
.20323 .46321 m .19639 .46025 L .20255 .46254 L p F P
0 g
s
.348 0 0 r
.20523 .46397 m .20323 .46321 L p .20255 .46254 L F P
0 g
s
.348 0 0 r
.20255 .46254 m .20766 .46476 L .20523 .46397 L p F P
0 g
s
.156 .683 .872 r
.37587 .49689 m .36513 .49685 L .36182 .49623 L p F P
0 g
s
0 0 0 r
.67356 .42314 m .67329 .42345 L .67516 .42221 L closepath p F P
0 g
s
0 0 0 r
.67077 .4262 m .67141 .4256 L .66162 .43099 L p F P
0 g
s
0 0 0 r
.66162 .43099 m .65944 .43309 L .67077 .4262 L p F P
0 g
s
.181 .555 .932 r
.15539 .28812 m .15375 .2877 L .15016 .28465 L p F P
0 g
s
.059 0 0 r
.54313 .33974 m .54378 .33913 L .53255 .34361 L p F P
0 g
s
.059 0 0 r
.53255 .34361 m .53232 .34383 L .54313 .33974 L p F P
0 g
s
.544 0 0 r
.15943 .44276 m .16145 .4441 L .16706 .4466 L p F P
0 g
s
.488 0 0 r
.16697 .44743 m .17252 .44994 L .16706 .4466 L p F P
0 g
s
.488 0 0 r
.16706 .4466 m .16145 .4441 L .16697 .44743 L p F P
0 g
s
.907 .728 .648 r
.0425 .31036 m .04284 .30943 L .0466 .31279 L p F P
0 g
s
.907 .728 .648 r
.0466 .31279 m .0462 .31389 L .0425 .31036 L p F P
0 g
s
.726 .874 .95 r
.68184 .27306 m .67045 .27847 L .66777 .27684 L p F P
0 g
s
0 0 0 r
.60872 .45854 m .60995 .45804 L .59933 .46225 L p F P
0 g
s
0 0 0 r
.59933 .46225 m .59738 .46306 L .60872 .45854 L p F P
0 g
s
.8 .31 .022 r
.10488 .40605 m .10529 .40662 L .1033 .40543 L closepath p F P
0 g
s
.617 .957 .889 r
.62988 .29499 m .61976 .30062 L .61767 .30074 L p F P
0 g
s
.603 .033 0 r
.14569 .43547 m .14232 .43286 L .1386 .43141 L p F P
0 g
s
0 .392 .778 r
.20491 .3127 m .20185 .31089 L .20042 .31032 L closepath p F P
0 g
s
.279 .782 .813 r
.5294 .48326 m .53203 .48306 L .52021 .48581 L p F P
0 g
s
.279 .782 .813 r
.52021 .48581 m .51817 .48597 L .5294 .48326 L p F P
0 g
s
.014 .579 .794 r
.31944 .49241 m .31985 .49245 L .32923 .49367 L p F P
0 g
s
.072 .618 .841 r
.33017 .49317 m .31985 .49245 L .32923 .49367 L p F P
0 g
s
.072 .618 .841 r
.32923 .49367 m .33354 .49399 L .33017 .49317 L p F P
0 g
s
.543 .709 .948 r
.10933 .27116 m .1051 .27168 L .10147 .26827 L p F P
0 g
s
.66 .106 0 r
.12584 .42378 m .13087 .42651 L .12681 .42279 L p F P
0 g
s
.66 .106 0 r
.12681 .42279 m .12175 .42006 L .12584 .42378 L p F P
0 g
s
.717 .183 0 r
.12161 .41992 m .12175 .42006 L .12681 .42279 L p F P
0 g
s
0 .343 .762 r
.19052 .30455 m .19538 .30747 L .18915 .30469 L p F P
0 g
s
0 .343 .762 r
.18465 .30176 m .19052 .30455 L p .18915 .30469 L F P
0 g
s
0 .343 .762 r
.18915 .30469 m .18514 .3021 L .18465 .30176 L p F P
0 g
s
.39 0 0 r
.19393 .4591 m .19639 .46025 L .1903 .45795 L closepath p F P
0 g
s
0 0 0 r
.68512 .41485 m .68456 .41563 L .68813 .41301 L closepath p F P
0 g
s
.556 .573 .826 r
.74155 .27723 m .7469 .27717 L .74335 .28105 L closepath p F P
0 g
s
.517 .538 .816 r
.75339 .27746 m .7469 .27717 L .74335 .28105 L p F P
0 g
s
.517 .538 .816 r
.75547 .28264 m .75339 .27746 L p .74335 .28105 L F P
0 g
s
.517 .538 .816 r
.75381 .28437 m .75547 .28264 L p .74335 .28105 L F P
0 g
s
.924 .599 .406 r
.0585 .35187 m .05828 .3518 L .05827 .35169 L closepath p F P
0 g
s
.621 .655 .862 r
.73612 .26709 m .73016 .27314 L p .72437 .26941 L F P
0 g
s
.6 .638 .86 r
.73016 .27314 m .73612 .26709 L .73877 .27182 L closepath p F P
0 g
s
0 0 0 r
.64931 .4384 m .64811 .43936 L .658 .43392 L closepath p F P
0 g
s
.263 0 0 r
.22149 .46969 m .21589 .46768 L .22234 .46986 L p F P
0 g
s
.263 0 0 r
.22234 .46986 m .22507 .47084 L .22149 .46969 L p F P
0 g
s
.239 .756 .812 r
.50339 .48864 m .50396 .48861 L .49278 .49076 L p F P
0 g
s
.239 .756 .812 r
.49278 .49076 m .49108 .49084 L .50339 .48864 L p F P
0 g
s
.19 .722 .78 r
.49108 .49084 m .49278 .49076 L p .47859 .49281 L F P
0 g
s
.606 .14 .12 r
.36835 .37272 m .37043 .37379 L .36738 .37355 L closepath p F P
0 g
s
.249 .062 .42 r
.74787 .34721 m .74516 .3495 L .74644 .34389 L p F P
0 g
s
.249 .062 .42 r
.74644 .34389 m .74795 .34261 L .74787 .34721 L p F P
0 g
s
.157 0 .239 r
.7291 .37208 m .72729 .3748 L .72879 .37368 L closepath p F P
0 g
s
.059 0 0 r
.54088 .3419 m .54313 .33974 L .53232 .34383 L p F P
0 g
s
.059 0 0 r
.53659 .34364 m .54088 .3419 L p .53232 .34383 L F P
0 g
s
.059 0 0 r
.53232 .34383 m .52992 .34621 L .53659 .34364 L p F P
0 g
s
.917 .56 .339 r
.0598 .36104 m .06395 .36418 L .063 .35957 L p F P
0 g
s
.917 .56 .339 r
.063 .35957 m .05884 .35642 L .0598 .36104 L p F P
0 g
s
.913 .723 .632 r
.04476 .31831 m .0462 .31389 L .0425 .31036 L p F P
0 g
s
0 0 0 r
.63679 .44527 m .63502 .44614 L .63662 .44541 L closepath p F P
0 g
s
0 0 0 r
.63413 .44703 m .63662 .44541 L .63502 .44614 L p F P
0 g
s
0 0 0 r
.63045 .44879 m .63413 .44703 L p .63502 .44614 L F P
0 g
s
0 0 0 r
.6235 .45195 m .63045 .44879 L p .63502 .44614 L F P
0 g
s
.928 .602 .403 r
.0544 .35018 m .05422 .3485 L .05827 .35169 L p F P
0 g
s
.928 .602 .403 r
.05827 .35169 m .05828 .3518 L .0544 .35018 L p F P
0 g
s
.631 .141 .07 r
.33766 .36738 m .33683 .36786 L .33551 .36705 L closepath p F P
0 g
s
.926 .597 .397 r
.05884 .35642 m .05828 .3518 L .0544 .35018 L p F P
0 g
s
.152 .685 .857 r
.37927 .49743 m .38803 .49725 L .37604 .49689 L closepath p F P
0 g
s
.145 .68 .849 r
.39096 .49733 m .39343 .4977 L p .37927 .49743 L F P
0 g
s
.145 .68 .849 r
.37927 .49743 m .38803 .49725 L .39096 .49733 L p F P
0 g
s
0 0 0 r
.67516 .42221 m .67329 .42345 L .67141 .4256 L p F P
0 g
s
.708 .956 .949 r
.64453 .2886 m .64237 .28805 L .65173 .28282 L closepath p F P
0 g
s
.324 .621 .957 r
.137 .28035 m .13643 .28027 L .13283 .27704 L p F P
0 g
s
.21 0 0 r
.2425 .47626 m .24385 .47665 L .24113 .47589 L closepath p F P
0 g
s
.906 .523 .284 r
.06525 .3687 m .06948 .3718 L .06818 .36729 L p F P
0 g
s
.906 .523 .284 r
.06818 .36729 m .06395 .36418 L .06525 .3687 L p F P
0 g
s
.741 .217 0 r
.10379 .40771 m .10854 .41057 L .10529 .40662 L p F P
0 g
s
.741 .217 0 r
.1011 .40444 m .10379 .40771 L p .10529 .40662 L F P
0 g
s
.741 .217 0 r
.10529 .40662 m .1033 .40543 L .1011 .40444 L p F P
0 g
s
.383 .296 .633 r
.76323 .31119 m .75794 .31639 L .75497 .31215 L p F P
0 g
s
.383 .296 .633 r
.76262 .3078 m .76323 .31119 L p .75497 .31215 L F P
0 g
s
.383 .296 .633 r
.75497 .31215 m .76122 .30597 L .76262 .3078 L p F P
0 g
s
.932 .635 .457 r
.05024 .34527 m .05422 .3485 L .05412 .34362 L p F P
0 g
s
.932 .635 .457 r
.05412 .34362 m .05014 .34038 L .05024 .34527 L p F P
0 g
s
.569 0 0 r
.15058 .43896 m .14569 .43547 L .15103 .43807 L p F P
0 g
s
.569 0 0 r
.15534 .44131 m .15058 .43896 L p .15103 .43807 L F P
0 g
s
.569 0 0 r
.15103 .43807 m .15573 .44145 L .15534 .44131 L p F P
0 g
s
0 .478 .733 r
.27389 .48431 m .27515 .48456 L .27287 .48406 L closepath p F P
0 g
s
.592 .024 0 r
.26599 .34465 m .26109 .34127 L .26751 .34358 L p F P
0 g
s
.592 .024 0 r
.26867 .34555 m .26599 .34465 L p .26751 .34358 L F P
0 g
s
.592 .024 0 r
.26751 .34358 m .27079 .34566 L .26867 .34555 L p F P
0 g
s
.012 .463 .871 r
.16743 .29296 m .16812 .29322 L .17254 .29631 L p F P
0 g
s
.027 .473 .878 r
.17503 .29574 m .17967 .29876 L .17254 .29631 L p F P
0 g
s
.027 .473 .878 r
.17254 .29631 m .16812 .29322 L .17503 .29574 L p F P
0 g
s
.54 0 0 r
.16145 .4441 m .15943 .44276 L .15573 .44145 L p F P
0 g
s
.466 0 0 r
.17664 .45145 m .1783 .45238 L .1738 .45051 L closepath p F P
0 g
s
0 0 0 r
.68456 .41563 m .67516 .42221 L .68318 .4175 L closepath p F P
0 g
s
0 0 0 r
.6821 .41873 m .68318 .4175 L .67516 .42221 L p F P
0 g
s
0 0 0 r
.67502 .42349 m .6821 .41873 L p .67516 .42221 L F P
0 g
s
0 0 0 r
.67141 .4256 m .67502 .42349 L p .67516 .42221 L F P
0 g
s
0 0 0 r
.59592 .46364 m .59738 .46306 L .58607 .46725 L p F P
0 g
s
0 0 0 r
.58607 .46725 m .58512 .46764 L .59592 .46364 L p F P
0 g
s
.387 .822 .669 r
.59168 .31448 m .59196 .31437 L .58219 .31983 L p F P
0 g
s
.387 .822 .669 r
.58219 .31983 m .5804 .32069 L .59168 .31448 L p F P
0 g
s
.631 .145 .08 r
.33179 .36898 m .32675 .36556 L .33551 .36705 L p F P
0 g
s
.631 .145 .08 r
.33434 .3694 m .33179 .36898 L p .33551 .36705 L F P
0 g
s
.631 .145 .08 r
.33551 .36705 m .33683 .36786 L .33434 .3694 L p F P
0 g
s
0 0 0 r
.64672 .44047 m .64811 .43936 L .63679 .44527 L p F P
0 g
s
0 0 0 r
.63679 .44527 m .63662 .44541 L .64672 .44047 L p F P
0 g
s
.621 .075 0 r
.28391 .35262 m .27905 .3492 L .28604 .35131 L p F P
0 g
s
.621 .075 0 r
.28522 .353 m .28391 .35262 L p .28604 .35131 L F P
0 g
s
.621 .075 0 r
.28604 .35131 m .28812 .35265 L .28522 .353 L p F P
0 g
s
.535 0 0 r
.24899 .33638 m .24392 .33308 L .2499 .33556 L p F P
0 g
s
.535 0 0 r
.25124 .33724 m .24899 .33638 L p .2499 .33556 L F P
0 g
s
.535 0 0 r
.2499 .33556 m .25351 .33773 L .25124 .33724 L p F P
0 g
s
.55 .092 .118 r
.40719 .37484 m .39761 .37491 L .39661 .37596 L p F P
0 g
s
.573 .119 .134 r
.39761 .37491 m .39661 .37596 L .39382 .37485 L closepath p F P
0 g
s
.891 .484 .229 r
.0711 .37622 m .07539 .37929 L .07377 .37487 L p F P
0 g
s
.891 .484 .229 r
.07377 .37487 m .06948 .3718 L .0711 .37622 L p F P
0 g
s
.574 .11 .115 r
.39514 .37765 m .39661 .37596 L .39382 .37485 L p F P
0 g
s
.574 .11 .115 r
.38814 .37748 m .39514 .37765 L p .39382 .37485 L F P
0 g
s
.574 .11 .115 r
.38246 .37482 m .38814 .37748 L p .39382 .37485 L F P
0 g
s
.574 .11 .115 r
.39382 .37485 m .38278 .37451 L .38246 .37482 L p F P
0 g
s
.552 .1 .133 r
.41191 .37476 m .41079 .37602 L .40719 .37484 L closepath p F P
0 g
s
.55 .092 .118 r
.40954 .37757 m .41079 .37602 L .40719 .37484 L p F P
0 g
s
.55 .092 .118 r
.40097 .37765 m .40954 .37757 L p .40719 .37484 L F P
0 g
s
.55 .092 .118 r
.39661 .37596 m .40097 .37765 L p .40719 .37484 L F P
0 g
s
.324 .621 .957 r
.13283 .27704 m .13302 .27707 L .137 .28035 L p F P
0 g
s
.342 .635 .961 r
.14297 .27838 m .13302 .27707 L .137 .28035 L p F P
0 g
s
.342 .635 .961 r
.137 .28035 m .14657 .28155 L .14297 .27838 L p F P
0 g
s
.096 0 .156 r
.72784 .37731 m .72195 .38167 L .72729 .3748 L p F P
0 g
s
.096 0 .156 r
.72729 .3748 m .72879 .37368 L .72784 .37731 L p F P
0 g
s
.267 0 0 r
.5042 .35715 m .5052 .35598 L .49354 .35903 L p F P
0 g
s
.267 0 0 r
.49354 .35903 m .49301 .35962 L .5042 .35715 L p F P
0 g
s
.19 .722 .78 r
.47859 .49281 m .47882 .49277 L .49108 .49084 L p F P
0 g
s
.227 .747 .819 r
.47859 .49281 m .47882 .49277 L .47856 .49281 L closepath p F P
0 g
s
.523 .068 .113 r
.42222 .37429 m .41191 .37476 L .41079 .37602 L p F P
0 g
s
.932 .662 .505 r
.04623 .33712 m .05014 .34038 L .05046 .33537 L p F P
0 g
s
.932 .662 .505 r
.05046 .33537 m .04656 .3321 L .04623 .33712 L p F P
0 g
s
.265 .77 .758 r
.55504 .47679 m .5578 .47627 L .54653 .47952 L p F P
0 g
s
.265 .77 .758 r
.54653 .47952 m .54364 .48006 L .55504 .47679 L p F P
0 g
s
.202 .724 .711 r
.54364 .48006 m .54653 .47952 L p .53236 .48301 L F P
0 g
s
.287 .784 .871 r
.47882 .49277 m .47856 .49281 L .47552 .49265 L p F P
0 g
s
.181 .555 .932 r
.15016 .28465 m .1512 .28493 L .15539 .28812 L p F P
0 g
s
.201 .566 .937 r
.1594 .28696 m .16381 .29008 L .15539 .28812 L p F P
0 g
s
.201 .566 .937 r
.15539 .28812 m .1512 .28493 L .1594 .28696 L p F P
0 g
s
.45 .868 .733 r
.59921 .31079 m .59445 .31342 L .59196 .31437 L p F P
0 g
s
.164 .695 .852 r
.40547 .49738 m .40761 .49767 L p .39343 .4977 L F P
0 g
s
.164 .695 .852 r
.39343 .4977 m .40097 .49738 L .40547 .49738 L p F P
0 g
s
.175 .701 .862 r
.39343 .4977 m .40097 .49738 L .39096 .49733 L closepath p F P
0 g
s
.27 .775 .854 r
.49108 .49084 m .48974 .49081 L .47882 .49277 L closepath p F P
0 g
s
.287 .784 .871 r
.48669 .49067 m .48974 .49081 L .47882 .49277 L p F P
0 g
s
.287 .784 .871 r
.47552 .49265 m .48669 .49067 L p .47882 .49277 L F P
0 g
s
0 0 0 r
.69633 .40615 m .69581 .407 L .69891 .40447 L closepath p F P
0 g
s
.387 0 .05 r
.47373 .36548 m .46705 .36676 L .46485 .3696 L p F P
0 g
s
.661 .145 .002 r
.30548 .35844 m .30575 .35864 L .30524 .3585 L closepath p F P
0 g
s
.025 .586 .806 r
.31944 .49241 m .31985 .49245 L .3192 .49236 L closepath p F P
0 g
s
0 0 0 r
.64549 .44126 m .64672 .44047 L .63662 .44541 L p F P
0 g
s
0 0 0 r
.63662 .44541 m .63413 .44703 L .64549 .44126 L p F P
0 g
s
.439 0 0 r
.2327 .32782 m .22735 .32469 L .23297 .3273 L p F P
0 g
s
.439 0 0 r
.23297 .3273 m .23627 .32912 L .2327 .32782 L p F P
0 g
s
.155 0 .292 r
.73998 .36154 m .73837 .36289 L .7389 .35879 L p F P
0 g
s
.155 0 .292 r
.7389 .35879 m .74299 .35539 L .73998 .36154 L p F P
0 g
s
.592 .131 .129 r
.38278 .37451 m .38246 .37482 L .38168 .37446 L closepath p F P
0 g
s
.316 .179 .53 r
.75623 .33009 m .7539 .33221 L .75313 .32726 L p F P
0 g
s
.316 .179 .53 r
.75313 .32726 m .75578 .32485 L .75623 .33009 L p F P
0 g
s
.593 .141 .148 r
.3764 .37696 m .37043 .37379 L .38168 .37446 L p F P
0 g
s
.593 .141 .148 r
.38019 .37717 m .3764 .37696 L p .38168 .37446 L F P
0 g
s
.593 .141 .148 r
.38168 .37446 m .38246 .37482 L .38019 .37717 L p F P
0 g
s
.872 .439 .168 r
.07714 .38319 m .07539 .37929 L .07976 .38232 L p F P
0 g
s
.872 .439 .168 r
.07976 .38232 m .08096 .38498 L .07714 .38319 L p F P
0 g
s
0 0 0 r
.6204 .45357 m .62278 .45233 L .61145 .45724 L p F P
0 g
s
0 0 0 r
.61145 .45724 m .60995 .45804 L .6204 .45357 L p F P
0 g
s
.435 0 .089 r
.45346 .36986 m .46243 .36996 L .45219 .37153 L closepath p F P
0 g
s
.657 .715 .891 r
.71012 .26912 m .72166 .2655 L .72437 .26941 L p F P
0 g
s
.67 .74 .902 r
.72166 .2655 m .71012 .26912 L .70743 .26594 L p F P
0 g
s
.686 .771 .916 r
.69595 .27041 m .70743 .26594 L .71012 .26912 L p F P
0 g
s
.67 .161 .024 r
.30288 .36024 m .31043 .36215 L .30575 .35864 L p F P
0 g
s
.67 .161 .024 r
.30195 .35948 m .30288 .36024 L p .30575 .35864 L F P
0 g
s
.67 .161 .024 r
.30575 .35864 m .30524 .3585 L .30195 .35948 L p F P
0 g
s
.253 .762 .856 r
.47552 .49265 m .46439 .49439 L .46129 .4942 L p F P
0 g
s
.338 .228 .579 r
.75973 .32101 m .75578 .32485 L .75503 .31922 L p F P
0 g
s
.338 .228 .579 r
.75503 .31922 m .75794 .31639 L .75973 .32101 L p F P
0 g
s
.109 .641 .867 r
.32811 .49264 m .33017 .49317 L .31985 .49245 L p F P
0 g
s
.109 .641 .867 r
.32456 .49212 m .32811 .49264 L p .31985 .49245 L F P
0 g
s
.109 .641 .867 r
.31604 .49152 m .32456 .49212 L p .31985 .49245 L F P
0 g
s
.109 .641 .867 r
.31985 .49245 m .3192 .49236 L .31604 .49152 L p F P
0 g
s
0 .55 .811 r
.28327 .48584 m .28443 .48618 L .27515 .48456 L p F P
0 g
s
0 .55 .811 r
.27819 .48466 m .28327 .48584 L p .27515 .48456 L F P
0 g
s
0 .55 .811 r
.2704 .48333 m .27819 .48466 L p .27515 .48456 L F P
0 g
s
0 .55 .811 r
.27515 .48456 m .27287 .48406 L .2704 .48333 L p F P
0 g
s
.18 .708 .851 r
.41962 .49706 m .4218 .49731 L p .40761 .49767 L F P
0 g
s
.18 .708 .851 r
.40761 .49767 m .41497 .49718 L .41962 .49706 L p F P
0 g
s
.195 .717 .865 r
.40761 .49767 m .41497 .49718 L .40547 .49738 L closepath p F P
0 g
s
.526 .076 .125 r
.42573 .37412 m .425 .37498 L .42222 .37429 L closepath p F P
0 g
s
.523 .068 .113 r
.42347 .377 m .425 .37498 L .42222 .37429 L p F P
0 g
s
.523 .068 .113 r
.41527 .37735 m .42347 .377 L p .42222 .37429 L F P
0 g
s
.523 .068 .113 r
.41079 .37602 m .41527 .37735 L p .42222 .37429 L F P
0 g
s
0 .468 .755 r
.24594 .47698 m .25285 .47901 L .24385 .47665 L p F P
0 g
s
0 .468 .755 r
.23895 .47519 m .24594 .47698 L p .24385 .47665 L F P
0 g
s
0 .468 .755 r
.24385 .47665 m .24113 .47589 L .23895 .47519 L p F P
0 g
s
.574 .579 .82 r
.7469 .27717 m .74155 .27723 L .73877 .27182 L p F P
0 g
s
.65 .134 .001 r
.30524 .3585 m .30195 .35948 L .29806 .35677 L closepath p F P
0 g
s
.055 .602 .838 r
.3192 .49236 m .31604 .49152 L .31109 .49104 L closepath p F P
0 g
s
.93 .687 .55 r
.04272 .32879 m .04656 .3321 L .04732 .32694 L p F P
0 g
s
.93 .687 .55 r
.04732 .32694 m .04349 .32363 L .04272 .32879 L p F P
0 g
s
.697 .82 .941 r
.70474 .26303 m .70743 .26594 L .69595 .27041 L p F P
0 g
s
.697 .82 .941 r
.69367 .26769 m .70474 .26303 L p .69595 .27041 L F P
0 g
s
.697 .82 .941 r
.69595 .27041 m .69338 .26797 L .69367 .26769 L p F P
0 g
s
.509 .058 .114 r
.43696 .37596 m .43913 .37301 L .42573 .37412 L p F P
0 g
s
.509 .058 .114 r
.43172 .37636 m .43696 .37596 L p .42573 .37412 L F P
0 g
s
.509 .058 .114 r
.42573 .37412 m .425 .37498 L .43172 .37636 L p F P
0 g
s
.225 .044 .414 r
.75248 .34307 m .74787 .34721 L .74795 .34261 L p F P
0 g
s
.225 .044 .414 r
.74795 .34261 m .75365 .3375 L .75248 .34307 L p F P
0 g
s
.247 .756 .865 r
.46129 .4942 m .45019 .49568 L .44705 .49544 L p F P
0 g
s
.212 .733 .85 r
.43599 .49665 m .44705 .49544 L .45019 .49568 L p F P
0 g
s
.628 .065 0 r
.13487 .4299 m .13087 .42651 L .13597 .42921 L p F P
0 g
s
.628 .065 0 r
.13597 .42921 m .1386 .43141 L .13487 .4299 L p F P
0 g
s
.193 .719 .849 r
.43342 .4964 m .43599 .49665 L p .4218 .49731 L F P
0 g
s
.193 .719 .849 r
.4218 .49731 m .43037 .49656 L .43342 .4964 L p F P
0 g
s
.212 .73 .866 r
.4218 .49731 m .43037 .49656 L .41962 .49706 L closepath p F P
0 g
s
.453 .681 .963 r
.13046 .27489 m .13283 .27704 L p .11901 .27373 L F P
0 g
s
.453 .681 .963 r
.11901 .27373 m .12907 .27376 L .13046 .27489 L p F P
0 g
s
.453 .678 .961 r
.12907 .27376 m .11901 .27373 L .11539 .27037 L p F P
0 g
s
.727 .198 0 r
.11205 .41445 m .11686 .41727 L .11336 .41339 L p F P
0 g
s
.727 .198 0 r
.11336 .41339 m .10854 .41057 L .11205 .41445 L p F P
0 g
s
.228 .742 .865 r
.44692 .49542 m .44705 .49544 L .43599 .49665 L p F P
0 g
s
.228 .742 .865 r
.43599 .49665 m .43342 .4964 L .44692 .49542 L p F P
0 g
s
0 .273 .645 r
.21548 .31832 m .21122 .31613 L .21653 .31887 L p F P
0 g
s
0 .273 .645 r
.21653 .31887 m .21905 .32009 L .21548 .31832 L p F P
0 g
s
0 0 0 r
.68813 .41301 m .68456 .41563 L .68318 .4175 L p F P
0 g
s
.775 .268 0 r
.1033 .40543 m .1011 .40444 L .10057 .40375 L closepath p F P
0 g
s
.594 .143 .149 r
.38246 .37482 m .38814 .37748 L .38019 .37717 L closepath p F P
0 g
s
.862 .422 .155 r
.08096 .38498 m .08176 .38663 L .08626 .38961 L p F P
0 g
s
.835 .368 .073 r
.08421 .3908 m .08869 .39379 L .08626 .38961 L p F P
0 g
s
.835 .368 .073 r
.08626 .38961 m .08176 .38663 L .08421 .3908 L p F P
0 g
s
.71 .936 .961 r
.6677 .27688 m .65641 .28277 L .65371 .28172 L p F P
0 g
s
.621 .655 .862 r
.72437 .26941 m .73601 .26691 L .73612 .26709 L p F P
0 g
s
.636 .679 .874 r
.73601 .26691 m .72437 .26941 L .72166 .2655 L p F P
0 g
s
.651 .171 .1 r
.33683 .36786 m .34064 .37045 L .33434 .3694 L closepath p F P
0 g
s
.503 .904 .79 r
.60573 .30721 m .59921 .31079 L .60476 .30748 L closepath p F P
0 g
s
.45 .868 .733 r
.60297 .308 m .60476 .30748 L .59921 .31079 L p F P
0 g
s
.45 .868 .733 r
.59344 .31346 m .60297 .308 L p .59921 .31079 L F P
0 g
s
.45 .868 .733 r
.59196 .31437 m .59344 .31346 L p .59921 .31079 L F P
0 g
s
0 .497 .769 r
.27287 .48406 m .2704 .48333 L .2676 .48276 L closepath p F P
0 g
s
.048 0 .083 r
.72704 .37969 m .72784 .37731 L .72195 .38167 L p F P
0 g
s
.048 0 .083 r
.7252 .38183 m .72704 .37969 L p .72195 .38167 L F P
0 g
s
.048 0 .083 r
.7177 .38739 m .7252 .38183 L p .72195 .38167 L F P
0 g
s
.048 0 .083 r
.72195 .38167 m .71814 .38607 L .7177 .38739 L p F P
0 g
s
.612 .15 .133 r
.36556 .37614 m .3764 .37696 L .37043 .37379 L p F P
0 g
s
.612 .15 .133 r
.36492 .37575 m .36556 .37614 L p .37043 .37379 L F P
0 g
s
.612 .15 .133 r
.37043 .37379 m .36738 .37355 L .36492 .37575 L p F P
0 g
s
.652 .964 .918 r
.63106 .29434 m .62988 .29499 L .63083 .29433 L closepath p F P
0 g
s
.617 .957 .889 r
.62834 .29423 m .63083 .29433 L .62988 .29499 L p F P
0 g
s
.617 .957 .889 r
.62029 .29888 m .62834 .29423 L p .62988 .29499 L F P
0 g
s
.617 .957 .889 r
.61767 .30074 m .62029 .29888 L p .62988 .29499 L F P
0 g
s
0 0 0 r
.56919 .32646 m .56913 .32649 L .56961 .32625 L closepath p F P
0 g
s
.067 0 .144 r
.73106 .37478 m .72784 .37731 L .72879 .37368 L p F P
0 g
s
.067 0 .144 r
.72879 .37368 m .73602 .36801 L .73106 .37478 L p F P
0 g
s
0 0 0 r
.69581 .407 m .68813 .41301 L .69459 .40898 L closepath p F P
0 g
s
0 0 0 r
.69341 .41058 m .69459 .40898 L .68813 .41301 L p F P
0 g
s
0 0 0 r
.68877 .41404 m .69341 .41058 L p .68813 .41301 L F P
0 g
s
0 0 0 r
.68318 .4175 m .68877 .41404 L p .68813 .41301 L F P
0 g
s
.358 0 0 r
.17872 .45307 m .18447 .45552 L .1783 .45238 L p F P
0 g
s
.358 0 0 r
.17297 .45019 m .17872 .45307 L p .1783 .45238 L F P
0 g
s
.358 0 0 r
.1783 .45238 m .1738 .45051 L .17297 .45019 L p F P
0 g
s
.125 0 0 r
.52962 .3465 m .52992 .34621 L .51885 .34998 L p F P
0 g
s
.125 0 0 r
.51885 .34998 m .5184 .35044 L .52962 .3465 L p F P
0 g
s
.281 0 0 r
.19722 .46086 m .20323 .46321 L .19639 .46025 L p F P
0 g
s
.281 0 0 r
.19029 .45795 m .19722 .46086 L p .19639 .46025 L F P
0 g
s
.281 0 0 r
.19639 .46025 m .1903 .45795 L .19029 .45795 L p F P
0 g
s
0 0 0 r
.56961 .32625 m .56913 .32649 L .56647 .32833 L p F P
0 g
s
.291 .787 .765 r
.5691 .47274 m .57037 .47249 L .55919 .476 L p F P
0 g
s
.291 .787 .765 r
.55919 .476 m .5578 .47627 L .5691 .47274 L p F P
0 g
s
.303 0 0 r
.50302 .35872 m .5042 .35715 L .49301 .35962 L p F P
0 g
s
.303 0 0 r
.49301 .35962 m .49134 .36177 L .50302 .35872 L p F P
0 g
s
.543 .709 .948 r
.10147 .26827 m .10556 .26777 L .10933 .27116 L p F P
0 g
s
.549 .712 .948 r
.11177 .26697 m .10556 .26777 L .10933 .27116 L p F P
0 g
s
.549 .712 .948 r
.10933 .27116 m .11539 .27037 L .11177 .26697 L p F P
0 g
s
.622 .163 .141 r
.36738 .37355 m .36492 .37575 L .35988 .37288 L closepath p F P
0 g
s
.675 .971 .916 r
.63972 .28757 m .64237 .28805 L .63106 .29434 L p F P
0 g
s
.675 .971 .916 r
.63106 .29434 m .63083 .29433 L .63972 .28757 L p F P
0 g
s
0 0 0 r
.5804 .32069 m .56961 .32625 L .57925 .32138 L closepath p F P
0 g
s
0 0 0 r
.57759 .3224 m .57925 .32138 L .56961 .32625 L p F P
0 g
s
0 0 0 r
.56773 .32768 m .57759 .3224 L p .56961 .32625 L F P
0 g
s
0 0 0 r
.56647 .32833 m .56773 .32768 L p .56961 .32625 L F P
0 g
s
0 .377 .677 r
.23029 .47251 m .22507 .47084 L .22149 .46969 L p F P
0 g
s
0 .407 .703 r
.24113 .47589 m .23895 .47519 L .23697 .47462 L closepath p F P
0 g
s
.913 .723 .632 r
.0425 .31036 m .041 .31495 L .04476 .31831 L p F P
0 g
s
.924 .709 .593 r
.03972 .32028 m .04349 .32363 L .04476 .31831 L p F P
0 g
s
.924 .709 .593 r
.04476 .31831 m .041 .31495 L .03972 .32028 L p F P
0 g
s
.659 .165 .064 r
.32322 .36741 m .33179 .36898 L .32675 .36556 L p F P
0 g
s
.659 .165 .064 r
.31938 .36444 m .32322 .36741 L p .32675 .36556 L F P
0 g
s
.659 .165 .064 r
.32675 .36556 m .31999 .36416 L .31938 .36444 L p F P
0 g
s
0 0 0 r
.7072 .397 m .70702 .39736 L .70803 .39643 L closepath p F P
0 g
s
.382 0 .032 r
.47934 .36444 m .47879 .36512 L .47373 .36548 L closepath p F P
0 g
s
.387 0 .05 r
.47721 .36733 m .47879 .36512 L .47373 .36548 L p F P
0 g
s
.387 0 .05 r
.46485 .3696 m .47721 .36733 L p .47373 .36548 L F P
0 g
s
.133 .659 .877 r
.34363 .49448 m .33354 .49399 L .33017 .49317 L p F P
0 g
s
.073 0 .093 r
.71814 .38607 m .71559 .38887 L .7177 .38739 L closepath p F P
0 g
s
0 .399 .79 r
.19828 .3087 m .19538 .30747 L .20042 .31032 L p F P
0 g
s
0 .399 .79 r
.20042 .31032 m .20185 .31089 L .19828 .3087 L p F P
0 g
s
.252 .762 .767 r
.53236 .48301 m .54281 .48028 L .53203 .48306 L closepath p F P
0 g
s
.202 .724 .711 r
.53236 .48301 m .54281 .48028 L .54364 .48006 L p F P
0 g
s
.474 .029 .112 r
.43923 .37287 m .43979 .37293 L .43913 .37301 L closepath p F P
0 g
s
.003 .561 .812 r
.29415 .48801 m .2879 .48711 L .28443 .48618 L p F P
0 g
s
0 .552 .802 r
.30169 .48951 m .30195 .48957 L p .2879 .48711 L F P
0 g
s
0 .552 .802 r
.2879 .48711 m .29415 .48801 L .30169 .48951 L p F P
0 g
s
.54 0 0 r
.15573 .44145 m .15591 .44157 L .16145 .4441 L p F P
0 g
s
.469 0 0 r
.16148 .44487 m .16697 .44743 L .16145 .4441 L p F P
0 g
s
.469 0 0 r
.16145 .4441 m .15591 .44157 L .16148 .44487 L p F P
0 g
s
0 0 0 r
.6235 .45195 m .62278 .45233 L .63045 .44879 L closepath p F P
0 g
s
.308 0 0 r
.20766 .46476 m .20949 .46547 L .21589 .46768 L p F P
0 g
s
.255 0 0 r
.21715 .46821 m .20949 .46547 L .21589 .46768 L p F P
0 g
s
.255 0 0 r
.2189 .46883 m .21715 .46821 L p .21589 .46768 L F P
0 g
s
.255 0 0 r
.21589 .46768 m .22149 .46969 L .2189 .46883 L p F P
0 g
s
.199 0 .355 r
.74755 .35154 m .74299 .35539 L .74516 .3495 L p F P
0 g
s
.199 0 .355 r
.74516 .3495 m .74787 .34721 L .74755 .35154 L p F P
0 g
s
.418 .35 .674 r
.7621 .30509 m .76122 .30597 L .75672 .30222 L p F P
0 g
s
.418 .35 .674 r
.75672 .30222 m .76051 .29842 L .7621 .30509 L p F P
0 g
s
.674 .971 .914 r
.63966 .28756 m .63972 .28757 L .63083 .29433 L p F P
0 g
s
.674 .971 .914 r
.63083 .29433 m .62834 .29423 L .63966 .28756 L p F P
0 g
s
.721 .849 .942 r
.69327 .26786 m .68184 .27306 L .67916 .27112 L p F P
0 g
s
.726 .874 .95 r
.66777 .27684 m .67916 .27112 L .68184 .27306 L p F P
0 g
s
.007 0 .001 r
.71635 .3906 m .70803 .39643 L .71559 .38887 L p F P
0 g
s
.007 0 .001 r
.71559 .38887 m .7177 .38739 L .71635 .3906 L p F P
0 g
s
0 0 0 r
.69891 .40447 m .69581 .407 L .69459 .40898 L p F P
0 g
s
.669 .142 0 r
.28812 .35265 m .29082 .35475 L .28522 .353 L closepath p F P
0 g
s
.81 .325 .018 r
.09141 .39789 m .09595 .40084 L .09324 .39673 L p F P
0 g
s
.81 .325 .018 r
.09324 .39673 m .08869 .39379 L .09141 .39789 L p F P
0 g
s
.29 .779 .716 r
.5946 .46404 m .59592 .46364 L .58512 .46764 L p F P
0 g
s
.29 .779 .716 r
.58512 .46764 m .58326 .46819 L .5946 .46404 L p F P
0 g
s
.625 .735 .926 r
.0874 .26766 m .09783 .26483 L .10147 .26827 L p F P
0 g
s
.045 .507 .888 r
.18514 .3021 m .18465 .30176 L .18446 .30171 L closepath p F P
0 g
s
.482 .044 .129 r
.43979 .37293 m .43913 .37301 L .43696 .37596 L p F P
0 g
s
0 0 0 r
.70702 .39736 m .69891 .40447 L .70565 .40001 L closepath p F P
0 g
s
0 0 0 r
.70468 .40157 m .70565 .40001 L .69891 .40447 L p F P
0 g
s
0 0 0 r
.70022 .40528 m .70468 .40157 L p .69891 .40447 L F P
0 g
s
0 0 0 r
.69459 .40898 m .70022 .40528 L p .69891 .40447 L F P
0 g
s
.713 .178 0 r
.12161 .41992 m .12175 .42006 L .12119 .41975 L closepath p F P
0 g
s
.481 .039 .122 r
.45219 .37153 m .45027 .37411 L .43979 .37293 L closepath p F P
0 g
s
.482 .044 .129 r
.45003 .37446 m .45027 .37411 L .43979 .37293 L p F P
0 g
s
.482 .044 .129 r
.43696 .37596 m .45003 .37446 L p .43979 .37293 L F P
0 g
s
.263 .762 .71 r
.58137 .46873 m .58326 .46819 L .57195 .47204 L p F P
0 g
s
.263 .762 .71 r
.57195 .47204 m .57037 .47249 L .58137 .46873 L p F P
0 g
s
.629 .158 .117 r
.36461 .37605 m .36492 .37575 L .35988 .37288 L p F P
0 g
s
.629 .158 .117 r
.35528 .37513 m .36461 .37605 L p .35988 .37288 L F P
0 g
s
.629 .158 .117 r
.35085 .3722 m .35528 .37513 L p .35988 .37288 L F P
0 g
s
.629 .158 .117 r
.35988 .37288 m .35127 .37187 L .35085 .3722 L p F P
0 g
s
.571 .126 .154 r
.39661 .37596 m .40097 .37765 L .39514 .37765 L closepath p F P
0 g
s
.008 .57 .803 r
.30195 .48957 m .30233 .48962 L .31109 .49104 L p F P
0 g
s
.064 .607 .846 r
.31263 .49058 m .30233 .48962 L .31109 .49104 L p F P
0 g
s
.064 .607 .846 r
.31109 .49104 m .31604 .49152 L .31263 .49058 L p F P
0 g
s
.664 .127 0 r
.27079 .34566 m .27245 .34695 L .27905 .3492 L p F P
0 g
s
.667 .13 0 r
.27695 .35049 m .28391 .35262 L .27905 .3492 L p F P
0 g
s
.667 .13 0 r
.27905 .3492 m .27245 .34695 L .27695 .35049 L p F P
0 g
s
0 .463 .735 r
.25642 .48003 m .26021 .48089 L .2676 .48276 L p F P
0 g
s
0 .465 .738 r
.25642 .48003 m .26021 .48089 L .25295 .47904 L closepath p F P
0 g
s
.637 .078 0 r
.25351 .33773 m .25499 .33885 L .26109 .34127 L p F P
0 g
s
.639 .081 0 r
.25956 .34233 m .26599 .34465 L .26109 .34127 L p F P
0 g
s
.639 .081 0 r
.26109 .34127 m .25499 .33885 L .25956 .34233 L p F P
0 g
s
0 0 0 r
.71591 .39146 m .71635 .3906 L .70803 .39643 L p F P
0 g
s
0 0 0 r
.70989 .39705 m .71591 .39146 L p .70803 .39643 L F P
0 g
s
0 0 0 r
.70565 .40001 m .70989 .39705 L p .70803 .39643 L F P
0 g
s
0 0 0 r
.70803 .39643 m .70702 .39736 L .70565 .40001 L p F P
0 g
s
.631 .071 0 r
.12088 .42101 m .12584 .42378 L .12175 .42006 L p F P
0 g
s
.631 .071 0 r
.11786 .41825 m .12088 .42101 L p .12175 .42006 L F P
0 g
s
.631 .071 0 r
.12175 .42006 m .12119 .41975 L .11786 .41825 L p F P
0 g
s
0 0 0 r
.55368 .33529 m .55503 .33407 L .54378 .33913 L p F P
0 g
s
0 0 0 r
.54378 .33913 m .54313 .33974 L .55368 .33529 L p F P
0 g
s
.311 .803 .827 r
.54281 .48028 m .53203 .48306 L .5294 .48326 L p F P
0 g
s
0 0 0 r
.658 .43392 m .64811 .43936 L .64672 .44047 L p F P
0 g
s
.299 .793 .865 r
.50094 .48856 m .50339 .48864 L .49108 .49084 L p F P
0 g
s
.299 .793 .865 r
.49108 .49084 m .48974 .49081 L .50094 .48856 L p F P
0 g
s
.057 .51 .893 r
.18107 .29922 m .17967 .29876 L .18446 .30171 L p F P
0 g
s
.057 .51 .893 r
.18446 .30171 m .18465 .30176 L .18107 .29922 L p F P
0 g
s
.175 0 0 r
.52767 .34879 m .52962 .3465 L .5184 .35044 L p F P
0 g
s
.175 0 0 r
.5184 .35044 m .51658 .35257 L .52767 .34879 L p F P
0 g
s
.027 .467 .877 r
.16743 .29296 m .16812 .29322 L .16398 .29019 L closepath p F P
0 g
s
0 0 0 r
.5663 .32845 m .56647 .32833 L .55622 .33316 L p F P
0 g
s
0 0 0 r
.55622 .33316 m .55503 .33407 L .5663 .32845 L p F P
0 g
s
.516 .077 .144 r
.425 .37498 m .43172 .37636 L .42347 .377 L closepath p F P
0 g
s
.65 .134 .001 r
.29538 .3583 m .29082 .35475 L .29806 .35677 L p F P
0 g
s
.65 .134 .001 r
.30108 .35974 m .29538 .3583 L p .29806 .35677 L F P
0 g
s
.65 .134 .001 r
.29806 .35677 m .30195 .35948 L .30108 .35974 L p F P
0 g
s
.548 .925 .799 r
.61428 .30124 m .61702 .30078 L .60573 .30721 L p F P
0 g
s
.548 .925 .799 r
.61291 .30206 m .61428 .30124 L p .60573 .30721 L F P
0 g
s
.548 .925 .799 r
.60573 .30721 m .60476 .30748 L .61291 .30206 L p F P
0 g
s
0 .326 .744 r
.19052 .30455 m .18465 .30176 L .18107 .29922 L p F P
0 g
s
.584 .008 0 r
.23627 .32912 m .23821 .33051 L .24392 .33308 L p F P
0 g
s
.581 .004 0 r
.24298 .3339 m .24899 .33638 L .24392 .33308 L p F P
0 g
s
.581 .004 0 r
.24392 .33308 m .23821 .33051 L .24298 .3339 L p F P
0 g
s
.681 .134 0 r
.12119 .41975 m .11786 .41825 L .11686 .41727 L closepath p F P
0 g
s
0 .504 .78 r
.26691 .48224 m .26021 .48089 L .2676 .48276 L p F P
0 g
s
0 .504 .78 r
.2676 .48276 m .2704 .48333 L .26691 .48224 L p F P
0 g
s
.603 .033 0 r
.1386 .43141 m .14042 .43283 L .14569 .43547 L p F P
0 g
s
.547 0 0 r
.14535 .43631 m .15058 .43896 L .14569 .43547 L p F P
0 g
s
.547 0 0 r
.14569 .43547 m .14042 .43283 L .14535 .43631 L p F P
0 g
s
.545 .104 .152 r
.41079 .37602 m .41527 .37735 L .40954 .37757 L closepath p F P
0 g
s
.177 .548 .929 r
.1512 .28493 m .15016 .28465 L .14657 .28155 L p F P
0 g
s
.344 0 .01 r
.48996 .36356 m .49134 .36177 L .47934 .36444 L p F P
0 g
s
.344 0 .01 r
.47934 .36444 m .47879 .36512 L .48996 .36356 L p F P
0 g
s
.543 .708 .947 r
.10556 .26777 m .10147 .26827 L .09783 .26483 L p F P
0 g
s
.131 .663 .864 r
.34767 .49526 m .354 .4954 L .34468 .4946 L closepath p F P
0 g
s
.131 .663 .864 r
.3606 .49597 m .36182 .49623 L p .34767 .49526 L F P
0 g
s
.131 .663 .864 r
.34767 .49526 m .354 .4954 L .3606 .49597 L p F P
0 g
s
.373 0 0 r
.20611 .31332 m .20185 .31089 L .19828 .3087 L p F P
0 g
s
.864 .424 .149 r
.08176 .38663 m .08096 .38498 L .07714 .38319 L p F P
0 g
s
.773 .265 0 r
.09732 .40263 m .09595 .40084 L .10057 .40375 L p F P
0 g
s
.773 .265 0 r
.10057 .40375 m .1011 .40444 L .09732 .40263 L p F P
0 g
s
.657 .11 0 r
.27079 .34566 m .27245 .34695 L .26867 .34555 L closepath p F P
0 g
s
.287 .787 .821 r
.52733 .4834 m .5294 .48326 L .51817 .48597 L p F P
0 g
s
.287 .787 .821 r
.51817 .48597 m .51548 .48616 L .52733 .4834 L p F P
0 g
s
.232 .751 .785 r
.51548 .48616 m .51817 .48597 L p .50396 .48861 L F P
0 g
s
.926 .597 .397 r
.0544 .35018 m .05476 .35324 L .05884 .35642 L p F P
0 g
s
.921 .562 .333 r
.05571 .35786 m .0598 .36104 L .05884 .35642 L p F P
0 g
s
.921 .562 .333 r
.05884 .35642 m .05476 .35324 L .05571 .35786 L p F P
0 g
s
.299 0 0 r
.20766 .46476 m .20949 .46547 L .20523 .46397 L closepath p F P
0 g
s
0 .414 .715 r
.2354 .474 m .23029 .47251 L .23697 .47462 L p F P
0 g
s
0 .414 .715 r
.23697 .47462 m .23895 .47519 L .2354 .474 L p F P
0 g
s
.931 .606 .401 r
.05053 .3482 m .05024 .34527 L .05422 .3485 L p F P
0 g
s
.931 .606 .401 r
.05422 .3485 m .0544 .35018 L .05053 .3482 L p F P
0 g
s
.294 .163 .526 r
.76048 .32598 m .75623 .33009 L .75578 .32485 L p F P
0 g
s
.294 .163 .526 r
.75578 .32485 m .75973 .32101 L .76048 .32598 L p F P
0 g
s
.574 .579 .82 r
.75125 .27254 m .7469 .27717 L p .73877 .27182 L F P
0 g
s
.574 .579 .82 r
.73877 .27182 m .75055 .27105 L .75125 .27254 L p F P
0 g
s
.567 .621 .866 r
.73612 .26709 m .73877 .27182 L .75055 .27105 L p F P
0 g
s
.908 .524 .276 r
.06109 .36555 m .06525 .3687 L .06395 .36418 L p F P
0 g
s
.908 .524 .276 r
.06395 .36418 m .0598 .36104 L .06109 .36555 L p F P
0 g
s
0 .442 .859 r
.17054 .29266 m .17503 .29574 L .16812 .29322 L p F P
0 g
s
0 .442 .859 r
.16385 .29009 m .17054 .29266 L p .16812 .29322 L F P
0 g
s
0 .442 .859 r
.16812 .29322 m .16398 .29019 L .16385 .29009 L p F P
0 g
s
.648 .15 .053 r
.31999 .36416 m .31938 .36444 L .31853 .36387 L closepath p F P
0 g
s
.461 0 0 r
.22707 .32523 m .22196 .32199 L .22735 .32469 L p F P
0 g
s
.461 0 0 r
.23263 .3278 m .22707 .32523 L p .22735 .32469 L F P
0 g
s
.461 0 0 r
.22735 .32469 m .2327 .32782 L .23263 .3278 L p F P
0 g
s
.496 0 0 r
.21905 .32009 m .22196 .32199 L .22735 .32469 L p F P
0 g
s
.504 0 0 r
.22196 .32199 m .21905 .32009 L .21548 .31832 L p F P
0 g
s
.935 .639 .454 r
.04632 .342 m .05024 .34527 L .05014 .34038 L p F P
0 g
s
.935 .639 .454 r
.05014 .34038 m .04623 .33712 L .04632 .342 L p F P
0 g
s
.633 .163 .12 r
.35127 .37187 m .35085 .3722 L .35008 .37173 L closepath p F P
0 g
s
0 0 0 r
.60655 .4594 m .60872 .45854 L .59738 .46306 L p F P
0 g
s
0 0 0 r
.59738 .46306 m .59592 .46364 L .60655 .4594 L p F P
0 g
s
.625 .06 0 r
.25351 .33773 m .25499 .33885 L .25124 .33724 L closepath p F P
0 g
s
.893 .484 .219 r
.06687 .37311 m .0711 .37622 L .06948 .3718 L p F P
0 g
s
.893 .484 .219 r
.06948 .3718 m .06525 .3687 L .06687 .37311 L p F P
0 g
s
.329 .62 .956 r
.13283 .27704 m .13302 .27707 L .13046 .27489 L closepath p F P
0 g
s
.541 .547 .81 r
.7469 .27717 m .75125 .27254 L .75339 .27746 L closepath p F P
0 g
s
.594 .021 0 r
.23821 .33051 m .23627 .32912 L .2327 .32782 L p F P
0 g
s
.648 .152 .058 r
.31519 .36566 m .31043 .36215 L .31853 .36387 L p F P
0 g
s
.648 .152 .058 r
.31635 .3659 m .31519 .36566 L p .31853 .36387 L F P
0 g
s
.648 .152 .058 r
.31853 .36387 m .31938 .36444 L .31635 .3659 L p F P
0 g
s
.227 0 0 r
.51542 .35394 m .51658 .35257 L .5052 .35598 L p F P
0 g
s
.227 0 0 r
.5052 .35598 m .5042 .35715 L .51542 .35394 L p F P
0 g
s
.632 .168 .133 r
.3457 .3739 m .34064 .37045 L .35008 .37173 L p F P
0 g
s
.632 .168 .133 r
.34832 .37424 m .3457 .3739 L p .35008 .37173 L F P
0 g
s
.632 .168 .133 r
.35008 .37173 m .35085 .3722 L .34832 .37424 L p F P
0 g
s
.462 .42 .726 r
.75658 .29288 m .75838 .29104 L .75931 .2941 L closepath p F P
0 g
s
.634 .963 .886 r
.61767 .30074 m .61702 .30078 L .62029 .29888 L closepath p F P
0 g
s
.307 .609 .953 r
.14159 .27713 m .14297 .27838 L .13302 .27707 L p F P
0 g
s
.307 .609 .953 r
.1391 .27511 m .14159 .27713 L p .13302 .27707 L F P
0 g
s
.307 .609 .953 r
.12922 .27376 m .1391 .27511 L p .13302 .27707 L F P
0 g
s
.307 .609 .953 r
.13302 .27707 m .13046 .27489 L .12922 .27376 L p F P
0 g
s
.429 0 0 r
.1738 .45051 m .17297 .45019 L .17252 .44994 L closepath p F P
0 g
s
0 0 0 r
.63045 .44879 m .62278 .45233 L .6204 .45357 L p F P
0 g
s
.177 .548 .929 r
.14657 .28155 m .1471 .28169 L .1512 .28493 L p F P
0 g
s
.194 .558 .934 r
.15513 .28378 m .1594 .28696 L .1512 .28493 L p F P
0 g
s
.194 .558 .934 r
.1512 .28493 m .1471 .28169 L .15513 .28378 L p F P
0 g
s
.27 .111 .474 r
.7564 .335 m .75365 .3375 L .7539 .33221 L p F P
0 g
s
.27 .111 .474 r
.7539 .33221 m .75623 .33009 L .7564 .335 L p F P
0 g
s
0 0 0 r
.71818 .38925 m .71635 .3906 L .7177 .38739 L p F P
0 g
s
0 0 0 r
.7177 .38739 m .7252 .38183 L .71818 .38925 L p F P
0 g
s
.337 .227 .579 r
.764 .31684 m .75973 .32101 L .75794 .31639 L p F P
0 g
s
.337 .227 .579 r
.75794 .31639 m .76323 .31119 L .764 .31684 L p F P
0 g
s
.02 .577 .814 r
.30195 .48957 m .30233 .48962 L .30169 .48951 L closepath p F P
0 g
s
.757 .24 0 r
.10379 .40771 m .1011 .40444 L .09732 .40263 L p F P
0 g
s
.439 0 .097 r
.46243 .36996 m .45219 .37153 L .45027 .37411 L p F P
0 g
s
.936 .666 .503 r
.04239 .33381 m .04623 .33712 L .04656 .3321 L p F P
0 g
s
.936 .666 .503 r
.04656 .3321 m .04272 .32879 L .04239 .33381 L p F P
0 g
s
.721 .917 .96 r
.66777 .27684 m .6677 .27688 L .66775 .27683 L closepath p F P
0 g
s
.71 .936 .961 r
.66508 .2755 m .66775 .27683 L .6677 .27688 L p F P
0 g
s
.71 .936 .961 r
.65371 .28172 m .66508 .2755 L p .6677 .27688 L F P
0 g
s
.728 .919 .958 r
.67648 .2694 m .67916 .27112 L .66777 .27684 L p F P
0 g
s
.728 .919 .958 r
.67507 .27015 m .67648 .2694 L p .66777 .27684 L F P
0 g
s
.728 .919 .958 r
.66777 .27684 m .66775 .27683 L .67507 .27015 L p F P
0 g
s
.599 .03 0 r
.14042 .43283 m .1386 .43141 L .13487 .4299 L p F P
0 g
s
.728 .92 .958 r
.66775 .27683 m .66508 .2755 L .67507 .27015 L closepath p F P
0 g
s
.874 .442 .163 r
.07303 .38055 m .0711 .37622 L .07539 .37929 L p F P
0 g
s
.874 .442 .163 r
.07567 .38244 m .07303 .38055 L p .07539 .37929 L F P
0 g
s
.874 .442 .163 r
.07539 .37929 m .07714 .38319 L .07567 .38244 L p F P
0 g
s
.691 .963 .941 r
.65173 .28282 m .64237 .28805 L .63972 .28757 L p F P
0 g
s
.156 .683 .872 r
.36182 .49623 m .36469 .49622 L .37587 .49689 L p F P
0 g
s
.16 .684 .874 r
.36182 .49623 m .36469 .49622 L .3606 .49597 L closepath p F P
0 g
s
.105 .633 .874 r
.31084 .49004 m .31263 .49058 L .30233 .48962 L p F P
0 g
s
.105 .633 .874 r
.30683 .48931 m .31084 .49004 L p .30233 .48962 L F P
0 g
s
.105 .633 .874 r
.29851 .48855 m .30683 .48931 L p .30233 .48962 L F P
0 g
s
.105 .633 .874 r
.30233 .48962 m .30169 .48951 L .29851 .48855 L p F P
0 g
s
0 .254 .635 r
.21173 .31636 m .20611 .31332 L .21122 .31613 L p F P
0 g
s
0 .254 .635 r
.21226 .31664 m .21173 .31636 L p .21122 .31613 L F P
0 g
s
0 .254 .635 r
.21122 .31613 m .21548 .31832 L .21226 .31664 L p F P
0 g
s
.626 .063 0 r
.13017 .42743 m .12584 .42378 L .13087 .42651 L p F P
0 g
s
.626 .063 0 r
.13395 .4295 m .13017 .42743 L p .13087 .42651 L F P
0 g
s
.626 .063 0 r
.13087 .42651 m .13487 .4299 L .13395 .4295 L p F P
0 g
s
.288 .766 .663 r
.62008 .45371 m .6204 .45357 L .60995 .45804 L p F P
0 g
s
.288 .766 .663 r
.60995 .45804 m .60872 .45854 L .62008 .45371 L p F P
0 g
s
0 0 0 r
.55216 .33668 m .55368 .33529 L .54313 .33974 L p F P
0 g
s
0 0 0 r
.54313 .33974 m .54088 .3419 L .55216 .33668 L p F P
0 g
s
.232 .751 .785 r
.50396 .48861 m .51115 .48706 L .51548 .48616 L p F P
0 g
s
.275 .779 .83 r
.50396 .48861 m .51115 .48706 L .50339 .48864 L closepath p F P
0 g
s
.046 .59 .843 r
.30169 .48951 m .29851 .48855 L .29415 .48801 L closepath p F P
0 g
s
.257 .751 .909 r
.41497 .49718 m .40547 .49738 L .40439 .49717 L p F P
0 g
s
.227 .732 .897 r
.40547 .49738 m .40439 .49717 L .40097 .49738 L closepath p F P
0 g
s
.354 0 0 r
.1903 .45795 m .19029 .45795 L .19028 .45794 L closepath p F P
0 g
s
.24 .738 .906 r
.40115 .49646 m .40439 .49717 L .40097 .49738 L p F P
0 g
s
.24 .738 .906 r
.39018 .49717 m .40115 .49646 L p .40097 .49738 L F P
0 g
s
.24 .738 .906 r
.40097 .49738 m .39096 .49733 L .39018 .49717 L p F P
0 g
s
.342 0 0 r
.18665 .45654 m .18447 .45552 L .19028 .45794 L p F P
0 g
s
.342 0 0 r
.19028 .45794 m .19029 .45795 L .18665 .45654 L p F P
0 g
s
.297 0 0 r
.19722 .46086 m .19029 .45795 L .18665 .45654 L p F P
0 g
s
.146 0 .285 r
.74702 .35562 m .73998 .36154 L .74299 .35539 L p F P
0 g
s
.146 0 .285 r
.74299 .35539 m .74755 .35154 L .74702 .35562 L p F P
0 g
s
.207 .717 .893 r
.39096 .49733 m .39018 .49717 L .38803 .49725 L closepath p F P
0 g
s
.72 .188 0 r
.10732 .41158 m .11205 .41445 L .10854 .41057 L p F P
0 g
s
.72 .188 0 r
.10854 .41057 m .10379 .40771 L .10732 .41158 L p F P
0 g
s
.504 .487 .771 r
.75381 .28437 m .75547 .28264 L .75629 .28488 L closepath p F P
0 g
s
.298 .791 .772 r
.56625 .47327 m .5691 .47274 L .5578 .47627 L p F P
0 g
s
.298 .791 .772 r
.5578 .47627 m .55504 .47679 L .56625 .47327 L p F P
0 g
s
.646 .185 .144 r
.35085 .3722 m .35528 .37513 L .34832 .37424 L closepath p F P
0 g
s
.419 0 0 r
.16931 .44871 m .16697 .44743 L .17252 .44994 L p F P
0 g
s
.419 0 0 r
.17252 .44994 m .17297 .45019 L .16931 .44871 L p F P
0 g
s
.22 .723 .903 r
.38692 .4964 m .39018 .49717 L .38803 .49725 L p F P
0 g
s
.22 .723 .903 r
.37599 .49688 m .38692 .4964 L p .38803 .49725 L F P
0 g
s
.22 .723 .903 r
.38803 .49725 m .37604 .49689 L .37599 .49688 L p F P
0 g
s
.37 0 .061 r
.48923 .36464 m .48996 .36356 L .47879 .36512 L p F P
0 g
s
.37 0 .061 r
.47879 .36512 m .47721 .36733 L .48923 .36464 L p F P
0 g
s
.93 .601 .394 r
.05476 .35324 m .0544 .35018 L .05053 .3482 L p F P
0 g
s
.675 .189 .087 r
.31938 .36444 m .32322 .36741 L .31635 .3659 L closepath p F P
0 g
s
.244 .746 .898 r
.41962 .49706 m .4186 .49688 L .41497 .49718 L closepath p F P
0 g
s
.257 .751 .909 r
.4154 .49623 m .4186 .49688 L .41497 .49718 L p F P
0 g
s
.257 .751 .909 r
.40439 .49717 m .4154 .49623 L p .41497 .49718 L F P
0 g
s
.67 .74 .902 r
.70743 .26594 m .71896 .26191 L .72166 .2655 L p F P
0 g
s
.684 .764 .912 r
.71896 .26191 m .70743 .26594 L .70474 .26303 L p F P
0 g
s
.933 .691 .549 r
.03894 .32544 m .04272 .32879 L .04349 .32363 L p F P
0 g
s
.933 .691 .549 r
.04349 .32363 m .03972 .32028 L .03894 .32544 L p F P
0 g
s
.272 .763 .909 r
.43037 .49656 m .41962 .49706 L .4186 .49688 L p F P
0 g
s
.172 0 .347 r
.75047 .34893 m .74755 .35154 L .74787 .34721 L p F P
0 g
s
.172 0 .347 r
.74787 .34721 m .75248 .34307 L .75047 .34893 L p F P
0 g
s
.864 .424 .149 r
.07714 .38319 m .07734 .38361 L .08176 .38663 L p F P
0 g
s
.834 .363 .058 r
.0798 .38779 m .08421 .3908 L .08176 .38663 L p F P
0 g
s
.834 .363 .058 r
.08176 .38663 m .07734 .38361 L .0798 .38779 L p F P
0 g
s
0 .461 .757 r
.24594 .47698 m .23895 .47519 L .2354 .474 L p F P
0 g
s
0 .391 .708 r
.21093 .46593 m .21715 .46821 L .20949 .46547 L p F P
0 g
s
0 .391 .708 r
.20405 .46353 m .21093 .46593 L p .20949 .46547 L F P
0 g
s
0 .391 .708 r
.20949 .46547 m .20523 .46397 L .20405 .46353 L p F P
0 g
s
0 0 0 r
.65944 .43309 m .658 .43392 L .65927 .43326 L closepath p F P
0 g
s
0 0 0 r
.65686 .43515 m .65927 .43326 L .658 .43392 L p F P
0 g
s
0 0 0 r
.65536 .43598 m .65686 .43515 L p .658 .43392 L F P
0 g
s
0 0 0 r
.64672 .44047 m .65536 .43598 L p .658 .43392 L F P
0 g
s
.636 .679 .874 r
.72166 .2655 m .73328 .2625 L .73601 .26691 L p F P
0 g
s
.651 .705 .887 r
.73328 .2625 m .72166 .2655 L .71896 .26191 L p F P
0 g
s
.096 0 .213 r
.73837 .36289 m .73798 .36488 L .73998 .36154 L closepath p F P
0 g
s
.531 0 0 r
.15573 .44145 m .15591 .44157 L .15534 .44131 L closepath p F P
0 g
s
.378 0 0 r
.17872 .45307 m .17297 .45019 L .16931 .44871 L p F P
0 g
s
0 .55 .82 r
.27819 .48466 m .2704 .48333 L .26691 .48224 L p F P
0 g
s
.453 .678 .961 r
.11539 .27037 m .12514 .27043 L .12907 .27376 L p F P
0 g
s
.453 .675 .959 r
.12514 .27043 m .11539 .27037 L .11177 .26697 L p F P
0 g
s
.184 .7 .888 r
.37604 .49689 m .37599 .49688 L .37587 .49689 L closepath p F P
0 g
s
.206 .71 .906 r
.3727 .49605 m .36469 .49622 L .37587 .49689 L p F P
0 g
s
.206 .71 .906 r
.37587 .49689 m .37599 .49688 L .3727 .49605 L p F P
0 g
s
.242 .733 .918 r
.38692 .4964 m .37599 .49688 L .3727 .49605 L p F P
0 g
s
.672 .133 0 r
.27039 .34822 m .27695 .35049 L .27245 .34695 L p F P
0 g
s
.672 .133 0 r
.26723 .34552 m .27039 .34822 L p .27245 .34695 L F P
0 g
s
.672 .133 0 r
.27245 .34695 m .26867 .34555 L .26723 .34552 L p F P
0 g
s
.545 .923 .795 r
.60476 .30748 m .60297 .308 L .61291 .30206 L closepath p F P
0 g
s
.423 0 0 r
.15607 .44229 m .16148 .44487 L .15591 .44157 L p F P
0 g
s
.423 0 0 r
.15203 .43989 m .15607 .44229 L p .15591 .44157 L F P
0 g
s
.423 0 0 r
.15591 .44157 m .15534 .44131 L .15203 .43989 L p F P
0 g
s
0 0 0 r
.66904 .42783 m .67077 .4262 L .65944 .43309 L p F P
0 g
s
0 0 0 r
.65944 .43309 m .65927 .43326 L .66904 .42783 L p F P
0 g
s
0 .383 .783 r
.1947 .30642 m .19052 .30455 L .19538 .30747 L p F P
0 g
s
0 .383 .783 r
.19538 .30747 m .19828 .3087 L .1947 .30642 L p F P
0 g
s
.681 .162 0 r
.28822 .35624 m .29538 .3583 L .29082 .35475 L p F P
0 g
s
.681 .162 0 r
.28457 .35309 m .28822 .35624 L p .29082 .35475 L F P
0 g
s
.681 .162 0 r
.29082 .35475 m .28522 .353 L .28457 .35309 L p F P
0 g
s
.698 .821 .941 r
.69338 .26797 m .69327 .26786 L .69367 .26769 L closepath p F P
0 g
s
.294 .79 .86 r
.50094 .48856 m .48974 .49081 L .48669 .49067 L p F P
0 g
s
.589 .947 .847 r
.62029 .29888 m .61702 .30078 L .61428 .30124 L p F P
0 g
s
0 .537 .815 r
.26376 .48122 m .26691 .48224 L .26021 .48089 L p F P
0 g
s
0 .537 .815 r
.26302 .48103 m .26376 .48122 L p .26021 .48089 L F P
0 g
s
0 .537 .815 r
.2529 .47902 m .26302 .48103 L p .26021 .48089 L F P
0 g
s
0 .537 .815 r
.26021 .48089 m .25295 .47904 L .2529 .47902 L p F P
0 g
s
.658 .185 .117 r
.33652 .37253 m .3457 .3739 L .34064 .37045 L p F P
0 g
s
.658 .185 .117 r
.33333 .37005 m .33652 .37253 L p .34064 .37045 L F P
0 g
s
.658 .185 .117 r
.34064 .37045 m .33434 .3694 L .33333 .37005 L p F P
0 g
s
.645 .087 0 r
.25346 .33989 m .25956 .34233 L .25499 .33885 L p F P
0 g
s
.645 .087 0 r
.24994 .337 m .25346 .33989 L p .25499 .33885 L F P
0 g
s
.645 .087 0 r
.25499 .33885 m .25124 .33724 L .24994 .337 L p F P
0 g
s
0 0 0 r
.67141 .4256 m .67077 .4262 L .67502 .42349 L closepath p F P
0 g
s
.695 .842 .953 r
.69367 .26769 m .69327 .26786 L .69059 .2656 L p F P
0 g
s
.721 .849 .942 r
.67916 .27112 m .69059 .2656 L .69327 .26786 L p F P
0 g
s
.259 .757 .898 r
.43342 .4964 m .43283 .49631 L .43037 .49656 L closepath p F P
0 g
s
.272 .763 .909 r
.42965 .49571 m .43283 .49631 L .43037 .49656 L p F P
0 g
s
.272 .763 .909 r
.4186 .49688 m .42965 .49571 L p .43037 .49656 L F P
0 g
s
.543 .708 .947 r
.09783 .26483 m .10188 .26434 L .10556 .26777 L p F P
0 g
s
.549 .71 .946 r
.10814 .26353 m .10188 .26434 L .10556 .26777 L p F P
0 g
s
.549 .71 .946 r
.10556 .26777 m .11177 .26697 L .10814 .26353 L p F P
0 g
s
.494 0 0 r
.15534 .44131 m .15203 .43989 L .15058 .43896 L closepath p F P
0 g
s
.33 .812 .878 r
.51115 .48706 m .50339 .48864 L .50094 .48856 L p F P
0 g
s
.71 .845 .947 r
.69367 .26769 m .70474 .26303 L .70206 .26037 L p F P
0 g
s
.71 .845 .947 r
.70206 .26037 m .70007 .26127 L .69367 .26769 L p F P
0 g
s
.695 .842 .953 r
.69059 .2656 m .70007 .26127 L .69367 .26769 L p F P
0 g
s
.292 .778 .91 r
.44391 .4949 m .44692 .49542 L .43342 .4964 L p F P
0 g
s
.292 .778 .91 r
.43342 .4964 m .43283 .49631 L .44391 .4949 L p F P
0 g
s
0 0 0 r
.68318 .4175 m .6821 .41873 L .68877 .41404 L closepath p F P
0 g
s
0 0 0 r
.66823 .42845 m .66904 .42783 L .65927 .43326 L p F P
0 g
s
0 0 0 r
.65927 .43326 m .65686 .43515 L .66823 .42845 L p F P
0 g
s
.127 .649 .882 r
.32456 .49212 m .31604 .49152 L .31263 .49058 L p F P
0 g
s
.808 .32 .003 r
.08694 .3949 m .09141 .39789 L .08869 .39379 L p F P
0 g
s
.808 .32 .003 r
.08869 .39379 m .08421 .3908 L .08694 .3949 L p F P
0 g
s
.264 .749 .924 r
.40115 .49646 m .39018 .49717 L .38692 .4964 L p F P
0 g
s
.691 .202 .083 r
.30723 .36387 m .31519 .36566 L .31043 .36215 L p F P
0 g
s
.691 .202 .083 r
.31043 .36215 m .30288 .36024 L .30723 .36387 L p F P
0 g
s
.227 .722 .917 r
.3694 .49517 m .3727 .49605 L .36469 .49622 L p F P
0 g
s
.227 .722 .917 r
.3585 .49542 m .3694 .49517 L p .36469 .49622 L F P
0 g
s
.227 .722 .917 r
.36469 .49622 m .3606 .49597 L .3585 .49542 L p F P
0 g
s
.296 .789 .878 r
.48562 .49059 m .48669 .49067 L .47552 .49265 L p F P
0 g
s
.296 .789 .878 r
.47552 .49265 m .47299 .4925 L .48562 .49059 L p F P
0 g
s
.253 .762 .856 r
.47299 .4925 m .47552 .49265 L p .46129 .4942 L F P
0 g
s
.594 .021 0 r
.2327 .32782 m .23273 .32785 L .23821 .33051 L p F P
0 g
s
.603 .033 0 r
.23725 .33132 m .24298 .3339 L .23821 .33051 L p F P
0 g
s
.603 .033 0 r
.23821 .33051 m .23273 .32785 L .23725 .33132 L p F P
0 g
s
0 0 0 r
.56393 .33045 m .5663 .32845 L .55503 .33407 L p F P
0 g
s
0 0 0 r
.55503 .33407 m .55368 .33529 L .56393 .33045 L p F P
0 g
s
.441 0 .093 r
.46485 .3696 m .46454 .37 L .46243 .36996 L closepath p F P
0 g
s
.439 0 .097 r
.46279 .37261 m .46454 .37 L .46243 .36996 L p F P
0 g
s
.439 0 .097 r
.45189 .37419 m .46279 .37261 L p .46243 .36996 L F P
0 g
s
.439 0 .097 r
.45027 .37411 m .45189 .37419 L p .46243 .36996 L F P
0 g
s
0 .42 .724 r
.23183 .47276 m .22366 .47038 L .23029 .47251 L p F P
0 g
s
0 .42 .724 r
.23029 .47251 m .2354 .474 L .23183 .47276 L p F P
0 g
s
0 .377 .677 r
.22149 .46969 m .22366 .47038 L .23029 .47251 L p F P
0 g
s
.473 .451 .753 r
.75629 .28488 m .76214 .28686 L .75838 .29104 L closepath p F P
0 g
s
.417 .392 .724 r
.7682 .2901 m .76214 .28686 L .75838 .29104 L p F P
0 g
s
.417 .392 .724 r
.76264 .29612 m .7682 .2901 L p .75838 .29104 L F P
0 g
s
.417 .392 .724 r
.75838 .29104 m .75931 .2941 L .76264 .29612 L p F P
0 g
s
.676 .129 0 r
.11411 .41647 m .11205 .41445 L .11686 .41727 L p F P
0 g
s
.676 .129 0 r
.11686 .41727 m .11786 .41825 L .11411 .41647 L p F P
0 g
s
.323 .807 .777 r
.58043 .46892 m .58137 .46873 L .57037 .47249 L p F P
0 g
s
.323 .807 .777 r
.57037 .47249 m .5691 .47274 L .58043 .46892 L p F P
0 g
s
.636 .964 .89 r
.62834 .29423 m .62029 .29888 L .62677 .2943 L closepath p F P
0 g
s
.589 .947 .847 r
.62561 .29436 m .62677 .2943 L .62029 .29888 L p F P
0 g
s
.589 .947 .847 r
.61428 .30124 m .62561 .29436 L p .62029 .29888 L F P
0 g
s
0 0 0 r
.63413 .44703 m .63045 .44879 L .63378 .44726 L closepath p F P
0 g
s
0 0 0 r
.63145 .44844 m .63378 .44726 L .63045 .44879 L p F P
0 g
s
0 0 0 r
.62347 .45217 m .63145 .44844 L p .63045 .44879 L F P
0 g
s
0 0 0 r
.6204 .45357 m .62347 .45217 L p .63045 .44879 L F P
0 g
s
.067 0 0 r
.52992 .34621 m .52962 .3465 L .53659 .34364 L closepath p F P
0 g
s
.434 .389 .709 r
.75931 .2941 m .76264 .29612 L .76051 .29842 L closepath p F P
0 g
s
.311 .803 .827 r
.54068 .48028 m .54361 .48006 L .54281 .48028 L p F P
0 g
s
.311 .803 .827 r
.5294 .48326 m .54068 .48028 L p .54281 .48028 L F P
0 g
s
.292 .79 .806 r
.54364 .48006 m .54361 .48006 L .54281 .48028 L closepath p F P
0 g
s
.047 .498 .888 r
.17749 .29658 m .17503 .29574 L .17967 .29876 L p F P
0 g
s
.047 .498 .888 r
.17967 .29876 m .18107 .29922 L .17749 .29658 L p F P
0 g
s
.576 .141 .179 r
.40954 .37757 m .40746 .38022 L .40097 .37765 L closepath p F P
0 g
s
.575 .134 .164 r
.40726 .3805 m .40746 .38022 L .40097 .37765 L p F P
0 g
s
.575 .134 .164 r
.39459 .38053 m .40726 .3805 L p .40097 .37765 L F P
0 g
s
.575 .134 .164 r
.39323 .3799 m .39459 .38053 L p .40097 .37765 L F P
0 g
s
.575 .134 .164 r
.40097 .37765 m .39514 .37765 L .39323 .3799 L p F P
0 g
s
.597 .158 .179 r
.39514 .37765 m .39323 .3799 L .38814 .37748 L closepath p F P
0 g
s
.188 .696 .901 r
.3606 .49597 m .3585 .49542 L .354 .4954 L closepath p F P
0 g
s
.599 .03 0 r
.13487 .4299 m .13521 .43016 L .14042 .43283 L p F P
0 g
s
.53 0 0 r
.14018 .43363 m .14535 .43631 L .14042 .43283 L p F P
0 g
s
.53 0 0 r
.14042 .43283 m .13521 .43016 L .14018 .43363 L p F P
0 g
s
.549 .112 .162 r
.41527 .37735 m .40954 .37757 L .40746 .38022 L p F P
0 g
s
.461 .461 .772 r
.75547 .28264 m .75629 .28488 L .76214 .28686 L p F P
0 g
s
.598 .644 .867 r
.73601 .26691 m .7363 .26687 L .73612 .26709 L closepath p F P
0 g
s
.567 .621 .866 r
.74776 .26544 m .7363 .26687 L .73612 .26709 L p F P
0 g
s
.567 .621 .866 r
.75055 .27105 m .74776 .26544 L p .73612 .26709 L F P
0 g
s
.279 .761 .924 r
.4154 .49623 m .40439 .49717 L .40115 .49646 L p F P
0 g
s
.31 0 .002 r
.50118 .3612 m .50302 .35872 L .49134 .36177 L p F P
0 g
s
.31 0 .002 r
.49134 .36177 m .48996 .36356 L .50118 .3612 L p F P
0 g
s
.003 .561 .812 r
.28443 .48618 m .28599 .4864 L .29415 .48801 L p F P
0 g
s
.055 .595 .851 r
.29507 .48747 m .28599 .4864 L .29415 .48801 L p F P
0 g
s
.055 .595 .851 r
.29415 .48801 m .29851 .48855 L .29507 .48747 L p F P
0 g
s
.712 .953 .952 r
.65371 .28172 m .65173 .28282 L .65325 .28158 L closepath p F P
0 g
s
.691 .963 .941 r
.65102 .28095 m .65325 .28158 L .65173 .28282 L p F P
0 g
s
.691 .963 .941 r
.63989 .28743 m .65102 .28095 L p .65173 .28282 L F P
0 g
s
.691 .963 .941 r
.63972 .28757 m .63989 .28743 L p .65173 .28282 L F P
0 g
s
.47 .878 .734 r
.59196 .31437 m .59168 .31448 L .59344 .31346 L closepath p F P
0 g
s
.409 0 .074 r
.47569 .3695 m .47721 .36733 L .46485 .3696 L p F P
0 g
s
.409 0 .074 r
.46485 .3696 m .46454 .37 L .47569 .3695 L p F P
0 g
s
.599 .152 .162 r
.39276 .38051 m .39323 .3799 L .38814 .37748 L p F P
0 g
s
.599 .152 .162 r
.38228 .38018 m .39276 .38051 L p .38814 .37748 L F P
0 g
s
.599 .152 .162 r
.37905 .37839 m .38228 .38018 L p .38814 .37748 L F P
0 g
s
.599 .152 .162 r
.38814 .37748 m .38019 .37717 L .37905 .37839 L p F P
0 g
s
.463 .685 .962 r
.13046 .27489 m .12922 .27376 L .12907 .27376 L closepath p F P
0 g
s
.322 .81 .818 r
.5549 .47681 m .55504 .47679 L .54364 .48006 L p F P
0 g
s
.322 .81 .818 r
.54364 .48006 m .54361 .48006 L .5549 .47681 L p F P
0 g
s
.612 .668 .88 r
.7363 .26687 m .73601 .26691 L .73328 .2625 L p F P
0 g
s
.253 .762 .856 r
.46129 .4942 m .46878 .49304 L .47299 .4925 L p F P
0 g
s
.283 .779 .884 r
.46129 .4942 m .46878 .49304 L .46007 .49409 L closepath p F P
0 g
s
.247 .756 .865 r
.46007 .49409 m .46129 .4942 L p .44705 .49544 L F P
0 g
s
.296 .784 .724 r
.59219 .46473 m .5946 .46404 L .58326 .46819 L p F P
0 g
s
.296 .784 .724 r
.58326 .46819 m .58137 .46873 L .59219 .46473 L p F P
0 g
s
.245 .093 .468 r
.76028 .33126 m .7564 .335 L .75623 .33009 L p F P
0 g
s
.245 .093 .468 r
.75623 .33009 m .76048 .32598 L .76028 .33126 L p F P
0 g
s
.343 .822 .838 r
.5549 .47681 m .54361 .48006 L .54068 .48028 L p F P
0 g
s
0 0 0 r
.69459 .40898 m .69341 .41058 L .70022 .40528 L closepath p F P
0 g
s
.612 .668 .88 r
.73328 .2625 m .74108 .26101 L .7363 .26687 L p F P
0 g
s
.59 .625 .855 r
.745 .26033 m .74108 .26101 L .7363 .26687 L p F P
0 g
s
.59 .625 .855 r
.7363 .26687 m .74776 .26544 L .745 .26033 L p F P
0 g
s
.551 .119 .173 r
.42347 .377 m .42172 .37936 L .41527 .37735 L closepath p F P
0 g
s
.549 .112 .162 r
.42128 .37999 m .42172 .37936 L .41527 .37735 L p F P
0 g
s
.549 .112 .162 r
.40815 .38047 m .42128 .37999 L p .41527 .37735 L F P
0 g
s
.549 .112 .162 r
.40746 .38022 m .40815 .38047 L p .41527 .37735 L F P
0 g
s
.51 .509 .791 r
.75339 .27746 m .75917 .27838 L .75547 .28264 L closepath p F P
0 g
s
.461 .461 .772 r
.76546 .2801 m .75917 .27838 L .75547 .28264 L p F P
0 g
s
.461 .461 .772 r
.76622 .28236 m .76546 .2801 L p .75547 .28264 L F P
0 g
s
.461 .461 .772 r
.76214 .28686 m .76622 .28236 L p .75547 .28264 L F P
0 g
s
.399 .338 .673 r
.76687 .29995 m .7621 .30509 L .76051 .29842 L p F P
0 g
s
.399 .338 .673 r
.76051 .29842 m .76264 .29612 L .76687 .29995 L p F P
0 g
s
0 0 0 r
.64672 .44047 m .64549 .44126 L .65536 .43598 L closepath p F P
0 g
s
.092 0 .21 r
.74685 .35649 m .74702 .35562 L .73998 .36154 L p F P
0 g
s
.092 0 .21 r
.74387 .36146 m .74685 .35649 L p .73998 .36154 L F P
0 g
s
.092 0 .21 r
.73762 .36673 m .74387 .36146 L p .73998 .36154 L F P
0 g
s
.092 0 .21 r
.73998 .36154 m .73798 .36488 L .73762 .36673 L p F P
0 g
s
.266 0 0 r
.51442 .3553 m .51542 .35394 L .5042 .35715 L p F P
0 g
s
.266 0 0 r
.5042 .35715 m .50302 .35872 L .51442 .3553 L p F P
0 g
s
.005 0 .06 r
.72784 .37731 m .72704 .37969 L .73106 .37478 L closepath p F P
0 g
s
.292 .772 .922 r
.42965 .49571 m .4186 .49688 L .4154 .49623 L p F P
0 g
s
.654 .18 .114 r
.33434 .3694 m .33333 .37005 L .33179 .36898 L closepath p F P
0 g
s
.273 .77 .889 r
.44705 .49544 m .44778 .49534 L .44692 .49542 L closepath p F P
0 g
s
.247 .756 .865 r
.44705 .49544 m .44778 .49534 L .46007 .49409 L p F P
0 g
s
.503 0 0 r
.22164 .32253 m .22707 .32523 L .22196 .32199 L p F P
0 g
s
.503 0 0 r
.22196 .32199 m .21677 .31921 L .22164 .32253 L p F P
0 g
s
.504 0 0 r
.21548 .31832 m .21677 .31921 L .22196 .32199 L p F P
0 g
s
.309 .784 .924 r
.44391 .4949 m .43283 .49631 L .42965 .49571 L p F P
0 g
s
.614 .171 .173 r
.38019 .37717 m .37905 .37839 L .3764 .37696 L closepath p F P
0 g
s
.773 .265 0 r
.09354 .4007 m .09141 .39789 L .09595 .40084 L p F P
0 g
s
.773 .265 0 r
.09595 .40084 m .09732 .40263 L .09354 .4007 L p F P
0 g
s
.266 0 0 r
.20523 .46397 m .20405 .46353 L .20323 .46321 L closepath p F P
0 g
s
.724 .955 .948 r
.66239 .27436 m .66508 .2755 L .65371 .28172 L p F P
0 g
s
.724 .955 .948 r
.65976 .27588 m .66239 .27436 L p .65371 .28172 L F P
0 g
s
.724 .955 .948 r
.65371 .28172 m .65325 .28158 L .65976 .27588 L p F P
0 g
s
.625 .068 0 r
.26867 .34555 m .26723 .34552 L .26599 .34465 L closepath p F P
0 g
s
.126 0 0 r
.53659 .34364 m .52962 .3465 L .52767 .34879 L p F P
0 g
s
0 .383 .687 r
.22149 .46969 m .22366 .47038 L .2189 .46883 L closepath p F P
0 g
s
.327 .797 .925 r
.44778 .49534 m .44692 .49542 L .44391 .4949 L p F P
0 g
s
.209 .584 .944 r
.16398 .29019 m .16385 .29009 L .16381 .29008 L closepath p F P
0 g
s
.381 .296 .634 r
.76122 .30597 m .7621 .30509 L .76262 .3078 L closepath p F P
0 g
s
.202 .704 .91 r
.35517 .49448 m .3585 .49542 L .354 .4954 L p F P
0 g
s
.202 .704 .91 r
.34432 .4945 m .35517 .49448 L p .354 .4954 L F P
0 g
s
.202 .704 .91 r
.354 .4954 m .34468 .4946 L .34432 .4945 L p F P
0 g
s
.52 .084 .153 r
.43172 .37636 m .42347 .377 L .42172 .37936 L p F P
0 g
s
.219 .039 .411 r
.75632 .3396 m .75248 .34307 L .75365 .3375 L p F P
0 g
s
.219 .039 .411 r
.75365 .3375 m .7564 .335 L .75632 .3396 L p F P
0 g
s
0 0 0 r
.64388 .44229 m .64549 .44126 L .63413 .44703 L p F P
0 g
s
0 0 0 r
.63413 .44703 m .63378 .44726 L .64388 .44229 L p F P
0 g
s
.614 .178 .189 r
.37094 .37951 m .36556 .37614 L .3764 .37696 L p F P
0 g
s
.614 .178 .189 r
.3777 .37995 m .37094 .37951 L p .3764 .37696 L F P
0 g
s
.614 .178 .189 r
.3764 .37696 m .37905 .37839 L .3777 .37995 L p F P
0 g
s
.327 .797 .925 r
.45504 .49327 m .45817 .49381 L .44778 .49534 L p F P
0 g
s
.327 .797 .925 r
.44391 .4949 m .45504 .49327 L p .44778 .49534 L F P
0 g
s
.313 .791 .913 r
.46007 .49409 m .45817 .49381 L .44778 .49534 L closepath p F P
0 g
s
.397 .824 .659 r
.59344 .31346 m .59168 .31448 L .58898 .31585 L p F P
0 g
s
.685 .183 .042 r
.30195 .35948 m .30288 .36024 L .30108 .35974 L closepath p F P
0 g
s
.93 .601 .394 r
.05053 .3482 m .05074 .35002 L .05476 .35324 L p F P
0 g
s
.924 .564 .326 r
.05169 .35464 m .05571 .35786 L .05476 .35324 L p F P
0 g
s
.924 .564 .326 r
.05476 .35324 m .05074 .35002 L .05169 .35464 L p F P
0 g
s
.217 .584 .945 r
.16026 .28716 m .1594 .28696 L .16381 .29008 L p F P
0 g
s
.217 .584 .945 r
.16381 .29008 m .16385 .29009 L .16026 .28716 L p F P
0 g
s
.731 .868 .945 r
.69059 .2656 m .67916 .27112 L .67648 .2694 L p F P
0 g
s
0 .446 .861 r
.17054 .29266 m .16385 .29009 L .16026 .28716 L p F P
0 g
s
.654 .183 .121 r
.32785 .37098 m .32322 .36741 L .33179 .36898 L p F P
0 g
s
.654 .183 .121 r
.33113 .37155 m .32785 .37098 L p .33179 .36898 L F P
0 g
s
.654 .183 .121 r
.33179 .36898 m .33333 .37005 L .33113 .37155 L p F P
0 g
s
.934 .61 .398 r
.0467 .34585 m .04632 .342 L .05024 .34527 L p F P
0 g
s
.934 .61 .398 r
.05024 .34527 m .05053 .3482 L .0467 .34585 L p F P
0 g
s
.911 .525 .268 r
.05701 .36237 m .06109 .36555 L .0598 .36104 L p F P
0 g
s
.911 .525 .268 r
.0598 .36104 m .05571 .35786 L .05701 .36237 L p F P
0 g
s
.322 .8 .729 r
.60596 .45958 m .60655 .4594 L .59592 .46364 L p F P
0 g
s
.322 .8 .729 r
.59592 .46364 m .5946 .46404 L .60596 .45958 L p F P
0 g
s
.176 .543 .927 r
.1471 .28169 m .14657 .28155 L .14297 .27838 L p F P
0 g
s
.427 0 .116 r
.47517 .37032 m .47569 .3695 L .46454 .37 L p F P
0 g
s
.427 0 .116 r
.46454 .37 m .46279 .37261 L .47517 .37032 L p F P
0 g
s
.133 .659 .877 r
.33017 .49317 m .33399 .49333 L .34363 .49448 L p F P
0 g
s
.132 .658 .876 r
.33017 .49317 m .33399 .49333 L .32811 .49264 L closepath p F P
0 g
s
.651 .097 0 r
.12088 .42101 m .11786 .41825 L .11411 .41647 L p F P
0 g
s
.295 .772 .67 r
.61734 .45477 m .62008 .45371 L .60872 .45854 L p F P
0 g
s
.295 .772 .67 r
.61325 .45653 m .61734 .45477 L p .60872 .45854 L F P
0 g
s
.295 .772 .67 r
.60872 .45854 m .60655 .4594 L .61325 .45653 L p F P
0 g
s
.011 .565 .819 r
.28443 .48618 m .28599 .4864 L .28327 .48584 L closepath p F P
0 g
s
.573 0 0 r
.25124 .33724 m .24994 .337 L .24899 .33638 L closepath p F P
0 g
s
0 0 0 r
.67502 .42349 m .67077 .4262 L .66904 .42783 L p F P
0 g
s
.65 .118 0 r
.28522 .353 m .28457 .35309 L .28391 .35262 L closepath p F P
0 g
s
.629 .178 .162 r
.36492 .37575 m .36556 .37614 L .36461 .37605 L closepath p F P
0 g
s
0 0 0 r
.58889 .3159 m .58898 .31585 L .57925 .32138 L p F P
0 g
s
0 0 0 r
.57925 .32138 m .57759 .3224 L .58889 .3159 L p F P
0 g
s
0 .326 .744 r
.18107 .29922 m .18581 .30157 L .19052 .30455 L p F P
0 g
s
0 .317 .744 r
.18581 .30157 m .18107 .29922 L .17749 .29658 L p F P
0 g
s
.459 .872 .727 r
.60297 .308 m .59344 .31346 L .60152 .30858 L closepath p F P
0 g
s
.397 .824 .659 r
.60021 .30911 m .60152 .30858 L .59344 .31346 L p F P
0 g
s
.397 .824 .659 r
.58946 .31556 m .60021 .30911 L p .59344 .31346 L F P
0 g
s
.397 .824 .659 r
.58898 .31585 m .58946 .31556 L p .59344 .31346 L F P
0 g
s
.895 .484 .21 r
.06272 .36997 m .06687 .37311 L .06525 .3687 L p F P
0 g
s
.895 .484 .21 r
.06525 .3687 m .06109 .36555 L .06272 .36997 L p F P
0 g
s
.939 .642 .451 r
.04247 .3387 m .04632 .342 L .04623 .33712 L p F P
0 g
s
.939 .642 .451 r
.04623 .33712 m .04239 .33381 L .04247 .3387 L p F P
0 g
s
.336 0 0 r
.18301 .45507 m .17872 .45307 L .18447 .45552 L p F P
0 g
s
.336 0 0 r
.18447 .45552 m .18665 .45654 L .18301 .45507 L p F P
0 g
s
.116 0 .219 r
.73798 .36488 m .73602 .36801 L .73762 .36673 L closepath p F P
0 g
s
.312 .802 .86 r
.51548 .48616 m .51518 .48616 L .51115 .48706 L closepath p F P
0 g
s
.33 .812 .878 r
.51218 .48606 m .51518 .48616 L .51115 .48706 L p F P
0 g
s
.33 .812 .878 r
.50094 .48856 m .51218 .48606 L p .51115 .48706 L F P
0 g
s
.373 0 0 r
.19828 .3087 m .20117 .31043 L .20611 .31332 L p F P
0 g
s
0 .213 .617 r
.20772 .31419 m .20611 .31332 L p .20656 .31355 L F P
0 g
s
.353 0 0 r
.20656 .31355 m .20831 .31455 L .20572 .31309 L p F P
0 g
s
0 .213 .617 r
.20611 .31332 m .20117 .31043 L .20656 .31355 L p F P
0 g
s
.353 0 0 r
.20572 .31309 m .20472 .31253 L p .20656 .31355 L F P
0 g
s
0 .213 .617 r
.20656 .31355 m .21173 .31636 L .20772 .31419 L p F P
0 g
s
.501 .524 .813 r
.75125 .27254 m .75339 .27746 L .75917 .27838 L p F P
0 g
s
.176 .543 .927 r
.14297 .27838 m .1431 .27841 L .1471 .28169 L p F P
0 g
s
.19 .551 .931 r
.15099 .28055 m .15513 .28378 L .1471 .28169 L p F P
0 g
s
.19 .551 .931 r
.1471 .28169 m .1431 .27841 L .15099 .28055 L p F P
0 g
s
.61 .045 0 r
.12523 .42465 m .13017 .42743 L .12584 .42378 L p F P
0 g
s
.61 .045 0 r
.12584 .42378 m .12088 .42101 L .12523 .42465 L p F P
0 g
s
.465 .683 .96 r
.12561 .27043 m .12514 .27043 L .12907 .27376 L p F P
0 g
s
.465 .683 .96 r
.12907 .27376 m .12922 .27376 L .12561 .27043 L p F P
0 g
s
0 .482 .771 r
.25295 .47904 m .2529 .47902 L .25285 .47901 L closepath p F P
0 g
s
0 .492 .787 r
.24937 .47777 m .24594 .47698 L .25285 .47901 L p F P
0 g
s
0 .492 .787 r
.25285 .47901 m .2529 .47902 L .24937 .47777 L p F P
0 g
s
.414 0 0 r
.16563 .44717 m .16148 .44487 L .16697 .44743 L p F P
0 g
s
.414 0 0 r
.16697 .44743 m .16931 .44871 L .16563 .44717 L p F P
0 g
s
.523 .091 .161 r
.43696 .37596 m .43599 .3773 L .43172 .37636 L closepath p F P
0 g
s
.52 .084 .153 r
.43487 .37902 m .43599 .3773 L .43172 .37636 L p F P
0 g
s
.52 .084 .153 r
.42354 .37983 m .43487 .37902 L p .43172 .37636 L F P
0 g
s
.52 .084 .153 r
.42172 .37936 m .42354 .37983 L p .43172 .37636 L F P
0 g
s
0 .331 .662 r
.20044 .46212 m .19722 .46086 L .20323 .46321 L p F P
0 g
s
0 .331 .662 r
.20323 .46321 m .20405 .46353 L .20044 .46212 L p F P
0 g
s
.663 .972 .889 r
.63696 .28739 m .63966 .28756 L .62834 .29423 L p F P
0 g
s
.663 .972 .889 r
.63084 .29114 m .63696 .28739 L p .62834 .29423 L F P
0 g
s
.663 .972 .889 r
.62834 .29423 m .62677 .2943 L .63084 .29114 L p F P
0 g
s
0 .538 .827 r
.26302 .48103 m .2529 .47902 L .24937 .47777 L p F P
0 g
s
.724 .956 .947 r
.65325 .28158 m .65102 .28095 L .65976 .27588 L closepath p F P
0 g
s
0 0 0 r
.70565 .40001 m .70468 .40157 L .70989 .39705 L closepath p F P
0 g
s
.334 .623 .957 r
.1391 .27511 m .12922 .27376 L .12561 .27043 L p F P
0 g
s
.649 .116 0 r
.281 .3536 m .27695 .35049 L .28391 .35262 L p F P
0 g
s
.649 .116 0 r
.28391 .35262 m .28457 .35309 L .281 .3536 L p F P
0 g
s
.291 .161 .526 r
.76446 .32209 m .76048 .32598 L .75973 .32101 L p F P
0 g
s
.291 .161 .526 r
.75973 .32101 m .764 .31684 L .76446 .32209 L p F P
0 g
s
.18 0 0 r
.52668 .34996 m .52767 .34879 L .51658 .35257 L p F P
0 g
s
.18 0 0 r
.51658 .35257 m .51542 .35394 L .52668 .34996 L p F P
0 g
s
.622 .064 0 r
.26365 .34537 m .25956 .34233 L .26599 .34465 L p F P
0 g
s
.622 .064 0 r
.26599 .34465 m .26723 .34552 L .26365 .34537 L p F P
0 g
s
.875 .441 .151 r
.06881 .37744 m .07303 .38055 L .0711 .37622 L p F P
0 g
s
.875 .441 .151 r
.0711 .37622 m .06687 .37311 L .06881 .37744 L p F P
0 g
s
.377 0 0 r
.20117 .31043 m .19828 .3087 L .1947 .30642 L p F P
0 g
s
0 0 0 r
.64284 .44281 m .64388 .44229 L .63378 .44726 L p F P
0 g
s
0 0 0 r
.63378 .44726 m .63145 .44844 L .64284 .44281 L p F P
0 g
s
.32 .808 .834 r
.53897 .48039 m .54068 .48028 L .5294 .48326 L p F P
0 g
s
.32 .808 .834 r
.5294 .48326 m .52733 .4834 L .53897 .48039 L p F P
0 g
s
.939 .67 .501 r
.03861 .33047 m .04239 .33381 L .04272 .32879 L p F P
0 g
s
.939 .67 .501 r
.04272 .32879 m .03894 .32544 L .03861 .33047 L p F P
0 g
s
.33 .261 .627 r
.76979 .30422 m .76687 .29995 L .7621 .30509 L p F P
0 g
s
.33 .261 .627 r
.76416 .31022 m .76979 .30422 L p .7621 .30509 L F P
0 g
s
.33 .261 .627 r
.7621 .30509 m .76262 .3078 L .76416 .31022 L p F P
0 g
s
.159 .675 .891 r
.34468 .4946 m .34432 .4945 L .34363 .49448 L closepath p F P
0 g
s
.635 .191 .178 r
.36196 .37872 m .37094 .37951 L .36556 .37614 L p F P
0 g
s
.635 .191 .178 r
.36556 .37614 m .36461 .37605 L .36196 .37872 L p F P
0 g
s
.757 .24 0 r
.09732 .40263 m .0991 .40482 L .10379 .40771 L p F P
0 g
s
.713 .179 0 r
.10265 .40868 m .10732 .41158 L .10379 .40771 L p F P
0 g
s
.713 .179 0 r
.10379 .40771 m .0991 .40482 L .10265 .40868 L p F P
0 g
s
0 0 0 r
.6821 .41873 m .67502 .42349 L .68103 .41993 L closepath p F P
0 g
s
0 0 0 r
.6796 .42125 m .68103 .41993 L .67502 .42349 L p F P
0 g
s
0 0 0 r
.6735 .4252 m .6796 .42125 L p .67502 .42349 L F P
0 g
s
0 0 0 r
.66904 .42783 m .6735 .4252 L p .67502 .42349 L F P
0 g
s
.865 .424 .139 r
.07714 .38319 m .07734 .38361 L .07567 .38244 L closepath p F P
0 g
s
.644 .202 .185 r
.36045 .37857 m .36196 .37872 L .36461 .37605 L p F P
0 g
s
.644 .202 .185 r
.36461 .37605 m .35528 .37513 L .36045 .37857 L p F P
0 g
s
.694 .199 .064 r
.2998 .36191 m .30723 .36387 L .30288 .36024 L p F P
0 g
s
.694 .199 .064 r
.29839 .36063 m .2998 .36191 L p .30288 .36024 L F P
0 g
s
.694 .199 .064 r
.30288 .36024 m .30108 .35974 L .29839 .36063 L p F P
0 g
s
.179 .684 .906 r
.34097 .49349 m .33399 .49333 L .34363 .49448 L p F P
0 g
s
.179 .684 .906 r
.34363 .49448 m .34432 .4945 L .34097 .49349 L p F P
0 g
s
.502 .069 .148 r
.44803 .37759 m .45003 .37446 L .43696 .37596 L p F P
0 g
s
.502 .069 .148 r
.4419 .37825 m .44803 .37759 L p .43696 .37596 L F P
0 g
s
.502 .069 .148 r
.43696 .37596 m .43599 .3773 L .4419 .37825 L p F P
0 g
s
.052 0 .132 r
.73666 .37033 m .73106 .37478 L .73602 .36801 L p F P
0 g
s
.052 0 .132 r
.73602 .36801 m .73762 .36673 L .73666 .37033 L p F P
0 g
s
.568 0 0 r
.24636 .33624 m .24298 .3339 L .24899 .33638 L p F P
0 g
s
.568 0 0 r
.24899 .33638 m .24994 .337 L .24636 .33624 L p F P
0 g
s
.098 .622 .878 r
.29271 .48669 m .29507 .48747 L .28599 .4864 L p F P
0 g
s
.098 .622 .878 r
.29022 .48614 m .29271 .48669 L p .28599 .4864 L F P
0 g
s
.098 .622 .878 r
.28097 .48507 m .29022 .48614 L p .28599 .4864 L F P
0 g
s
.098 .622 .878 r
.28599 .4864 m .28327 .48584 L .28097 .48507 L p F P
0 g
s
.486 0 0 r
.14833 .43825 m .14535 .43631 L .15058 .43896 L p F P
0 g
s
.486 0 0 r
.15058 .43896 m .15203 .43989 L .14833 .43825 L p F P
0 g
s
0 .377 .703 r
.21093 .46593 m .20405 .46353 L .20044 .46212 L p F P
0 g
s
0 0 0 r
.56647 .32833 m .5663 .32845 L .56773 .32768 L closepath p F P
0 g
s
.822 .342 .018 r
.07546 .38473 m .0798 .38779 L .07734 .38361 L p F P
0 g
s
.822 .342 .018 r
.07334 .38111 m .07546 .38473 L p .07734 .38361 L F P
0 g
s
.822 .342 .018 r
.07734 .38361 m .07567 .38244 L .07334 .38111 L p F P
0 g
s
.482 0 0 r
.21548 .31832 m .21677 .31921 L .21226 .31664 L closepath p F P
0 g
s
.711 .209 .042 r
.28822 .35624 m .28457 .35309 L .281 .3536 L p F P
0 g
s
.229 .714 .929 r
.35517 .49448 m .34432 .4945 L .34097 .49349 L p F P
0 g
s
0 .369 .778 r
.19111 .30404 m .18581 .30157 L .19052 .30455 L p F P
0 g
s
0 .369 .778 r
.19052 .30455 m .1947 .30642 L .19111 .30404 L p F P
0 g
s
.336 .805 .921 r
.46878 .49304 m .46007 .49409 L .45817 .49381 L p F P
0 g
s
0 .467 .776 r
.2314 .4726 m .23183 .47276 L .22366 .47038 L p F P
0 g
s
0 .467 .776 r
.22574 .47066 m .2314 .4726 L p .22366 .47038 L F P
0 g
s
0 .467 .776 r
.2179 .46845 m .22574 .47066 L p .22366 .47038 L F P
0 g
s
0 .467 .776 r
.22366 .47038 m .2189 .46883 L .2179 .46845 L p F P
0 g
s
.341 .82 .87 r
.52644 .4834 m .52733 .4834 L .51548 .48616 L p F P
0 g
s
.341 .82 .87 r
.51548 .48616 m .51518 .48616 L .52644 .4834 L p F P
0 g
s
.674 .171 .041 r
.30108 .35974 m .29839 .36063 L .29538 .3583 L closepath p F P
0 g
s
.674 .209 .14 r
.33333 .37005 m .33652 .37253 L .33113 .37155 L closepath p F P
0 g
s
.329 .811 .784 r
.57758 .46943 m .58043 .46892 L .5691 .47274 L p F P
0 g
s
.329 .811 .784 r
.56703 .473 m .57758 .46943 L p .5691 .47274 L F P
0 g
s
.329 .811 .784 r
.5691 .47274 m .56625 .47327 L .56703 .473 L p F P
0 g
s
.651 .705 .887 r
.71896 .26191 m .73057 .25845 L .73328 .2625 L p F P
0 g
s
.665 .73 .898 r
.73057 .25845 m .71896 .26191 L .71627 .25861 L p F P
0 g
s
.684 .764 .912 r
.70474 .26303 m .71627 .25861 L .71896 .26191 L p F P
0 g
s
.356 .271 .621 r
.76262 .3078 m .76416 .31022 L .76323 .31119 L closepath p F P
0 g
s
.756 .239 0 r
.0991 .40482 m .09732 .40263 L .09354 .4007 L p F P
0 g
s
0 0 0 r
.56773 .32768 m .5663 .32845 L .56393 .33045 L p F P
0 g
s
.683 .204 .107 r
.31949 .36933 m .32785 .37098 L .32322 .36741 L p F P
0 g
s
.683 .204 .107 r
.31584 .36616 m .31949 .36933 L p .32322 .36741 L F P
0 g
s
.683 .204 .107 r
.32322 .36741 m .31635 .3659 L .31584 .36616 L p F P
0 g
s
.453 .675 .959 r
.11177 .26697 m .12134 .26705 L .12514 .27043 L p F P
0 g
s
.455 .672 .957 r
.12134 .26705 m .11177 .26697 L .10814 .26353 L p F P
0 g
s
.696 .786 .92 r
.71627 .25861 m .70474 .26303 L .70206 .26037 L p F P
0 g
s
.582 .009 0 r
.2327 .32782 m .23273 .32785 L .23263 .3278 L closepath p F P
0 g
s
.034 .576 .844 r
.28327 .48584 m .28097 .48507 L .27819 .48466 L closepath p F P
0 g
s
.609 .041 0 r
.23175 .32865 m .23725 .33132 L .23273 .32785 L p F P
0 g
s
.609 .041 0 r
.22912 .32651 m .23175 .32865 L p .23273 .32785 L F P
0 g
s
.609 .041 0 r
.23273 .32785 m .23263 .3278 L .22912 .32651 L p F P
0 g
s
.126 0 0 r
.53848 .34464 m .54072 .34208 L .53659 .34364 L p F P
0 g
s
.126 0 0 r
.52767 .34879 m .53848 .34464 L p .53659 .34364 L F P
0 g
s
.105 0 0 r
.54088 .3419 m .53659 .34364 L .54072 .34208 L closepath p F P
0 g
s
0 0 0 r
.68877 .41404 m .6821 .41873 L .68103 .41993 L p F P
0 g
s
.501 .524 .813 r
.76252 .27205 m .75245 .2711 L .75125 .27254 L p F P
0 g
s
.501 .524 .813 r
.76321 .27383 m .76252 .27205 L p .75125 .27254 L F P
0 g
s
.501 .524 .813 r
.75917 .27838 m .76321 .27383 L p .75125 .27254 L F P
0 g
s
.543 .562 .824 r
.75055 .27105 m .75245 .2711 L .75125 .27254 L closepath p F P
0 g
s
.117 0 .276 r
.74768 .35503 m .74702 .35562 L .74755 .35154 L p F P
0 g
s
.117 0 .276 r
.74755 .35154 m .75047 .34893 L .74768 .35503 L p F P
0 g
s
.38 0 .072 r
.48723 .36765 m .48923 .36464 L .47721 .36733 L p F P
0 g
s
.38 0 .072 r
.48258 .36866 m .48723 .36765 L p .47721 .36733 L F P
0 g
s
.38 0 .072 r
.47721 .36733 m .47569 .3695 L .48258 .36866 L p F P
0 g
s
.5 0 0 r
.23263 .3278 m .22912 .32651 L .22707 .32523 L closepath p F P
0 g
s
.591 .021 0 r
.13487 .4299 m .13521 .43016 L .13395 .4295 L closepath p F P
0 g
s
.652 .197 .16 r
.35049 .37745 m .36045 .37857 L .35528 .37513 L p F P
0 g
s
.652 .197 .16 r
.34736 .37506 m .35049 .37745 L p .35528 .37513 L F P
0 g
s
.652 .197 .16 r
.35528 .37513 m .34832 .37424 L .34736 .37506 L p F P
0 g
s
.411 .355 .685 r
.77002 .29656 m .76687 .29995 L .76264 .29612 L p F P
0 g
s
.411 .355 .685 r
.76856 .29039 m .77002 .29656 L p .76264 .29612 L F P
0 g
s
.411 .355 .685 r
.76264 .29612 m .7682 .2901 L .76856 .29039 L p F P
0 g
s
.703 .179 0 r
.27039 .34822 m .26723 .34552 L .26365 .34537 L p F P
0 g
s
.359 .829 .886 r
.52644 .4834 m .51518 .48616 L .51218 .48606 L p F P
0 g
s
.121 .639 .888 r
.30683 .48931 m .29851 .48855 L .29507 .48747 L p F P
0 g
s
0 0 0 r
.57759 .3224 m .56773 .32768 L .57651 .3232 L closepath p F P
0 g
s
0 0 0 r
.57477 .32451 m .57651 .3232 L .56773 .32768 L p F P
0 g
s
0 0 0 r
.56744 .3286 m .57477 .32451 L p .56773 .32768 L F P
0 g
s
0 0 0 r
.56393 .33045 m .56744 .3286 L p .56773 .32768 L F P
0 g
s
.464 .036 .14 r
.45027 .37411 m .45189 .37419 L .45003 .37446 L closepath p F P
0 g
s
.678 .132 0 r
.25346 .33989 m .24994 .337 L .24636 .33624 L p F P
0 g
s
.805 .315 0 r
.08253 .39188 m .08694 .3949 L .08421 .3908 L p F P
0 g
s
.805 .315 0 r
.08421 .3908 m .0798 .38779 L .08253 .39188 L p F P
0 g
s
.72 .933 .959 r
.67507 .27015 m .66508 .2755 L .66239 .27436 L p F P
0 g
s
.675 .128 0 r
.11035 .4146 m .10732 .41158 L .11205 .41445 L p F P
0 g
s
.675 .128 0 r
.11205 .41445 m .11411 .41647 L .11035 .4146 L p F P
0 g
s
.933 .605 .39 r
.05074 .35002 m .05053 .3482 L .0467 .34585 L p F P
0 g
s
.484 .885 .734 r
.61291 .30206 m .60297 .308 L .60152 .30858 L p F P
0 g
s
.287 0 0 r
.19127 .45849 m .18665 .45654 L .18301 .45507 L p F P
0 g
s
.297 0 0 r
.18665 .45654 m .19127 .45849 L .19722 .46086 L p F P
0 g
s
.485 0 0 r
.13509 .43091 m .14018 .43363 L .13521 .43016 L p F P
0 g
s
.485 0 0 r
.13114 .42816 m .13509 .43091 L p .13521 .43016 L F P
0 g
s
.485 0 0 r
.13521 .43016 m .13395 .4295 L .13114 .42816 L p F P
0 g
s
.616 .18 .19 r
.37905 .37839 m .38228 .38018 L .3777 .37995 L closepath p F P
0 g
s
.203 .698 .919 r
.3376 .49243 m .34097 .49349 L .33399 .49333 L p F P
0 g
s
.203 .698 .919 r
.32678 .49223 m .3376 .49243 L p .33399 .49333 L F P
0 g
s
.203 .698 .919 r
.33399 .49333 m .32811 .49264 L .32678 .49223 L p F P
0 g
s
.257 .733 .937 r
.3694 .49517 m .3585 .49542 L .35517 .49448 L p F P
0 g
s
0 0 0 r
.56346 .33085 m .56393 .33045 L .55368 .33529 L p F P
0 g
s
0 0 0 r
.55368 .33529 m .55216 .33668 L .56346 .33085 L p F P
0 g
s
0 0 0 r
.71635 .3906 m .71591 .39146 L .71818 .38925 L closepath p F P
0 g
s
.558 .584 .836 r
.75245 .2711 m .75055 .27105 L .74776 .26544 L p F P
0 g
s
.001 0 .057 r
.73594 .3724 m .73666 .37033 L .73106 .37478 L p F P
0 g
s
.001 0 .057 r
.73375 .3751 m .73594 .3724 L p .73106 .37478 L F P
0 g
s
.001 0 .057 r
.72669 .38071 m .73375 .3751 L p .73106 .37478 L F P
0 g
s
.001 0 .057 r
.73106 .37478 m .72704 .37969 L .72669 .38071 L p F P
0 g
s
.04 .487 .884 r
.1739 .29386 m .17054 .29266 L .17503 .29574 L p F P
0 g
s
.04 .487 .884 r
.17503 .29574 m .17749 .29658 L .1739 .29386 L p F P
0 g
s
.628 .669 .87 r
.74108 .26101 m .73328 .2625 L .73057 .25845 L p F P
0 g
s
.165 0 .343 r
.75601 .34392 m .75047 .34893 L .75248 .34307 L p F P
0 g
s
.165 0 .343 r
.75248 .34307 m .75632 .3396 L .75601 .34392 L p F P
0 g
s
.02 0 .12 r
.73926 .36814 m .73666 .37033 L .73762 .36673 L p F P
0 g
s
.02 0 .12 r
.73762 .36673 m .74387 .36146 L .73926 .36814 L p F P
0 g
s
0 0 0 r
.65536 .43598 m .64549 .44126 L .64388 .44229 L p F P
0 g
s
.322 .789 .678 r
.6204 .45357 m .62008 .45371 L .62347 .45217 L closepath p F P
0 g
s
.845 .383 .072 r
.07567 .38244 m .07334 .38111 L .07303 .38055 L closepath p F P
0 g
s
0 0 0 r
.69341 .41058 m .68877 .41404 L .69265 .41159 L closepath p F P
0 g
s
0 0 0 r
.69095 .41347 m .69265 .41159 L .68877 .41404 L p F P
0 g
s
0 0 0 r
.68818 .41545 m .69095 .41347 L p .68877 .41404 L F P
0 g
s
0 0 0 r
.68103 .41993 m .68818 .41545 L p .68877 .41404 L F P
0 g
s
.517 0 0 r
.21642 .31975 m .22164 .32253 L .21677 .31921 L p F P
0 g
s
.517 0 0 r
.2119 .31646 m .21642 .31975 L p .21677 .31921 L F P
0 g
s
.517 0 0 r
.21677 .31921 m .21226 .31664 L .2119 .31646 L p F P
0 g
s
.271 0 0 r
.51244 .35801 m .51442 .3553 L .50302 .35872 L p F P
0 g
s
.271 0 0 r
.50302 .35872 m .50118 .3612 L .51244 .35801 L p F P
0 g
s
.192 .019 .404 r
.75921 .33681 m .75632 .3396 L .7564 .335 L p F P
0 g
s
.192 .019 .404 r
.7564 .335 m .76028 .33126 L .75921 .33681 L p F P
0 g
s
.446 0 0 r
.15607 .44229 m .15203 .43989 L .14833 .43825 L p F P
0 g
s
.321 .799 .908 r
.47299 .4925 m .47243 .49243 L .46878 .49304 L closepath p F P
0 g
s
.336 .805 .921 r
.46933 .49194 m .47243 .49243 L .46878 .49304 L p F P
0 g
s
.336 .805 .921 r
.45817 .49381 m .46933 .49194 L p .46878 .49304 L F P
0 g
s
.705 .967 .936 r
.63972 .28757 m .63966 .28756 L .63989 .28743 L closepath p F P
0 g
s
.473 .051 .158 r
.45189 .37419 m .45003 .37446 L .44803 .37759 L p F P
0 g
s
.378 0 0 r
.16931 .44871 m .17304 .45059 L .17872 .45307 L p F P
0 g
s
.37 0 0 r
.17304 .45059 m .16931 .44871 L .16563 .44717 L p F P
0 g
s
0 .461 .757 r
.2354 .474 m .23906 .47493 L .24594 .47698 L p F P
0 g
s
0 .47 .767 r
.23906 .47493 m .2354 .474 L .23183 .47276 L p F P
0 g
s
.315 .212 .575 r
.76587 .31488 m .764 .31684 L .76323 .31119 L p F P
0 g
s
.315 .212 .575 r
.76323 .31119 m .76416 .31022 L .76587 .31488 L p F P
0 g
s
.677 .97 .918 r
.63989 .28743 m .63966 .28756 L .63696 .28739 L p F P
0 g
s
.712 .964 .94 r
.65102 .28095 m .63989 .28743 L .64834 .28038 L closepath p F P
0 g
s
.677 .97 .918 r
.64832 .28038 m .64834 .28038 L .63989 .28743 L p F P
0 g
s
.677 .97 .918 r
.63696 .28739 m .64832 .28038 L p .63989 .28743 L F P
0 g
s
.338 0 .055 r
.50093 .36157 m .50118 .3612 L .48996 .36356 L p F P
0 g
s
.338 0 .055 r
.48996 .36356 m .48923 .36464 L .50093 .36157 L p F P
0 g
s
.707 .863 .956 r
.70007 .26127 m .69059 .2656 L .68791 .26355 L p F P
0 g
s
.731 .868 .945 r
.67648 .2694 m .68791 .26355 L .69059 .2656 L p F P
0 g
s
.329 .805 .736 r
.60318 .46036 m .60596 .45958 L .5946 .46404 L p F P
0 g
s
.329 .805 .736 r
.59796 .46242 m .60318 .46036 L p .5946 .46404 L F P
0 g
s
.329 .805 .736 r
.5946 .46404 m .59219 .46473 L .59796 .46242 L p F P
0 g
s
.341 .817 .885 r
.51016 .48595 m .51218 .48606 L .50094 .48856 L p F P
0 g
s
.341 .817 .885 r
.50094 .48856 m .49803 .48844 L .51016 .48595 L p F P
0 g
s
.294 .79 .86 r
.49803 .48844 m .50094 .48856 L p .48669 .49067 L F P
0 g
s
0 .55 .82 r
.26691 .48224 m .27058 .48285 L .27819 .48466 L p F P
0 g
s
0 .551 .822 r
.26691 .48224 m .27058 .48285 L .26376 .48122 L closepath p F P
0 g
s
.654 .2 .162 r
.34832 .37424 m .34736 .37506 L .3457 .3739 L closepath p F P
0 g
s
0 .498 .796 r
.24584 .47647 m .23906 .47493 L .24594 .47698 L p F P
0 g
s
0 .498 .796 r
.24594 .47698 m .24937 .47777 L .24584 .47647 L p F P
0 g
s
.666 .138 0 r
.27466 .35184 m .27039 .34822 L .27695 .35049 L p F P
0 g
s
.666 .138 0 r
.28042 .35367 m .27466 .35184 L p .27695 .35049 L F P
0 g
s
.666 .138 0 r
.27695 .35049 m .281 .3536 L .28042 .35367 L p F P
0 g
s
.471 .044 .147 r
.46279 .37261 m .46138 .37477 L .45189 .37419 L closepath p F P
0 g
s
.473 .051 .158 r
.46081 .37573 m .46138 .37477 L .45189 .37419 L p F P
0 g
s
.473 .051 .158 r
.44803 .37759 m .46081 .37573 L p .45189 .37419 L F P
0 g
s
.773 .265 0 r
.08975 .39866 m .08694 .3949 L .09141 .39789 L p F P
0 g
s
.773 .265 0 r
.09141 .39789 m .09354 .4007 L .08975 .39866 L p F P
0 g
s
.553 0 0 r
.13395 .4295 m .13114 .42816 L .13017 .42743 L closepath p F P
0 g
s
.027 0 .067 r
.72704 .37969 m .7252 .38183 L .72669 .38071 L closepath p F P
0 g
s
0 0 0 r
.70022 .40528 m .69341 .41058 L .69265 .41159 L p F P
0 g
s
.674 .171 .039 r
.2925 .35989 m .28822 .35624 L .29538 .3583 L p F P
0 g
s
.674 .171 .039 r
.29699 .36109 m .2925 .35989 L p .29538 .3583 L F P
0 g
s
.674 .171 .039 r
.29538 .3583 m .29839 .36063 L .29699 .36109 L p F P
0 g
s
.053 0 0 r
.55128 .33762 m .55216 .33668 L .54088 .3419 L p F P
0 g
s
.053 0 0 r
.54088 .3419 m .54072 .34208 L .55128 .33762 L p F P
0 g
s
.155 .666 .898 r
.32811 .49264 m .32678 .49223 L .32456 .49212 L closepath p F P
0 g
s
.242 .733 .918 r
.3727 .49605 m .38364 .49558 L .38692 .4964 L p F P
0 g
s
.281 .75 .943 r
.38364 .49558 m .3727 .49605 L .3694 .49517 L p F P
0 g
s
.352 .828 .828 r
.56623 .47327 m .56625 .47327 L .55504 .47679 L p F P
0 g
s
.352 .828 .828 r
.55504 .47679 m .5549 .47681 L .56623 .47327 L p F P
0 g
s
.33 0 0 r
.17935 .45355 m .17304 .45059 L .17872 .45307 L p F P
0 g
s
.33 0 0 r
.17872 .45307 m .18301 .45507 L .17935 .45355 L p F P
0 g
s
.045 .582 .854 r
.27749 .48385 m .27058 .48285 L .27819 .48466 L p F P
0 g
s
.045 .582 .854 r
.27819 .48466 m .28097 .48507 L .27749 .48385 L p F P
0 g
s
0 .402 .721 r
.2189 .46883 m .2179 .46845 L .21715 .46821 L closepath p F P
0 g
s
.64 .086 0 r
.25786 .34345 m .25346 .33989 L .25956 .34233 L p F P
0 g
s
.64 .086 0 r
.26292 .34532 m .25786 .34345 L p .25956 .34233 L F P
0 g
s
.64 .086 0 r
.25956 .34233 m .26365 .34537 L .26292 .34532 L p F P
0 g
s
.349 .815 .917 r
.48362 .49032 m .48562 .49059 L .47299 .4925 L p F P
0 g
s
.349 .815 .917 r
.47299 .4925 m .47243 .49243 L .48362 .49032 L p F P
0 g
s
0 0 0 r
.72533 .38388 m .71818 .38925 L .7252 .38183 L p F P
0 g
s
0 0 0 r
.7252 .38183 m .72669 .38071 L .72533 .38388 L p F P
0 g
s
0 .335 .671 r
.19682 .46065 m .19127 .45849 L .19722 .46086 L p F P
0 g
s
0 .335 .671 r
.19722 .46086 m .20044 .46212 L .19682 .46065 L p F P
0 g
s
.213 .576 .942 r
.15666 .28415 m .15513 .28378 L .1594 .28696 L p F P
0 g
s
.213 .576 .942 r
.1594 .28696 m .16026 .28716 L .15666 .28415 L p F P
0 g
s
.653 .204 .171 r
.34113 .37613 m .33652 .37253 L .3457 .3739 L p F P
0 g
s
.653 .204 .171 r
.34548 .37675 m .34113 .37613 L p .3457 .3739 L F P
0 g
s
.653 .204 .171 r
.3457 .3739 m .34736 .37506 L .34548 .37675 L p F P
0 g
s
.332 .797 .689 r
.62347 .45217 m .62008 .45371 L .61734 .45477 L p F P
0 g
s
.353 .826 .788 r
.59179 .4648 m .59219 .46473 L .58137 .46873 L p F P
0 g
s
.353 .826 .788 r
.58137 .46873 m .58043 .46892 L .59179 .4648 L p F P
0 g
s
.558 .584 .836 r
.74776 .26544 m .75742 .2652 L .75245 .2711 L p F P
0 g
s
.526 .531 .803 r
.75965 .26527 m .75742 .2652 L .75245 .2711 L p F P
0 g
s
.526 .531 .803 r
.75245 .2711 m .76252 .27205 L .75965 .26527 L p F P
0 g
s
.442 .403 .72 r
.76842 .28986 m .7682 .2901 L .76214 .28686 L p F P
0 g
s
.442 .403 .72 r
.76214 .28686 m .76622 .28236 L .76842 .28986 L p F P
0 g
s
.343 .822 .838 r
.54068 .48028 m .55199 .47702 L .5549 .47681 L p F P
0 g
s
.373 .84 .848 r
.56623 .47327 m .5549 .47681 L .55199 .47702 L p F P
0 g
s
.671 .188 .095 r
.31635 .3659 m .31584 .36616 L .31519 .36566 L closepath p F P
0 g
s
.508 .088 .177 r
.43599 .3773 m .4419 .37825 L .43487 .37902 L closepath p F P
0 g
s
.933 .605 .39 r
.0467 .34585 m .0468 .34677 L .05074 .35002 L p F P
0 g
s
.927 .566 .319 r
.04775 .35139 m .05169 .35464 L .05074 .35002 L p F P
0 g
s
.927 .566 .319 r
.05074 .35002 m .0468 .34677 L .04775 .35139 L p F P
0 g
s
.409 0 0 r
.16189 .44553 m .15607 .44229 L .16148 .44487 L p F P
0 g
s
.409 0 0 r
.16206 .44561 m .16189 .44553 L p .16148 .44487 L F P
0 g
s
.409 0 0 r
.16148 .44487 m .16563 .44717 L .16206 .44561 L p F P
0 g
s
.052 0 0 r
.54928 .33979 m .55128 .33762 L .54072 .34208 L p F P
0 g
s
.052 0 0 r
.54516 .34175 m .54928 .33979 L p .54072 .34208 L F P
0 g
s
.052 0 0 r
.54072 .34208 m .53848 .34464 L .54516 .34175 L p F P
0 g
s
.377 0 0 r
.1947 .30642 m .19639 .30748 L .20117 .31043 L p F P
0 g
s
0 .192 .606 r
.20158 .31067 m .20656 .31355 L .20117 .31043 L p F P
0 g
s
0 .192 .606 r
.20117 .31043 m .19639 .30748 L .20158 .31067 L p F P
0 g
s
.913 .526 .259 r
.05299 .35916 m .05701 .36237 L .05571 .35786 L p F P
0 g
s
.913 .526 .259 r
.05571 .35786 m .05169 .35464 L .05299 .35916 L p F P
0 g
s
0 0 0 r
.70468 .40157 m .70022 .40528 L .7039 .40281 L closepath p F P
0 g
s
0 0 0 r
.70229 .40494 m .7039 .40281 L .70022 .40528 L p F P
0 g
s
0 0 0 r
.70039 .40644 m .70229 .40494 L p .70022 .40528 L F P
0 g
s
0 0 0 r
.69265 .41159 m .70039 .40644 L p .70022 .40528 L F P
0 g
s
.127 .649 .882 r
.31263 .49058 m .31556 .49076 L .32456 .49212 L p F P
0 g
s
.128 .65 .884 r
.31263 .49058 m .31556 .49076 L .31084 .49004 L closepath p F P
0 g
s
.593 .163 .195 r
.39323 .3799 m .39459 .38053 L .39276 .38051 L closepath p F P
0 g
s
.938 .613 .395 r
.0429 .34311 m .04247 .3387 L .04632 .342 L p F P
0 g
s
.938 .613 .395 r
.04632 .342 m .0467 .34585 L .0429 .34311 L p F P
0 g
s
.294 .79 .86 r
.48669 .49067 m .49661 .48869 L .49803 .48844 L p F P
0 g
s
.33 .809 .894 r
.48669 .49067 m .49661 .48869 L .48562 .49059 L closepath p F P
0 g
s
.651 .097 0 r
.11411 .41647 m .11599 .4182 L .12088 .42101 L p F P
0 g
s
.597 .032 0 r
.12037 .42183 m .12523 .42465 L .12088 .42101 L p F P
0 g
s
.597 .032 0 r
.12088 .42101 m .11599 .4182 L .12037 .42183 L p F P
0 g
s
.223 0 0 r
.52553 .35152 m .52668 .34996 L .51542 .35394 L p F P
0 g
s
.223 0 0 r
.51542 .35394 m .51442 .3553 L .52553 .35152 L p F P
0 g
s
.671 .189 .098 r
.31163 .36751 m .30723 .36387 L .31519 .36566 L p F P
0 g
s
.671 .189 .098 r
.3128 .36777 m .31163 .36751 L p .31519 .36566 L F P
0 g
s
.671 .189 .098 r
.31519 .36566 m .31584 .36616 L .3128 .36777 L p F P
0 g
s
.171 .673 .91 r
.32339 .4911 m .31556 .49076 L .32456 .49212 L p F P
0 g
s
.171 .673 .91 r
.32456 .49212 m .32678 .49223 L .32339 .4911 L p F P
0 g
s
.264 .749 .924 r
.39825 .49577 m .40115 .49646 L p .38692 .4964 L F P
0 g
s
.264 .749 .924 r
.38692 .4964 m .39688 .49576 L .39825 .49577 L p F P
0 g
s
.299 .764 .944 r
.39688 .49576 m .38692 .4964 L .38364 .49558 L p F P
0 g
s
.313 .213 .577 r
.77157 .30887 m .76587 .31488 L .76416 .31022 L p F P
0 g
s
.313 .213 .577 r
.76416 .31022 m .76979 .30422 L .77157 .30887 L p F P
0 g
s
0 0 0 r
.70989 .39705 m .70468 .40157 L .7039 .40281 L p F P
0 g
s
.896 .484 .2 r
.05863 .36679 m .06272 .36997 L .06109 .36555 L p F P
0 g
s
.896 .484 .2 r
.06109 .36555 m .05701 .36237 L .05863 .36679 L p F P
0 g
s
0 0 0 r
.72482 .38484 m .72533 .38388 L .71818 .38925 L p F P
0 g
s
0 0 0 r
.71955 .39001 m .72482 .38484 L p .71818 .38925 L F P
0 g
s
0 0 0 r
.71479 .39358 m .71955 .39001 L p .71818 .38925 L F P
0 g
s
0 0 0 r
.71818 .38925 m .71591 .39146 L .71479 .39358 L p F P
0 g
s
.584 .009 0 r
.2419 .33476 m .23725 .33132 L .24298 .3339 L p F P
0 g
s
.584 .009 0 r
.24412 .33571 m .2419 .33476 L p .24298 .3339 L F P
0 g
s
.584 .009 0 r
.24298 .3339 m .24636 .33624 L .24412 .33571 L p F P
0 g
s
.241 .09 .466 r
.76464 .327 m .76028 .33126 L .76048 .32598 L p F P
0 g
s
.241 .09 .466 r
.76048 .32598 m .76446 .32209 L .76464 .327 L p F P
0 g
s
.184 .543 .928 r
.14297 .27838 m .1431 .27841 L .14159 .27713 L closepath p F P
0 g
s
0 0 0 r
.71591 .39146 m .70989 .39705 L .71479 .39358 L closepath p F P
0 g
s
.661 .972 .886 r
.62677 .2943 m .62561 .29436 L .63084 .29114 L closepath p F P
0 g
s
.942 .646 .448 r
.03869 .33536 m .04247 .3387 L .04239 .33381 L p F P
0 g
s
.942 .646 .448 r
.04239 .33381 m .03861 .33047 L .03869 .33536 L p F P
0 g
s
0 .446 .861 r
.16026 .28716 m .16619 .28951 L .17054 .29266 L p F P
0 g
s
0 .441 .861 r
.16619 .28951 m .16026 .28716 L .15666 .28415 L p F P
0 g
s
0 0 0 r
.71358 .39548 m .71479 .39358 L .70989 .39705 L p F P
0 g
s
0 0 0 r
.71071 .398 m .71358 .39548 L p .70989 .39705 L F P
0 g
s
0 0 0 r
.7039 .40281 m .71071 .398 L p .70989 .39705 L F P
0 g
s
0 .411 .735 r
.21431 .46701 m .21093 .46593 L .21715 .46821 L p F P
0 g
s
0 .411 .735 r
.21715 .46821 m .2179 .46845 L .21431 .46701 L p F P
0 g
s
.153 .525 .919 r
.14697 .27725 m .15099 .28055 L .1431 .27841 L p F P
0 g
s
.153 .525 .919 r
.13937 .27515 m .14697 .27725 L p .1431 .27841 L F P
0 g
s
.153 .525 .919 r
.1431 .27841 m .14159 .27713 L .13937 .27515 L p F P
0 g
s
.486 .471 .766 r
.75917 .27838 m .76321 .27383 L .76546 .2801 L closepath p F P
0 g
s
.465 .68 .958 r
.12199 .26705 m .12134 .26705 L .12514 .27043 L p F P
0 g
s
.465 .68 .958 r
.12514 .27043 m .12561 .27043 L .12199 .26705 L p F P
0 g
s
.544 .923 .797 r
.61428 .30124 m .61291 .30206 L .61404 .30131 L closepath p F P
0 g
s
.484 .885 .734 r
.61154 .30203 m .61404 .30131 L .61291 .30206 L p F P
0 g
s
.484 .885 .734 r
.6073 .30467 m .61154 .30203 L p .61291 .30206 L F P
0 g
s
.484 .885 .734 r
.60152 .30858 m .6073 .30467 L p .61291 .30206 L F P
0 g
s
.756 .239 0 r
.09354 .4007 m .09449 .40189 L .0991 .40482 L p F P
0 g
s
.704 .169 0 r
.09806 .40574 m .10265 .40868 L .0991 .40482 L p F P
0 g
s
.704 .169 0 r
.0991 .40482 m .09449 .40189 L .09806 .40574 L p F P
0 g
s
.876 .44 .14 r
.06465 .3743 m .06881 .37744 L .06687 .37311 L p F P
0 g
s
.876 .44 .14 r
.06687 .37311 m .06272 .36997 L .06465 .3743 L p F P
0 g
s
0 0 0 r
.63145 .44844 m .62347 .45217 L .63067 .44883 L closepath p F P
0 g
s
.332 .797 .689 r
.62875 .44956 m .63067 .44883 L .62347 .45217 L p F P
0 g
s
.332 .797 .689 r
.61734 .45477 m .62875 .44956 L p .62347 .45217 L F P
0 g
s
0 0 0 r
.58623 .31761 m .58889 .3159 L .57759 .3224 L p F P
0 g
s
0 0 0 r
.57759 .3224 m .57651 .3232 L .58623 .31761 L p F P
0 g
s
.368 .823 .932 r
.48362 .49032 m .47243 .49243 L .46933 .49194 L p F P
0 g
s
.54 .117 .188 r
.42172 .37936 m .42354 .37983 L .42128 .37999 L closepath p F P
0 g
s
.481 0 0 r
.14462 .43653 m .14018 .43363 L .14535 .43631 L p F P
0 g
s
.481 0 0 r
.14535 .43631 m .14833 .43825 L .14462 .43653 L p F P
0 g
s
.279 .761 .924 r
.41262 .49562 m .4154 .49623 L p .40115 .49646 L F P
0 g
s
.279 .761 .924 r
.40115 .49646 m .41067 .49565 L .41262 .49562 L p F P
0 g
s
.29 .765 .932 r
.40115 .49646 m .41067 .49565 L .39825 .49577 L closepath p F P
0 g
s
.568 .142 .194 r
.40746 .38022 m .40815 .38047 L .40726 .3805 L closepath p F P
0 g
s
.582 .94 .803 r
.62308 .29474 m .62561 .29436 L .61428 .30124 L p F P
0 g
s
.582 .94 .803 r
.61428 .30124 m .61404 .30131 L .62308 .29474 L p F P
0 g
s
.334 .623 .957 r
.12561 .27043 m .13518 .27178 L .1391 .27511 L p F P
0 g
s
.337 .62 .955 r
.13518 .27178 m .12561 .27043 L .12199 .26705 L p F P
0 g
s
.731 .912 .956 r
.67648 .2694 m .67507 .27015 L .67608 .26918 L closepath p F P
0 g
s
.72 .933 .959 r
.67379 .26794 m .67608 .26918 L .67507 .27015 L p F P
0 g
s
.72 .933 .959 r
.66239 .27436 m .67379 .26794 L p .67507 .27015 L F P
0 g
s
.697 .225 .126 r
.31584 .36616 m .31949 .36933 L .3128 .36777 L closepath p F P
0 g
s
0 .317 .744 r
.17749 .29658 m .18125 .29852 L .18581 .30157 L p F P
0 g
s
0 .31 .745 r
.18125 .29852 m .17749 .29658 L .1739 .29386 L p F P
0 g
s
0 .457 .776 r
.22574 .47066 m .2179 .46845 L .21431 .46701 L p F P
0 g
s
0 0 0 r
.72722 .38238 m .72533 .38388 L .72669 .38071 L p F P
0 g
s
0 0 0 r
.72669 .38071 m .73375 .3751 L .72722 .38238 L p F P
0 g
s
.347 .81 .928 r
.46933 .49194 m .45817 .49381 L .45504 .49327 L p F P
0 g
s
.292 .772 .922 r
.42664 .4951 m .42965 .49571 L p .4154 .49623 L F P
0 g
s
.292 .772 .922 r
.4154 .49623 m .42577 .49513 L .42664 .4951 L p F P
0 g
s
.306 .778 .933 r
.4154 .49623 m .42577 .49513 L .41262 .49562 L closepath p F P
0 g
s
0 .358 .774 r
.18719 .30142 m .18125 .29852 L .18581 .30157 L p F P
0 g
s
0 .358 .774 r
.18856 .30228 m .18719 .30142 L p .18581 .30157 L F P
0 g
s
0 .358 .774 r
.18581 .30157 m .19111 .30404 L .18856 .30228 L p F P
0 g
s
0 0 0 r
.65686 .43515 m .65536 .43598 L .65667 .43529 L closepath p F P
0 g
s
0 0 0 r
.65424 .4368 m .65667 .43529 L .65536 .43598 L p F P
0 g
s
0 0 0 r
.65095 .43858 m .65424 .4368 L p .65536 .43598 L F P
0 g
s
0 0 0 r
.64388 .44229 m .65095 .43858 L p .65536 .43598 L F P
0 g
s
.647 .093 0 r
.11599 .4182 m .11411 .41647 L .11035 .4146 L p F P
0 g
s
.488 0 0 r
.22553 .32509 m .22164 .32253 L .22707 .32523 L p F P
0 g
s
.488 0 0 r
.22707 .32523 m .22912 .32651 L .22553 .32509 L p F P
0 g
s
.371 .837 .88 r
.53773 .48038 m .53897 .48039 L .52733 .4834 L p F P
0 g
s
.371 .837 .88 r
.52733 .4834 m .52644 .4834 L .53773 .48038 L p F P
0 g
s
.578 .591 .829 r
.75742 .2652 m .74776 .26544 L .745 .26033 L p F P
0 g
s
.735 .913 .955 r
.68523 .2617 m .68791 .26355 L .67648 .2694 L p F P
0 g
s
.735 .913 .955 r
.68166 .26365 m .68523 .2617 L p .67648 .2694 L F P
0 g
s
.735 .913 .955 r
.67648 .2694 m .67608 .26918 L .68166 .26365 L p F P
0 g
s
.104 0 .265 r
.75465 .34872 m .74768 .35503 L .75047 .34893 L p F P
0 g
s
.104 0 .265 r
.75566 .3465 m .75465 .34872 L p .75047 .34893 L F P
0 g
s
.104 0 .265 r
.75047 .34893 m .75601 .34392 L .75566 .3465 L p F P
0 g
s
.845 .382 .061 r
.06954 .37879 m .06881 .37744 L .07303 .38055 L p F P
0 g
s
.845 .382 .061 r
.07303 .38055 m .07334 .38111 L .06954 .37879 L p F P
0 g
s
.344 .804 .936 r
.45504 .49327 m .44391 .4949 L .44075 .49431 L p F P
0 g
s
.309 .784 .924 r
.42965 .49571 m .44075 .49431 L .44391 .4949 L p F P
0 g
s
.599 .184 .227 r
.40726 .3805 m .39459 .38053 L .40095 .38362 L p F P
0 g
s
.599 .176 .21 r
.39051 .38353 m .40095 .38362 L .39459 .38053 L p F P
0 g
s
.599 .176 .21 r
.39459 .38053 m .39276 .38051 L .39051 .38353 L p F P
0 g
s
.322 .79 .933 r
.44028 .49421 m .44075 .49431 L .42965 .49571 L p F P
0 g
s
.322 .79 .933 r
.42965 .49571 m .42664 .4951 L .44028 .49421 L p F P
0 g
s
.44 .012 .129 r
.47325 .37347 m .47517 .37032 L .46279 .37261 L p F P
0 g
s
.44 .012 .129 r
.46648 .37468 m .47325 .37347 L p .46279 .37261 L F P
0 g
s
.44 .012 .129 r
.46279 .37261 m .46138 .37477 L .46648 .37468 L p F P
0 g
s
.618 .198 .223 r
.38805 .38345 m .39051 .38353 L .39276 .38051 L p F P
0 g
s
.618 .198 .223 r
.39276 .38051 m .38228 .38018 L .38805 .38345 L p F P
0 g
s
.575 .157 .212 r
.40815 .38047 m .40726 .3805 L .40514 .38361 L p F P
0 g
s
.599 .184 .227 r
.40095 .38362 m .40514 .38361 L .40726 .3805 L p F P
0 g
s
.575 .162 .221 r
.42128 .37999 m .40815 .38047 L .4154 .3833 L p F P
0 g
s
.575 .157 .212 r
.40514 .38361 m .4154 .3833 L .40815 .38047 L p F P
0 g
s
.35 0 .069 r
.49899 .36463 m .50093 .36157 L .48923 .36464 L p F P
0 g
s
.35 0 .069 r
.48923 .36464 m .48723 .36765 L .49899 .36463 L p F P
0 g
s
.68 .222 .157 r
.33224 .37466 m .34113 .37613 L .33652 .37253 L p F P
0 g
s
.68 .222 .157 r
.3298 .37252 m .33224 .37466 L p .33652 .37253 L F P
0 g
s
.68 .222 .157 r
.33652 .37253 m .33113 .37155 L .3298 .37252 L p F P
0 g
s
.124 0 0 r
.53797 .34523 m .53848 .34464 L .52767 .34879 L p F P
0 g
s
.124 0 0 r
.52767 .34879 m .52668 .34996 L .53797 .34523 L p F P
0 g
s
.58 .939 .799 r
.62288 .29477 m .62308 .29474 L .61404 .30131 L p F P
0 g
s
.58 .939 .799 r
.61404 .30131 m .61154 .30203 L .62288 .29477 L p F P
0 g
s
0 0 0 r
.68103 .41993 m .6796 .42125 L .68818 .41545 L closepath p F P
0 g
s
0 0 0 r
.66904 .42783 m .66823 .42845 L .6735 .4252 L closepath p F P
0 g
s
0 0 0 r
.66643 .42981 m .66823 .42845 L .65686 .43515 L p F P
0 g
s
0 0 0 r
.65686 .43515 m .65667 .43529 L .66643 .42981 L p F P
0 g
s
.667 .221 .183 r
.34736 .37506 m .35049 .37745 L .34548 .37675 L closepath p F P
0 g
s
.71 .964 .941 r
.65976 .27588 m .65102 .28095 L .64834 .28038 L p F P
0 g
s
.351 .827 .846 r
.55041 .47712 m .55199 .47702 L .54068 .48028 L p F P
0 g
s
.351 .827 .846 r
.54068 .48028 m .53897 .48039 L .55041 .47712 L p F P
0 g
s
.354 .82 .741 r
.60655 .4594 m .60596 .45958 L .61325 .45653 L closepath p F P
0 g
s
.113 .626 .892 r
.29022 .48614 m .28097 .48507 L .27749 .48385 L p F P
0 g
s
.232 .708 .937 r
.3376 .49243 m .32678 .49223 L .32339 .4911 L p F P
0 g
s
0 .174 .598 r
.19639 .30748 m .1947 .30642 L .19111 .30404 L p F P
0 g
s
.621 .19 .202 r
.3763 .38291 m .38805 .38345 L .38228 .38018 L p F P
0 g
s
.621 .19 .202 r
.37561 .38246 m .3763 .38291 L p .38228 .38018 L F P
0 g
s
.621 .19 .202 r
.38228 .38018 m .3777 .37995 L .37561 .38246 L p F P
0 g
s
.267 .144 .52 r
.7666 .31986 m .76446 .32209 L .764 .31684 L p F P
0 g
s
.267 .144 .52 r
.764 .31684 m .76587 .31488 L .7666 .31986 L p F P
0 g
s
.37 .837 .803 r
.59179 .4648 m .58043 .46892 L .57758 .46943 L p F P
0 g
s
.833 .361 .035 r
.07546 .38473 m .07334 .38111 L .06954 .37879 L p F P
0 g
s
.087 .608 .879 r
.274 .48258 m .27749 .48385 L .27058 .48285 L p F P
0 g
s
.087 .608 .879 r
.2634 .48109 m .274 .48258 L p .27058 .48285 L F P
0 g
s
.087 .608 .879 r
.27058 .48285 m .26376 .48122 L .2634 .48109 L p F P
0 g
s
.201 .69 .925 r
.31999 .48992 m .32339 .4911 L .31556 .49076 L p F P
0 g
s
.201 .69 .925 r
.30921 .48949 m .31999 .48992 L p .31556 .49076 L F P
0 g
s
.201 .69 .925 r
.31556 .49076 m .31084 .49004 L .30921 .48949 L p F P
0 g
s
.679 .753 .907 r
.72787 .25471 m .71627 .25861 L .71358 .25557 L p F P
0 g
s
.696 .786 .92 r
.70206 .26037 m .71358 .25557 L .71627 .25861 L p F P
0 g
s
.665 .73 .898 r
.71627 .25861 m .72787 .25471 L .73057 .25845 L p F P
0 g
s
.546 .131 .204 r
.42354 .37983 m .42128 .37999 L .41924 .38316 L p F P
0 g
s
.575 .162 .221 r
.4154 .3833 m .41924 .38316 L .42128 .37999 L p F P
0 g
s
0 .47 .767 r
.23183 .47276 m .23222 .47286 L .23906 .47493 L p F P
0 g
s
0 .506 .807 r
.24187 .47502 m .23222 .47286 L .23906 .47493 L p F P
0 g
s
0 .506 .807 r
.24276 .4753 m .24187 .47502 L p .23906 .47493 L F P
0 g
s
0 .506 .807 r
.23906 .47493 m .24584 .47647 L .24276 .4753 L p F P
0 g
s
0 .538 .827 r
.24937 .47777 m .25594 .47904 L .26302 .48103 L p F P
0 g
s
.004 .546 .837 r
.25594 .47904 m .24937 .47777 L .24584 .47647 L p F P
0 g
s
.349 .635 .961 r
.14159 .27713 m .13937 .27515 L .1391 .27511 L closepath p F P
0 g
s
.711 .209 .042 r
.281 .3536 m .28147 .35403 L .28822 .35624 L p F P
0 g
s
.717 .221 .059 r
.28543 .35779 m .2925 .35989 L .28822 .35624 L p F P
0 g
s
.717 .221 .059 r
.28822 .35624 m .28147 .35403 L .28543 .35779 L p F P
0 g
s
.545 0 0 r
.12741 .4263 m .12523 .42465 L .13017 .42743 L p F P
0 g
s
.545 0 0 r
.13017 .42743 m .13114 .42816 L .12741 .4263 L p F P
0 g
s
.634 .206 .212 r
.3777 .37995 m .37561 .38246 L .37094 .37951 L closepath p F P
0 g
s
0 0 0 r
.69265 .41159 m .69095 .41347 L .70039 .40644 L closepath p F P
0 g
s
.711 .836 .942 r
.70206 .26037 m .70007 .26127 L .70141 .25978 L closepath p F P
0 g
s
.707 .863 .956 r
.69938 .25796 m .70141 .25978 L .70007 .26127 L p F P
0 g
s
.707 .863 .956 r
.68791 .26355 m .69938 .25796 L p .70007 .26127 L F P
0 g
s
.735 .914 .954 r
.67608 .26918 m .67379 .26794 L .68166 .26365 L closepath p F P
0 g
s
.357 0 0 r
.21226 .31664 m .2119 .31646 L .21173 .31636 L closepath p F P
0 g
s
.672 .126 0 r
.10645 .41248 m .10265 .40868 L .10732 .41158 L p F P
0 g
s
.672 .126 0 r
.10718 .41293 m .10645 .41248 L p .10732 .41158 L F P
0 g
s
.672 .126 0 r
.10732 .41158 m .11035 .4146 L .10718 .41293 L p F P
0 g
s
0 0 0 r
.66565 .43029 m .66643 .42981 L .65667 .43529 L p F P
0 g
s
0 0 0 r
.65667 .43529 m .65424 .4368 L .66565 .43029 L p F P
0 g
s
.455 .672 .957 r
.10814 .26353 m .11765 .26361 L .12134 .26705 L p F P
0 g
s
.801 .309 0 r
.0782 .38882 m .08253 .39188 L .0798 .38779 L p F P
0 g
s
.801 .309 0 r
.0798 .38779 m .07546 .38473 L .0782 .38882 L p F P
0 g
s
.703 .179 0 r
.26365 .34537 m .26416 .34583 L .27039 .34822 L p F P
0 g
s
.71 .191 0 r
.26815 .34954 m .27466 .35184 L .27039 .34822 L p F P
0 g
s
.71 .191 0 r
.27039 .34822 m .26416 .34583 L .26815 .34954 L p F P
0 g
s
.547 .132 .206 r
.43487 .37902 m .42354 .37983 L .43211 .38224 L p F P
0 g
s
.546 .131 .204 r
.41924 .38316 m .43211 .38224 L .42354 .37983 L p F P
0 g
s
.377 .83 .928 r
.49661 .48869 m .48562 .49059 L .48362 .49032 L p F P
0 g
s
.506 .895 .735 r
.60152 .30858 m .60021 .30911 L .6073 .30467 L closepath p F P
0 g
s
.711 .236 .12 r
.30384 .36566 m .31163 .36751 L .30723 .36387 L p F P
0 g
s
.711 .236 .12 r
.30723 .36387 m .2998 .36191 L .30384 .36566 L p F P
0 g
s
.628 .669 .87 r
.74371 .25812 m .74108 .26101 L p .73057 .25845 L F P
0 g
s
.606 .652 .87 r
.74108 .26101 m .74371 .25812 L .745 .26033 L closepath p F P
0 g
s
.036 .478 .882 r
.17031 .29104 m .16619 .28951 L .17054 .29266 L p F P
0 g
s
.036 .478 .882 r
.17054 .29266 m .1739 .29386 L .17031 .29104 L p F P
0 g
s
.343 0 0 r
.20831 .31455 m .20656 .31355 L .21173 .31636 L p F P
0 g
s
.343 0 0 r
.21173 .31636 m .2119 .31646 L .20831 .31455 L p F P
0 g
s
.628 .669 .87 r
.73057 .25845 m .74226 .2557 L .74371 .25812 L p F P
0 g
s
.643 .693 .882 r
.74226 .2557 m .73057 .25845 L .72787 .25471 L p F P
0 g
s
.547 0 0 r
.21642 .31975 m .2119 .31646 L .20831 .31455 L p F P
0 g
s
.642 .204 .195 r
.3753 .38285 m .37561 .38246 L .37094 .37951 L p F P
0 g
s
.642 .204 .195 r
.36534 .38212 m .3753 .38285 L p .37094 .37951 L F P
0 g
s
.642 .204 .195 r
.36145 .37927 m .36534 .38212 L p .37094 .37951 L F P
0 g
s
.642 .204 .195 r
.37094 .37951 m .36196 .37872 L .36145 .37927 L p F P
0 g
s
.399 0 .115 r
.47569 .3695 m .48258 .36866 L .47517 .37032 L closepath p F P
0 g
s
0 .377 .703 r
.20044 .46212 m .20476 .46362 L .21093 .46593 L p F P
0 g
s
0 .384 .715 r
.20476 .46362 m .20044 .46212 L .19682 .46065 L p F P
0 g
s
.708 .835 .943 r
.7109 .25276 m .71358 .25557 L .70206 .26037 L p F P
0 g
s
.708 .835 .943 r
.7059 .25502 m .7109 .25276 L p .70206 .26037 L F P
0 g
s
.708 .835 .943 r
.70206 .26037 m .70141 .25978 L .7059 .25502 L p F P
0 g
s
.675 .215 .153 r
.33113 .37155 m .3298 .37252 L .32785 .37098 L closepath p F P
0 g
s
.678 .132 0 r
.24636 .33624 m .24763 .33735 L .25346 .33989 L p F P
0 g
s
.682 .138 0 r
.25177 .34099 m .25786 .34345 L .25346 .33989 L p F P
0 g
s
.682 .138 0 r
.25346 .33989 m .24763 .33735 L .25177 .34099 L p F P
0 g
s
.37 0 0 r
.16563 .44717 m .16743 .44808 L .17304 .45059 L p F P
0 g
s
.32 0 0 r
.174 .45111 m .16743 .44808 L .17304 .45059 L p F P
0 g
s
.32 0 0 r
.17898 .45339 m .174 .45111 L p .17304 .45059 L F P
0 g
s
.32 0 0 r
.17304 .45059 m .17935 .45355 L .17898 .45339 L p F P
0 g
s
.049 0 .187 r
.74702 .35562 m .74685 .35649 L .74768 .35503 L closepath p F P
0 g
s
.287 0 0 r
.18301 .45507 m .18539 .45608 L .19127 .45849 L p F P
0 g
s
0 .341 .682 r
.19267 .45891 m .18539 .45608 L .19127 .45849 L p F P
0 g
s
0 .341 .682 r
.19404 .45948 m .19267 .45891 L p .19127 .45849 L F P
0 g
s
0 .341 .682 r
.19127 .45849 m .19682 .46065 L .19404 .45948 L p F P
0 g
s
.754 .237 0 r
.09449 .40189 m .09354 .4007 L .08975 .39866 L p F P
0 g
s
0 0 0 r
.56156 .33276 m .56346 .33085 L .55216 .33668 L p F P
0 g
s
0 0 0 r
.55216 .33668 m .55128 .33762 L .56156 .33276 L p F P
0 g
s
.148 .655 .902 r
.31084 .49004 m .30921 .48949 L .30683 .48931 L closepath p F P
0 g
s
.229 .714 .929 r
.35241 .49364 m .35517 .49448 L p .34097 .49349 L F P
0 g
s
.229 .714 .929 r
.34097 .49349 m .35068 .49347 L .35241 .49364 L p F P
0 g
s
.261 .729 .946 r
.35068 .49347 m .34097 .49349 L .3376 .49243 L p F P
0 g
s
0 0 0 r
.64077 .44383 m .64284 .44281 L .63145 .44844 L p F P
0 g
s
0 0 0 r
.63145 .44844 m .63067 .44883 L .64077 .44383 L p F P
0 g
s
.708 .218 .079 r
.29839 .36063 m .2998 .36191 L .29699 .36109 L closepath p F P
0 g
s
.136 0 .334 r
.75735 .34263 m .75601 .34392 L .75632 .3396 L p F P
0 g
s
.136 0 .334 r
.75632 .3396 m .75921 .33681 L .75735 .34263 L p F P
0 g
s
.418 .835 .661 r
.58898 .31585 m .58889 .3159 L .58946 .31556 L closepath p F P
0 g
s
.363 .827 .751 r
.61325 .45653 m .60596 .45958 L .60318 .46036 L p F P
0 g
s
.385 .844 .893 r
.53773 .48038 m .52644 .4834 L .52345 .4833 L p F P
0 g
s
.359 .829 .886 r
.51218 .48606 m .52345 .4833 L .52644 .4834 L p F P
0 g
s
.358 .278 .628 r
.7712 .30272 m .76979 .30422 L .76687 .29995 L p F P
0 g
s
.358 .278 .628 r
.76687 .29995 m .77002 .29656 L .7712 .30272 L p F P
0 g
s
.772 .264 0 r
.08554 .3959 m .08253 .39188 L .08694 .3949 L p F P
0 g
s
.772 .264 0 r
.08858 .39799 m .08554 .3959 L p .08694 .3949 L F P
0 g
s
.772 .264 0 r
.08694 .3949 m .08975 .39866 L .08858 .39799 L p F P
0 g
s
0 0 0 r
.7039 .40281 m .70229 .40494 L .71071 .398 L closepath p F P
0 g
s
.624 .961 .855 r
.63084 .29114 m .62561 .29436 L .62308 .29474 L p F P
0 g
s
.226 0 0 r
.52373 .35399 m .52553 .35152 L .51442 .3553 L p F P
0 g
s
.226 0 0 r
.51442 .3553 m .51244 .35801 L .52373 .35399 L p F P
0 g
s
.509 0 0 r
.13509 .43091 m .13114 .42816 L .12741 .4263 L p F P
0 g
s
.937 .608 .386 r
.0468 .34677 m .0467 .34585 L .0429 .34311 L p F P
0 g
s
.513 .096 .187 r
.4419 .37825 m .43487 .37902 L .43286 .38219 L p F P
0 g
s
.547 .132 .206 r
.43211 .38224 m .43286 .38219 L .43487 .37902 L p F P
0 g
s
0 0 0 r
.58946 .31556 m .58889 .3159 L .58623 .31761 L p F P
0 g
s
.389 0 0 r
.1566 .44289 m .16189 .44553 L .15607 .44229 L p F P
0 g
s
.389 0 0 r
.15607 .44229 m .15072 .43967 L .1566 .44289 L p F P
0 g
s
.446 0 0 r
.14833 .43825 m .15072 .43967 L .15607 .44229 L p F P
0 g
s
.339 .789 .64 r
.64388 .44229 m .64284 .44281 L .65095 .43858 L closepath p F P
0 g
s
.675 .217 .158 r
.32374 .37305 m .31949 .36933 L .32785 .37098 L p F P
0 g
s
.675 .217 .158 r
.32803 .37385 m .32374 .37305 L p .32785 .37098 L F P
0 g
s
.675 .217 .158 r
.32785 .37098 m .3298 .37252 L .32803 .37385 L p F P
0 g
s
.411 .831 .657 r
.60021 .30911 m .58946 .31556 L .59852 .30999 L closepath p F P
0 g
s
0 0 0 r
.59744 .31057 m .59852 .30999 L .58946 .31556 L p F P
0 g
s
0 0 0 r
.58688 .3172 m .59744 .31057 L p .58946 .31556 L F P
0 g
s
0 0 0 r
.58623 .31761 m .58688 .3172 L p .58946 .31556 L F P
0 g
s
0 .416 .745 r
.21072 .46553 m .20476 .46362 L .21093 .46593 L p F P
0 g
s
0 .416 .745 r
.21093 .46593 m .21431 .46701 L .21072 .46553 L p F P
0 g
s
.623 .057 0 r
.23616 .33217 m .2419 .33476 L .23725 .33132 L p F P
0 g
s
.623 .057 0 r
.23725 .33132 m .23175 .32865 L .23616 .33217 L p F P
0 g
s
.635 .074 0 r
.23175 .32865 m .22912 .32651 L .22553 .32509 L p F P
0 g
s
.73 .95 .949 r
.66239 .27436 m .65976 .27588 L .6617 .27413 L closepath p F P
0 g
s
.71 .964 .941 r
.6597 .27347 m .6617 .27413 L .65976 .27588 L p F P
0 g
s
.71 .964 .941 r
.64839 .28033 m .6597 .27347 L p .65976 .27588 L F P
0 g
s
.71 .964 .941 r
.64834 .28038 m .64839 .28033 L p .65976 .27588 L F P
0 g
s
.046 0 .185 r
.75103 .3551 m .75465 .34872 L .74768 .35503 L p F P
0 g
s
.046 0 .185 r
.74626 .35942 m .75103 .3551 L p .74768 .35503 L F P
0 g
s
.046 0 .185 r
.74768 .35503 m .74685 .35649 L .74626 .35942 L p F P
0 g
s
.212 .57 .939 r
.15306 .28106 m .15099 .28055 L .15513 .28378 L p F P
0 g
s
.212 .57 .939 r
.15513 .28378 m .15666 .28415 L .15306 .28106 L p F P
0 g
s
.187 .015 .401 r
.76457 .3316 m .75921 .33681 L .76028 .33126 L p F P
0 g
s
.187 .015 .401 r
.76028 .33126 m .76464 .327 L .76457 .3316 L p F P
0 g
s
0 .174 .598 r
.19111 .30404 m .19176 .30447 L .19639 .30748 L p F P
0 g
s
0 .173 .597 r
.19678 .30771 m .20158 .31067 L .19639 .30748 L p F P
0 g
s
0 .173 .597 r
.19639 .30748 m .19176 .30447 L .19678 .30771 L p F P
0 g
s
.649 .214 .201 r
.36196 .37872 m .36145 .37927 L .36045 .37857 L closepath p F P
0 g
s
.121 .639 .888 r
.29507 .48747 m .29845 .48775 L .30683 .48931 L p F P
0 g
s
.121 .639 .888 r
.29507 .48747 m .29845 .48775 L .29271 .48669 L closepath p F P
0 g
s
.277 0 0 r
.18539 .45608 m .18301 .45507 L .17935 .45355 L p F P
0 g
s
.647 .093 0 r
.11035 .4146 m .11118 .41536 L .11599 .4182 L p F P
0 g
s
.583 .018 0 r
.11558 .41898 m .12037 .42183 L .11599 .4182 L p F P
0 g
s
.583 .018 0 r
.11599 .4182 m .11118 .41536 L .11558 .41898 L p F P
0 g
s
0 0 0 r
.5861 .3177 m .58623 .31761 L .57651 .3232 L p F P
0 g
s
0 0 0 r
.57651 .3232 m .57477 .32451 L .5861 .3177 L p F P
0 g
s
.648 .218 .212 r
.35515 .38107 m .35049 .37745 L .36045 .37857 L p F P
0 g
s
.648 .218 .212 r
.35944 .38153 m .35515 .38107 L p .36045 .37857 L F P
0 g
s
.648 .218 .212 r
.36045 .37857 m .36145 .37927 L .35944 .38153 L p F P
0 g
s
.709 .837 .943 r
.70141 .25978 m .69938 .25796 L .7059 .25502 L closepath p F P
0 g
s
.162 .661 .913 r
.30579 .48824 m .29845 .48775 L .30683 .48931 L p F P
0 g
s
.162 .661 .913 r
.30683 .48931 m .30921 .48949 L .30579 .48824 L p F P
0 g
s
0 0 0 r
.6735 .4252 m .66823 .42845 L .66643 .42981 L p F P
0 g
s
.937 .608 .386 r
.0429 .34311 m .04294 .34347 L .0468 .34677 L p F P
0 g
s
.93 .568 .312 r
.04388 .34809 m .04775 .35139 L .0468 .34677 L p F P
0 g
s
.93 .568 .312 r
.0468 .34677 m .04294 .34347 L .04388 .34809 L p F P
0 g
s
.071 0 .194 r
.74685 .35649 m .74387 .36146 L .74626 .35942 L closepath p F P
0 g
s
.915 .527 .251 r
.04905 .3559 m .05299 .35916 L .05169 .35464 L p F P
0 g
s
.915 .527 .251 r
.05169 .35464 m .04775 .35139 L .04905 .3559 L p F P
0 g
s
.438 0 0 r
.15072 .43967 m .14833 .43825 L .14462 .43653 L p F P
0 g
s
.737 .952 .947 r
.67111 .26667 m .67379 .26794 L .66239 .27436 L p F P
0 g
s
.737 .952 .947 r
.66684 .26922 m .67111 .26667 L p .66239 .27436 L F P
0 g
s
.737 .952 .947 r
.66239 .27436 m .6617 .27413 L .66684 .26922 L p F P
0 g
s
.257 .733 .937 r
.36818 .49481 m .3694 .49517 L p .35517 .49448 L F P
0 g
s
.257 .733 .937 r
.35517 .49448 m .36137 .49431 L .36818 .49481 L p F P
0 g
s
.256 .733 .936 r
.35517 .49448 m .36137 .49431 L .35241 .49364 L closepath p F P
0 g
s
.019 .559 .844 r
.26376 .48122 m .2634 .48109 L .26302 .48103 L closepath p F P
0 g
s
.941 .617 .391 r
.03913 .33996 m .03869 .33536 L .04247 .3387 L p F P
0 g
s
.941 .617 .391 r
.04247 .3387 m .0429 .34311 L .03913 .33996 L p F P
0 g
s
.71 .201 .019 r
.281 .3536 m .28147 .35403 L .28042 .35367 L closepath p F P
0 g
s
.381 .845 .838 r
.56625 .47327 m .56623 .47327 L .56703 .473 L closepath p F P
0 g
s
.669 .118 0 r
.24636 .33624 m .24763 .33735 L .24412 .33571 L closepath p F P
0 g
s
.516 .1 .19 r
.44803 .37759 m .44705 .37916 L .4419 .37825 L closepath p F P
0 g
s
.513 .096 .187 r
.44612 .38082 m .44705 .37916 L .4419 .37825 L p F P
0 g
s
.513 .096 .187 r
.43286 .38219 m .44612 .38082 L p .4419 .37825 L F P
0 g
s
0 0 .029 r
.73666 .37033 m .73594 .3724 L .73926 .36814 L closepath p F P
0 g
s
.407 0 .13 r
.48258 .36866 m .47517 .37032 L .47325 .37347 L p F P
0 g
s
.67 .973 .895 r
.63696 .28739 m .63084 .29114 L .63559 .28741 L closepath p F P
0 g
s
.624 .961 .855 r
.63424 .28745 m .63559 .28741 L .63084 .29114 L p F P
0 g
s
.624 .961 .855 r
.62374 .29422 m .63424 .28745 L p .63084 .29114 L F P
0 g
s
.624 .961 .855 r
.62308 .29474 m .62374 .29422 L p .63084 .29114 L F P
0 g
s
.264 .143 .521 r
.77232 .31385 m .7666 .31986 L .76587 .31488 L p F P
0 g
s
.264 .143 .521 r
.76587 .31488 m .77157 .30887 L .77232 .31385 L p F P
0 g
s
.401 .856 .857 r
.56703 .473 m .56623 .47327 L .56334 .47348 L p F P
0 g
s
.373 .84 .848 r
.55199 .47702 m .56334 .47348 L .56623 .47327 L p F P
0 g
s
.897 .484 .19 r
.05461 .36357 m .05863 .36679 L .05701 .36237 L p F P
0 g
s
.897 .484 .19 r
.05701 .36237 m .05299 .35916 L .05461 .36357 L p F P
0 g
s
.359 0 0 r
.16563 .44717 m .16743 .44808 L .16206 .44561 L closepath p F P
0 g
s
.475 0 0 r
.14031 .43431 m .13509 .43091 L .14018 .43363 L p F P
0 g
s
.475 0 0 r
.14256 .43553 m .14031 .43431 L p .14018 .43363 L F P
0 g
s
.475 0 0 r
.14018 .43363 m .14462 .43653 L .14256 .43553 L p F P
0 g
s
.578 .591 .829 r
.75886 .26352 m .75742 .2652 L p .745 .26033 L F P
0 g
s
.578 .591 .829 r
.745 .26033 m .75684 .25933 L .75886 .26352 L p F P
0 g
s
.571 .636 .876 r
.74371 .25812 m .745 .26033 L .75684 .25933 L p F P
0 g
s
.733 .86 .94 r
.69938 .25796 m .68791 .26355 L .68523 .2617 L p F P
0 g
s
.372 .835 .897 r
.52208 .48322 m .52345 .4833 L .51218 .48606 L p F P
0 g
s
.372 .835 .897 r
.51218 .48606 m .51016 .48595 L .52208 .48322 L p F P
0 g
s
.754 .237 0 r
.08975 .39866 m .08996 .39892 L .09449 .40189 L p F P
0 g
s
.695 .158 0 r
.09354 .40277 m .09806 .40574 L .09449 .40189 L p F P
0 g
s
.695 .158 0 r
.09449 .40189 m .08996 .39892 L .09354 .40277 L p F P
0 g
s
.171 0 0 r
.53637 .34736 m .53797 .34523 L .52668 .34996 L p F P
0 g
s
.171 0 0 r
.52668 .34996 m .52553 .35152 L .53637 .34736 L p F P
0 g
s
.035 .567 .857 r
.25989 .47972 m .25594 .47904 L .26302 .48103 L p F P
0 g
s
.035 .567 .857 r
.26302 .48103 m .2634 .48109 L .25989 .47972 L p F P
0 g
s
0 .477 .779 r
.23183 .47276 m .23222 .47286 L .2314 .4726 L closepath p F P
0 g
s
.354 .634 .959 r
.13576 .27185 m .13518 .27178 L .1391 .27511 L p F P
0 g
s
.354 .634 .959 r
.1391 .27511 m .13937 .27515 L .13576 .27185 L p F P
0 g
s
.303 0 .043 r
.51235 .35815 m .51244 .35801 L .50118 .3612 L p F P
0 g
s
.303 0 .043 r
.50118 .3612 m .50093 .36157 L .51235 .35815 L p F P
0 g
s
.7 .169 0 r
.26365 .34537 m .26416 .34583 L .26292 .34532 L closepath p F P
0 g
s
.352 .827 .806 r
.57758 .46943 m .56703 .473 L .57726 .46948 L closepath p F P
0 g
s
.401 .856 .857 r
.57472 .46966 m .57726 .46948 L .56703 .473 L p F P
0 g
s
.401 .856 .857 r
.56334 .47348 m .57472 .46966 L p .56703 .473 L F P
0 g
s
.501 0 0 r
.22124 .32311 m .21642 .31975 L .22164 .32253 L p F P
0 g
s
.501 0 0 r
.2233 .32415 m .22124 .32311 L p .22164 .32253 L F P
0 g
s
.501 0 0 r
.22164 .32253 m .22553 .32509 L .2233 .32415 L p F P
0 g
s
0 0 0 r
.56393 .33045 m .56346 .33085 L .56744 .3286 L closepath p F P
0 g
s
.465 .677 .956 r
.11837 .2636 m .11765 .26361 L .12134 .26705 L p F P
0 g
s
.465 .677 .956 r
.12134 .26705 m .12199 .26705 L .11837 .2636 L p F P
0 g
s
.876 .439 .129 r
.06056 .37112 m .06465 .3743 L .06272 .36997 L p F P
0 g
s
.876 .439 .129 r
.06272 .36997 m .05863 .36679 L .06056 .37112 L p F P
0 g
s
.186 .543 .928 r
.14697 .27725 m .13937 .27515 L .13576 .27185 L p F P
0 g
s
.102 .611 .893 r
.274 .48258 m .2634 .48109 L .25989 .47972 L p F P
0 g
s
.013 .547 .849 r
.23529 .47285 m .24187 .47502 L .23222 .47286 L p F P
0 g
s
.013 .547 .849 r
.22827 .47131 m .23529 .47285 L p .23222 .47286 L F P
0 g
s
.013 .547 .849 r
.23222 .47286 m .2314 .4726 L .22827 .47131 L p F P
0 g
s
.361 .824 .913 r
.49803 .48844 m .4979 .48842 L .49661 .48869 L closepath p F P
0 g
s
.377 .83 .928 r
.49485 .48798 m .4979 .48842 L .49661 .48869 L p F P
0 g
s
.377 .83 .928 r
.48362 .49032 m .49485 .48798 L p .49661 .48869 L F P
0 g
s
.721 .22 .044 r
.27877 .35554 m .28543 .35779 L .28147 .35403 L p F P
0 g
s
.721 .22 .044 r
.27741 .35416 m .27877 .35554 L p .28147 .35403 L F P
0 g
s
.721 .22 .044 r
.28147 .35403 m .28042 .35367 L .27741 .35416 L p F P
0 g
s
.716 .235 .102 r
.29655 .36364 m .30384 .36566 L .2998 .36191 L p F P
0 g
s
.716 .235 .102 r
.29481 .36189 m .29655 .36364 L p .2998 .36191 L F P
0 g
s
.716 .235 .102 r
.2998 .36191 m .29699 .36109 L .29481 .36189 L p F P
0 g
s
0 0 0 r
.71479 .39358 m .71358 .39548 L .71955 .39001 L closepath p F P
0 g
s
0 .441 .861 r
.15666 .28415 m .16196 .28631 L .16619 .28951 L p F P
0 g
s
0 .437 .861 r
.16196 .28631 m .15666 .28415 L .15306 .28106 L p F P
0 g
s
0 .31 .745 r
.1739 .29386 m .17682 .29541 L .18125 .29852 L p F P
0 g
s
0 .332 .765 r
.1826 .29836 m .18719 .30142 L .18125 .29852 L p F P
0 g
s
0 .332 .765 r
.18125 .29852 m .17682 .29541 L .1826 .29836 L p F P
0 g
s
.656 .228 .217 r
.36145 .37927 m .36534 .38212 L .35944 .38153 L closepath p F P
0 g
s
0 0 0 r
.6796 .42125 m .6735 .4252 L .67865 .42211 L closepath p F P
0 g
s
0 0 0 r
.67706 .42329 m .67865 .42211 L .6735 .4252 L p F P
0 g
s
0 0 0 r
.6706 .42733 m .67706 .42329 L p .6735 .4252 L F P
0 g
s
0 0 0 r
.66643 .42981 m .6706 .42733 L p .6735 .4252 L F P
0 g
s
.383 .843 .798 r
.59219 .46473 m .59179 .4648 L .59796 .46242 L closepath p F P
0 g
s
.491 .074 .176 r
.45896 .37899 m .46081 .37573 L .44803 .37759 L p F P
0 g
s
.491 .074 .176 r
.45322 .3798 m .45896 .37899 L p .44803 .37759 L F P
0 g
s
.491 .074 .176 r
.44803 .37759 m .44705 .37916 L .45322 .3798 L p F P
0 g
s
0 .486 .802 r
.2314 .4726 m .22827 .47131 L .22574 .47066 L closepath p F P
0 g
s
.337 .62 .955 r
.12199 .26705 m .13137 .26838 L .13518 .27178 L p F P
0 g
s
.341 .618 .953 r
.13137 .26838 m .12199 .26705 L .11837 .2636 L p F P
0 g
s
.387 .839 .921 r
.50916 .48584 m .51016 .48595 L .49803 .48844 L p F P
0 g
s
.387 .839 .921 r
.49803 .48844 m .4979 .48842 L .50916 .48584 L p F P
0 g
s
.372 .823 .708 r
.64017 .44405 m .64077 .44383 L .63067 .44883 L p F P
0 g
s
.372 .823 .708 r
.63067 .44883 m .62875 .44956 L .64017 .44405 L p F P
0 g
s
.281 .75 .943 r
.38346 .49553 m .38364 .49558 L p .3694 .49517 L F P
0 g
s
.281 .75 .943 r
.3694 .49517 m .37247 .49502 L .38346 .49553 L p F P
0 g
s
.283 .751 .944 r
.3694 .49517 m .37247 .49502 L .36818 .49481 L closepath p F P
0 g
s
.214 .071 .46 r
.76643 .32514 m .76464 .327 L .76446 .32209 L p F P
0 g
s
.214 .071 .46 r
.76446 .32209 m .7666 .31986 L .76643 .32514 L p F P
0 g
s
.714 .192 0 r
.26197 .34712 m .26815 .34954 L .26416 .34583 L p F P
0 g
s
.714 .192 0 r
.26006 .34523 m .26197 .34712 L p .26416 .34583 L F P
0 g
s
.714 .192 0 r
.26416 .34583 m .26292 .34532 L .26006 .34523 L p F P
0 g
s
.672 .233 .198 r
.34557 .37981 m .35515 .38107 L .35049 .37745 L p F P
0 g
s
.672 .233 .198 r
.34384 .37831 m .34557 .37981 L p .35049 .37745 L F P
0 g
s
.672 .233 .198 r
.35049 .37745 m .34548 .37675 L .34384 .37831 L p F P
0 g
s
.845 .382 .052 r
.06574 .37633 m .06465 .3743 L .06881 .37744 L p F P
0 g
s
.845 .382 .052 r
.06881 .37744 m .06954 .37879 L .06574 .37633 L p F P
0 g
s
.69 .176 .004 r
.28042 .35367 m .27741 .35416 L .27466 .35184 L closepath p F P
0 g
s
.399 .853 .889 r
.54907 .4771 m .55041 .47712 L .53897 .48039 L p F P
0 g
s
.399 .853 .889 r
.53897 .48039 m .53773 .48038 L .54907 .4771 L p F P
0 g
s
.316 0 .061 r
.51045 .36122 m .51235 .35815 L .50093 .36157 L p F P
0 g
s
.316 0 .061 r
.50093 .36157 m .49899 .36463 L .51045 .36122 L p F P
0 g
s
.453 .435 .748 r
.76546 .2801 m .76742 .28091 L .76622 .28236 L closepath p F P
0 g
s
.423 .391 .719 r
.77307 .28429 m .76842 .28986 L .76622 .28236 L p F P
0 g
s
.423 .391 .719 r
.76622 .28236 m .76742 .28091 L .77307 .28429 L p F P
0 g
s
.439 .442 .765 r
.76321 .27383 m .76546 .2801 L .76742 .28091 L p F P
0 g
s
.409 .847 .937 r
.50916 .48584 m .4979 .48842 L .49485 .48798 L p F P
0 g
s
.315 .788 .69 r
.61734 .45477 m .61325 .45653 L .617 .4549 L closepath p F P
0 g
s
.363 .827 .751 r
.61459 .45555 m .617 .4549 L .61325 .45653 L p F P
0 g
s
.363 .827 .751 r
.60318 .46036 m .61459 .45555 L p .61325 .45653 L F P
0 g
s
.007 0 .109 r
.74529 .36299 m .73926 .36814 L .74387 .36146 L p F P
0 g
s
.007 0 .109 r
.74387 .36146 m .74626 .35942 L .74529 .36299 L p F P
0 g
s
.691 .979 .893 r
.64562 .2801 m .64832 .28038 L .63696 .28739 L p F P
0 g
s
.691 .979 .893 r
.6397 .28392 m .64562 .2801 L p .63696 .28739 L F P
0 g
s
.691 .979 .893 r
.63696 .28739 m .63559 .28741 L .6397 .28392 L p F P
0 g
s
.705 .24 .146 r
.31559 .37132 m .32374 .37305 L .31949 .36933 L p F P
0 g
s
.705 .24 .146 r
.31228 .36807 m .31559 .37132 L p .31949 .36933 L F P
0 g
s
.705 .24 .146 r
.31949 .36933 m .3128 .36777 L .31228 .36807 L p F P
0 g
s
.409 .355 .687 r
.7682 .2901 m .76842 .28986 L .76856 .29039 L closepath p F P
0 g
s
0 0 0 r
.56061 .33372 m .56156 .33276 L .55128 .33762 L p F P
0 g
s
0 0 0 r
.55128 .33762 m .54928 .33979 L .56061 .33372 L p F P
0 g
s
.228 .699 .942 r
.31999 .48992 m .30921 .48949 L .30579 .48824 L p F P
0 g
s
0 .305 .747 r
.17682 .29541 m .1739 .29386 L .17031 .29104 L p F P
0 g
s
.452 .039 .164 r
.46138 .37477 m .46648 .37468 L .46081 .37573 L closepath p F P
0 g
s
.54 0 0 r
.12368 .42435 m .12037 .42183 L .12523 .42465 L p F P
0 g
s
.54 0 0 r
.12523 .42465 m .12741 .4263 L .12368 .42435 L p F P
0 g
s
.737 .953 .946 r
.6617 .27413 m .6597 .27347 L .66684 .26922 L closepath p F P
0 g
s
.439 .847 .667 r
.6073 .30467 m .60021 .30911 L .59852 .30999 L p F P
0 g
s
.694 .243 .176 r
.3298 .37252 m .33224 .37466 L .32803 .37385 L closepath p F P
0 g
s
.668 .127 0 r
.26292 .34532 m .26006 .34523 L .25786 .34345 L closepath p F P
0 g
s
.356 .32 .681 r
.77723 .28816 m .77307 .28429 L .76842 .28986 L p F P
0 g
s
.356 .32 .681 r
.7722 .29402 m .77723 .28816 L p .76842 .28986 L F P
0 g
s
.356 .32 .681 r
.76842 .28986 m .76856 .29039 L .7722 .29402 L p F P
0 g
s
.663 .117 0 r
.10187 .40954 m .10645 .41248 L .10265 .40868 L p F P
0 g
s
.663 .117 0 r
.10265 .40868 m .09806 .40574 L .10187 .40954 L p F P
0 g
s
.689 .146 0 r
.24597 .33843 m .25177 .34099 L .24763 .33735 L p F P
0 g
s
.689 .146 0 r
.24277 .33542 m .24597 .33843 L p .24763 .33735 L F P
0 g
s
.689 .146 0 r
.24763 .33735 m .24412 .33571 L .24277 .33542 L p F P
0 g
s
.601 .657 .877 r
.74226 .2557 m .74592 .25511 L .74371 .25812 L closepath p F P
0 g
s
.571 .636 .876 r
.75407 .25398 m .74592 .25511 L .74371 .25812 L p F P
0 g
s
.571 .636 .876 r
.75684 .25933 m .75407 .25398 L p .74371 .25812 L F P
0 g
s
.696 .206 .078 r
.29699 .36109 m .29481 .36189 L .2925 .35989 L closepath p F P
0 g
s
.34 .786 .958 r
.41067 .49565 m .39825 .49577 L .39791 .49568 L p F P
0 g
s
.313 .771 .95 r
.39825 .49577 m .39791 .49568 L .39688 .49576 L closepath p F P
0 g
s
.353 0 0 r
.20472 .31253 m .20158 .31067 L .20656 .31355 L p F P
0 g
s
.379 .324 .67 r
.76856 .29039 m .7722 .29402 L .77002 .29656 L closepath p F P
0 g
s
.299 .764 .944 r
.38364 .49558 m .38416 .49555 L .39688 .49576 L p F P
0 g
s
.307 .766 .949 r
.38364 .49558 m .38416 .49555 L .38346 .49553 L closepath p F P
0 g
s
.336 .777 .963 r
.39465 .49462 m .38416 .49555 L .39688 .49576 L p F P
0 g
s
.336 .777 .963 r
.39688 .49576 m .39791 .49568 L .39465 .49462 L p F P
0 g
s
0 0 0 r
.56744 .3286 m .56346 .33085 L .56156 .33276 L p F P
0 g
s
.397 .853 .812 r
.59796 .46242 m .59179 .4648 L .58897 .46529 L p F P
0 g
s
.37 .837 .803 r
.57758 .46943 m .58897 .46529 L .59179 .4648 L p F P
0 g
s
0 0 0 r
.68818 .41545 m .6796 .42125 L .67865 .42211 L p F P
0 g
s
.277 0 0 r
.17935 .45355 m .17956 .45364 L .18539 .45608 L p F P
0 g
s
0 .364 .71 r
.18694 .45643 m .19267 .45891 L .18539 .45608 L p F P
0 g
s
0 .364 .71 r
.18539 .45608 m .17956 .45364 L .18694 .45643 L p F P
0 g
s
.195 .679 .928 r
.30236 .48693 m .30579 .48824 L .29845 .48775 L p F P
0 g
s
.195 .679 .928 r
.29162 .48628 m .30236 .48693 L p .29845 .48775 L F P
0 g
s
.195 .679 .928 r
.29845 .48775 m .29271 .48669 L .29162 .48628 L p F P
0 g
s
.492 .494 .787 r
.76252 .27205 m .76432 .27245 L .76321 .27383 L closepath p F P
0 g
s
.439 .442 .765 r
.7722 .27509 m .76432 .27245 L .76321 .27383 L p F P
0 g
s
.439 .442 .765 r
.76742 .28091 m .7722 .27509 L p .76321 .27383 L F P
0 g
s
.833 .361 .035 r
.06954 .37879 m .07119 .38164 L .07546 .38473 L p F P
0 g
s
.798 .304 0 r
.07394 .38573 m .0782 .38882 L .07546 .38473 L p F P
0 g
s
.798 .304 0 r
.07546 .38473 m .07119 .38164 L .07394 .38573 L p F P
0 g
s
.34 .786 .958 r
.40895 .49449 m .41218 .4955 L .41067 .49565 L p F P
0 g
s
.34 .786 .958 r
.39791 .49568 m .40895 .49449 L p .41067 .49565 L F P
0 g
s
.33 .783 .952 r
.41262 .49562 m .41218 .4955 L .41067 .49565 L closepath p F P
0 g
s
.381 .832 .929 r
.49485 .48798 m .48362 .49032 L .48054 .48983 L p F P
0 g
s
.368 .823 .932 r
.46933 .49194 m .48054 .48983 L .48362 .49032 L p F P
0 g
s
.354 .797 .958 r
.42577 .49513 m .41262 .49562 L .41218 .4955 L p F P
0 g
s
0 .328 .689 r
.16853 .44853 m .174 .45111 L .16743 .44808 L p F P
0 g
s
0 .328 .689 r
.16195 .44556 m .16853 .44853 L p .16743 .44808 L F P
0 g
s
.326 0 0 r
.16206 .44561 m .16195 .44556 L .16189 .44553 L closepath p F P
0 g
s
0 .328 .689 r
.16743 .44808 m .16206 .44561 L .16195 .44556 L p F P
0 g
s
.344 .793 .646 r
.65095 .43858 m .64284 .44281 L .64077 .44383 L p F P
0 g
s
.673 .234 .199 r
.34548 .37675 m .34384 .37831 L .34113 .37613 L closepath p F P
0 g
s
.355 .784 .97 r
.39139 .49349 m .39465 .49462 L .38416 .49555 L p F P
0 g
s
.355 .784 .97 r
.38036 .49449 m .39139 .49349 L p .38416 .49555 L F P
0 g
s
.355 .784 .97 r
.38416 .49555 m .38346 .49553 L .38036 .49449 L p F P
0 g
s
.381 .845 .856 r
.56165 .47358 m .56334 .47348 L .55199 .47702 L p F P
0 g
s
.381 .845 .856 r
.55199 .47702 m .55041 .47712 L .56165 .47358 L p F P
0 g
s
.326 .769 .963 r
.38346 .49553 m .38036 .49449 L .37247 .49502 L closepath p F P
0 g
s
.035 .471 .88 r
.16671 .28812 m .16196 .28631 L .16619 .28951 L p F P
0 g
s
.035 .471 .88 r
.16619 .28951 m .17031 .29104 L .16671 .28812 L p F P
0 g
s
.64 .086 0 r
.11035 .4146 m .11118 .41536 L .10718 .41293 L closepath p F P
0 g
s
.4 0 .109 r
.48723 .36765 m .48689 .36818 L .48258 .36866 L closepath p F P
0 g
s
.407 0 .13 r
.48537 .37084 m .48689 .36818 L .48258 .36866 L p F P
0 g
s
.407 0 .13 r
.47325 .37347 m .48537 .37084 L p .48258 .36866 L F P
0 g
s
.508 .517 .801 r
.76432 .27245 m .76252 .27205 L .75965 .26527 L p F P
0 g
s
0 .457 .776 r
.21431 .46701 m .21937 .46843 L .22574 .47066 L p F P
0 g
s
0 .466 .787 r
.21937 .46843 m .21431 .46701 L .21072 .46553 L p F P
0 g
s
.643 .693 .882 r
.72787 .25471 m .73954 .25147 L .74226 .2557 L p F P
0 g
s
.658 .718 .893 r
.73954 .25147 m .72787 .25471 L .72517 .25125 L p F P
0 g
s
.679 .753 .907 r
.71358 .25557 m .72517 .25125 L .72787 .25471 L p F P
0 g
s
.692 .775 .915 r
.72517 .25125 m .71358 .25557 L .7109 .25276 L p F P
0 g
s
.375 .797 .974 r
.40895 .49449 m .39791 .49568 L .39465 .49462 L p F P
0 g
s
0 .423 .755 r
.2068 .46388 m .19866 .46129 L .20476 .46362 L p F P
0 g
s
0 .423 .755 r
.20757 .46418 m .2068 .46388 L p .20476 .46362 L F P
0 g
s
0 .423 .755 r
.20476 .46362 m .21072 .46553 L .20757 .46418 L p F P
0 g
s
0 .384 .715 r
.19682 .46065 m .19866 .46129 L .20476 .46362 L p F P
0 g
s
.126 0 .326 r
.76366 .33649 m .75735 .34263 L .75921 .33681 L p F P
0 g
s
.126 0 .326 r
.76437 .33425 m .76366 .33649 L p .75921 .33681 L F P
0 g
s
.126 0 .326 r
.75921 .33681 m .76457 .3316 L .76437 .33425 L p F P
0 g
s
0 .187 .621 r
.19111 .30404 m .19176 .30447 L .18856 .30228 L closepath p F P
0 g
s
.382 .828 .941 r
.47939 .48961 m .48054 .48983 L .46933 .49194 L p F P
0 g
s
.382 .828 .941 r
.46933 .49194 m .46665 .49146 L .47939 .48961 L p F P
0 g
s
.347 .81 .928 r
.46665 .49146 m .46933 .49194 L p .45504 .49327 L F P
0 g
s
.06 0 0 r
.53848 .34464 m .53797 .34523 L .54516 .34175 L closepath p F P
0 g
s
.348 .809 .703 r
.62726 .45011 m .62875 .44956 L .61734 .45477 L p F P
0 g
s
.348 .809 .703 r
.61734 .45477 m .617 .4549 L .62726 .45011 L p F P
0 g
s
.367 0 0 r
.15137 .44022 m .1566 .44289 L .15072 .43967 L p F P
0 g
s
.367 0 0 r
.15072 .43967 m .14545 .43702 L .15137 .44022 L p F P
0 g
s
.438 0 0 r
.14462 .43653 m .14545 .43702 L .15072 .43967 L p F P
0 g
s
.833 .361 .024 r
.07119 .38164 m .06954 .37879 L .06574 .37633 L p F P
0 g
s
.344 .794 .952 r
.42664 .4951 m .42646 .49505 L .42577 .49513 L closepath p F P
0 g
s
.354 .797 .958 r
.42326 .4941 m .42646 .49505 L .42577 .49513 L p F P
0 g
s
.354 .797 .958 r
.41218 .4955 m .42326 .4941 L p .42577 .49513 L F P
0 g
s
.375 .811 .959 r
.43758 .49345 m .44028 .49421 L .42664 .4951 L p F P
0 g
s
.375 .811 .959 r
.42664 .4951 m .42646 .49505 L .43758 .49345 L p F P
0 g
s
.729 .927 .957 r
.68166 .26365 m .67379 .26794 L .67111 .26667 L p F P
0 g
s
.635 .074 0 r
.22553 .32509 m .22647 .32589 L .23175 .32865 L p F P
0 g
s
.64 .08 0 r
.23066 .32949 m .23616 .33217 L .23175 .32865 L p F P
0 g
s
.64 .08 0 r
.23175 .32865 m .22647 .32589 L .23066 .32949 L p F P
0 g
s
.542 .559 .821 r
.75742 .2652 m .75886 .26352 L .75965 .26527 L closepath p F P
0 g
s
0 0 0 r
.57477 .32451 m .56744 .3286 L .57395 .32525 L closepath p F P
0 g
s
0 0 0 r
.57195 .32706 m .57395 .32525 L .56744 .3286 L p F P
0 g
s
0 0 0 r
.56837 .32914 m .57195 .32706 L p .56744 .3286 L F P
0 g
s
0 0 0 r
.56156 .33276 m .56837 .32914 L p .56744 .3286 L F P
0 g
s
.389 .807 .974 r
.42326 .4941 m .41218 .4955 L .40895 .49449 L p F P
0 g
s
.334 .771 .967 r
.37707 .49331 m .38036 .49449 L .37247 .49502 L p F P
0 g
s
.334 .771 .967 r
.36609 .4941 m .37707 .49331 L p .37247 .49502 L F P
0 g
s
.334 .771 .967 r
.37247 .49502 m .36818 .49481 L .36609 .4941 L p F P
0 g
s
.672 .236 .206 r
.3364 .37842 m .33224 .37466 L .34113 .37613 L p F P
0 g
s
.672 .236 .206 r
.34274 .37939 m .3364 .37842 L p .34113 .37613 L F P
0 g
s
.672 .236 .206 r
.34113 .37613 m .34384 .37831 L .34274 .37939 L p F P
0 g
s
.347 .81 .928 r
.45504 .49327 m .4635 .49185 L .46665 .49146 L p F P
0 g
s
.372 .818 .946 r
.45504 .49327 m .4635 .49185 L .4536 .49298 L closepath p F P
0 g
s
.344 .804 .936 r
.4536 .49298 m .45504 .49327 L p .44075 .49431 L F P
0 g
s
0 0 .026 r
.74486 .36421 m .74529 .36299 L .73926 .36814 L p F P
0 g
s
0 0 .026 r
.74146 .3686 m .74486 .36421 L p .73926 .36814 L F P
0 g
s
0 0 .026 r
.7355 .37369 m .74146 .3686 L p .73926 .36814 L F P
0 g
s
0 0 .026 r
.73926 .36814 m .73594 .3724 L .7355 .37369 L p F P
0 g
s
.113 .626 .892 r
.27749 .48385 m .28243 .48439 L .29022 .48614 L p F P
0 g
s
.128 .636 .9 r
.28243 .48439 m .27749 .48385 L .274 .48258 L p F P
0 g
s
.766 .257 0 r
.08121 .39284 m .08554 .3959 L .08253 .39188 L p F P
0 g
s
.766 .257 0 r
.08253 .39188 m .0782 .38882 L .08121 .39284 L p F P
0 g
s
.434 .409 .731 r
.77604 .28076 m .77307 .28429 L .76742 .28091 L p F P
0 g
s
.434 .409 .731 r
.77479 .27643 m .77604 .28076 L p .76742 .28091 L F P
0 g
s
.434 .409 .731 r
.76742 .28091 m .7722 .27509 L .77479 .27643 L p F P
0 g
s
.004 .546 .837 r
.24584 .47647 m .24887 .47705 L .25594 .47904 L p F P
0 g
s
.049 .575 .866 r
.25638 .4783 m .24887 .47705 L .25594 .47904 L p F P
0 g
s
.049 .575 .866 r
.25594 .47904 m .25989 .47972 L .25638 .4783 L p F P
0 g
s
.508 .898 .742 r
.61154 .30203 m .6073 .30467 L .61077 .30233 L closepath p F P
0 g
s
.439 .847 .667 r
.60879 .30313 m .61077 .30233 L .6073 .30467 L p F P
0 g
s
.439 .847 .667 r
.60316 .30681 m .60879 .30313 L p .6073 .30467 L F P
0 g
s
.439 .847 .667 r
.59852 .30999 m .60316 .30681 L p .6073 .30467 L F P
0 g
s
.402 .817 .974 r
.43758 .49345 m .42646 .49505 L .42326 .4941 L p F P
0 g
s
.232 .708 .937 r
.336 .49189 m .3376 .49243 L p .32339 .4911 L F P
0 g
s
.232 .708 .937 r
.32339 .4911 m .33112 .49122 L .336 .49189 L p F P
0 g
s
.257 .72 .949 r
.33112 .49122 m .32339 .4911 L .31999 .48992 L p F P
0 g
s
0 0 0 r
.72533 .38388 m .72482 .38484 L .72722 .38238 L closepath p F P
0 g
s
.344 .804 .936 r
.44075 .49431 m .44305 .49397 L .4536 .49298 L p F P
0 g
s
.365 .81 .95 r
.44075 .49431 m .44305 .49397 L .44028 .49421 L closepath p F P
0 g
s
.302 .753 .958 r
.36818 .49481 m .36609 .4941 L .36137 .49431 L closepath p F P
0 g
s
.335 .263 .625 r
.77497 .29834 m .7712 .30272 L .77002 .29656 L p F P
0 g
s
.335 .263 .625 r
.77002 .29656 m .7722 .29402 L .77497 .29834 L p F P
0 g
s
0 0 0 r
.69095 .41347 m .68818 .41545 L .69049 .41398 L closepath p F P
0 g
s
0 0 0 r
.68846 .41578 m .69049 .41398 L .68818 .41545 L p F P
0 g
s
0 0 0 r
.68633 .41725 m .68846 .41578 L p .68818 .41545 L F P
0 g
s
0 0 0 r
.67865 .42211 m .68633 .41725 L p .68818 .41545 L F P
0 g
s
.402 0 0 r
.19213 .30468 m .19678 .30771 L .19176 .30447 L p F P
0 g
s
.402 0 0 r
.19176 .30447 m .18856 .30228 L .18752 .30157 L p F P
0 g
s
.402 0 0 r
.18752 .30157 m .19213 .30468 L p .19176 .30447 L F P
0 g
s
.007 .548 .84 r
.24584 .47647 m .24887 .47705 L .24276 .4753 L closepath p F P
0 g
s
.696 .205 .075 r
.28943 .36155 m .28543 .35779 L .2925 .35989 L p F P
0 g
s
.696 .205 .075 r
.29297 .36254 m .28943 .36155 L p .2925 .35989 L F P
0 g
s
.696 .205 .075 r
.2925 .35989 m .29481 .36189 L .29297 .36254 L p F P
0 g
s
.535 0 0 r
.11086 .4161 m .11558 .41898 L .11118 .41536 L p F P
0 g
s
.535 0 0 r
.10659 .4126 m .11086 .4161 L p .11118 .41536 L F P
0 g
s
.535 0 0 r
.11118 .41536 m .10718 .41293 L .10659 .4126 L p F P
0 g
s
.459 .052 .179 r
.46648 .37468 m .46081 .37573 L .45896 .37899 L p F P
0 g
s
.136 .641 .903 r
.29271 .48669 m .29162 .48628 L .29022 .48614 L closepath p F P
0 g
s
.603 .193 .238 r
.40514 .38361 m .40409 .38521 L .40095 .38362 L closepath p F P
0 g
s
.605 .189 .226 r
.4031 .38684 m .40409 .38521 L .40095 .38362 L p F P
0 g
s
.605 .189 .226 r
.39372 .38679 m .4031 .38684 L p .40095 .38362 L F P
0 g
s
.605 .189 .226 r
.38982 .38451 m .39372 .38679 L p .40095 .38362 L F P
0 g
s
.605 .189 .226 r
.40095 .38362 m .39051 .38353 L .38982 .38451 L p F P
0 g
s
.692 .223 .133 r
.3128 .36777 m .31228 .36807 L .31163 .36751 L closepath p F P
0 g
s
.58 .167 .224 r
.4154 .3833 m .40514 .38361 L .40409 .38521 L p F P
0 g
s
.212 .564 .937 r
.14946 .27789 m .14697 .27725 L .15099 .28055 L p F P
0 g
s
.212 .564 .937 r
.15099 .28055 m .15306 .28106 L .14946 .27789 L p F P
0 g
s
.073 0 .254 r
.75601 .34392 m .75566 .3465 L .75735 .34263 L closepath p F P
0 g
s
.404 .851 .77 r
.62602 .45044 m .62726 .45011 L .617 .4549 L p F P
0 g
s
.404 .851 .77 r
.617 .4549 m .61459 .45555 L .62602 .45044 L p F P
0 g
s
.69 .172 0 r
.27221 .35326 m .26815 .34954 L .27466 .35184 L p F P
0 g
s
.69 .172 0 r
.27565 .3544 m .27221 .35326 L p .27466 .35184 L F P
0 g
s
.69 .172 0 r
.27466 .35184 m .27741 .35416 L .27565 .3544 L p F P
0 g
s
.624 .21 .237 r
.39051 .38353 m .38982 .38451 L .38805 .38345 L closepath p F P
0 g
s
.707 .854 .952 r
.7059 .25502 m .69938 .25796 L .69671 .25578 L p F P
0 g
s
.733 .86 .94 r
.68523 .2617 m .69671 .25578 L .69938 .25796 L p F P
0 g
s
.361 0 .088 r
.49814 .36602 m .49899 .36463 L .48723 .36765 L p F P
0 g
s
.361 0 .088 r
.48723 .36765 m .48689 .36818 L .49814 .36602 L p F P
0 g
s
.635 .214 .226 r
.37561 .38246 m .3763 .38291 L .3753 .38285 L closepath p F P
0 g
s
.311 .212 .577 r
.772 .3084 m .77157 .30887 L .76979 .30422 L p F P
0 g
s
.311 .212 .577 r
.76979 .30422 m .7712 .30272 L .772 .3084 L p F P
0 g
s
0 .491 .811 r
.2247 .46979 m .21937 .46843 L .22574 .47066 L p F P
0 g
s
0 .491 .811 r
.22574 .47066 m .22827 .47131 L .2247 .46979 L p F P
0 g
s
.616 .673 .882 r
.74592 .25511 m .74226 .2557 L .73954 .25147 L p F P
0 g
s
0 0 0 r
.70039 .40644 m .69095 .41347 L .69049 .41398 L p F P
0 g
s
.622 .216 .252 r
.38142 .38642 m .3763 .38291 L .38805 .38345 L p F P
0 g
s
.622 .216 .252 r
.38838 .38669 m .38142 .38642 L p .38805 .38345 L F P
0 g
s
.622 .216 .252 r
.38805 .38345 m .38982 .38451 L .38838 .38669 L p F P
0 g
s
.724 .968 .936 r
.64834 .28038 m .64832 .28038 L .64839 .28033 L closepath p F P
0 g
s
.508 .517 .801 r
.75965 .26527 m .76892 .26666 L .76432 .27245 L p F P
0 g
s
.481 .479 .778 r
.77378 .27318 m .7722 .27509 L .76432 .27245 L p F P
0 g
s
.481 .479 .778 r
.77177 .26741 m .77378 .27318 L p .76432 .27245 L F P
0 g
s
.481 .479 .778 r
.76432 .27245 m .76892 .26666 L .77177 .26741 L p F P
0 g
s
.701 .974 .922 r
.64839 .28033 m .64832 .28038 L .64562 .2801 L p F P
0 g
s
.722 .978 .918 r
.64839 .28033 m .6597 .27347 L .65701 .27278 L p F P
0 g
s
.722 .978 .918 r
.65701 .27278 m .6558 .27356 L .64839 .28033 L p F P
0 g
s
.701 .974 .922 r
.64562 .2801 m .6558 .27356 L .64839 .28033 L p F P
0 g
s
0 0 .037 r
.73594 .3724 m .73375 .3751 L .7355 .37369 L closepath p F P
0 g
s
.692 .224 .134 r
.30791 .36943 m .30384 .36566 L .31163 .36751 L p F P
0 g
s
.692 .224 .134 r
.30936 .36976 m .30791 .36943 L p .31163 .36751 L F P
0 g
s
.692 .224 .134 r
.31163 .36751 m .31228 .36807 L .30936 .36976 L p F P
0 g
s
.547 0 0 r
.20831 .31455 m .21139 .31689 L .21642 .31975 L p F P
0 g
s
.55 0 0 r
.21139 .31689 m .20831 .31455 L .20472 .31253 L p F P
0 g
s
.941 .612 .381 r
.04294 .34347 m .0429 .34311 L .03913 .33996 L p F P
0 g
s
.509 0 0 r
.12741 .4263 m .13006 .42816 L .13509 .43091 L p F P
0 g
s
.454 0 0 r
.13532 .43155 m .14031 .43431 L .13509 .43091 L p F P
0 g
s
.454 0 0 r
.13509 .43091 m .13006 .42816 L .13532 .43155 L p F P
0 g
s
.75 .232 0 r
.08975 .39866 m .08996 .39892 L .08858 .39799 L closepath p F P
0 g
s
.311 .757 .962 r
.36277 .49288 m .36609 .4941 L .36137 .49431 L p F P
0 g
s
.311 .757 .962 r
.35183 .49344 m .36277 .49288 L p .36137 .49431 L F P
0 g
s
.311 .757 .962 r
.36137 .49431 m .35241 .49364 L .35183 .49344 L p F P
0 g
s
.581 .173 .234 r
.41924 .38316 m .41839 .38452 L .4154 .3833 L closepath p F P
0 g
s
.58 .167 .224 r
.4173 .38644 m .41839 .38452 L .4154 .3833 L p F P
0 g
s
.58 .167 .224 r
.40732 .38674 m .4173 .38644 L p .4154 .3833 L F P
0 g
s
.58 .167 .224 r
.40409 .38521 m .40732 .38674 L p .4154 .3833 L F P
0 g
s
.412 .859 .9 r
.54907 .4771 m .53773 .48038 L .53477 .48028 L p F P
0 g
s
.385 .844 .893 r
.52345 .4833 m .53477 .48028 L .53773 .48038 L p F P
0 g
s
.21 .067 .457 r
.77214 .31914 m .76643 .32514 L .7666 .31986 L p F P
0 g
s
.21 .067 .457 r
.7666 .31986 m .77232 .31385 L .77214 .31914 L p F P
0 g
s
.618 .051 0 r
.24412 .33571 m .24277 .33542 L .2419 .33476 L closepath p F P
0 g
s
.553 .919 .751 r
.62015 .2955 m .62288 .29477 L .61154 .30203 L p F P
0 g
s
.553 .919 .751 r
.61821 .2968 m .62015 .2955 L p .61154 .30203 L F P
0 g
s
.553 .919 .751 r
.61154 .30203 m .61077 .30233 L .61821 .2968 L p F P
0 g
s
0 .391 .725 r
.19682 .46065 m .19866 .46129 L .19404 .45948 L closepath p F P
0 g
s
.174 0 0 r
.53505 .34915 m .53637 .34736 L .52553 .35152 L p F P
0 g
s
.174 0 0 r
.52553 .35152 m .52373 .35399 L .53505 .34915 L p F P
0 g
s
0 0 .096 r
.74672 .3617 m .74529 .36299 L .74626 .35942 L p F P
0 g
s
0 0 .096 r
.74626 .35942 m .75103 .3551 L .74672 .3617 L p F P
0 g
s
.405 .824 .97 r
.44305 .49397 m .44028 .49421 L .43758 .49345 L p F P
0 g
s
.533 0 0 r
.21601 .32031 m .22124 .32311 L .21642 .31975 L p F P
0 g
s
.533 0 0 r
.21642 .31975 m .21139 .31689 L .21601 .32031 L p F P
0 g
s
.552 .142 .218 r
.43211 .38224 m .41924 .38316 L .41839 .38452 L p F P
0 g
s
.498 .093 .204 r
.44705 .37916 m .45322 .3798 L .44612 .38082 L closepath p F P
0 g
s
.35 .82 .757 r
.60318 .46036 m .59796 .46242 L .60283 .46045 L closepath p F P
0 g
s
.397 .853 .812 r
.60038 .46085 m .60283 .46045 L .59796 .46242 L p F P
0 g
s
.397 .853 .812 r
.58897 .46529 m .60038 .46085 L p .59796 .46242 L F P
0 g
s
.941 .612 .381 r
.03913 .33996 m .03915 .34013 L .04294 .34347 L p F P
0 g
s
.932 .57 .305 r
.04009 .34476 m .04388 .34809 L .04294 .34347 L p F P
0 g
s
.932 .57 .305 r
.04294 .34347 m .03915 .34013 L .04009 .34476 L p F P
0 g
s
.917 .528 .242 r
.04518 .35261 m .04905 .3559 L .04775 .35139 L p F P
0 g
s
.917 .528 .242 r
.04775 .35139 m .04388 .34809 L .04518 .35261 L p F P
0 g
s
.665 .12 0 r
.256 .34462 m .25177 .34099 L .25786 .34345 L p F P
0 g
s
.665 .12 0 r
.25708 .34504 m .256 .34462 L p .25786 .34345 L F P
0 g
s
.665 .12 0 r
.25786 .34345 m .26006 .34523 L .25708 .34504 L p F P
0 g
s
0 0 0 r
.65424 .4368 m .65095 .43858 L .65382 .43706 L closepath p F P
0 g
s
.344 .793 .646 r
.6516 .43811 m .65382 .43706 L .65095 .43858 L p F P
0 g
s
.344 .793 .646 r
.64475 .44172 m .6516 .43811 L p .65095 .43858 L F P
0 g
s
.344 .793 .646 r
.64077 .44383 m .64475 .44172 L p .65095 .43858 L F P
0 g
s
.117 0 0 r
.54516 .34175 m .53797 .34523 L .53637 .34736 L p F P
0 g
s
.151 .647 .914 r
.28816 .4849 m .28243 .48439 L .29022 .48614 L p F P
0 g
s
.151 .647 .914 r
.29022 .48614 m .29162 .48628 L .28816 .4849 L p F P
0 g
s
.662 .119 0 r
.08909 .39976 m .09354 .40277 L .08996 .39892 L p F P
0 g
s
.662 .119 0 r
.08597 .3964 m .08909 .39976 L p .08996 .39892 L F P
0 g
s
.662 .119 0 r
.08996 .39892 m .08858 .39799 L .08597 .3964 L p F P
0 g
s
0 0 0 r
.73412 .37682 m .72722 .38238 L .73375 .3751 L p F P
0 g
s
0 0 0 r
.73375 .3751 m .7355 .37369 L .73412 .37682 L p F P
0 g
s
.497 .534 .825 r
.75886 .26352 m .75965 .26527 L .76892 .26666 L p F P
0 g
s
.502 0 0 r
.13006 .42816 m .12741 .4263 L .12368 .42435 L p F P
0 g
s
.394 .822 .963 r
.4536 .49298 m .4519 .49254 L .44305 .49397 L closepath p F P
0 g
s
.405 .824 .97 r
.44874 .49162 m .4519 .49254 L .44305 .49397 L p F P
0 g
s
.405 .824 .97 r
.43758 .49345 m .44874 .49162 L p .44305 .49397 L F P
0 g
s
.898 .483 .179 r
.05067 .36032 m .05461 .36357 L .05299 .35916 L p F P
0 g
s
.898 .483 .179 r
.05299 .35916 m .04905 .3559 L .05067 .36032 L p F P
0 g
s
.642 .228 .244 r
.37305 .38593 m .38142 .38642 L .3763 .38291 L p F P
0 g
s
.642 .228 .244 r
.3763 .38291 m .3753 .38285 L .37305 .38593 L p F P
0 g
s
.415 .853 .929 r
.52046 .48302 m .52208 .48322 L .51016 .48595 L p F P
0 g
s
.415 .853 .929 r
.51016 .48595 m .50916 .48584 L .52046 .48302 L p F P
0 g
s
.654 .242 .252 r
.37014 .38571 m .37305 .38593 L .3753 .38285 L p F P
0 g
s
.654 .242 .252 r
.3753 .38285 m .36534 .38212 L .37014 .38571 L p F P
0 g
s
.383 .845 .816 r
.58808 .46542 m .58897 .46529 L .57758 .46943 L p F P
0 g
s
.383 .845 .816 r
.57758 .46943 m .57726 .46948 L .58808 .46542 L p F P
0 g
s
.261 .729 .946 r
.3376 .49243 m .34073 .4924 L .35068 .49347 L p F P
0 g
s
.26 .728 .945 r
.3376 .49243 m .34073 .4924 L .336 .49189 L closepath p F P
0 g
s
.356 .63 .957 r
.13214 .26848 m .13137 .26838 L .13518 .27178 L p F P
0 g
s
.356 .63 .957 r
.13518 .27178 m .13576 .27185 L .13214 .26848 L p F P
0 g
s
.717 .259 .161 r
.31228 .36807 m .31559 .37132 L .30936 .36976 L closepath p F P
0 g
s
0 0 0 r
.58367 .31962 m .5861 .3177 L .57477 .32451 L p F P
0 g
s
0 0 0 r
.57477 .32451 m .57395 .32525 L .58367 .31962 L p F P
0 g
s
.383 0 .131 r
.49715 .3678 m .49814 .36602 L .48689 .36818 L p F P
0 g
s
.383 0 .131 r
.48689 .36818 m .48537 .37084 L .49715 .3678 L p F P
0 g
s
.876 .437 .117 r
.05655 .3679 m .06056 .37112 L .05863 .36679 L p F P
0 g
s
.876 .437 .117 r
.05863 .36679 m .05461 .36357 L .05655 .3679 L p F P
0 g
s
0 .305 .747 r
.17031 .29104 m .17252 .29225 L .17682 .29541 L p F P
0 g
s
0 .321 .761 r
.17816 .29524 m .1826 .29836 L .17682 .29541 L p F P
0 g
s
0 .321 .761 r
.17682 .29541 m .17252 .29225 L .17816 .29524 L p F P
0 g
s
0 0 0 r
.69984 .40763 m .70195 .40539 L .70039 .40644 L p F P
0 g
s
0 0 0 r
.69942 .40795 m .69984 .40763 L p .70039 .40644 L F P
0 g
s
0 0 0 r
.69049 .41398 m .69942 .40795 L p .70039 .40644 L F P
0 g
s
0 0 0 r
.70229 .40494 m .70039 .40644 L .70195 .40539 L closepath p F P
0 g
s
.457 .044 .167 r
.47325 .37347 m .47255 .37467 L .46648 .37468 L closepath p F P
0 g
s
.459 .052 .179 r
.47145 .37677 m .47255 .37467 L .46648 .37468 L p F P
0 g
s
.459 .052 .179 r
.45896 .37899 m .47145 .37677 L p .46648 .37468 L F P
0 g
s
.729 .927 .957 r
.68255 .26009 m .68411 .26102 L .68166 .26365 L p F P
0 g
s
.729 .927 .957 r
.67111 .26667 m .68255 .26009 L p .68166 .26365 L F P
0 g
s
.739 .903 .952 r
.68523 .2617 m .68166 .26365 L .68411 .26102 L closepath p F P
0 g
s
.274 .735 .95 r
.35241 .49364 m .35183 .49344 L .35068 .49347 L closepath p F P
0 g
s
.7 .256 .193 r
.32781 .37684 m .3364 .37842 L .33224 .37466 L p F P
0 g
s
.7 .256 .193 r
.32624 .37528 m .32781 .37684 L p .33224 .37466 L F P
0 g
s
.7 .256 .193 r
.33224 .37466 m .32803 .37385 L .32624 .37528 L p F P
0 g
s
.689 .979 .891 r
.63559 .28741 m .63424 .28745 L .6397 .28392 L closepath p F P
0 g
s
0 0 0 r
.71071 .398 m .70229 .40494 L .70195 .40539 L p F P
0 g
s
.158 0 .393 r
.76546 .33068 m .76457 .3316 L .76464 .327 L p F P
0 g
s
.158 0 .393 r
.76464 .327 m .76643 .32514 L .76546 .33068 L p F P
0 g
s
.542 .571 .834 r
.75684 .25933 m .76189 .25944 L .75886 .26352 L closepath p F P
0 g
s
.497 .534 .825 r
.76886 .26004 m .76189 .25944 L .75886 .26352 L p F P
0 g
s
.497 .534 .825 r
.77067 .26449 m .76886 .26004 L p .75886 .26352 L F P
0 g
s
.497 .534 .825 r
.76892 .26666 m .77067 .26449 L p .75886 .26352 L F P
0 g
s
0 0 0 r
.67865 .42211 m .67706 .42329 L .68633 .41725 L closepath p F P
0 g
s
0 0 0 r
.66357 .43153 m .66565 .43029 L .65424 .4368 L p F P
0 g
s
0 0 0 r
.65424 .4368 m .65382 .43706 L .66357 .43153 L p F P
0 g
s
.186 .543 .928 r
.13576 .27185 m .14306 .2739 L .14697 .27725 L p F P
0 g
s
.192 .541 .927 r
.14306 .2739 m .13576 .27185 L .13214 .26848 L p F P
0 g
s
.293 .74 .961 r
.34849 .49217 m .34073 .4924 L .35068 .49347 L p F P
0 g
s
.293 .74 .961 r
.35068 .49347 m .35183 .49344 L .34849 .49217 L p F P
0 g
s
0 .315 .664 r
.17935 .45355 m .17956 .45364 L .17898 .45339 L closepath p F P
0 g
s
.622 .059 0 r
.22553 .32509 m .22647 .32589 L .2233 .32415 L closepath p F P
0 g
s
0 0 0 r
.73375 .3775 m .73412 .37682 L .72722 .38238 L p F P
0 g
s
0 0 0 r
.72816 .38326 m .73375 .3775 L p .72722 .38238 L F P
0 g
s
0 0 0 r
.72376 .38681 m .72816 .38326 L p .72722 .38238 L F P
0 g
s
0 0 0 r
.72722 .38238 m .72482 .38484 L .72376 .38681 L p F P
0 g
s
.612 .044 0 r
.23917 .33454 m .23616 .33217 L .2419 .33476 L p F P
0 g
s
.612 .044 0 r
.2419 .33476 m .24277 .33542 L .23917 .33454 L p F P
0 g
s
.219 .686 .943 r
.30236 .48693 m .29162 .48628 L .28816 .4849 L p F P
0 g
s
.069 0 .252 r
.76098 .34258 m .76366 .33649 L .75735 .34263 L p F P
0 g
s
.069 0 .252 r
.75546 .34797 m .76098 .34258 L p .75735 .34263 L F P
0 g
s
.069 0 .252 r
.75735 .34263 m .75566 .3465 L .75546 .34797 L p F P
0 g
s
0 0 0 r
.72482 .38484 m .71955 .39001 L .72376 .38681 L closepath p F P
0 g
s
0 .408 .76 r
.18128 .45393 m .18694 .45643 L .17956 .45364 L p F P
0 g
s
0 .408 .76 r
.1757 .45182 m .18128 .45393 L p .17956 .45364 L F P
0 g
s
0 .408 .76 r
.17956 .45364 m .17898 .45339 L .1757 .45182 L p F P
0 g
s
0 0 0 r
.69049 .41398 m .68846 .41578 L .69942 .40795 L closepath p F P
0 g
s
.555 .148 .226 r
.43286 .38219 m .43272 .38243 L .43211 .38224 L closepath p F P
0 g
s
.552 .142 .218 r
.43102 .38555 m .43272 .38243 L .43211 .38224 L p F P
0 g
s
.552 .142 .218 r
.4228 .38609 m .43102 .38555 L p .43211 .38224 L F P
0 g
s
.552 .142 .218 r
.41839 .38452 m .4228 .38609 L p .43211 .38224 L F P
0 g
s
.845 .382 .043 r
.06195 .37371 m .06056 .37112 L .06465 .3743 L p F P
0 g
s
.845 .382 .043 r
.06465 .3743 m .06574 .37633 L .06195 .37371 L p F P
0 g
s
.429 .872 .864 r
.58613 .46556 m .58808 .46542 L .57726 .46948 L p F P
0 g
s
.429 .872 .864 r
.57726 .46948 m .57472 .46966 L .58613 .46556 L p F P
0 g
s
0 0 0 r
.66643 .42981 m .66565 .43029 L .6706 .42733 L closepath p F P
0 g
s
.402 .851 .907 r
.53379 .48021 m .53477 .48028 L .52345 .4833 L p F P
0 g
s
.402 .851 .907 r
.52345 .4833 m .52208 .48322 L .53379 .48021 L p F P
0 g
s
.536 .129 .215 r
.44429 .38418 m .44612 .38082 L .43286 .38219 L p F P
0 g
s
.536 .129 .215 r
.44132 .38448 m .44429 .38418 L p .43286 .38219 L F P
0 g
s
.536 .129 .215 r
.43286 .38219 m .43272 .38243 L .44132 .38448 L p F P
0 g
s
.427 0 0 r
.14462 .43653 m .14545 .43702 L .14256 .43553 L closepath p F P
0 g
s
.341 .618 .953 r
.11837 .2636 m .12769 .26493 L .13137 .26838 L p F P
0 g
s
0 .437 .861 r
.15306 .28106 m .15786 .28306 L .16196 .28631 L p F P
0 g
s
.004 .435 .863 r
.15786 .28306 m .15306 .28106 L .14946 .27789 L p F P
0 g
s
.263 0 .024 r
.52349 .35437 m .52373 .35399 L .51244 .35801 L p F P
0 g
s
.263 0 .024 r
.51244 .35801 m .51235 .35815 L .52349 .35437 L p F P
0 g
s
.535 0 0 r
.11993 .42232 m .11558 .41898 L .12037 .42183 L p F P
0 g
s
.535 0 0 r
.12037 .42183 m .12368 .42435 L .11993 .42232 L p F P
0 g
s
0 0 0 r
.71358 .39548 m .71071 .398 L .71303 .39633 L closepath p F P
0 g
s
0 0 0 r
.7112 .39867 m .71303 .39633 L .71071 .398 L p F P
0 g
s
0 0 0 r
.71048 .39927 m .7112 .39867 L p .71071 .398 L F P
0 g
s
0 0 0 r
.70195 .40539 m .71048 .39927 L p .71071 .398 L F P
0 g
s
.714 .185 0 r
.08858 .39799 m .08597 .3964 L .08554 .3959 L closepath p F P
0 g
s
.661 .238 .231 r
.35965 .38475 m .37014 .38571 L .36534 .38212 L p F P
0 g
s
.661 .238 .231 r
.35794 .3833 m .35965 .38475 L p .36534 .38212 L F P
0 g
s
.661 .238 .231 r
.36534 .38212 m .35944 .38153 L .35794 .3833 L p F P
0 g
s
0 0 0 r
.71955 .39001 m .71358 .39548 L .71303 .39633 L p F P
0 g
s
0 0 0 r
.72251 .38871 m .72376 .38681 L .71955 .39001 L p F P
0 g
s
0 0 0 r
.71995 .39108 m .72251 .38871 L p .71955 .39001 L F P
0 g
s
0 0 0 r
.71303 .39633 m .71995 .39108 L p .71955 .39001 L F P
0 g
s
0 .262 .635 r
.15827 .44372 m .1566 .44289 L .16189 .44553 L p F P
0 g
s
0 .262 .635 r
.16189 .44553 m .16195 .44556 L .15827 .44372 L p F P
0 g
s
0 .203 .61 r
.20112 .31038 m .19678 .30771 L .20158 .31067 L p F P
0 g
s
0 .203 .61 r
.20158 .31067 m .20472 .31253 L .20112 .31038 L p F P
0 g
s
.285 .194 .573 r
.77666 .30302 m .772 .3084 L .7712 .30272 L p F P
0 g
s
.285 .194 .573 r
.7712 .30272 m .77497 .29834 L .77666 .30302 L p F P
0 g
s
.616 .673 .882 r
.73954 .25147 m .75082 .24917 L .74592 .25511 L p F P
0 g
s
.593 .638 .864 r
.75131 .24907 m .75082 .24917 L .74592 .25511 L p F P
0 g
s
.593 .638 .864 r
.74592 .25511 m .75407 .25398 L .75131 .24907 L p F P
0 g
s
0 .307 .677 r
.16853 .44853 m .16195 .44556 L .15827 .44372 L p F P
0 g
s
.643 .967 .852 r
.62308 .29474 m .62288 .29477 L .62374 .29422 L closepath p F P
0 g
s
.62 .213 .25 r
.38982 .38451 m .39372 .38679 L .38838 .38669 L closepath p F P
0 g
s
0 .334 .695 r
.17898 .45339 m .1757 .45182 L .174 .45111 L closepath p F P
0 g
s
0 .472 .807 r
.20088 .46147 m .2068 .46388 L .19866 .46129 L p F P
0 g
s
0 .472 .807 r
.19318 .45909 m .20088 .46147 L p .19866 .46129 L F P
0 g
s
0 .472 .807 r
.19866 .46129 m .19404 .45948 L .19318 .45909 L p F P
0 g
s
.274 0 .043 r
.5216 .35742 m .52349 .35437 L .51235 .35815 L p F P
0 g
s
.274 0 .043 r
.51235 .35815 m .51045 .36122 L .5216 .35742 L p F P
0 g
s
.71 .825 .936 r
.7109 .25276 m .7059 .25502 L .70908 .251 L closepath p F P
0 g
s
.707 .854 .952 r
.70823 .25018 m .70908 .251 L .7059 .25502 L p F P
0 g
s
.707 .854 .952 r
.69671 .25578 m .70823 .25018 L p .7059 .25502 L F P
0 g
s
.653 .107 0 r
.09736 .40656 m .10187 .40954 L .09806 .40574 L p F P
0 g
s
.653 .107 0 r
.09806 .40574 m .09354 .40277 L .09736 .40656 L p F P
0 g
s
.739 .903 .951 r
.69403 .25378 m .69671 .25578 L .68523 .2617 L p F P
0 g
s
.739 .903 .951 r
.68751 .25736 m .69403 .25378 L p .68523 .2617 L F P
0 g
s
.739 .903 .951 r
.68523 .2617 m .68411 .26102 L .68751 .25736 L p F P
0 g
s
.425 .867 .896 r
.56043 .47356 m .56165 .47358 L .55041 .47712 L p F P
0 g
s
.425 .867 .896 r
.55041 .47712 m .54907 .4771 L .56043 .47356 L p F P
0 g
s
.412 .831 .967 r
.4635 .49185 m .4536 .49298 L .4519 .49254 L p F P
0 g
s
.342 .765 .975 r
.36277 .49288 m .35183 .49344 L .34849 .49217 L p F P
0 g
s
.539 .143 .238 r
.43272 .38243 m .44132 .38448 L .43102 .38555 L closepath p F P
0 g
s
.096 .604 .893 r
.25292 .47686 m .25638 .4783 L .24887 .47705 L p F P
0 g
s
.096 .604 .893 r
.25277 .47682 m .25292 .47686 L p .24887 .47705 L F P
0 g
s
.096 .604 .893 r
.24229 .4751 m .25277 .47682 L p .24887 .47705 L F P
0 g
s
.096 .604 .893 r
.24887 .47705 m .24276 .4753 L .24229 .4751 L p F P
0 g
s
.01 .54 .851 r
.23529 .47285 m .22827 .47131 L .2247 .46979 L p F P
0 g
s
.694 .248 .188 r
.32803 .37385 m .32624 .37528 L .32374 .37305 L closepath p F P
0 g
s
.382 .839 .768 r
.61327 .45589 m .61459 .45555 L .60318 .46036 L p F P
0 g
s
.382 .839 .768 r
.60318 .46036 m .60283 .46045 L .61327 .45589 L p F P
0 g
s
.549 .916 .746 r
.61077 .30233 m .60879 .30313 L .61821 .2968 L closepath p F P
0 g
s
.833 .361 .024 r
.06574 .37633 m .067 .37851 L .07119 .38164 L p F P
0 g
s
.793 .298 0 r
.06975 .38259 m .07394 .38573 L .07119 .38164 L p F P
0 g
s
.793 .298 0 r
.07119 .38164 m .067 .37851 L .06975 .38259 L p F P
0 g
s
0 0 0 r
.73537 .37576 m .73412 .37682 L .7355 .37369 L p F P
0 g
s
0 0 0 r
.7355 .37369 m .74146 .3686 L .73537 .37576 L p F P
0 g
s
.596 .946 .809 r
.62374 .29422 m .62288 .29477 L .62015 .2955 L p F P
0 g
s
0 .339 .756 r
.18856 .30228 m .18752 .30157 L .18719 .30142 L closepath p F P
0 g
s
.735 .251 .094 r
.28248 .3594 m .28943 .36155 L .28543 .35779 L p F P
0 g
s
.735 .251 .094 r
.28543 .35779 m .27877 .35554 L .28248 .3594 L p F P
0 g
s
.379 .828 .714 r
.63747 .44504 m .64017 .44405 L .62875 .44956 L p F P
0 g
s
.379 .828 .714 r
.63661 .44546 m .63747 .44504 L p .62875 .44956 L F P
0 g
s
.379 .828 .714 r
.62875 .44956 m .62726 .45011 L .63661 .44546 L p F P
0 g
s
.102 .611 .893 r
.27352 .48239 m .274 .48258 L p .25989 .47972 L F P
0 g
s
.102 .611 .893 r
.25989 .47972 m .26727 .48072 L .27352 .48239 L p F P
0 g
s
.119 .621 .903 r
.26727 .48072 m .25989 .47972 L .25638 .4783 L p F P
0 g
s
0 0 0 r
.70195 .40539 m .69984 .40763 L .71048 .39927 L closepath p F P
0 g
s
.726 .962 .942 r
.66684 .26922 m .6597 .27347 L .65701 .27278 L p F P
0 g
s
.037 .465 .879 r
.1631 .28511 m .15786 .28306 L .16196 .28631 L p F P
0 g
s
.037 .465 .879 r
.16196 .28631 m .16671 .28812 L .1631 .28511 L p F P
0 g
s
.729 .267 .154 r
.30028 .36751 m .30791 .36943 L .30384 .36566 L p F P
0 g
s
.729 .267 .154 r
.30384 .36566 m .29655 .36364 L .30028 .36751 L p F P
0 g
s
.712 .179 0 r
.24597 .33843 m .24277 .33542 L .23917 .33454 L p F P
0 g
s
.667 .246 .236 r
.35944 .38153 m .35794 .3833 L .35515 .38107 L closepath p F P
0 g
s
.39 .824 .67 r
.66304 .43178 m .66357 .43153 L .65382 .43706 L p F P
0 g
s
.39 .824 .67 r
.65382 .43706 m .6516 .43811 L .66304 .43178 L p F P
0 g
s
.685 .253 .217 r
.34384 .37831 m .34557 .37981 L .34274 .37939 L closepath p F P
0 g
s
.657 .972 .865 r
.63424 .28745 m .62374 .29422 L .63183 .28773 L closepath p F P
0 g
s
.596 .946 .809 r
.63152 .28777 m .63183 .28773 L .62374 .29422 L p F P
0 g
s
.596 .946 .809 r
.62015 .2955 m .63152 .28777 L p .62374 .29422 L F P
0 g
s
0 .302 .75 r
.17252 .29225 m .17031 .29104 L .16671 .28812 L p F P
0 g
s
0 .264 .645 r
.14623 .43751 m .15137 .44022 L .14545 .43702 L p F P
0 g
s
0 .264 .645 r
.14545 .43702 m .14256 .43553 L .14091 .43467 L p F P
0 g
s
0 .264 .645 r
.14091 .43467 m .14623 .43751 L p .14545 .43702 L F P
0 g
s
.649 .092 0 r
.22538 .32672 m .23066 .32949 L .22647 .32589 L p F P
0 g
s
.649 .092 0 r
.22193 .32359 m .22538 .32672 L p .22647 .32589 L F P
0 g
s
.649 .092 0 r
.22647 .32589 m .2233 .32415 L .22193 .32359 L p F P
0 g
s
.089 0 0 r
.54928 .33979 m .54516 .34175 L .54902 .34012 L closepath p F P
0 g
s
.117 0 0 r
.5469 .34281 m .54902 .34012 L .54516 .34175 L p F P
0 g
s
.117 0 0 r
.53637 .34736 m .5469 .34281 L p .54516 .34175 L F P
0 g
s
.423 .01 .149 r
.48379 .37367 m .48537 .37084 L .47325 .37347 L p F P
0 g
s
.423 .01 .149 r
.47325 .37347 m .47255 .37467 L .48379 .37367 L p F P
0 g
s
.462 .858 .668 r
.59852 .30999 m .59744 .31057 L .60316 .30681 L closepath p F P
0 g
s
.728 .251 .114 r
.29481 .36189 m .29655 .36364 L .29297 .36254 L closepath p F P
0 g
s
.343 .274 .634 r
.77892 .29377 m .77497 .29834 L .7722 .29402 L p F P
0 g
s
.343 .274 .634 r
.77808 .28938 m .77892 .29377 L p .7722 .29402 L F P
0 g
s
.343 .274 .634 r
.7722 .29402 m .77723 .28816 L .77808 .28938 L p F P
0 g
s
.432 .859 .942 r
.52046 .48302 m .50916 .48584 L .50613 .48539 L p F P
0 g
s
.409 .847 .937 r
.49485 .48798 m .50613 .48539 L .50916 .48584 L p F P
0 g
s
.315 .751 .968 r
.34514 .49083 m .34849 .49217 L .34073 .4924 L p F P
0 g
s
.315 .751 .968 r
.33423 .49121 m .34514 .49083 L p .34073 .4924 L F P
0 g
s
.315 .751 .968 r
.34073 .4924 m .336 .49189 L .33423 .49121 L p F P
0 g
s
.728 .22 .015 r
.26576 .35092 m .27221 .35326 L .26815 .34954 L p F P
0 g
s
.728 .22 .015 r
.26815 .34954 m .26197 .34712 L .26576 .35092 L p F P
0 g
s
.128 .636 .9 r
.274 .48258 m .27459 .48264 L .28243 .48439 L p F P
0 g
s
.169 .655 .923 r
.28469 .48347 m .27459 .48264 L .28243 .48439 L p F P
0 g
s
.169 .655 .923 r
.28243 .48439 m .28816 .4849 L .28469 .48347 L p F P
0 g
s
.595 .193 .25 r
.40409 .38521 m .40732 .38674 L .4031 .38684 L closepath p F P
0 g
s
.601 .042 0 r
.10718 .41293 m .10659 .4126 L .10645 .41248 L closepath p F P
0 g
s
.568 .169 .246 r
.41839 .38452 m .4228 .38609 L .4173 .38644 L closepath p F P
0 g
s
.692 .775 .915 r
.7109 .25276 m .72248 .24804 L .72517 .25125 L p F P
0 g
s
.658 .718 .893 r
.72517 .25125 m .73683 .24754 L .73954 .25147 L p F P
0 g
s
.672 .741 .902 r
.73683 .24754 m .72517 .25125 L .72248 .24804 L p F P
0 g
s
.368 .779 .981 r
.37707 .49331 m .36609 .4941 L .36277 .49288 L p F P
0 g
s
0 .466 .787 r
.21072 .46553 m .21304 .46617 L .21937 .46843 L p F P
0 g
s
0 .498 .82 r
.22111 .46822 m .21304 .46617 L .21937 .46843 L p F P
0 g
s
0 .498 .82 r
.21937 .46843 m .2247 .46979 L .22111 .46822 L p F P
0 g
s
.409 .861 .864 r
.5727 .46977 m .57472 .46966 L .56334 .47348 L p F P
0 g
s
.409 .861 .864 r
.56334 .47348 m .56165 .47358 L .5727 .46977 L p F P
0 g
s
.095 0 .261 r
.75566 .3465 m .75465 .34872 L .75546 .34797 L closepath p F P
0 g
s
0 0 0 r
.58623 .31761 m .5861 .3177 L .58688 .3172 L closepath p F P
0 g
s
.431 .872 .824 r
.61182 .45612 m .61327 .45589 L .60283 .46045 L p F P
0 g
s
.431 .872 .824 r
.60283 .46045 m .60038 .46085 L .61182 .45612 L p F P
0 g
s
.665 .249 .244 r
.34973 .38361 m .34557 .37981 L .35515 .38107 L p F P
0 g
s
.665 .249 .244 r
.35701 .38446 m .34973 .38361 L p .35515 .38107 L F P
0 g
s
.665 .249 .244 r
.35515 .38107 m .35794 .3833 L .35701 .38446 L p F P
0 g
s
.561 .575 .825 r
.76189 .25944 m .75684 .25933 L .75407 .25398 L p F P
0 g
s
.693 .249 .192 r
.31947 .37517 m .31559 .37132 L .32374 .37305 L p F P
0 g
s
.693 .249 .192 r
.32504 .37627 m .31947 .37517 L p .32374 .37305 L F P
0 g
s
.693 .249 .192 r
.32374 .37305 m .32624 .37528 L .32504 .37627 L p F P
0 g
s
.722 .203 0 r
.26006 .34523 m .26197 .34712 L .25708 .34504 L closepath p F P
0 g
s
.761 .25 0 r
.07696 .38974 m .08121 .39284 L .0782 .38882 L p F P
0 g
s
.761 .25 0 r
.0782 .38882 m .07394 .38573 L .07696 .38974 L p F P
0 g
s
.228 .699 .942 r
.31892 .48952 m .31999 .48992 L p .30579 .48824 L F P
0 g
s
.228 .699 .942 r
.30579 .48824 m .31305 .48849 L .31892 .48952 L p F P
0 g
s
.251 .709 .952 r
.31305 .48849 m .30579 .48824 L .30236 .48693 L p F P
0 g
s
.732 .234 .052 r
.27741 .35416 m .27877 .35554 L .27565 .3544 L closepath p F P
0 g
s
.504 .104 .217 r
.45322 .3798 m .44612 .38082 L .44429 .38418 L p F P
0 g
s
0 0 0 r
.58688 .3172 m .5861 .3177 L .58367 .31962 L p F P
0 g
s
0 0 0 r
.5833 .31991 m .58367 .31962 L .57395 .32525 L p F P
0 g
s
0 0 0 r
.57395 .32525 m .57195 .32706 L .5833 .31991 L p F P
0 g
s
0 .347 .77 r
.18392 .29902 m .1826 .29836 L .18719 .30142 L p F P
0 g
s
0 .347 .77 r
.18719 .30142 m .18752 .30157 L .18392 .29902 L p F P
0 g
s
.273 .727 .956 r
.336 .49189 m .33423 .49121 L .33112 .49122 L closepath p F P
0 g
s
.705 .823 .938 r
.7198 .24507 m .72248 .24804 L .7109 .25276 L p F P
0 g
s
.705 .823 .938 r
.71083 .24903 m .7198 .24507 L p .7109 .25276 L F P
0 g
s
.705 .823 .938 r
.7109 .25276 m .70908 .251 L .71083 .24903 L p F P
0 g
s
.592 .035 0 r
.10283 .41039 m .10187 .40954 L .10645 .41248 L p F P
0 g
s
.592 .035 0 r
.10645 .41248 m .10659 .4126 L .10283 .41039 L p F P
0 g
s
.399 .829 .958 r
.46665 .49146 m .46622 .49136 L .4635 .49185 L closepath p F P
0 g
s
.412 .831 .967 r
.46309 .4905 m .46622 .49136 L .4635 .49185 L p F P
0 g
s
.412 .831 .967 r
.4519 .49254 m .46309 .4905 L p .4635 .49185 L F P
0 g
s
0 0 0 r
.59466 .3124 m .59573 .31168 L .58688 .3172 L p F P
0 g
s
.416 .815 .596 r
.59573 .31168 m .59466 .3124 L .59492 .31222 L p F P
0 g
s
0 0 0 r
.59703 .31082 m .58688 .3172 L .59573 .31168 L p F P
0 g
s
.416 .815 .596 r
.59492 .31222 m .60019 .30857 L .59573 .31168 L p F P
0 g
s
0 0 0 r
.59573 .31168 m .59744 .31057 L .59703 .31082 L p F P
0 g
s
0 0 0 r
.58543 .31849 m .59466 .3124 L p .58688 .3172 L F P
0 g
s
0 0 0 r
.58367 .31962 m .58543 .31849 L p .58688 .3172 L F P
0 g
s
.149 0 .386 r
.77113 .3247 m .76546 .33068 L .76643 .32514 L p F P
0 g
s
.149 0 .386 r
.76643 .32514 m .77214 .31914 L .77113 .3247 L p F P
0 g
s
.7 .165 0 r
.24995 .34214 m .256 .34462 L .25177 .34099 L p F P
0 g
s
.7 .165 0 r
.25177 .34099 m .24597 .33843 L .24995 .34214 L p F P
0 g
s
.42 .851 .944 r
.50412 .48504 m .50613 .48539 L .49485 .48798 L p F P
0 g
s
.42 .851 .944 r
.49485 .48798 m .49191 .4875 L .50412 .48504 L p F P
0 g
s
.381 .832 .929 r
.49191 .4875 m .49485 .48798 L p .48054 .48983 L F P
0 g
s
.558 0 0 r
.11086 .4161 m .10659 .4126 L .10283 .41039 L p F P
0 g
s
.632 .679 .876 r
.75082 .24917 m .73954 .25147 L .73683 .24754 L p F P
0 g
s
.407 0 0 r
.19213 .30468 m .18752 .30157 L .18392 .29902 L p F P
0 g
s
.502 0 0 r
.12368 .42435 m .12512 .42537 L .13006 .42816 L p F P
0 g
s
.435 0 0 r
.13041 .42874 m .13532 .43155 L .13006 .42816 L p F P
0 g
s
.435 0 0 r
.13006 .42816 m .12512 .42537 L .13041 .42874 L p F P
0 g
s
.389 .792 .984 r
.39139 .49349 m .38036 .49449 L .37707 .49331 L p F P
0 g
s
.323 0 .073 r
.50943 .36289 m .51045 .36122 L .49899 .36463 L p F P
0 g
s
.323 0 .073 r
.49899 .36463 m .49814 .36602 L .50943 .36289 L p F P
0 g
s
.024 0 .17 r
.75469 .35174 m .75103 .3551 L .75465 .34872 L p F P
0 g
s
.024 0 .17 r
.75465 .34872 m .75546 .34797 L .75469 .35174 L p F P
0 g
s
0 0 0 r
.6706 .42733 m .66565 .43029 L .66357 .43153 L p F P
0 g
s
.033 0 0 r
.55931 .33525 m .56061 .33372 L .54928 .33979 L p F P
0 g
s
.033 0 0 r
.54928 .33979 m .54902 .34012 L .55931 .33525 L p F P
0 g
s
.214 .56 .936 r
.14585 .27462 m .14306 .2739 L .14697 .27725 L p F P
0 g
s
.214 .56 .936 r
.14697 .27725 m .14946 .27789 L .14585 .27462 L p F P
0 g
s
.832 .36 .013 r
.067 .37851 m .06574 .37633 L .06195 .37371 L p F P
0 g
s
0 0 0 r
.71303 .39633 m .7112 .39867 L .71995 .39108 L closepath p F P
0 g
s
.55 0 0 r
.20472 .31253 m .20653 .31396 L .21139 .31689 L p F P
0 g
s
.546 0 0 r
.21097 .31744 m .21601 .32031 L .21139 .31689 L p F P
0 g
s
.546 0 0 r
.21139 .31689 m .20653 .31396 L .21097 .31744 L p F P
0 g
s
0 0 0 r
.56156 .33276 m .56061 .33372 L .56837 .32914 L closepath p F P
0 g
s
.744 .944 .947 r
.67111 .26667 m .66684 .26922 L .66985 .26618 L closepath p F P
0 g
s
.726 .962 .942 r
.66843 .26563 m .66985 .26618 L .66684 .26922 L p F P
0 g
s
.726 .962 .942 r
.65701 .27278 m .66843 .26563 L p .66684 .26922 L F P
0 g
s
.259 .139 .52 r
.77248 .31368 m .77232 .31385 L .77157 .30887 L p F P
0 g
s
.259 .139 .52 r
.77157 .30887 m .772 .3084 L .77248 .31368 L p F P
0 g
s
.404 .843 .72 r
.64077 .44383 m .64017 .44405 L .64475 .44172 L closepath p F P
0 g
s
.423 .842 .963 r
.47744 .48912 m .47939 .48961 L .46665 .49146 L p F P
0 g
s
.423 .842 .963 r
.46665 .49146 m .46622 .49136 L .47744 .48912 L p F P
0 g
s
0 .47 .794 r
.21072 .46553 m .21304 .46617 L .20757 .46418 L closepath p F P
0 g
s
.74 .905 .951 r
.68411 .26102 m .68255 .26009 L .68751 .25736 L closepath p F P
0 g
s
0 .404 .75 r
.19404 .45948 m .19318 .45909 L .19267 .45891 L closepath p F P
0 g
s
.413 .842 .952 r
.48054 .48983 m .49061 .48773 L .47939 .48961 L closepath p F P
0 g
s
.381 .832 .929 r
.48054 .48983 m .49061 .48773 L .49191 .4875 L p F P
0 g
s
.257 .72 .949 r
.31999 .48992 m .32184 .48993 L .33112 .49122 L p F P
0 g
s
.288 .73 .964 r
.33085 .48982 m .32184 .48993 L .33112 .49122 L p F P
0 g
s
.288 .73 .964 r
.33112 .49122 m .33423 .49121 L .33085 .48982 L p F P
0 g
s
.375 .797 .974 r
.39465 .49462 m .40572 .49341 L .40895 .49449 L p F P
0 g
s
.405 .803 .985 r
.40572 .49341 m .39465 .49462 L .39139 .49349 L p F P
0 g
s
.709 .18 0 r
.0822 .39398 m .08121 .39284 L .08554 .3959 L p F P
0 g
s
.709 .18 0 r
.08554 .3959 m .08597 .3964 L .0822 .39398 L p F P
0 g
s
.022 .552 .856 r
.24276 .4753 m .24229 .4751 L .24187 .47502 L closepath p F P
0 g
s
.659 .972 .865 r
.6397 .28392 m .63424 .28745 L .63183 .28773 L p F P
0 g
s
.441 .867 .936 r
.53179 .47996 m .53379 .48021 L .52208 .48322 L p F P
0 g
s
.441 .867 .936 r
.52208 .48322 m .52046 .48302 L .53179 .47996 L p F P
0 g
s
.391 0 0 r
.14256 .43553 m .14091 .43467 L .14031 .43431 L closepath p F P
0 g
s
.231 .119 .513 r
.7774 .30802 m .77248 .31368 L .772 .3084 L p F P
0 g
s
.231 .119 .513 r
.772 .3084 m .77666 .30302 L .7774 .30802 L p F P
0 g
s
.919 .529 .233 r
.04138 .34927 m .04518 .35261 L .04388 .34809 L p F P
0 g
s
.919 .529 .233 r
.04388 .34809 m .04009 .34476 L .04138 .34927 L p F P
0 g
s
.031 0 0 r
.55775 .33711 m .55931 .33525 L .54902 .34012 L p F P
0 g
s
.031 0 0 r
.55155 .34056 m .55775 .33711 L p .54902 .34012 L F P
0 g
s
.031 0 0 r
.54902 .34012 m .5469 .34281 L .55155 .34056 L p F P
0 g
s
.624 .059 0 r
.23497 .33306 m .23066 .32949 L .23616 .33217 L p F P
0 g
s
.624 .059 0 r
.23659 .33382 m .23497 .33306 L p .23616 .33217 L F P
0 g
s
.624 .059 0 r
.23616 .33217 m .23917 .33454 L .23659 .33382 L p F P
0 g
s
.69 .265 .232 r
.34054 .38222 m .34973 .38361 L .34557 .37981 L p F P
0 g
s
.69 .265 .232 r
.34028 .38196 m .34054 .38222 L p .34557 .37981 L F P
0 g
s
.69 .265 .232 r
.34557 .37981 m .34274 .37939 L .34028 .38196 L p F P
0 g
s
.505 .104 .214 r
.45896 .37899 m .45819 .3804 L .45322 .3798 L closepath p F P
0 g
s
.504 .104 .217 r
.4572 .38239 m .45819 .3804 L .45322 .3798 L p F P
0 g
s
.504 .104 .217 r
.44429 .38418 m .4572 .38239 L p .45322 .3798 L F P
0 g
s
.539 0 0 r
.2233 .32415 m .22193 .32359 L .22124 .32311 L closepath p F P
0 g
s
0 0 .157 r
.75761 .3489 m .75469 .35174 L .75546 .34797 L p F P
0 g
s
0 0 .157 r
.75546 .34797 m .76098 .34258 L .75761 .3489 L p F P
0 g
s
.899 .483 .169 r
.04679 .35703 m .05067 .36032 L .04905 .3559 L p F P
0 g
s
.899 .483 .169 r
.04905 .3559 m .04518 .35261 L .04679 .35703 L p F P
0 g
s
.037 .558 .867 r
.23874 .47353 m .23529 .47285 L .24187 .47502 L p F P
0 g
s
.037 .558 .867 r
.24187 .47502 m .24229 .4751 L .23874 .47353 L p F P
0 g
s
.137 .639 .906 r
.274 .48258 m .27459 .48264 L .27352 .48239 L closepath p F P
0 g
s
.389 .807 .974 r
.40895 .49449 m .42005 .49307 L .42326 .4941 L p F P
0 g
s
.416 .813 .985 r
.42005 .49307 m .40895 .49449 L .40572 .49341 L p F P
0 g
s
.448 .846 .976 r
.47744 .48912 m .46622 .49136 L .46309 .4905 L p F P
0 g
s
0 0 0 r
.67706 .42329 m .6706 .42733 L .67602 .42404 L closepath p F P
0 g
s
0 0 0 r
.67448 .42493 m .67602 .42404 L .6706 .42733 L p F P
0 g
s
0 0 0 r
.6663 .42989 m .67448 .42493 L p .6706 .42733 L F P
0 g
s
0 0 0 r
.66357 .43153 m .6663 .42989 L p .6706 .42733 L F P
0 g
s
.439 .873 .907 r
.56043 .47356 m .54907 .4771 L .54613 .47699 L p F P
0 g
s
.412 .859 .9 r
.53477 .48028 m .54613 .47699 L .54907 .4771 L p F P
0 g
s
.437 .038 .183 r
.48356 .37411 m .48379 .37367 L .47255 .37467 L p F P
0 g
s
.437 .038 .183 r
.47255 .37467 m .47145 .37677 L .48356 .37411 L p F P
0 g
s
.748 .945 .945 r
.67987 .25868 m .68255 .26009 L .67111 .26667 L p F P
0 g
s
.748 .945 .945 r
.67309 .2628 m .67987 .25868 L p .67111 .26667 L F P
0 g
s
.748 .945 .945 r
.67111 .26667 m .66985 .26618 L .67309 .2628 L p F P
0 g
s
0 .341 .706 r
.17204 .45001 m .16853 .44853 L .174 .45111 L p F P
0 g
s
0 .341 .706 r
.174 .45111 m .1757 .45182 L .17204 .45001 L p F P
0 g
s
.411 .861 .824 r
.59872 .4611 m .60038 .46085 L .58897 .46529 L p F P
0 g
s
.411 .861 .824 r
.58897 .46529 m .58808 .46542 L .59872 .4611 L p F P
0 g
s
0 .302 .75 r
.16671 .28812 m .16833 .28903 L .17252 .29225 L p F P
0 g
s
0 .313 .76 r
.17387 .29206 m .17816 .29524 L .17252 .29225 L p F P
0 g
s
0 .313 .76 r
.17252 .29225 m .16833 .28903 L .17387 .29206 L p F P
0 g
s
.259 .72 .95 r
.31999 .48992 m .32184 .48993 L .31892 .48952 L closepath p F P
0 g
s
.383 .332 .677 r
.77772 .28758 m .77723 .28816 L .77307 .28429 L p F P
0 g
s
.383 .332 .677 r
.77307 .28429 m .77604 .28076 L .77772 .28758 L p F P
0 g
s
.358 .627 .955 r
.12852 .26504 m .12769 .26493 L .13137 .26838 L p F P
0 g
s
.358 .627 .955 r
.13137 .26838 m .13214 .26848 L .12852 .26504 L p F P
0 g
s
.734 .849 .935 r
.70823 .25018 m .69671 .25578 L .69403 .25378 L p F P
0 g
s
.736 .268 .137 r
.29314 .36542 m .30028 .36751 L .29655 .36364 L p F P
0 g
s
.736 .268 .137 r
.29121 .36325 m .29314 .36542 L p .29655 .36364 L F P
0 g
s
.736 .268 .137 r
.29655 .36364 m .29297 .36254 L .29121 .36325 L p F P
0 g
s
.683 .146 0 r
.08909 .39976 m .08597 .3964 L .0822 .39398 L p F P
0 g
s
.402 .817 .974 r
.42326 .4941 m .4344 .49248 L .43758 .49345 L p F P
0 g
s
.423 .821 .983 r
.4344 .49248 m .42326 .4941 L .42005 .49307 L p F P
0 g
s
.439 .838 .978 r
.46309 .4905 m .4519 .49254 L .44874 .49162 L p F P
0 g
s
0 .412 .763 r
.18955 .45735 m .18694 .45643 L .19267 .45891 L p F P
0 g
s
0 .412 .763 r
.19267 .45891 m .19318 .45909 L .18955 .45735 L p F P
0 g
s
.106 .603 .903 r
.25277 .47682 m .24229 .4751 L .23874 .47353 L p F P
0 g
s
.876 .436 .105 r
.0526 .36465 m .05655 .3679 L .05461 .36357 L p F P
0 g
s
.876 .436 .105 r
.05461 .36357 m .05067 .36032 L .0526 .36465 L p F P
0 g
s
.427 .829 .979 r
.44874 .49162 m .43758 .49345 L .4344 .49248 L p F P
0 g
s
.69 .264 .232 r
.34274 .37939 m .34028 .38196 L .3364 .37842 L closepath p F P
0 g
s
.211 .678 .942 r
.28199 .48231 m .28469 .48347 L .27459 .48264 L p F P
0 g
s
.211 .678 .942 r
.28033 .48189 m .28199 .48231 L p .27459 .48264 L F P
0 g
s
.211 .678 .942 r
.27051 .4811 m .28033 .48189 L p .27459 .48264 L F P
0 g
s
.211 .678 .942 r
.27459 .48264 m .27352 .48239 L .27051 .4811 L p F P
0 g
s
.742 .254 .079 r
.27592 .35711 m .28248 .3594 L .27877 .35554 L p F P
0 g
s
.742 .254 .079 r
.2738 .35473 m .27592 .35711 L p .27877 .35554 L F P
0 g
s
.742 .254 .079 r
.27877 .35554 m .27565 .3544 L .2738 .35473 L p F P
0 g
s
0 .267 .646 r
.15458 .44182 m .15137 .44022 L .1566 .44289 L p F P
0 g
s
0 .267 .646 r
.1566 .44289 m .15827 .44372 L .15458 .44182 L p F P
0 g
s
.551 0 0 r
.20653 .31396 m .20472 .31253 L .20112 .31038 L p F P
0 g
s
.528 0 0 r
.11552 .41966 m .11086 .4161 L .11558 .41898 L p F P
0 g
s
.528 0 0 r
.11882 .42169 m .11552 .41966 L p .11558 .41898 L F P
0 g
s
.528 0 0 r
.11558 .41898 m .11993 .42232 L .11882 .42169 L p F P
0 g
s
.094 0 .316 r
.76457 .3316 m .76437 .33425 L .76546 .33068 L closepath p F P
0 g
s
.724 .274 .181 r
.31155 .37335 m .31947 .37517 L .31559 .37132 L p F P
0 g
s
.724 .274 .181 r
.3087 .37019 m .31155 .37335 L p .31559 .37132 L F P
0 g
s
.724 .274 .181 r
.31559 .37132 m .30936 .36976 L .3087 .37019 L p F P
0 g
s
.703 .98 .902 r
.64562 .2801 m .6397 .28392 L .64412 .28006 L closepath p F P
0 g
s
.659 .972 .865 r
.64291 .28004 m .64412 .28006 L .6397 .28392 L p F P
0 g
s
.659 .972 .865 r
.63273 .28695 m .64291 .28004 L p .6397 .28392 L F P
0 g
s
.659 .972 .865 r
.63183 .28773 m .63273 .28695 L p .6397 .28392 L F P
0 g
s
0 .193 .61 r
.1972 .30792 m .19213 .30468 L .19678 .30771 L p F P
0 g
s
0 .193 .61 r
.19847 .30871 m .1972 .30792 L p .19678 .30771 L F P
0 g
s
0 .193 .61 r
.19678 .30771 m .20112 .31038 L .19847 .30871 L p F P
0 g
s
.112 0 0 r
.54639 .34349 m .5469 .34281 L .53637 .34736 L p F P
0 g
s
.112 0 0 r
.53637 .34736 m .53505 .34915 L .54639 .34349 L p F P
0 g
s
0 .459 .803 r
.20088 .46147 m .19318 .45909 L .18955 .45735 L p F P
0 g
s
.144 .636 .916 r
.27352 .48239 m .27051 .4811 L .26727 .48072 L closepath p F P
0 g
s
.391 .802 .594 r
.60316 .30681 m .59744 .31057 L .59573 .31168 L p F P
0 g
s
.192 .541 .927 r
.13214 .26848 m .13927 .2705 L .14306 .2739 L p F P
0 g
s
.201 .54 .927 r
.13927 .2705 m .13214 .26848 L .12852 .26504 L p F P
0 g
s
.41 .847 .727 r
.64475 .44172 m .64017 .44405 L .63747 .44504 L p F P
0 g
s
.845 .381 .033 r
.05816 .37094 m .05655 .3679 L .06056 .37112 L p F P
0 g
s
.845 .381 .033 r
.06056 .37112 m .06195 .37371 L .05816 .37094 L p F P
0 g
s
.493 0 0 r
.12512 .42537 m .12368 .42435 L .11993 .42232 L p F P
0 g
s
.477 .075 .199 r
.46971 .38016 m .47145 .37677 L .45896 .37899 L p F P
0 g
s
.477 .075 .199 r
.46673 .38068 m .46971 .38016 L p .45896 .37899 L F P
0 g
s
.477 .075 .199 r
.45896 .37899 m .45819 .3804 L .46673 .38068 L p F P
0 g
s
.642 .096 0 r
.09292 .40354 m .09736 .40656 L .09354 .40277 L p F P
0 g
s
.642 .096 0 r
.09354 .40277 m .08909 .39976 L .09292 .40354 L p F P
0 g
s
0 0 .084 r
.75356 .35543 m .74672 .3617 L .75103 .3551 L p F P
0 g
s
0 0 .084 r
.75376 .35512 m .75356 .35543 L p .75103 .3551 L F P
0 g
s
0 0 .084 r
.75103 .3551 m .75469 .35174 L .75376 .35512 L p F P
0 g
s
.737 .226 .003 r
.25964 .34847 m .26576 .35092 L .26197 .34712 L p F P
0 g
s
.737 .226 .003 r
.25645 .34502 m .25964 .34847 L p .26197 .34712 L F P
0 g
s
.737 .226 .003 r
.26197 .34712 m .25708 .34504 L .25645 .34502 L p F P
0 g
s
.41 .856 .776 r
.62354 .45108 m .62602 .45044 L .61459 .45555 L p F P
0 g
s
.41 .856 .776 r
.61459 .45555 m .61327 .45589 L .62354 .45108 L p F P
0 g
s
.6 .204 .264 r
.40732 .38674 m .4031 .38684 L .40116 .39019 L p F P
0 g
s
.622 .228 .275 r
.39928 .39018 m .40116 .39019 L .4031 .38684 L p F P
0 g
s
.622 .228 .275 r
.4031 .38684 m .39372 .38679 L .39928 .39018 L p F P
0 g
s
0 0 0 r
.74529 .36299 m .74486 .36421 L .74672 .3617 L closepath p F P
0 g
s
0 0 0 r
.72376 .38681 m .72251 .38871 L .72816 .38326 L closepath p F P
0 g
s
.624 .222 .261 r
.38648 .38996 m .39928 .39018 L .39372 .38679 L p F P
0 g
s
.624 .222 .261 r
.38637 .38988 m .38648 .38996 L p .39372 .38679 L F P
0 g
s
.624 .222 .261 r
.39372 .38679 m .38838 .38669 L .38637 .38988 L p F P
0 g
s
.216 0 0 r
.53435 .35022 m .53505 .34915 L .52373 .35399 L p F P
0 g
s
.216 0 0 r
.52373 .35399 m .52349 .35437 L .53435 .35022 L p F P
0 g
s
.599 .208 .272 r
.4173 .38644 m .40732 .38674 L .41364 .3899 L p F P
0 g
s
.6 .204 .264 r
.40116 .39019 m .41364 .3899 L .40732 .38674 L p F P
0 g
s
.39 0 .14 r
.49538 .37109 m .49715 .3678 L .48537 .37084 L p F P
0 g
s
.39 0 .14 r
.4887 .37278 m .49538 .37109 L p .48537 .37084 L F P
0 g
s
.39 0 .14 r
.48537 .37084 m .48379 .37367 L .4887 .37278 L p F P
0 g
s
.017 .538 .86 r
.21967 .46756 m .22111 .46822 L .21304 .46617 L p F P
0 g
s
.017 .538 .86 r
.216 .46615 m .21967 .46756 L p .21304 .46617 L F P
0 g
s
.017 .538 .86 r
.20711 .46397 m .216 .46615 L p .21304 .46617 L F P
0 g
s
.017 .538 .86 r
.21304 .46617 m .20757 .46418 L .20711 .46397 L p F P
0 g
s
.561 .575 .825 r
.7662 .25398 m .76189 .25944 L p .75407 .25398 L F P
0 g
s
.561 .575 .825 r
.75407 .25398 m .76601 .25359 L .7662 .25398 L p F P
0 g
s
.58 .6 .837 r
.76601 .25359 m .75407 .25398 L .75131 .24907 L p F P
0 g
s
.64 .241 .271 r
.38838 .38669 m .38637 .38988 L .38142 .38642 L closepath p F P
0 g
s
.004 .435 .863 r
.14946 .27789 m .15386 .27975 L .15786 .28306 L p F P
0 g
s
.013 .434 .865 r
.15386 .27975 m .14946 .27789 L .14585 .27462 L p F P
0 g
s
0 0 0 r
.68633 .41725 m .67706 .42329 L .67602 .42404 L p F P
0 g
s
.527 0 0 r
.21832 .322 m .21601 .32031 L .22124 .32311 L p F P
0 g
s
.527 0 0 r
.22124 .32311 m .22193 .32359 L .21832 .322 L p F P
0 g
s
.379 0 0 r
.1372 .43265 m .13532 .43155 L .14031 .43431 L p F P
0 g
s
.379 0 0 r
.14031 .43431 m .14091 .43467 L .1372 .43265 L p F P
0 g
s
.314 .743 .972 r
.32746 .48837 m .33085 .48982 L .32184 .48993 L p F P
0 g
s
.314 .743 .972 r
.31659 .48855 m .32746 .48837 L p .32184 .48993 L F P
0 g
s
.314 .743 .972 r
.32184 .48993 m .31892 .48952 L .31659 .48855 L p F P
0 g
s
.524 .541 .815 r
.76189 .25944 m .7662 .25398 L .76886 .26004 L closepath p F P
0 g
s
.431 .867 .778 r
.62726 .45011 m .62602 .45044 L .63661 .44546 L closepath p F P
0 g
s
.348 .758 .981 r
.34514 .49083 m .33423 .49121 L .33085 .48982 L p F P
0 g
s
.832 .36 .013 r
.06195 .37371 m .06288 .37534 L .067 .37851 L p F P
0 g
s
.788 .292 0 r
.06564 .37942 m .06975 .38259 L .067 .37851 L p F P
0 g
s
.788 .292 0 r
.067 .37851 m .06288 .37534 L .06564 .37942 L p F P
0 g
s
.573 .18 .258 r
.4228 .38609 m .4173 .38644 L .41544 .38984 L p F P
0 g
s
.599 .208 .272 r
.41364 .3899 m .41544 .38984 L .4173 .38644 L p F P
0 g
s
.712 .274 .209 r
.32624 .37528 m .32781 .37684 L .32504 .37627 L closepath p F P
0 g
s
.647 .24 .259 r
.38632 .38995 m .38637 .38988 L .38142 .38642 L p F P
0 g
s
.647 .24 .259 r
.37476 .38939 m .38632 .38995 L p .38142 .38642 L F P
0 g
s
.647 .24 .259 r
.37212 .38726 m .37476 .38939 L p .38142 .38642 L F P
0 g
s
.647 .24 .259 r
.38142 .38642 m .37305 .38593 L .37212 .38726 L p F P
0 g
s
.673 .259 .25 r
.35794 .3833 m .35965 .38475 L .35701 .38446 L closepath p F P
0 g
s
.716 .238 .112 r
.29297 .36254 m .29121 .36325 L .28943 .36155 L closepath p F P
0 g
s
.43 .866 .915 r
.54527 .47693 m .54613 .47699 L .53477 .48028 L p F P
0 g
s
.43 .866 .915 r
.53477 .48028 m .53379 .48021 L .54527 .47693 L p F P
0 g
s
.689 .266 .237 r
.33156 .38075 m .32781 .37684 L .3364 .37842 L p F P
0 g
s
.689 .266 .237 r
.3401 .38215 m .33156 .38075 L p .3364 .37842 L F P
0 g
s
.689 .266 .237 r
.3364 .37842 m .34028 .38196 L .3401 .38215 L p F P
0 g
s
.041 .462 .88 r
.1595 .28199 m .15386 .27975 L .15786 .28306 L p F P
0 g
s
.041 .462 .88 r
.15786 .28306 m .1631 .28511 L .1595 .28199 L p F P
0 g
s
.701 .979 .903 r
.6558 .27356 m .64562 .2801 L .64412 .28006 L p F P
0 g
s
.435 .409 .731 r
.7722 .27509 m .77378 .27318 L .77479 .27643 L closepath p F P
0 g
s
.091 0 .314 r
.76935 .33051 m .77113 .3247 L .76546 .33068 L p F P
0 g
s
.091 0 .314 r
.76425 .3359 m .76935 .33051 L p .76546 .33068 L F P
0 g
s
.091 0 .314 r
.76546 .33068 m .76437 .33425 L .76425 .3359 L p F P
0 g
s
.448 .852 .97 r
.49061 .48773 m .47939 .48961 L .47744 .48912 L p F P
0 g
s
0 .389 .749 r
.18128 .45393 m .1757 .45182 L .17204 .45001 L p F P
0 g
s
.348 0 .119 r
.50862 .36438 m .50943 .36289 L .49814 .36602 L p F P
0 g
s
.348 0 .119 r
.49814 .36602 m .49715 .3678 L .50862 .36438 L p F P
0 g
s
.391 .802 .594 r
.60603 .30457 m .60774 .30367 L .60316 .30681 L p F P
0 g
s
.391 .802 .594 r
.60019 .30857 m .60603 .30457 L p .60316 .30681 L F P
0 g
s
.391 .802 .594 r
.59573 .31168 m .60019 .30857 L p .60316 .30681 L F P
0 g
s
.47 .865 .68 r
.60879 .30313 m .60316 .30681 L .60774 .30367 L closepath p F P
0 g
s
.267 .716 .958 r
.31892 .48952 m .31659 .48855 L .31305 .48849 L closepath p F P
0 g
s
.712 .209 .038 r
.27565 .3544 m .2738 .35473 L .27221 .35326 L closepath p F P
0 g
s
.45 .88 .902 r
.57184 .46976 m .5727 .46977 L .56165 .47358 L p F P
0 g
s
.45 .88 .902 r
.56165 .47358 m .56043 .47356 L .57184 .46976 L p F P
0 g
s
.222 0 .013 r
.53244 .35322 m .53435 .35022 L .52349 .35437 L p F P
0 g
s
.222 0 .013 r
.52349 .35437 m .5216 .35742 L .53244 .35322 L p F P
0 g
s
0 0 0 r
.56837 .32914 m .56061 .33372 L .55931 .33525 L p F P
0 g
s
0 .238 .627 r
.14623 .43751 m .14091 .43467 L .1372 .43265 L p F P
0 g
s
.712 .179 0 r
.23917 .33454 m .24041 .33577 L .24597 .33843 L p F P
0 g
s
.717 .187 0 r
.24418 .33955 m .24995 .34214 L .24597 .33843 L p F P
0 g
s
.717 .187 0 r
.24597 .33843 m .24041 .33577 L .24418 .33955 L p F P
0 g
s
.705 .824 .939 r
.70908 .251 m .70823 .25018 L .71083 .24903 L closepath p F P
0 g
s
.368 .811 .667 r
.6516 .43811 m .64475 .44172 L .65069 .43854 L closepath p F P
0 g
s
.41 .847 .727 r
.64893 .43914 m .65069 .43854 L .64475 .44172 L p F P
0 g
s
.41 .847 .727 r
.63747 .44504 m .64893 .43914 L p .64475 .44172 L F P
0 g
s
.574 .182 .263 r
.43102 .38555 m .42941 .3886 L .4228 .38609 L closepath p F P
0 g
s
.573 .18 .258 r
.42922 .38899 m .42941 .3886 L .4228 .38609 L p F P
0 g
s
.573 .18 .258 r
.41544 .38984 m .42922 .38899 L p .4228 .38609 L F P
0 g
s
.219 .686 .943 r
.30097 .48637 m .30236 .48693 L p .28816 .4849 L F P
0 g
s
.219 .686 .943 r
.28816 .4849 m .2962 .48535 L .30097 .48637 L p F P
0 g
s
.242 .696 .953 r
.2962 .48535 m .28816 .4849 L .28469 .48347 L p F P
0 g
s
.668 .117 0 r
.22538 .32672 m .22193 .32359 L .21832 .322 L p F P
0 g
s
0 .307 .677 r
.15827 .44372 m .16313 .44592 L .16853 .44853 L p F P
0 g
s
0 .314 .69 r
.16313 .44592 m .15827 .44372 L .15458 .44182 L p F P
0 g
s
.454 .885 .869 r
.59756 .46118 m .59872 .4611 L .58808 .46542 L p F P
0 g
s
.454 .885 .869 r
.58808 .46542 m .58613 .46556 L .59756 .46118 L p F P
0 g
s
.658 .253 .266 r
.37305 .38593 m .37212 .38726 L .37014 .38571 L closepath p F P
0 g
s
.482 .479 .777 r
.76892 .26666 m .77067 .26449 L .77177 .26741 L closepath p F P
0 g
s
0 .3 .755 r
.16833 .28903 m .16671 .28812 L .1631 .28511 L p F P
0 g
s
0 .34 .771 r
.18032 .29635 m .17816 .29524 L .1826 .29836 L p F P
0 g
s
0 .34 .771 r
.1826 .29836 m .18392 .29902 L .18032 .29635 L p F P
0 g
s
.286 .194 .573 r
.77973 .29947 m .77666 .30302 L .77497 .29834 L p F P
0 g
s
.286 .194 .573 r
.77497 .29834 m .77892 .29377 L .77973 .29947 L p F P
0 g
s
.755 .244 0 r
.07277 .38661 m .07696 .38974 L .07394 .38573 L p F P
0 g
s
.755 .244 0 r
.07394 .38573 m .06975 .38259 L .07277 .38661 L p F P
0 g
s
.656 .256 .276 r
.3639 .38854 m .35965 .38475 L .37014 .38571 L p F P
0 g
s
.656 .256 .276 r
.3709 .38913 m .3639 .38854 L p .37014 .38571 L F P
0 g
s
.656 .256 .276 r
.37014 .38571 m .37212 .38726 L .3709 .38913 L p F P
0 g
s
.435 .875 .87 r
.58355 .46571 m .58613 .46556 L .57472 .46966 L p F P
0 g
s
.435 .875 .87 r
.57472 .46966 m .5727 .46977 L .58355 .46571 L p F P
0 g
s
.586 .031 0 r
.09907 .40808 m .09736 .40656 L .10187 .40954 L p F P
0 g
s
.586 .031 0 r
.10187 .40954 m .10283 .41039 L .09907 .40808 L p F P
0 g
s
.711 .256 .168 r
.30936 .36976 m .3087 .37019 L .30791 .36943 L closepath p F P
0 g
s
.01 .54 .851 r
.2247 .46979 m .22875 .47066 L .23529 .47285 L p F P
0 g
s
.024 .548 .861 r
.22875 .47066 m .2247 .46979 L .22111 .46822 L p F P
0 g
s
.672 .741 .902 r
.72248 .24804 m .73413 .2439 L .73683 .24754 L p F P
0 g
s
.686 .762 .909 r
.73413 .2439 m .72248 .24804 L .7198 .24507 L p F P
0 g
s
.493 0 0 r
.11993 .42232 m .12024 .42254 L .12512 .42537 L p F P
0 g
s
.415 0 0 r
.12557 .4259 m .13041 .42874 L .12512 .42537 L p F P
0 g
s
.415 0 0 r
.12512 .42537 m .12024 .42254 L .12557 .4259 L p F P
0 g
s
.342 .765 .975 r
.34849 .49217 m .35944 .49157 L .36277 .49288 L p F P
0 g
s
.379 .774 .987 r
.35944 .49157 m .34849 .49217 L .34514 .49083 L p F P
0 g
s
.735 .919 .955 r
.68751 .25736 m .68255 .26009 L .67987 .25868 L p F P
0 g
s
.543 .15 .247 r
.44132 .38448 m .43102 .38555 L .42941 .3886 L p F P
0 g
s
0 0 0 r
.74848 .36228 m .75356 .35543 L .74672 .3617 L p F P
0 g
s
0 0 0 r
.7441 .36631 m .74848 .36228 L p .74672 .3617 L F P
0 g
s
0 0 0 r
.74672 .3617 m .74486 .36421 L .7441 .36631 L p F P
0 g
s
.551 0 0 r
.20112 .31038 m .20182 .31096 L .20653 .31396 L p F P
0 g
s
.557 0 0 r
.20612 .31449 m .21097 .31744 L .20653 .31396 L p F P
0 g
s
.557 0 0 r
.20653 .31396 m .20182 .31096 L .20612 .31449 L p F P
0 g
s
.489 .876 .685 r
.61821 .2968 m .60879 .30313 L .60774 .30367 L p F P
0 g
s
.632 .679 .876 r
.75114 .24879 m .75082 .24917 L p .73683 .24754 L F P
0 g
s
.632 .679 .876 r
.73683 .24754 m .74858 .24462 L .75114 .24879 L p F P
0 g
s
.648 .703 .887 r
.74858 .24462 m .73683 .24754 L .73413 .2439 L p F P
0 g
s
0 0 0 r
.68846 .41578 m .68633 .41725 L .68809 .41611 L closepath p F P
0 g
s
0 0 0 r
.68593 .41764 m .68809 .41611 L .68633 .41725 L p F P
0 g
s
0 0 0 r
.6832 .41944 m .68593 .41764 L p .68633 .41725 L F P
0 g
s
0 0 0 r
.67602 .42404 m .6832 .41944 L p .68633 .41725 L F P
0 g
s
.749 .947 .945 r
.66985 .26618 m .66843 .26563 L .67309 .2628 L closepath p F P
0 g
s
.051 .565 .876 r
.23518 .4719 m .22875 .47066 L .23529 .47285 L p F P
0 g
s
.051 .565 .876 r
.23529 .47285 m .23874 .47353 L .23518 .4719 L p F P
0 g
s
.202 .06 .454 r
.77267 .31858 m .77214 .31914 L .77232 .31385 L p F P
0 g
s
.202 .06 .454 r
.77232 .31385 m .77248 .31368 L .77267 .31858 L p F P
0 g
s
.717 .237 .108 r
.28621 .36326 m .28248 .3594 L .28943 .36155 L p F P
0 g
s
.717 .237 .108 r
.28901 .36409 m .28621 .36326 L p .28943 .36155 L F P
0 g
s
.717 .237 .108 r
.28943 .36155 m .29121 .36325 L .28901 .36409 L p F P
0 g
s
.455 .87 .946 r
.53179 .47996 m .52046 .48302 L .51745 .48257 L p F P
0 g
s
.432 .859 .942 r
.50613 .48539 m .51745 .48257 L .52046 .48302 L p F P
0 g
s
.119 .621 .903 r
.25638 .4783 m .26002 .47877 L .25292 .47686 L closepath p F P
0 g
s
.119 .621 .903 r
.25638 .4783 m .26002 .47877 L .26727 .48072 L p F P
0 g
s
.711 .256 .168 r
.30402 .3714 m .30028 .36751 L .30791 .36943 L p F P
0 g
s
.711 .256 .168 r
.30601 .37188 m .30402 .3714 L p .30791 .36943 L F P
0 g
s
.711 .256 .168 r
.30791 .36943 m .3087 .37019 L .30601 .37188 L p F P
0 g
s
.155 .639 .922 r
.26701 .47954 m .26002 .47877 L .26727 .48072 L p F P
0 g
s
.155 .639 .922 r
.26727 .48072 m .27051 .4811 L .26701 .47954 L p F P
0 g
s
.171 .038 .446 r
.77727 .3133 m .77267 .31858 L .77248 .31368 L p F P
0 g
s
.171 .038 .446 r
.77248 .31368 m .7774 .30802 L .77727 .3133 L p F P
0 g
s
.219 .557 .934 r
.14223 .27127 m .13927 .2705 L .14306 .2739 L p F P
0 g
s
.219 .557 .934 r
.14306 .2739 m .14585 .27462 L .14223 .27127 L p F P
0 g
s
0 0 0 r
.69942 .40795 m .68846 .41578 L .68809 .41611 L p F P
0 g
s
0 0 .002 r
.74486 .36421 m .74146 .3686 L .7441 .36631 L closepath p F P
0 g
s
.655 .099 0 r
.22949 .33036 m .23497 .33306 L .23066 .32949 L p F P
0 g
s
.655 .099 0 r
.23066 .32949 m .22538 .32672 L .22949 .33036 L p F P
0 g
s
.251 .709 .952 r
.30236 .48693 m .30443 .48698 L .31305 .48849 L p F P
0 g
s
.28 .719 .964 r
.31318 .48705 m .30443 .48698 L .31305 .48849 L p F P
0 g
s
.28 .719 .964 r
.31305 .48849 m .31659 .48855 L .31318 .48705 L p F P
0 g
s
.279 0 .052 r
.52076 .3588 m .5216 .35742 L .51045 .36122 L p F P
0 g
s
.279 0 .052 r
.51045 .36122 m .50943 .36289 L .52076 .3588 L p F P
0 g
s
.712 .205 .028 r
.2696 .35473 m .26576 .35092 L .27221 .35326 L p F P
0 g
s
.712 .205 .028 r
.27087 .35517 m .2696 .35473 L p .27221 .35326 L F P
0 g
s
.712 .205 .028 r
.27221 .35326 m .2738 .35473 L .27087 .35517 L p F P
0 g
s
.117 0 .323 r
.76437 .33425 m .76366 .33649 L .76425 .3359 L closepath p F P
0 g
s
.485 .095 .226 r
.45819 .3804 m .46673 .38068 L .4572 .38239 L closepath p F P
0 g
s
0 .346 .716 r
.16836 .44813 m .16313 .44592 L .16853 .44853 L p F P
0 g
s
0 .346 .716 r
.16853 .44853 m .17204 .45001 L .16836 .44813 L p F P
0 g
s
.704 .842 .949 r
.71083 .24903 m .70823 .25018 L .70555 .24783 L p F P
0 g
s
.734 .849 .935 r
.69403 .25378 m .70555 .24783 L .70823 .25018 L p F P
0 g
s
.704 .176 0 r
.07842 .39144 m .07696 .38974 L .08121 .39284 L p F P
0 g
s
.704 .176 0 r
.08121 .39284 m .0822 .39398 L .07842 .39144 L p F P
0 g
s
.733 .974 .925 r
.65701 .27278 m .6558 .27356 L .65667 .27273 L closepath p F P
0 g
s
.701 .979 .903 r
.65431 .27236 m .65667 .27273 L .6558 .27356 L p F P
0 g
s
.701 .979 .903 r
.64731 .27707 m .65431 .27236 L p .6558 .27356 L F P
0 g
s
.701 .979 .903 r
.64412 .28006 m .64731 .27707 L p .6558 .27356 L F P
0 g
s
0 .417 .773 r
.18591 .45554 m .18128 .45393 L .18694 .45643 L p F P
0 g
s
0 .417 .773 r
.18694 .45643 m .18955 .45735 L .18591 .45554 L p F P
0 g
s
.705 .167 0 r
.23917 .33454 m .24041 .33577 L .23659 .33382 L closepath p F P
0 g
s
0 0 0 r
.56927 .32992 m .57154 .32749 L .56837 .32914 L p F P
0 g
s
0 0 0 r
.55931 .33525 m .56927 .32992 L p .56837 .32914 L F P
0 g
s
0 0 0 r
.57195 .32706 m .56837 .32914 L .57154 .32749 L closepath p F P
0 g
s
.368 .779 .981 r
.37441 .49228 m .37707 .49331 L p .36277 .49288 L F P
0 g
s
.368 .779 .981 r
.36277 .49288 m .37224 .49215 L .37441 .49228 L p F P
0 g
s
.402 .788 .99 r
.37224 .49215 m .36277 .49288 L .35944 .49157 L p F P
0 g
s
.692 .16 0 r
.25708 .34504 m .25645 .34502 L .256 .34462 L closepath p F P
0 g
s
.717 .287 .226 r
.32326 .37907 m .33156 .38075 L .32781 .37684 L p F P
0 g
s
.717 .287 .226 r
.32265 .37837 m .32326 .37907 L p .32781 .37684 L F P
0 g
s
.717 .287 .226 r
.32781 .37684 m .32504 .37627 L .32265 .37837 L p F P
0 g
s
.466 .878 .942 r
.54317 .47665 m .54527 .47693 L .53379 .48021 L p F P
0 g
s
.466 .878 .942 r
.53379 .48021 m .53179 .47996 L .54317 .47665 L p F P
0 g
s
0 0 0 r
.73412 .37682 m .73375 .3775 L .73537 .37576 L closepath p F P
0 g
s
.678 .27 .265 r
.35469 .38753 m .3639 .38854 L .35965 .38475 L p F P
0 g
s
.678 .27 .265 r
.35965 .38475 m .35701 .38446 L .35469 .38753 L p F P
0 g
s
.398 .829 .677 r
.66044 .43297 m .66304 .43178 L .6516 .43811 L p F P
0 g
s
.398 .829 .677 r
.6516 .43811 m .65069 .43854 L .66044 .43297 L p F P
0 g
s
.831 .358 .001 r
.06288 .37534 m .06195 .37371 L .05816 .37094 L p F P
0 g
s
.449 .054 .197 r
.48192 .37757 m .48356 .37411 L .47145 .37677 L p F P
0 g
s
.449 .054 .197 r
.47145 .37677 m .46971 .38016 L .48192 .37757 L p F P
0 g
s
.407 0 0 r
.18392 .29902 m .18763 .30159 L .19213 .30468 L p F P
0 g
s
0 .141 .584 r
.18763 .30159 m .18392 .29902 L .18032 .29635 L p F P
0 g
s
.742 .976 .922 r
.66574 .2648 m .66843 .26563 L .65701 .27278 L p F P
0 g
s
.742 .976 .922 r
.66236 .26703 m .66574 .2648 L p .65701 .27278 L F P
0 g
s
.742 .976 .922 r
.65701 .27278 m .65667 .27273 L .66236 .26703 L p F P
0 g
s
.558 0 0 r
.10283 .41039 m .10622 .41317 L .11086 .4161 L p F P
0 g
s
.55 0 0 r
.10622 .41317 m .10283 .41039 L .09907 .40808 L p F P
0 g
s
0 .476 .812 r
.20757 .46418 m .20711 .46397 L .2068 .46388 L closepath p F P
0 g
s
.743 .892 .947 r
.69403 .25378 m .68751 .25736 L .69176 .25225 L closepath p F P
0 g
s
.735 .919 .955 r
.69135 .25198 m .69176 .25225 L .68751 .25736 L p F P
0 g
s
.735 .919 .955 r
.67987 .25868 m .69135 .25198 L p .68751 .25736 L F P
0 g
s
.252 .709 .952 r
.30236 .48693 m .30443 .48698 L .30097 .48637 L closepath p F P
0 g
s
.447 .863 .952 r
.51612 .48232 m .51745 .48257 L .50613 .48539 L p F P
0 g
s
.447 .863 .952 r
.50613 .48539 m .50412 .48504 L .51612 .48232 L p F P
0 g
s
0 .272 .656 r
.15088 .43985 m .14623 .43751 L .15137 .44022 L p F P
0 g
s
0 .272 .656 r
.15137 .44022 m .15458 .44182 L .15088 .43985 L p F P
0 g
s
.445 .439 .758 r
.77177 .26741 m .77659 .26938 L .77378 .27318 L closepath p F P
0 g
s
.38 .374 .727 r
.78212 .2728 m .77659 .26938 L .77378 .27318 L p F P
0 g
s
.38 .374 .727 r
.77777 .2785 m .78212 .2728 L p .77378 .27318 L F P
0 g
s
.38 .374 .727 r
.77378 .27318 m .77479 .27643 L .77777 .2785 L p F P
0 g
s
.437 .875 .83 r
.60918 .45653 m .61182 .45612 L .60038 .46085 L p F P
0 g
s
.437 .875 .83 r
.60038 .46085 m .59872 .4611 L .60918 .45653 L p F P
0 g
s
.735 .29 .193 r
.3087 .37019 m .31155 .37335 L .30601 .37188 L closepath p F P
0 g
s
0 0 0 r
.74272 .3694 m .73537 .37576 L .74146 .3686 L p F P
0 g
s
0 0 0 r
.74146 .3686 m .7441 .36631 L .74272 .3694 L p F P
0 g
s
.547 .156 .252 r
.44429 .38418 m .4438 .38513 L .44132 .38448 L closepath p F P
0 g
s
.543 .15 .247 r
.4426 .38769 m .4438 .38513 L .44132 .38448 L p F P
0 g
s
.543 .15 .247 r
.43033 .38888 m .4426 .38769 L p .44132 .38448 L F P
0 g
s
.543 .15 .247 r
.42941 .3886 m .43033 .38888 L p .44132 .38448 L F P
0 g
s
0 .3 .755 r
.1631 .28511 m .16426 .28576 L .16833 .28903 L p F P
0 g
s
0 .307 .761 r
.1697 .28882 m .17387 .29206 L .16833 .28903 L p F P
0 g
s
0 .307 .761 r
.16833 .28903 m .16426 .28576 L .1697 .28882 L p F P
0 g
s
.683 .276 .269 r
.35386 .38743 m .35469 .38753 L .35701 .38446 L p F P
0 g
s
.683 .276 .269 r
.35701 .38446 m .34973 .38361 L .35386 .38743 L p F P
0 g
s
.4 .372 .713 r
.77479 .27643 m .77777 .2785 L .77604 .28076 L closepath p F P
0 g
s
.9 .483 .158 r
.04299 .35369 m .04679 .35703 L .04518 .35261 L p F P
0 g
s
.9 .483 .158 r
.04518 .35261 m .04138 .34927 L .04299 .35369 L p F P
0 g
s
.69 .155 0 r
.25283 .3448 m .24995 .34214 L .256 .34462 L p F P
0 g
s
.69 .155 0 r
.256 .34462 m .25645 .34502 L .25283 .3448 L p F P
0 g
s
.61 .663 .877 r
.75082 .24917 m .75114 .24879 L .75131 .24907 L closepath p F P
0 g
s
0 .483 .823 r
.2035 .46221 m .20088 .46147 L .2068 .46388 L p F P
0 g
s
0 .483 .823 r
.2068 .46388 m .20711 .46397 L .2035 .46221 L p F P
0 g
s
.433 .849 .96 r
.49191 .4875 m .49179 .48748 L .49061 .48773 L closepath p F P
0 g
s
.448 .852 .97 r
.48871 .48666 m .49179 .48748 L .49061 .48773 L p F P
0 g
s
.448 .852 .97 r
.47744 .48912 m .48871 .48666 L p .49061 .48773 L F P
0 g
s
.456 .885 .83 r
.62328 .45112 m .62354 .45108 L .61327 .45589 L p F P
0 g
s
.456 .885 .83 r
.61327 .45589 m .61182 .45612 L .62328 .45112 L p F P
0 g
s
0 0 0 r
.68809 .41611 m .69728 .40983 L p .69942 .40795 L F P
0 g
s
0 0 0 r
.68809 .41611 m .68593 .41764 L .69728 .40983 L closepath p F P
0 g
s
.564 .926 .763 r
.62015 .2955 m .61821 .2968 L .61974 .29565 L closepath p F P
0 g
s
.489 .876 .685 r
.61741 .29653 m .61974 .29565 L .61821 .2968 L p F P
0 g
s
.489 .876 .685 r
.61395 .29897 m .61741 .29653 L p .61821 .2968 L F P
0 g
s
.489 .876 .685 r
.60774 .30367 m .61395 .29897 L p .61821 .2968 L F P
0 g
s
.508 0 0 r
.1109 .41672 m .11552 .41966 L .11086 .4161 L p F P
0 g
s
.508 0 0 r
.11086 .4161 m .10622 .41317 L .1109 .41672 L p F P
0 g
s
.408 .822 .631 r
.67602 .42404 m .67448 .42493 L .6832 .41944 L closepath p F P
0 g
s
.719 .839 .938 r
.71083 .24903 m .7198 .24507 L .71712 .2423 L p F P
0 g
s
.719 .839 .938 r
.71712 .2423 m .71533 .24316 L .71083 .24903 L p F P
0 g
s
.704 .842 .949 r
.70555 .24783 m .71533 .24316 L .71083 .24903 L p F P
0 g
s
0 .168 .603 r
.19256 .30488 m .1972 .30792 L .19213 .30468 L p F P
0 g
s
0 .168 .603 r
.19213 .30468 m .18763 .30159 L .19256 .30488 L p F P
0 g
s
.711 .278 .22 r
.32504 .37627 m .32265 .37837 L .31947 .37517 L closepath p F P
0 g
s
.047 0 .235 r
.76369 .33991 m .76098 .34258 L .76366 .33649 L p F P
0 g
s
.047 0 .235 r
.76366 .33649 m .76425 .3359 L .76369 .33991 L p F P
0 g
s
.58 .6 .837 r
.75131 .24907 m .76322 .24794 L .76601 .25359 L p F P
0 g
s
.573 .645 .884 r
.75114 .24879 m .75131 .24907 L .76322 .24794 L p F P
0 g
s
.875 .435 .093 r
.04872 .36136 m .0526 .36465 L .05067 .36032 L p F P
0 g
s
.875 .435 .093 r
.05067 .36032 m .04679 .35703 L .04872 .36136 L p F P
0 g
s
0 0 0 r
.58126 .32184 m .5833 .31991 L .57195 .32706 L p F P
0 g
s
0 0 0 r
.57195 .32706 m .57154 .32749 L .58126 .32184 L p F P
0 g
s
.524 .133 .241 r
.45554 .38591 m .4572 .38239 L .44429 .38418 L p F P
0 g
s
.524 .133 .241 r
.45139 .38647 m .45554 .38591 L p .44429 .38418 L F P
0 g
s
.524 .133 .241 r
.44429 .38418 m .4438 .38513 L .45139 .38647 L p F P
0 g
s
.389 .792 .984 r
.38954 .49279 m .39139 .49349 L p .37707 .49331 L F P
0 g
s
.389 .792 .984 r
.37707 .49331 m .38422 .49261 L .38954 .49279 L p F P
0 g
s
.39 .792 .984 r
.37707 .49331 m .38422 .49261 L .37441 .49228 L closepath p F P
0 g
s
.43 .447 .776 r
.77067 .26449 m .77177 .26741 L .77659 .26938 L p F P
0 g
s
.359 .317 .675 r
.78166 .28246 m .77772 .28758 L .77604 .28076 L p F P
0 g
s
.359 .317 .675 r
.77604 .28076 m .77777 .2785 L .78166 .28246 L p F P
0 g
s
.437 .871 .784 r
.63661 .44546 m .62602 .45044 L .62354 .45108 L p F P
0 g
s
.013 .529 .861 r
.216 .46615 m .20711 .46397 L .2035 .46221 L p F P
0 g
s
.465 .886 .913 r
.57184 .46976 m .56043 .47356 L .55751 .47344 L p F P
0 g
s
.439 .873 .907 r
.54613 .47699 m .55751 .47344 L .56043 .47356 L p F P
0 g
s
.742 .977 .921 r
.65667 .27273 m .65431 .27236 L .66236 .26703 L closepath p F P
0 g
s
.455 .86 .964 r
.50308 .48481 m .50412 .48504 L .49191 .4875 L p F P
0 g
s
.455 .86 .964 r
.49191 .4875 m .49179 .48748 L .50308 .48481 L p F P
0 g
s
0 0 0 r
.69984 .40763 m .69942 .40795 L .69976 .40772 L closepath p F P
0 g
s
0 0 0 r
.69736 .40978 m .69976 .40772 L .69942 .40795 L p F P
0 g
s
0 0 0 r
.69728 .40983 m .69736 .40978 L p .69942 .40795 L F P
0 g
s
0 0 0 r
.71048 .39927 m .69984 .40763 L .69976 .40772 L p F P
0 g
s
.601 .942 .769 r
.6288 .28838 m .63152 .28777 L .62015 .2955 L p F P
0 g
s
.601 .942 .769 r
.62721 .28951 m .6288 .28838 L p .62015 .2955 L F P
0 g
s
.601 .942 .769 r
.62015 .2955 m .61974 .29565 L .62721 .28951 L p F P
0 g
s
.602 .665 .883 r
.74858 .24462 m .75436 .24364 L .75114 .24879 L closepath p F P
0 g
s
.573 .645 .884 r
.76045 .24275 m .75436 .24364 L .75114 .24879 L p F P
0 g
s
.573 .645 .884 r
.76322 .24794 m .76045 .24275 L p .75114 .24879 L F P
0 g
s
.533 0 0 r
.21471 .32027 m .21097 .31744 L .21601 .32031 L p F P
0 g
s
.533 0 0 r
.21601 .32031 m .21832 .322 L .21471 .32027 L p F P
0 g
s
.755 .256 .036 r
.25964 .34847 m .25645 .34502 L .25283 .3448 L p F P
0 g
s
.479 .864 .977 r
.50308 .48481 m .49179 .48748 L .48871 .48666 L p F P
0 g
s
.659 .26 .278 r
.37212 .38726 m .37476 .38939 L .3709 .38913 L closepath p F P
0 g
s
.157 0 0 r
.54492 .34568 m .54639 .34349 L .53505 .34915 L p F P
0 g
s
.157 0 0 r
.53505 .34915 m .53435 .35022 L .54492 .34568 L p F P
0 g
s
.631 .085 0 r
.08856 .40049 m .09292 .40354 L .08909 .39976 L p F P
0 g
s
.631 .085 0 r
.08909 .39976 m .08472 .39671 L .08856 .40049 L p F P
0 g
s
.683 .146 0 r
.0822 .39398 m .08472 .39671 L .08909 .39976 L p F P
0 g
s
0 0 0 r
.69976 .40772 m .70885 .40112 L p .71048 .39927 L F P
0 g
s
0 0 0 r
.70877 .40119 m .70885 .40112 L .69976 .40772 L p F P
0 g
s
0 0 0 r
.69976 .40772 m .69736 .40978 L .70877 .40119 L p F P
0 g
s
.486 .5 .797 r
.76886 .26004 m .77317 .26097 L .77067 .26449 L closepath p F P
0 g
s
.43 .447 .776 r
.78091 .26367 m .77317 .26097 L .77067 .26449 L p F P
0 g
s
.43 .447 .776 r
.77659 .26938 m .78091 .26367 L p .77067 .26449 L F P
0 g
s
.844 .38 .022 r
.05438 .368 m .0526 .36465 L .05655 .3679 L p F P
0 g
s
.844 .38 .022 r
.05655 .3679 m .05816 .37094 L .05438 .368 L p F P
0 g
s
.37 0 0 r
.13348 .43055 m .13041 .42874 L .13532 .43155 L p F P
0 g
s
.37 0 0 r
.13532 .43155 m .1372 .43265 L .13348 .43055 L p F P
0 g
s
.424 .845 .685 r
.66357 .43153 m .66304 .43178 L .6663 .42989 L closepath p F P
0 g
s
.201 .54 .927 r
.12852 .26504 m .13559 .26704 L .13927 .2705 L p F P
0 g
s
.356 0 .131 r
.50689 .36768 m .50862 .36438 L .49715 .3678 L p F P
0 g
s
.356 0 .131 r
.49715 .3678 m .49538 .37109 L .50689 .36768 L p F P
0 g
s
0 0 0 r
.74269 .36944 m .74272 .3694 L .73537 .37576 L p F P
0 g
s
0 0 0 r
.73593 .37675 m .74269 .36944 L p .73537 .37576 L F P
0 g
s
0 0 0 r
.73253 .3797 m .73593 .37675 L p .73537 .37576 L F P
0 g
s
0 0 0 r
.73537 .37576 m .73375 .3775 L .73253 .3797 L p F P
0 g
s
.676 .141 0 r
.08472 .39671 m .0822 .39398 L .07842 .39144 L p F P
0 g
s
.405 .803 .985 r
.40423 .49285 m .40572 .49341 L p .39139 .49349 L F P
0 g
s
.405 .803 .985 r
.39139 .49349 m .39699 .49283 L .40423 .49285 L p F P
0 g
s
.409 .803 .987 r
.39139 .49349 m .39699 .49283 L .38954 .49279 L closepath p F P
0 g
s
.011 0 .223 r
.76687 .33656 m .76369 .33991 L .76425 .3359 L p F P
0 g
s
.011 0 .223 r
.76425 .3359 m .76935 .33051 L .76687 .33656 L p F P
0 g
s
.34 .273 .634 r
.77723 .28816 m .77772 .28758 L .77808 .28938 L closepath p F P
0 g
s
.704 .3 .28 r
.34424 .38617 m .35386 .38743 L .34973 .38361 L p F P
0 g
s
.704 .3 .28 r
.34973 .38361 m .34054 .38222 L .34424 .38617 L p F P
0 g
s
0 0 0 r
.73375 .3775 m .72816 .38326 L .73253 .3797 L closepath p F P
0 g
s
0 0 .069 r
.75469 .35174 m .75376 .35512 L .75761 .3489 L closepath p F P
0 g
s
.747 .283 .145 r
.29121 .36325 m .29314 .36542 L .28901 .36409 L closepath p F P
0 g
s
.309 .733 .973 r
.30975 .48548 m .31318 .48705 L .30443 .48698 L p F P
0 g
s
.309 .733 .973 r
.29892 .48546 m .30975 .48548 L p .30443 .48698 L F P
0 g
s
.309 .733 .973 r
.30443 .48698 m .30097 .48637 L .29892 .48546 L p F P
0 g
s
.724 .196 0 r
.23866 .33687 m .24418 .33955 L .24041 .33577 L p F P
0 g
s
.724 .196 0 r
.23555 .33356 m .23866 .33687 L p .24041 .33577 L F P
0 g
s
.724 .196 0 r
.24041 .33577 m .23659 .33382 L .23555 .33356 L p F P
0 g
s
.23 .68 .952 r
.28033 .48189 m .27051 .4811 L .26701 .47954 L p F P
0 g
s
.717 .984 .897 r
.64412 .28006 m .64291 .28004 L .64731 .27707 L closepath p F P
0 g
s
.47 .856 .98 r
.48871 .48666 m .47744 .48912 L .47434 .48825 L p F P
0 g
s
.448 .846 .976 r
.46309 .4905 m .47434 .48825 L .47744 .48912 L p F P
0 g
s
.746 .296 .185 r
.29658 .36941 m .30402 .3714 L .30028 .36751 L p F P
0 g
s
.746 .296 .185 r
.30028 .36751 m .29314 .36542 L .29658 .36941 L p F P
0 g
s
.752 .266 .083 r
.2738 .35473 m .27592 .35711 L .27087 .35517 L closepath p F P
0 g
s
.741 .891 .948 r
.70288 .24567 m .70555 .24783 L .69403 .25378 L p F P
0 g
s
.741 .891 .948 r
.69256 .25132 m .70288 .24567 L p .69403 .25378 L F P
0 g
s
.741 .891 .948 r
.69403 .25378 m .69176 .25225 L .69256 .25132 L p F P
0 g
s
0 0 0 r
.7112 .39867 m .71048 .39927 L .71106 .39885 L closepath p F P
0 g
s
0 0 0 r
.70885 .40112 m .71106 .39885 L .71048 .39927 L p F P
0 g
s
.347 .748 .983 r
.32746 .48837 m .31659 .48855 L .31318 .48705 L p F P
0 g
s
0 0 0 r
.71995 .39108 m .7112 .39867 L .71106 .39885 L p F P
0 g
s
.532 0 0 r
.20112 .31038 m .20182 .31096 L .19847 .30871 L closepath p F P
0 g
s
.416 .813 .985 r
.41849 .49251 m .42005 .49307 L p .40572 .49341 L F P
0 g
s
.416 .813 .985 r
.40572 .49341 m .41088 .49271 L .41849 .49251 L p F P
0 g
s
.424 .813 .988 r
.40572 .49341 m .41088 .49271 L .40423 .49285 L closepath p F P
0 g
s
.106 .603 .903 r
.23874 .47353 m .24606 .47468 L .25277 .47682 L p F P
0 g
s
.122 .611 .911 r
.24606 .47468 m .23874 .47353 L .23518 .4719 L p F P
0 g
s
.831 .358 .001 r
.05816 .37094 m .05884 .37213 L .06288 .37534 L p F P
0 g
s
.783 .286 0 r
.0616 .37621 m .06564 .37942 L .06288 .37534 L p F P
0 g
s
.783 .286 0 r
.06288 .37534 m .05884 .37213 L .0616 .37621 L p F P
0 g
s
0 0 0 r
.58367 .31962 m .5833 .31991 L .58543 .31849 L closepath p F P
0 g
s
.013 .434 .865 r
.14585 .27462 m .14998 .27639 L .15386 .27975 L p F P
0 g
s
.023 .435 .867 r
.14998 .27639 m .14585 .27462 L .14223 .27127 L p F P
0 g
s
.194 .661 .939 r
.2635 .47792 m .26701 .47954 L .26002 .47877 L p F P
0 g
s
.194 .661 .939 r
.25285 .47683 m .2635 .47792 L p .26002 .47877 L F P
0 g
s
.194 .661 .939 r
.26002 .47877 m .25292 .47686 L .25285 .47683 L p F P
0 g
s
.752 .28 .125 r
.27938 .36106 m .28621 .36326 L .28248 .3594 L p F P
0 g
s
.752 .28 .125 r
.28248 .3594 m .27592 .35711 L .27938 .36106 L p F P
0 g
s
0 0 0 r
.73146 .38126 m .73253 .3797 L .72816 .38326 L p F P
0 g
s
0 0 0 r
.72819 .38443 m .73146 .38126 L p .72816 .38326 L F P
0 g
s
0 0 0 r
.72198 .38952 m .72819 .38443 L p .72816 .38326 L F P
0 g
s
0 0 0 r
.72816 .38326 m .72251 .38871 L .72198 .38952 L p F P
0 g
s
.514 .887 .686 r
.60774 .30367 m .60603 .30457 L .61395 .29897 L closepath p F P
0 g
s
.678 .978 .861 r
.63183 .28773 m .63152 .28777 L .63273 .28695 L closepath p F P
0 g
s
.048 .459 .881 r
.15588 .27876 m .14998 .27639 L .15386 .27975 L p F P
0 g
s
.048 .459 .881 r
.15386 .27975 m .1595 .28199 L .15588 .27876 L p F P
0 g
s
0 0 0 r
.5805 .32257 m .58126 .32184 L .57154 .32749 L p F P
0 g
s
0 0 0 r
.57009 .32943 m .5805 .32257 L p .57154 .32749 L F P
0 g
s
0 0 0 r
.57154 .32749 m .56927 .32992 L .57009 .32943 L p F P
0 g
s
.597 .939 .764 r
.61974 .29565 m .61741 .29653 L .62721 .28951 L closepath p F P
0 g
s
.461 .848 .981 r
.47434 .48825 m .46309 .4905 L .45996 .48956 L p F P
0 g
s
.439 .838 .978 r
.44874 .49162 m .45996 .48956 L .46309 .4905 L p F P
0 g
s
0 0 0 r
.72251 .38871 m .71995 .39108 L .72198 .38952 L closepath p F P
0 g
s
.71 .278 .222 r
.31507 .37733 m .31155 .37335 L .31947 .37517 L p F P
0 g
s
.71 .278 .222 r
.32214 .37882 m .31507 .37733 L p .31947 .37517 L F P
0 g
s
.71 .278 .222 r
.31947 .37517 m .32265 .37837 L .32214 .37882 L p F P
0 g
s
.024 .548 .861 r
.22111 .46822 m .22225 .46845 L .22875 .47066 L p F P
0 g
s
.066 .572 .885 r
.23162 .47022 m .22225 .46845 L .22875 .47066 L p F P
0 g
s
.066 .572 .885 r
.22875 .47066 m .23518 .4719 L .23162 .47022 L p F P
0 g
s
0 0 0 r
.72014 .39177 m .72198 .38952 L .71995 .39108 L p F P
0 g
s
0 0 0 r
.71937 .39245 m .72014 .39177 L p .71995 .39108 L F P
0 g
s
0 0 0 r
.71106 .39885 m .71937 .39245 L p .71995 .39108 L F P
0 g
s
.277 .23 .624 r
.78437 .28682 m .78166 .28246 L .77772 .28758 L p F P
0 g
s
.277 .23 .624 r
.77991 .29251 m .78437 .28682 L p .77772 .28758 L F P
0 g
s
.277 .23 .624 r
.77772 .28758 m .77808 .28938 L .77991 .29251 L p F P
0 g
s
.423 .821 .983 r
.43237 .49178 m .4344 .49248 L p .42005 .49307 L F P
0 g
s
.423 .821 .983 r
.42005 .49307 m .4263 .49213 L .43237 .49178 L p F P
0 g
s
.435 .822 .987 r
.42005 .49307 m .4263 .49213 L .41849 .49251 L closepath p F P
0 g
s
.481 0 0 r
.11993 .42232 m .12024 .42254 L .11882 .42169 L closepath p F P
0 g
s
0 .459 .803 r
.18955 .45735 m .19503 .45903 L .20088 .46147 L p F P
0 g
s
0 .466 .814 r
.19503 .45903 m .18955 .45735 L .18591 .45554 L p F P
0 g
s
0 0 0 r
.56912 .33009 m .56927 .32992 L .55931 .33525 L p F P
0 g
s
0 0 0 r
.55931 .33525 m .55775 .33711 L .56912 .33009 L p F P
0 g
s
.452 .839 .984 r
.45912 .48927 m .45996 .48956 L .44874 .49162 L p F P
0 g
s
.452 .839 .984 r
.44874 .49162 m .44593 .49072 L .45912 .48927 L p F P
0 g
s
.427 .829 .979 r
.44593 .49072 m .44874 .49162 L p .4344 .49248 L F P
0 g
s
.475 .513 .817 r
.7662 .25398 m .76886 .26004 L .77317 .26097 L p F P
0 g
s
.739 .957 .943 r
.67309 .2628 m .66843 .26563 L .66574 .2648 L p F P
0 g
s
.443 .83 .986 r
.4344 .49248 m .44384 .4909 L .43237 .49178 L closepath p F P
0 g
s
.427 .829 .979 r
.4344 .49248 m .44384 .4909 L .44593 .49072 L p F P
0 g
s
0 0 0 r
.70914 .40089 m .70885 .40112 L .71106 .39885 L p F P
0 g
s
0 0 0 r
.71106 .39885 m .71937 .39245 L .70914 .40089 L p F P
0 g
s
.527 .147 .263 r
.4438 .38513 m .45139 .38647 L .4426 .38769 L closepath p F P
0 g
s
.255 .703 .958 r
.30097 .48637 m .29892 .48546 L .2962 .48535 L closepath p F P
0 g
s
.451 .871 .746 r
.66041 .43298 m .66044 .43297 L .65069 .43854 L p F P
0 g
s
.451 .871 .746 r
.65069 .43854 m .64893 .43914 L .66041 .43298 L p F P
0 g
s
.14 0 .382 r
.77258 .32316 m .77113 .3247 L .77214 .31914 L p F P
0 g
s
.14 0 .382 r
.77214 .31914 m .77267 .31858 L .77258 .32316 L p F P
0 g
s
0 .335 .773 r
.17671 .29356 m .17387 .29206 L .17816 .29524 L p F P
0 g
s
0 .335 .773 r
.17816 .29524 m .18032 .29635 L .17671 .29356 L p F P
0 g
s
.744 .246 .046 r
.26323 .35235 m .2696 .35473 L .26576 .35092 L p F P
0 g
s
.744 .246 .046 r
.26576 .35092 m .25964 .34847 L .26323 .35235 L p F P
0 g
s
.456 .879 .921 r
.55654 .47337 m .55751 .47344 L .54613 .47699 L p F P
0 g
s
.456 .879 .921 r
.54613 .47699 m .54527 .47693 L .55654 .47337 L p F P
0 g
s
0 .205 .613 r
.12081 .42302 m .12557 .4259 L .12024 .42254 L p F P
0 g
s
.443 0 0 r
.11882 .42169 m .11619 .42011 L .11552 .41966 L closepath p F P
0 g
s
0 .205 .613 r
.12024 .42254 m .11882 .42169 L .11619 .42011 L p F P
0 g
s
0 .205 .613 r
.11619 .42011 m .12081 .42302 L p .12024 .42254 L F P
0 g
s
.579 .026 0 r
.09531 .40567 m .09292 .40354 L .09736 .40656 L p F P
0 g
s
.579 .026 0 r
.09736 .40656 m .09907 .40808 L .09531 .40567 L p F P
0 g
s
.407 .013 .176 r
.48379 .37367 m .4887 .37278 L .48356 .37411 L closepath p F P
0 g
s
.428 .848 .69 r
.6663 .42989 m .66304 .43178 L .66044 .43297 L p F P
0 g
s
.639 .964 .826 r
.63273 .28695 m .63152 .28777 L .6288 .28838 L p F P
0 g
s
.23 .119 .513 r
.78022 .30476 m .7774 .30802 L .77666 .30302 L p F P
0 g
s
.23 .119 .513 r
.77666 .30302 m .77973 .29947 L .78022 .30476 L p F P
0 g
s
.309 .243 .619 r
.77808 .28938 m .77991 .29251 L .77892 .29377 L closepath p F P
0 g
s
.041 0 0 r
.5469 .34281 m .54639 .34349 L .55155 .34056 L closepath p F P
0 g
s
.571 .015 0 r
.20143 .31147 m .20612 .31449 L .20182 .31096 L p F P
0 g
s
.571 .015 0 r
.19751 .30812 m .20143 .31147 L p .20182 .31096 L F P
0 g
s
.571 .015 0 r
.20182 .31096 m .19847 .30871 L .19751 .30812 L p F P
0 g
s
.748 .237 0 r
.06866 .38343 m .07277 .38661 L .06975 .38259 L p F P
0 g
s
.748 .237 0 r
.06975 .38259 m .06564 .37942 L .06866 .38343 L p F P
0 g
s
.702 .283 .247 r
.34028 .38196 m .34054 .38222 L .3401 .38215 L closepath p F P
0 g
s
.46 .888 .875 r
.59473 .46133 m .59756 .46118 L .58613 .46556 L p F P
0 g
s
.46 .888 .875 r
.58737 .46415 m .59473 .46133 L p .58613 .46556 L F P
0 g
s
.46 .888 .875 r
.58613 .46556 m .58355 .46571 L .58737 .46415 L p F P
0 g
s
.696 .982 .878 r
.64291 .28004 m .63273 .28695 L .64025 .28021 L closepath p F P
0 g
s
.639 .964 .826 r
.6402 .28021 m .64025 .28021 L .63273 .28695 L p F P
0 g
s
.639 .964 .826 r
.6288 .28838 m .6402 .28021 L p .63273 .28695 L F P
0 g
s
.309 0 .101 r
.5198 .36058 m .52076 .3588 L .50943 .36289 L p F P
0 g
s
.309 0 .101 r
.50943 .36289 m .50862 .36438 L .5198 .36058 L p F P
0 g
s
0 0 0 r
.58543 .31849 m .5833 .31991 L .58126 .32184 L p F P
0 g
s
.668 .117 0 r
.21832 .322 m .2203 .32387 L .22538 .32672 L p F P
0 g
s
.668 .118 0 r
.22423 .32757 m .22949 .33036 L .22538 .32672 L p F P
0 g
s
.668 .118 0 r
.22538 .32672 m .2203 .32387 L .22423 .32757 L p F P
0 g
s
.491 .107 .24 r
.46673 .38068 m .4572 .38239 L .45554 .38591 L p F P
0 g
s
0 0 .149 r
.76291 .34366 m .75761 .3489 L .76098 .34258 L p F P
0 g
s
0 0 .149 r
.76098 .34258 m .76369 .33991 L .76291 .34366 L p F P
0 g
s
0 .3 .76 r
.16426 .28576 m .1631 .28511 L .1595 .28199 L p F P
0 g
s
0 .397 .761 r
.1757 .45139 m .17204 .45001 L .16836 .44813 L p F P
0 g
s
0 .389 .749 r
.17204 .45001 m .1757 .45139 L .18128 .45393 L p F P
0 g
s
.381 .766 .989 r
.34057 .48944 m .33085 .48982 L .32746 .48837 L p F P
0 g
s
.348 .758 .981 r
.34244 .48968 m .34514 .49083 L p .33085 .48982 L F P
0 g
s
.348 .758 .981 r
.33085 .48982 m .34057 .48944 L .34244 .48968 L p F P
0 g
s
.106 0 .372 r
.77635 .31884 m .77258 .32316 L .77267 .31858 L p F P
0 g
s
.106 0 .372 r
.77267 .31858 m .77727 .3133 L .77635 .31884 L p F P
0 g
s
0 .423 .782 r
.18226 .45367 m .1757 .45139 L .18128 .45393 L p F P
0 g
s
0 .423 .782 r
.18128 .45393 m .18591 .45554 L .18226 .45367 L p F P
0 g
s
.648 .703 .887 r
.73413 .2439 m .74586 .24048 L .74858 .24462 L p F P
0 g
s
.662 .725 .896 r
.74586 .24048 m .73413 .2439 L .73144 .24051 L p F P
0 g
s
.686 .762 .909 r
.7198 .24507 m .73144 .24051 L .73413 .2439 L p F P
0 g
s
0 0 0 r
.74279 .36933 m .74272 .3694 L .7441 .36631 L p F P
0 g
s
0 0 0 r
.7441 .36631 m .74848 .36228 L .74279 .36933 L p F P
0 g
s
0 .314 .69 r
.15458 .44182 m .1578 .44328 L .16313 .44592 L p F P
0 g
s
0 .352 .727 r
.16468 .44619 m .1578 .44328 L .16313 .44592 L p F P
0 g
s
0 .352 .727 r
.16313 .44592 m .16836 .44813 L .16468 .44619 L p F P
0 g
s
.755 .935 .945 r
.67987 .25868 m .67309 .2628 L .67764 .25765 L closepath p F P
0 g
s
.739 .957 .943 r
.67719 .25744 m .67764 .25765 L .67309 .2628 L p F P
0 g
s
.739 .957 .943 r
.66574 .2648 m .67719 .25744 L p .67309 .2628 L F P
0 g
s
.607 .22 .283 r
.41364 .3899 m .40116 .39019 L .40067 .39109 L p F P
0 g
s
.628 .242 .294 r
.40116 .39019 m .40067 .39109 L .39928 .39018 L closepath p F P
0 g
s
.708 .298 .268 r
.33761 .38508 m .34424 .38617 L .34054 .38222 L p F P
0 g
s
.708 .298 .268 r
.34054 .38222 m .3401 .38215 L .33761 .38508 L p F P
0 g
s
.625 .247 .306 r
.39131 .39359 m .38648 .38996 L .39928 .39018 L p F P
0 g
s
.625 .247 .306 r
.39936 .3937 m .39131 .39359 L p .39928 .39018 L F P
0 g
s
.625 .247 .306 r
.39928 .39018 m .40067 .39109 L .39936 .3937 L p F P
0 g
s
0 .238 .627 r
.1372 .43265 m .14115 .43477 L .14623 .43751 L p F P
0 g
s
0 .245 .64 r
.14115 .43477 m .1372 .43265 L .13348 .43055 L p F P
0 g
s
.473 .892 .906 r
.58327 .4657 m .58355 .46571 L .5727 .46977 L p F P
0 g
s
.473 .892 .906 r
.5727 .46977 m .57184 .46976 L .58327 .4657 L p F P
0 g
s
0 0 0 r
.59466 .3124 m .58543 .31849 L .59313 .31361 L closepath p F P
0 g
s
0 0 0 r
.59188 .31462 m .59313 .31361 L .58543 .31849 L p F P
0 g
s
0 0 0 r
.58486 .3195 m .59188 .31462 L p .58543 .31849 L F P
0 g
s
0 0 0 r
.58126 .32184 m .58486 .3195 L p .58543 .31849 L F P
0 g
s
.707 .297 .267 r
.33528 .3847 m .33761 .38508 L .3401 .38215 L p F P
0 g
s
.707 .297 .267 r
.3401 .38215 m .33156 .38075 L .33528 .3847 L p F P
0 g
s
.387 .81 .628 r
.67448 .42493 m .6663 .42989 L .67314 .4257 L closepath p F P
0 g
s
.428 .848 .69 r
.67188 .42625 m .67314 .4257 L .6663 .42989 L p F P
0 g
s
.428 .848 .69 r
.66059 .43288 m .67188 .42625 L p .6663 .42989 L F P
0 g
s
.428 .848 .69 r
.66044 .43297 m .66059 .43288 L p .6663 .42989 L F P
0 g
s
.636 .243 .281 r
.38637 .38988 m .38648 .38996 L .38632 .38995 L closepath p F P
0 g
s
.418 .032 .197 r
.4887 .37278 m .48356 .37411 L .48192 .37757 L p F P
0 g
s
.157 0 0 r
.54349 .34783 m .54492 .34568 L .53435 .35022 L p F P
0 g
s
.157 0 0 r
.53648 .35145 m .54349 .34783 L p .53435 .35022 L F P
0 g
s
.157 0 0 r
.53435 .35022 m .53244 .35322 L .53648 .35145 L p F P
0 g
s
.699 .782 .916 r
.73144 .24051 m .7198 .24507 L .71712 .2423 L p F P
0 g
s
.368 .33 .684 r
.78511 .27804 m .78166 .28246 L .77777 .2785 L p F P
0 g
s
.368 .33 .684 r
.78434 .27486 m .78511 .27804 L p .77777 .2785 L F P
0 g
s
.368 .33 .684 r
.77777 .2785 m .78212 .2728 L .78434 .27486 L p F P
0 g
s
0 .322 .702 r
.1578 .44328 m .15458 .44182 L .15088 .43985 L p F P
0 g
s
.643 .26 .303 r
.38444 .39341 m .39131 .39359 L .38648 .38996 L p F P
0 g
s
.643 .26 .303 r
.38648 .38996 m .38632 .38995 L .38444 .39341 L p F P
0 g
s
.658 .276 .311 r
.37917 .39315 m .38444 .39341 L .38632 .38995 L p F P
0 g
s
.658 .276 .311 r
.38632 .38995 m .37476 .38939 L .37917 .39315 L p F P
0 g
s
.225 .555 .933 r
.13861 .26783 m .13559 .26704 L .13927 .2705 L p F P
0 g
s
.225 .555 .933 r
.13927 .2705 m .14223 .27127 L .13861 .26783 L p F P
0 g
s
.701 .169 0 r
.24802 .34333 m .24418 .33955 L .24995 .34214 L p F P
0 g
s
.701 .169 0 r
.25106 .34463 m .24802 .34333 L p .24995 .34214 L F P
0 g
s
.701 .169 0 r
.24995 .34214 m .25283 .3448 L .25106 .34463 L p F P
0 g
s
.606 .224 .291 r
.41544 .38984 m .41503 .39065 L .41364 .3899 L closepath p F P
0 g
s
.607 .22 .283 r
.41372 .39342 m .41503 .39065 L .41364 .3899 L p F P
0 g
s
.607 .22 .283 r
.40475 .39362 m .41372 .39342 L p .41364 .3899 L F P
0 g
s
.607 .22 .283 r
.40067 .39109 m .40475 .39362 L p .41364 .3899 L F P
0 g
s
.595 .211 .285 r
.42759 .39261 m .42922 .38899 L .41544 .38984 L p F P
0 g
s
.595 .211 .285 r
.42002 .39306 m .42759 .39261 L p .41544 .38984 L F P
0 g
s
.595 .211 .285 r
.41544 .38984 m .41503 .39065 L .42002 .39306 L p F P
0 g
s
.242 .696 .953 r
.28469 .48347 m .28823 .48364 L .2962 .48535 L p F P
0 g
s
.239 .695 .951 r
.28469 .48347 m .28823 .48364 L .28199 .48231 L closepath p F P
0 g
s
0 .489 .832 r
.19988 .4604 m .19503 .45903 L .20088 .46147 L p F P
0 g
s
0 .489 .832 r
.20088 .46147 m .2035 .46221 L .19988 .4604 L p F P
0 g
s
.268 .705 .964 r
.29547 .48385 m .28823 .48364 L .2962 .48535 L p F P
0 g
s
.268 .705 .964 r
.2962 .48535 m .29892 .48546 L .29547 .48385 L p F P
0 g
s
.699 .173 0 r
.07464 .38879 m .07277 .38661 L .07696 .38974 L p F P
0 g
s
.699 .173 0 r
.07696 .38974 m .07842 .39144 L .07464 .38879 L p F P
0 g
s
.671 .123 0 r
.2203 .32387 m .21832 .322 L .21471 .32027 L p F P
0 g
s
0 .277 .667 r
.14717 .4378 m .14115 .43477 L .14623 .43751 L p F P
0 g
s
0 .277 .667 r
.14623 .43751 m .15088 .43985 L .14717 .4378 L p F P
0 g
s
.4 .843 .734 r
.63747 .44504 m .63661 .44546 L .63737 .44507 L closepath p F P
0 g
s
.437 .871 .784 r
.63475 .44569 m .63737 .44507 L .63661 .44546 L p F P
0 g
s
.437 .871 .784 r
.62551 .45009 m .63475 .44569 L p .63661 .44546 L F P
0 g
s
.437 .871 .784 r
.62354 .45108 m .62551 .45009 L p .63661 .44546 L F P
0 g
s
.477 .881 .95 r
.54317 .47665 m .53179 .47996 L .5288 .4795 L p F P
0 g
s
.455 .87 .946 r
.51745 .48257 m .5288 .4795 L .53179 .47996 L p F P
0 g
s
.655 .099 0 r
.23659 .33382 m .23555 .33356 L .23497 .33306 L closepath p F P
0 g
s
.463 .889 .836 r
.62051 .4515 m .62328 .45112 L .61182 .45612 L p F P
0 g
s
.463 .889 .836 r
.61054 .45589 m .62051 .4515 L p .61182 .45612 L F P
0 g
s
.463 .889 .836 r
.61182 .45612 m .60918 .45653 L .61054 .45589 L p F P
0 g
s
.431 .861 .743 r
.64726 .43971 m .64893 .43914 L .63747 .44504 L p F P
0 g
s
.431 .861 .743 r
.63747 .44504 m .63737 .44507 L .64726 .43971 L p F P
0 g
s
0 0 0 r
.72198 .38952 m .72014 .39177 L .72819 .38443 L closepath p F P
0 g
s
.034 .552 .867 r
.22111 .46822 m .22225 .46845 L .21967 .46756 L closepath p F P
0 g
s
.557 .175 .272 r
.42941 .3886 m .43033 .38888 L .42922 .38899 L closepath p F P
0 g
s
.479 .871 .969 r
.51442 .48192 m .51612 .48232 L .50412 .48504 L p F P
0 g
s
.479 .871 .969 r
.50412 .48504 m .50308 .48481 L .51442 .48192 L p F P
0 g
s
.478 .897 .873 r
.60902 .45654 m .60918 .45653 L .59872 .4611 L p F P
0 g
s
.478 .897 .873 r
.59872 .4611 m .59756 .46118 L .60902 .45654 L p F P
0 g
s
.664 .271 .292 r
.36884 .39244 m .37917 .39315 L .37476 .38939 L p F P
0 g
s
.664 .271 .292 r
.37476 .38939 m .3709 .38913 L .36884 .39244 L p F P
0 g
s
.475 .513 .817 r
.77734 .25528 m .76644 .25363 L .7662 .25398 L p F P
0 g
s
.475 .513 .817 r
.77317 .26097 m .77734 .25528 L p .7662 .25398 L F P
0 g
s
.523 .554 .829 r
.76601 .25359 m .76644 .25363 L .7662 .25398 L closepath p F P
0 g
s
.618 .663 .871 r
.75436 .24364 m .74858 .24462 L .74586 .24048 L p F P
0 g
s
.257 .174 .567 r
.78153 .29723 m .77973 .29947 L .77892 .29377 L p F P
0 g
s
.257 .174 .567 r
.77892 .29377 m .77991 .29251 L .78153 .29723 L p F P
0 g
s
.379 .774 .987 r
.35872 .49126 m .35944 .49157 L p .34514 .49083 L F P
0 g
s
.379 .774 .987 r
.34514 .49083 m .35075 .49046 L .35872 .49126 L p F P
0 g
s
.374 .774 .985 r
.34514 .49083 m .35075 .49046 L .34244 .48968 L closepath p F P
0 g
s
.098 0 0 r
.55155 .34056 m .54639 .34349 L .54492 .34568 L p F P
0 g
s
.478 .894 .803 r
.64624 .43995 m .64726 .43971 L .63737 .44507 L p F P
0 g
s
.478 .894 .803 r
.63737 .44507 m .63475 .44569 L .64624 .43995 L p F P
0 g
s
.755 .299 .169 r
.2896 .36726 m .29658 .36941 L .29314 .36542 L p F P
0 g
s
.755 .299 .169 r
.28758 .36471 m .2896 .36726 L p .29314 .36542 L F P
0 g
s
.755 .299 .169 r
.29314 .36542 m .28901 .36409 L .28758 .36471 L p F P
0 g
s
.488 .889 .945 r
.55458 .47311 m .55654 .47337 L .54527 .47693 L p F P
0 g
s
.488 .889 .945 r
.54527 .47693 m .54317 .47665 L .55458 .47311 L p F P
0 g
s
0 .3 .76 r
.1595 .28199 m .16029 .28244 L .16426 .28576 L p F P
0 g
s
0 .305 .763 r
.16566 .28552 m .1697 .28882 L .16426 .28576 L p F P
0 g
s
0 .305 .763 r
.16426 .28576 m .16029 .28244 L .16566 .28552 L p F P
0 g
s
.454 .818 .995 r
.41088 .49271 m .40423 .49285 L .40247 .49212 L p F P
0 g
s
.436 .81 .993 r
.40423 .49285 m .40247 .49212 L .39699 .49283 L closepath p F P
0 g
s
.442 .81 .994 r
.39922 .49063 m .40247 .49212 L .39699 .49283 L p F P
0 g
s
.442 .81 .994 r
.38811 .49218 m .39922 .49063 L p .39699 .49283 L F P
0 g
s
.442 .81 .994 r
.39699 .49283 m .38954 .49279 L .38811 .49218 L p F P
0 g
s
.742 .305 .214 r
.30739 .37542 m .31507 .37733 L .31155 .37335 L p F P
0 g
s
.742 .305 .214 r
.30507 .37253 m .30739 .37542 L p .31155 .37335 L F P
0 g
s
.742 .305 .214 r
.31155 .37335 m .30601 .37188 L .30507 .37253 L p F P
0 g
s
.55 0 0 r
.09907 .40808 m .10166 .41021 L .10622 .41317 L p F P
0 g
s
.492 0 0 r
.10635 .41375 m .1109 .41672 L .10622 .41317 L p F P
0 g
s
.492 0 0 r
.10622 .41317 m .10166 .41021 L .10635 .41375 L p F P
0 g
s
.229 0 .025 r
.53211 .35375 m .53244 .35322 L .5216 .35742 L p F P
0 g
s
.229 0 .025 r
.5216 .35742 m .52076 .3588 L .53211 .35375 L p F P
0 g
s
.539 .577 .842 r
.76644 .25363 m .76601 .25359 L .76322 .24794 L p F P
0 g
s
.124 .616 .91 r
.25292 .47686 m .25285 .47683 L .25277 .47682 L closepath p F P
0 g
s
.42 .8 .992 r
.38954 .49279 m .38811 .49218 L .38422 .49261 L closepath p F P
0 g
s
0 .159 .603 r
.18808 .30177 m .19256 .30488 L .18763 .30159 L p F P
0 g
s
0 .159 .603 r
.18763 .30159 m .18327 .29844 L .18808 .30177 L p F P
0 g
s
0 .141 .584 r
.18032 .29635 m .18327 .29844 L .18763 .30159 L p F P
0 g
s
.139 .621 .919 r
.24932 .47514 m .24606 .47468 L .25277 .47682 L p F P
0 g
s
.139 .621 .919 r
.25277 .47682 m .25285 .47683 L .24932 .47514 L p F P
0 g
s
.694 .981 .878 r
.64731 .27707 m .64291 .28004 L .64025 .28021 L p F P
0 g
s
.448 .819 .993 r
.41849 .49251 m .41683 .49184 L .41088 .49271 L closepath p F P
0 g
s
.454 .818 .995 r
.41361 .49039 m .41683 .49184 L .41088 .49271 L p F P
0 g
s
.454 .818 .995 r
.40247 .49212 m .41361 .49039 L p .41088 .49271 L F P
0 g
s
.209 .661 .947 r
.2635 .47792 m .25285 .47683 L .24932 .47514 L p F P
0 g
s
.538 0 0 r
.21055 .31799 m .20612 .31449 L .21097 .31744 L p F P
0 g
s
.538 0 0 r
.21251 .31914 m .21055 .31799 L p .21097 .31744 L F P
0 g
s
.538 0 0 r
.21097 .31744 m .21471 .32027 L .21251 .31914 L p F P
0 g
s
.829 .356 0 r
.05884 .37213 m .05816 .37094 L .05438 .368 L p F P
0 g
s
.673 .283 .298 r
.36807 .39238 m .36884 .39244 L .3709 .38913 L p F P
0 g
s
.673 .283 .298 r
.3709 .38913 m .3639 .38854 L .36807 .39238 L p F P
0 g
s
.756 .935 .944 r
.68868 .2504 m .69135 .25198 L .67987 .25868 L p F P
0 g
s
.756 .935 .944 r
.67854 .25662 m .68868 .2504 L p .67987 .25868 L F P
0 g
s
.756 .935 .944 r
.67987 .25868 m .67764 .25765 L .67854 .25662 L p F P
0 g
s
.425 .801 .993 r
.38483 .49066 m .38811 .49218 L .38422 .49261 L p F P
0 g
s
.425 .801 .993 r
.37377 .49201 m .38483 .49066 L p .38422 .49261 L F P
0 g
s
.425 .801 .993 r
.38422 .49261 m .37441 .49228 L .37377 .49201 L p F P
0 g
s
.518 .55 .828 r
.77783 .2546 m .77734 .25528 L .76644 .25363 L p F P
0 g
s
.518 .55 .828 r
.7753 .24854 m .77783 .2546 L p .76644 .25363 L F P
0 g
s
.518 .55 .828 r
.76644 .25363 m .77008 .24808 L .7753 .24854 L p F P
0 g
s
.539 .577 .842 r
.76322 .24794 m .77008 .24808 L .76644 .25363 L p F P
0 g
s
.619 .24 .303 r
.40067 .39109 m .40475 .39362 L .39936 .3937 L closepath p F P
0 g
s
.566 .193 .293 r
.43033 .38888 m .42922 .38899 L .42759 .39261 L p F P
0 g
s
.762 .286 .112 r
.27293 .35872 m .27938 .36106 L .27592 .35711 L p F P
0 g
s
.762 .286 .112 r
.27017 .35531 m .27293 .35872 L p .27592 .35711 L F P
0 g
s
.762 .286 .112 r
.27592 .35711 m .27087 .35517 L .27017 .35531 L p F P
0 g
s
0 .141 .594 r
.18327 .29844 m .18032 .29635 L .17671 .29356 L p F P
0 g
s
.464 .826 .995 r
.4263 .49213 m .41849 .49251 L .41683 .49184 L p F P
0 g
s
.717 .86 .949 r
.71533 .24316 m .70555 .24783 L .70288 .24567 L p F P
0 g
s
.361 0 0 r
.12975 .42838 m .12557 .4259 L .13041 .42874 L p F P
0 g
s
.361 0 0 r
.13041 .42874 m .13348 .43055 L .12975 .42838 L p F P
0 g
s
0 0 0 r
.60019 .30857 m .59466 .3124 L .59313 .31361 L p F P
0 g
s
.874 .433 .081 r
.04492 .35802 m .04872 .36136 L .04679 .35703 L p F P
0 g
s
.874 .433 .081 r
.04679 .35703 m .04299 .35369 L .04492 .35802 L p F P
0 g
s
.427 .411 .739 r
.78338 .27115 m .78212 .2728 L .77659 .26938 L p F P
0 g
s
.427 .411 .739 r
.78116 .2638 m .78338 .27115 L p .77659 .26938 L F P
0 g
s
.427 .411 .739 r
.77659 .26938 m .78091 .26367 L .78116 .2638 L p F P
0 g
s
.566 .191 .29 r
.4426 .38769 m .43033 .38888 L .43822 .39157 L p F P
0 g
s
.566 .193 .293 r
.42759 .39261 m .43822 .39157 L .43033 .38888 L p F P
0 g
s
.541 0 0 r
.10166 .41021 m .09907 .40808 L .09531 .40567 L p F P
0 g
s
.649 .09 0 r
.23193 .33251 m .22949 .33036 L .23497 .33306 L p F P
0 g
s
.649 .09 0 r
.23497 .33306 m .23555 .33356 L .23193 .33251 L p F P
0 g
s
.593 .218 .3 r
.41503 .39065 m .42002 .39306 L .41372 .39342 L closepath p F P
0 g
s
.413 .826 .636 r
.6832 .41944 m .67448 .42493 L .67314 .4257 L p F P
0 g
s
.122 .605 .914 r
.23035 .4696 m .23162 .47022 L .22225 .46845 L p F P
0 g
s
.122 .605 .914 r
.22633 .4681 m .23035 .4696 L p .22225 .46845 L F P
0 g
s
.122 .605 .914 r
.21752 .46649 m .22633 .4681 L p .22225 .46845 L F P
0 g
s
.122 .605 .914 r
.22225 .46845 m .21967 .46756 L .21752 .46649 L p F P
0 g
s
.676 .141 0 r
.07842 .39144 m .08042 .39363 L .08472 .39671 L p F P
0 g
s
.618 .074 0 r
.08428 .3974 m .08856 .40049 L .08472 .39671 L p F P
0 g
s
.618 .074 0 r
.08472 .39671 m .08042 .39363 L .08428 .3974 L p F P
0 g
s
0 0 .066 r
.76263 .34464 m .76291 .34366 L .75761 .3489 L p F P
0 g
s
0 0 .066 r
.75969 .34935 m .76263 .34464 L p .75761 .3489 L F P
0 g
s
0 0 .066 r
.75372 .35528 m .75969 .34935 L p .75761 .3489 L F P
0 g
s
0 0 .066 r
.75761 .3489 m .75376 .35512 L .75372 .35528 L p F P
0 g
s
.729 .319 .272 r
.32662 .38312 m .33528 .3847 L .33156 .38075 L p F P
0 g
s
.729 .319 .272 r
.33156 .38075 m .32326 .37907 L .32662 .38312 L p F P
0 g
s
.408 .012 .172 r
.49538 .37109 m .49507 .37169 L .4887 .37278 L closepath p F P
0 g
s
.418 .032 .197 r
.49376 .37455 m .49507 .37169 L .4887 .37278 L p F P
0 g
s
.418 .032 .197 r
.48192 .37757 m .49376 .37455 L p .4887 .37278 L F P
0 g
s
.4 .788 .989 r
.37441 .49228 m .37377 .49201 L .37224 .49215 L closepath p F P
0 g
s
.491 .898 .919 r
.58327 .4657 m .57184 .46976 L .56894 .46963 L p F P
0 g
s
.465 .886 .913 r
.55751 .47344 m .56894 .46963 L .57184 .46976 L p F P
0 g
s
.473 .875 .958 r
.52788 .47932 m .5288 .4795 L .51745 .48257 L p F P
0 g
s
.473 .875 .958 r
.51745 .48257 m .51612 .48232 L .52788 .47932 L p F P
0 g
s
.492 .105 .234 r
.46971 .38016 m .46939 .38082 L .46673 .38068 L closepath p F P
0 g
s
.491 .107 .24 r
.46812 .38373 m .46939 .38082 L .46673 .38068 L p F P
0 g
s
.491 .107 .24 r
.45554 .38591 m .46812 .38373 L p .46673 .38068 L F P
0 g
s
.733 .982 .909 r
.65431 .27236 m .64731 .27707 L .65231 .27218 L closepath p F P
0 g
s
.694 .981 .878 r
.65162 .27213 m .65231 .27218 L .64731 .27707 L p F P
0 g
s
.694 .981 .878 r
.64039 .28008 m .65162 .27213 L p .64731 .27707 L F P
0 g
s
.694 .981 .878 r
.64025 .28021 m .64039 .28008 L p .64731 .27707 L F P
0 g
s
.418 .787 .994 r
.37047 .49046 m .36112 .49142 L .37224 .49215 L p F P
0 g
s
.418 .787 .994 r
.37224 .49215 m .37377 .49201 L .37047 .49046 L p F P
0 g
s
.402 .788 .99 r
.35944 .49157 m .36112 .49142 L .37224 .49215 L p F P
0 g
s
.842 .379 .01 r
.0506 .3649 m .04872 .36136 L .0526 .36465 L p F P
0 g
s
.842 .379 .01 r
.0526 .36465 m .05438 .368 L .0506 .3649 L p F P
0 g
s
.685 .287 .286 r
.35762 .39139 m .36807 .39238 L .3639 .38854 L p F P
0 g
s
.685 .287 .286 r
.35439 .38795 m .35762 .39139 L p .3639 .38854 L F P
0 g
s
.685 .287 .286 r
.3639 .38854 m .35469 .38753 L .35439 .38795 L p F P
0 g
s
.457 .827 .992 r
.43237 .49178 m .4312 .49133 L .4263 .49213 L closepath p F P
0 g
s
.464 .826 .995 r
.428 .48993 m .4312 .49133 L .4263 .49213 L p F P
0 g
s
.464 .826 .995 r
.41683 .49184 m .428 .48993 L p .4263 .49213 L F P
0 g
s
.403 .788 .99 r
.35944 .49157 m .36112 .49142 L .35872 .49126 L closepath p F P
0 g
s
.476 .482 .785 r
.78106 .26347 m .78091 .26367 L .77317 .26097 L p F P
0 g
s
.476 .482 .785 r
.77819 .2555 m .78106 .26347 L p .77317 .26097 L F P
0 g
s
.476 .482 .785 r
.77317 .26097 m .77734 .25528 L .77819 .2555 L p F P
0 g
s
.073 0 .303 r
.77225 .32743 m .76935 .33051 L .77113 .3247 L p F P
0 g
s
.073 0 .303 r
.77113 .3247 m .77258 .32316 L .77225 .32743 L p F P
0 g
s
.338 .737 .983 r
.30975 .48548 m .29892 .48546 L .29547 .48385 L p F P
0 g
s
.396 0 0 r
.19847 .30871 m .19751 .30812 L .1972 .30792 L closepath p F P
0 g
s
.06 0 0 r
.55775 .33711 m .55155 .34056 L .55717 .33789 L closepath p F P
0 g
s
.098 0 0 r
.55516 .34069 m .55717 .33789 L .55155 .34056 L p F P
0 g
s
.098 0 0 r
.54492 .34568 m .55516 .34069 L p .55155 .34056 L F P
0 g
s
.761 .267 .052 r
.25719 .34986 m .26323 .35235 L .25964 .34847 L p F P
0 g
s
.761 .267 .052 r
.25964 .34847 m .25381 .34591 L .25719 .34986 L p F P
0 g
s
.755 .256 .036 r
.25283 .3448 m .25381 .34591 L .25964 .34847 L p F P
0 g
s
.315 0 .114 r
.51807 .36386 m .5198 .36058 L .50862 .36438 L p F P
0 g
s
.315 0 .114 r
.50862 .36438 m .50689 .36768 L .51807 .36386 L p F P
0 g
s
.429 .826 .613 r
.60603 .30457 m .60019 .30857 L .60491 .30528 L closepath p F P
0 g
s
0 0 0 r
.60327 .30635 m .60491 .30528 L .60019 .30857 L p F P
0 g
s
0 0 0 r
.59817 .31003 m .60327 .30635 L p .60019 .30857 L F P
0 g
s
0 0 0 r
.59313 .31361 m .59817 .31003 L p .60019 .30857 L F P
0 g
s
.741 .219 0 r
.23866 .33687 m .23555 .33356 L .23193 .33251 L p F P
0 g
s
.471 .834 .993 r
.44384 .4909 m .43237 .49178 L .4312 .49133 L p F P
0 g
s
.255 .175 .57 r
.78604 .29152 m .78153 .29723 L .77991 .29251 L p F P
0 g
s
.255 .175 .57 r
.77991 .29251 m .78437 .28682 L .78604 .29152 L p F P
0 g
s
.461 .075 .219 r
.48066 .38028 m .48192 .37757 L .46971 .38016 L p F P
0 g
s
.461 .075 .219 r
.46971 .38016 m .46939 .38082 L .48066 .38028 L p F P
0 g
s
.829 .356 0 r
.05438 .368 m .05487 .36888 L .05884 .37213 L p F P
0 g
s
.777 .28 0 r
.05763 .37296 m .0616 .37621 L .05884 .37213 L p F P
0 g
s
.777 .28 0 r
.05884 .37213 m .05487 .36888 L .05763 .37296 L p F P
0 g
s
.013 .529 .861 r
.2035 .46221 m .20996 .46378 L .216 .46615 L p F P
0 g
s
.028 .537 .87 r
.20996 .46378 m .2035 .46221 L .19988 .4604 L p F P
0 g
s
.735 .269 .144 r
.28901 .36409 m .28758 .36471 L .28621 .36326 L closepath p F P
0 g
s
.297 .721 .972 r
.29201 .48217 m .29547 .48385 L .28823 .48364 L p F P
0 g
s
.297 .721 .972 r
.28122 .48195 m .29201 .48217 L p .28823 .48364 L F P
0 g
s
.297 .721 .972 r
.28823 .48364 m .28199 .48231 L .28122 .48195 L p F P
0 g
s
.669 .136 0 r
.08042 .39363 m .07842 .39144 L .07464 .38879 L p F P
0 g
s
.023 .435 .867 r
.14223 .27127 m .1462 .27298 L .14998 .27639 L p F P
0 g
s
.057 .458 .882 r
.15227 .27543 m .1462 .27298 L .14998 .27639 L p F P
0 g
s
.057 .458 .882 r
.14998 .27639 m .15588 .27876 L .15227 .27543 L p F P
0 g
s
.499 .872 .979 r
.51442 .48192 m .50308 .48481 L .50003 .48398 L p F P
0 g
s
.479 .864 .977 r
.48871 .48666 m .50003 .48398 L .50308 .48481 L p F P
0 g
s
.47 .804 .999 r
.38483 .49066 m .37377 .49201 L .37047 .49046 L p F P
0 g
s
.036 .437 .871 r
.1462 .27298 m .14223 .27127 L .13861 .26783 L p F P
0 g
s
.039 .549 .875 r
.21967 .46756 m .21752 .46649 L .216 .46615 L closepath p F P
0 g
s
.728 .286 .2 r
.30601 .37188 m .30507 .37253 L .30402 .3714 L closepath p F P
0 g
s
.436 .795 .996 r
.36715 .48879 m .37047 .49046 L .36112 .49142 L p F P
0 g
s
.436 .795 .996 r
.35611 .49004 m .36715 .48879 L p .36112 .49142 L F P
0 g
s
.436 .795 .996 r
.36112 .49142 m .35872 .49126 L .35611 .49004 L p F P
0 g
s
.431 0 0 r
.11245 .41778 m .1109 .41672 L .11552 .41966 L p F P
0 g
s
.431 0 0 r
.11552 .41966 m .11619 .42011 L .11245 .41778 L p F P
0 g
s
.741 .893 .948 r
.69176 .25225 m .69135 .25198 L .69256 .25132 L closepath p F P
0 g
s
0 0 .135 r
.76372 .34281 m .76291 .34366 L .76369 .33991 L p F P
0 g
s
0 0 .135 r
.76369 .33991 m .76687 .33656 L .76372 .34281 L p F P
0 g
s
.728 .303 .238 r
.32265 .37837 m .32326 .37907 L .32214 .37882 L closepath p F P
0 g
s
.727 .981 .911 r
.66236 .26703 m .65431 .27236 L .65231 .27218 L p F P
0 g
s
.169 .037 .446 r
.78042 .30967 m .77727 .3133 L .7774 .30802 L p F P
0 g
s
.169 .037 .446 r
.7774 .30802 m .78022 .30476 L .78042 .30967 L p F P
0 g
s
0 .333 .777 r
.1731 .29064 m .1697 .28882 L .17387 .29206 L p F P
0 g
s
0 .333 .777 r
.17387 .29206 m .17671 .29356 L .1731 .29064 L p F P
0 g
s
.533 .158 .275 r
.45139 .38647 m .4426 .38769 L .44098 .3913 L p F P
0 g
s
.566 .191 .29 r
.43822 .39157 m .44098 .3913 L .4426 .38769 L p F P
0 g
s
0 0 0 r
.73253 .3797 m .73146 .38126 L .73593 .37675 L closepath p F P
0 g
s
.407 .781 .993 r
.35872 .49126 m .35611 .49004 L .35075 .49046 L closepath p F P
0 g
s
.671 .123 0 r
.21471 .32027 m .2154 .32095 L .2203 .32387 L p F P
0 g
s
.68 .134 0 r
.21917 .32469 m .22423 .32757 L .2203 .32387 L p F P
0 g
s
.68 .134 0 r
.2203 .32387 m .2154 .32095 L .21917 .32469 L p F P
0 g
s
0 .177 .601 r
.1939 .30577 m .19256 .30488 L .1972 .30792 L p F P
0 g
s
0 .177 .601 r
.1972 .30792 m .19751 .30812 L .1939 .30577 L p F P
0 g
s
0 .397 .761 r
.16836 .44813 m .17018 .44881 L .1757 .45139 L p F P
0 g
s
0 .43 .793 r
.17795 .45149 m .17018 .44881 L .1757 .45139 L p F P
0 g
s
0 .43 .793 r
.17994 .45245 m .17795 .45149 L p .1757 .45139 L F P
0 g
s
0 .43 .793 r
.1757 .45139 m .18226 .45367 L .17994 .45245 L p F P
0 g
s
.572 .021 0 r
.09154 .40315 m .08856 .40049 L .09292 .40354 L p F P
0 g
s
.572 .021 0 r
.09292 .40354 m .09531 .40567 L .09154 .40315 L p F P
0 g
s
.45 .838 .62 r
.61395 .29897 m .60603 .30457 L .60491 .30528 L p F P
0 g
s
0 0 0 r
.68593 .41764 m .6832 .41944 L .68544 .41798 L closepath p F P
0 g
s
.413 .826 .636 r
.68336 .41911 m .68544 .41798 L .6832 .41944 L p F P
0 g
s
.413 .826 .636 r
.6788 .42202 m .68336 .41911 L p .6832 .41944 L F P
0 g
s
.413 .826 .636 r
.67314 .4257 m .6788 .42202 L p .6832 .41944 L F P
0 g
s
.689 .292 .289 r
.35469 .38753 m .35439 .38795 L .35386 .38743 L closepath p F P
0 g
s
0 .322 .702 r
.15088 .43985 m .15255 .4406 L .1578 .44328 L p F P
0 g
s
0 .359 .74 r
.15954 .4435 m .15255 .4406 L .1578 .44328 L p F P
0 g
s
0 .359 .74 r
.16459 .44614 m .15954 .4435 L p .1578 .44328 L F P
0 g
s
0 .359 .74 r
.1578 .44328 m .16468 .44619 L .16459 .44614 L p F P
0 g
s
.687 .293 .295 r
.34787 .39017 m .34424 .38617 L .35386 .38743 L p F P
0 g
s
.687 .293 .295 r
.35251 .39076 m .34787 .39017 L p .35386 .38743 L F P
0 g
s
.687 .293 .295 r
.35386 .38743 m .35439 .38795 L .35251 .39076 L p F P
0 g
s
.484 .812 1 r
.39922 .49063 m .38811 .49218 L .38483 .49066 L p F P
0 g
s
.741 .23 0 r
.06463 .38022 m .06866 .38343 L .06564 .37942 L p F P
0 g
s
.741 .23 0 r
.06564 .37942 m .0616 .37621 L .06463 .38022 L p F P
0 g
s
.732 .209 0 r
.24229 .34071 m .24802 .34333 L .24418 .33955 L p F P
0 g
s
.732 .209 0 r
.24418 .33955 m .23866 .33687 L .24229 .34071 L p F P
0 g
s
0 0 .077 r
.75376 .35512 m .75356 .35543 L .75372 .35528 L closepath p F P
0 g
s
.483 .864 .978 r
.50003 .48398 m .48871 .48666 L .48563 .48576 L p F P
0 g
s
.47 .856 .98 r
.47434 .48825 m .48563 .48576 L .48871 .48666 L p F P
0 g
s
.496 .905 .887 r
.60902 .45654 m .59756 .46118 L .59473 .46133 L p F P
0 g
s
.574 .02 0 r
.20143 .31147 m .19751 .30812 L .1939 .30577 L p F P
0 g
s
.23 .68 .952 r
.26701 .47954 m .27298 .47997 L .28033 .48189 L p F P
0 g
s
.248 .689 .959 r
.27298 .47997 m .26701 .47954 L .2635 .47792 L p F P
0 g
s
.729 .286 .199 r
.30001 .37341 m .29658 .36941 L .30402 .3714 L p F P
0 g
s
.729 .286 .199 r
.30275 .37412 m .30001 .37341 L p .30402 .3714 L F P
0 g
s
.729 .286 .199 r
.30402 .3714 m .30507 .37253 L .30275 .37412 L p F P
0 g
s
0 0 0 r
.7525 .35854 m .74848 .36228 L .75356 .35543 L p F P
0 g
s
0 0 0 r
.75356 .35543 m .75372 .35528 L .7525 .35854 L p F P
0 g
s
.482 .899 .836 r
.62354 .45108 m .62328 .45112 L .62551 .45009 L closepath p F P
0 g
s
.471 .096 .246 r
.48032 .3811 m .48066 .38028 L .46939 .38082 L p F P
0 g
s
.471 .096 .246 r
.46939 .38082 m .46812 .38373 L .48032 .3811 L p F P
0 g
s
0 .466 .814 r
.18591 .45554 m .18924 .45656 L .19503 .45903 L p F P
0 g
s
0 .495 .841 r
.19625 .45852 m .18924 .45656 L .19503 .45903 L p F P
0 g
s
0 .495 .841 r
.19503 .45903 m .19988 .4604 L .19625 .45852 L p F P
0 g
s
.462 .835 .99 r
.44593 .49072 m .44558 .49059 L .44384 .4909 L closepath p F P
0 g
s
.471 .834 .993 r
.44241 .48926 m .44558 .49059 L .44384 .4909 L p F P
0 g
s
.471 .834 .993 r
.4312 .49133 m .44241 .48926 L p .44384 .4909 L F P
0 g
s
.459 .877 .752 r
.65775 .43382 m .66041 .43298 L .64893 .43914 L p F P
0 g
s
.459 .877 .752 r
.65283 .4365 m .65775 .43382 L p .64893 .43914 L F P
0 g
s
.459 .877 .752 r
.64893 .43914 m .64726 .43971 L .65283 .4365 L p F P
0 g
s
.48 .891 .925 r
.5676 .46953 m .56894 .46963 L .55751 .47344 L p F P
0 g
s
.48 .891 .925 r
.55751 .47344 m .55654 .47337 L .5676 .46953 L p F P
0 g
s
0 0 0 r
.56716 .33257 m .56912 .33009 L .55775 .33711 L p F P
0 g
s
0 0 0 r
.55775 .33711 m .55717 .33789 L .56716 .33257 L p F P
0 g
s
0 0 0 r
.69728 .40983 m .68593 .41764 L .68544 .41798 L p F P
0 g
s
.735 .268 .138 r
.28286 .36502 m .27938 .36106 L .28621 .36326 L p F P
0 g
s
.735 .268 .138 r
.28512 .36573 m .28286 .36502 L p .28621 .36326 L F P
0 g
s
.735 .268 .138 r
.28621 .36326 m .28758 .36471 L .28512 .36573 L p F P
0 g
s
.347 .748 .983 r
.32541 .48743 m .32746 .48837 L p .31318 .48705 L F P
0 g
s
.347 .748 .983 r
.31318 .48705 m .32194 .48684 L .32541 .48743 L p F P
0 g
s
.375 .757 .989 r
.32194 .48684 m .31318 .48705 L .30975 .48548 L p F P
0 g
s
.122 .611 .911 r
.23518 .4719 m .23937 .47254 L .24606 .47468 L p F P
0 g
s
.139 .62 .919 r
.23937 .47254 m .23518 .4719 L .23162 .47022 L p F P
0 g
s
0 0 0 r
.75495 .35612 m .7525 .35854 L .75372 .35528 L p F P
0 g
s
0 0 0 r
.75372 .35528 m .75969 .34935 L .75495 .35612 L p F P
0 g
s
.199 .097 .506 r
.78224 .30224 m .78022 .30476 L .77973 .29947 L p F P
0 g
s
.199 .097 .506 r
.77973 .29947 m .78153 .29723 L .78224 .30224 L p F P
0 g
s
.384 0 0 r
.12081 .42302 m .11619 .42011 L .11245 .41778 L p F P
0 g
s
.618 .663 .871 r
.75813 .23872 m .75436 .24364 L p .74586 .24048 L F P
0 g
s
.595 .645 .87 r
.75436 .24364 m .75813 .23872 L .76045 .24275 L closepath p F P
0 g
s
.56 .581 .831 r
.77008 .24808 m .76322 .24794 L .76045 .24275 L p F P
0 g
s
.262 0 .076 r
.53067 .3564 m .53211 .35375 L .52076 .3588 L p F P
0 g
s
.262 0 .076 r
.52076 .3588 m .5198 .36058 L .53067 .3564 L p F P
0 g
s
.737 .909 .953 r
.69256 .25132 m .69135 .25198 L .68868 .2504 L p F P
0 g
s
.484 .845 .992 r
.45681 .48836 m .45912 .48927 L .44593 .49072 L p F P
0 g
s
.484 .845 .992 r
.44593 .49072 m .44558 .49059 L .45681 .48836 L p F P
0 g
s
.732 .24 .07 r
.27087 .35517 m .27017 .35531 L .2696 .35473 L closepath p F P
0 g
s
.734 .317 .258 r
.31936 .38151 m .32662 .38312 L .32326 .37907 L p F P
0 g
s
.734 .317 .258 r
.32326 .37907 m .32214 .37882 L .31936 .38151 L p F P
0 g
s
.368 0 .153 r
.5064 .36865 m .50689 .36768 L .49538 .37109 L p F P
0 g
s
.368 0 .153 r
.49538 .37109 m .49507 .37169 L .5064 .36865 L p F P
0 g
s
.495 .82 1 r
.41361 .49039 m .40247 .49212 L .39922 .49063 L p F P
0 g
s
0 .474 .825 r
.18924 .45656 m .18591 .45554 L .18226 .45367 L p F P
0 g
s
.155 .628 .927 r
.24578 .47339 m .23937 .47254 L .24606 .47468 L p F P
0 g
s
.155 .628 .927 r
.24606 .47468 m .24932 .47514 L .24578 .47339 L p F P
0 g
s
.486 .857 .986 r
.48463 .48542 m .48563 .48576 L .47434 .48825 L p F P
0 g
s
.486 .857 .986 r
.47434 .48825 m .47202 .48751 L .48463 .48542 L p F P
0 g
s
.461 .848 .981 r
.47202 .48751 m .47434 .48825 L p .45996 .48956 L F P
0 g
s
.037 0 .291 r
.77471 .32462 m .77225 .32743 L .77258 .32316 L p F P
0 g
s
.037 0 .291 r
.77258 .32316 m .77635 .31884 L .77471 .32462 L p F P
0 g
s
.754 .249 .008 r
.25283 .3448 m .25381 .34591 L .25106 .34463 L closepath p F P
0 g
s
0 .245 .64 r
.13348 .43055 m .13616 .43199 L .14115 .43477 L p F P
0 g
s
0 .284 .68 r
.1424 .4351 m .13616 .43199 L .14115 .43477 L p F P
0 g
s
0 .284 .68 r
.14664 .43749 m .1424 .4351 L p .14115 .43477 L F P
0 g
s
0 .284 .68 r
.14115 .43477 m .14717 .4378 L .14664 .43749 L p F P
0 g
s
.696 .304 .301 r
.35439 .38795 m .35762 .39139 L .35251 .39076 L closepath p F P
0 g
s
.737 .909 .953 r
.68868 .2504 m .69738 .24532 L .69256 .25132 L p F P
0 g
s
.754 .909 .944 r
.69256 .25132 m .70288 .24567 L .7002 .24367 L p F P
0 g
s
.754 .909 .944 r
.7002 .24367 m .69738 .24532 L .69256 .25132 L p F P
0 g
s
.662 .725 .896 r
.73144 .24051 m .74316 .23663 L .74586 .24048 L p F P
0 g
s
.677 .747 .904 r
.74316 .23663 m .73144 .24051 L .72875 .23734 L p F P
0 g
s
.699 .782 .916 r
.71712 .2423 m .72875 .23734 L .73144 .24051 L p F P
0 g
s
0 .302 .766 r
.16029 .28244 m .1595 .28199 L .15588 .27876 L p F P
0 g
s
.411 .784 .994 r
.35277 .48836 m .35611 .49004 L .35075 .49046 L p F P
0 g
s
.411 .784 .994 r
.34177 .48937 m .35277 .48836 L p .35075 .49046 L F P
0 g
s
.411 .784 .994 r
.35075 .49046 m .34244 .48968 L .34177 .48937 L p F P
0 g
s
.726 .307 .251 r
.31856 .38134 m .31936 .38151 L .32214 .37882 L p F P
0 g
s
.726 .307 .251 r
.32214 .37882 m .31507 .37733 L .31856 .38134 L p F P
0 g
s
.496 .906 .849 r
.62551 .45009 m .62328 .45112 L .62051 .4515 L p F P
0 g
s
.503 .827 1 r
.428 .48993 m .41683 .49184 L .41361 .49039 L p F P
0 g
s
.461 .848 .981 r
.45996 .48956 m .4655 .48843 L .47202 .48751 L p F P
0 g
s
.483 .848 .99 r
.45996 .48956 m .4655 .48843 L .45912 .48927 L closepath p F P
0 g
s
.72 .832 .934 r
.71712 .2423 m .71533 .24316 L .71638 .2416 L closepath p F P
0 g
s
.717 .86 .949 r
.71444 .23976 m .71638 .2416 L .71533 .24316 L p F P
0 g
s
.717 .86 .949 r
.70288 .24567 m .71444 .23976 L p .71533 .24316 L F P
0 g
s
.45 .838 .62 r
.61467 .29787 m .61666 .29689 L .61395 .29897 L p F P
0 g
s
.45 .838 .62 r
.6107 .30081 m .61467 .29787 L p .61395 .29897 L F P
0 g
s
.45 .838 .62 r
.60491 .30528 m .6107 .30081 L p .61395 .29897 L F P
0 g
s
.535 .902 .71 r
.61741 .29653 m .61395 .29897 L .61666 .29689 L closepath p F P
0 g
s
.754 .97 .928 r
.66574 .2648 m .66236 .26703 L .66469 .26455 L closepath p F P
0 g
s
.727 .981 .911 r
.66305 .26418 m .66469 .26455 L .66236 .26703 L p F P
0 g
s
.727 .981 .911 r
.65392 .27053 m .66305 .26418 L p .66236 .26703 L F P
0 g
s
.727 .981 .911 r
.65231 .27218 m .65392 .27053 L p .66236 .26703 L F P
0 g
s
.733 .237 .06 r
.26652 .35589 m .26323 .35235 L .2696 .35473 L p F P
0 g
s
.733 .237 .06 r
.2696 .35473 m .27017 .35531 L .26652 .35589 L p F P
0 g
s
.501 .879 .973 r
.5258 .4788 m .52788 .47932 L .51612 .48232 L p F P
0 g
s
.501 .879 .973 r
.51612 .48232 m .51442 .48192 L .5258 .4788 L p F P
0 g
s
.509 .835 .999 r
.44241 .48926 m .4312 .49133 L .428 .48993 L p F P
0 g
s
.693 .168 0 r
.07086 .38601 m .06866 .38343 L .07277 .38661 L p F P
0 g
s
.693 .168 0 r
.07277 .38661 m .07464 .38879 L .07086 .38601 L p F P
0 g
s
.239 .687 .955 r
.28199 .48231 m .28122 .48195 L .28033 .48189 L closepath p F P
0 g
s
.514 .842 .998 r
.45681 .48836 m .44558 .49059 L .44241 .48926 L p F P
0 g
s
.536 .16 .275 r
.45554 .38591 m .45496 .3872 L .45139 .38647 L closepath p F P
0 g
s
.533 .158 .275 r
.45399 .38958 m .45496 .3872 L .45139 .38647 L p F P
0 g
s
.533 .158 .275 r
.44098 .3913 m .45399 .38958 L p .45139 .38647 L F P
0 g
s
.618 .663 .871 r
.74586 .24048 m .7577 .23798 L .75813 .23872 L p F P
0 g
s
.634 .685 .88 r
.7577 .23798 m .74586 .24048 L .74316 .23663 L p F P
0 g
s
.051 .553 .883 r
.21393 .46465 m .20996 .46378 L .216 .46615 L p F P
0 g
s
.051 .553 .883 r
.216 .46615 m .21752 .46649 L .21393 .46465 L p F P
0 g
s
.004 0 .218 r
.77169 .33142 m .76687 .33656 L .76935 .33051 L p F P
0 g
s
.004 0 .218 r
.76935 .33051 m .77225 .32743 L .77169 .33142 L p F P
0 g
s
.546 .907 .713 r
.62721 .28951 m .61741 .29653 L .61666 .29689 L p F P
0 g
s
.712 .83 .938 r
.72607 .23438 m .72875 .23734 L .71712 .2423 L p F P
0 g
s
.712 .83 .938 r
.71986 .23726 m .72607 .23438 L p .71712 .2423 L F P
0 g
s
.712 .83 .938 r
.71712 .2423 m .71638 .2416 L .71986 .23726 L p F P
0 g
s
0 .253 .654 r
.13616 .43199 m .13348 .43055 L .12975 .42838 L p F P
0 g
s
.541 0 0 r
.09531 .40567 m .09717 .40721 L .10166 .41021 L p F P
0 g
s
.475 0 0 r
.10188 .41074 m .10635 .41375 L .10166 .41021 L p F P
0 g
s
.475 0 0 r
.10166 .41021 m .09717 .40721 L .10188 .41074 L p F P
0 g
s
.459 .884 .802 r
.63475 .44569 m .62551 .45009 L .63361 .44595 L closepath p F P
0 g
s
.496 .906 .849 r
.63201 .44616 m .63361 .44595 L .62551 .45009 L p F P
0 g
s
.496 .906 .849 r
.62051 .4515 m .63201 .44616 L p .62551 .45009 L F P
0 g
s
.558 0 0 r
.20572 .31502 m .21055 .31799 L .20612 .31449 L p F P
0 g
s
.558 0 0 r
.20612 .31449 m .20143 .31147 L .20572 .31502 L p F P
0 g
s
0 .404 .772 r
.17018 .44881 m .16836 .44813 L .16468 .44619 L p F P
0 g
s
0 0 0 r
.74943 .36313 m .74279 .36933 L .74848 .36228 L p F P
0 g
s
0 0 0 r
.75163 .36039 m .74943 .36313 L p .74848 .36228 L F P
0 g
s
0 0 0 r
.74848 .36228 m .7525 .35854 L .75163 .36039 L p F P
0 g
s
.759 .971 .926 r
.67451 .25644 m .67719 .25744 L .66574 .2648 L p F P
0 g
s
.759 .971 .926 r
.66816 .26074 m .67451 .25644 L p .66574 .2648 L F P
0 g
s
.759 .971 .926 r
.66574 .2648 m .66469 .26455 L .66816 .26074 L p F P
0 g
s
.388 .007 .189 r
.50528 .37113 m .5064 .36865 L .49507 .37169 L p F P
0 g
s
.388 .007 .189 r
.49507 .37169 m .49376 .37455 L .50528 .37113 L p F P
0 g
s
.656 .1 0 r
.22825 .33125 m .22423 .32757 L .22949 .33036 L p F P
0 g
s
.656 .1 0 r
.22839 .33132 m .22825 .33125 L p .22949 .33036 L F P
0 g
s
.656 .1 0 r
.22949 .33036 m .23193 .33251 L .22839 .33132 L p F P
0 g
s
0 .153 .606 r
.18374 .29859 m .18808 .30177 L .18327 .29844 L p F P
0 g
s
0 .153 .606 r
.18327 .29844 m .17903 .29524 L .18374 .29859 L p F P
0 g
s
0 .141 .594 r
.17671 .29356 m .17903 .29524 L .18327 .29844 L p F P
0 g
s
.752 .319 .223 r
.30507 .37253 m .30739 .37542 L .30275 .37412 L closepath p F P
0 g
s
.713 .311 .285 r
.3387 .38876 m .34787 .39017 L .34424 .38617 L p F P
0 g
s
.713 .311 .285 r
.33667 .38626 m .3387 .38876 L p .34424 .38617 L F P
0 g
s
.713 .311 .285 r
.34424 .38617 m .33761 .38508 L .33667 .38626 L p F P
0 g
s
.253 .689 .961 r
.27774 .48023 m .27298 .47997 L .28033 .48189 L p F P
0 g
s
.253 .689 .961 r
.28033 .48189 m .28122 .48195 L .27774 .48023 L p F P
0 g
s
.311 .25 .626 r
.78635 .28429 m .78437 .28682 L .78166 .28246 L p F P
0 g
s
.311 .25 .626 r
.78166 .28246 m .78511 .27804 L .78635 .28429 L p F P
0 g
s
0 .302 .766 r
.15588 .27876 m .15642 .27907 L .16029 .28244 L p F P
0 g
s
0 .305 .768 r
.16175 .28216 m .16566 .28552 L .16029 .28244 L p F P
0 g
s
0 .305 .768 r
.16029 .28244 m .15642 .27907 L .16175 .28216 L p F P
0 g
s
.381 .766 .989 r
.32746 .48837 m .33117 .48817 L .34057 .48944 L p F P
0 g
s
.375 .767 .988 r
.32746 .48837 m .33117 .48817 L .32541 .48743 L closepath p F P
0 g
s
0 0 0 r
.68544 .41798 m .69397 .41207 L p .69728 .40983 L F P
0 g
s
.459 .854 .66 r
.68544 .41798 m .68336 .41911 L .69397 .41207 L closepath p F P
0 g
s
0 .33 .715 r
.15255 .4406 m .15088 .43985 L .14717 .4378 L p F P
0 g
s
0 .209 .618 r
.12602 .42612 m .12081 .42302 L .12557 .4259 L p F P
0 g
s
0 .209 .618 r
.12557 .4259 m .12975 .42838 L .12602 .42612 L p F P
0 g
s
.777 .311 .136 r
.27293 .35872 m .27017 .35531 L .26652 .35589 L p F P
0 g
s
.377 .767 .988 r
.34244 .48968 m .34177 .48937 L .34057 .48944 L closepath p F P
0 g
s
.499 .891 .953 r
.55458 .47311 m .54317 .47665 L .5402 .47619 L p F P
0 g
s
.477 .881 .95 r
.5288 .4795 m .5402 .47619 L .54317 .47665 L p F P
0 g
s
.495 .903 .909 r
.58355 .46571 m .58327 .4657 L .58737 .46415 L closepath p F P
0 g
s
.509 .134 .263 r
.46659 .38738 m .46812 .38373 L .45554 .38591 L p F P
0 g
s
.509 .134 .263 r
.46302 .38799 m .46659 .38738 L p .45554 .38591 L F P
0 g
s
.509 .134 .263 r
.45554 .38591 m .45496 .3872 L .46302 .38799 L p F P
0 g
s
0 0 0 r
.69736 .40978 m .69728 .40983 L .69734 .40979 L closepath p F P
0 g
s
0 0 0 r
.69484 .41147 m .69734 .40979 L .69728 .40983 L p F P
0 g
s
0 0 0 r
.69397 .41207 m .69484 .41147 L p .69728 .40983 L F P
0 g
s
0 0 0 r
.70877 .40119 m .69736 .40978 L p .7017 .40658 L F P
0 g
s
0 0 0 r
.70641 .40311 m .70877 .40119 L p .7017 .40658 L F P
0 g
s
.443 .83 .603 r
.69484 .41147 m .70629 .40319 L p .69757 .40962 L F P
0 g
s
0 0 0 r
.69736 .40978 m .69734 .40979 L .7064 .40312 L p F P
0 g
s
.443 .83 .603 r
.69734 .40979 m .69734 .40979 L p .69757 .40962 L F P
0 g
s
.443 .83 .603 r
.69734 .40979 m .69484 .41147 L p .69757 .40962 L F P
0 g
s
0 0 0 r
.7064 .40312 m .70641 .40311 L p .7017 .40658 L F P
0 g
s
.443 .83 .603 r
.70629 .40319 m .7064 .40312 L .69734 .40979 L p F P
0 g
s
.472 .874 .712 r
.67314 .4257 m .67188 .42625 L .6788 .42202 L closepath p F P
0 g
s
.768 .272 .042 r
.25142 .34727 m .25719 .34986 L .25381 .34591 L p F P
0 g
s
.768 .272 .042 r
.24919 .34451 m .25142 .34727 L p .25381 .34591 L F P
0 g
s
.768 .272 .042 r
.25381 .34591 m .25106 .34463 L .24919 .34451 L p F P
0 g
s
0 0 0 r
.56927 .32992 m .56912 .33009 L .57009 .32943 L closepath p F P
0 g
s
0 0 0 r
.56628 .3337 m .56716 .33257 L .55717 .33789 L p F P
0 g
s
0 0 0 r
.55704 .33967 m .56628 .3337 L p .55717 .33789 L F P
0 g
s
0 0 0 r
.55717 .33789 m .55516 .34069 L .55704 .33967 L p F P
0 g
s
.624 .251 .316 r
.40475 .39362 m .39936 .3937 L .39764 .39732 L p F P
0 g
s
.643 .272 .326 r
.39601 .3973 m .39764 .39732 L .39936 .3937 L p F P
0 g
s
.643 .272 .326 r
.39936 .3937 m .39131 .39359 L .39601 .3973 L p F P
0 g
s
.394 .766 .992 r
.33841 .48768 m .33117 .48817 L .34057 .48944 L p F P
0 g
s
.394 .766 .992 r
.34057 .48944 m .34177 .48937 L .33841 .48768 L p F P
0 g
s
.322 .722 .98 r
.29201 .48217 m .28122 .48195 L .27774 .48023 L p F P
0 g
s
.765 .312 .175 r
.28758 .36471 m .2896 .36726 L .28512 .36573 L closepath p F P
0 g
s
0 0 0 r
.58126 .32184 m .5805 .32257 L .58486 .3195 L closepath p F P
0 g
s
.606 .064 0 r
.08007 .39427 m .08428 .3974 L .08042 .39363 L p F P
0 g
s
.606 .064 0 r
.08042 .39363 m .0762 .3905 L .08007 .39427 L p F P
0 g
s
.669 .136 0 r
.07464 .38879 m .0762 .3905 L .08042 .39363 L p F P
0 g
s
.622 .254 .324 r
.41372 .39342 m .40475 .39362 L .41006 .39713 L p F P
0 g
s
.624 .251 .316 r
.39764 .39732 m .41006 .39713 L .40475 .39362 L p F P
0 g
s
.826 .353 0 r
.05487 .36888 m .05438 .368 L .0506 .3649 L p F P
0 g
s
.647 .27 .315 r
.38345 .39698 m .39601 .3973 L .39131 .39359 L p F P
0 g
s
.647 .27 .315 r
.38285 .39646 m .38345 .39698 L p .39131 .39359 L F P
0 g
s
.647 .27 .315 r
.39131 .39359 m .38444 .39341 L .38285 .39646 L p F P
0 g
s
.509 .898 .948 r
.56602 .46932 m .5676 .46953 L .55654 .47337 L p F P
0 g
s
.509 .898 .948 r
.55654 .47337 m .55458 .47311 L .56602 .46932 L p F P
0 g
s
.088 0 0 r
.55488 .3411 m .55516 .34069 L .54492 .34568 L p F P
0 g
s
.088 0 0 r
.54492 .34568 m .54349 .34783 L .55488 .3411 L p F P
0 g
s
.659 .11 0 r
.21471 .32027 m .2154 .32095 L .21251 .31914 L closepath p F P
0 g
s
.428 .046 .21 r
.49219 .37808 m .49376 .37455 L .48192 .37757 L p F P
0 g
s
.428 .046 .21 r
.48797 .37914 m .49219 .37808 L p .48192 .37757 L F P
0 g
s
.428 .046 .21 r
.48192 .37757 m .48066 .38028 L .48797 .37914 L p F P
0 g
s
.506 .849 .995 r
.4655 .48843 m .45912 .48927 L .45681 .48836 L p F P
0 g
s
.122 .598 .916 r
.22633 .4681 m .21752 .46649 L .21393 .46465 L p F P
0 g
s
.513 .908 .922 r
.58737 .46415 m .58327 .4657 L .58039 .46555 L p F P
0 g
s
.491 .898 .919 r
.56894 .46963 m .58039 .46555 L .58327 .4657 L p F P
0 g
s
.598 .229 .313 r
.42002 .39306 m .41372 .39342 L .41208 .39709 L p F P
0 g
s
.622 .254 .324 r
.41006 .39713 m .41208 .39709 L .41372 .39342 L p F P
0 g
s
.661 .285 .322 r
.38444 .39341 m .38285 .39646 L .37917 .39315 L closepath p F P
0 g
s
0 0 0 r
.59313 .31361 m .59188 .31462 L .59817 .31003 L closepath p F P
0 g
s
0 0 0 r
.57009 .32943 m .56912 .33009 L .56716 .33257 L p F P
0 g
s
.761 .324 .213 r
.29276 .37135 m .30001 .37341 L .29658 .36941 L p F P
0 g
s
.761 .324 .213 r
.29658 .36941 m .2896 .36726 L .29276 .37135 L p F P
0 g
s
0 0 0 r
.74272 .3694 m .74269 .36944 L .74279 .36933 L closepath p F P
0 g
s
0 .142 .604 r
.17903 .29524 m .17671 .29356 L .1731 .29064 L p F P
0 g
s
.757 .937 .944 r
.67764 .25765 m .67719 .25744 L .67854 .25662 L closepath p F P
0 g
s
.747 .33 .259 r
.31056 .37954 m .31856 .38134 L .31507 .37733 L p F P
0 g
s
.747 .33 .259 r
.31507 .37733 m .30739 .37542 L .31056 .37954 L p F P
0 g
s
.84 .376 0 r
.04682 .36163 m .04492 .35802 L .04872 .36136 L p F P
0 g
s
.84 .376 0 r
.04872 .36136 m .0506 .3649 L .04682 .36163 L p F P
0 g
s
0 0 0 r
.74301 .37042 m .74943 .36313 L .74279 .36933 L p F P
0 g
s
0 0 0 r
.74109 .37221 m .74301 .37042 L p .74279 .36933 L F P
0 g
s
0 0 0 r
.74279 .36933 m .74269 .36944 L .74109 .37221 L p F P
0 g
s
0 0 0 r
.5805 .32257 m .57009 .32943 L .57899 .32424 L closepath p F P
0 g
s
0 0 0 r
.57768 .32571 m .57899 .32424 L .57009 .32943 L p F P
0 g
s
0 0 0 r
.57197 .32968 m .57768 .32571 L p .57009 .32943 L F P
0 g
s
0 0 0 r
.56716 .33257 m .57197 .32968 L p .57009 .32943 L F P
0 g
s
0 0 0 r
.74269 .36944 m .73593 .37675 L .74109 .37221 L closepath p F P
0 g
s
.622 .953 .789 r
.6288 .28838 m .62721 .28951 L .62842 .2885 L closepath p F P
0 g
s
.546 .907 .713 r
.62607 .28928 m .62842 .2885 L .62721 .28951 L p F P
0 g
s
.546 .907 .713 r
.62284 .29171 m .62607 .28928 L p .62721 .28951 L F P
0 g
s
.546 .907 .713 r
.61666 .29689 m .62284 .29171 L p .62721 .28951 L F P
0 g
s
.713 .831 .938 r
.71638 .2416 m .71444 .23976 L .71986 .23726 L closepath p F P
0 g
s
.671 .289 .314 r
.38261 .39695 m .38285 .39646 L .37917 .39315 L p F P
0 g
s
.671 .289 .314 r
.3719 .39634 m .38261 .39695 L p .37917 .39315 L F P
0 g
s
.671 .289 .314 r
.36858 .39289 m .3719 .39634 L p .37917 .39315 L F P
0 g
s
.671 .289 .314 r
.37917 .39315 m .36884 .39244 L .36858 .39289 L p F P
0 g
s
.454 .787 .999 r
.35277 .48836 m .34177 .48937 L .33841 .48768 L p F P
0 g
s
0 0 0 r
.70885 .40112 m .70877 .40119 L .70914 .40089 L closepath p F P
0 g
s
.171 0 0 r
.53244 .35322 m .53211 .35375 L .53648 .35145 L closepath p F P
0 g
s
.103 0 .37 r
.78034 .31425 m .77635 .31884 L .77727 .3133 L p F P
0 g
s
.103 0 .37 r
.77727 .3133 m .78042 .30967 L .78034 .31425 L p F P
0 g
s
.531 0 0 r
.09717 .40721 m .09531 .40567 L .09154 .40315 L p F P
0 g
s
.65 .963 .791 r
.63749 .28068 m .6402 .28021 L .6288 .28838 L p F P
0 g
s
.65 .963 .791 r
.63489 .28263 m .63749 .28068 L p .6288 .28838 L F P
0 g
s
.65 .963 .791 r
.6288 .28838 m .62842 .2885 L .63489 .28263 L p F P
0 g
s
.209 .661 .947 r
.26161 .47701 m .2635 .47792 L p .24932 .47514 L F P
0 g
s
.209 .661 .947 r
.24932 .47514 m .25843 .47604 L .26161 .47701 L p F P
0 g
s
.231 .67 .956 r
.25843 .47604 m .24932 .47514 L .24578 .47339 L p F P
0 g
s
.482 .889 .757 r
.66044 .43297 m .66041 .43298 L .66059 .43288 L closepath p F P
0 g
s
.476 .851 .622 r
.60491 .30528 m .60327 .30635 L .6107 .30081 L closepath p F P
0 g
s
.598 .231 .317 r
.42759 .39261 m .42605 .39618 L .42002 .39306 L closepath p F P
0 g
s
.598 .229 .313 r
.426 .3963 m .42605 .39618 L .42002 .39306 L p F P
0 g
s
.598 .229 .313 r
.41208 .39709 m .426 .3963 L p .42002 .39306 L F P
0 g
s
.711 .309 .284 r
.33761 .38508 m .33667 .38626 L .33528 .3847 L closepath p F P
0 g
s
.495 .897 .769 r
.66059 .43288 m .66041 .43298 L .65775 .43382 L p F P
0 g
s
.196 .095 .506 r
.78678 .29653 m .78224 .30224 L .78153 .29723 L p F P
0 g
s
.196 .095 .506 r
.78153 .29723 m .78604 .29152 L .78678 .29653 L p F P
0 g
s
.767 .307 .154 r
.27616 .36276 m .28286 .36502 L .27938 .36106 L p F P
0 g
s
.767 .307 .154 r
.27938 .36106 m .27293 .35872 L .27616 .36276 L p F P
0 g
s
.453 .864 .71 r
.67188 .42625 m .66059 .43288 L .66997 .42706 L closepath p F P
0 g
s
.495 .897 .769 r
.66926 .42728 m .66997 .42706 L .66059 .43288 L p F P
0 g
s
.495 .897 .769 r
.65775 .43382 m .66926 .42728 L p .66059 .43288 L F P
0 g
s
0 .449 .814 r
.1726 .44885 m .17795 .45149 L .17018 .44881 L p F P
0 g
s
0 .449 .814 r
.17018 .44881 m .16473 .44621 L .1726 .44885 L p F P
0 g
s
0 .404 .772 r
.16468 .44619 m .16473 .44621 L .17018 .44881 L p F P
0 g
s
0 0 0 r
.70914 .40089 m .70877 .40119 L .7064 .40312 L p F P
0 g
s
0 0 0 r
.71773 .39417 m .70914 .40089 L .71937 .39245 L p F P
0 g
s
0 0 0 r
.71772 .39419 m .71773 .39417 L .70914 .40089 L p F P
0 g
s
0 0 0 r
.70675 .40284 m .71772 .39419 L p .70914 .40089 L F P
0 g
s
0 0 0 r
.7064 .40312 m .70675 .40284 L p .70914 .40089 L F P
0 g
s
.497 .885 .962 r
.53941 .47603 m .5402 .47619 L .5288 .4795 L p F P
0 g
s
.497 .885 .962 r
.5288 .4795 m .52788 .47932 L .53941 .47603 L p F P
0 g
s
.743 .853 .931 r
.71444 .23976 m .70288 .24567 L .7002 .24367 L p F P
0 g
s
.826 .353 0 r
.0506 .3649 m .05099 .36559 L .05487 .36888 L p F P
0 g
s
.771 .274 0 r
.05375 .36967 m .05763 .37296 L .05487 .36888 L p F P
0 g
s
.771 .274 0 r
.05487 .36888 m .05099 .36559 L .05375 .36967 L p F P
0 g
s
.688 .146 0 r
.2143 .32175 m .21917 .32469 L .2154 .32095 L p F P
0 g
s
.688 .146 0 r
.21109 .31842 m .2143 .32175 L p .2154 .32095 L F P
0 g
s
.688 .146 0 r
.2154 .32095 m .21251 .31914 L .21109 .31842 L p F P
0 g
s
.421 0 0 r
.1087 .41537 m .10635 .41375 L .1109 .41672 L p F P
0 g
s
.421 0 0 r
.1109 .41672 m .11245 .41778 L .1087 .41537 L p F P
0 g
s
.741 .219 0 r
.23193 .33251 m .23336 .3341 L .23866 .33687 L p F P
0 g
s
.746 .227 0 r
.23682 .33799 m .24229 .34071 L .23866 .33687 L p F P
0 g
s
.746 .227 0 r
.23866 .33687 m .23336 .3341 L .23682 .33799 L p F P
0 g
s
.56 .581 .831 r
.77315 .24377 m .77008 .24808 L p .76045 .24275 L F P
0 g
s
.56 .581 .831 r
.76045 .24275 m .77247 .24234 L .77315 .24377 L p F P
0 g
s
.549 .623 .877 r
.75813 .23872 m .76045 .24275 L .77247 .24234 L p F P
0 g
s
.139 .62 .919 r
.23162 .47022 m .23269 .47037 L .23937 .47254 L p F P
0 g
s
.172 .635 .935 r
.24222 .47158 m .23269 .47037 L .23937 .47254 L p F P
0 g
s
.172 .635 .935 r
.23937 .47254 m .24578 .47339 L .24222 .47158 L p F P
0 g
s
0 .33 .715 r
.14717 .4378 m .14737 .43789 L .15255 .4406 L p F P
0 g
s
0 .383 .766 r
.15443 .44076 m .15954 .4435 L .15255 .4406 L p F P
0 g
s
0 .383 .766 r
.15255 .4406 m .14737 .43789 L .15443 .44076 L p F P
0 g
s
.036 .437 .871 r
.13861 .26783 m .14253 .26952 L .1462 .27298 L p F P
0 g
s
.068 .458 .884 r
.14865 .27199 m .14253 .26952 L .1462 .27298 L p F P
0 g
s
.068 .458 .884 r
.1462 .27298 m .15227 .27543 L .14865 .27199 L p F P
0 g
s
0 0 0 r
.74042 .37314 m .74109 .37221 L .73593 .37675 L p F P
0 g
s
0 0 0 r
.73563 .37801 m .74042 .37314 L p .73593 .37675 L F P
0 g
s
0 0 0 r
.73072 .38234 m .73563 .37801 L p .73593 .37675 L F P
0 g
s
0 0 0 r
.73593 .37675 m .73146 .38126 L .73072 .38234 L p F P
0 g
s
0 .474 .825 r
.18226 .45367 m .18352 .45405 L .18924 .45656 L p F P
0 g
s
0 .502 .851 r
.19224 .45647 m .18352 .45405 L .18924 .45656 L p F P
0 g
s
0 .502 .851 r
.1933 .45695 m .19224 .45647 L p .18924 .45656 L F P
0 g
s
0 .502 .851 r
.18924 .45656 m .19625 .45852 L .1933 .45695 L p F P
0 g
s
0 .173 .608 r
.19028 .30327 m .18808 .30177 L .19256 .30488 L p F P
0 g
s
0 .173 .608 r
.19256 .30488 m .1939 .30577 L .19028 .30327 L p F P
0 g
s
.71 .309 .287 r
.32992 .38722 m .32662 .38312 L .33528 .3847 L p F P
0 g
s
.71 .309 .287 r
.33522 .38814 m .32992 .38722 L p .33528 .3847 L F P
0 g
s
.71 .309 .287 r
.33528 .3847 m .33667 .38626 L .33522 .38814 L p F P
0 g
s
.57 .917 .712 r
.61666 .29689 m .61467 .29787 L .62284 .29171 L closepath p F P
0 g
s
.501 .908 .877 r
.60918 .45653 m .60902 .45654 L .61054 .45589 L closepath p F P
0 g
s
.494 .851 .992 r
.47202 .48751 m .47122 .48722 L .4655 .48843 L closepath p F P
0 g
s
.506 .849 .995 r
.46809 .48591 m .47122 .48722 L .4655 .48843 L p F P
0 g
s
.506 .849 .995 r
.45681 .48836 m .46809 .48591 L p .4655 .48843 L F P
0 g
s
.57 .202 .304 r
.43822 .39157 m .42759 .39261 L .42605 .39618 L p F P
0 g
s
0 .332 .782 r
.16949 .2876 m .16566 .28552 L .1697 .28882 L p F P
0 g
s
0 .332 .782 r
.1697 .28882 m .1731 .29064 L .16949 .2876 L p F P
0 g
s
.135 .013 .436 r
.78215 .30751 m .78042 .30967 L .78022 .30476 L p F P
0 g
s
.135 .013 .436 r
.78022 .30476 m .78224 .30224 L .78215 .30751 L p F P
0 g
s
.749 .95 .944 r
.67854 .25662 m .67719 .25744 L .67451 .25644 L p F P
0 g
s
.367 .33 .685 r
.78212 .2728 m .78338 .27115 L .78434 .27486 L closepath p F P
0 g
s
.724 .205 0 r
.25106 .34463 m .24919 .34451 L .24802 .34333 L closepath p F P
0 g
s
.265 0 .086 r
.52916 .35921 m .53067 .3564 L .5198 .36058 L p F P
0 g
s
.265 0 .086 r
.52419 .36148 m .52916 .35921 L p .5198 .36058 L F P
0 g
s
.265 0 .086 r
.5198 .36058 m .51807 .36386 L .52419 .36148 L p F P
0 g
s
.564 .015 0 r
.08777 .40053 m .08428 .3974 L .08856 .40049 L p F P
0 g
s
.564 .015 0 r
.08856 .40049 m .09154 .40315 L .08777 .40053 L p F P
0 g
s
0 0 0 r
.73146 .38126 m .72819 .38443 L .73072 .38234 L closepath p F P
0 g
s
0 0 0 r
.72014 .39177 m .71937 .39245 L .71997 .39198 L closepath p F P
0 g
s
0 0 0 r
.71937 .39245 m .71997 .39198 L .71773 .39417 L p F P
0 g
s
.679 .299 .319 r
.36884 .39244 m .36858 .39289 L .36807 .39238 L closepath p F P
0 g
s
0 0 .115 r
.76926 .33688 m .76372 .34281 L .76687 .33656 L p F P
0 g
s
0 0 .115 r
.77144 .3326 m .76926 .33688 L p .76687 .33656 L F P
0 g
s
0 0 .115 r
.76687 .33656 m .77169 .33142 L .77144 .3326 L p F P
0 g
s
0 0 0 r
.72819 .38443 m .72014 .39177 L .71997 .39198 L p F P
0 g
s
0 0 0 r
.7291 .38423 m .73072 .38234 L .72819 .38443 L p F P
0 g
s
0 0 0 r
.7273 .38589 m .7291 .38423 L p .72819 .38443 L F P
0 g
s
0 0 0 r
.71997 .39198 m .7273 .38589 L p .72819 .38443 L F P
0 g
s
.475 .796 .999 r
.36715 .48879 m .35611 .49004 L .35277 .48836 L p F P
0 g
s
.517 .915 .891 r
.61054 .45589 m .60902 .45654 L .60621 .45664 L p F P
0 g
s
.496 .905 .887 r
.59473 .46133 m .60621 .45664 L .60902 .45654 L p F P
0 g
s
.676 .3 .326 r
.36123 .39542 m .35762 .39139 L .36807 .39238 L p F P
0 g
s
.676 .3 .326 r
.36694 .39594 m .36123 .39542 L p .36807 .39238 L F P
0 g
s
.676 .3 .326 r
.36807 .39238 m .36858 .39289 L .36694 .39594 L p F P
0 g
s
.413 .776 .995 r
.33503 .48589 m .33841 .48768 L .33117 .48817 L p F P
0 g
s
.413 .776 .995 r
.32407 .48676 m .33503 .48589 L p .33117 .48817 L F P
0 g
s
.413 .776 .995 r
.33117 .48817 m .32541 .48743 L .32407 .48676 L p F P
0 g
s
.767 .95 .936 r
.67854 .25662 m .68868 .2504 L .686 .24897 L p F P
0 g
s
.767 .95 .936 r
.686 .24897 m .68357 .25055 L .67854 .25662 L p F P
0 g
s
.749 .95 .944 r
.67451 .25644 m .68357 .25055 L .67854 .25662 L p F P
0 g
s
.662 .13 0 r
.0762 .3905 m .07464 .38879 L .07086 .38601 L p F P
0 g
s
.514 .148 .284 r
.45496 .3872 m .46302 .38799 L .45399 .38958 L closepath p F P
0 g
s
.481 .898 .892 r
.59473 .46133 m .58737 .46415 L .59419 .46134 L closepath p F P
0 g
s
.513 .908 .922 r
.59187 .46121 m .59419 .46134 L .58737 .46415 L p F P
0 g
s
.513 .908 .922 r
.58039 .46555 m .59187 .46121 L p .58737 .46415 L F P
0 g
s
.338 .737 .983 r
.30755 .48441 m .30975 .48548 L p .29547 .48385 L F P
0 g
s
.338 .737 .983 r
.29547 .48385 m .30465 .48381 L .30755 .48441 L p F P
0 g
s
.365 .745 .989 r
.30465 .48381 m .29547 .48385 L .29201 .48217 L p F P
0 g
s
.647 .961 .786 r
.62842 .2885 m .62607 .28928 L .63489 .28263 L closepath p F P
0 g
s
.759 .972 .924 r
.66469 .26455 m .66305 .26418 L .66816 .26074 L closepath p F P
0 g
s
.213 0 .046 r
.53648 .35145 m .53211 .35375 L .53067 .3564 L p F P
0 g
s
.743 .25 .063 r
.26059 .35382 m .25719 .34986 L .26323 .35235 L p F P
0 g
s
.743 .25 .063 r
.26607 .35594 m .26059 .35382 L p .26323 .35235 L F P
0 g
s
.743 .25 .063 r
.26323 .35235 m .26652 .35589 L .26607 .35594 L p F P
0 g
s
.484 .897 .808 r
.64353 .44055 m .64624 .43995 L .63475 .44569 L p F P
0 g
s
.484 .897 .808 r
.64338 .44063 m .64353 .44055 L p .63475 .44569 L F P
0 g
s
.484 .897 .808 r
.63475 .44569 m .63361 .44595 L .64338 .44063 L p F P
0 g
s
.733 .223 0 r
.06066 .37697 m .06463 .38022 L .0616 .37621 L p F P
0 g
s
.733 .223 0 r
.0616 .37621 m .05763 .37296 L .06066 .37697 L p F P
0 g
s
.248 .689 .959 r
.2635 .47792 m .26558 .47805 L .27298 .47997 L p F P
0 g
s
.273 .696 .968 r
.27425 .47844 m .26558 .47805 L .27298 .47997 L p F P
0 g
s
.273 .696 .968 r
.27298 .47997 m .27774 .48023 L .27425 .47844 L p F P
0 g
s
0 .253 .654 r
.12975 .42838 m .13124 .42917 L .13616 .43199 L p F P
0 g
s
0 .306 .707 r
.13753 .43227 m .1424 .4351 L .13616 .43199 L p F P
0 g
s
0 .306 .707 r
.13616 .43199 m .13124 .42917 L .13753 .43227 L p F P
0 g
s
.517 .88 .981 r
.5258 .4788 m .51442 .48192 L .51138 .48107 L p F P
0 g
s
.499 .872 .979 r
.50003 .48398 m .51138 .48107 L .51442 .48192 L p F P
0 g
s
.028 .537 .87 r
.19988 .4604 m .20398 .46137 L .20996 .46378 L p F P
0 g
s
.043 .545 .879 r
.20398 .46137 m .19988 .4604 L .19625 .45852 L p F P
0 g
s
.483 .9 .852 r
.62051 .4515 m .61054 .45589 L .61942 .45163 L closepath p F P
0 g
s
.517 .915 .891 r
.61772 .45169 m .61942 .45163 L .61054 .45589 L p F P
0 g
s
.517 .915 .891 r
.60621 .45664 m .61772 .45169 L p .61054 .45589 L F P
0 g
s
.711 .986 .872 r
.64025 .28021 m .6402 .28021 L .64039 .28008 L closepath p F P
0 g
s
0 0 0 r
.71778 .39414 m .71773 .39417 L .71997 .39198 L p F P
0 g
s
0 0 0 r
.71997 .39198 m .7273 .38589 L .71778 .39414 L p F P
0 g
s
.742 .985 .904 r
.65231 .27218 m .65162 .27213 L .65392 .27053 L closepath p F P
0 g
s
.065 .559 .891 r
.21032 .46275 m .20398 .46137 L .20996 .46378 L p F P
0 g
s
.065 .559 .891 r
.20996 .46378 m .21393 .46465 L .21032 .46275 L p F P
0 g
s
.679 .978 .844 r
.64039 .28008 m .6402 .28021 L .63749 .28068 L p F P
0 g
s
.705 .985 .844 r
.64039 .28008 m .65162 .27213 L .64891 .27214 L p F P
0 g
s
.705 .985 .844 r
.64891 .27214 m .64709 .2735 L .64039 .28008 L p F P
0 g
s
.679 .978 .844 r
.63749 .28068 m .64709 .2735 L .64039 .28008 L p F P
0 g
s
0 0 0 r
.58486 .3195 m .5805 .32257 L .57899 .32424 L p F P
0 g
s
.681 .305 .328 r
.36858 .39289 m .3719 .39634 L .36694 .39594 L closepath p F P
0 g
s
.52 .546 .822 r
.77008 .24808 m .77315 .24377 L .7753 .24854 L closepath p F P
0 g
s
.501 .901 .927 r
.57846 .46541 m .58039 .46555 L .56894 .46963 L p F P
0 g
s
.501 .901 .927 r
.56894 .46963 m .5676 .46953 L .57846 .46541 L p F P
0 g
s
.503 .907 .809 r
.64726 .43971 m .64624 .43995 L .65283 .4365 L closepath p F P
0 g
s
.47 .804 .999 r
.37047 .49046 m .38154 .48901 L .38483 .49066 L p F P
0 g
s
.493 .804 1 r
.38154 .48901 m .37047 .49046 L .36715 .48879 L p F P
0 g
s
.481 .112 .26 r
.47887 .38481 m .48032 .3811 L .46812 .38373 L p F P
0 g
s
.481 .112 .26 r
.46812 .38373 m .46659 .38738 L .47887 .38481 L p F P
0 g
s
.734 .208 0 r
.23193 .33251 m .23336 .3341 L .22839 .33132 L closepath p F P
0 g
s
.512 .859 .993 r
.48253 .48461 m .48463 .48542 L .47202 .48751 L p F P
0 g
s
.512 .859 .993 r
.47202 .48751 m .47122 .48722 L .48253 .48461 L p F P
0 g
s
.327 0 .134 r
.51777 .36447 m .51807 .36386 L .50689 .36768 L p F P
0 g
s
.327 0 .134 r
.50689 .36768 m .5064 .36865 L .51777 .36447 L p F P
0 g
s
.374 .757 .989 r
.32541 .48743 m .32407 .48676 L .32194 .48684 L closepath p F P
0 g
s
0 0 .028 r
.76291 .34366 m .76263 .34464 L .76372 .34281 L closepath p F P
0 g
s
.573 .208 .31 r
.44098 .3913 m .44051 .39244 L .43822 .39157 L closepath p F P
0 g
s
.57 .202 .304 r
.4395 .39508 m .44051 .39244 L .43822 .39157 L p F P
0 g
s
.57 .202 .304 r
.42629 .39628 m .4395 .39508 L p .43822 .39157 L F P
0 g
s
.57 .202 .304 r
.42605 .39618 m .42629 .39628 L p .43822 .39157 L F P
0 g
s
.522 .887 .975 r
.53721 .47547 m .53941 .47603 L .52788 .47932 L p F P
0 g
s
.522 .887 .975 r
.52788 .47932 m .5258 .4788 L .53721 .47547 L p F P
0 g
s
.574 .02 0 r
.1939 .30577 m .19689 .30839 L .20143 .31147 L p F P
0 g
s
.569 .02 0 r
.19689 .30839 m .1939 .30577 L .19028 .30327 L p F P
0 g
s
.678 .131 0 r
.22303 .32843 m .22825 .33125 L .22423 .32757 L p F P
0 g
s
.678 .131 0 r
.22423 .32757 m .21917 .32469 L .22303 .32843 L p F P
0 g
s
.425 .411 .74 r
.78091 .26367 m .78106 .26347 L .78116 .2638 L closepath p F P
0 g
s
.687 .163 0 r
.06708 .38311 m .06463 .38022 L .06866 .38343 L p F P
0 g
s
.687 .163 0 r
.06866 .38343 m .07086 .38601 L .06708 .38311 L p F P
0 g
s
.511 .873 .984 r
.50906 .48034 m .51138 .48107 L .50003 .48398 L p F P
0 g
s
.511 .873 .984 r
.50003 .48398 m .49701 .48308 L .50906 .48034 L p F P
0 g
s
.483 .864 .978 r
.49701 .48308 m .50003 .48398 L p .48563 .48576 L F P
0 g
s
.758 .334 .243 r
.30312 .37754 m .31056 .37954 L .30739 .37542 L p F P
0 g
s
.758 .334 .243 r
.30142 .37513 m .30312 .37754 L p .30739 .37542 L F P
0 g
s
.758 .334 .243 r
.30739 .37542 m .30275 .37412 L .30142 .37513 L p F P
0 g
s
.7 .314 .315 r
.35135 .39424 m .36123 .39542 L .35762 .39139 L p F P
0 g
s
.7 .314 .315 r
.35078 .39353 m .35135 .39424 L p .35762 .39139 L F P
0 g
s
.7 .314 .315 r
.35762 .39139 m .35251 .39076 L .35078 .39353 L p F P
0 g
s
0 0 0 r
.59188 .31462 m .58486 .3195 L .59068 .31575 L closepath p F P
0 g
s
0 0 0 r
.58909 .31728 m .59068 .31575 L .58486 .3195 L p F P
0 g
s
0 0 0 r
.58496 .32031 m .58909 .31728 L p .58486 .3195 L F P
0 g
s
0 0 0 r
.57899 .32424 m .58496 .32031 L p .58486 .3195 L F P
0 g
s
0 .306 .773 r
.15642 .27907 m .15588 .27876 L .15227 .27543 L p F P
0 g
s
.187 0 .005 r
.54349 .34783 m .53648 .35145 L .54301 .34865 L closepath p F P
0 g
s
.213 0 .046 r
.54123 .35179 m .54301 .34865 L .53648 .35145 L p F P
0 g
s
.213 0 .046 r
.53067 .3564 m .54123 .35179 L p .53648 .35145 L F P
0 g
s
.384 0 0 r
.11245 .41778 m .11613 .42011 L .12081 .42302 L p F P
0 g
s
0 .183 .605 r
.11613 .42011 m .11245 .41778 L .1087 .41537 L p F P
0 g
s
.562 .008 0 r
.20106 .31198 m .20572 .31502 L .20143 .31147 L p F P
0 g
s
.562 .008 0 r
.20143 .31147 m .19689 .30839 L .20106 .31198 L p F P
0 g
s
0 0 .204 r
.7724 .33062 m .77169 .33142 L .77225 .32743 L p F P
0 g
s
0 0 .204 r
.77225 .32743 m .77471 .32462 L .7724 .33062 L p F P
0 g
s
.691 .767 .91 r
.74046 .23302 m .72875 .23734 L .72607 .23438 L p F P
0 g
s
.677 .747 .904 r
.72875 .23734 m .74046 .23302 L .74316 .23663 L p F P
0 g
s
.553 .187 .301 r
.45254 .39336 m .45399 .38958 L .44098 .3913 L p F P
0 g
s
.553 .187 .301 r
.44661 .39413 m .45254 .39336 L p .44098 .3913 L F P
0 g
s
.553 .187 .301 r
.44098 .3913 m .44051 .39244 L .44661 .39413 L p F P
0 g
s
.634 .685 .88 r
.74316 .23663 m .75497 .2336 L .7577 .23798 L p F P
0 g
s
.65 .708 .89 r
.75497 .2336 m .74316 .23663 L .74046 .23302 L p F P
0 g
s
.385 .371 .721 r
.78116 .2638 m .78606 .26722 L .78338 .27115 L closepath p F P
0 g
s
.363 .372 .735 r
.78106 .26347 m .78116 .2638 L .78606 .26722 L p F P
0 g
s
.434 .44 .767 r
.77819 .2555 m .78453 .25816 L .78106 .26347 L closepath p F P
0 g
s
.363 .372 .735 r
.78993 .26163 m .78453 .25816 L .78106 .26347 L p F P
0 g
s
.363 .372 .735 r
.78606 .26722 m .78993 .26163 L p .78106 .26347 L F P
0 g
s
.484 .812 1 r
.38483 .49066 m .39595 .48901 L .39922 .49063 L p F P
0 g
s
.509 .811 .999 r
.39595 .48901 m .38483 .49066 L .38154 .48901 L p F P
0 g
s
.722 .199 0 r
.24555 .34411 m .24229 .34071 L .24802 .34333 L p F P
0 g
s
.722 .199 0 r
.24802 .34333 m .24919 .34451 L .24555 .34411 L p F P
0 g
s
.249 .689 .959 r
.2635 .47792 m .26558 .47805 L .26161 .47701 L closepath p F P
0 g
s
.531 0 0 r
.09154 .40315 m .09277 .40417 L .09717 .40721 L p F P
0 g
s
.457 0 0 r
.09749 .40769 m .10188 .41074 L .09717 .40721 L p F P
0 g
s
.457 0 0 r
.09717 .40721 m .09277 .40417 L .09749 .40769 L p F P
0 g
s
.772 .329 .199 r
.28595 .36913 m .29276 .37135 L .2896 .36726 L p F P
0 g
s
.772 .329 .199 r
.28393 .36629 m .28595 .36913 L p .2896 .36726 L F P
0 g
s
.772 .329 .199 r
.2896 .36726 m .28512 .36573 L .28393 .36629 L p F P
0 g
s
.723 .326 .297 r
.33667 .38626 m .3387 .38876 L .33522 .38814 L closepath p F P
0 g
s
.476 .877 .716 r
.6788 .42202 m .67188 .42625 L .66997 .42706 L p F P
0 g
s
.74 .333 .279 r
.32161 .38552 m .32992 .38722 L .32662 .38312 L p F P
0 g
s
.74 .333 .279 r
.31901 .38189 m .32161 .38552 L p .32662 .38312 L F P
0 g
s
.74 .333 .279 r
.32662 .38312 m .31936 .38151 L .31901 .38189 L p F P
0 g
s
0 .149 .611 r
.17955 .29536 m .18374 .29859 L .17903 .29524 L p F P
0 g
s
0 .149 .611 r
.17903 .29524 m .17491 .29198 L .17955 .29536 L p F P
0 g
s
0 .142 .604 r
.1731 .29064 m .17491 .29198 L .17903 .29524 L p F P
0 g
s
.146 .622 .923 r
.23162 .47022 m .23269 .47037 L .23035 .4696 L closepath p F P
0 g
s
.476 .483 .786 r
.77734 .25528 m .77783 .2546 L .77819 .2555 L closepath p F P
0 g
s
0 .215 .631 r
.12171 .4234 m .11613 .42011 L .12081 .42302 L p F P
0 g
s
0 .215 .631 r
.12463 .42524 m .12171 .4234 L p .12081 .42302 L F P
0 g
s
0 .215 .631 r
.12081 .42302 m .12602 .42612 L .12463 .42524 L p F P
0 g
s
.375 .757 .989 r
.30975 .48548 m .31323 .48535 L .32194 .48684 L p F P
0 g
s
.37 .757 .988 r
.30975 .48548 m .31323 .48535 L .30755 .48441 L closepath p F P
0 g
s
.572 .004 0 r
.21251 .31914 m .21109 .31842 L .21055 .31799 L closepath p F P
0 g
s
.388 .756 .992 r
.32066 .48497 m .31323 .48535 L .32194 .48684 L p F P
0 g
s
.388 .756 .992 r
.32194 .48684 m .32407 .48676 L .32066 .48497 L p F P
0 g
s
.302 .287 .676 r
.78986 .27122 m .78606 .26722 L .78338 .27115 L p F P
0 g
s
.302 .287 .676 r
.786 .27677 m .78986 .27122 L p .78338 .27115 L F P
0 g
s
.302 .287 .676 r
.78338 .27115 m .78434 .27486 L .786 .27677 L p F P
0 g
s
0 .479 .833 r
.18226 .45367 m .18352 .45405 L .17994 .45245 L closepath p F P
0 g
s
0 .306 .773 r
.15227 .27543 m .15265 .27565 L .15642 .27907 L p F P
0 g
s
0 .307 .774 r
.15795 .27875 m .16175 .28216 L .15642 .27907 L p F P
0 g
s
0 .307 .774 r
.15642 .27907 m .15265 .27565 L .15795 .27875 L p F P
0 g
s
.483 .864 .978 r
.48563 .48576 m .49631 .48322 L .49701 .48308 L p F P
0 g
s
.51 .864 .99 r
.48563 .48576 m .49631 .48322 L .48463 .48542 L closepath p F P
0 g
s
.495 .82 1 r
.39922 .49063 m .41037 .48881 L .41361 .49039 L p F P
0 g
s
.52 .818 .999 r
.41037 .48881 m .39922 .49063 L .39595 .48901 L p F P
0 g
s
.702 .318 .317 r
.35251 .39076 m .35078 .39353 L .34787 .39017 L closepath p F P
0 g
s
0 0 .025 r
.7654 .34338 m .76926 .33688 L .76372 .34281 L p F P
0 g
s
0 0 .025 r
.7619 .34713 m .7654 .34338 L p .76372 .34281 L F P
0 g
s
0 0 .025 r
.76372 .34281 m .76263 .34464 L .7619 .34713 L p F P
0 g
s
.031 0 .286 r
.77977 .3188 m .77471 .32462 L .77635 .31884 L p F P
0 g
s
.031 0 .286 r
.78008 .31769 m .77977 .3188 L p .77635 .31884 L F P
0 g
s
.031 0 .286 r
.77635 .31884 m .78034 .31425 L .78008 .31769 L p F P
0 g
s
.75 .922 .948 r
.69738 .24532 m .68868 .2504 L .686 .24897 L p F P
0 g
s
.254 .175 .57 r
.7872 .29004 m .78604 .29152 L .78437 .28682 L p F P
0 g
s
.254 .175 .57 r
.78437 .28682 m .78635 .28429 L .7872 .29004 L p F P
0 g
s
.777 .311 .136 r
.26652 .35589 m .26681 .35626 L .27293 .35872 L p F P
0 g
s
.784 .326 .158 r
.26983 .36037 m .27616 .36276 L .27293 .35872 L p F P
0 g
s
.784 .326 .158 r
.27293 .35872 m .26681 .35626 L .26983 .36037 L p F P
0 g
s
.722 .986 .889 r
.65392 .27053 m .65162 .27213 L .64891 .27214 L p F P
0 g
s
.503 .827 1 r
.41361 .49039 m .42479 .4884 L .428 .48993 L p F P
0 g
s
.526 .825 .999 r
.42479 .4884 m .41361 .49039 L .41037 .48881 L p F P
0 g
s
0 0 0 r
.59817 .31003 m .59188 .31462 L .59068 .31575 L p F P
0 g
s
.418 .448 .785 r
.77783 .2546 m .77819 .2555 L .78453 .25816 L p F P
0 g
s
.537 .855 .997 r
.48253 .48461 m .47122 .48722 L .46809 .48591 L p F P
0 g
s
.586 .647 .878 r
.7577 .23798 m .75862 .23786 L .75813 .23872 L closepath p F P
0 g
s
.549 .623 .877 r
.76968 .23681 m .75862 .23786 L .75813 .23872 L p F P
0 g
s
.549 .623 .877 r
.77247 .24234 m .76968 .23681 L p .75813 .23872 L F P
0 g
s
.395 .017 .2 r
.50374 .37468 m .50528 .37113 L .49376 .37455 L p F P
0 g
s
.395 .017 .2 r
.49376 .37455 m .49219 .37808 L .50374 .37468 L p F P
0 g
s
0 0 0 r
.7525 .35854 m .75163 .36039 L .75495 .35612 L closepath p F P
0 g
s
.592 .053 0 r
.07594 .3911 m .08007 .39427 L .0762 .3905 L p F P
0 g
s
.592 .053 0 r
.0762 .3905 m .07207 .38733 L .07594 .3911 L p F P
0 g
s
.662 .13 0 r
.07086 .38601 m .07207 .38733 L .0762 .3905 L p F P
0 g
s
.33 .294 .666 r
.78434 .27486 m .786 .27677 L .78511 .27804 L closepath p F P
0 g
s
.219 .66 .953 r
.23935 .47006 m .24222 .47158 L .23269 .47037 L p F P
0 g
s
.219 .66 .953 r
.23812 .46962 m .23935 .47006 L p .23269 .47037 L F P
0 g
s
.219 .66 .953 r
.22804 .46839 m .23812 .46962 L p .23269 .47037 L F P
0 g
s
.219 .66 .953 r
.23269 .47037 m .23035 .4696 L .22804 .46839 L p F P
0 g
s
.712 .846 .946 r
.71986 .23726 m .71444 .23976 L .71177 .2374 L p F P
0 g
s
.743 .853 .931 r
.7002 .24367 m .71177 .2374 L .71444 .23976 L p F P
0 g
s
.478 .502 .805 r
.7753 .24854 m .78084 .24979 L .77783 .2546 L closepath p F P
0 g
s
.418 .448 .785 r
.78768 .25227 m .78084 .24979 L .77783 .2546 L p F P
0 g
s
.418 .448 .785 r
.78797 .2531 m .78768 .25227 L p .77783 .2546 L F P
0 g
s
.418 .448 .785 r
.78453 .25816 m .78797 .2531 L p .77783 .2546 L F P
0 g
s
.52 .901 .955 r
.56602 .46932 m .55458 .47311 L .55163 .47263 L p F P
0 g
s
.499 .891 .953 r
.5402 .47619 m .55163 .47263 L .55458 .47311 L p F P
0 g
s
0 .26 .667 r
.13124 .42917 m .12975 .42838 L .12602 .42612 L p F P
0 g
s
.509 .835 .999 r
.428 .48993 m .43922 .48779 L .44241 .48926 L p F P
0 g
s
.53 .832 .999 r
.43922 .48779 m .428 .48993 L .42479 .4884 L p F P
0 g
s
.535 .847 .999 r
.46809 .48591 m .45681 .48836 L .45366 .48696 L p F P
0 g
s
.514 .842 .998 r
.44241 .48926 m .45366 .48696 L .45681 .48836 L p F P
0 g
s
.751 .989 .89 r
.65392 .27053 m .66305 .26418 L .66036 .26375 L p F P
0 g
s
.751 .989 .89 r
.66036 .26375 m .65971 .26422 L .65392 .27053 L p F P
0 g
s
.722 .986 .889 r
.64891 .27214 m .65971 .26422 L .65392 .27053 L p F P
0 g
s
.534 .839 .999 r
.45366 .48696 m .44241 .48926 L .43922 .48779 L p F P
0 g
s
0 0 .037 r
.76263 .34464 m .75969 .34935 L .7619 .34713 L closepath p F P
0 g
s
0 0 0 r
.73072 .38234 m .7291 .38423 L .73563 .37801 L closepath p F P
0 g
s
.505 .909 .896 r
.60462 .45668 m .60621 .45664 L .59473 .46133 L p F P
0 g
s
.505 .909 .896 r
.59473 .46133 m .59419 .46134 L .60462 .45668 L p F P
0 g
s
.35 0 .173 r
.51649 .36732 m .51777 .36447 L .5064 .36865 L p F P
0 g
s
.35 0 .173 r
.5064 .36865 m .50528 .37113 L .51649 .36732 L p F P
0 g
s
0 .412 .784 r
.16468 .44619 m .16473 .44621 L .16459 .44614 L closepath p F P
0 g
s
0 .488 .853 r
.16733 .44617 m .1726 .44885 L .16473 .44621 L p F P
0 g
s
0 .488 .853 r
.16101 .44406 m .16733 .44617 L p .16473 .44621 L F P
0 g
s
0 .488 .853 r
.16473 .44621 m .16459 .44614 L .16101 .44406 L p F P
0 g
s
0 .416 .796 r
.16459 .44614 m .16101 .44406 L .15954 .4435 L closepath p F P
0 g
s
.822 .349 0 r
.05099 .36559 m .0506 .3649 L .04682 .36163 L p F P
0 g
s
.7 .318 .321 r
.34186 .39293 m .3387 .38876 L .34787 .39017 L p F P
0 g
s
.7 .318 .321 r
.35043 .39411 m .34186 .39293 L p .34787 .39017 L F P
0 g
s
.7 .318 .321 r
.34787 .39017 m .35078 .39353 L .35043 .39411 L p F P
0 g
s
.13 .008 .433 r
.78668 .30182 m .78215 .30751 L .78224 .30224 L p F P
0 g
s
.13 .008 .433 r
.78224 .30224 m .78678 .29653 L .78668 .30182 L p F P
0 g
s
.307 .714 .977 r
.27075 .47659 m .27425 .47844 L .26558 .47805 L p F P
0 g
s
.307 .714 .977 r
.25998 .47617 m .27075 .47659 L p .26558 .47805 L F P
0 g
s
.307 .714 .977 r
.26558 .47805 m .26161 .47701 L .25998 .47617 L p F P
0 g
s
.054 .544 .888 r
.18672 .45388 m .19224 .45647 L .18352 .45405 L p F P
0 g
s
.054 .544 .888 r
.1786 .4517 m .18672 .45388 L p .18352 .45405 L F P
0 g
s
.054 .544 .888 r
.18352 .45405 m .17994 .45245 L .1786 .4517 L p F P
0 g
s
.744 .314 .23 r
.30275 .37412 m .30142 .37513 L .30001 .37341 L closepath p F P
0 g
s
.601 .668 .886 r
.75862 .23786 m .7577 .23798 L .75497 .2336 L p F P
0 g
s
0 .338 .729 r
.14717 .4378 m .14737 .43789 L .14664 .43749 L closepath p F P
0 g
s
.44 .07 .239 r
.48066 .38028 m .48797 .37914 L .48032 .3811 L closepath p F P
0 g
s
.439 .844 .658 r
.68336 .41911 m .6788 .42202 L .68252 .41956 L closepath p F P
0 g
s
.476 .877 .716 r
.68077 .42027 m .68252 .41956 L .6788 .42202 L p F P
0 g
s
.476 .877 .716 r
.67309 .42501 m .68077 .42027 L p .6788 .42202 L F P
0 g
s
.476 .877 .716 r
.66997 .42706 m .67309 .42501 L p .6788 .42202 L F P
0 g
s
.754 .239 0 r
.23157 .3352 m .23682 .33799 L .23336 .3341 L p F P
0 g
s
.754 .239 0 r
.2283 .33129 m .23157 .3352 L p .23336 .3341 L F P
0 g
s
.754 .239 0 r
.23336 .3341 m .22839 .33132 L .2283 .33129 L p F P
0 g
s
.522 .919 .854 r
.63361 .44595 m .63201 .44616 L .64338 .44063 L closepath p F P
0 g
s
.553 .197 .317 r
.44051 .39244 m .44661 .39413 L .4395 .39508 L closepath p F P
0 g
s
.452 .778 .998 r
.33503 .48589 m .32407 .48676 L .32066 .48497 L p F P
0 g
s
.781 .293 .059 r
.25142 .34727 m .24919 .34451 L .24555 .34411 L p F P
0 g
s
0 0 0 r
.60327 .30635 m .59817 .31003 L .60227 .30712 L closepath p F P
0 g
s
0 0 0 r
.6005 .30851 m .60227 .30712 L .59817 .31003 L p F P
0 g
s
0 0 0 r
.5969 .31126 m .6005 .30851 L p .59817 .31003 L F P
0 g
s
0 0 0 r
.59068 .31575 m .5969 .31126 L p .59817 .31003 L F P
0 g
s
0 .426 .811 r
.14941 .43799 m .15443 .44076 L .14737 .43789 L p F P
0 g
s
0 .426 .811 r
.14347 .43558 m .14941 .43799 L p .14737 .43789 L F P
0 g
s
0 .426 .811 r
.14737 .43789 m .14664 .43749 L .14347 .43558 L p F P
0 g
s
.281 .23 .621 r
.78855 .28119 m .78635 .28429 L .78511 .27804 L p F P
0 g
s
.281 .23 .621 r
.78511 .27804 m .786 .27677 L .78855 .28119 L p F P
0 g
s
.557 0 0 r
.20746 .31646 m .20572 .31502 L .21055 .31799 L p F P
0 g
s
.557 0 0 r
.21055 .31799 m .21109 .31842 L .20746 .31646 L p F P
0 g
s
.131 0 0 r
.55329 .34368 m .55488 .3411 L .54349 .34783 L p F P
0 g
s
.131 0 0 r
.54349 .34783 m .54301 .34865 L .55329 .34368 L p F P
0 g
s
.775 .291 .078 r
.25463 .35129 m .26059 .35382 L .25719 .34986 L p F P
0 g
s
.775 .291 .078 r
.25719 .34986 m .25142 .34727 L .25463 .35129 L p F P
0 g
s
.508 .909 .813 r
.65283 .4365 m .64624 .43995 L .64353 .44055 L p F P
0 g
s
.411 0 0 r
.10495 .41285 m .10188 .41074 L .10635 .41375 L p F P
0 g
s
.411 0 0 r
.10635 .41375 m .1087 .41537 L .10495 .41285 L p F P
0 g
s
.601 .668 .886 r
.75497 .2336 m .76161 .23247 L .75862 .23786 L p F P
0 g
s
.576 .623 .861 r
.76691 .23171 m .76161 .23247 L .75862 .23786 L p F P
0 g
s
.576 .623 .861 r
.75862 .23786 m .76968 .23681 L .76691 .23171 L p F P
0 g
s
0 .146 .616 r
.17491 .29198 m .1731 .29064 L .16949 .2876 L p F P
0 g
s
.752 .298 .175 r
.28512 .36573 m .28393 .36629 L .28286 .36502 L closepath p F P
0 g
s
0 .171 .616 r
.18667 .30062 m .18374 .29859 L .18808 .30177 L p F P
0 g
s
0 .171 .616 r
.18808 .30177 m .19028 .30327 L .18667 .30062 L p F P
0 g
s
.141 .611 .924 r
.23035 .4696 m .22804 .46839 L .22633 .4681 L closepath p F P
0 g
s
.351 .729 .986 r
.28843 .48042 m .27774 .48023 L .27425 .47844 L p F P
0 g
s
.322 .722 .98 r
.28864 .48047 m .29201 .48217 L p .27774 .48023 L F P
0 g
s
.322 .722 .98 r
.27774 .48023 m .28843 .48042 L .28864 .48047 L p F P
0 g
s
.506 .911 .857 r
.6295 .44646 m .63201 .44616 L .62051 .4515 L p F P
0 g
s
.506 .911 .857 r
.62051 .4515 m .61942 .45163 L .6295 .44646 L p F P
0 g
s
.066 0 .359 r
.78132 .31304 m .78034 .31425 L .78042 .30967 L p F P
0 g
s
.066 0 .359 r
.78042 .30967 m .78215 .30751 L .78132 .31304 L p F P
0 g
s
.528 .907 .949 r
.5775 .46528 m .57846 .46541 L .5676 .46953 L p F P
0 g
s
.528 .907 .949 r
.5676 .46953 m .56602 .46932 L .5775 .46528 L p F P
0 g
s
.521 .163 .3 r
.46302 .38799 m .45399 .38958 L .45254 .39336 L p F P
0 g
s
.822 .349 0 r
.04682 .36163 m .04717 .36226 L .05099 .36559 L p F P
0 g
s
.764 .269 0 r
.04993 .36634 m .05375 .36967 L .05099 .36559 L p F P
0 g
s
.764 .269 0 r
.05099 .36559 m .04717 .36226 L .04993 .36634 L p F P
0 g
s
.658 .287 .33 r
.38285 .39646 m .38345 .39698 L .38261 .39695 L closepath p F P
0 g
s
0 .349 .746 r
.14664 .43749 m .14347 .43558 L .1424 .4351 L closepath p F P
0 g
s
.732 .323 .273 r
.31936 .38151 m .31901 .38189 L .31856 .38134 L closepath p F P
0 g
s
.53 .862 .995 r
.49631 .48322 m .48463 .48542 L .48253 .48461 L p F P
0 g
s
0 .332 .788 r
.16587 .28443 m .16175 .28216 L .16566 .28552 L p F P
0 g
s
0 .332 .788 r
.16566 .28552 m .16949 .2876 L .16587 .28443 L p F P
0 g
s
0 0 0 r
.6107 .30081 m .60327 .30635 L .60227 .30712 L p F P
0 g
s
.122 .598 .916 r
.21393 .46465 m .22017 .46576 L .22633 .4681 L p F P
0 g
s
.137 .606 .923 r
.22017 .46576 m .21393 .46465 L .21032 .46275 L p F P
0 g
s
.043 .545 .879 r
.19625 .45852 m .19805 .45894 L .20398 .46137 L p F P
0 g
s
.079 .566 .898 r
.20671 .46079 m .19805 .45894 L .20398 .46137 L p F P
0 g
s
.079 .566 .898 r
.20398 .46137 m .21032 .46275 L .20671 .46079 L p F P
0 g
s
.463 .858 .665 r
.69397 .41207 m .68336 .41911 L .68252 .41956 L p F P
0 g
s
.409 .767 .995 r
.31725 .48307 m .32066 .48497 L .31323 .48535 L p F P
0 g
s
.409 .767 .995 r
.30632 .48378 m .31725 .48307 L p .31323 .48535 L F P
0 g
s
.409 .767 .995 r
.31323 .48535 m .30755 .48441 L .30632 .48378 L p F P
0 g
s
.554 .009 0 r
.084 .39781 m .08007 .39427 L .08428 .3974 L p F P
0 g
s
.554 .009 0 r
.08428 .3974 m .08777 .40053 L .084 .39781 L p F P
0 g
s
.52 0 0 r
.09277 .40417 m .09154 .40315 L .08777 .40053 L p F P
0 g
s
.745 .314 .227 r
.29588 .37547 m .29276 .37135 L .30001 .37341 L p F P
0 g
s
.745 .314 .227 r
.29959 .37649 m .29588 .37547 L p .30001 .37341 L F P
0 g
s
.745 .314 .227 r
.30001 .37341 m .30142 .37513 L .29959 .37649 L p F P
0 g
s
.694 .156 0 r
.2143 .32175 m .21109 .31842 L .20746 .31646 L p F P
0 g
s
.534 .918 .924 r
.60338 .45661 m .60462 .45668 L .59419 .46134 L p F P
0 g
s
.534 .918 .924 r
.59419 .46134 m .59187 .46121 L .60338 .45661 L p F P
0 g
s
.732 .323 .274 r
.31368 .38368 m .31056 .37954 L .31856 .38134 L p F P
0 g
s
.732 .323 .274 r
.31671 .38436 m .31368 .38368 L p .31856 .38134 L F P
0 g
s
.732 .323 .274 r
.31856 .38134 m .31901 .38189 L .31671 .38436 L p F P
0 g
s
.748 .978 .918 r
.66816 .26074 m .66305 .26418 L .66036 .26375 L p F P
0 g
s
0 0 0 r
.76068 .35036 m .75495 .35612 L .75969 .34935 L p F P
0 g
s
0 0 0 r
.75969 .34935 m .7619 .34713 L .76068 .35036 L p F P
0 g
s
.631 .269 .338 r
.41006 .39713 m .39764 .39732 L .3972 .39834 L p F P
0 g
s
.649 .289 .346 r
.39764 .39732 m .3972 .39834 L .39601 .3973 L closepath p F P
0 g
s
.646 .291 .355 r
.38741 .40093 m .38345 .39698 L .39601 .3973 L p F P
0 g
s
.646 .291 .355 r
.39607 .40111 m .38741 .40093 L p .39601 .3973 L F P
0 g
s
.646 .291 .355 r
.39601 .3973 m .3972 .39834 L .39607 .40111 L p F P
0 g
s
.518 .894 .964 r
.55072 .47245 m .55163 .47263 L .5402 .47619 L p F P
0 g
s
.518 .894 .964 r
.5402 .47619 m .53941 .47603 L .55072 .47245 L p F P
0 g
s
.75 .922 .948 r
.69753 .24187 m .69909 .24292 L .69738 .24532 L p F P
0 g
s
.75 .922 .948 r
.686 .24897 m .69753 .24187 L p .69738 .24532 L F P
0 g
s
.756 .896 .94 r
.7002 .24367 m .69738 .24532 L .69909 .24292 L closepath p F P
0 g
s
0 .26 .667 r
.12602 .42612 m .1264 .42632 L .13124 .42917 L p F P
0 g
s
0 .32 .726 r
.13274 .42939 m .13753 .43227 L .13124 .42917 L p F P
0 g
s
0 .32 .726 r
.13124 .42917 m .1264 .42632 L .13274 .42939 L p F P
0 g
s
.728 .836 .931 r
.71986 .23726 m .72607 .23438 L .72339 .2316 L p F P
0 g
s
.728 .836 .931 r
.72339 .2316 m .72308 .23176 L .71986 .23726 L p F P
0 g
s
.712 .846 .946 r
.71177 .2374 m .72308 .23176 L .71986 .23726 L p F P
0 g
s
.466 .515 .824 r
.77315 .24377 m .7753 .24854 L .78084 .24979 L p F P
0 g
s
.629 .271 .345 r
.41208 .39709 m .4116 .39827 L .41006 .39713 L closepath p F P
0 g
s
.631 .269 .338 r
.41059 .40093 m .4116 .39827 L .41006 .39713 L p F P
0 g
s
.631 .269 .338 r
.40049 .40109 m .41059 .40093 L p .41006 .39713 L F P
0 g
s
.631 .269 .338 r
.3972 .39834 m .40049 .40109 L p .41006 .39713 L F P
0 g
s
.454 .787 .999 r
.33841 .48768 m .34942 .48656 L .35277 .48836 L p F P
0 g
s
.477 .788 .999 r
.34942 .48656 m .33841 .48768 L .33503 .48589 L p F P
0 g
s
.451 .09 .26 r
.48797 .37914 m .48032 .3811 L .47887 .38481 L p F P
0 g
s
.619 .26 .34 r
.42459 .40021 m .426 .3963 L .41208 .39709 L p F P
0 g
s
.619 .26 .34 r
.41526 .4007 m .42459 .40021 L p .41208 .39709 L F P
0 g
s
.619 .26 .34 r
.41208 .39709 m .4116 .39827 L .41526 .4007 L p F P
0 g
s
.241 .676 .959 r
.26161 .47701 m .25998 .47617 L .25843 .47604 L closepath p F P
0 g
s
.231 .67 .956 r
.24578 .47339 m .25164 .47392 L .25843 .47604 L p F P
0 g
s
.248 .678 .962 r
.25164 .47392 m .24578 .47339 L .24222 .47158 L p F P
0 g
s
.753 .297 .168 r
.27938 .36682 m .27616 .36276 L .28286 .36502 L p F P
0 g
s
.753 .297 .168 r
.28128 .36745 m .27938 .36682 L p .28286 .36502 L F P
0 g
s
.753 .297 .168 r
.28286 .36502 m .28393 .36629 L .28128 .36745 L p F P
0 g
s
.664 .304 .352 r
.38096 .40069 m .38741 .40093 L .38345 .39698 L p F P
0 g
s
.664 .304 .352 r
.38345 .39698 m .38261 .39695 L .38096 .40069 L p F P
0 g
s
.677 .318 .358 r
.37554 .40039 m .38096 .40069 L .38261 .39695 L p F P
0 g
s
.677 .318 .358 r
.38261 .39695 m .3719 .39634 L .37554 .40039 L p F P
0 g
s
.725 .216 0 r
.05677 .37368 m .06066 .37697 L .05763 .37296 L p F P
0 g
s
.725 .216 0 r
.05763 .37296 m .05375 .36967 L .05677 .37368 L p F P
0 g
s
.749 .347 .288 r
.31901 .38189 m .32161 .38552 L .31671 .38436 L closepath p F P
0 g
s
.503 .872 .653 r
.61467 .29787 m .6107 .30081 L .61378 .2984 L closepath p F P
0 g
s
0 0 0 r
.61192 .29954 m .61378 .2984 L .6107 .30081 L p F P
0 g
s
0 0 0 r
.60827 .3024 m .61192 .29954 L p .6107 .30081 L F P
0 g
s
0 0 0 r
.60227 .30712 m .60827 .3024 L p .6107 .30081 L F P
0 g
s
.727 .338 .313 r
.33311 .39137 m .34186 .39293 L .3387 .38876 L p F P
0 g
s
.727 .338 .313 r
.33301 .39122 m .33311 .39137 L p .3387 .38876 L F P
0 g
s
.727 .338 .313 r
.3387 .38876 m .33522 .38814 L .33301 .39122 L p F P
0 g
s
.653 .123 0 r
.07207 .38733 m .07086 .38601 L .06708 .38311 L p F P
0 g
s
.751 .895 .943 r
.70909 .23521 m .71177 .2374 L .7002 .24367 L p F P
0 g
s
.751 .895 .943 r
.70172 .23946 m .70909 .23521 L p .7002 .24367 L F P
0 g
s
.751 .895 .943 r
.7002 .24367 m .69909 .24292 L .70172 .23946 L p F P
0 g
s
.282 .234 .626 r
.79252 .2756 m .78855 .28119 L .786 .27677 L p F P
0 g
s
.282 .234 .626 r
.786 .27677 m .78986 .27122 L .79252 .2756 L p F P
0 g
s
.731 .209 0 r
.24033 .3419 m .23682 .33799 L .24229 .34071 L p F P
0 g
s
.731 .209 0 r
.24477 .34399 m .24033 .3419 L p .24229 .34071 L F P
0 g
s
.731 .209 0 r
.24229 .34071 m .24555 .34411 L .24477 .34399 L p F P
0 g
s
.771 .961 .929 r
.67451 .25644 m .66816 .26074 L .6723 .25574 L closepath p F P
0 g
s
.748 .978 .918 r
.67182 .25559 m .6723 .25574 L .66816 .26074 L p F P
0 g
s
.748 .978 .918 r
.66036 .26375 m .67182 .25559 L p .66816 .26074 L F P
0 g
s
.011 0 0 r
.55516 .34069 m .55488 .3411 L .55704 .33967 L closepath p F P
0 g
s
.688 .145 0 r
.21802 .32553 m .22303 .32843 L .21917 .32469 L p F P
0 g
s
.688 .145 0 r
.21917 .32469 m .2143 .32175 L .21802 .32553 L p F P
0 g
s
.133 0 0 r
.552 .34582 m .55329 .34368 L .54301 .34865 L p F P
0 g
s
.133 0 0 r
.54678 .34905 m .552 .34582 L p .54301 .34865 L F P
0 g
s
.133 0 0 r
.54301 .34865 m .54123 .35179 L .54678 .34905 L p F P
0 g
s
.78 .308 .118 r
.26652 .35589 m .26681 .35626 L .26607 .35594 L closepath p F P
0 g
s
0 0 .19 r
.77738 .32483 m .7724 .33062 L .77471 .32462 L p F P
0 g
s
0 0 .19 r
.77471 .32462 m .77977 .3188 L .77738 .32483 L p F P
0 g
s
.52 .91 .928 r
.58912 .46102 m .59187 .46121 L .58039 .46555 L p F P
0 g
s
.52 .91 .928 r
.58039 .46555 m .57846 .46541 L .58912 .46102 L p F P
0 g
s
0 0 0 r
.56716 .33257 m .56628 .3337 L .57197 .32968 L closepath p F P
0 g
s
.479 .889 .77 r
.65775 .43382 m .65283 .4365 L .65698 .43406 L closepath p F P
0 g
s
.508 .909 .813 r
.65506 .43445 m .65698 .43406 L .65283 .4365 L p F P
0 g
s
.508 .909 .813 r
.64353 .44055 m .65506 .43445 L p .65283 .4365 L F P
0 g
s
0 .478 .84 r
.17994 .45245 m .1786 .4517 L .17795 .45149 L closepath p F P
0 g
s
.581 .222 .324 r
.42605 .39618 m .42629 .39628 L .426 .3963 L closepath p F P
0 g
s
.363 .745 .988 r
.30755 .48441 m .30632 .48378 L .30465 .48381 L closepath p F P
0 g
s
.515 .878 .656 r
.62284 .29171 m .61467 .29787 L .61378 .2984 L p F P
0 g
s
.209 0 .05 r
.54058 .35298 m .54123 .35179 L .53067 .3564 L p F P
0 g
s
.209 0 .05 r
.53067 .3564 m .52916 .35921 L .54058 .35298 L p F P
0 g
s
.569 .02 0 r
.19028 .30327 m .19249 .30525 L .19689 .30839 L p F P
0 g
s
.564 .015 0 r
.19656 .30887 m .20106 .31198 L .19689 .30839 L p F P
0 g
s
.564 .015 0 r
.19689 .30839 m .19249 .30525 L .19656 .30887 L p F P
0 g
s
.475 .796 .999 r
.35277 .48836 m .36383 .487 L .36715 .48879 L p F P
0 g
s
.506 .795 .997 r
.36383 .487 m .35277 .48836 L .34942 .48656 L p F P
0 g
s
.685 .316 .342 r
.36512 .39955 m .37554 .40039 L .3719 .39634 L p F P
0 g
s
.685 .316 .342 r
.3719 .39634 m .36694 .39594 L .36512 .39955 L p F P
0 g
s
.535 .887 .981 r
.53721 .47547 m .5258 .4788 L .52277 .47795 L p F P
0 g
s
.517 .88 .981 r
.51138 .48107 m .52277 .47795 L .5258 .4788 L p F P
0 g
s
.59 .242 .347 r
.42629 .39628 m .426 .3963 L .42459 .40021 L p F P
0 g
s
.59 .241 .346 r
.4395 .39508 m .42629 .39628 L .43272 .39947 L p F P
0 g
s
.59 .242 .347 r
.42459 .40021 m .43272 .39947 L .42629 .39628 L p F P
0 g
s
.222 .152 .563 r
.79014 .28592 m .7872 .29004 L .78635 .28429 L p F P
0 g
s
.222 .152 .563 r
.78635 .28429 m .78855 .28119 L .79014 .28592 L p F P
0 g
s
.789 .328 .146 r
.26381 .35786 m .26983 .36037 L .26681 .35626 L p F P
0 g
s
.789 .328 .146 r
.26286 .3565 m .26381 .35786 L p .26681 .35626 L F P
0 g
s
.789 .328 .146 r
.26681 .35626 m .26607 .35594 L .26286 .3565 L p F P
0 g
s
.365 .745 .989 r
.29201 .48217 m .29663 .48209 L .30465 .48381 L p F P
0 g
s
.358 .745 .987 r
.29201 .48217 m .29663 .48209 L .28864 .48047 L closepath p F P
0 g
s
0 0 0 r
.57899 .32424 m .57768 .32571 L .58496 .32031 L closepath p F P
0 g
s
.679 .158 0 r
.06329 .38008 m .06066 .37697 L .06463 .38022 L p F P
0 g
s
.679 .158 0 r
.06463 .38022 m .06708 .38311 L .06329 .38008 L p F P
0 g
s
0 0 0 r
.74109 .37221 m .74042 .37314 L .74301 .37042 L closepath p F P
0 g
s
.52 0 0 r
.08777 .40053 m .08844 .40109 L .09277 .40417 L p F P
0 g
s
.44 0 0 r
.09318 .40461 m .09749 .40769 L .09277 .40417 L p F P
0 g
s
.44 0 0 r
.09277 .40417 m .08844 .40109 L .09318 .40461 L p F P
0 g
s
.641 .285 .353 r
.3972 .39834 m .40049 .40109 L .39607 .40111 L closepath p F P
0 g
s
.724 .334 .311 r
.33522 .38814 m .33301 .39122 L .32992 .38722 L closepath p F P
0 g
s
0 0 0 r
.76057 .35058 m .76068 .35036 L .75495 .35612 L p F P
0 g
s
0 0 0 r
.75554 .35706 m .76057 .35058 L p .75495 .35612 L F P
0 g
s
0 0 0 r
.75108 .36156 m .75554 .35706 L p .75495 .35612 L F P
0 g
s
0 0 0 r
.75495 .35612 m .75163 .36039 L .75108 .36156 L p F P
0 g
s
.152 .614 .929 r
.22446 .46644 m .22017 .46576 L .22633 .4681 L p F P
0 g
s
.152 .614 .929 r
.22633 .4681 m .22804 .46839 L .22446 .46644 L p F P
0 g
s
0 .183 .605 r
.1087 .41537 m .11153 .41715 L .11613 .42011 L p F P
0 g
s
0 .232 .654 r
.11713 .42044 m .12171 .4234 L .11613 .42011 L p F P
0 g
s
0 .232 .654 r
.11613 .42011 m .11153 .41715 L .11713 .42044 L p F P
0 g
s
.422 .819 .6 r
.69484 .41147 m .69397 .41207 L .69467 .41159 L closepath p F P
0 g
s
.463 .858 .665 r
.69228 .4128 m .69467 .41159 L .69397 .41207 L p F P
0 g
s
.463 .858 .665 r
.68948 .41468 m .69228 .4128 L p .69397 .41207 L F P
0 g
s
.463 .858 .665 r
.68252 .41956 m .68948 .41468 L p .69397 .41207 L F P
0 g
s
.051 .548 .884 r
.19625 .45852 m .19805 .45894 L .1933 .45695 L closepath p F P
0 g
s
.252 .678 .963 r
.25646 .47428 m .25164 .47392 L .25843 .47604 L p F P
0 g
s
.252 .678 .963 r
.25843 .47604 m .25998 .47617 L .25646 .47428 L p F P
0 g
s
.54 .895 .976 r
.54866 .47192 m .55072 .47245 L .53941 .47603 L p F P
0 g
s
.54 .895 .976 r
.53941 .47603 m .53721 .47547 L .54866 .47192 L p F P
0 g
s
.665 .729 .897 r
.75226 .2295 m .74046 .23302 L .73777 .22964 L p F P
0 g
s
.691 .767 .91 r
.72607 .23438 m .73777 .22964 L .74046 .23302 L p F P
0 g
s
.65 .708 .89 r
.74046 .23302 m .75226 .2295 L .75497 .2336 L p F P
0 g
s
0 .311 .781 r
.15265 .27565 m .15227 .27543 L .14865 .27199 L p F P
0 g
s
.521 .163 .3 r
.4652 .39121 m .4662 .3884 L .46302 .38799 L p F P
0 g
s
.521 .163 .3 r
.45254 .39336 m .4652 .39121 L p .46302 .38799 L F P
0 g
s
.522 .162 .296 r
.46659 .38738 m .4662 .3884 L .46302 .38799 L closepath p F P
0 g
s
.453 .837 .61 r
.70378 .40478 m .70629 .40319 L .69484 .41147 L p F P
0 g
s
.453 .837 .61 r
.70333 .40511 m .70378 .40478 L p .69484 .41147 L F P
0 g
s
.453 .837 .61 r
.69484 .41147 m .69467 .41159 L .70333 .40511 L p F P
0 g
s
0 .149 .619 r
.17549 .29206 m .17955 .29536 L .17491 .29198 L p F P
0 g
s
0 .149 .619 r
.17491 .29198 m .17091 .28866 L .17549 .29206 L p F P
0 g
s
0 .146 .616 r
.16949 .2876 m .17091 .28866 L .17491 .29198 L p F P
0 g
s
.07 0 0 r
.55704 .33967 m .55488 .3411 L .55329 .34368 L p F P
0 g
s
.692 .324 .346 r
.3647 .39951 m .36512 .39955 L .36694 .39594 L p F P
0 g
s
.692 .324 .346 r
.36694 .39594 m .36123 .39542 L .3647 .39951 L p F P
0 g
s
.76 .281 .103 r
.26607 .35594 m .26286 .3565 L .26059 .35382 L closepath p F P
0 g
s
.759 .96 .934 r
.68357 .25055 m .67451 .25644 L .6723 .25574 L p F P
0 g
s
.279 0 .11 r
.51807 .36386 m .51777 .36447 L .52419 .36148 L closepath p F P
0 g
s
.376 .744 .991 r
.30288 .48189 m .29663 .48209 L .30465 .48381 L p F P
0 g
s
.376 .744 .991 r
.30465 .48381 m .30632 .48378 L .30288 .48189 L p F P
0 g
s
.466 .515 .824 r
.78452 .24421 m .77392 .24246 L .77315 .24377 L p F P
0 g
s
.466 .515 .824 r
.78084 .24979 m .78452 .24421 L p .77315 .24377 L F P
0 g
s
.517 .557 .836 r
.77247 .24234 m .77392 .24246 L .77315 .24377 L closepath p F P
0 g
s
.616 .264 .351 r
.4116 .39827 m .41526 .4007 L .41059 .40093 L closepath p F P
0 g
s
.781 .34 .203 r
.28393 .36629 m .28595 .36913 L .28128 .36745 L closepath p F P
0 g
s
0 0 0 r
.59068 .31575 m .58909 .31728 L .5969 .31126 L closepath p F P
0 g
s
.767 .346 .25 r
.30142 .37513 m .30312 .37754 L .29959 .37649 L closepath p F P
0 g
s
.601 .937 .745 r
.62607 .28928 m .62284 .29171 L .62526 .28962 L closepath p F P
0 g
s
.515 .878 .656 r
.62334 .29047 m .62526 .28962 L .62284 .29171 L p F P
0 g
s
.515 .878 .656 r
.61936 .29362 m .62334 .29047 L p .62284 .29171 L F P
0 g
s
.515 .878 .656 r
.61378 .2984 m .61936 .29362 L p .62284 .29171 L F P
0 g
s
.493 .804 1 r
.36715 .48879 m .37825 .48722 L .38154 .48901 L p F P
0 g
s
.528 .801 .996 r
.37825 .48722 m .36715 .48879 L .36383 .487 L p F P
0 g
s
.704 .785 .915 r
.73777 .22964 m .72607 .23438 L .72339 .2316 L p F P
0 g
s
.02 0 0 r
.56628 .3337 m .55704 .33967 L .56515 .33535 L closepath p F P
0 g
s
.07 0 0 r
.56343 .3379 m .56515 .33535 L .55704 .33967 L p F P
0 g
s
.07 0 0 r
.56176 .33903 m .56343 .3379 L p .55704 .33967 L F P
0 g
s
.07 0 0 r
.55329 .34368 m .56176 .33903 L p .55704 .33967 L F P
0 g
s
0 .311 .781 r
.14865 .27199 m .14899 .27219 L .15265 .27565 L p F P
0 g
s
0 .312 .782 r
.15428 .27528 m .15795 .27875 L .15265 .27565 L p F P
0 g
s
0 .312 .782 r
.15265 .27565 m .14899 .27219 L .15428 .27528 L p F P
0 g
s
.562 .018 0 r
.19249 .30525 m .19028 .30327 L .18667 .30062 L p F P
0 g
s
0 .191 .619 r
.11153 .41715 m .1087 .41537 L .10495 .41285 L p F P
0 g
s
.539 .925 .893 r
.62925 .44647 m .6295 .44646 L .61942 .45163 L p F P
0 g
s
.539 .925 .893 r
.61942 .45163 m .61772 .45169 L .62925 .44647 L p F P
0 g
s
.505 .902 .776 r
.66661 .42808 m .66926 .42728 L .65775 .43382 L p F P
0 g
s
.505 .902 .776 r
.66601 .42842 m .66661 .42808 L p .65775 .43382 L F P
0 g
s
.505 .902 .776 r
.65775 .43382 m .65698 .43406 L .66601 .42842 L p F P
0 g
s
.508 .884 .688 r
.69467 .41159 m .69228 .4128 L .70333 .40511 L closepath p F P
0 g
s
.532 .88 .986 r
.52088 .47733 m .52277 .47795 L .51138 .48107 L p F P
0 g
s
.532 .88 .986 r
.51138 .48107 m .50906 .48034 L .52088 .47733 L p F P
0 g
s
.518 .901 .736 r
.68252 .41956 m .68077 .42027 L .68948 .41468 L closepath p F P
0 g
s
.763 .358 .285 r
.30597 .38177 m .31368 .38368 L .31056 .37954 L p F P
0 g
s
.763 .358 .285 r
.31056 .37954 m .30312 .37754 L .30597 .38177 L p F P
0 g
s
.192 .092 .505 r
.78771 .29534 m .78678 .29653 L .78604 .29152 L p F P
0 g
s
.192 .092 .505 r
.78604 .29152 m .7872 .29004 L .78771 .29534 L p F P
0 g
s
.056 0 .352 r
.78581 .30736 m .78132 .31304 L .78215 .30751 L p F P
0 g
s
.056 0 .352 r
.78215 .30751 m .78668 .30182 L .78581 .30736 L p F P
0 g
s
0 0 0 r
.75163 .36039 m .74943 .36313 L .75108 .36156 L closepath p F P
0 g
s
0 .422 .805 r
.15732 .44186 m .15443 .44076 L .15954 .4435 L p F P
0 g
s
0 .422 .805 r
.15954 .4435 m .16101 .44406 L .15732 .44186 L p F P
0 g
s
0 .483 .849 r
.17494 .44958 m .1726 .44885 L .17795 .45149 L p F P
0 g
s
0 .483 .849 r
.17795 .45149 m .1786 .4517 L .17494 .44958 L p F P
0 g
s
.604 .938 .745 r
.63489 .28263 m .62607 .28928 L .62526 .28962 L p F P
0 g
s
0 0 .1 r
.77169 .33142 m .77144 .3326 L .7724 .33062 L closepath p F P
0 g
s
.709 .346 .358 r
.35443 .39845 m .3647 .39951 L .36123 .39542 L p F P
0 g
s
.709 .346 .358 r
.36123 .39542 m .35135 .39424 L .35443 .39845 L p F P
0 g
s
.493 .133 .283 r
.4775 .38846 m .47887 .38481 L .46659 .38738 L p F P
0 g
s
.493 .133 .283 r
.46659 .38738 m .4662 .3884 L .4775 .38846 L p F P
0 g
s
.524 .918 .897 r
.61492 .45175 m .61772 .45169 L .60621 .45664 L p F P
0 g
s
.524 .918 .897 r
.61467 .45186 m .61492 .45175 L p .60621 .45664 L F P
0 g
s
.524 .918 .897 r
.60621 .45664 m .60462 .45668 L .61467 .45186 L p F P
0 g
s
.777 .351 .24 r
.28883 .37333 m .29588 .37547 L .29276 .37135 L p F P
0 g
s
.777 .351 .24 r
.29276 .37135 m .28595 .36913 L .28883 .37333 L p F P
0 g
s
.685 .138 0 r
.22839 .33132 m .2283 .33129 L .22825 .33125 L closepath p F P
0 g
s
.579 .043 0 r
.07188 .38789 m .07594 .3911 L .07207 .38733 L p F P
0 g
s
.579 .043 0 r
.07207 .38733 m .068 .38413 L .07188 .38789 L p F P
0 g
s
.653 .123 0 r
.06708 .38311 m .068 .38413 L .07207 .38733 L p F P
0 g
s
.533 .579 .847 r
.77392 .24246 m .77247 .24234 L .76968 .23681 L p F P
0 g
s
.781 .293 .059 r
.24555 .34411 m .24591 .34458 L .25142 .34727 L p F P
0 g
s
.789 .309 .081 r
.24894 .34866 m .25463 .35129 L .25142 .34727 L p F P
0 g
s
.789 .309 .081 r
.25142 .34727 m .24591 .34458 L .24894 .34866 L p F P
0 g
s
.678 .13 0 r
.22465 .33002 m .22303 .32843 L .22825 .33125 L p F P
0 g
s
.678 .13 0 r
.22825 .33125 m .2283 .33129 L .22465 .33002 L p F P
0 g
s
.618 .666 .874 r
.76161 .23247 m .75497 .2336 L .75226 .2295 L p F P
0 g
s
.351 .325 .689 r
.79218 .26791 m .78986 .27122 L .78606 .26722 L p F P
0 g
s
.351 .325 .689 r
.79081 .26246 m .79218 .26791 L p .78606 .26722 L F P
0 g
s
.351 .325 .689 r
.78606 .26722 m .78993 .26163 L .79081 .26246 L p F P
0 g
s
.765 .254 0 r
.23157 .3352 m .2283 .33129 L .22465 .33002 L p F P
0 g
s
.723 .335 .313 r
.32449 .38976 m .32161 .38552 L .32992 .38722 L p F P
0 g
s
.723 .335 .313 r
.33294 .39133 m .32449 .38976 L p .32992 .38722 L F P
0 g
s
.723 .335 .313 r
.32992 .38722 m .33301 .39122 L .33294 .39133 L p F P
0 g
s
.326 .712 .982 r
.27075 .47659 m .25998 .47617 L .25646 .47428 L p F P
0 g
s
.509 .811 .999 r
.39304 .48743 m .39595 .48901 L p .38154 .48901 L F P
0 g
s
.509 .811 .999 r
.38154 .48901 m .39165 .48739 L .39304 .48743 L p F P
0 g
s
.542 .807 .995 r
.39165 .48739 m .38154 .48901 L .37825 .48722 L p F P
0 g
s
.516 .866 .99 r
.49701 .48308 m .49696 .48306 L .49631 .48322 L closepath p F P
0 g
s
.53 .862 .995 r
.49387 .4818 m .49696 .48306 L .49631 .48322 L p F P
0 g
s
.53 .862 .995 r
.48253 .48461 m .49387 .4818 L p .49631 .48322 L F P
0 g
s
0 0 0 r
.60227 .30712 m .6005 .30851 L .60827 .3024 L closepath p F P
0 g
s
0 0 0 r
.76096 .35007 m .76068 .35036 L .7619 .34713 L p F P
0 g
s
0 0 0 r
.7619 .34713 m .7654 .34338 L .76096 .35007 L p F P
0 g
s
.445 .076 .242 r
.49219 .37808 m .49199 .37857 L .48797 .37914 L closepath p F P
0 g
s
.451 .09 .26 r
.49077 .38181 m .49199 .37857 L .48797 .37914 L p F P
0 g
s
.451 .09 .26 r
.47887 .38481 m .49077 .38181 L p .48797 .37914 L F P
0 g
s
.356 0 .185 r
.51496 .37085 m .51649 .36732 L .50528 .37113 L p F P
0 g
s
.356 0 .185 r
.50528 .37113 m .50374 .37468 L .51496 .37085 L p F P
0 g
s
0 0 0 r
.74944 .36433 m .74301 .37042 L .74943 .36313 L p F P
0 g
s
0 0 0 r
.74943 .36313 m .75108 .36156 L .74944 .36433 L p F P
0 g
s
.483 .855 .625 r
.7064 .40312 m .70629 .40319 L .70675 .40284 L closepath p F P
0 g
s
.226 .655 .956 r
.23812 .46962 m .22804 .46839 L .22446 .46644 L p F P
0 g
s
0 .356 .757 r
.13976 .43327 m .13753 .43227 L .1424 .4351 L p F P
0 g
s
0 .356 .757 r
.1424 .4351 m .14347 .43558 L .13976 .43327 L p F P
0 g
s
.56 .211 .334 r
.44661 .39413 m .4395 .39508 L .43811 .39898 L p F P
0 g
s
.59 .241 .346 r
.43272 .39947 m .43811 .39898 L .4395 .39508 L p F P
0 g
s
.556 0 0 r
.20383 .31433 m .20106 .31198 L .20572 .31502 L p F P
0 g
s
.556 0 0 r
.20572 .31502 m .20746 .31646 L .20383 .31433 L p F P
0 g
s
.525 .912 .778 r
.66997 .42706 m .66926 .42728 L .67309 .42501 L closepath p F P
0 g
s
.532 .872 .99 r
.50833 .48008 m .50906 .48034 L .49701 .48308 L p F P
0 g
s
.532 .872 .99 r
.49701 .48308 m .49696 .48306 L .50833 .48008 L p F P
0 g
s
.041 .529 .883 r
.18672 .45388 m .1786 .4517 L .17494 .44958 L p F P
0 g
s
.308 0 .153 r
.52419 .36148 m .51777 .36447 L .51649 .36732 L p F P
0 g
s
.541 .909 .957 r
.5775 .46528 m .56602 .46932 L .56309 .46883 L p F P
0 g
s
.52 .901 .955 r
.55163 .47263 m .56309 .46883 L .56602 .46932 L p F P
0 g
s
.527 .921 .859 r
.64338 .44063 m .63201 .44616 L .6295 .44646 L p F P
0 g
s
.445 .769 .997 r
.31725 .48307 m .30632 .48378 L .30288 .48189 L p F P
0 g
s
.752 .897 .943 r
.69909 .24292 m .69753 .24187 L .70172 .23946 L closepath p F P
0 g
s
.555 .867 .995 r
.50833 .48008 m .49696 .48306 L .49387 .4818 L p F P
0 g
s
.137 .598 .925 r
.20476 .45969 m .20671 .46079 L .19805 .45894 L p F P
0 g
s
.137 .598 .925 r
.20213 .45853 m .20476 .45969 L p .19805 .45894 L F P
0 g
s
.137 .598 .925 r
.19261 .45656 m .20213 .45853 L p .19805 .45894 L F P
0 g
s
.137 .598 .925 r
.19805 .45894 m .1933 .45695 L .19261 .45656 L p F P
0 g
s
.709 .329 .327 r
.35078 .39353 m .35135 .39424 L .35043 .39411 L closepath p F P
0 g
s
.488 .859 .63 r
.70675 .40284 m .70629 .40319 L .70378 .40478 L p F P
0 g
s
0 0 0 r
.70675 .40284 m .71772 .39419 L .71526 .39609 L p F P
0 g
s
0 0 0 r
.71526 .39609 m .71519 .39614 L .70675 .40284 L p F P
0 g
s
.488 .859 .63 r
.70378 .40478 m .71519 .39614 L .70675 .40284 L p F P
0 g
s
.52 .818 .999 r
.40768 .48736 m .41037 .48881 L p .39595 .48901 L F P
0 g
s
.52 .818 .999 r
.39595 .48901 m .40528 .48738 L .40768 .48736 L p F P
0 g
s
.522 .817 .999 r
.39595 .48901 m .40528 .48738 L .39304 .48743 L closepath p F P
0 g
s
.782 .332 .181 r
.27282 .36451 m .27938 .36682 L .27616 .36276 L p F P
0 g
s
.782 .332 .181 r
.27616 .36276 m .26983 .36037 L .27282 .36451 L p F P
0 g
s
0 .148 .584 r
.10119 .41025 m .09749 .40769 L .10188 .41074 L p F P
0 g
s
0 .148 .584 r
.10188 .41074 m .10495 .41285 L .10119 .41025 L p F P
0 g
s
.677 .975 .815 r
.63749 .28068 m .63489 .28263 L .63677 .28086 L closepath p F P
0 g
s
.604 .938 .745 r
.63477 .28139 m .63677 .28086 L .63489 .28263 L p F P
0 g
s
.604 .938 .745 r
.63039 .28486 m .63477 .28139 L p .63489 .28263 L F P
0 g
s
.604 .938 .745 r
.62526 .28962 m .63039 .28486 L p .63489 .28263 L F P
0 g
s
0 0 .097 r
.77437 .33107 m .77738 .32483 L .7724 .33062 L p F P
0 g
s
0 0 .097 r
.77089 .33512 m .77437 .33107 L p .7724 .33062 L F P
0 g
s
0 0 .097 r
.7724 .33062 m .77144 .3326 L .77089 .33512 L p F P
0 g
s
0 .172 .627 r
.18305 .29782 m .17955 .29536 L .18374 .29859 L p F P
0 g
s
0 .172 .627 r
.18374 .29859 m .18667 .30062 L .18305 .29782 L p F P
0 g
s
.773 .938 .936 r
.686 .24897 m .68357 .25055 L .68509 .24855 L closepath p F P
0 g
s
.759 .96 .934 r
.68332 .24774 m .68509 .24855 L .68357 .25055 L p F P
0 g
s
.759 .96 .934 r
.67319 .25466 m .68332 .24774 L p .68357 .25055 L F P
0 g
s
.759 .96 .934 r
.6723 .25574 m .67319 .25466 L p .68357 .25055 L F P
0 g
s
0 .269 .682 r
.12602 .42612 m .1264 .42632 L .12463 .42524 L closepath p F P
0 g
s
.554 .859 .997 r
.49387 .4818 m .48253 .48461 L .47941 .48325 L p F P
0 g
s
.537 .855 .997 r
.46809 .48591 m .47941 .48325 L .48253 .48461 L p F P
0 g
s
.533 .579 .847 r
.76968 .23681 m .77709 .23703 L .77392 .24246 L p F P
0 g
s
.511 .55 .833 r
.78463 .24404 m .78452 .24421 L .77392 .24246 L p F P
0 g
s
.511 .55 .833 r
.78184 .2375 m .78463 .24404 L p .77392 .24246 L F P
0 g
s
.511 .55 .833 r
.77392 .24246 m .77709 .23703 L .78184 .2375 L p F P
0 g
s
.726 .862 .946 r
.72308 .23176 m .71177 .2374 L .70909 .23521 L p F P
0 g
s
.526 .825 .999 r
.42191 .48688 m .42479 .4884 L p .41037 .48881 L F P
0 g
s
.526 .825 .999 r
.41037 .48881 m .42027 .48695 L .42191 .48688 L p F P
0 g
s
.531 .822 .999 r
.41037 .48881 m .42027 .48695 L .40768 .48736 L closepath p F P
0 g
s
.673 .974 .815 r
.64709 .2735 m .63749 .28068 L .63677 .28086 L p F P
0 g
s
.541 .889 .656 r
.61378 .2984 m .61192 .29954 L .61936 .29362 L closepath p F P
0 g
s
0 0 0 r
.7494 .36438 m .74944 .36433 L .74301 .37042 L p F P
0 g
s
0 0 0 r
.74241 .37176 m .7494 .36438 L p .74301 .37042 L F P
0 g
s
0 0 0 r
.73924 .37478 m .74241 .37176 L p .74301 .37042 L F P
0 g
s
0 0 0 r
.74301 .37042 m .74042 .37314 L .73924 .37478 L p F P
0 g
s
0 .468 .843 r
.16733 .44617 m .16101 .44406 L .15732 .44186 L p F P
0 g
s
0 0 0 r
.57197 .32968 m .56628 .3337 L .56515 .33535 L p F P
0 g
s
.555 .85 .998 r
.47941 .48325 m .46809 .48591 L .46495 .48445 L p F P
0 g
s
.535 .847 .999 r
.45366 .48696 m .46495 .48445 L .46809 .48591 L p F P
0 g
s
0 0 .272 r
.78034 .31425 m .78008 .31769 L .78132 .31304 L closepath p F P
0 g
s
.77 .938 .937 r
.69485 .24024 m .69753 .24187 L .686 .24897 L p F P
0 g
s
.77 .938 .937 r
.68814 .24461 m .69485 .24024 L p .686 .24897 L F P
0 g
s
.77 .938 .937 r
.686 .24897 m .68509 .24855 L .68814 .24461 L p F P
0 g
s
0 .367 .774 r
.12802 .42648 m .13274 .42939 L .1264 .42632 L p F P
0 g
s
0 .367 .774 r
.12229 .42371 m .12802 .42648 L p .1264 .42632 L F P
0 g
s
0 .367 .774 r
.1264 .42632 m .12463 .42524 L .12229 .42371 L p F P
0 g
s
.538 .829 .999 r
.43572 .48599 m .43603 .48616 L .42479 .4884 L p F P
0 g
s
.538 .829 .999 r
.42479 .4884 m .42191 .48688 L .43572 .48599 L p F P
0 g
s
.53 .832 .999 r
.42479 .4884 m .43603 .48616 L .43922 .48779 L p F P
0 g
s
.544 .002 0 r
.08005 .3948 m .07594 .3911 L .08007 .39427 L p F P
0 g
s
.544 .002 0 r
.08207 .39636 m .08005 .3948 L p .08007 .39427 L F P
0 g
s
.544 .002 0 r
.08007 .39427 m .084 .39781 L .08207 .39636 L p F P
0 g
s
0 .403 .797 r
.14941 .43799 m .14347 .43558 L .13976 .43327 L p F P
0 g
s
.393 .382 .728 r
.7904 .26094 m .78993 .26163 L .78453 .25816 L p F P
0 g
s
.393 .382 .728 r
.78453 .25816 m .78797 .2531 L .7904 .26094 L p F P
0 g
s
0 0 0 r
.74042 .37314 m .73563 .37801 L .73924 .37478 L closepath p F P
0 g
s
0 .335 .795 r
.16225 .28113 m .15795 .27875 L .16175 .28216 L p F P
0 g
s
0 .335 .795 r
.16175 .28216 m .16587 .28443 L .16225 .28113 L p F P
0 g
s
.715 .346 .349 r
.34851 .39765 m .35443 .39845 L .35135 .39424 L p F P
0 g
s
.715 .346 .349 r
.35135 .39424 m .35043 .39411 L .34851 .39765 L p F P
0 g
s
.499 .148 .304 r
.47746 .38859 m .4775 .38846 L .4662 .3884 L p F P
0 g
s
.499 .148 .304 r
.4662 .3884 m .4652 .39121 L .47746 .38859 L p F P
0 g
s
0 .151 .628 r
.17091 .28866 m .16949 .2876 L .16587 .28443 L p F P
0 g
s
.554 .843 .998 r
.46495 .48445 m .45366 .48696 L .45049 .48542 L p F P
0 g
s
.534 .839 .999 r
.43922 .48779 m .45049 .48542 L .45366 .48696 L p F P
0 g
s
.559 .833 .997 r
.45049 .48542 m .43922 .48779 L .43603 .48616 L p F P
0 g
s
.468 .829 .568 r
.71773 .39417 m .71772 .39419 L .71778 .39414 L closepath p F P
0 g
s
.472 .832 .572 r
.71778 .39414 m .71772 .39419 L .71526 .39609 L p F P
0 g
s
0 0 0 r
.72546 .38765 m .71778 .39414 L .7273 .38589 L p F P
0 g
s
.472 .832 .572 r
.71526 .39609 m .72546 .38765 L .71778 .39414 L p F P
0 g
s
.562 .211 .332 r
.45254 .39336 m .45169 .39577 L .44661 .39413 L closepath p F P
0 g
s
.56 .211 .334 r
.4512 .39728 m .45169 .39577 L .44661 .39413 L p F P
0 g
s
.56 .211 .334 r
.43811 .39898 m .4512 .39728 L p .44661 .39413 L F P
0 g
s
.155 .067 .495 r
.79087 .29094 m .78771 .29534 L .7872 .29004 L p F P
0 g
s
.155 .067 .495 r
.7872 .29004 m .79014 .28592 L .79087 .29094 L p F P
0 g
s
.717 .348 .35 r
.34488 .39715 m .34851 .39765 L .35043 .39411 L p F P
0 g
s
.717 .348 .35 r
.35043 .39411 m .34186 .39293 L .34488 .39715 L p F P
0 g
s
0 0 .108 r
.77144 .3326 m .76926 .33688 L .77089 .33512 L closepath p F P
0 g
s
.408 .041 .225 r
.50336 .37563 m .50374 .37468 L .49219 .37808 L p F P
0 g
s
.408 .041 .225 r
.49219 .37808 m .49199 .37857 L .50336 .37563 L p F P
0 g
s
.758 .246 0 r
.23492 .33915 m .24033 .3419 L .23682 .33799 L p F P
0 g
s
.758 .246 0 r
.23682 .33799 m .23157 .3352 L .23492 .33915 L p F P
0 g
s
.544 .927 .827 r
.65698 .43406 m .65506 .43445 L .66601 .42842 L closepath p F P
0 g
s
0 0 0 r
.73809 .37606 m .73924 .37478 L .73563 .37801 L p F P
0 g
s
0 0 0 r
.73446 .37955 m .73809 .37606 L p .73563 .37801 L F P
0 g
s
0 0 0 r
.72868 .38473 m .73446 .37955 L p .73563 .37801 L F P
0 g
s
0 0 0 r
.73563 .37801 m .7291 .38423 L .72868 .38473 L p F P
0 g
s
.398 .757 .993 r
.29944 .47991 m .30288 .48189 L .29663 .48209 L p F P
0 g
s
.398 .757 .993 r
.28854 .48042 m .29944 .47991 L p .29663 .48209 L F P
0 g
s
.398 .757 .993 r
.29663 .48209 m .28864 .48047 L .28854 .48042 L p F P
0 g
s
.452 .778 .998 r
.32066 .48497 m .33165 .48398 L .33503 .48589 L p F P
0 g
s
.478 .778 .997 r
.33165 .48398 m .32066 .48497 L .31725 .48307 L p F P
0 g
s
.447 .455 .774 r
.78472 .24427 m .78452 .24421 L .78084 .24979 L p F P
0 g
s
.447 .455 .774 r
.78084 .24979 m .78768 .25227 L .78472 .24427 L p F P
0 g
s
0 0 0 r
.7291 .38423 m .7273 .38589 L .72868 .38473 L closepath p F P
0 g
s
0 0 0 r
.7267 .38657 m .72546 .38765 L p .7273 .38589 L F P
0 g
s
0 0 0 r
.7273 .38589 m .72868 .38473 L .7267 .38657 L p F P
0 g
s
.761 .278 .089 r
.25784 .35533 m .25463 .35129 L .26059 .35382 L p F P
0 g
s
.761 .278 .089 r
.2612 .3567 m .25784 .35533 L p .26059 .35382 L F P
0 g
s
.761 .278 .089 r
.26059 .35382 m .26286 .3565 L .2612 .3567 L p F P
0 g
s
.248 .678 .962 r
.24222 .47158 m .24484 .47179 L .25164 .47392 L p F P
0 g
s
.271 .684 .969 r
.25293 .47232 m .24484 .47179 L .25164 .47392 L p F P
0 g
s
.271 .684 .969 r
.25164 .47392 m .25646 .47428 L .25293 .47232 L p F P
0 g
s
.694 .156 0 r
.20746 .31646 m .2096 .31873 L .2143 .32175 L p F P
0 g
s
.695 .157 0 r
.21319 .32256 m .21802 .32553 L .2143 .32175 L p F P
0 g
s
.695 .157 0 r
.2143 .32175 m .2096 .31873 L .21319 .32256 L p F P
0 g
s
.508 0 0 r
.08844 .40109 m .08777 .40053 L .084 .39781 L p F P
0 g
s
0 0 0 r
.57768 .32571 m .57197 .32968 L .57683 .3268 L closepath p F P
0 g
s
0 0 0 r
.57486 .32937 m .57683 .3268 L .57197 .32968 L p F P
0 g
s
0 0 0 r
.57428 .3298 m .57486 .32937 L p .57197 .32968 L F P
0 g
s
0 0 0 r
.56515 .33535 m .57428 .3298 L p .57197 .32968 L F P
0 g
s
.537 .902 .965 r
.56179 .46857 m .56309 .46883 L .55163 .47263 L p F P
0 g
s
.537 .902 .965 r
.55163 .47263 m .55072 .47245 L .56179 .46857 L p F P
0 g
s
.628 .946 .742 r
.62526 .28962 m .62334 .29047 L .63039 .28486 L closepath p F P
0 g
s
.717 .209 0 r
.05296 .37035 m .05677 .37368 L .05375 .36967 L p F P
0 g
s
.717 .209 0 r
.05375 .36967 m .04993 .36634 L .05296 .37035 L p F P
0 g
s
.137 .606 .923 r
.21032 .46275 m .21406 .46339 L .22017 .46576 L p F P
0 g
s
.167 .62 .936 r
.22087 .46444 m .21406 .46339 L .22017 .46576 L p F P
0 g
s
.167 .62 .936 r
.22017 .46576 m .22446 .46644 L .22087 .46444 L p F P
0 g
s
.351 .729 .986 r
.27425 .47844 m .28107 .47848 L .28843 .48042 L p F P
0 g
s
.37 .737 .99 r
.28107 .47848 m .27425 .47844 L .27075 .47659 L p F P
0 g
s
.729 .99 .865 r
.64891 .27214 m .64709 .2735 L .64836 .27218 L closepath p F P
0 g
s
.673 .974 .815 r
.64621 .27239 m .64836 .27218 L .64709 .2735 L p F P
0 g
s
.673 .974 .815 r
.64155 .27605 m .64621 .27239 L p .64709 .2735 L F P
0 g
s
.673 .974 .815 r
.63677 .28086 m .64155 .27605 L p .64709 .2735 L F P
0 g
s
0 0 0 r
.74953 .36424 m .74944 .36433 L .75108 .36156 L p F P
0 g
s
0 0 0 r
.75108 .36156 m .75554 .35706 L .74953 .36424 L p F P
0 g
s
.53 .915 .783 r
.67309 .42501 m .66926 .42728 L .66661 .42808 L p F P
0 g
s
.772 .361 .271 r
.29877 .37969 m .30597 .38177 L .30312 .37754 L p F P
0 g
s
.772 .361 .271 r
.29773 .37802 m .29877 .37969 L p .30312 .37754 L F P
0 g
s
.772 .361 .271 r
.30312 .37754 m .29959 .37649 L .29773 .37802 L p F P
0 g
s
.754 .36 .307 r
.31653 .38794 m .32449 .38976 L .32161 .38552 L p F P
0 g
s
.754 .36 .307 r
.31532 .386 m .31653 .38794 L p .32161 .38552 L F P
0 g
s
.754 .36 .307 r
.32161 .38552 m .31671 .38436 L .31532 .386 L p F P
0 g
s
.289 0 .12 r
.52916 .35921 m .52419 .36148 L .52895 .35965 L closepath p F P
0 g
s
.308 0 .153 r
.52739 .3631 m .52895 .35965 L .52419 .36148 L p F P
0 g
s
.308 0 .153 r
.51649 .36732 m .52739 .3631 L p .52419 .36148 L F P
0 g
s
.423 .067 .254 r
.50234 .3784 m .50336 .37563 L .49199 .37857 L p F P
0 g
s
.423 .067 .254 r
.49199 .37857 m .49077 .38181 L .50234 .3784 L p F P
0 g
s
.153 .613 .93 r
.21406 .46339 m .21032 .46275 L .20671 .46079 L p F P
0 g
s
.722 .988 .867 r
.65971 .26422 m .64891 .27214 L .64836 .27218 L p F P
0 g
s
.539 .919 .928 r
.60053 .45639 m .60338 .45661 L .59187 .46121 L p F P
0 g
s
.539 .919 .928 r
.59032 .46049 m .60053 .45639 L p .59187 .46121 L F P
0 g
s
.539 .919 .928 r
.59187 .46121 m .58912 .46102 L .59032 .46049 L p F P
0 g
s
.538 .188 .322 r
.46391 .39515 m .4652 .39121 L .45254 .39336 L p F P
0 g
s
.538 .188 .322 r
.45562 .39652 m .46391 .39515 L p .45254 .39336 L F P
0 g
s
.538 .188 .322 r
.45254 .39336 m .45169 .39577 L .45562 .39652 L p F P
0 g
s
.562 .018 0 r
.18667 .30062 m .18823 .30205 L .19249 .30525 L p F P
0 g
s
.563 .02 0 r
.19221 .3057 m .19656 .30887 L .19249 .30525 L p F P
0 g
s
.563 .02 0 r
.19249 .30525 m .18823 .30205 L .19221 .3057 L p F P
0 g
s
.545 .915 .949 r
.589 .46101 m .58912 .46102 L .57846 .46541 L p F P
0 g
s
.545 .915 .949 r
.57846 .46541 m .5775 .46528 L .589 .46101 L p F P
0 g
s
.224 .155 .565 r
.79415 .28033 m .79014 .28592 L .78855 .28119 L p F P
0 g
s
.224 .155 .565 r
.78855 .28119 m .79252 .2756 L .79415 .28033 L p F P
0 g
s
.693 .157 0 r
.2096 .31873 m .20746 .31646 L .20383 .31433 L p F P
0 g
s
.643 .116 0 r
.068 .38413 m .06708 .38311 L .06329 .38008 L p F P
0 g
s
0 .286 .704 r
.12463 .42524 m .12229 .42371 L .12171 .4234 L closepath p F P
0 g
s
.788 .358 .228 r
.28219 .37104 m .28883 .37333 L .28595 .36913 L p F P
0 g
s
.788 .358 .228 r
.28025 .36797 m .28219 .37104 L p .28595 .36913 L F P
0 g
s
.788 .358 .228 r
.28595 .36913 m .28128 .36745 L .28025 .36797 L p F P
0 g
s
0 0 .27 r
.78425 .31313 m .78581 .30736 L .78132 .31304 L p F P
0 g
s
0 0 .27 r
.78002 .31851 m .78425 .31313 L p .78132 .31304 L F P
0 g
s
0 0 .27 r
.78132 .31304 m .78008 .31769 L .78002 .31851 L p F P
0 g
s
0 .191 .619 r
.10495 .41285 m .10701 .41416 L .11153 .41715 L p F P
0 g
s
0 .244 .673 r
.11263 .41743 m .11713 .42044 L .11153 .41715 L p F P
0 g
s
0 .244 .673 r
.11153 .41715 m .10701 .41416 L .11263 .41743 L p F P
0 g
s
.646 .3 .37 r
.40049 .40109 m .39607 .40111 L .39462 .40504 L p F P
0 g
s
.663 .317 .377 r
.39114 .40497 m .39462 .40504 L .39607 .40111 L p F P
0 g
s
.663 .317 .377 r
.39607 .40111 m .38741 .40093 L .39114 .40497 L p F P
0 g
s
.477 .788 .999 r
.33503 .48589 m .34606 .48464 L .34942 .48656 L p F P
0 g
s
.512 .786 .995 r
.34606 .48464 m .33503 .48589 L .33165 .48398 L p F P
0 g
s
.781 .288 .037 r
.24555 .34411 m .24591 .34458 L .24477 .34399 L closepath p F P
0 g
s
0 0 0 r
.58496 .32031 m .57768 .32571 L .57683 .3268 L p F P
0 g
s
.508 0 0 r
.084 .39781 m .08419 .39797 L .08844 .40109 L p F P
0 g
s
.422 0 0 r
.08895 .40148 m .09318 .40461 L .08844 .40109 L p F P
0 g
s
.422 0 0 r
.08844 .40109 m .08419 .39797 L .08895 .40148 L p F P
0 g
s
.643 .301 .377 r
.41059 .40093 m .40049 .40109 L .4047 .40498 L p F P
0 g
s
.646 .3 .37 r
.39462 .40504 m .4047 .40498 L .40049 .40109 L p F P
0 g
s
.555 .582 .836 r
.77709 .23703 m .76968 .23681 L .76691 .23171 L p F P
0 g
s
.249 .678 .962 r
.24222 .47158 m .24484 .47179 L .23935 .47006 L closepath p F P
0 g
s
.693 .979 .81 r
.63677 .28086 m .63477 .28139 L .64155 .27605 L closepath p F P
0 g
s
.67 .151 0 r
.05951 .37692 m .05677 .37368 L .06066 .37697 L p F P
0 g
s
.67 .151 0 r
.06066 .37697 m .06329 .38008 L .05951 .37692 L p F P
0 g
s
.5 .892 .735 r
.68077 .42027 m .67309 .42501 L .67932 .42084 L closepath p F P
0 g
s
.53 .915 .783 r
.67815 .42116 m .67932 .42084 L .67309 .42501 L p F P
0 g
s
.53 .915 .783 r
.66661 .42808 m .67815 .42116 L p .67309 .42501 L F P
0 g
s
0 0 .005 r
.76986 .33855 m .7654 .34338 L .76926 .33688 L p F P
0 g
s
0 0 .005 r
.76926 .33688 m .77089 .33512 L .76986 .33855 L p F P
0 g
s
.737 .369 .354 r
.33583 .39569 m .34488 .39715 L .34186 .39293 L p F P
0 g
s
.737 .369 .354 r
.34186 .39293 m .33311 .39137 L .33583 .39569 L p F P
0 g
s
.622 .279 .369 r
.41526 .4007 m .41059 .40093 L .40921 .40491 L p F P
0 g
s
.643 .301 .377 r
.4047 .40498 m .40921 .40491 L .41059 .40093 L p F P
0 g
s
.668 .316 .367 r
.37939 .40454 m .39114 .40497 L .38741 .40093 L p F P
0 g
s
.668 .316 .367 r
.38741 .40093 m .38096 .40069 L .37939 .40454 L p F P
0 g
s
.05 .54 .886 r
.1933 .45695 m .19261 .45656 L .19224 .45647 L closepath p F P
0 g
s
.462 .105 .274 r
.48941 .38562 m .49077 .38181 L .47887 .38481 L p F P
0 g
s
.462 .105 .274 r
.47843 .38835 m .48941 .38562 L p .47887 .38481 L F P
0 g
s
.462 .105 .274 r
.47887 .38481 m .4775 .38846 L .47843 .38835 L p F P
0 g
s
0 .151 .628 r
.16587 .28443 m .16702 .2853 L .17091 .28866 L p F P
0 g
s
0 .152 .629 r
.17156 .28871 m .17549 .29206 L .17091 .28866 L p F P
0 g
s
0 .152 .629 r
.17091 .28866 m .16702 .2853 L .17156 .28871 L p F P
0 g
s
0 .488 .856 r
.17128 .44739 m .16733 .44617 L .1726 .44885 L p F P
0 g
s
0 .488 .856 r
.1726 .44885 m .17494 .44958 L .17128 .44739 L p F P
0 g
s
.771 .94 .936 r
.68509 .24855 m .68332 .24774 L .68814 .24461 L closepath p F P
0 g
s
0 0 0 r
.72868 .38473 m .7267 .38657 L .73446 .37955 L closepath p F P
0 g
s
.618 .666 .874 r
.76474 .22796 m .76161 .23247 L p .75226 .2295 L F P
0 g
s
.593 .648 .874 r
.76161 .23247 m .76474 .22796 L .76691 .23171 L closepath p F P
0 g
s
0 .427 .814 r
.15362 .43958 m .14941 .43799 L .15443 .44076 L p F P
0 g
s
0 .427 .814 r
.15443 .44076 m .15732 .44186 L .15362 .43958 L p F P
0 g
s
.551 .894 .982 r
.54866 .47192 m .53721 .47547 L .53421 .47461 L p F P
0 g
s
.535 .887 .981 r
.52277 .47795 m .53421 .47461 L .53721 .47547 L p F P
0 g
s
.621 .28 .372 r
.42459 .40021 m .41526 .4007 L .42021 .40437 L p F P
0 g
s
.622 .279 .369 r
.40921 .40491 m .42021 .40437 L .41526 .4007 L p F P
0 g
s
.68 .329 .372 r
.37898 .40451 m .37939 .40454 L .38096 .40069 L p F P
0 g
s
.68 .329 .372 r
.38096 .40069 m .37554 .40039 L .37898 .40451 L p F P
0 g
s
.122 .002 .43 r
.78791 .30025 m .78668 .30182 L .78678 .29653 L p F P
0 g
s
.122 .002 .43 r
.78678 .29653 m .78771 .29534 L .78791 .30025 L p F P
0 g
s
.795 .313 .072 r
.2435 .34593 m .24894 .34866 L .24591 .34458 L p F P
0 g
s
.795 .313 .072 r
.24189 .34366 m .2435 .34593 L p .24591 .34458 L F P
0 g
s
.795 .313 .072 r
.24591 .34458 m .24477 .34399 L .24189 .34366 L p F P
0 g
s
.665 .729 .897 r
.73777 .22964 m .74955 .22566 L .75226 .2295 L p F P
0 g
s
.679 .749 .904 r
.74955 .22566 m .73777 .22964 L .73508 .22646 L p F P
0 g
s
.704 .785 .915 r
.72339 .2316 m .73508 .22646 L .73777 .22964 L p F P
0 g
s
.552 .926 .924 r
.60462 .45668 m .60338 .45661 L .61467 .45186 L closepath p F P
0 g
s
.555 .931 .903 r
.62925 .44647 m .61772 .45169 L .61492 .45175 L p F P
0 g
s
.503 .908 .824 r
.64353 .44055 m .64338 .44063 L .64351 .44055 L closepath p F P
0 g
s
.527 .921 .859 r
.6408 .44082 m .64351 .44055 L .64338 .44063 L p F P
0 g
s
.527 .921 .859 r
.63094 .44567 m .6408 .44082 L p .64338 .44063 L F P
0 g
s
.527 .921 .859 r
.6295 .44646 m .63094 .44567 L p .64338 .44063 L F P
0 g
s
.682 .136 0 r
.22101 .32855 m .21802 .32553 L .22303 .32843 L p F P
0 g
s
.682 .136 0 r
.22303 .32843 m .22465 .33002 L .22101 .32855 L p F P
0 g
s
.529 .92 .829 r
.65318 .43481 m .65506 .43445 L .64353 .44055 L p F P
0 g
s
.529 .92 .829 r
.64353 .44055 m .64351 .44055 L .65318 .43481 L p F P
0 g
s
.758 .341 .258 r
.29959 .37649 m .29773 .37802 L .29588 .37547 L closepath p F P
0 g
s
.75 .909 .947 r
.70172 .23946 m .69753 .24187 L .69485 .24024 L p F P
0 g
s
.562 .936 .87 r
.65236 .43489 m .65318 .43481 L .64351 .44055 L p F P
0 g
s
.562 .936 .87 r
.64351 .44055 m .6408 .44082 L .65236 .43489 L p F P
0 g
s
.761 .987 .898 r
.66036 .26375 m .65971 .26422 L .66014 .26373 L closepath p F P
0 g
s
.722 .988 .867 r
.65766 .26356 m .66014 .26373 L .65971 .26422 L p F P
0 g
s
.722 .988 .867 r
.65301 .26714 m .65766 .26356 L p .65971 .26422 L F P
0 g
s
.722 .988 .867 r
.64836 .27218 m .65301 .26714 L p .65971 .26422 L F P
0 g
s
0 0 0 r
.58909 .31728 m .58496 .32031 L .58836 .31807 L closepath p F P
0 g
s
0 0 0 r
.58629 .32039 m .58836 .31807 L .58496 .32031 L p F P
0 g
s
0 0 0 r
.58557 .32095 m .58629 .32039 L p .58496 .32031 L F P
0 g
s
0 0 0 r
.57683 .3268 m .58557 .32095 L p .58496 .32031 L F P
0 g
s
.798 .351 .184 r
.26662 .36206 m .27282 .36451 L .26983 .36037 L p F P
0 g
s
.798 .351 .184 r
.26983 .36037 m .26381 .35786 L .26662 .36206 L p F P
0 g
s
.739 .992 .86 r
.64836 .27218 m .64621 .27239 L .65301 .26714 L closepath p F P
0 g
s
.691 .336 .367 r
.36774 .40376 m .37898 .40451 L .37554 .40039 L p F P
0 g
s
.691 .336 .367 r
.36497 .39989 m .36774 .40376 L p .37554 .40039 L F P
0 g
s
.691 .336 .367 r
.37554 .40039 m .36512 .39955 L .36497 .39989 L p F P
0 g
s
.766 .988 .896 r
.66914 .25496 m .67182 .25559 L .66036 .26375 L p F P
0 g
s
.766 .988 .896 r
.66501 .25805 m .66914 .25496 L p .66036 .26375 L F P
0 g
s
.766 .988 .896 r
.66036 .26375 m .66014 .26373 L .66501 .25805 L p F P
0 g
s
.745 .349 .3 r
.31671 .38436 m .31532 .386 L .31368 .38368 L closepath p F P
0 g
s
.062 .544 .893 r
.18897 .45444 m .18672 .45388 L .19224 .45647 L p F P
0 g
s
.062 .544 .893 r
.19224 .45647 m .19261 .45656 L .18897 .45444 L p F P
0 g
s
.506 .795 .997 r
.36214 .486 m .36383 .487 L p .34942 .48656 L F P
0 g
s
.506 .795 .997 r
.34942 .48656 m .35709 .48549 L .36214 .486 L p F P
0 g
s
.533 .797 .994 r
.35709 .48549 m .34942 .48656 L .34606 .48464 L p F P
0 g
s
.347 .731 .986 r
.28864 .48047 m .28854 .48042 L .28843 .48042 L closepath p F P
0 g
s
.556 .901 .976 r
.56014 .46815 m .56179 .46857 L .55072 .47245 L p F P
0 g
s
.556 .901 .976 r
.55072 .47245 m .54866 .47192 L .56014 .46815 L p F P
0 g
s
.243 0 .098 r
.53955 .35507 m .54058 .35298 L .52916 .35921 L p F P
0 g
s
.243 0 .098 r
.52916 .35921 m .52895 .35965 L .53955 .35507 L p F P
0 g
s
.36 .73 .988 r
.28507 .47844 m .28107 .47848 L .28843 .48042 L p F P
0 g
s
.36 .73 .988 r
.28843 .48042 m .28854 .48042 L .28507 .47844 L p F P
0 g
s
.618 .666 .874 r
.75226 .2295 m .76416 .22698 L .76474 .22796 L p F P
0 g
s
.634 .687 .883 r
.76416 .22698 m .75226 .2295 L .74955 .22566 L p F P
0 g
s
.432 .758 .995 r
.29944 .47991 m .28854 .48042 L .28507 .47844 L p F P
0 g
s
.596 .255 .362 r
.43272 .39947 m .42459 .40021 L .42326 .40421 L p F P
0 g
s
.621 .28 .372 r
.42021 .40437 m .42326 .40421 L .42459 .40021 L p F P
0 g
s
0 .361 .766 r
.13604 .43089 m .13274 .42939 L .13753 .43227 L p F P
0 g
s
0 .361 .766 r
.13753 .43227 m .13976 .43327 L .13604 .43089 L p F P
0 g
s
.55 .877 .991 r
.51974 .47691 m .52088 .47733 L .50906 .48034 L p F P
0 g
s
.55 .877 .991 r
.50906 .48034 m .50833 .48008 L .51974 .47691 L p F P
0 g
s
.643 .116 0 r
.06329 .38008 m .06402 .38088 L .068 .38413 L p F P
0 g
s
.565 .033 0 r
.0679 .38464 m .07188 .38789 L .068 .38413 L p F P
0 g
s
.565 .033 0 r
.068 .38413 m .06402 .38088 L .0679 .38464 L p F P
0 g
s
.552 0 0 r
.2002 .31203 m .19656 .30887 L .20106 .31198 L p F P
0 g
s
.552 0 0 r
.20106 .31198 m .20383 .31433 L .2002 .31203 L p F P
0 g
s
.131 .587 .923 r
.20213 .45853 m .19261 .45656 L .18897 .45444 L p F P
0 g
s
.752 .244 0 r
.24477 .34399 m .24189 .34366 L .24033 .3419 L closepath p F P
0 g
s
.728 .834 .931 r
.72339 .2316 m .72308 .23176 L .72325 .23146 L closepath p F P
0 g
s
.726 .862 .946 r
.72071 .22904 m .72325 .23146 L .72308 .23176 L p F P
0 g
s
.726 .862 .946 r
.70909 .23521 m .72071 .22904 L p .72308 .23176 L F P
0 g
s
0 0 0 r
.5969 .31126 m .58909 .31728 L .58836 .31807 L p F P
0 g
s
.772 .963 .928 r
.6723 .25574 m .67182 .25559 L .67319 .25466 L closepath p F P
0 g
s
.717 .831 .935 r
.7324 .22347 m .73508 .22646 L .72339 .2316 L p F P
0 g
s
.717 .831 .935 r
.72721 .22594 m .7324 .22347 L p .72339 .2316 L F P
0 g
s
.717 .831 .935 r
.72339 .2316 m .72325 .23146 L .72721 .22594 L p F P
0 g
s
.766 .989 .894 r
.66014 .26373 m .65766 .26356 L .66501 .25805 L closepath p F P
0 g
s
.553 .015 0 r
.18823 .30205 m .18667 .30062 L .18305 .29782 L p F P
0 g
s
0 .198 .633 r
.10701 .41416 m .10495 .41285 L .10119 .41025 L p F P
0 g
s
.145 0 .01 r
.54123 .35179 m .54058 .35298 L .54678 .34905 L closepath p F P
0 g
s
.55 .885 .987 r
.53246 .47403 m .53421 .47461 L .52277 .47795 L p F P
0 g
s
.55 .885 .987 r
.52277 .47795 m .52088 .47733 L .53246 .47403 L p F P
0 g
s
.522 .903 .74 r
.68948 .41468 m .68077 .42027 L .67932 .42084 L p F P
0 g
s
.054 0 0 r
.55329 .34368 m .552 .34582 L .56176 .33903 L closepath p F P
0 g
s
.718 .833 .936 r
.72325 .23146 m .72071 .22904 L .72721 .22594 L closepath p F P
0 g
s
.75 .909 .947 r
.69485 .24024 m .70537 .2338 L .70172 .23946 L p F P
0 g
s
.767 .902 .935 r
.70172 .23946 m .70909 .23521 L .70642 .23316 L p F P
0 g
s
.767 .902 .935 r
.70642 .23316 m .70537 .2338 L .70172 .23946 L p F P
0 g
s
.56 .917 .958 r
.589 .46101 m .5775 .46528 L .57459 .46479 L p F P
0 g
s
.541 .909 .957 r
.56309 .46883 m .57459 .46479 L .5775 .46528 L p F P
0 g
s
.25 0 .119 r
.53794 .35845 m .53955 .35507 L .52895 .35965 L p F P
0 g
s
.25 0 .119 r
.52895 .35965 m .52739 .3631 L .53794 .35845 L p F P
0 g
s
.528 .801 .996 r
.3779 .48701 m .37825 .48722 L p .36383 .487 L F P
0 g
s
.528 .801 .996 r
.36383 .487 m .36796 .48633 L .3779 .48701 L p F P
0 g
s
.524 .803 .997 r
.36383 .487 m .36796 .48633 L .36214 .486 L closepath p F P
0 g
s
.745 .349 .3 r
.30872 .38606 m .30597 .38177 L .31368 .38368 L p F P
0 g
s
.745 .349 .3 r
.31418 .38734 m .30872 .38606 L p .31368 .38368 L F P
0 g
s
.745 .349 .3 r
.31368 .38368 m .31532 .386 L .31418 .38734 L p F P
0 g
s
0 .155 .597 r
.09742 .40755 m .09318 .40461 L .09749 .40769 L p F P
0 g
s
0 .155 .597 r
.09749 .40769 m .10119 .41025 L .09742 .40755 L p F P
0 g
s
.307 .702 .978 r
.24939 .47029 m .25293 .47232 L .24484 .47179 L p F P
0 g
s
.307 .702 .978 r
.23867 .46968 m .24939 .47029 L p .24484 .47179 L F P
0 g
s
.307 .702 .978 r
.24484 .47179 m .23935 .47006 L .23867 .46968 L p F P
0 g
s
0 .175 .639 r
.17943 .29487 m .17549 .29206 L .17955 .29536 L p F P
0 g
s
0 .175 .639 r
.17955 .29536 m .18305 .29782 L .17943 .29487 L p F P
0 g
s
.083 0 .419 r
.7908 .29623 m .78791 .30025 L .78771 .29534 L p F P
0 g
s
.083 0 .419 r
.78771 .29534 m .79087 .29094 L .7908 .29623 L p F P
0 g
s
.698 .343 .371 r
.36512 .39955 m .36497 .39989 L .3647 .39951 L closepath p F P
0 g
s
.76 .341 .254 r
.29165 .37757 m .28883 .37333 L .29588 .37547 L p F P
0 g
s
.76 .341 .254 r
.29653 .37898 m .29165 .37757 L p .29588 .37547 L F P
0 g
s
.76 .341 .254 r
.29588 .37547 m .29773 .37802 L .29653 .37898 L p F P
0 g
s
.695 .343 .375 r
.35732 .40274 m .35443 .39845 L .3647 .39951 L p F P
0 g
s
.695 .343 .375 r
.3635 .40337 m .35732 .40274 L p .3647 .39951 L F P
0 g
s
.695 .343 .375 r
.3647 .39951 m .36497 .39989 L .3635 .40337 L p F P
0 g
s
.768 .327 .203 r
.28128 .36745 m .28025 .36797 L .27938 .36682 L closepath p F P
0 g
s
.737 .352 .322 r
.33301 .39122 m .33311 .39137 L .33294 .39133 L closepath p F P
0 g
s
0 0 0 r
.76633 .34419 m .76096 .35007 L .7654 .34338 L p F P
0 g
s
0 0 0 r
.76948 .3395 m .76633 .34419 L p .7654 .34338 L F P
0 g
s
0 0 0 r
.7654 .34338 m .76986 .33855 L .76948 .3395 L p F P
0 g
s
.283 .235 .625 r
.79347 .27424 m .79252 .2756 L .78986 .27122 L p F P
0 g
s
.283 .235 .625 r
.78986 .27122 m .79218 .26791 L .79347 .27424 L p F P
0 g
s
0 0 0 r
.56515 .33535 m .56343 .3379 L .57428 .3298 L closepath p F P
0 g
s
.597 .256 .363 r
.43811 .39898 m .43715 .40193 L .43272 .39947 L closepath p F P
0 g
s
.596 .255 .362 r
.43683 .40301 m .43715 .40193 L .43272 .39947 L p F P
0 g
s
.596 .255 .362 r
.42326 .40421 m .43683 .40301 L p .43272 .39947 L F P
0 g
s
0 0 0 r
.6005 .30851 m .5969 .31126 L .59977 .30918 L closepath p F P
0 g
s
0 0 0 r
.59773 .31108 m .59977 .30918 L .5969 .31126 L p F P
0 g
s
0 0 0 r
.5962 .31231 m .59773 .31108 L p .5969 .31126 L F P
0 g
s
0 0 0 r
.58836 .31807 m .5962 .31231 L p .5969 .31126 L F P
0 g
s
.018 0 .281 r
.78008 .31769 m .77977 .3188 L .78002 .31851 L closepath p F P
0 g
s
.789 .314 .103 r
.25198 .35276 m .25784 .35533 L .25463 .35129 L p F P
0 g
s
.789 .314 .103 r
.25463 .35129 m .24894 .34866 L .25198 .35276 L p F P
0 g
s
.308 0 .161 r
.5262 .36581 m .52739 .3631 L .51649 .36732 L p F P
0 g
s
.308 0 .161 r
.51881 .36935 m .5262 .36581 L p .51649 .36732 L F P
0 g
s
.308 0 .161 r
.51649 .36732 m .51496 .37085 L .51881 .36935 L p F P
0 g
s
.742 .369 .346 r
.33083 .39472 m .33583 .39569 L .33311 .39137 L p F P
0 g
s
.742 .369 .346 r
.33311 .39137 m .33294 .39133 L .33083 .39472 L p F P
0 g
s
0 .293 .716 r
.11855 .42119 m .11713 .42044 L .12171 .4234 L p F P
0 g
s
0 .293 .716 r
.12171 .4234 m .12229 .42371 L .11855 .42119 L p F P
0 g
s
.738 .365 .344 r
.32726 .39406 m .33083 .39472 L .33294 .39133 L p F P
0 g
s
.738 .365 .344 r
.33294 .39133 m .32449 .38976 L .32726 .39406 L p F P
0 g
s
.769 .26 0 r
.22973 .33632 m .23492 .33915 L .23157 .3352 L p F P
0 g
s
.769 .26 0 r
.23157 .3352 m .22652 .33232 L .22973 .33632 L p F P
0 g
s
.765 .254 0 r
.22465 .33002 m .22652 .33232 L .23157 .3352 L p F P
0 g
s
.326 .712 .982 r
.26826 .47522 m .27075 .47659 L p .25646 .47428 L F P
0 g
s
.326 .712 .982 r
.25646 .47428 m .26625 .4746 L .26826 .47522 L p F P
0 g
s
.35 .718 .986 r
.26625 .4746 m .25646 .47428 L .25293 .47232 L p F P
0 g
s
0 0 0 r
.77077 .3375 m .76986 .33855 L .77089 .33512 L p F P
0 g
s
0 0 0 r
.77089 .33512 m .77437 .33107 L .77077 .3375 L p F P
0 g
s
.153 .613 .93 r
.20671 .46079 m .20799 .461 L .21406 .46339 L p F P
0 g
s
.183 .626 .942 r
.21728 .46237 m .20799 .461 L .21406 .46339 L p F P
0 g
s
.183 .626 .942 r
.21406 .46339 m .22087 .46444 L .21728 .46237 L p F P
0 g
s
.537 .815 .997 r
.40528 .48738 m .39304 .48743 L .39268 .48722 L p F P
0 g
s
.524 .81 .998 r
.39304 .48743 m .39268 .48722 L .39165 .48739 L closepath p F P
0 g
s
.51 .168 .322 r
.47623 .39259 m .47746 .38859 L .4652 .39121 L p F P
0 g
s
.51 .168 .322 r
.4652 .39121 m .46391 .39515 L .47623 .39259 L p F P
0 g
s
.796 .335 .143 r
.26286 .3565 m .26381 .35786 L .2612 .3567 L closepath p F P
0 g
s
.542 .807 .995 r
.37825 .48722 m .37921 .48705 L .39165 .48739 L p F P
0 g
s
.542 .807 .995 r
.37825 .48722 m .37921 .48705 L .3779 .48701 L closepath p F P
0 g
s
.539 .799 .993 r
.3894 .48512 m .37921 .48705 L .39165 .48739 L p F P
0 g
s
.539 .799 .993 r
.39165 .48739 m .39268 .48722 L .3894 .48512 L p F P
0 g
s
.041 .529 .883 r
.17494 .44958 m .18128 .45126 L .18672 .45388 L p F P
0 g
s
.055 .535 .891 r
.18128 .45126 m .17494 .44958 L .17128 .44739 L p F P
0 g
s
.535 .816 .998 r
.40768 .48736 m .40712 .48704 L .40528 .48738 L closepath p F P
0 g
s
.537 .815 .997 r
.40387 .48496 m .40712 .48704 L .40528 .48738 L p F P
0 g
s
.537 .815 .997 r
.39268 .48722 m .40387 .48496 L p .40528 .48738 L F P
0 g
s
.7 .348 .377 r
.36497 .39989 m .36774 .40376 L .3635 .40337 L closepath p F P
0 g
s
.226 .655 .956 r
.22446 .46644 m .23189 .46729 L .23812 .46962 L p F P
0 g
s
.243 .662 .961 r
.23189 .46729 m .22446 .46644 L .22087 .46444 L p F P
0 g
s
.569 .872 .995 r
.51974 .47691 m .50833 .48008 L .50526 .4788 L p F P
0 g
s
.555 .867 .995 r
.49387 .4818 m .50526 .4788 L .50833 .48008 L p F P
0 g
s
.762 .972 .923 r
.67319 .25466 m .67182 .25559 L .66914 .25496 L p F P
0 g
s
.545 .82 .997 r
.42027 .48695 m .40768 .48736 L .40712 .48704 L p F P
0 g
s
0 0 0 r
.60827 .3024 m .6005 .30851 L .59977 .30918 L p F P
0 g
s
.529 0 0 r
.07599 .39159 m .08005 .3948 L .07594 .3911 L p F P
0 g
s
.529 0 0 r
.07594 .3911 m .07188 .38789 L .07599 .39159 L p F P
0 g
s
.445 .769 .997 r
.30288 .48189 m .31383 .48108 L .31725 .48307 L p F P
0 g
s
.47 .768 .996 r
.31383 .48108 m .30288 .48189 L .29944 .47991 L p F P
0 g
s
0 .339 .802 r
.15864 .2777 m .15428 .27528 L .15795 .27875 L p F P
0 g
s
0 .339 .802 r
.15795 .27875 m .16225 .28113 L .15864 .2777 L p F P
0 g
s
.782 .972 .916 r
.67319 .25466 m .68332 .24774 L .68064 .24667 L p F P
0 g
s
.782 .972 .916 r
.68064 .24667 m .67784 .24869 L .67319 .25466 L p F P
0 g
s
.762 .972 .923 r
.66914 .25496 m .67784 .24869 L .67319 .25466 L p F P
0 g
s
0 0 .178 r
.77942 .32244 m .77738 .32483 L .77977 .3188 L p F P
0 g
s
0 0 .178 r
.77977 .3188 m .78002 .31851 L .77942 .32244 L p F P
0 g
s
.578 .238 .357 r
.45 .40137 m .4512 .39728 L .43811 .39898 L p F P
0 g
s
.578 .238 .357 r
.43901 .40273 m .45 .40137 L p .43811 .39898 L F P
0 g
s
.578 .238 .357 r
.43811 .39898 m .43715 .40193 L .43901 .40273 L p F P
0 g
s
0 0 0 r
.57683 .3268 m .57486 .32937 L .58557 .32095 L closepath p F P
0 g
s
.693 .157 0 r
.20383 .31433 m .20505 .31565 L .2096 .31873 L p F P
0 g
s
.7 .166 0 r
.20854 .31951 m .21319 .32256 L .2096 .31873 L p F P
0 g
s
.7 .166 0 r
.2096 .31873 m .20505 .31565 L .20854 .31951 L p F P
0 g
s
.77 .326 .196 r
.2758 .36867 m .27282 .36451 L .27938 .36682 L p F P
0 g
s
.77 .326 .196 r
.27749 .36925 m .2758 .36867 L p .27938 .36682 L F P
0 g
s
.77 .326 .196 r
.27938 .36682 m .28025 .36797 L .27749 .36925 L p F P
0 g
s
0 .34 .756 r
.12802 .42648 m .12229 .42371 L .11855 .42119 L p F P
0 g
s
0 0 0 r
.73924 .37478 m .73809 .37606 L .74241 .37176 L closepath p F P
0 g
s
.554 .805 .992 r
.38612 .48282 m .3894 .48512 L .37921 .48705 L p F P
0 g
s
.554 .805 .992 r
.37494 .48514 m .38612 .48282 L p .37921 .48705 L F P
0 g
s
.554 .805 .992 r
.37921 .48705 m .3779 .48701 L .37494 .48514 L p F P
0 g
s
.539 .198 .338 r
.45169 .39577 m .45562 .39652 L .4512 .39728 L closepath p F P
0 g
s
.768 .258 0 r
.22652 .33232 m .22465 .33002 L .22101 .32855 L p F P
0 g
s
.586 .801 .982 r
.40387 .48496 m .39268 .48722 L .3894 .48512 L p F P
0 g
s
.539 .8 .993 r
.3779 .48701 m .37494 .48514 L .36796 .48633 L closepath p F P
0 g
s
0 .158 .642 r
.16702 .2853 m .16587 .28443 L .16225 .28113 L p F P
0 g
s
.369 .005 .209 r
.51476 .37134 m .51496 .37085 L .50374 .37468 L p F P
0 g
s
.369 .005 .209 r
.50374 .37468 m .50336 .37563 L .51476 .37134 L p F P
0 g
s
.542 .823 .998 r
.42191 .48688 m .42157 .48669 L .42027 .48695 L closepath p F P
0 g
s
.545 .82 .997 r
.41835 .48465 m .42157 .48669 L .42027 .48695 L p F P
0 g
s
.545 .82 .997 r
.40712 .48704 m .41835 .48465 L p .42027 .48695 L F P
0 g
s
0 0 .163 r
.78204 .31912 m .77942 .32244 L .78002 .31851 L p F P
0 g
s
0 0 .163 r
.78002 .31851 m .78425 .31313 L .78204 .31912 L p F P
0 g
s
.569 .862 .996 r
.50526 .4788 m .49387 .4818 L .49078 .4804 L p F P
0 g
s
.554 .859 .997 r
.47941 .48325 m .49078 .4804 L .49387 .4818 L p F P
0 g
s
.562 .83 .996 r
.43283 .4842 m .43572 .48599 L .42191 .48688 L p F P
0 g
s
.562 .83 .996 r
.42191 .48688 m .42157 .48669 L .43283 .4842 L p F P
0 g
s
.489 .875 .686 r
.69228 .4128 m .68948 .41468 L .69171 .41309 L closepath p F P
0 g
s
.522 .903 .74 r
.6897 .41383 m .69171 .41309 L .68948 .41468 L p F P
0 g
s
.522 .903 .74 r
.68379 .41766 m .6897 .41383 L p .68948 .41468 L F P
0 g
s
.522 .903 .74 r
.67932 .42084 m .68379 .41766 L p .68948 .41468 L F P
0 g
s
.47 .839 .593 r
.61192 .29954 m .60827 .3024 L .61108 .30015 L closepath p F P
0 g
s
0 0 0 r
.60916 .30157 m .61108 .30015 L .60827 .3024 L p F P
0 g
s
0 0 0 r
.60649 .30378 m .60916 .30157 L p .60827 .3024 L F P
0 g
s
0 0 0 r
.60827 .3024 m .6027 .30684 L .60649 .30378 L F
.6064 .30397 m .60816 .30243 L p .60649 .30378 L F P
0 g
s
0 0 0 r
.60816 .30243 m .60853 .30211 L .60649 .30378 L p F P
0 g
s
0 0 0 r
.59977 .30918 m .60649 .30378 L p .6027 .30684 L F P
0 g
s
.555 .582 .836 r
.77972 .23287 m .77709 .23703 L p .76691 .23171 L F P
0 g
s
.555 .582 .836 r
.76691 .23171 m .77901 .23139 L .77972 .23287 L p F P
0 g
s
.543 .623 .882 r
.76474 .22796 m .76691 .23171 L .77901 .23139 L p F P
0 g
s
0 .475 .852 r
.16214 .44345 m .15732 .44186 L .15362 .43958 L p F P
0 g
s
0 .468 .843 r
.15732 .44186 m .16214 .44345 L .16733 .44617 L p F P
0 g
s
0 .403 .797 r
.13976 .43327 m .14446 .43517 L .14941 .43799 L p F P
0 g
s
0 .409 .806 r
.14446 .43517 m .13976 .43327 L .13604 .43089 L p F P
0 g
s
0 0 0 r
.76068 .35036 m .76057 .35058 L .76096 .35007 L closepath p F P
0 g
s
.591 .805 .981 r
.41835 .48465 m .40712 .48704 L .40387 .48496 L p F P
0 g
s
.75 .852 .926 r
.72071 .22904 m .70909 .23521 L .70642 .23316 L p F P
0 g
s
.562 .928 .932 r
.61467 .45186 m .60338 .45661 L .60053 .45639 L p F P
0 g
s
.719 .359 .366 r
.34768 .40147 m .35732 .40274 L .35443 .39845 L p F P
0 g
s
.719 .359 .366 r
.34709 .40051 m .34768 .40147 L p .35443 .39845 L F P
0 g
s
.719 .359 .366 r
.35443 .39845 m .34851 .39765 L .34709 .40051 L p F P
0 g
s
.483 .845 .597 r
.61936 .29362 m .61192 .29954 L .61108 .30015 L p F P
0 g
s
.571 .853 .996 r
.49078 .4804 m .47941 .48325 L .47629 .48174 L p F P
0 g
s
.555 .85 .998 r
.46495 .48445 m .47629 .48174 L .47941 .48325 L p F P
0 g
s
.553 .91 .965 r
.57266 .4644 m .57459 .46479 L .56309 .46883 L p F P
0 g
s
.553 .91 .965 r
.56309 .46883 m .56179 .46857 L .57266 .4644 L p F P
0 g
s
.56 .934 .894 r
.6295 .44646 m .62925 .44647 L .63094 .44567 L closepath p F P
0 g
s
.548 .929 .831 r
.66601 .42842 m .65506 .43445 L .65318 .43481 L p F P
0 g
s
.553 .015 0 r
.18305 .29782 m .18409 .29879 L .18823 .30205 L p F P
0 g
s
.559 .021 0 r
.18801 .30246 m .19221 .3057 L .18823 .30205 L p F P
0 g
s
.559 .021 0 r
.18823 .30205 m .18409 .29879 L .18801 .30246 L p F P
0 g
s
.512 .887 .692 r
.70333 .40511 m .69228 .4128 L .69171 .41309 L p F P
0 g
s
0 0 0 r
.58836 .31807 m .58629 .32039 L .5962 .31231 L closepath p F P
0 g
s
.381 .735 .991 r
.2816 .47639 m .27361 .47656 L .28107 .47848 L p F P
0 g
s
.381 .735 .991 r
.28107 .47848 m .28507 .47844 L .2816 .47639 L p F P
0 g
s
.37 .737 .99 r
.27075 .47659 m .27361 .47656 L .28107 .47848 L p F P
0 g
s
.593 .81 .983 r
.43283 .4842 m .42157 .48669 L .41835 .48465 L p F P
0 g
s
.157 .068 .496 r
.79489 .28536 m .79087 .29094 L .79014 .28592 L p F P
0 g
s
.157 .068 .496 r
.79488 .28531 m .79489 .28536 L p .79014 .28592 L F P
0 g
s
.157 .068 .496 r
.79014 .28592 m .79415 .28033 L .79488 .28531 L p F P
0 g
s
0 0 0 r
.76123 .3511 m .76633 .34419 L .76096 .35007 L p F P
0 g
s
0 0 0 r
.75921 .3533 m .76123 .3511 L p .76096 .35007 L F P
0 g
s
0 0 0 r
.76096 .35007 m .76057 .35058 L .75921 .3533 L p F P
0 g
s
.494 0 0 r
.084 .39781 m .08419 .39797 L .08207 .39636 L closepath p F P
0 g
s
.568 .845 .997 r
.475 .48101 m .47629 .48174 L .46495 .48445 L p F P
0 g
s
.568 .845 .997 r
.46495 .48445 m .46226 .48305 L .475 .48101 L p F P
0 g
s
.554 .843 .998 r
.46226 .48305 m .46495 .48445 L p .45049 .48542 L F P
0 g
s
.189 0 .064 r
.54678 .34905 m .54058 .35298 L .53955 .35507 L p F P
0 g
s
0 .257 .69 r
.10822 .41439 m .11263 .41743 L .10701 .41416 L p F P
0 g
s
0 .257 .69 r
.10701 .41416 m .10257 .41113 L .10822 .41439 L p F P
0 g
s
0 .198 .633 r
.10119 .41025 m .10257 .41113 L .10701 .41416 L p F P
0 g
s
0 0 0 r
.76057 .35058 m .75554 .35706 L .75921 .3533 L closepath p F P
0 g
s
.559 .833 .997 r
.44911 .48465 m .45049 .48542 L p .43603 .48616 L F P
0 g
s
.559 .833 .997 r
.43603 .48616 m .43752 .48583 L .44911 .48465 L p F P
0 g
s
.567 .826 .994 r
.43603 .48616 m .43752 .48583 L .43572 .48599 L closepath p F P
0 g
s
.539 .802 .994 r
.37163 .48285 m .37494 .48514 L .36796 .48633 L p F P
0 g
s
.539 .802 .994 r
.36049 .48499 m .37163 .48285 L p .36796 .48633 L F P
0 g
s
.539 .802 .994 r
.36796 .48633 m .36214 .486 L .36049 .48499 L p F P
0 g
s
.047 0 .347 r
.78782 .3048 m .78581 .30736 L .78668 .30182 L p F P
0 g
s
.047 0 .347 r
.78668 .30182 m .78791 .30025 L .78782 .3048 L p F P
0 g
s
.554 .843 .998 r
.45049 .48542 m .45871 .48353 L .46226 .48305 L p F P
0 g
s
.566 .834 .996 r
.45049 .48542 m .45871 .48353 L .44911 .48465 L closepath p F P
0 g
s
.75 .238 0 r
.23822 .34302 m .23492 .33915 L .24033 .3419 L p F P
0 g
s
.75 .238 0 r
.24033 .3419 m .24189 .34366 L .23822 .34302 L p F P
0 g
s
.478 .778 .997 r
.32871 .48222 m .33165 .48398 L p .31725 .48307 L F P
0 g
s
.478 .778 .997 r
.31725 .48307 m .32754 .48202 L .32871 .48222 L p F P
0 g
s
.509 .779 .993 r
.32754 .48202 m .31725 .48307 L .31383 .48108 L p F P
0 g
s
0 .493 .864 r
.1676 .44513 m .16214 .44345 L .16733 .44617 L p F P
0 g
s
0 .493 .864 r
.16733 .44617 m .17128 .44739 L .1676 .44513 L p F P
0 g
s
.349 .324 .69 r
.78993 .26163 m .7904 .26094 L .79081 .26246 L closepath p F P
0 g
s
.805 .356 .173 r
.26072 .3595 m .26662 .36206 L .26381 .35786 L p F P
0 g
s
.805 .356 .173 r
.25917 .35706 m .26072 .3595 L p .26381 .35786 L F P
0 g
s
.805 .356 .173 r
.26381 .35786 m .2612 .3567 L .25917 .35706 L p F P
0 g
s
0 .172 .625 r
.0848 .39831 m .08895 .40148 L .08419 .39797 L p F P
0 g
s
0 .172 .625 r
.08022 .39494 m .0848 .39831 L p .08419 .39797 L F P
0 g
s
.454 0 0 r
.08207 .39636 m .08022 .39494 L .08005 .3948 L closepath p F P
0 g
s
0 .172 .625 r
.08419 .39797 m .08207 .39636 L .08022 .39494 L p F P
0 g
s
.579 .916 .696 r
.62334 .29047 m .61936 .29362 L .62232 .29101 L closepath p F P
0 g
s
.483 .845 .597 r
.6206 .29196 m .62232 .29101 L .61936 .29362 L p F P
0 g
s
.483 .845 .597 r
.61661 .2953 m .6206 .29196 L p .61936 .29362 L F P
0 g
s
.483 .845 .597 r
.61108 .30015 m .61661 .2953 L p .61936 .29362 L F P
0 g
s
.573 .939 .905 r
.63094 .44567 m .62925 .44647 L .62647 .44648 L p F P
0 g
s
.555 .931 .903 r
.61492 .45175 m .62647 .44648 L .62925 .44647 L p F P
0 g
s
0 .432 .822 r
.14992 .43723 m .14446 .43517 L .14941 .43799 L p F P
0 g
s
0 .432 .822 r
.14941 .43799 m .15362 .43958 L .14992 .43723 L p F P
0 g
s
.235 .662 .959 r
.23935 .47006 m .23867 .46968 L .23812 .46962 L closepath p F P
0 g
s
.431 .081 .268 r
.50101 .38222 m .50234 .3784 L .49077 .38181 L p F P
0 g
s
.431 .081 .268 r
.49077 .38181 m .48941 .38562 L .50101 .38222 L p F P
0 g
s
.796 .367 .229 r
.28025 .36797 m .28219 .37104 L .27749 .36925 L closepath p F P
0 g
s
.778 .385 .31 r
.30128 .38404 m .30872 .38606 L .30597 .38177 L p F P
0 g
s
.778 .385 .31 r
.30597 .38177 m .29877 .37969 L .30128 .38404 L p F P
0 g
s
.632 .108 0 r
.06402 .38088 m .06329 .38008 L .05951 .37692 L p F P
0 g
s
.759 .385 .346 r
.31902 .39232 m .32726 .39406 L .32449 .38976 L p F P
0 g
s
.759 .385 .346 r
.32449 .38976 m .31653 .38794 L .31902 .39232 L p F P
0 g
s
.767 .949 .936 r
.68814 .24461 m .68332 .24774 L .68064 .24667 L p F P
0 g
s
.519 .795 .996 r
.36214 .486 m .36049 .48499 L .35709 .48549 L closepath p F P
0 g
s
.661 .144 0 r
.05573 .37364 m .05296 .37035 L .05677 .37368 L p F P
0 g
s
.661 .144 0 r
.05677 .37368 m .05951 .37692 L .05573 .37364 L p F P
0 g
s
.684 .14 0 r
.21686 .32638 m .21319 .32256 L .21802 .32553 L p F P
0 g
s
.684 .14 0 r
.21881 .32754 m .21686 .32638 L p .21802 .32553 L F P
0 g
s
.684 .14 0 r
.21802 .32553 m .22101 .32855 L .21881 .32754 L p F P
0 g
s
.577 .823 .991 r
.43752 .48583 m .43572 .48599 L .43283 .4842 L p F P
0 g
s
.075 .549 .9 r
.18533 .45225 m .18128 .45126 L .18672 .45388 L p F P
0 g
s
.075 .549 .9 r
.18672 .45388 m .18897 .45444 L .18533 .45225 L p F P
0 g
s
.368 .737 .989 r
.27075 .47659 m .27361 .47656 L .26826 .47522 L closepath p F P
0 g
s
.582 .918 .697 r
.63039 .28486 m .62334 .29047 L .62232 .29101 L p F P
0 g
s
.72 .36 .366 r
.34851 .39765 m .34709 .40051 L .34488 .39715 L closepath p F P
0 g
s
.763 .372 .314 r
.31532 .386 m .31653 .38794 L .31418 .38734 L closepath p F P
0 g
s
0 .158 .642 r
.16225 .28113 m .16324 .28188 L .16702 .2853 L p F P
0 g
s
0 .158 .642 r
.16776 .28529 m .17156 .28871 L .16702 .2853 L p F P
0 g
s
0 .158 .642 r
.16702 .2853 m .16324 .28188 L .16776 .28529 L p F P
0 g
s
.387 .034 .24 r
.51359 .37458 m .51476 .37134 L .50336 .37563 L p F P
0 g
s
.387 .034 .24 r
.50336 .37563 m .50234 .3784 L .51359 .37458 L p F P
0 g
s
.577 .823 .991 r
.44413 .48147 m .44731 .48359 L .43752 .48583 L p F P
0 g
s
.577 .823 .991 r
.43283 .4842 m .44413 .48147 L p .43752 .48583 L F P
0 g
s
.572 .829 .994 r
.44911 .48465 m .44731 .48359 L .43752 .48583 L closepath p F P
0 g
s
.16 .615 .934 r
.20671 .46079 m .20799 .461 L .20476 .45969 L closepath p F P
0 g
s
.402 .412 .755 r
.78768 .25227 m .78828 .25259 L .78797 .2531 L closepath p F P
0 g
s
.364 .364 .725 r
.79324 .2562 m .7904 .26094 L .78797 .2531 L p F P
0 g
s
.364 .364 .725 r
.78797 .2531 m .78828 .25259 L .79324 .2562 L p F P
0 g
s
.546 .93 .872 r
.6408 .44082 m .63094 .44567 L .63934 .44095 L closepath p F P
0 g
s
.573 .939 .905 r
.63805 .44095 m .63934 .44095 L .63094 .44567 L p F P
0 g
s
.573 .939 .905 r
.62647 .44648 m .63805 .44095 L p .63094 .44567 L F P
0 g
s
.513 .546 .827 r
.77709 .23703 m .77972 .23287 L .78184 .2375 L closepath p F P
0 g
s
.419 .437 .772 r
.78828 .25259 m .78768 .25227 L .78472 .24427 L p F P
0 g
s
0 0 0 r
.59977 .30918 m .59773 .31108 L .60649 .30378 L closepath p F P
0 g
s
.791 .378 .266 r
.2848 .37535 m .29165 .37757 L .28883 .37333 L p F P
0 g
s
.791 .378 .266 r
.28883 .37333 m .28219 .37104 L .2848 .37535 L p F P
0 g
s
.246 .663 .962 r
.2351 .46761 m .23189 .46729 L .23812 .46962 L p F P
0 g
s
.246 .663 .962 r
.23812 .46962 m .23867 .46968 L .2351 .46761 L p F P
0 g
s
.276 .276 .679 r
.79694 .26025 m .79324 .2562 L .7904 .26094 L p F P
0 g
s
.276 .276 .679 r
.79357 .26569 m .79694 .26025 L p .7904 .26094 L F P
0 g
s
.276 .276 .679 r
.7904 .26094 m .79081 .26246 L .79357 .26569 L p F P
0 g
s
.69 .157 0 r
.20505 .31565 m .20383 .31433 L .2002 .31203 L p F P
0 g
s
0 .366 .776 r
.13232 .42842 m .12802 .42648 L .13274 .42939 L p F P
0 g
s
0 .366 .776 r
.13274 .42939 m .13604 .43089 L .13232 .42842 L p F P
0 g
s
.548 .218 .36 r
.45562 .39652 m .4512 .39728 L .45 .40137 L p F P
0 g
s
.533 .797 .994 r
.34606 .48464 m .34651 .48457 L .35709 .48549 L p F P
0 g
s
.531 .785 .991 r
.35716 .48274 m .34651 .48457 L .35709 .48549 L p F P
0 g
s
.531 .785 .991 r
.35709 .48549 m .36049 .48499 L .35716 .48274 L p F P
0 g
s
.582 .918 .697 r
.63204 .28236 m .63352 .28182 L .63039 .28486 L p F P
0 g
s
.582 .918 .697 r
.62672 .28682 m .63204 .28236 L p .63039 .28486 L F P
0 g
s
.582 .918 .697 r
.62232 .29101 m .62672 .28682 L p .63039 .28486 L F P
0 g
s
.665 .966 .779 r
.63477 .28139 m .63039 .28486 L .63352 .28182 L closepath p F P
0 g
s
.154 0 .014 r
.552 .34582 m .54678 .34905 L .55148 .34677 L closepath p F P
0 g
s
.189 0 .064 r
.5498 .35002 m .55148 .34677 L .54678 .34905 L p F P
0 g
s
.189 0 .064 r
.53955 .35507 m .5498 .35002 L p .54678 .34905 L F P
0 g
s
0 0 0 r
.75534 .35825 m .74953 .36424 L .75554 .35706 L p F P
0 g
s
0 0 0 r
.75837 .35463 m .75534 .35825 L p .75554 .35706 L F P
0 g
s
0 0 0 r
.75554 .35706 m .75921 .3533 L .75837 .35463 L p F P
0 g
s
.307 .285 .67 r
.79081 .26246 m .79357 .26569 L .79218 .26791 L closepath p F P
0 g
s
.781 .372 .276 r
.29773 .37802 m .29877 .37969 L .29653 .37898 L closepath p F P
0 g
s
.567 .9 .981 r
.56014 .46815 m .54866 .47192 L .54568 .47105 L p F P
0 g
s
.551 .894 .982 r
.53421 .47461 m .54568 .47105 L .54866 .47192 L p F P
0 g
s
.512 .786 .995 r
.34585 .48451 m .34606 .48464 L p .33165 .48398 L F P
0 g
s
.512 .786 .995 r
.33165 .48398 m .33722 .48323 L .34585 .48451 L p F P
0 g
s
.504 .791 .997 r
.33165 .48398 m .33722 .48323 L .32871 .48222 L closepath p F P
0 g
s
.718 .36 .369 r
.33837 .40009 m .33583 .39569 L .34488 .39715 L p F P
0 g
s
.718 .36 .369 r
.3467 .40132 m .33837 .40009 L p .34488 .39715 L F P
0 g
s
.718 .36 .369 r
.34488 .39715 m .34709 .40051 L .3467 .40132 L p F P
0 g
s
.546 0 0 r
.19631 .30933 m .19221 .3057 L .19656 .30887 L p F P
0 g
s
.546 0 0 r
.19779 .31038 m .19631 .30933 L p .19656 .30887 L F P
0 g
s
.546 0 0 r
.19656 .30887 m .2002 .31203 L .19779 .31038 L p F P
0 g
s
.634 .687 .883 r
.74955 .22566 m .76143 .22261 L .76416 .22698 L p F P
0 g
s
.649 .709 .891 r
.76143 .22261 m .74955 .22566 L .74685 .22204 L p F P
0 g
s
.679 .749 .904 r
.73508 .22646 m .74685 .22204 L .74955 .22566 L p F P
0 g
s
.693 .767 .909 r
.74685 .22204 m .73508 .22646 L .7324 .22347 L p F P
0 g
s
.319 .697 .98 r
.24939 .47029 m .23867 .46968 L .2351 .46761 L p F P
0 g
s
.787 .941 .927 r
.68814 .24461 m .69485 .24024 L .69217 .23874 L p F P
0 g
s
.787 .941 .927 r
.69217 .23874 m .69194 .2389 L .68814 .24461 L p F P
0 g
s
.767 .949 .936 r
.68064 .24667 m .69194 .2389 L .68814 .24461 L p F P
0 g
s
.475 .853 .631 r
.70378 .40478 m .70333 .40511 L .70368 .40484 L closepath p F P
0 g
s
.512 .887 .692 r
.70124 .406 m .70368 .40484 L .70333 .40511 L p F P
0 g
s
.512 .887 .692 r
.69877 .40773 m .70124 .406 L p .70333 .40511 L F P
0 g
s
.512 .887 .692 r
.69171 .41309 m .69877 .40773 L p .70333 .40511 L F P
0 g
s
.565 .882 .991 r
.53119 .47355 m .53246 .47403 L .52088 .47733 L p F P
0 g
s
.565 .882 .991 r
.52088 .47733 m .51974 .47691 L .53119 .47355 L p F P
0 g
s
0 0 .08 r
.7786 .3261 m .77437 .33107 L .77738 .32483 L p F P
0 g
s
0 0 .08 r
.77738 .32483 m .77942 .32244 L .7786 .3261 L p F P
0 g
s
.419 .437 .772 r
.78472 .24427 m .79139 .2472 L .78828 .25259 L p F P
0 g
s
.37 .375 .734 r
.79661 .25074 m .79324 .2562 L .78828 .25259 L p F P
0 g
s
.37 .375 .734 r
.78828 .25259 m .79139 .2472 L .79661 .25074 L p F P
0 g
s
.499 .866 .638 r
.71519 .39614 m .70378 .40478 L .70368 .40484 L p F P
0 g
s
.562 .924 .758 r
.69171 .41309 m .6897 .41383 L .69877 .40773 L closepath p F P
0 g
s
.652 .316 .39 r
.4047 .40498 m .39462 .40504 L .39363 .40802 L p F P
0 g
s
.668 .332 .396 r
.39462 .40504 m .39363 .40802 L .39114 .40497 L closepath p F P
0 g
s
.649 .316 .395 r
.40921 .40491 m .40809 .40852 L .4047 .40498 L closepath p F P
0 g
s
.652 .316 .39 r
.40795 .40903 m .40809 .40852 L .4047 .40498 L p F P
0 g
s
.652 .316 .39 r
.39457 .40913 m .40795 .40903 L p .4047 .40498 L F P
0 g
s
.652 .316 .39 r
.39363 .40802 m .39457 .40913 L p .4047 .40498 L F P
0 g
s
.676 .337 .393 r
.39329 .40912 m .39363 .40802 L .39114 .40497 L p F P
0 g
s
.676 .337 .393 r
.382 .40879 m .39329 .40912 L p .39114 .40497 L F P
0 g
s
.676 .337 .393 r
.37926 .4049 m .382 .40879 L p .39114 .40497 L F P
0 g
s
.676 .337 .393 r
.39114 .40497 m .37939 .40454 L .37926 .4049 L p F P
0 g
s
.551 .023 0 r
.064 .38135 m .0679 .38464 L .06402 .38088 L p F P
0 g
s
.551 .023 0 r
.06402 .38088 m .06012 .37759 L .064 .38135 L p F P
0 g
s
.632 .108 0 r
.05951 .37692 m .06012 .37759 L .06402 .38088 L p F P
0 g
s
.661 .965 .779 r
.64155 .27605 m .63477 .28139 L .63352 .28182 L p F P
0 g
s
.628 .295 .388 r
.42021 .40437 m .40921 .40491 L .40809 .40852 L p F P
0 g
s
.777 .309 .13 r
.2612 .3567 m .25917 .35706 L .25784 .35533 L closepath p F P
0 g
s
.802 .33 .104 r
.24638 .35008 m .25198 .35276 L .24894 .34866 L p F P
0 g
s
.802 .33 .104 r
.24894 .34866 m .2435 .34593 L .24638 .35008 L p F P
0 g
s
.499 .866 .638 r
.70368 .40484 m .71159 .39845 L p .71519 .39614 L F P
0 g
s
.555 .911 .713 r
.70368 .40484 m .70124 .406 L .71159 .39845 L closepath p F P
0 g
s
.562 .922 .948 r
.58912 .46102 m .589 .46101 L .59032 .46049 L closepath p F P
0 g
s
.232 .651 .958 r
.21413 .46051 m .21728 .46237 L .20799 .461 L p F P
0 g
s
.232 .651 .958 r
.21339 .46019 m .21413 .46051 L p .20799 .461 L F P
0 g
s
.232 .651 .958 r
.20309 .45871 m .21339 .46019 L p .20799 .461 L F P
0 g
s
.232 .651 .958 r
.20799 .461 m .20476 .45969 L .20309 .45871 L p F P
0 g
s
.47 .124 .296 r
.4775 .38846 m .47843 .38835 L .47746 .38859 L closepath p F P
0 g
s
.566 .933 .798 r
.67932 .42084 m .67815 .42116 L .68379 .41766 L closepath p F P
0 g
s
.466 .483 .792 r
.78452 .24421 m .78463 .24404 L .78472 .24427 L closepath p F P
0 g
s
.483 .148 .322 r
.47843 .38835 m .47746 .38859 L .47623 .39259 L p F P
0 g
s
.795 .357 .207 r
.26939 .36629 m .2758 .36867 L .27282 .36451 L p F P
0 g
s
.795 .357 .207 r
.27282 .36451 m .26662 .36206 L .26939 .36629 L p F P
0 g
s
.579 .924 .958 r
.59032 .46049 m .589 .46101 L .58611 .46049 L p F P
0 g
s
.56 .917 .958 r
.57459 .46479 m .58611 .46049 L .589 .46101 L p F P
0 g
s
.401 .444 .79 r
.78463 .24404 m .78472 .24427 L .79139 .2472 L p F P
0 g
s
.005 0 .334 r
.79003 .30175 m .78782 .3048 L .78791 .30025 L p F P
0 g
s
.005 0 .334 r
.78791 .30025 m .7908 .29623 L .79003 .30175 L p F P
0 g
s
0 .162 .61 r
.09366 .40475 m .08895 .40148 L .09318 .40461 L p F P
0 g
s
0 .162 .61 r
.09318 .40461 m .09742 .40755 L .09366 .40475 L p F P
0 g
s
.466 .5 .81 r
.78184 .2375 m .78743 .23886 L .78463 .24404 L closepath p F P
0 g
s
.401 .444 .79 r
.79434 .24156 m .78743 .23886 L .78463 .24404 L p F P
0 g
s
.401 .444 .79 r
.7945 .24203 m .79434 .24156 L p .78463 .24404 L F P
0 g
s
.401 .444 .79 r
.79139 .2472 m .7945 .24203 L p .78463 .24404 L F P
0 g
s
.582 .649 .882 r
.76416 .22698 m .76527 .22684 L .76474 .22796 L closepath p F P
0 g
s
.543 .623 .882 r
.77622 .22591 m .76527 .22684 L .76474 .22796 L p F P
0 g
s
.543 .623 .882 r
.77901 .23139 m .77622 .22591 L p .76474 .22796 L F P
0 g
s
.778 .273 0 r
.22474 .3334 m .22973 .33632 L .22652 .33232 L p F P
0 g
s
.778 .273 0 r
.22652 .33232 m .22166 .32937 L .22474 .3334 L p F P
0 g
s
.768 .258 0 r
.22101 .32855 m .22166 .32937 L .22652 .33232 L p F P
0 g
s
.549 .213 .352 r
.46391 .39515 m .46296 .3983 L .45562 .39652 L closepath p F P
0 g
s
.548 .218 .36 r
.4627 .39921 m .46296 .3983 L .45562 .39652 L p F P
0 g
s
.548 .218 .36 r
.45 .40137 m .4627 .39921 L p .45562 .39652 L F P
0 g
s
.687 .349 .397 r
.37939 .40454 m .37926 .4049 L .37898 .40451 L closepath p F P
0 g
s
.683 .348 .402 r
.37052 .40811 m .36774 .40376 L .37898 .40451 L p F P
0 g
s
.683 .348 .402 r
.37802 .40861 m .37052 .40811 L p .37898 .40451 L F P
0 g
s
.683 .348 .402 r
.37898 .40451 m .37926 .4049 L .37802 .40861 L p F P
0 g
s
.51 .857 .597 r
.61108 .30015 m .60916 .30157 L .61661 .2953 L closepath p F P
0 g
s
.726 .99 .84 r
.64621 .27239 m .64155 .27605 L .64475 .27263 L closepath p F P
0 g
s
.661 .965 .779 r
.64349 .27286 m .64475 .27263 L .64155 .27605 L p F P
0 g
s
.661 .965 .779 r
.63692 .27831 m .64349 .27286 L p .64155 .27605 L F P
0 g
s
.661 .965 .779 r
.63352 .28182 m .63692 .27831 L p .64155 .27605 L F P
0 g
s
0 0 0 r
.74944 .36433 m .7494 .36438 L .74953 .36424 L closepath p F P
0 g
s
0 .18 .652 r
.17581 .29176 m .17156 .28871 L .17549 .29206 L p F P
0 g
s
0 .18 .652 r
.17549 .29206 m .17943 .29487 L .17581 .29176 L p F P
0 g
s
.533 .797 .994 r
.34606 .48464 m .34651 .48457 L .34585 .48451 L closepath p F P
0 g
s
.106 0 0 r
.56176 .33903 m .552 .34582 L .55148 .34677 L p F P
0 g
s
.483 .148 .322 r
.48818 .38959 m .48887 .38729 L .47843 .38835 L p F P
0 g
s
.483 .148 .322 r
.47623 .39259 m .48818 .38959 L p .47843 .38835 L F P
0 g
s
.478 .135 .305 r
.48941 .38562 m .48887 .38729 L .47843 .38835 L closepath p F P
0 g
s
.249 .212 .619 r
.79606 .27013 m .79347 .27424 L .79218 .26791 L p F P
0 g
s
.249 .212 .619 r
.79218 .26791 m .79357 .26569 L .79606 .27013 L p F P
0 g
s
0 .299 .726 r
.11481 .41859 m .11263 .41743 L .11713 .42044 L p F P
0 g
s
0 .299 .726 r
.11713 .42044 m .11855 .42119 L .11481 .41859 L p F P
0 g
s
0 0 0 r
.74867 .36565 m .75534 .35825 L .74953 .36424 L p F P
0 g
s
0 0 0 r
.74755 .36681 m .74867 .36565 L p .74953 .36424 L F P
0 g
s
0 0 0 r
.74953 .36424 m .7494 .36438 L .74755 .36681 L p F P
0 g
s
.628 .298 .393 r
.42326 .40421 m .42261 .40644 L .42021 .40437 L closepath p F P
0 g
s
.628 .295 .388 r
.42208 .40839 m .42261 .40644 L .42021 .40437 L p F P
0 g
s
.628 .295 .388 r
.4086 .409 m .42208 .40839 L p .42021 .40437 L F P
0 g
s
.628 .295 .388 r
.40809 .40852 m .4086 .409 L p .42021 .40437 L F P
0 g
s
0 0 0 r
.7494 .36438 m .74241 .37176 L .74755 .36681 L closepath p F P
0 g
s
.576 .83 .993 r
.45871 .48353 m .44911 .48465 L .44731 .48359 L p F P
0 g
s
.571 .908 .975 r
.57166 .46415 m .57266 .4644 L .56179 .46857 L p F P
0 g
s
.571 .908 .975 r
.56179 .46857 m .56014 .46815 L .57166 .46415 L p F P
0 g
s
.432 .758 .995 r
.28507 .47844 m .29599 .47783 L .29944 .47991 L p F P
0 g
s
.451 .759 .995 r
.29599 .47783 m .28507 .47844 L .2816 .47639 L p F P
0 g
s
.523 .913 .792 r
.66661 .42808 m .66601 .42842 L .6665 .4281 L closepath p F P
0 g
s
.548 .929 .831 r
.66393 .42854 m .6665 .4281 L .66601 .42842 L p F P
0 g
s
.548 .929 .831 r
.65692 .43244 m .66393 .42854 L p .66601 .42842 L F P
0 g
s
.548 .929 .831 r
.65318 .43481 m .65692 .43244 L p .66601 .42842 L F P
0 g
s
.542 .01 0 r
.18409 .29879 m .18305 .29782 L .17943 .29487 L p F P
0 g
s
0 .206 .646 r
.10257 .41113 m .10119 .41025 L .09742 .40755 L p F P
0 g
s
.407 .749 .994 r
.27811 .47424 m .2816 .47639 L .27361 .47656 L p F P
0 g
s
.407 .749 .994 r
.26724 .47462 m .27811 .47424 L p .27361 .47656 L F P
0 g
s
.407 .749 .994 r
.27361 .47656 m .26826 .47522 L .26724 .47462 L p F P
0 g
s
.131 .587 .923 r
.18897 .45444 m .19653 .45597 L .20213 .45853 L p F P
0 g
s
.145 .593 .929 r
.19653 .45597 m .18897 .45444 L .18533 .45225 L p F P
0 g
s
.804 .326 .077 r
.2435 .34593 m .24189 .34366 L .23822 .34302 L p F P
0 g
s
.557 .924 .94 r
.60053 .45639 m .59032 .46049 L .59954 .45628 L closepath p F P
0 g
s
.579 .924 .958 r
.59767 .45596 m .59954 .45628 L .59032 .46049 L p F P
0 g
s
.579 .924 .958 r
.58611 .46049 m .59767 .45596 L p .59032 .46049 L F P
0 g
s
.547 .795 .99 r
.35382 .48031 m .35716 .48274 L .34651 .48457 L p F P
0 g
s
.547 .795 .99 r
.3427 .48245 m .35382 .48031 L p .34651 .48457 L F P
0 g
s
.547 .795 .99 r
.34651 .48457 m .34585 .48451 L .3427 .48245 L p F P
0 g
s
.566 .891 .987 r
.5438 .47042 m .54568 .47105 L .53421 .47461 L p F P
0 g
s
.566 .891 .987 r
.53421 .47461 m .53246 .47403 L .5438 .47042 L p F P
0 g
s
.549 .925 .796 r
.67581 .42179 m .67815 .42116 L .66661 .42808 L p F P
0 g
s
.549 .925 .796 r
.66661 .42808 m .6665 .4281 L .67581 .42179 L p F P
0 g
s
.523 .786 .993 r
.34585 .48451 m .3427 .48245 L .33722 .48323 L closepath p F P
0 g
s
.615 .285 .389 r
.43572 .40724 m .43683 .40301 L .42326 .40421 L p F P
0 g
s
.615 .285 .389 r
.42491 .40815 m .43572 .40724 L p .42326 .40421 L F P
0 g
s
.615 .285 .389 r
.42326 .40421 m .42261 .40644 L .42491 .40815 L p F P
0 g
s
.762 .921 .941 r
.70537 .2338 m .69485 .24024 L .69217 .23874 L p F P
0 g
s
.717 .988 .841 r
.65301 .26714 m .64621 .27239 L .64475 .27263 L p F P
0 g
s
.718 .845 .942 r
.72721 .22594 m .72071 .22904 L .71804 .22662 L p F P
0 g
s
.75 .852 .926 r
.70642 .23316 m .71804 .22662 L .72071 .22904 L p F P
0 g
s
.684 .349 .402 r
.37926 .4049 m .382 .40879 L .37802 .40861 L closepath p F P
0 g
s
.458 .826 .571 r
.71526 .39609 m .71519 .39614 L .71524 .3961 L closepath p F P
0 g
s
.499 .866 .638 r
.71276 .39756 m .71524 .3961 L .71519 .39614 L p F P
0 g
s
.499 .866 .638 r
.71159 .39845 m .71276 .39756 L p .71519 .39614 L F P
0 g
s
.484 .84 .579 r
.72546 .38765 m .71526 .39609 L .71524 .3961 L p F P
0 g
s
.484 .84 .579 r
.71524 .3961 m .72269 .38969 L p .72546 .38765 L F P
0 g
s
.545 .893 .662 r
.71524 .3961 m .71276 .39756 L .72269 .38969 L closepath p F P
0 g
s
.22 .153 .565 r
.79436 .28003 m .79415 .28033 L .79252 .2756 L p F P
0 g
s
.22 .153 .565 r
.79252 .2756 m .79347 .27424 L .79436 .28003 L p F P
0 g
s
.577 .244 .368 r
.43715 .40193 m .43901 .40273 L .43683 .40301 L closepath p F P
0 g
s
.583 .944 .843 r
.67551 .42184 m .67581 .42179 L .6665 .4281 L p F P
0 g
s
.583 .944 .843 r
.6665 .4281 m .66393 .42854 L .67551 .42184 L p F P
0 g
s
.767 .386 .333 r
.31177 .39048 m .31902 .39232 L .31653 .38794 L p F P
0 g
s
.767 .386 .333 r
.31653 .38794 m .31418 .38734 L .31177 .39048 L p F P
0 g
s
.597 .668 .889 r
.76527 .22684 m .76416 .22698 L .76143 .22261 L p F P
0 g
s
.69 .157 0 r
.2002 .31203 m .20064 .31251 L .20505 .31565 L p F P
0 g
s
.702 .172 0 r
.20404 .3164 m .20854 .31951 L .20505 .31565 L p F P
0 g
s
.702 .172 0 r
.20505 .31565 m .20064 .31251 L .20404 .3164 L p F P
0 g
s
.514 0 0 r
.07202 .38834 m .07599 .39159 L .07188 .38789 L p F P
0 g
s
.514 0 0 r
.07188 .38789 m .0679 .38464 L .07202 .38834 L p F P
0 g
s
0 0 0 r
.74709 .36729 m .74755 .36681 L .74241 .37176 L p F P
0 g
s
0 0 0 r
.741 .37336 m .74709 .36729 L p .74241 .37176 L F P
0 g
s
0 0 0 r
.73716 .37708 m .741 .37336 L p .74241 .37176 L F P
0 g
s
0 0 0 r
.74241 .37176 m .73809 .37606 L .73716 .37708 L p F P
0 g
s
.588 .787 .975 r
.37163 .48285 m .36049 .48499 L .35716 .48274 L p F P
0 g
s
.786 .387 .297 r
.29433 .38186 m .30128 .38404 L .29877 .37969 L p F P
0 g
s
.786 .387 .297 r
.294 .38126 m .29433 .38186 L p .29877 .37969 L F P
0 g
s
.786 .387 .297 r
.29877 .37969 m .29653 .37898 L .294 .38126 L p F P
0 g
s
.704 .362 .395 r
.36199 .40733 m .37052 .40811 L .36774 .40376 L p F P
0 g
s
.704 .362 .395 r
.36774 .40376 m .3635 .40337 L .36199 .40733 L p F P
0 g
s
0 0 .257 r
.78748 .30903 m .78425 .31313 L .78581 .30736 L p F P
0 g
s
0 0 .257 r
.78581 .30736 m .78782 .3048 L .78748 .30903 L p F P
0 g
s
.746 .382 .363 r
.3298 .39846 m .33837 .40009 L .33583 .39569 L p F P
0 g
s
.746 .382 .363 r
.32928 .39748 m .3298 .39846 L p .33583 .39569 L F P
0 g
s
.746 .382 .363 r
.33583 .39569 m .33083 .39472 L .32928 .39748 L p F P
0 g
s
0 0 0 r
.73809 .37606 m .73446 .37955 L .73716 .37708 L closepath p F P
0 g
s
0 0 0 r
.7267 .38657 m .72546 .38765 L .7264 .38684 L closepath p F P
0 g
s
.484 .84 .579 r
.72425 .3884 m .7264 .38684 L .72546 .38765 L p F P
0 g
s
.484 .84 .579 r
.72269 .38969 m .72425 .3884 L p .72546 .38765 L F P
0 g
s
0 0 0 r
.73446 .37955 m .7267 .38657 L .7264 .38684 L p F P
0 g
s
.764 .992 .88 r
.65766 .26356 m .65301 .26714 L .65608 .26354 L closepath p F P
0 g
s
.717 .988 .841 r
.65496 .26355 m .65608 .26354 L .65301 .26714 L p F P
0 g
s
.717 .988 .841 r
.64735 .26973 m .65496 .26355 L p .65301 .26714 L F P
0 g
s
.717 .988 .841 r
.64475 .27263 m .64735 .26973 L p .65301 .26714 L F P
0 g
s
.542 .925 .91 r
.61492 .45175 m .61467 .45186 L .61489 .45175 L closepath p F P
0 g
s
.562 .928 .932 r
.61209 .4515 m .61489 .45175 L .61467 .45186 L p F P
0 g
s
.562 .928 .932 r
.60053 .45639 m .61209 .4515 L p .61467 .45186 L F P
0 g
s
0 0 0 r
.7357 .37836 m .73716 .37708 L .73446 .37955 L p F P
0 g
s
0 0 0 r
.73241 .38136 m .7357 .37836 L p .73446 .37955 L F P
0 g
s
0 0 0 r
.7264 .38684 m .73241 .38136 L p .73446 .37955 L F P
0 g
s
.564 .934 .912 r
.6249 .44647 m .62647 .44648 L .61492 .45175 L p F P
0 g
s
.564 .934 .912 r
.61492 .45175 m .61489 .45175 L .6249 .44647 L p F P
0 g
s
.586 .937 .935 r
.62367 .44636 m .6249 .44647 L .61489 .45175 L p F P
0 g
s
.586 .937 .935 r
.61489 .45175 m .61209 .4515 L .62367 .44636 L p F P
0 g
s
.597 .668 .889 r
.76143 .22261 m .76773 .22159 L .76527 .22684 L p F P
0 g
s
.572 .623 .864 r
.77345 .22081 m .76773 .22159 L .76527 .22684 L p F P
0 g
s
.572 .623 .864 r
.76527 .22684 m .77622 .22591 L .77345 .22081 L p F P
0 g
s
.779 .307 .116 r
.25501 .35687 m .25198 .35276 L .25784 .35533 L p F P
0 g
s
.779 .307 .116 r
.25625 .35741 m .25501 .35687 L p .25784 .35533 L F P
0 g
s
.779 .307 .116 r
.25784 .35533 m .25917 .35706 L .25625 .35741 L p F P
0 g
s
.582 .876 .994 r
.53119 .47355 m .51974 .47691 L .51669 .47561 L p F P
0 g
s
.569 .872 .995 r
.50526 .4788 m .51669 .47561 L .51974 .47691 L p F P
0 g
s
.148 .599 .93 r
.20476 .45969 m .20309 .45871 L .20213 .45853 L closepath p F P
0 g
s
.607 .926 .694 r
.62232 .29101 m .6206 .29196 L .62672 .28682 L closepath p F P
0 g
s
.567 .938 .874 r
.64964 .4351 m .65236 .43489 L .6408 .44082 L p F P
0 g
s
.567 .938 .874 r
.64582 .43707 m .64964 .4351 L p .6408 .44082 L F P
0 g
s
.567 .938 .874 r
.6408 .44082 m .63934 .44095 L .64582 .43707 L p F P
0 g
s
.757 .245 0 r
.23296 .34033 m .22973 .33632 L .23492 .33915 L p F P
0 g
s
.757 .245 0 r
.23805 .34299 m .23296 .34033 L p .23492 .33915 L F P
0 g
s
.757 .245 0 r
.23492 .33915 m .23822 .34302 L .23805 .34299 L p F P
0 g
s
.758 .374 .327 r
.31137 .39039 m .31177 .39048 L .31418 .38734 L p F P
0 g
s
.758 .374 .327 r
.31418 .38734 m .30872 .38606 L .31137 .39039 L p F P
0 g
s
.082 0 .417 r
.79481 .29065 m .7908 .29623 L .79087 .29094 L p F P
0 g
s
.082 0 .417 r
.79489 .28539 m .79481 .29065 L p .79087 .29094 L F P
0 g
s
.082 0 .417 r
.79087 .29094 m .79489 .28536 L .79489 .28539 L p F P
0 g
s
.6 .788 .97 r
.38612 .48282 m .37494 .48514 L .37163 .48285 L p F P
0 g
s
.055 .535 .891 r
.17128 .44739 m .17592 .44861 L .18128 .45126 L p F P
0 g
s
.07 .541 .898 r
.17592 .44861 m .17128 .44739 L .1676 .44513 L p F P
0 g
s
0 .167 .657 r
.16324 .28188 m .16225 .28113 L .15864 .2777 L p F P
0 g
s
.71 .368 .398 r
.35997 .40713 m .36199 .40733 L .3635 .40337 L p F P
0 g
s
.71 .368 .398 r
.3635 .40337 m .35732 .40274 L .35997 .40713 L p F P
0 g
s
.35 .718 .986 r
.25293 .47232 m .25947 .47246 L .26625 .4746 L p F P
0 g
s
.368 .725 .989 r
.25947 .47246 m .25293 .47232 L .24939 .47029 L p F P
0 g
s
0 0 0 r
.77562 .33175 m .77077 .3375 L .77437 .33107 L p F P
0 g
s
0 0 0 r
.77832 .32698 m .77562 .33175 L p .77437 .33107 L F P
0 g
s
0 0 0 r
.77437 .33107 m .7786 .3261 L .77832 .32698 L p F P
0 g
s
.753 .991 .884 r
.66501 .25805 m .65766 .26356 L .65608 .26354 L p F P
0 g
s
.059 0 0 r
.56343 .3379 m .56176 .33903 L .56322 .33824 L closepath p F P
0 g
s
.106 0 0 r
.56144 .34134 m .56322 .33824 L .56176 .33903 L p F P
0 g
s
.106 0 0 r
.55148 .34677 m .56144 .34134 L p .56176 .33903 L F P
0 g
s
0 .475 .852 r
.15362 .43958 m .15702 .4407 L .16214 .44345 L p F P
0 g
s
.013 .498 .871 r
.16391 .44281 m .15702 .4407 L .16214 .44345 L p F P
0 g
s
.013 .498 .871 r
.16214 .44345 m .1676 .44513 L .16391 .44281 L p F P
0 g
s
.243 .662 .961 r
.22087 .46444 m .22568 .46495 L .23189 .46729 L p F P
0 g
s
.259 .668 .966 r
.22568 .46495 m .22087 .46444 L .21728 .46237 L p F P
0 g
s
.257 0 .132 r
.53765 .35911 m .53794 .35845 L .52739 .3631 L p F P
0 g
s
.257 0 .132 r
.52739 .3631 m .5262 .36581 L .53765 .35911 L p F P
0 g
s
.181 0 .07 r
.54911 .35142 m .5498 .35002 L .53955 .35507 L p F P
0 g
s
.181 0 .07 r
.54037 .35724 m .54911 .35142 L p .53955 .35507 L F P
0 g
s
.181 0 .07 r
.53955 .35507 m .53794 .35845 L .54037 .35724 L p F P
0 g
s
0 .34 .756 r
.11855 .42119 m .12339 .42353 L .12802 .42648 L p F P
0 g
s
0 .346 .767 r
.12339 .42353 m .11855 .42119 L .11481 .41859 L p F P
0 g
s
.542 .01 0 r
.17943 .29487 m .18008 .29548 L .18409 .29879 L p F P
0 g
s
.551 .02 0 r
.18394 .29916 m .18801 .30246 L .18409 .29879 L p F P
0 g
s
.551 .02 0 r
.18409 .29879 m .18008 .29548 L .18394 .29916 L p F P
0 g
s
.569 .838 .996 r
.46226 .48305 m .4618 .4828 L .45871 .48353 L closepath p F P
0 g
s
.576 .83 .993 r
.45864 .48079 m .4618 .4828 L .45871 .48353 L p F P
0 g
s
.576 .83 .993 r
.44731 .48359 m .45864 .48079 L p .45871 .48353 L F P
0 g
s
.522 .188 .342 r
.47508 .39668 m .47623 .39259 L .46391 .39515 L p F P
0 g
s
.522 .188 .342 r
.46584 .39855 m .47508 .39668 L p .46391 .39515 L F P
0 g
s
.522 .188 .342 r
.46391 .39515 m .46296 .3983 L .46584 .39855 L p F P
0 g
s
.499 .769 .992 r
.31006 .47899 m .29944 .47991 L .29599 .47783 L p F P
0 g
s
.47 .768 .996 r
.31067 .47912 m .31383 .48108 L p .29944 .47991 L F P
0 g
s
.47 .768 .996 r
.29944 .47991 m .31006 .47899 L .31067 .47912 L p F P
0 g
s
.803 .385 .255 r
.27834 .37299 m .2848 .37535 L .28219 .37104 L p F P
0 g
s
.803 .385 .255 r
.27654 .36978 m .27834 .37299 L p .28219 .37104 L F P
0 g
s
.803 .385 .255 r
.28219 .37104 m .27749 .36925 L .27654 .36978 L p F P
0 g
s
.568 .916 .964 r
.58333 .45996 m .58611 .46049 L .57459 .46479 L p F P
0 g
s
.568 .916 .964 r
.57459 .46479 m .57266 .4644 L .58333 .45996 L p F P
0 g
s
0 .268 .706 r
.10388 .4113 m .10822 .41439 L .10257 .41113 L p F P
0 g
s
0 .268 .706 r
.10257 .41113 m .09821 .40805 L .10388 .4113 L p F P
0 g
s
0 .206 .646 r
.09742 .40755 m .09821 .40805 L .10257 .41113 L p F P
0 g
s
.012 0 0 r
.57428 .3298 m .56343 .3379 L .56322 .33824 L p F P
0 g
s
.772 .366 .284 r
.29653 .37898 m .294 .38126 L .29165 .37757 L closepath p F P
0 g
s
.453 .512 .829 r
.77972 .23287 m .78184 .2375 L .78743 .23886 L p F P
0 g
s
.088 .554 .906 r
.18167 .45 m .17592 .44861 L .18128 .45126 L p F P
0 g
s
.088 .554 .906 r
.18128 .45126 m .18533 .45225 L .18167 .45 L p F P
0 g
s
0 .437 .83 r
.14621 .43481 m .13959 .43232 L .14446 .43517 L p F P
0 g
s
0 .437 .83 r
.14446 .43517 m .14992 .43723 L .14621 .43481 L p F P
0 g
s
0 .409 .806 r
.13604 .43089 m .13959 .43232 L .14446 .43517 L p F P
0 g
s
.262 .668 .967 r
.23153 .46548 m .22568 .46495 L .23189 .46729 L p F P
0 g
s
.262 .668 .967 r
.23189 .46729 m .2351 .46761 L .23153 .46548 L p F P
0 g
s
.098 0 .002 r
.56057 .3429 m .56144 .34134 L .55148 .34677 L p F P
0 g
s
.098 0 .002 r
.55421 .34757 m .56057 .3429 L p .55148 .34677 L F P
0 g
s
.098 0 .002 r
.55148 .34677 m .5498 .35002 L .55421 .34757 L p F P
0 g
s
.586 .265 .393 r
.43901 .40273 m .43683 .40301 L .43572 .40724 L p F P
0 g
s
.325 0 .189 r
.51496 .37085 m .51476 .37134 L .51881 .36935 L closepath p F P
0 g
s
.586 .801 .982 r
.3894 .48512 m .40061 .48265 L .40387 .48496 L p F P
0 g
s
.608 .789 .968 r
.40061 .48265 m .3894 .48512 L .38612 .48282 L p F P
0 g
s
.582 .866 .995 r
.51669 .47561 m .50526 .4788 L .50219 .47736 L p F P
0 g
s
.569 .862 .996 r
.49078 .4804 m .50219 .47736 L .50526 .4788 L p F P
0 g
s
.533 .87 .607 r
.7264 .38684 m .72425 .3884 L .73241 .38136 L closepath p F P
0 g
s
.348 .72 .986 r
.26826 .47522 m .26724 .47462 L .26625 .4746 L closepath p F P
0 g
s
.699 .163 0 r
.21209 .32337 m .21686 .32638 L .21319 .32256 L p F P
0 g
s
.699 .163 0 r
.21319 .32256 m .20854 .31951 L .21209 .32337 L p F P
0 g
s
.522 .791 .994 r
.33933 .48009 m .3427 .48245 L .33722 .48323 L p F P
0 g
s
.522 .791 .994 r
.32825 .48194 m .33933 .48009 L p .33722 .48323 L F P
0 g
s
.522 .791 .994 r
.33722 .48323 m .32871 .48222 L .32825 .48194 L p F P
0 g
s
0 .481 .86 r
.15702 .4407 m .15362 .43958 L .14992 .43723 L p F P
0 g
s
.44 0 0 r
.07645 .39195 m .07599 .39159 L .08005 .3948 L p F P
0 g
s
.44 0 0 r
.08005 .3948 m .08022 .39494 L .07645 .39195 L p F P
0 g
s
0 0 0 r
.76986 .33855 m .76948 .3395 L .77077 .3375 L closepath p F P
0 g
s
.182 .127 .556 r
.79762 .27489 m .79436 .28003 L .79347 .27424 L p F P
0 g
s
.182 .127 .556 r
.79347 .27424 m .79606 .27013 L .79762 .27489 L p F P
0 g
s
0 0 .064 r
.77924 .3253 m .7786 .3261 L .77942 .32244 L p F P
0 g
s
0 0 .064 r
.77942 .32244 m .78204 .31912 L .77924 .3253 L p F P
0 g
s
0 .415 .816 r
.13959 .43232 m .13604 .43089 L .13232 .42842 L p F P
0 g
s
.742 .377 .361 r
.33083 .39472 m .32928 .39748 L .32726 .39406 L closepath p F P
0 g
s
.726 .387 .405 r
.35002 .40595 m .35997 .40713 L .35732 .40274 L p F P
0 g
s
.726 .387 .405 r
.35732 .40274 m .34768 .40147 L .35002 .40595 L p F P
0 g
s
.586 .263 .388 r
.45 .40137 m .43901 .40273 L .44531 .40601 L p F P
0 g
s
.586 .265 .393 r
.43572 .40724 m .44531 .40601 L .43901 .40273 L p F P
0 g
s
.733 .832 .926 r
.72721 .22594 m .7324 .22347 L .72971 .22063 L p F P
0 g
s
.733 .832 .926 r
.72971 .22063 m .72967 .22065 L .72721 .22594 L p F P
0 g
s
.718 .845 .942 r
.71804 .22662 m .72967 .22065 L .72721 .22594 L p F P
0 g
s
.582 .842 .994 r
.47316 .47992 m .475 .48101 L .46226 .48305 L p F P
0 g
s
.582 .842 .994 r
.46226 .48305 m .4618 .4828 L .47316 .47992 L p F P
0 g
s
.784 .981 .906 r
.66914 .25496 m .66501 .25805 L .66762 .25469 L closepath p F P
0 g
s
.753 .991 .884 r
.66644 .25449 m .66762 .25469 L .66501 .25805 L p F P
0 g
s
.753 .991 .884 r
.65818 .26101 m .66644 .25449 L p .66501 .25805 L F P
0 g
s
.753 .991 .884 r
.65608 .26354 m .65818 .26101 L p .66501 .25805 L F P
0 g
s
.582 .945 .871 r
.65318 .43481 m .65236 .43489 L .65692 .43244 L closepath p F P
0 g
s
0 .139 .6 r
.0848 .39831 m .08022 .39494 L .07645 .39195 L p F P
0 g
s
.591 .805 .981 r
.40387 .48496 m .41511 .48238 L .41835 .48465 L p F P
0 g
s
.613 .791 .967 r
.41511 .48238 m .40387 .48496 L .40061 .48265 L p F P
0 g
s
.768 .895 .933 r
.70642 .23316 m .70537 .2338 L .70595 .23283 L closepath p F P
0 g
s
.762 .921 .941 r
.70374 .2313 m .70595 .23283 L .70537 .2338 L p F P
0 g
s
.762 .921 .941 r
.69217 .23874 m .70374 .2313 L p .70537 .2338 L F P
0 g
s
.012 0 0 r
.56322 .33824 m .57287 .33241 L p .57428 .3298 L F P
0 g
s
.001 0 0 r
.57203 .33373 m .57287 .33241 L .56322 .33824 L p F P
0 g
s
.001 0 0 r
.5659 .33859 m .57203 .33373 L p .56322 .33824 L F P
0 g
s
.001 0 0 r
.56322 .33824 m .56144 .34134 L .5659 .33859 L p F P
0 g
s
.582 .857 .995 r
.50219 .47736 m .49078 .4804 L .48767 .47883 L p F P
0 g
s
.571 .853 .996 r
.47629 .48174 m .48767 .47883 L .49078 .4804 L p F P
0 g
s
.763 .25 0 r
.22101 .32855 m .22166 .32937 L .21881 .32754 L closepath p F P
0 g
s
.395 .049 .256 r
.51227 .37839 m .51359 .37458 L .50234 .3784 L p F P
0 g
s
.395 .049 .256 r
.50234 .3784 m .50101 .38222 L .51227 .37839 L p F P
0 g
s
.62 .1 0 r
.06012 .37759 m .05951 .37692 L .05573 .37364 L p F P
0 g
s
0 .166 .656 r
.16408 .28182 m .16776 .28529 L .16324 .28188 L p F P
0 g
s
0 .166 .656 r
.16324 .28188 m .15957 .2784 L .16408 .28182 L p F P
0 g
s
0 .167 .657 r
.15864 .2777 m .15957 .2784 L .16324 .28188 L p F P
0 g
s
.57 .935 .801 r
.68379 .41766 m .67815 .42116 L .67581 .42179 L p F P
0 g
s
.348 0 .223 r
.51881 .36935 m .51476 .37134 L .51359 .37458 L p F P
0 g
s
.593 .81 .983 r
.41835 .48465 m .42962 .48199 L .43283 .4842 L p F P
0 g
s
.614 .796 .969 r
.42962 .48199 m .41835 .48465 L .41511 .48238 L p F P
0 g
s
.759 .894 .938 r
.71536 .22435 m .71804 .22662 L .70642 .23316 L p F P
0 g
s
.759 .894 .938 r
.70912 .22809 m .71536 .22435 L p .70642 .23316 L F P
0 g
s
.759 .894 .938 r
.70642 .23316 m .70595 .23283 L .70912 .22809 L p F P
0 g
s
0 .372 .785 r
.12858 .42588 m .12339 .42353 L .12802 .42648 L p F P
0 g
s
0 .372 .785 r
.12802 .42648 m .13232 .42842 L .12858 .42588 L p F P
0 g
s
.682 .97 .773 r
.63352 .28182 m .63204 .28236 L .63692 .27831 L closepath p F P
0 g
s
.771 .98 .911 r
.67784 .24869 m .66914 .25496 L .66762 .25469 L p F P
0 g
s
.251 .217 .624 r
.79952 .26467 m .79606 .27013 L .79357 .26569 L p F P
0 g
s
.251 .217 .624 r
.79357 .26569 m .79694 .26025 L .79952 .26467 L p F P
0 g
s
.727 .371 .374 r
.34709 .40051 m .34768 .40147 L .3467 .40132 L closepath p F P
0 g
s
.358 .719 .987 r
.26373 .47249 m .25947 .47246 L .26625 .4746 L p F P
0 g
s
.358 .719 .987 r
.26625 .4746 m .26724 .47462 L .26373 .47249 L p F P
0 g
s
.158 .602 .934 r
.19946 .4565 m .19653 .45597 L .20213 .45853 L p F P
0 g
s
.158 .602 .934 r
.20213 .45853 m .20309 .45871 L .19946 .4565 L p F P
0 g
s
.584 .843 .994 r
.48756 .47877 m .48767 .47883 L .47629 .48174 L p F P
0 g
s
.584 .843 .994 r
.47629 .48174 m .475 .48101 L .48756 .47877 L p F P
0 g
s
.811 .375 .208 r
.26332 .36379 m .26939 .36629 L .26662 .36206 L p F P
0 g
s
.811 .375 .208 r
.26662 .36206 m .26072 .3595 L .26332 .36379 L p F P
0 g
s
.613 .803 .973 r
.44413 .48147 m .43283 .4842 L .42962 .48199 L p F P
0 g
s
.804 .326 .077 r
.23822 .34302 m .23828 .34312 L .2435 .34593 L p F P
0 g
s
.814 .344 .104 r
.24103 .34731 m .24638 .35008 L .2435 .34593 L p F P
0 g
s
.814 .344 .104 r
.2435 .34593 m .23828 .34312 L .24103 .34731 L p F P
0 g
s
.509 .779 .993 r
.31383 .48108 m .31907 .48042 L .32754 .48202 L p F P
0 g
s
.5 .784 .996 r
.31383 .48108 m .31907 .48042 L .31067 .47912 L closepath p F P
0 g
s
.547 .006 0 r
.19203 .30611 m .19631 .30933 L .19221 .3057 L p F P
0 g
s
.547 .006 0 r
.19221 .3057 m .18801 .30246 L .19203 .30611 L p F P
0 g
s
.66 .328 .401 r
.39363 .40802 m .39457 .40913 L .39329 .40912 L closepath p F P
0 g
s
.012 0 0 r
.57287 .33241 m .57477 .3295 L .57428 .3298 L p F P
0 g
s
0 0 0 r
.57486 .32937 m .57428 .3298 L .57477 .3295 L closepath p F P
0 g
s
.775 .394 .334 r
.30368 .38846 m .31137 .39039 L .30872 .38606 L p F P
0 g
s
.775 .394 .334 r
.30872 .38606 m .30128 .38404 L .30368 .38846 L p F P
0 g
s
.61 .812 .978 r
.45864 .48079 m .44731 .48359 L .44413 .48147 L p F P
0 g
s
.611 .287 .397 r
.42261 .40644 m .42491 .40815 L .42208 .40839 L closepath p F P
0 g
s
.606 .823 .983 r
.47316 .47992 m .4618 .4828 L .45864 .48079 L p F P
0 g
s
.741 .377 .362 r
.32136 .39678 m .31902 .39232 L .32726 .39406 L p F P
0 g
s
.741 .377 .362 r
.32884 .39826 m .32136 .39678 L p .32726 .39406 L F P
0 g
s
.741 .377 .362 r
.32726 .39406 m .32928 .39748 L .32884 .39826 L p F P
0 g
s
0 0 0 r
.58557 .32095 m .57486 .32937 L .57477 .3295 L p F P
0 g
s
.812 .362 .168 r
.25917 .35706 m .26072 .3595 L .25625 .35741 L closepath p F P
0 g
s
.649 .709 .891 r
.74685 .22204 m .75871 .21849 L .76143 .22261 L p F P
0 g
s
.664 .729 .898 r
.75871 .21849 m .74685 .22204 L .74415 .21862 L p F P
0 g
s
.693 .767 .909 r
.7324 .22347 m .74415 .21862 L .74685 .22204 L p F P
0 g
s
.491 .779 .996 r
.32871 .48222 m .32825 .48194 L .32754 .48202 L closepath p F P
0 g
s
0 0 0 r
.58349 .32409 m .58412 .32324 L .57477 .3295 L p F P
0 g
s
0 0 0 r
.57647 .32995 m .58349 .32409 L p .57477 .3295 L F P
0 g
s
0 0 0 r
.57477 .3295 m .57287 .33241 L .57647 .32995 L p F P
0 g
s
0 0 0 r
.57477 .3295 m .58412 .32324 L p .58557 .32095 L F P
0 g
s
0 0 0 r
.77137 .3384 m .77562 .33175 L .77077 .3375 L p F P
0 g
s
0 0 0 r
.76859 .3417 m .77137 .3384 L p .77077 .3375 L F P
0 g
s
0 0 0 r
.77077 .3375 m .76948 .3395 L .76859 .3417 L p F P
0 g
s
.582 .906 .98 r
.57166 .46415 m .56014 .46815 L .55718 .46727 L p F P
0 g
s
.567 .9 .981 r
.54568 .47105 m .55718 .46727 L .56014 .46815 L p F P
0 g
s
.433 .747 .993 r
.27811 .47424 m .26724 .47462 L .26373 .47249 L p F P
0 g
s
.784 .283 0 r
.21994 .33042 m .22474 .3334 L .22166 .32937 L p F P
0 g
s
.784 .283 0 r
.21736 .32692 m .21994 .33042 L p .22166 .32937 L F P
0 g
s
.784 .283 0 r
.22166 .32937 m .21881 .32754 L .21736 .32692 L p F P
0 g
s
.537 .014 0 r
.06018 .37802 m .064 .38135 L .06012 .37759 L p F P
0 g
s
.537 .014 0 r
.06012 .37759 m .0563 .37426 L .06018 .37802 L p F P
0 g
s
.62 .1 0 r
.05573 .37364 m .0563 .37426 L .06012 .37759 L p F P
0 g
s
.443 .103 .292 r
.50029 .38449 m .50101 .38222 L .48941 .38562 L p F P
0 g
s
.443 .103 .292 r
.48941 .38562 m .48887 .38729 L .50029 .38449 L p F P
0 g
s
.231 .641 .958 r
.21339 .46019 m .20309 .45871 L .19946 .4565 L p F P
0 g
s
.774 .367 .28 r
.28732 .3797 m .2848 .37535 L .29165 .37757 L p F P
0 g
s
.774 .367 .28 r
.29359 .38162 m .28732 .3797 L p .29165 .37757 L F P
0 g
s
.774 .367 .28 r
.29165 .37757 m .294 .38126 L .29359 .38162 L p F P
0 g
s
.507 .556 .84 r
.77901 .23139 m .7804 .23153 L .77972 .23287 L closepath p F P
0 g
s
.453 .512 .829 r
.79058 .23342 m .7804 .23153 L .77972 .23287 L p F P
0 g
s
.453 .512 .829 r
.78743 .23886 m .79058 .23342 L p .77972 .23287 L F P
0 g
s
.579 .887 .991 r
.54268 .46999 m .5438 .47042 L .53246 .47403 L p F P
0 g
s
.579 .887 .991 r
.53246 .47403 m .53119 .47355 L .54268 .46999 L p F P
0 g
s
.761 .896 .938 r
.70595 .23283 m .70374 .2313 L .70912 .22809 L closepath p F P
0 g
s
.575 .931 .94 r
.60976 .45127 m .61209 .4515 L .60053 .45639 L p F P
0 g
s
.575 .931 .94 r
.60053 .45639 m .59954 .45628 L .60976 .45127 L p F P
0 g
s
.503 .772 .992 r
.32486 .47965 m .31907 .48042 L .32754 .48202 L p F P
0 g
s
.503 .772 .992 r
.32754 .48202 m .32825 .48194 L .32486 .47965 L p F P
0 g
s
.545 .917 .758 r
.6897 .41383 m .68379 .41766 L .68846 .41427 L closepath p F P
0 g
s
.57 .935 .801 r
.68709 .4146 m .68846 .41427 L .68379 .41766 L p F P
0 g
s
.57 .935 .801 r
.6769 .421 m .68709 .4146 L p .68379 .41766 L F P
0 g
s
.57 .935 .801 r
.67581 .42179 m .6769 .421 L p .68379 .41766 L F P
0 g
s
0 0 .155 r
.78648 .31346 m .78204 .31912 L .78425 .31313 L p F P
0 g
s
0 0 .155 r
.78703 .31197 m .78648 .31346 L p .78425 .31313 L F P
0 g
s
0 0 .155 r
.78425 .31313 m .78748 .30903 L .78703 .31197 L p F P
0 g
s
0 0 0 r
.75921 .3533 m .75837 .35463 L .76123 .3511 L closepath p F P
0 g
s
.706 .784 .913 r
.74415 .21862 m .7324 .22347 L .72971 .22063 L p F P
0 g
s
.329 0 .19 r
.5262 .36581 m .51881 .36935 L .52587 .36663 L closepath p F P
0 g
s
.348 0 .223 r
.5245 .37034 m .52587 .36663 L .51881 .36935 L p F P
0 g
s
.348 0 .223 r
.51359 .37458 m .5245 .37034 L p .51881 .36935 L F P
0 g
s
0 .169 .623 r
.08977 .40177 m .0848 .39831 L .08895 .40148 L p F P
0 g
s
0 .169 .623 r
.09105 .40276 m .08977 .40177 L p .08895 .40148 L F P
0 g
s
0 .169 .623 r
.08895 .40148 m .09366 .40475 L .09105 .40276 L p F P
0 g
s
.733 .389 .398 r
.34509 .40522 m .35002 .40595 L .34768 .40147 L p F P
0 g
s
.733 .389 .398 r
.34768 .40147 m .3467 .40132 L .34509 .40522 L p F P
0 g
s
.677 .146 0 r
.2002 .31203 m .20064 .31251 L .19779 .31038 L closepath p F P
0 g
s
.636 .308 .399 r
.40809 .40852 m .4086 .409 L .40795 .40903 L closepath p F P
0 g
s
.791 .961 .92 r
.68064 .24667 m .67784 .24869 L .67953 .24629 L closepath p F P
0 g
s
.771 .98 .911 r
.67795 .24577 m .67953 .24629 L .67784 .24869 L p F P
0 g
s
.771 .98 .911 r
.66963 .25209 m .67795 .24577 L p .67784 .24869 L F P
0 g
s
.771 .98 .911 r
.66762 .25469 m .66963 .25209 L p .67784 .24869 L F P
0 g
s
.783 .354 .231 r
.27749 .36925 m .27654 .36978 L .2758 .36867 L closepath p F P
0 g
s
0 0 0 r
.76948 .3395 m .76633 .34419 L .76859 .3417 L closepath p F P
0 g
s
.561 .239 .38 r
.46168 .40348 m .4627 .39921 L .45 .40137 L p F P
0 g
s
.561 .239 .38 r
.45 .40137 m .44889 .40557 L .46168 .40348 L p F P
0 g
s
.586 .263 .388 r
.44531 .40601 m .44889 .40557 L .45 .40137 L p F P
0 g
s
0 .304 .736 r
.11106 .4159 m .10822 .41439 L .11263 .41743 L p F P
0 g
s
0 .304 .736 r
.11263 .41743 m .11481 .41859 L .11106 .4159 L p F P
0 g
s
0 0 0 r
.58629 .32039 m .58557 .32095 L .58616 .32055 L closepath p F P
0 g
s
0 0 0 r
.58412 .32324 m .58616 .32055 L .58557 .32095 L p F P
0 g
s
.733 .389 .399 r
.3407 .40457 m .34509 .40522 L .3467 .40132 L p F P
0 g
s
.733 .389 .399 r
.3467 .40132 m .33837 .40009 L .3407 .40457 L p F P
0 g
s
.572 .779 .977 r
.33933 .48009 m .32825 .48194 L .32486 .47965 L p F P
0 g
s
0 0 0 r
.5962 .31231 m .58629 .32039 L .58616 .32055 L p F P
0 g
s
0 0 .241 r
.78859 .3075 m .78748 .30903 L .78782 .3048 L p F P
0 g
s
0 0 .241 r
.78782 .3048 m .79003 .30175 L .78859 .3075 L p F P
0 g
s
.735 .991 .833 r
.64475 .27263 m .64349 .27286 L .64735 .26973 L closepath p F P
0 g
s
0 .186 .666 r
.17219 .2885 m .16776 .28529 L .17156 .28871 L p F P
0 g
s
0 .186 .666 r
.17156 .28871 m .17581 .29176 L .17219 .2885 L p F P
0 g
s
.319 .697 .98 r
.24597 .46827 m .24939 .47029 L p .2351 .46761 L F P
0 g
s
.319 .697 .98 r
.2351 .46761 m .24574 .46819 L .24597 .46827 L p F P
0 g
s
.341 .703 .983 r
.24574 .46819 m .2351 .46761 L .23153 .46548 L p F P
0 g
s
.519 .843 .548 r
.73716 .37708 m .7357 .37836 L .741 .37336 L closepath p F P
0 g
s
.524 .577 .851 r
.7804 .23153 m .77901 .23139 L .77622 .22591 L p F P
0 g
s
.777 .96 .927 r
.69194 .2389 m .68064 .24667 L .67953 .24629 L p F P
0 g
s
.614 .665 .876 r
.76773 .22159 m .76143 .22261 L .75871 .21849 L p F P
0 g
s
.59 .948 .878 r
.65692 .43244 m .65236 .43489 L .64964 .4351 L p F P
0 g
s
.663 .348 .43 r
.40795 .40903 m .39457 .40913 L .39756 .41345 L p F P
0 g
s
.667 .349 .426 r
.39216 .41343 m .39756 .41345 L .39457 .40913 L p F P
0 g
s
.667 .349 .426 r
.39457 .40913 m .39329 .40912 L .39216 .41343 L p F P
0 g
s
.681 .363 .43 r
.38465 .41321 m .39216 .41343 L .39329 .40912 L p F P
0 g
s
.681 .363 .43 r
.39329 .40912 m .382 .40879 L .38465 .41321 L p F P
0 g
s
.802 .336 .125 r
.24925 .35425 m .25501 .35687 L .25198 .35276 L p F P
0 g
s
.802 .336 .125 r
.25198 .35276 m .24638 .35008 L .24925 .35425 L p F P
0 g
s
.644 .33 .425 r
.4086 .409 m .40795 .40903 L .40689 .41337 L p F P
0 g
s
.663 .348 .43 r
.39756 .41345 m .40689 .41337 L .40795 .40903 L p F P
0 g
s
0 0 0 r
.58616 .32055 m .59518 .31384 L p .5962 .31231 L F P
0 g
s
0 0 0 r
.59495 .31411 m .59518 .31384 L .58616 .32055 L p F P
0 g
s
0 0 0 r
.5864 .32153 m .59495 .31411 L p .58616 .32055 L F P
0 g
s
0 0 0 r
.58616 .32055 m .58412 .32324 L .5864 .32153 L p F P
0 g
s
.711 .186 0 r
.1997 .31322 m .20404 .3164 L .20064 .31251 L p F P
0 g
s
.711 .186 0 r
.19657 .30956 m .1997 .31322 L p .20064 .31251 L F P
0 g
s
.711 .186 0 r
.20064 .31251 m .19779 .31038 L .19657 .30956 L p F P
0 g
s
.642 .33 .427 r
.42208 .40839 m .4086 .409 L .4121 .41316 L p F P
0 g
s
.644 .33 .425 r
.40689 .41337 m .4121 .41316 L .4086 .409 L p F P
0 g
s
.149 .063 .494 r
.79415 .28033 m .79436 .28003 L .79488 .28531 L closepath p F P
0 g
s
.58 .941 .91 r
.63527 .44092 m .63805 .44095 L .62647 .44648 L p F P
0 g
s
.58 .941 .91 r
.63177 .4426 m .63527 .44092 L p .62647 .44648 L F P
0 g
s
.58 .941 .91 r
.62647 .44648 m .6249 .44647 L .63177 .4426 L p F P
0 g
s
.328 .314 .691 r
.79889 .25711 m .79694 .26025 L .79324 .2562 L p F P
0 g
s
.328 .314 .691 r
.79746 .25157 m .79889 .25711 L p .79324 .2562 L F P
0 g
s
.328 .314 .691 r
.79324 .2562 m .79661 .25074 L .79746 .25157 L p F P
0 g
s
.786 .353 .223 r
.27211 .37055 m .26939 .36629 L .2758 .36867 L p F P
0 g
s
.786 .353 .223 r
.27377 .37115 m .27211 .37055 L p .2758 .36867 L F P
0 g
s
.786 .353 .223 r
.2758 .36867 m .27654 .36978 L .27377 .37115 L p F P
0 g
s
.565 .926 .762 r
.69877 .40773 m .6897 .41383 L .68846 .41427 L p F P
0 g
s
0 0 .329 r
.794 .2962 m .79003 .30175 L .7908 .29623 L p F P
0 g
s
0 0 .329 r
.7908 .29623 m .79481 .29065 L .794 .2962 L p F P
0 g
s
0 0 0 r
.59773 .31108 m .5962 .31231 L .59741 .31142 L closepath p F P
0 g
s
0 0 0 r
.59518 .31384 m .59741 .31142 L .5962 .31231 L p F P
0 g
s
.528 .003 0 r
.18008 .29548 m .17943 .29487 L .17581 .29176 L p F P
0 g
s
.689 .365 .423 r
.3768 .41284 m .38465 .41321 L .382 .40879 L p F P
0 g
s
.689 .365 .423 r
.382 .40879 m .37802 .40861 L .3768 .41284 L p F P
0 g
s
.592 .946 .905 r
.63934 .44095 m .63805 .44095 L .64582 .43707 L closepath p F P
0 g
s
.5 0 0 r
.06812 .38505 m .07202 .38834 L .0679 .38464 L p F P
0 g
s
.5 0 0 r
.0679 .38464 m .064 .38135 L .06812 .38505 L p F P
0 g
s
.58 .897 .986 r
.55491 .46651 m .55718 .46727 L .54568 .47105 L p F P
0 g
s
.58 .897 .986 r
.54568 .47105 m .5438 .47042 L .55491 .46651 L p F P
0 g
s
0 .214 .66 r
.09821 .40805 m .09742 .40755 L .09366 .40475 L p F P
0 g
s
0 0 0 r
.60649 .30378 m .59773 .31108 L .59741 .31142 L p F P
0 g
s
.061 .001 .468 r
.79834 .27993 m .79762 .27489 L .79436 .28003 L p F P
0 g
s
.061 .001 .468 r
.79489 .28536 m .79834 .27993 L p .79436 .28003 L F P
0 g
s
.061 .001 .468 r
.79436 .28003 m .79488 .28531 L .79489 .28536 L p F P
0 g
s
.779 .276 0 r
.22784 .33745 m .23296 .34033 L .22973 .33632 L p F P
0 g
s
.779 .276 0 r
.22973 .33632 m .22474 .3334 L .22784 .33745 L p F P
0 g
s
.594 .779 .968 r
.35382 .48031 m .3427 .48245 L .33933 .48009 L p F P
0 g
s
.494 .167 .34 r
.48708 .39371 m .48818 .38959 L .47623 .39259 L p F P
0 g
s
.494 .167 .34 r
.47623 .39259 m .47508 .39668 L .48708 .39371 L p F P
0 g
s
.259 .668 .966 r
.21728 .46237 m .2195 .46258 L .22568 .46495 L p F P
0 g
s
.279 .673 .971 r
.22795 .46329 m .2195 .46258 L .22568 .46495 L p F P
0 g
s
.279 .673 .971 r
.22568 .46495 m .23153 .46548 L .22795 .46329 L p F P
0 g
s
.597 .84 .99 r
.48456 .47688 m .48756 .47877 L .475 .48101 L p F P
0 g
s
.597 .84 .99 r
.475 .48101 m .47316 .47992 L .48456 .47688 L p F P
0 g
s
.698 .375 .426 r
.37297 .41259 m .3768 .41284 L .37802 .40861 L p F P
0 g
s
.698 .375 .426 r
.37802 .40861 m .37052 .40811 L .37297 .41259 L p F P
0 g
s
0 0 0 r
.76651 .34524 m .76123 .3511 L .76633 .34419 L p F P
0 g
s
0 0 0 r
.76734 .34411 m .76651 .34524 L p .76633 .34419 L F P
0 g
s
0 0 0 r
.76633 .34419 m .76859 .3417 L .76734 .34411 L p F P
0 g
s
0 .481 .86 r
.14992 .43723 m .15199 .43791 L .15702 .4407 L p F P
0 g
s
.026 .503 .878 r
.16022 .44042 m .15199 .43791 L .15702 .4407 L p F P
0 g
s
.026 .503 .878 r
.15702 .4407 m .16391 .44281 L .16022 .44042 L p F P
0 g
s
.16 .598 .935 r
.191 .45337 m .18533 .45225 L .18167 .45 L p F P
0 g
s
.145 .593 .929 r
.18533 .45225 m .191 .45337 L .19653 .45597 L p F P
0 g
s
.451 .759 .995 r
.2816 .47639 m .29253 .47566 L .29599 .47783 L p F P
0 g
s
.48 .759 .992 r
.29253 .47566 m .2816 .47639 L .27811 .47424 L p F P
0 g
s
.499 .547 .837 r
.79099 .23271 m .79058 .23342 L .7804 .23153 L p F P
0 g
s
.499 .547 .837 r
.78849 .22689 m .79099 .23271 L p .7804 .23153 L F P
0 g
s
.499 .547 .837 r
.7804 .23153 m .78305 .22623 L .78849 .22689 L p F P
0 g
s
.524 .577 .851 r
.77622 .22591 m .78305 .22623 L .7804 .23153 L p F P
0 g
s
.773 .405 .36 r
.31351 .3949 m .32136 .39678 L .31902 .39232 L p F P
0 g
s
.773 .405 .36 r
.31158 .39078 m .31351 .3949 L p .31902 .39232 L F P
0 g
s
.773 .405 .36 r
.31902 .39232 m .31177 .39048 L .31158 .39078 L p F P
0 g
s
.07 .541 .898 r
.1676 .44513 m .17062 .44592 L .17592 .44861 L p F P
0 g
s
.101 .559 .912 r
.17801 .44768 m .17062 .44592 L .17592 .44861 L p F P
0 g
s
.101 .559 .912 r
.17592 .44861 m .18167 .45 L .17801 .44768 L p F P
0 g
s
.619 .308 .421 r
.42491 .40815 m .42208 .40839 L .42106 .41275 L p F P
0 g
s
.642 .33 .427 r
.4121 .41316 m .42106 .41275 L .42208 .40839 L p F P
0 g
s
0 0 0 r
.60916 .30157 m .60649 .30378 L .60853 .30211 L closepath p F P
0 g
s
0 0 0 r
.60522 .305 m .6064 .30397 L p .60649 .30378 L F P
0 g
s
0 0 0 r
.59741 .31142 m .60522 .305 L p .60649 .30378 L F P
0 g
s
.768 .994 .875 r
.65608 .26354 m .65496 .26355 L .65818 .26101 L closepath p F P
0 g
s
.567 .938 .845 r
.66393 .42854 m .65692 .43244 L .66265 .42874 L closepath p F P
0 g
s
.59 .948 .878 r
.66124 .42883 m .66265 .42874 L .65692 .43244 L p F P
0 g
s
.59 .948 .878 r
.64964 .4351 m .66124 .42883 L p .65692 .43244 L F P
0 g
s
.732 .86 .941 r
.72967 .22065 m .71804 .22662 L .71536 .22435 L p F P
0 g
s
0 0 0 r
.61661 .2953 m .60916 .30157 L .60853 .30211 L p F P
0 g
s
0 .442 .839 r
.14221 .4322 m .13481 .42943 L .13959 .43232 L p F P
0 g
s
0 .442 .839 r
.14353 .43301 m .14221 .4322 L p .13959 .43232 L F P
0 g
s
0 .442 .839 r
.13959 .43232 m .14621 .43481 L .14353 .43301 L p F P
0 g
s
0 .415 .816 r
.13232 .42842 m .13481 .42943 L .13959 .43232 L p F P
0 g
s
.793 .413 .335 r
.29653 .38634 m .30368 .38846 L .30128 .38404 L p F P
0 g
s
.793 .413 .335 r
.30128 .38404 m .29433 .38186 L .29653 .38634 L p F P
0 g
s
.619 .308 .42 r
.43572 .40724 m .42491 .40815 L .42922 .41206 L p F P
0 g
s
.619 .308 .421 r
.42106 .41275 m .42922 .41206 L .42491 .40815 L p F P
0 g
s
.588 .787 .975 r
.35716 .48274 m .36832 .48035 L .37163 .48285 L p F P
0 g
s
.611 .777 .96 r
.36832 .48035 m .35716 .48274 L .35382 .48031 L p F P
0 g
s
.752 .409 .401 r
.33187 .40302 m .3407 .40457 L .33837 .40009 L p F P
0 g
s
.752 .409 .401 r
.33837 .40009 m .3298 .39846 L .33187 .40302 L p F P
0 g
s
.524 .198 .357 r
.46296 .3983 m .46584 .39855 L .4627 .39921 L closepath p F P
0 g
s
.71 .381 .419 r
.36223 .41166 m .37297 .41259 L .37052 .40811 L p F P
0 g
s
.71 .381 .419 r
.36125 .40963 m .36223 .41166 L p .37052 .40811 L F P
0 g
s
.71 .381 .419 r
.37052 .40811 m .36199 .40733 L .36125 .40963 L p F P
0 g
s
.528 .003 0 r
.17581 .29176 m .17617 .29211 L .18008 .29548 L p F P
0 g
s
.54 .015 0 r
.18 .2958 m .18394 .29916 L .18008 .29548 L p F P
0 g
s
.54 .015 0 r
.18008 .29548 m .17617 .29211 L .18 .2958 L p F P
0 g
s
.368 .725 .989 r
.24939 .47029 m .25264 .47032 L .25947 .47246 L p F P
0 g
s
.378 .723 .989 r
.26021 .47028 m .25264 .47032 L .25947 .47246 L p F P
0 g
s
.378 .723 .989 r
.25947 .47246 m .26373 .47249 L .26021 .47028 L p F P
0 g
s
.374 .374 .731 r
.79704 .25003 m .79661 .25074 L .79139 .2472 L p F P
0 g
s
.374 .374 .731 r
.79139 .2472 m .7945 .24203 L .79704 .25003 L p F P
0 g
s
.584 .914 .974 r
.58321 .45993 m .58333 .45996 L .57266 .4644 L p F P
0 g
s
.584 .914 .974 r
.57266 .4644 m .57166 .46415 L .58321 .45993 L p F P
0 g
s
0 .214 .66 r
.09366 .40475 m .09394 .40494 L .09821 .40805 L p F P
0 g
s
0 .279 .721 r
.09963 .40818 m .10388 .4113 L .09821 .40805 L p F P
0 g
s
0 .279 .721 r
.09821 .40805 m .09394 .40494 L .09963 .40818 L p F P
0 g
s
.519 .785 .993 r
.32146 .47721 m .32486 .47965 L .31907 .48042 L p F P
0 g
s
.519 .785 .993 r
.31041 .47895 m .32146 .47721 L p .31907 .48042 L F P
0 g
s
.519 .785 .993 r
.31907 .48042 m .31067 .47912 L .31041 .47895 L p F P
0 g
s
.592 .93 .956 r
.60925 .45118 m .60976 .45127 L .59954 .45628 L p F P
0 g
s
.592 .93 .956 r
.59954 .45628 m .59767 .45596 L .60925 .45118 L p F P
0 g
s
.702 .169 0 r
.2075 .32028 m .21209 .32337 L .20854 .31951 L p F P
0 g
s
.702 .169 0 r
.20854 .31951 m .20404 .3164 L .2075 .32028 L p F P
0 g
s
.711 .175 0 r
.21881 .32754 m .21736 .32692 L .21686 .32638 L closepath p F P
0 g
s
.583 .923 .962 r
.59479 .45539 m .59767 .45596 L .58611 .46049 L p F P
0 g
s
.583 .923 .962 r
.58442 .45946 m .59479 .45539 L p .58611 .46049 L F P
0 g
s
.583 .923 .962 r
.58611 .46049 m .58333 .45996 L .58442 .45946 L p F P
0 g
s
.453 .122 .313 r
.49979 .38617 m .50029 .38449 L .48887 .38729 L p F P
0 g
s
.453 .122 .313 r
.48887 .38729 m .48818 .38959 L .49979 .38617 L p F P
0 g
s
0 0 0 r
.59593 .31322 m .59518 .31384 L .59741 .31142 L p F P
0 g
s
0 0 0 r
.59741 .31142 m .60522 .305 L .59593 .31322 L p F P
0 g
s
.556 .892 .645 r
.6206 .29196 m .61661 .2953 L .61954 .29265 L closepath p F P
0 g
s
0 0 0 r
.61786 .29378 m .61954 .29265 L .61661 .2953 L p F P
0 g
s
0 0 0 r
.61445 .29679 m .61786 .29378 L p .61661 .2953 L F P
0 g
s
0 0 0 r
.60853 .30211 m .61445 .29679 L p .61661 .2953 L F P
0 g
s
.593 .88 .992 r
.54268 .46999 m .53119 .47355 L .52816 .47223 L p F P
0 g
s
.582 .876 .994 r
.51669 .47561 m .52816 .47223 L .53119 .47355 L p F P
0 g
s
.811 .393 .254 r
.27654 .36978 m .27834 .37299 L .27377 .37115 L closepath p F P
0 g
s
.284 0 .17 r
.53648 .36201 m .53765 .35911 L .5262 .36581 L p F P
0 g
s
.284 0 .17 r
.5262 .36581 m .52587 .36663 L .53648 .36201 L p F P
0 g
s
.788 .936 .927 r
.69217 .23874 m .69194 .2389 L .69207 .2387 L closepath p F P
0 g
s
.777 .96 .927 r
.68948 .23745 m .69207 .2387 L .69194 .2389 L p F P
0 g
s
.777 .96 .927 r
.68201 .24285 m .68948 .23745 L p .69194 .2389 L F P
0 g
s
.777 .96 .927 r
.67953 .24629 m .68201 .24285 L p .69194 .2389 L F P
0 g
s
.782 .935 .93 r
.70106 .22957 m .70374 .2313 L .69217 .23874 L p F P
0 g
s
.782 .935 .93 r
.69584 .23313 m .70106 .22957 L p .69217 .23874 L F P
0 g
s
.782 .935 .93 r
.69217 .23874 m .69207 .2387 L .69584 .23313 L p F P
0 g
s
.432 .45 .778 r
.79137 .23366 m .79058 .23342 L .78743 .23886 L p F P
0 g
s
.432 .45 .778 r
.78743 .23886 m .79434 .24156 L .79137 .23366 L p F P
0 g
s
.821 .383 .2 r
.25754 .36118 m .26332 .36379 L .26072 .3595 L p F P
0 g
s
.821 .383 .2 r
.25548 .35755 m .25754 .36118 L p .26072 .3595 L F P
0 g
s
.821 .383 .2 r
.26072 .3595 m .25625 .35741 L .25548 .35755 L p F P
0 g
s
.558 .893 .646 r
.62672 .28682 m .6206 .29196 L .61954 .29265 L p F P
0 g
s
.536 .903 .712 r
.70124 .406 m .69877 .40773 L .70068 .40625 L closepath p F P
0 g
s
.565 .926 .762 r
.69867 .40692 m .70068 .40625 L .69877 .40773 L p F P
0 g
s
.565 .926 .762 r
.69309 .4107 m .69867 .40692 L p .69877 .40773 L F P
0 g
s
.565 .926 .762 r
.68846 .41427 m .69309 .4107 L p .69877 .40773 L F P
0 g
s
.172 .606 .939 r
.19583 .45424 m .191 .45337 L .19653 .45597 L p F P
0 g
s
.172 .606 .939 r
.19653 .45597 m .19946 .4565 L .19583 .45424 L p F P
0 g
s
0 .1 .567 r
.07267 .38886 m .07202 .38834 L .07599 .39159 L p F P
0 g
s
0 .1 .567 r
.07599 .39159 m .07645 .39195 L .07267 .38886 L p F P
0 g
s
.784 .938 .93 r
.69207 .2387 m .68948 .23745 L .69584 .23313 L closepath p F P
0 g
s
.6 .788 .97 r
.37163 .48285 m .38283 .48027 L .38612 .48282 L p F P
0 g
s
.624 .774 .953 r
.38283 .48027 m .37163 .48285 L .36832 .48035 L p F P
0 g
s
0 0 .045 r
.7836 .31968 m .77924 .3253 L .78204 .31912 L p F P
0 g
s
0 0 .045 r
.78204 .31912 m .78648 .31346 L .7836 .31968 L p F P
0 g
s
.084 .546 .905 r
.17062 .44592 m .1676 .44513 L .16391 .44281 L p F P
0 g
s
0 .346 .767 r
.11481 .41859 m .11885 .42054 L .12339 .42353 L p F P
0 g
s
0 .352 .777 r
.11885 .42054 m .11481 .41859 L .11106 .4159 L p F P
0 g
s
.805 .323 .057 r
.23822 .34302 m .23828 .34312 L .23805 .34299 L closepath p F P
0 g
s
.784 .982 .903 r
.66762 .25469 m .66644 .25449 L .66963 .25209 L closepath p F P
0 g
s
.805 .403 .291 r
.28067 .3774 m .28732 .3797 L .2848 .37535 L p F P
0 g
s
.805 .403 .291 r
.2848 .37535 m .27834 .37299 L .28067 .3774 L p F P
0 g
s
.652 .954 .74 r
.63204 .28236 m .62672 .28682 L .63048 .28306 L closepath p F P
0 g
s
.558 .893 .646 r
.62931 .28361 m .63048 .28306 L .62672 .28682 L p F P
0 g
s
.558 .893 .646 r
.6237 .28858 m .62931 .28361 L p .62672 .28682 L F P
0 g
s
.558 .893 .646 r
.61954 .29265 m .6237 .28858 L p .62672 .28682 L F P
0 g
s
.365 .726 .988 r
.24939 .47029 m .25264 .47032 L .24597 .46827 L closepath p F P
0 g
s
.818 .348 .095 r
.23589 .34445 m .24103 .34731 L .23828 .34312 L p F P
0 g
s
.818 .348 .095 r
.23454 .34233 m .23589 .34445 L p .23828 .34312 L F P
0 g
s
.818 .348 .095 r
.23828 .34312 m .23805 .34299 L .23454 .34233 L p F P
0 g
s
.558 .913 .717 r
.71159 .39845 m .70124 .406 L .70068 .40625 L p F P
0 g
s
.262 .668 .967 r
.21728 .46237 m .2195 .46258 L .21413 .46051 L closepath p F P
0 g
s
0 .377 .794 r
.12485 .42325 m .11885 .42054 L .12339 .42353 L p F P
0 g
s
0 .377 .794 r
.12339 .42353 m .12858 .42588 L .12485 .42325 L p F P
0 g
s
0 0 0 r
.76076 .35237 m .76651 .34524 L .76123 .3511 L p F P
0 g
s
0 0 0 r
.75752 .35598 m .76076 .35237 L p .76123 .3511 L F P
0 g
s
0 0 0 r
.76123 .3511 m .75837 .35463 L .75752 .35598 L p F P
0 g
s
.776 .278 .017 r
.23805 .34299 m .23454 .34233 L .23296 .34033 L closepath p F P
0 g
s
.499 .769 .992 r
.29599 .47783 m .30233 .47715 L .31006 .47899 L p F P
0 g
s
.52 .776 .99 r
.30233 .47715 m .29599 .47783 L .29253 .47566 L p F P
0 g
s
.715 .386 .421 r
.36199 .40733 m .36125 .40963 L .35997 .40713 L closepath p F P
0 g
s
.647 .952 .739 r
.63692 .27831 m .63204 .28236 L .63048 .28306 L p F P
0 g
s
.755 .393 .369 r
.32928 .39748 m .3298 .39846 L .32884 .39826 L closepath p F P
0 g
s
.631 .773 .948 r
.39735 .48008 m .38612 .48282 L .38283 .48027 L p F P
0 g
s
.608 .789 .968 r
.38612 .48282 m .39735 .48008 L .40061 .48265 L p F P
0 g
s
.593 .869 .994 r
.52816 .47223 m .51669 .47561 L .51363 .47415 L p F P
0 g
s
.582 .866 .995 r
.50219 .47736 m .51363 .47415 L .51669 .47561 L p F P
0 g
s
.535 .222 .383 r
.46584 .39855 m .4627 .39921 L .46168 .40348 L p F P
0 g
s
.788 .962 .92 r
.67953 .24629 m .67795 .24577 L .68201 .24285 L closepath p F P
0 g
s
0 .139 .6 r
.07645 .39195 m .08072 .39511 L .0848 .39831 L p F P
0 g
s
0 .147 .613 r
.08072 .39511 m .07645 .39195 L .07267 .38886 L p F P
0 g
s
.593 .283 .413 r
.44531 .40601 m .43572 .40724 L .43473 .4116 L p F P
0 g
s
.619 .308 .42 r
.42922 .41206 m .43473 .4116 L .43572 .40724 L p F P
0 g
s
.005 .487 .868 r
.15199 .43791 m .14992 .43723 L .14621 .43481 L p F P
0 g
s
.711 .385 .424 r
.35208 .41054 m .35002 .40595 L .35997 .40713 L p F P
0 g
s
.711 .385 .424 r
.36067 .4115 m .35208 .41054 L p .35997 .40713 L F P
0 g
s
.711 .385 .424 r
.35997 .40713 m .36125 .40963 L .36067 .4115 L p F P
0 g
s
0 .421 .825 r
.13481 .42943 m .13232 .42842 L .12858 .42588 L p F P
0 g
s
.722 .987 .811 r
.64349 .27286 m .63692 .27831 L .64137 .2734 L closepath p F P
0 g
s
.647 .952 .739 r
.64078 .27356 m .64137 .2734 L .63692 .27831 L p F P
0 g
s
.647 .952 .739 r
.63305 .28033 m .64078 .27356 L p .63692 .27831 L F P
0 g
s
.647 .952 .739 r
.63048 .28306 m .63305 .28033 L p .63692 .27831 L F P
0 g
s
.538 .004 0 r
.18791 .30283 m .19203 .30611 L .18801 .30246 L p F P
0 g
s
.538 .004 0 r
.18801 .30246 m .18394 .29916 L .18791 .30283 L p F P
0 g
s
0 0 0 r
.74755 .36681 m .74709 .36729 L .74867 .36565 L closepath p F P
0 g
s
.589 .947 .847 r
.67285 .42221 m .67551 .42184 L .66393 .42854 L p F P
0 g
s
.589 .947 .847 r
.66827 .42488 m .67285 .42221 L p .66393 .42854 L F P
0 g
s
.589 .947 .847 r
.66393 .42854 m .66265 .42874 L .66827 .42488 L p F P
0 g
s
0 0 0 r
.75837 .35463 m .75534 .35825 L .75752 .35598 L closepath p F P
0 g
s
.186 .132 .559 r
.80112 .26942 m .79762 .27489 L .79606 .27013 L p F P
0 g
s
.186 .132 .559 r
.79606 .27013 m .79952 .26467 L .80112 .26942 L p F P
0 g
s
.575 .026 0 r
.19779 .31038 m .19657 .30956 L .19631 .30933 L closepath p F P
0 g
s
.613 .791 .967 r
.40061 .48265 m .41187 .47982 L .41511 .48238 L p F P
0 g
s
.634 .774 .947 r
.41187 .47982 m .40061 .48265 L .39735 .48008 L p F P
0 g
s
.546 .58 .839 r
.78305 .22623 m .77622 .22591 L .77345 .22081 L p F P
0 g
s
.293 0 .193 r
.53507 .36565 m .53648 .36201 L .52587 .36663 L p F P
0 g
s
.293 0 .193 r
.52587 .36663 m .5245 .37034 L .53507 .36565 L p F P
0 g
s
.703 .165 0 r
.21371 .32515 m .21209 .32337 L .21686 .32638 L p F P
0 g
s
.703 .165 0 r
.21686 .32638 m .21736 .32692 L .21371 .32515 L p F P
0 g
s
.59 .937 .938 r
.62085 .44606 m .62367 .44636 L .61209 .4515 L p F P
0 g
s
.59 .937 .938 r
.61304 .44954 m .62085 .44606 L p .61209 .4515 L F P
0 g
s
.59 .937 .938 r
.61209 .4515 m .60976 .45127 L .61304 .44954 L p F P
0 g
s
.711 .984 .812 r
.64735 .26973 m .64349 .27286 L .64137 .2734 L p F P
0 g
s
.596 .857 .993 r
.5116 .47304 m .51363 .47415 L .50219 .47736 L p F P
0 g
s
.596 .857 .993 r
.50219 .47736 m .49971 .47605 L .5116 .47304 L p F P
0 g
s
.582 .857 .995 r
.49971 .47605 m .50219 .47736 L p .48767 .47883 L F P
0 g
s
.351 .008 .236 r
.52322 .37399 m .5245 .37034 L .51359 .37458 L p F P
0 g
s
.351 .008 .236 r
.52228 .37446 m .52322 .37399 L p .51359 .37458 L F P
0 g
s
.351 .008 .236 r
.51359 .37458 m .51227 .37839 L .52228 .37446 L p F P
0 g
s
.479 .823 .537 r
.60853 .30211 m .6064 .30397 L .61445 .29679 L closepath p F P
0 g
s
.199 0 .098 r
.53794 .35845 m .53765 .35911 L .54037 .35724 L closepath p F P
0 g
s
.614 .665 .876 r
.77092 .21644 m .76773 .22159 L p .75871 .21849 L F P
0 g
s
.589 .647 .876 r
.76773 .22159 m .77092 .21644 L .77345 .22081 L closepath p F P
0 g
s
.614 .796 .969 r
.41511 .48238 m .4264 .47949 L .42962 .48199 L p F P
0 g
s
.635 .778 .949 r
.4264 .47949 m .41511 .48238 L .41187 .47982 L p F P
0 g
s
.482 .77 .995 r
.31067 .47912 m .31041 .47895 L .31006 .47899 L closepath p F P
0 g
s
0 0 0 r
.7786 .3261 m .77832 .32698 L .77924 .3253 L closepath p F P
0 g
s
.535 .215 .373 r
.47508 .39668 m .4743 .39976 L .46584 .39855 L closepath p F P
0 g
s
.535 .222 .383 r
.47403 .40091 m .4743 .39976 L .46584 .39855 L p F P
0 g
s
.535 .222 .383 r
.46168 .40348 m .47403 .40091 L p .46584 .39855 L F P
0 g
s
.766 .996 .86 r
.65496 .26355 m .64735 .26973 L .65229 .26372 L closepath p F P
0 g
s
.711 .984 .812 r
.65225 .26372 m .65229 .26372 L .64735 .26973 L p F P
0 g
s
.711 .984 .812 r
.64256 .27203 m .65225 .26372 L p .64735 .26973 L F P
0 g
s
.711 .984 .812 r
.64137 .2734 m .64256 .27203 L p .64735 .26973 L F P
0 g
s
.763 .393 .353 r
.31177 .39048 m .31158 .39078 L .31137 .39039 L closepath p F P
0 g
s
0 0 0 r
.75436 .35969 m .74867 .36565 L .75534 .35825 L p F P
0 g
s
0 0 0 r
.7561 .35775 m .75436 .35969 L p .75534 .35825 L F P
0 g
s
0 0 0 r
.75534 .35825 m .75752 .35598 L .7561 .35775 L p F P
0 g
s
.809 .382 .232 r
.26585 .36811 m .27211 .37055 L .26939 .36629 L p F P
0 g
s
.809 .382 .232 r
.26939 .36629 m .26332 .36379 L .26585 .36811 L p F P
0 g
s
.596 .911 .979 r
.58321 .45993 m .57166 .46415 L .56872 .46327 L p F P
0 g
s
.582 .906 .98 r
.55718 .46727 m .56872 .46327 L .57166 .46415 L p F P
0 g
s
.492 .763 .991 r
.30698 .4766 m .30233 .47715 L .31006 .47899 L p F P
0 g
s
.492 .763 .991 r
.31006 .47899 m .31041 .47895 L .30698 .4766 L p F P
0 g
s
.664 .729 .898 r
.74415 .21862 m .756 .21461 L .75871 .21849 L p F P
0 g
s
.678 .747 .903 r
.756 .21461 m .74415 .21862 L .74146 .21538 L p F P
0 g
s
.706 .784 .913 r
.72971 .22063 m .74146 .21538 L .74415 .21862 L p F P
0 g
s
.795 .397 .3 r
.294 .38126 m .29433 .38186 L .29359 .38162 L closepath p F P
0 g
s
.759 .411 .394 r
.32705 .40201 m .33187 .40302 L .3298 .39846 L p F P
0 g
s
.759 .411 .394 r
.3298 .39846 m .32884 .39826 L .32705 .40201 L p F P
0 g
s
.526 .884 .661 r
.71276 .39756 m .71159 .39845 L .71248 .39772 L closepath p F P
0 g
s
.558 .913 .717 r
.71023 .39869 m .71248 .39772 L .71159 .39845 L p F P
0 g
s
.558 .913 .717 r
.70696 .40109 m .71023 .39869 L p .71159 .39845 L F P
0 g
s
.558 .913 .717 r
.70068 .40625 m .70696 .40109 L p .71159 .39845 L F P
0 g
s
.764 .393 .352 r
.30594 .39293 m .30368 .38846 L .31137 .39039 L p F P
0 g
s
.764 .393 .352 r
.30955 .39383 m .30594 .39293 L p .31137 .39039 L F P
0 g
s
.764 .393 .352 r
.31137 .39039 m .31158 .39078 L .30955 .39383 L p F P
0 g
s
.613 .803 .973 r
.42962 .48199 m .44094 .47907 L .44413 .48147 L p F P
0 g
s
.632 .784 .955 r
.44094 .47907 m .42962 .48199 L .4264 .47949 L p F P
0 g
s
.599 .948 .91 r
.64582 .43707 m .63805 .44095 L .63527 .44092 L p F P
0 g
s
.582 .857 .995 r
.48767 .47883 m .48911 .47844 L .49971 .47605 L p F P
0 g
s
.6 .841 .99 r
.48767 .47883 m .48911 .47844 L .48756 .47877 L closepath p F P
0 g
s
.814 .351 .125 r
.24375 .35153 m .24925 .35425 L .24638 .35008 L p F P
0 g
s
.814 .351 .125 r
.24638 .35008 m .24103 .34731 L .24375 .35153 L p F P
0 g
s
0 0 .23 r
.79252 .30196 m .78859 .3075 L .79003 .30175 L p F P
0 g
s
0 0 .23 r
.79003 .30175 m .794 .2962 L .79252 .30196 L p F P
0 g
s
.549 .896 .666 r
.72269 .38969 m .71276 .39756 L .71248 .39772 L p F P
0 g
s
.112 0 .023 r
.5498 .35002 m .54911 .35142 L .55421 .34757 L closepath p F P
0 g
s
.567 .774 .976 r
.32146 .47721 m .31041 .47895 L .30698 .4766 L p F P
0 g
s
.407 .07 .278 r
.51174 .38006 m .51227 .37839 L .50101 .38222 L p F P
0 g
s
.407 .07 .278 r
.50101 .38222 m .50029 .38449 L .51174 .38006 L p F P
0 g
s
0 .179 .639 r
.0857 .39856 m .08977 .40177 L .0848 .39831 L p F P
0 g
s
0 .179 .639 r
.0848 .39831 m .08072 .39511 L .0857 .39856 L p F P
0 g
s
0 .31 .746 r
.1073 .41313 m .10388 .4113 L .10822 .41439 L p F P
0 g
s
0 .31 .746 r
.10822 .41439 m .11106 .4159 L .1073 .41313 L p F P
0 g
s
.61 .812 .978 r
.44413 .48147 m .45547 .47852 L .45864 .48079 L p F P
0 g
s
.628 .794 .962 r
.45547 .47852 m .44413 .48147 L .44094 .47907 L p F P
0 g
s
.754 .405 .392 r
.3235 .40131 m .32705 .40201 L .32884 .39826 L p F P
0 g
s
.754 .405 .392 r
.32884 .39826 m .32136 .39678 L .3235 .40131 L p F P
0 g
s
.787 .286 0 r
.21994 .33042 m .21736 .32692 L .21371 .32515 L p F P
0 g
s
.606 .836 .987 r
.48911 .47844 m .48756 .47877 L .48456 .47688 L p F P
0 g
s
.617 .82 .978 r
.48456 .47688 m .47316 .47992 L .47001 .47781 L p F P
0 g
s
.606 .823 .983 r
.45864 .48079 m .47001 .47781 L .47316 .47992 L p F P
0 g
s
.623 .806 .97 r
.47001 .47781 m .45864 .48079 L .45547 .47852 L p F P
0 g
s
.603 .944 .777 r
.70068 .40625 m .69867 .40692 L .70696 .40109 L closepath p F P
0 g
s
.318 .692 .979 r
.22436 .46102 m .22795 .46329 L .2195 .46258 L p F P
0 g
s
.318 .692 .979 r
.21367 .46022 m .22436 .46102 L p .2195 .46258 L F P
0 g
s
.318 .692 .979 r
.2195 .46258 m .21413 .46051 L .21367 .46022 L p F P
0 g
s
.605 .95 .814 r
.68846 .41427 m .68709 .4146 L .69309 .4107 L closepath p F P
0 g
s
.601 .943 .933 r
.6249 .44647 m .62367 .44636 L .63177 .4426 L closepath p F P
0 g
s
.759 .906 .941 r
.70912 .22809 m .70374 .2313 L .70106 .22957 L p F P
0 g
s
.753 .994 .863 r
.65818 .26101 m .65496 .26355 L .65229 .26372 L p F P
0 g
s
.781 .415 .363 r
.31158 .39078 m .31351 .3949 L .30955 .39383 L closepath p F P
0 g
s
.117 .039 .483 r
.79488 .28531 m .79489 .28536 L .79489 .28536 L closepath p F P
0 g
s
.614 .665 .876 r
.75871 .21849 m .7707 .21606 L .77092 .21644 L p F P
0 g
s
.63 .685 .883 r
.7707 .21606 m .75871 .21849 L .756 .21461 L p F P
0 g
s
.04 0 .403 r
.79489 .28536 m .79489 .28539 L .79489 .28536 L closepath p F P
0 g
s
.037 0 .402 r
.79831 .28522 m .79834 .27993 L .79489 .28536 L p F P
0 g
s
.037 0 .402 r
.79509 .29026 m .79831 .28522 L p .79489 .28536 L F P
0 g
s
.037 0 .402 r
.79489 .28536 m .79489 .28539 L .79509 .29026 L p F P
0 g
s
.07 0 .413 r
.79489 .28539 m .79481 .29065 L .79509 .29026 L closepath p F P
0 g
s
0 0 0 r
.76859 .3417 m .76734 .34411 L .77137 .3384 L closepath p F P
0 g
s
0 .195 .682 r
.16857 .28508 m .16408 .28182 L .16776 .28529 L p F P
0 g
s
0 .195 .682 r
.16776 .28529 m .17219 .2885 L .16857 .28508 L p F P
0 g
s
.8 .414 .324 r
.29079 .38442 m .29653 .38634 L .29433 .38186 L p F P
0 g
s
.8 .414 .324 r
.29433 .38186 m .29359 .38162 L .29079 .38442 L p F P
0 g
s
.595 .285 .413 r
.44889 .40557 m .44835 .40798 L .44531 .40601 L closepath p F P
0 g
s
.593 .283 .413 r
.44793 .40995 m .44835 .40798 L .44531 .40601 L p F P
0 g
s
.593 .283 .413 r
.43473 .4116 m .44793 .40995 L p .44531 .40601 L F P
0 g
s
.591 .891 .989 r
.5542 .46624 m .55491 .46651 L .5438 .47042 L p F P
0 g
s
.591 .891 .989 r
.5438 .47042 m .54268 .46999 L .5542 .46624 L p F P
0 g
s
.433 .747 .993 r
.26373 .47249 m .27461 .47201 L .27811 .47424 L p F P
0 g
s
.45 .749 .993 r
.27461 .47201 m .26373 .47249 L .26021 .47028 L p F P
0 g
s
.595 .849 .992 r
.49971 .47605 m .4991 .47571 L .48911 .47844 L closepath p F P
0 g
s
.606 .836 .987 r
.49599 .47369 m .4991 .47571 L .48911 .47844 L p F P
0 g
s
.606 .836 .987 r
.48456 .47688 m .49599 .47369 L p .48911 .47844 L F P
0 g
s
.784 .996 .865 r
.65818 .26101 m .66644 .25449 L .66374 .2542 L p F P
0 g
s
.784 .996 .865 r
.66374 .2542 m .6627 .25506 L .65818 .26101 L p F P
0 g
s
.753 .994 .863 r
.65235 .26364 m .6627 .25506 L .65818 .26101 L p F P
0 g
s
.753 .994 .863 r
.65229 .26372 m .65235 .26364 L p .65818 .26101 L F P
0 g
s
.556 .012 0 r
.19294 .30695 m .19203 .30611 L .19631 .30933 L p F P
0 g
s
.556 .012 0 r
.19631 .30933 m .19657 .30956 L .19294 .30695 L p F P
0 g
s
.737 .404 .418 r
.34363 .40928 m .35208 .41054 L .35002 .40595 L p F P
0 g
s
.737 .404 .418 r
.35002 .40595 m .34509 .40522 L .34363 .40928 L p F P
0 g
s
0 0 0 r
.74704 .36731 m .75436 .35969 L .74867 .36565 L p F P
0 g
s
0 0 0 r
.74867 .36565 m .74709 .36729 L .74542 .36902 L p F P
0 g
s
0 0 0 r
.74542 .36902 m .74704 .36731 L p .74867 .36565 L F P
0 g
s
.231 .641 .958 r
.19946 .4565 m .20773 .45764 L .21339 .46019 L p F P
0 g
s
.245 .646 .962 r
.20773 .45764 m .19946 .4565 L .19583 .45424 L p F P
0 g
s
.236 0 .142 r
.54037 .35724 m .53765 .35911 L .53648 .36201 L p F P
0 g
s
.405 .738 .992 r
.25668 .46799 m .26021 .47028 L .25264 .47032 L p F P
0 g
s
.405 .738 .992 r
.24584 .46819 m .25668 .46799 L p .25264 .47032 L F P
0 g
s
.405 .738 .992 r
.25264 .47032 m .24597 .46827 L .24584 .46819 L p F P
0 g
s
.787 .287 0 r
.22293 .3345 m .22784 .33745 L .22474 .3334 L p F P
0 g
s
.787 .287 0 r
.22474 .3334 m .21994 .33042 L .22293 .3345 L p F P
0 g
s
.733 .832 .926 r
.72971 .22063 m .72967 .22065 L .72969 .22061 L closepath p F P
0 g
s
.732 .86 .941 r
.72703 .21799 m .72969 .22061 L .72967 .22065 L p F P
0 g
s
.732 .86 .941 r
.71536 .22435 m .72703 .21799 L p .72967 .22065 L F P
0 g
s
.719 .828 .932 r
.73877 .21231 m .74146 .21538 L .72971 .22063 L p F P
0 g
s
.719 .828 .932 r
.73331 .21495 m .73877 .21231 L p .72971 .22063 L F P
0 g
s
.719 .828 .932 r
.72971 .22063 m .72969 .22061 L .73331 .21495 L p F P
0 g
s
0 0 0 r
.78015 .32608 m .7836 .31968 L .77924 .3253 L p F P
0 g
s
0 0 0 r
.77753 .32946 m .78015 .32608 L p .77924 .3253 L F P
0 g
s
0 0 0 r
.77924 .3253 m .77832 .32698 L .77753 .32946 L p F P
0 g
s
.72 .83 .933 r
.72969 .22061 m .72703 .21799 L .73331 .21495 L closepath p F P
0 g
s
0 0 0 r
.74709 .36729 m .741 .37336 L .74542 .36902 L closepath p F P
0 g
s
.513 .861 .605 r
.72425 .3884 m .72269 .38969 L .72386 .38867 L closepath p F P
0 g
s
.549 .896 .666 r
.72177 .38981 m .72386 .38867 L .72269 .38969 L p F P
0 g
s
.549 .896 .666 r
.71897 .39204 m .72177 .38981 L p .72269 .38969 L F P
0 g
s
.549 .896 .666 r
.71248 .39772 m .71897 .39204 L p .72269 .38969 L F P
0 g
s
.785 .393 .312 r
.28974 .3841 m .29079 .38442 L .29359 .38162 L p F P
0 g
s
.785 .393 .312 r
.29359 .38162 m .28732 .3797 L .28974 .3841 L p F P
0 g
s
.599 .934 .735 r
.71248 .39772 m .71023 .39869 L .71897 .39204 L closepath p F P
0 g
s
.013 0 0 r
.56144 .34134 m .56057 .3429 L .5659 .33859 L closepath p F P
0 g
s
.537 .873 .611 r
.73241 .38136 m .72425 .3884 L .72386 .38867 L p F P
0 g
s
.794 .337 .157 r
.25625 .35741 m .25548 .35755 L .25501 .35687 L closepath p F P
0 g
s
.465 .144 .336 r
.49872 .3903 m .49979 .38617 L .48818 .38959 L p F P
0 g
s
.465 .144 .336 r
.48818 .38959 m .48708 .39371 L .49872 .3903 L p F P
0 g
s
.005 .487 .868 r
.14621 .43481 m .14704 .43508 L .15199 .43791 L p F P
0 g
s
.04 .508 .885 r
.1554 .43757 m .14704 .43508 L .15199 .43791 L p F P
0 g
s
.04 .508 .885 r
.16007 .44032 m .1554 .43757 L p .15199 .43791 L F P
0 g
s
.04 .508 .885 r
.15199 .43791 m .16022 .44042 L .16007 .44032 L p F P
0 g
s
.7 .176 0 r
.1997 .31322 m .19657 .30956 L .19294 .30695 L p F P
0 g
s
.605 .953 .846 r
.67581 .42179 m .67551 .42184 L .6769 .421 L closepath p F P
0 g
s
0 0 .138 r
.78748 .30903 m .78703 .31197 L .78859 .3075 L closepath p F P
0 g
s
.084 .546 .905 r
.16391 .44281 m .16541 .44319 L .17062 .44592 L p F P
0 g
s
.115 .563 .918 r
.17433 .44529 m .16541 .44319 L .17062 .44592 L p F P
0 g
s
.115 .563 .918 r
.17062 .44592 m .17801 .44768 L .17433 .44529 L p F P
0 g
s
.572 .779 .977 r
.32486 .47965 m .33596 .47755 L .33933 .48009 L p F P
0 g
s
.595 .773 .965 r
.33596 .47755 m .32486 .47965 L .32146 .47721 L p F P
0 g
s
.523 .846 .552 r
.74473 .36958 m .74542 .36902 L .741 .37336 L p F P
0 g
s
.523 .846 .552 r
.73876 .37523 m .74473 .36958 L p .741 .37336 L F P
0 g
s
.523 .846 .552 r
.73484 .37911 m .73876 .37523 L p .741 .37336 L F P
0 g
s
.523 .846 .552 r
.741 .37336 m .7357 .37836 L .73484 .37911 L p F P
0 g
s
.574 .265 .407 r
.46076 .40788 m .46168 .40348 L .44889 .40557 L p F P
0 g
s
.574 .265 .407 r
.45142 .40937 m .46076 .40788 L p .44889 .40557 L F P
0 g
s
.574 .265 .407 r
.44889 .40557 m .44835 .40798 L .45142 .40937 L p F P
0 g
s
.203 0 .095 r
.54911 .35142 m .54037 .35724 L .54822 .35341 L closepath p F P
0 g
s
.236 0 .142 r
.54672 .35691 m .54822 .35341 L .54037 .35724 L p F P
0 g
s
.236 0 .142 r
.53648 .36201 m .54672 .35691 L p .54037 .35724 L F P
0 g
s
.498 .833 .545 r
.7357 .37836 m .73241 .38136 L .73484 .37911 L closepath p F P
0 g
s
.537 .873 .611 r
.73327 .38015 m .73484 .37911 L .73241 .38136 L p F P
0 g
s
.537 .873 .611 r
.72948 .38345 m .73327 .38015 L p .73241 .38136 L F P
0 g
s
.537 .873 .611 r
.72386 .38867 m .72948 .38345 L p .73241 .38136 L F P
0 g
s
.485 0 0 r
.0643 .38172 m .06812 .38505 L .064 .38135 L p F P
0 g
s
.485 0 0 r
.064 .38135 m .06018 .37802 L .0643 .38172 L p F P
0 g
s
.341 .703 .983 r
.23153 .46548 m .23954 .46583 L .24574 .46819 L p F P
0 g
s
.357 .708 .985 r
.23954 .46583 m .23153 .46548 L .22795 .46329 L p F P
0 g
s
0 0 0 r
.77832 .32698 m .77562 .33175 L .77753 .32946 L closepath p F P
0 g
s
.584 .903 .643 r
.61954 .29265 m .61786 .29378 L .6237 .28858 L closepath p F P
0 g
s
.775 .987 .897 r
.66963 .25209 m .66644 .25449 L .66374 .2542 L p F P
0 g
s
.668 .366 .452 r
.40689 .41337 m .39756 .41345 L .40004 .41794 L p F P
0 g
s
.673 .367 .448 r
.39119 .41791 m .40004 .41794 L .39756 .41345 L p F P
0 g
s
.673 .367 .448 r
.39756 .41345 m .39216 .41343 L .39119 .41791 L p F P
0 g
s
.686 .381 .452 r
.38686 .41779 m .39119 .41791 L .39216 .41343 L p F P
0 g
s
.686 .381 .452 r
.39216 .41343 m .38465 .41321 L .38686 .41779 L p F P
0 g
s
.592 .902 .985 r
.56581 .46231 m .56872 .46327 L .55718 .46727 L p F P
0 g
s
.592 .902 .985 r
.55718 .46727 m .55491 .46651 L .56581 .46231 L p F P
0 g
s
.65 .349 .448 r
.4121 .41316 m .40689 .41337 L .40598 .41789 L p F P
0 g
s
.668 .366 .452 r
.40004 .41794 m .40598 .41789 L .40689 .41337 L p F P
0 g
s
.759 .906 .941 r
.70106 .22957 m .71198 .22265 L .70912 .22809 L p F P
0 g
s
.775 .895 .928 r
.70912 .22809 m .71536 .22435 L .71268 .22221 L p F P
0 g
s
.775 .895 .928 r
.71268 .22221 m .71198 .22265 L .70912 .22809 L p F P
0 g
s
.511 0 0 r
.17617 .29211 m .17581 .29176 L .17219 .2885 L p F P
0 g
s
0 .453 .851 r
.13757 .42924 m .14221 .4322 L .13481 .42943 L p F P
0 g
s
0 .453 .851 r
.13481 .42943 m .13012 .42649 L .13757 .42924 L p F P
0 g
s
0 .421 .825 r
.12858 .42588 m .13012 .42649 L .13481 .42943 L p F P
0 g
s
.252 .217 .624 r
.80024 .26352 m .79952 .26467 L .79694 .26025 L p F P
0 g
s
.252 .217 .624 r
.79694 .26025 m .79889 .25711 L .80024 .26352 L p F P
0 g
s
.736 .404 .418 r
.34276 .40915 m .34363 .40928 L .34509 .40522 L p F P
0 g
s
.736 .404 .418 r
.34509 .40522 m .3407 .40457 L .34276 .40915 L p F P
0 g
s
.817 .411 .281 r
.2744 .37497 m .28067 .3774 L .27834 .37299 L p F P
0 g
s
.817 .411 .281 r
.27281 .37172 m .2744 .37497 L p .27834 .37299 L F P
0 g
s
.817 .411 .281 r
.27834 .37299 m .27377 .37115 L .27281 .37172 L p F P
0 g
s
.797 .335 .143 r
.25177 .35799 m .24925 .35425 L .25501 .35687 L p F P
0 g
s
.797 .335 .143 r
.25501 .35687 m .25548 .35755 L .25177 .35799 L p F P
0 g
s
0 .222 .674 r
.09366 .40475 m .09394 .40494 L .09105 .40276 L closepath p F P
0 g
s
.717 .391 .425 r
.36125 .40963 m .36223 .41166 L .36067 .4115 L closepath p F P
0 g
s
.694 .383 .446 r
.37574 .41726 m .38686 .41779 L .38465 .41321 L p F P
0 g
s
.694 .383 .446 r
.38465 .41321 m .3768 .41284 L .37574 .41726 L p F P
0 g
s
.799 .985 .893 r
.66963 .25209 m .67795 .24577 L .67526 .24502 L p F P
0 g
s
.799 .985 .893 r
.67526 .24502 m .67369 .24627 L .66963 .25209 L p F P
0 g
s
.775 .987 .897 r
.66374 .2542 m .67369 .24627 L .66963 .25209 L p F P
0 g
s
.648 .348 .449 r
.42106 .41275 m .4121 .41316 L .41502 .41752 L p F P
0 g
s
.65 .349 .448 r
.40598 .41789 m .41502 .41752 L .4121 .41316 L p F P
0 g
s
.614 .957 .854 r
.6769 .421 m .67551 .42184 L .67285 .42221 L p F P
0 g
s
.16 .598 .935 r
.18167 .45 m .18553 .45074 L .191 .45337 L p F P
0 g
s
.185 .61 .944 r
.19219 .4519 m .18553 .45074 L .191 .45337 L p F P
0 g
s
.185 .61 .944 r
.191 .45337 m .19583 .45424 L .19219 .4519 L p F P
0 g
s
.702 .174 0 r
.20308 .31713 m .2075 .32028 L .20404 .3164 L p F P
0 g
s
.702 .174 0 r
.20404 .3164 m .1997 .31322 L .20308 .31713 L p F P
0 g
s
.594 .779 .968 r
.33933 .48009 m .35048 .47766 L .35382 .48031 L p F P
0 g
s
.618 .769 .952 r
.35048 .47766 m .33933 .48009 L .33596 .47755 L p F P
0 g
s
.603 .93 .962 r
.60925 .45118 m .59767 .45596 L .59479 .45539 L p F P
0 g
s
0 .326 .768 r
.09547 .40501 m .09963 .40818 L .09394 .40494 L p F P
0 g
s
0 .326 .768 r
.08989 .40185 m .09547 .40501 L p .09394 .40494 L F P
0 g
s
0 .326 .768 r
.09394 .40494 m .09105 .40276 L .08989 .40185 L p F P
0 g
s
0 0 0 r
.57287 .33241 m .57203 .33373 L .57647 .32995 L closepath p F P
0 g
s
.511 0 0 r
.17219 .2885 m .17239 .28869 L .17617 .29211 L p F P
0 g
s
.526 .008 0 r
.17619 .29239 m .18 .2958 L .17617 .29211 L p F P
0 g
s
.526 .008 0 r
.17617 .29211 m .17239 .28869 L .17619 .29239 L p F P
0 g
s
.589 .945 .815 r
.68709 .4146 m .6769 .421 L .68489 .41511 L closepath p F P
0 g
s
.614 .957 .854 r
.68446 .41517 m .68489 .41511 L .6769 .421 L p F P
0 g
s
.614 .957 .854 r
.67285 .42221 m .68446 .41517 L p .6769 .421 L F P
0 g
s
.582 .944 .886 r
.64964 .4351 m .64582 .43707 L .64899 .43514 L closepath p F P
0 g
s
.599 .948 .91 r
.64689 .43508 m .64899 .43514 L .64582 .43707 L p F P
0 g
s
.599 .948 .91 r
.63527 .44092 m .64689 .43508 L p .64582 .43707 L F P
0 g
s
.773 .424 .395 r
.31543 .39951 m .3235 .40131 L .32136 .39678 L p F P
0 g
s
.773 .424 .395 r
.32136 .39678 m .31351 .3949 L .31543 .39951 L p F P
0 g
s
.593 .919 .688 r
.72386 .38867 m .72177 .38981 L .72948 .38345 L closepath p F P
0 g
s
.775 .272 0 r
.23086 .34139 m .22784 .33745 L .23296 .34033 L p F P
0 g
s
.775 .272 0 r
.23296 .34033 m .23454 .34233 L .23086 .34139 L p F P
0 g
s
.703 .392 .448 r
.37501 .41721 m .37574 .41726 L .3768 .41284 L p F P
0 g
s
.703 .392 .448 r
.3768 .41284 m .37297 .41259 L .37501 .41721 L p F P
0 g
s
.505 .188 .363 r
.48605 .39793 m .48708 .39371 L .47508 .39668 L p F P
0 g
s
.505 .188 .363 r
.47951 .39953 m .48605 .39793 L p .47508 .39668 L F P
0 g
s
.505 .188 .363 r
.47508 .39668 m .4743 .39976 L .47951 .39953 L p F P
0 g
s
.174 .604 .94 r
.18553 .45074 m .18167 .45 L .17801 .44768 L p F P
0 g
s
.626 .328 .444 r
.42922 .41206 m .42106 .41275 L .4202 .41729 L p F P
0 g
s
.648 .348 .449 r
.41502 .41752 m .4202 .41729 L .42106 .41275 L p F P
0 g
s
.48 .759 .992 r
.29138 .47489 m .29253 .47566 L p .27811 .47424 L F P
0 g
s
.48 .759 .992 r
.27811 .47424 m .28661 .47353 L .29138 .47489 L p F P
0 g
s
.502 .763 .989 r
.28661 .47353 m .27811 .47424 L .27461 .47201 L p F P
0 g
s
.52 .776 .99 r
.29253 .47566 m .29415 .47544 L .30233 .47715 L p F P
0 g
s
.516 .764 .986 r
.30354 .47412 m .29415 .47544 L .30233 .47715 L p F P
0 g
s
.516 .764 .986 r
.30233 .47715 m .30698 .4766 L .30354 .47412 L p F P
0 g
s
.83 .395 .205 r
.25754 .36118 m .25548 .35755 L .25177 .35799 L p F P
0 g
s
.79 .422 .359 r
.29858 .39088 m .30594 .39293 L .30368 .38846 L p F P
0 g
s
.79 .422 .359 r
.30368 .38846 m .29653 .38634 L .29858 .39088 L p F P
0 g
s
.75 .42 .426 r
.33369 .40768 m .34276 .40915 L .3407 .40457 L p F P
0 g
s
.75 .42 .426 r
.3407 .40457 m .33187 .40302 L .33369 .40768 L p F P
0 g
s
.615 .957 .882 r
.66265 .42874 m .66124 .42883 L .66827 .42488 L closepath p F P
0 g
s
.715 .407 .456 r
.364 .41636 m .37501 .41721 L .37297 .41259 L p F P
0 g
s
.715 .407 .456 r
.37297 .41259 m .36223 .41166 L .364 .41636 L p F P
0 g
s
.783 .97 .918 r
.68201 .24285 m .67795 .24577 L .67526 .24502 L p F P
0 g
s
.546 .58 .839 r
.78586 .22118 m .78305 .22623 L p .77345 .22081 L F P
0 g
s
.546 .58 .839 r
.77345 .22081 m .78565 .22075 L .78586 .22118 L p F P
0 g
s
.533 .619 .884 r
.77092 .21644 m .77345 .22081 L .78565 .22075 L p F P
0 g
s
0 .108 .581 r
.06889 .38566 m .06812 .38505 L .07202 .38834 L p F P
0 g
s
0 .108 .581 r
.07202 .38834 m .07267 .38886 L .06889 .38566 L p F P
0 g
s
.611 .777 .96 r
.35382 .48031 m .365 .4776 L .36832 .48035 L p F P
0 g
s
.635 .763 .94 r
.365 .4776 m .35382 .48031 L .35048 .47766 L p F P
0 g
s
.157 0 .074 r
.55421 .34757 m .54911 .35142 L .54822 .35341 L p F P
0 g
s
0 .352 .777 r
.11106 .4159 m .11438 .41751 L .11885 .42054 L p F P
0 g
s
0 .382 .802 r
.121 .4205 m .11438 .41751 L .11885 .42054 L p F P
0 g
s
0 .382 .802 r
.12165 .42094 m .121 .4205 L p .11885 .42054 L F P
0 g
s
0 .382 .802 r
.11885 .42054 m .12485 .42325 L .12165 .42094 L p F P
0 g
s
.603 .884 .991 r
.5542 .46624 m .54268 .46999 L .53967 .46867 L p F P
0 g
s
.593 .88 .992 r
.52816 .47223 m .53967 .46867 L .54268 .46999 L p F P
0 g
s
0 0 0 r
.75752 .35598 m .7561 .35775 L .76076 .35237 L closepath p F P
0 g
s
.754 .849 .921 r
.72703 .21799 m .71536 .22435 L .71268 .22221 L p F P
0 g
s
0 0 0 r
.77615 .33266 m .77137 .3384 L .77562 .33175 L p F P
0 g
s
0 0 0 r
.77628 .33246 m .77615 .33266 L p .77562 .33175 L F P
0 g
s
0 0 0 r
.77562 .33175 m .77753 .32946 L .77628 .33246 L p F P
0 g
s
0 0 .135 r
.79041 .30793 m .79252 .30196 L .78859 .3075 L p F P
0 g
s
0 0 .135 r
.78688 .31294 m .79041 .30793 L p .78859 .3075 L F P
0 g
s
0 0 .135 r
.78859 .3075 m .78703 .31197 L .78688 .31294 L p F P
0 g
s
.609 .944 .939 r
.63177 .4426 m .62367 .44636 L .62085 .44606 L p F P
0 g
s
.239 .648 .96 r
.21413 .46051 m .21367 .46022 L .21339 .46019 L closepath p F P
0 g
s
.823 .398 .232 r
.25992 .36555 m .26585 .36811 L .26332 .36379 L p F P
0 g
s
.823 .398 .232 r
.26332 .36379 m .25754 .36118 L .25992 .36555 L p F P
0 g
s
.602 .952 .887 r
.65852 .42898 m .66124 .42883 L .64964 .4351 L p F P
0 g
s
.602 .952 .887 r
.65803 .42925 m .65852 .42898 L p .64964 .4351 L F P
0 g
s
.602 .952 .887 r
.64964 .4351 m .64899 .43514 L .65803 .42925 L p F P
0 g
s
.804 .963 .911 r
.68201 .24285 m .68948 .23745 L .6868 .23626 L p F P
0 g
s
.804 .963 .911 r
.6868 .23626 m .68558 .23719 L .68201 .24285 L p F P
0 g
s
.783 .97 .918 r
.67526 .24502 m .68558 .23719 L .68201 .24285 L p F P
0 g
s
.624 .774 .953 r
.36832 .48035 m .37954 .47742 L .38283 .48027 L p F P
0 g
s
.646 .757 .93 r
.37954 .47742 m .36832 .48035 L .365 .4776 L p F P
0 g
s
0 .359 .787 r
.11438 .41751 m .11106 .4159 L .1073 .41313 L p F P
0 g
s
.627 .328 .443 r
.43473 .4116 m .42922 .41206 L .43283 .41622 L p F P
0 g
s
.626 .328 .444 r
.4202 .41729 m .43283 .41622 L .42922 .41206 L p F P
0 g
s
.112 0 .015 r
.56057 .3429 m .55421 .34757 L .55974 .34455 L closepath p F P
0 g
s
.157 0 .074 r
.55813 .34788 m .55974 .34455 L .55421 .34757 L p F P
0 g
s
.157 0 .074 r
.54822 .35341 m .55813 .34788 L p .55421 .34757 L F P
0 g
s
.42 .092 .301 r
.51108 .38235 m .51174 .38006 L .50029 .38449 L p F P
0 g
s
.42 .092 .301 r
.50029 .38449 m .49979 .38617 L .51108 .38235 L p F P
0 g
s
.701 .166 0 r
.21006 .32315 m .2075 .32028 L .21209 .32337 L p F P
0 g
s
.701 .166 0 r
.21209 .32337 m .21371 .32515 L .21006 .32315 L p F P
0 g
s
.669 .958 .733 r
.63048 .28306 m .62931 .28361 L .63305 .28033 L closepath p F P
0 g
s
.526 0 0 r
.18393 .29949 m .18791 .30283 L .18394 .29916 L p F P
0 g
s
.526 0 0 r
.18394 .29916 m .18 .2958 L .18393 .29949 L p F P
0 g
s
.325 .313 .692 r
.79661 .25074 m .79704 .25003 L .79746 .25157 L closepath p F P
0 g
s
.802 .412 .315 r
.2829 .38186 m .28974 .3841 L .28732 .3797 L p F P
0 g
s
.802 .412 .315 r
.28732 .3797 m .28067 .3774 L .2829 .38186 L p F P
0 g
s
.113 .039 .486 r
.80169 .2747 m .79834 .27993 L .79762 .27489 L p F P
0 g
s
.113 .039 .486 r
.80125 .27026 m .80169 .2747 L p .79762 .27489 L F P
0 g
s
.113 .039 .486 r
.79762 .27489 m .80112 .26942 L .80125 .27026 L p F P
0 g
s
0 0 0 r
.58412 .32324 m .58349 .32409 L .5864 .32153 L closepath p F P
0 g
s
.098 .552 .911 r
.16541 .44319 m .16391 .44281 L .16022 .44042 L p F P
0 g
s
0 .147 .613 r
.07267 .38886 m .07673 .39186 L .08072 .39511 L p F P
0 g
s
0 .155 .627 r
.07673 .39186 m .07267 .38886 L .06889 .38566 L p F P
0 g
s
.339 .705 .983 r
.24597 .46827 m .24584 .46819 L .24574 .46819 L closepath p F P
0 g
s
.249 .649 .963 r
.21006 .45792 m .20773 .45764 L .21339 .46019 L p F P
0 g
s
.249 .649 .963 r
.21339 .46019 m .21367 .46022 L .21006 .45792 L p F P
0 g
s
.825 .364 .123 r
.23849 .34871 m .24375 .35153 L .24103 .34731 L p F P
0 g
s
.825 .364 .123 r
.24103 .34731 m .23589 .34445 L .23849 .34871 L p F P
0 g
s
.348 .704 .984 r
.24229 .46591 m .23954 .46583 L .24574 .46819 L p F P
0 g
s
.348 .704 .984 r
.24574 .46819 m .24584 .46819 L .24229 .46591 L p F P
0 g
s
.631 .773 .948 r
.38283 .48027 m .39408 .47719 L .39735 .48008 L p F P
0 g
s
.652 .753 .924 r
.39408 .47719 m .38283 .48027 L .37954 .47742 L p F P
0 g
s
.425 .735 .991 r
.25668 .46799 m .24584 .46819 L .24229 .46591 L p F P
0 g
s
.603 .873 .992 r
.53967 .46867 m .52816 .47223 L .52512 .47075 L p F P
0 g
s
.593 .869 .994 r
.51363 .47415 m .52512 .47075 L .52816 .47223 L p F P
0 g
s
.722 .411 .451 r
.35957 .4159 m .364 .41636 L .36223 .41166 L p F P
0 g
s
.722 .411 .451 r
.36223 .41166 m .36067 .4115 L .35957 .4159 L p F P
0 g
s
.315 .684 .978 r
.22436 .46102 m .21367 .46022 L .21006 .45792 L p F P
0 g
s
.502 .542 .83 r
.78305 .22623 m .78586 .22118 L .78849 .22689 L closepath p F P
0 g
s
.606 .309 .439 r
.44717 .41455 m .44793 .40995 L .43473 .4116 L p F P
0 g
s
.606 .309 .439 r
.43473 .4116 m .43388 .41613 L .44717 .41455 L p F P
0 g
s
.627 .328 .443 r
.43283 .41622 m .43388 .41613 L .43473 .4116 L p F P
0 g
s
.518 .778 .991 r
.29253 .47566 m .29415 .47544 L .29138 .47489 L closepath p F P
0 g
s
0 0 .322 r
.79499 .29479 m .794 .2962 L .79481 .29065 L p F P
0 g
s
0 0 .322 r
.79481 .29065 m .79509 .29026 L .79499 .29479 L p F P
0 g
s
.597 .92 .972 r
.58333 .45996 m .58321 .45993 L .58442 .45946 L closepath p F P
0 g
s
.573 .269 .415 r
.44835 .40798 m .45142 .40937 L .44793 .40995 L closepath p F P
0 g
s
.604 .852 .991 r
.51056 .47243 m .5116 .47304 L .49971 .47605 L p F P
0 g
s
.604 .852 .991 r
.49971 .47605 m .4991 .47571 L .51056 .47243 L p F P
0 g
s
.548 .245 .406 r
.47318 .40535 m .47403 .40091 L .46168 .40348 L p F P
0 g
s
.548 .245 .406 r
.46168 .40348 m .46076 .40788 L .47318 .40535 L p F P
0 g
s
.726 .415 .453 r
.35378 .41526 m .35957 .4159 L .36067 .4115 L p F P
0 g
s
.726 .415 .453 r
.36067 .4115 m .35208 .41054 L .35378 .41526 L p F P
0 g
s
0 .427 .834 r
.13012 .42649 m .12858 .42588 L .12485 .42325 L p F P
0 g
s
.608 .952 .817 r
.69309 .4107 m .68709 .4146 L .68489 .41511 L p F P
0 g
s
.797 .38 .258 r
.27377 .37115 m .27281 .37172 L .27211 .37055 L closepath p F P
0 g
s
.017 .491 .874 r
.14621 .43481 m .14704 .43508 L .14353 .43301 L closepath p F P
0 g
s
.067 0 0 r
.5659 .33859 m .56057 .3429 L .55974 .34455 L p F P
0 g
s
.634 .774 .947 r
.39735 .48008 m .40863 .47693 L .41187 .47982 L p F P
0 g
s
.655 .752 .921 r
.40863 .47693 m .39735 .48008 L .39408 .47719 L p F P
0 g
s
.612 .917 .978 r
.58442 .45946 m .58321 .45993 L .58029 .45904 L p F P
0 g
s
.596 .911 .979 r
.56872 .46327 m .58029 .45904 L .58321 .45993 L p F P
0 g
s
.781 .945 .93 r
.69584 .23313 m .68948 .23745 L .6868 .23626 L p F P
0 g
s
.584 .901 .637 r
.73484 .37911 m .73327 .38015 L .73876 .37523 L closepath p F P
0 g
s
.382 .403 .758 r
.79434 .24156 m .79465 .24174 L .7945 .24203 L closepath p F P
0 g
s
.34 .353 .728 r
.79944 .24542 m .79704 .25003 L .7945 .24203 L p F P
0 g
s
.34 .353 .728 r
.7945 .24203 m .79465 .24174 L .79944 .24542 L p F P
0 g
s
.399 .429 .775 r
.79465 .24174 m .79434 .24156 L .79137 .23366 L p F P
0 g
s
0 .316 .755 r
.10354 .41027 m .09963 .40818 L .10388 .4113 L p F P
0 g
s
0 .316 .755 r
.10388 .4113 m .1073 .41313 L .10354 .41027 L p F P
0 g
s
.244 .259 .678 r
.80301 .24952 m .79944 .24542 L .79704 .25003 L p F P
0 g
s
.244 .259 .678 r
.80013 .25484 m .80301 .24952 L p .79704 .25003 L F P
0 g
s
.244 .259 .678 r
.79704 .25003 m .79746 .25157 L .80013 .25484 L p F P
0 g
s
0 .188 .653 r
.08172 .39531 m .0857 .39856 L .08072 .39511 L p F P
0 g
s
0 .188 .653 r
.08072 .39511 m .07673 .39186 L .08172 .39531 L p F P
0 g
s
0 0 .305 r
.79758 .29074 m .79499 .29479 L .79509 .29026 L p F P
0 g
s
0 0 .305 r
.79509 .29026 m .79831 .28522 L .79758 .29074 L p F P
0 g
s
.005 0 0 r
.57203 .33373 m .5659 .33859 L .57106 .33543 L closepath p F P
0 g
s
.067 0 0 r
.56932 .33857 m .57106 .33543 L .5659 .33859 L p F P
0 g
s
.067 0 0 r
.55974 .34455 m .56932 .33857 L p .5659 .33859 L F P
0 g
s
.277 .269 .67 r
.79746 .25157 m .80013 .25484 L .79889 .25711 L closepath p F P
0 g
s
.607 .858 .991 r
.52325 .46971 m .52512 .47075 L .51363 .47415 L p F P
0 g
s
.607 .858 .991 r
.51363 .47415 m .5116 .47304 L .52325 .46971 L p F P
0 g
s
.635 .778 .949 r
.41187 .47982 m .42318 .47665 L .4264 .47949 L p F P
0 g
s
.654 .754 .923 r
.42318 .47665 m .41187 .47982 L .40863 .47693 L p F P
0 g
s
.678 .747 .903 r
.74146 .21538 m .7533 .21093 L .756 .21461 L p F P
0 g
s
.692 .764 .907 r
.7533 .21093 m .74146 .21538 L .73877 .21231 L p F P
0 g
s
.399 .429 .775 r
.79137 .23366 m .79726 .23647 L .79465 .24174 L p F P
0 g
s
.345 .364 .737 r
.80228 .24008 m .79944 .24542 L .79465 .24174 L p F P
0 g
s
.345 .364 .737 r
.79465 .24174 m .79726 .23647 L .80228 .24008 L p F P
0 g
s
.763 .426 .415 r
.32544 .40595 m .33369 .40768 L .33187 .40302 L p F P
0 g
s
.763 .426 .415 r
.33187 .40302 m .32705 .40201 L .32544 .40595 L p F P
0 g
s
.598 .923 .969 r
.59479 .45539 m .58442 .45946 L .59371 .45513 L closepath p F P
0 g
s
.612 .917 .978 r
.59189 .45459 m .59371 .45513 L .58442 .45946 L p F P
0 g
s
.612 .917 .978 r
.58029 .45904 m .59189 .45459 L p .58442 .45946 L F P
0 g
s
.645 .706 .891 r
.76796 .21165 m .756 .21461 L .7533 .21093 L p F P
0 g
s
.63 .685 .883 r
.756 .21461 m .76796 .21165 L .7707 .21606 L p F P
0 g
s
.787 .286 0 r
.21371 .32515 m .2153 .32736 L .21994 .33042 L p F P
0 g
s
.793 .296 0 r
.2182 .33147 m .22293 .3345 L .21994 .33042 L p F P
0 g
s
.793 .296 0 r
.21994 .33042 m .2153 .32736 L .2182 .33147 L p F P
0 g
s
.784 .429 .384 r
.30797 .3975 m .31543 .39951 L .31351 .3949 L p F P
0 g
s
.784 .429 .384 r
.30775 .39693 m .30797 .3975 L p .31351 .3949 L F P
0 g
s
.784 .429 .384 r
.31351 .3949 m .30955 .39383 L .30775 .39693 L p F P
0 g
s
0 0 0 r
.77125 .33952 m .77615 .33266 L .77137 .3384 L p F P
0 g
s
0 0 0 r
.7671 .34458 m .77125 .33952 L p .77137 .3384 L F P
0 g
s
0 0 0 r
.77137 .3384 m .76734 .34411 L .7671 .34458 L p F P
0 g
s
.543 .006 0 r
.18931 .30414 m .18791 .30283 L .19203 .30611 L p F P
0 g
s
.543 .006 0 r
.19203 .30611 m .19294 .30695 L .18931 .30414 L p F P
0 g
s
.607 .936 .954 r
.60976 .45127 m .60925 .45118 L .61304 .44954 L closepath p F P
0 g
s
.622 .956 .914 r
.64899 .43514 m .64689 .43508 L .65803 .42925 L closepath p F P
0 g
s
.098 .552 .911 r
.16022 .44042 m .16027 .44043 L .16541 .44319 L p F P
0 g
s
.129 .568 .923 r
.16974 .44259 m .16027 .44043 L .16541 .44319 L p F P
0 g
s
.129 .568 .923 r
.17318 .44452 m .16974 .44259 L p .16541 .44319 L F P
0 g
s
.129 .568 .923 r
.16541 .44319 m .17433 .44529 L .17318 .44452 L p F P
0 g
s
.534 .778 .987 r
.3001 .4715 m .30354 .47412 L .29415 .47544 L p F P
0 g
s
.534 .778 .987 r
.28906 .4733 m .3001 .4715 L p .29415 .47544 L F P
0 g
s
.534 .778 .987 r
.29415 .47544 m .29138 .47489 L .28906 .4733 L p F P
0 g
s
.825 .356 .092 r
.23589 .34445 m .23454 .34233 L .23086 .34139 L p F P
0 g
s
.11 .548 .915 r
.15063 .43467 m .1554 .43757 L .14704 .43508 L p F P
0 g
s
.11 .548 .915 r
.1425 .43229 m .15063 .43467 L p .14704 .43508 L F P
0 g
s
.11 .548 .915 r
.14704 .43508 m .14353 .43301 L .1425 .43229 L p F P
0 g
s
.632 .784 .955 r
.4264 .47949 m .43774 .47633 L .44094 .47907 L p F P
0 g
s
.65 .76 .93 r
.43774 .47633 m .4264 .47949 L .42318 .47665 L p F P
0 g
s
.801 .381 .249 r
.26832 .37247 m .26585 .36811 L .27211 .37055 L p F P
0 g
s
.801 .381 .249 r
.27011 .37315 m .26832 .37247 L p .27211 .37055 L F P
0 g
s
.801 .381 .249 r
.27211 .37055 m .27281 .37172 L .27011 .37315 L p F P
0 g
s
.451 .478 .795 r
.79058 .23342 m .79099 .23271 L .79137 .23366 L closepath p F P
0 g
s
0 .243 .695 r
.09105 .40276 m .08989 .40185 L .08977 .40177 L closepath p F P
0 g
s
0 0 0 r
.57647 .32995 m .57203 .33373 L .57106 .33543 L p F P
0 g
s
0 0 .148 r
.78703 .31197 m .78648 .31346 L .78688 .31294 L closepath p F P
0 g
s
.62 .833 .982 r
.51056 .47243 m .4991 .47571 L .49599 .47369 L p F P
0 g
s
.804 .342 .135 r
.24644 .35577 m .24375 .35153 L .24925 .35425 L p F P
0 g
s
.804 .342 .135 r
.25117 .35802 m .24644 .35577 L p .24925 .35425 L F P
0 g
s
.804 .342 .135 r
.24925 .35425 m .25177 .35799 L .25117 .35802 L p F P
0 g
s
.567 .774 .976 r
.30698 .4766 m .31805 .47461 L .32146 .47721 L p F P
0 g
s
.589 .769 .965 r
.31805 .47461 m .30698 .4766 L .30354 .47412 L p F P
0 g
s
.587 .938 .778 r
.69867 .40692 m .69309 .4107 L .69738 .40733 L closepath p F P
0 g
s
.608 .952 .817 r
.69607 .4076 m .69738 .40733 L .69309 .4107 L p F P
0 g
s
.608 .952 .817 r
.68631 .414 m .69607 .4076 L p .69309 .4107 L F P
0 g
s
.608 .952 .817 r
.68489 .41511 m .68631 .414 L p .69309 .4107 L F P
0 g
s
.628 .794 .962 r
.44094 .47907 m .4523 .47593 L .45547 .47852 L p F P
0 g
s
.645 .771 .94 r
.4523 .47593 m .44094 .47907 L .43774 .47633 L p F P
0 g
s
.301 0 .208 r
.53471 .36667 m .53507 .36565 L .5245 .37034 L p F P
0 g
s
.301 0 .208 r
.5245 .37034 m .52322 .37399 L .53471 .36667 L p F P
0 g
s
.366 .033 .262 r
.51227 .37839 m .51174 .38006 L .52228 .37446 L closepath p F P
0 g
s
0 0 0 r
.59518 .31384 m .59495 .31411 L .59593 .31322 L closepath p F P
0 g
s
0 0 0 r
.58349 .32409 m .57647 .32995 L .58218 .32607 L closepath p F P
0 g
s
0 0 0 r
.58068 .32839 m .58218 .32607 L .57647 .32995 L p F P
0 g
s
0 0 0 r
.57878 .33008 m .58068 .32839 L p .57647 .32995 L F P
0 g
s
0 0 0 r
.57106 .33543 m .57878 .33008 L p .57647 .32995 L F P
0 g
s
.789 .917 .925 r
.70106 .22957 m .69584 .23313 L .69859 .22809 L closepath p F P
0 g
s
.781 .945 .93 r
.69837 .22796 m .69859 .22809 L .69584 .23313 L p F P
0 g
s
.781 .945 .93 r
.6868 .23626 m .69837 .22796 L p .69584 .23313 L F P
0 g
s
.625 .817 .974 r
.49599 .47369 m .48456 .47688 L .48143 .47467 L p F P
0 g
s
.617 .82 .978 r
.47001 .47781 m .48143 .47467 L .48456 .47688 L p F P
0 g
s
.623 .806 .97 r
.45547 .47852 m .46686 .4754 L .47001 .47781 L p F P
0 g
s
.639 .784 .951 r
.46686 .4754 m .45547 .47852 L .4523 .47593 L p F P
0 g
s
.742 .425 .447 r
.34431 .41392 m .35378 .41526 L .35208 .41054 L p F P
0 g
s
.742 .425 .447 r
.34326 .4106 m .34431 .41392 L p .35208 .41054 L F P
0 g
s
.742 .425 .447 r
.35208 .41054 m .34363 .40928 L .34326 .4106 L p F P
0 g
s
.805 .432 .35 r
.2917 .38866 m .29858 .39088 L .29653 .38634 L p F P
0 g
s
.805 .432 .35 r
.29022 .38508 m .2917 .38866 L p .29653 .38634 L F P
0 g
s
.805 .432 .35 r
.29653 .38634 m .29079 .38442 L .29022 .38508 L p F P
0 g
s
.73 .988 .803 r
.64137 .2734 m .64078 .27356 L .64256 .27203 L closepath p F P
0 g
s
.632 .8 .963 r
.48143 .47467 m .47001 .47781 L .46686 .4754 L p F P
0 g
s
.229 0 .151 r
.54621 .35819 m .54672 .35691 L .53648 .36201 L p F P
0 g
s
.229 0 .151 r
.53795 .36421 m .54621 .35819 L p .53648 .36201 L F P
0 g
s
.229 0 .151 r
.53648 .36201 m .53507 .36565 L .53795 .36421 L p F P
0 g
s
.174 .604 .94 r
.17801 .44768 m .18014 .44808 L .18553 .45074 L p F P
0 g
s
.199 .615 .948 r
.18853 .44951 m .18014 .44808 L .18553 .45074 L p F P
0 g
s
.199 .615 .948 r
.18553 .45074 m .19219 .4519 L .18853 .44951 L p F P
0 g
s
.212 .19 .615 r
.80255 .25932 m .80024 .26352 L .79889 .25711 L p F P
0 g
s
.212 .19 .615 r
.79889 .25711 m .80013 .25484 L .80255 .25932 L p F P
0 g
s
.432 .115 .326 r
.51001 .38647 m .51108 .38235 L .49979 .38617 L p F P
0 g
s
.432 .115 .326 r
.49979 .38617 m .49872 .3903 L .51001 .38647 L p F P
0 g
s
.38 .434 .792 r
.79099 .23271 m .79137 .23366 L .79726 .23647 L p F P
0 g
s
0 .462 .861 r
.13301 .42625 m .13757 .42924 L .13012 .42649 L p F P
0 g
s
0 .462 .861 r
.13012 .42649 m .12551 .42352 L .13301 .42625 L p F P
0 g
s
0 .427 .834 r
.12485 .42325 m .12551 .42352 L .13012 .42649 L p F P
0 g
s
.49 .761 .991 r
.29138 .47489 m .28906 .4733 L .28661 .47353 L closepath p F P
0 g
s
.594 .944 .919 r
.63527 .44092 m .63177 .4426 L .63473 .44089 L closepath p F P
0 g
s
.609 .944 .939 r
.63248 .44063 m .63473 .44089 L .63177 .4426 L p F P
0 g
s
.609 .944 .939 r
.62085 .44606 m .63248 .44063 L p .63177 .4426 L F P
0 g
s
0 0 0 r
.5864 .32153 m .58349 .32409 L .58218 .32607 L p F P
0 g
s
0 0 .029 r
.78601 .31653 m .7836 .31968 L .78648 .31346 L p F P
0 g
s
0 0 .029 r
.78648 .31346 m .78688 .31294 L .78601 .31653 L p F P
0 g
s
0 0 0 r
.59495 .31411 m .5864 .32153 L .5931 .31645 L closepath p F P
0 g
s
0 0 0 r
.59216 .31768 m .5931 .31645 L .5864 .32153 L p F P
0 g
s
0 0 0 r
.58745 .32204 m .59216 .31768 L p .5864 .32153 L F P
0 g
s
0 0 0 r
.58218 .32607 m .58745 .32204 L p .5864 .32153 L F P
0 g
s
.45 .749 .993 r
.26021 .47028 m .27111 .46968 L .27461 .47201 L p F P
0 g
s
.477 .749 .989 r
.27111 .46968 m .26021 .47028 L .25668 .46799 L p F P
0 g
s
.449 .494 .813 r
.78849 .22689 m .79309 .22816 L .79099 .23271 L closepath p F P
0 g
s
.38 .434 .792 r
.80003 .23113 m .79309 .22816 L .79099 .23271 L p F P
0 g
s
.38 .434 .792 r
.79726 .23647 m .80003 .23113 L p .79099 .23271 L F P
0 g
s
.787 .287 0 r
.2153 .32736 m .21371 .32515 L .21006 .32315 L p F P
0 g
s
.245 .646 .962 r
.19583 .45424 m .20213 .45506 L .20773 .45764 L p F P
0 g
s
.26 .651 .965 r
.20213 .45506 m .19583 .45424 L .19219 .4519 L p F P
0 g
s
0 0 0 r
.77753 .32946 m .77628 .33246 L .78015 .32608 L closepath p F P
0 g
s
.72 .841 .939 r
.73331 .21495 m .72703 .21799 L .72435 .21548 L p F P
0 g
s
.754 .849 .921 r
.71268 .22221 m .72435 .21548 L .72703 .21799 L p F P
0 g
s
.603 .908 .982 r
.57735 .45808 m .58029 .45904 L .56872 .46327 L p F P
0 g
s
.603 .908 .982 r
.56642 .46206 m .57735 .45808 L p .56872 .46327 L F P
0 g
s
.603 .908 .982 r
.56872 .46327 m .56581 .46231 L .56642 .46206 L p F P
0 g
s
.619 .935 .961 r
.61304 .44954 m .60925 .45118 L .60639 .45059 L p F P
0 g
s
.603 .93 .962 r
.59479 .45539 m .60639 .45059 L .60925 .45118 L p F P
0 g
s
.757 .419 .412 r
.3254 .40595 m .32544 .40595 L .32705 .40201 L p F P
0 g
s
.757 .419 .412 r
.32705 .40201 m .3235 .40131 L .3254 .40595 L p F P
0 g
s
.574 .646 .884 r
.7707 .21606 m .77109 .21602 L .77092 .21644 L closepath p F P
0 g
s
.533 .619 .884 r
.78285 .21524 m .77109 .21602 L .77092 .21644 L p F P
0 g
s
.533 .619 .884 r
.78565 .22075 m .78285 .21524 L p .77092 .21644 L F P
0 g
s
.779 .276 0 r
.22594 .3386 m .22293 .3345 L .22784 .33745 L p F P
0 g
s
.779 .276 0 r
.2306 .3413 m .22594 .3386 L p .22784 .33745 L F P
0 g
s
.779 .276 0 r
.22784 .33745 m .23086 .34139 L .2306 .3413 L p F P
0 g
s
0 0 0 r
.59593 .31322 m .59495 .31411 L .5931 .31645 L p F P
0 g
s
0 0 0 r
.60383 .30658 m .59593 .31322 L .60522 .305 L p F P
0 g
s
0 0 0 r
.60363 .30679 m .60383 .30658 L .59593 .31322 L p F P
0 g
s
0 0 0 r
.59597 .31405 m .60363 .30679 L p .59593 .31322 L F P
0 g
s
0 0 0 r
.5931 .31645 m .59597 .31405 L p .59593 .31322 L F P
0 g
s
.606 .946 .78 r
.70696 .40109 m .69867 .40692 L .69738 .40733 L p F P
0 g
s
.602 .896 .988 r
.56576 .46229 m .56581 .46231 L .55491 .46651 L p F P
0 g
s
.602 .896 .988 r
.55491 .46651 m .5542 .46624 L .56576 .46229 L p F P
0 g
s
.7 .176 0 r
.19294 .30695 m .19549 .30998 L .1997 .31322 L p F P
0 g
s
.699 .175 0 r
.19881 .31391 m .20308 .31713 L .1997 .31322 L p F P
0 g
s
.699 .175 0 r
.1997 .31322 m .19549 .30998 L .19881 .31391 L p F P
0 g
s
.691 .171 0 r
.19549 .30998 m .19294 .30695 L .18931 .30414 L p F P
0 g
s
.595 .773 .965 r
.32146 .47721 m .33258 .47481 L .33596 .47755 L p F P
0 g
s
.618 .764 .95 r
.33258 .47481 m .32146 .47721 L .31805 .47461 L p F P
0 g
s
.509 .199 .377 r
.4743 .39976 m .47951 .39953 L .47403 .40091 L closepath p F P
0 g
s
0 0 0 r
.76734 .34411 m .76651 .34524 L .7671 .34458 L closepath p F P
0 g
s
.619 .958 .886 r
.66827 .42488 m .66124 .42883 L .65852 .42898 L p F P
0 g
s
.774 .416 .378 r
.30955 .39383 m .30775 .39693 L .30594 .39293 L closepath p F P
0 g
s
.772 .916 .935 r
.71198 .22265 m .70106 .22957 L .69859 .22809 L p F P
0 g
s
.583 .293 .442 r
.45142 .40937 m .44793 .40995 L .44717 .41455 L p F P
0 g
s
.492 0 0 r
.17239 .28869 m .17219 .2885 L .16857 .28508 L p F P
0 g
s
.181 .129 .559 r
.80116 .26936 m .80112 .26942 L .79952 .26467 L p F P
0 g
s
.181 .129 .559 r
.79952 .26467 m .80024 .26352 L .80116 .26936 L p F P
0 g
s
0 0 0 r
.6064 .30397 m .60522 .305 L .60611 .30425 L closepath p F P
0 g
s
0 0 0 r
.60522 .305 m .60611 .30425 L .60383 .30658 L p F P
0 g
s
.147 0 .083 r
.5577 .34883 m .55813 .34788 L .54822 .35341 L p F P
0 g
s
.147 0 .083 r
.54988 .35513 m .5577 .34883 L p .54822 .35341 L F P
0 g
s
.147 0 .083 r
.54822 .35341 m .54672 .35691 L .54988 .35513 L p F P
0 g
s
.824 .419 .279 r
.27281 .37172 m .2744 .37497 L .27011 .37315 L closepath p F P
0 g
s
.674 .387 .477 r
.40598 .41789 m .40004 .41794 L .40189 .42265 L p F P
0 g
s
.679 .389 .475 r
.39043 .42261 m .40189 .42265 L .40004 .41794 L p F P
0 g
s
.679 .389 .475 r
.40004 .41794 m .39119 .41791 L .39043 .42261 L p F P
0 g
s
0 0 0 r
.61445 .29679 m .6064 .30397 L .60611 .30425 L p F P
0 g
s
.589 .666 .892 r
.77109 .21602 m .7707 .21606 L .76796 .21165 L p F P
0 g
s
.476 .163 .356 r
.49772 .39454 m .49872 .3903 L .48708 .39371 L p F P
0 g
s
.476 .163 .356 r
.48708 .39371 m .48605 .39793 L .49772 .39454 L p F P
0 g
s
0 .25 .706 r
.08611 .39881 m .0857 .39856 L .08977 .40177 L p F P
0 g
s
0 .25 .706 r
.08977 .40177 m .08989 .40185 L .08611 .39881 L p F P
0 g
s
.692 .401 .477 r
.38849 .42256 m .39043 .42261 L .39119 .41791 L p F P
0 g
s
.692 .401 .477 r
.39119 .41791 m .38686 .41779 L .38849 .42256 L p F P
0 g
s
.657 .371 .474 r
.41502 .41752 m .40598 .41789 L .40527 .42262 L p F P
0 g
s
.674 .387 .477 r
.40189 .42265 m .40527 .42262 L .40598 .41789 L p F P
0 g
s
0 0 0 r
.76536 .34717 m .76076 .35237 L .76651 .34524 L p F P
0 g
s
0 0 0 r
.76651 .34524 m .7671 .34458 L .76536 .34717 L p F P
0 g
s
0 0 .011 r
.78773 .3141 m .78601 .31653 L .78688 .31294 L p F P
0 g
s
0 0 .011 r
.78688 .31294 m .79041 .30793 L .78773 .3141 L p F P
0 g
s
.533 .865 .593 r
.61786 .29378 m .61445 .29679 L .61692 .29449 L closepath p F P
0 g
s
0 0 0 r
.6151 .29593 m .61692 .29449 L .61445 .29679 L p F P
0 g
s
0 0 0 r
.61276 .29814 m .6151 .29593 L p .61445 .29679 L F P
0 g
s
0 0 0 r
.60611 .30425 m .61276 .29814 L p .61445 .29679 L F P
0 g
s
0 .295 .746 r
.09547 .40501 m .08989 .40185 L .08611 .39881 L p F P
0 g
s
.492 0 0 r
.16857 .28508 m .16871 .28521 L .17239 .28869 L p F P
0 g
s
.507 0 0 r
.17251 .28892 m .17619 .29239 L .17239 .28869 L p F P
0 g
s
.507 0 0 r
.17239 .28869 m .16871 .28521 L .17251 .28892 L p F P
0 g
s
.7 .407 .476 r
.37644 .42204 m .38849 .42256 L .38686 .41779 L p F P
0 g
s
.7 .407 .476 r
.37547 .41876 m .37644 .42204 L p .38686 .41779 L F P
0 g
s
.7 .407 .476 r
.38686 .41779 m .37574 .41726 L .37547 .41876 L p F P
0 g
s
.534 .866 .593 r
.6237 .28858 m .61786 .29378 L .61692 .29449 L p F P
0 g
s
.589 .666 .892 r
.76796 .21165 m .77292 .21092 L .77109 .21602 L p F P
0 g
s
.563 .618 .865 r
.78007 .2101 m .77292 .21092 L .77109 .21602 L p F P
0 g
s
.563 .618 .865 r
.77109 .21602 m .78285 .21524 L .78007 .2101 L p F P
0 g
s
.357 .708 .985 r
.22795 .46329 m .23336 .46346 L .23954 .46583 L p F P
0 g
s
.374 .714 .987 r
.23336 .46346 m .22795 .46329 L .22436 .46102 L p F P
0 g
s
.818 .429 .315 r
.27646 .37949 m .2829 .38186 L .28067 .3774 L p F P
0 g
s
.818 .429 .315 r
.28067 .3774 m .2744 .37497 L .27646 .37949 L p F P
0 g
s
.638 .938 .698 r
.62931 .28361 m .6237 .28858 L .62761 .28455 L closepath p F P
0 g
s
.534 .866 .593 r
.62658 .28514 m .62761 .28455 L .6237 .28858 L p F P
0 g
s
.534 .866 .593 r
.62123 .29016 m .62658 .28514 L p .6237 .28858 L F P
0 g
s
.534 .866 .593 r
.61692 .29449 m .62123 .29016 L p .6237 .28858 L F P
0 g
s
.83 .395 .205 r
.25177 .35799 m .25203 .35847 L .25754 .36118 L p F P
0 g
s
.836 .413 .232 r
.25428 .36288 m .25992 .36555 L .25754 .36118 L p F P
0 g
s
.836 .413 .232 r
.25754 .36118 m .25203 .35847 L .25428 .36288 L p F P
0 g
s
.612 .951 .919 r
.64433 .43498 m .64689 .43508 L .63527 .44092 L p F P
0 g
s
.612 .951 .919 r
.63527 .44092 m .63473 .44089 L .64433 .43498 L p F P
0 g
s
.631 .936 .697 r
.63305 .28033 m .62931 .28361 L .62761 .28455 L p F P
0 g
s
.717 .981 .779 r
.64078 .27356 m .63305 .28033 L .6382 .27444 L closepath p F P
0 g
s
.631 .936 .697 r
.63805 .2745 m .6382 .27444 L .63305 .28033 L p F P
0 g
s
.631 .936 .697 r
.6298 .28216 m .63805 .2745 L p .63305 .28033 L F P
0 g
s
.631 .936 .697 r
.62761 .28455 m .6298 .28216 L p .63305 .28033 L F P
0 g
s
.655 .37 .475 r
.4202 .41729 m .41502 .41752 L .41721 .42214 L p F P
0 g
s
.657 .371 .474 r
.40527 .42262 m .41721 .42214 L .41502 .41752 L p F P
0 g
s
0 .359 .787 r
.1073 .41313 m .11001 .41443 L .11438 .41751 L p F P
0 g
s
0 .391 .814 r
.11665 .41741 m .121 .4205 L .11438 .41751 L p F P
0 g
s
0 .391 .814 r
.11438 .41751 m .11001 .41443 L .11665 .41741 L p F P
0 g
s
.618 .769 .952 r
.33596 .47755 m .34713 .47476 L .35048 .47766 L p F P
0 g
s
.64 .757 .933 r
.34713 .47476 m .33596 .47755 L .33258 .47481 L p F P
0 g
s
.77 .436 .42 r
.31711 .40421 m .3254 .40595 L .3235 .40131 L p F P
0 g
s
.77 .436 .42 r
.3235 .40131 m .31543 .39951 L .31711 .40421 L p F P
0 g
s
.574 .878 .583 r
.74542 .36902 m .74473 .36958 L .74704 .36731 L closepath p F P
0 g
s
.584 .291 .437 r
.46076 .40788 m .45142 .40937 L .45705 .41291 L p F P
0 g
s
.583 .293 .442 r
.44717 .41455 m .45705 .41291 L .45142 .40937 L p F P
0 g
s
.366 .708 .986 r
.23872 .46356 m .23336 .46346 L .23954 .46583 L p F P
0 g
s
.366 .708 .986 r
.23954 .46583 m .24229 .46591 L .23872 .46356 L p F P
0 g
s
.705 .978 .779 r
.64256 .27203 m .64078 .27356 L .6382 .27444 L p F P
0 g
s
.741 .424 .446 r
.34363 .40928 m .34326 .4106 L .34276 .40915 L closepath p F P
0 g
s
0 .116 .594 r
.06511 .38236 m .0643 .38172 L .06812 .38505 L p F P
0 g
s
0 .116 .594 r
.06812 .38505 m .06889 .38566 L .06511 .38236 L p F P
0 g
s
.74 .988 .787 r
.64256 .27203 m .65225 .26372 L .64954 .26415 L p F P
0 g
s
.74 .988 .787 r
.64954 .26415 m .64755 .26594 L .64256 .27203 L p F P
0 g
s
.705 .978 .779 r
.63848 .27411 m .64755 .26594 L .64256 .27203 L p F P
0 g
s
.705 .978 .779 r
.6382 .27444 m .63848 .27411 L p .64256 .27203 L F P
0 g
s
.635 .351 .471 r
.43283 .41622 m .4202 .41729 L .41951 .42203 L p F P
0 g
s
.655 .37 .475 r
.41721 .42214 m .41951 .42203 L .4202 .41729 L p F P
0 g
s
.263 .653 .966 r
.20644 .45555 m .20213 .45506 L .20773 .45764 L p F P
0 g
s
.263 .653 .966 r
.20773 .45764 m .21006 .45792 L .20644 .45555 L p F P
0 g
s
0 0 .222 r
.79462 .29897 m .79252 .30196 L .794 .2962 L p F P
0 g
s
0 0 .222 r
.794 .2962 m .79499 .29479 L .79462 .29897 L p F P
0 g
s
.709 .415 .478 r
.37574 .41726 m .37547 .41876 L .37501 .41721 L closepath p F P
0 g
s
.603 .939 .946 r
.62085 .44606 m .61304 .44954 L .61975 .4459 L closepath p F P
0 g
s
.619 .935 .961 r
.61802 .44555 m .61975 .4459 L .61304 .44954 L p F P
0 g
s
.619 .935 .961 r
.60639 .45059 m .61802 .44555 L p .61304 .44954 L F P
0 g
s
0 0 0 r
.60436 .30609 m .60383 .30658 L .60611 .30425 L p F P
0 g
s
0 0 0 r
.60611 .30425 m .61276 .29814 L .60436 .30609 L p F P
0 g
s
.582 .927 .736 r
.71023 .39869 m .70696 .40109 L .70943 .39903 L closepath p F P
0 g
s
.606 .946 .78 r
.70767 .39954 m .70943 .39903 L .70696 .40109 L p F P
0 g
s
.606 .946 .78 r
.70131 .40404 m .70767 .39954 L p .70696 .40109 L F P
0 g
s
.606 .946 .78 r
.69738 .40733 m .70131 .40404 L p .70696 .40109 L F P
0 g
s
.739 .423 .447 r
.33517 .41246 m .33369 .40768 L .34276 .40915 L p F P
0 g
s
.739 .423 .447 r
.34242 .41361 m .33517 .41246 L p .34276 .40915 L F P
0 g
s
.739 .423 .447 r
.34276 .40915 m .34326 .4106 L .34242 .41361 L p F P
0 g
s
0 0 0 r
.76586 .34655 m .76536 .34717 L .7671 .34458 L p F P
0 g
s
0 0 0 r
.7671 .34458 m .77125 .33952 L .76586 .34655 L p F P
0 g
s
.705 .413 .479 r
.36528 .42124 m .364 .41636 L .37501 .41721 L p F P
0 g
s
.705 .413 .479 r
.37494 .42195 m .36528 .42124 L p .37501 .41721 L F P
0 g
s
.705 .413 .479 r
.37501 .41721 m .37547 .41876 L .37494 .42195 L p F P
0 g
s
.052 0 0 r
.5692 .33881 m .56932 .33857 L .55974 .34455 L p F P
0 g
s
.052 0 0 r
.56027 .34654 m .5692 .33881 L p .55974 .34455 L F P
0 g
s
.052 0 0 r
.55974 .34455 m .55813 .34788 L .56027 .34654 L p F P
0 g
s
.028 0 .399 r
.80181 .27976 m .79831 .28522 L .79834 .27993 L p F P
0 g
s
.028 0 .399 r
.80182 .2777 m .80181 .27976 L p .79834 .27993 L F P
0 g
s
.028 0 .399 r
.79834 .27993 m .80169 .2747 L .80182 .2777 L p F P
0 g
s
.776 .416 .376 r
.30044 .3955 m .29858 .39088 L .30594 .39293 L p F P
0 g
s
.776 .416 .376 r
.3075 .39736 m .30044 .3955 L p .30594 .39293 L F P
0 g
s
.776 .416 .376 r
.30594 .39293 m .30775 .39693 L .3075 .39736 L p F P
0 g
s
.697 .164 0 r
.20641 .32092 m .20308 .31713 L .2075 .32028 L p F P
0 g
s
.697 .164 0 r
.2075 .32028 m .21006 .32315 L .20641 .32092 L p F P
0 g
s
.825 .356 .092 r
.23086 .34139 m .23095 .34152 L .23589 .34445 L p F P
0 g
s
.834 .376 .12 r
.23344 .34582 m .23849 .34871 L .23589 .34445 L p F P
0 g
s
.834 .376 .12 r
.23589 .34445 m .23095 .34152 L .23344 .34582 L p F P
0 g
s
.769 .996 .854 r
.65229 .26372 m .65225 .26372 L .65235 .26364 L closepath p F P
0 g
s
.613 .889 .989 r
.56576 .46229 m .5542 .46624 L .55121 .46492 L p F P
0 g
s
.603 .884 .991 r
.53967 .46867 m .55121 .46492 L .5542 .46624 L p F P
0 g
s
.189 .609 .945 r
.18014 .44808 m .17801 .44768 L .17433 .44529 L p F P
0 g
s
.521 .225 .405 r
.47951 .39953 m .47403 .40091 L .47318 .40535 L p F P
0 g
s
.502 .763 .989 r
.27461 .47201 m .27939 .4715 L .28661 .47353 L p F P
0 g
s
.497 .755 .987 r
.28559 .47079 m .27939 .4715 L .28661 .47353 L p F P
0 g
s
.497 .755 .987 r
.28661 .47353 m .28906 .4733 L .28559 .47079 L p F P
0 g
s
.75 .994 .837 r
.65235 .26364 m .65225 .26372 L .64954 .26415 L p F P
0 g
s
.796 .994 .872 r
.657 .25764 m .65235 .26364 L .6627 .25506 L p F P
0 g
s
.75 .994 .837 r
.64954 .26415 m .657 .25764 L .65235 .26364 L p F P
0 g
s
.635 .763 .94 r
.35048 .47766 m .36168 .47453 L .365 .4776 L p F P
0 g
s
.657 .747 .916 r
.36168 .47453 m .35048 .47766 L .34713 .47476 L p F P
0 g
s
.522 .77 .987 r
.27939 .4715 m .27461 .47201 L .27111 .46968 L p F P
0 g
s
.383 .059 .287 r
.52228 .37446 m .51174 .38006 L .51108 .38235 L p F P
0 g
s
0 0 0 r
.76511 .34745 m .76536 .34717 L .76076 .35237 L p F P
0 g
s
0 0 0 r
.75954 .35387 m .76511 .34745 L p .76076 .35237 L F P
0 g
s
0 0 0 r
.75559 .35838 m .75954 .35387 L p .76076 .35237 L F P
0 g
s
0 0 0 r
.76076 .35237 m .7561 .35775 L .75559 .35838 L p F P
0 g
s
.602 .936 .739 r
.71897 .39204 m .71023 .39869 L .70943 .39903 L p F P
0 g
s
.137 .099 .548 r
.80408 .2641 m .80116 .26936 L .80024 .26352 L p F P
0 g
s
.137 .099 .548 r
.80024 .26352 m .80255 .25932 L .80408 .2641 L p F P
0 g
s
.509 0 0 r
.1801 .29608 m .18393 .29949 L .18 .2958 L p F P
0 g
s
.509 0 0 r
.18 .2958 m .17619 .29239 L .1801 .29608 L p F P
0 g
s
.012 .483 .872 r
.14353 .43301 m .1425 .43229 L .14221 .4322 L closepath p F P
0 g
s
.435 .504 .831 r
.78586 .22118 m .78849 .22689 L .79309 .22816 L p F P
0 g
s
.603 .953 .859 r
.67285 .42221 m .66827 .42488 L .67191 .42233 L closepath p F P
0 g
s
.619 .958 .886 r
.67016 .42239 m .67191 .42233 L .66827 .42488 L p F P
0 g
s
.619 .958 .886 r
.65852 .42898 m .67016 .42239 L p .66827 .42488 L F P
0 g
s
.735 .829 .923 r
.73331 .21495 m .73877 .21231 L .73608 .20938 L p F P
0 g
s
.735 .829 .923 r
.73608 .20938 m .73533 .20977 L .73331 .21495 L p F P
0 g
s
.72 .841 .939 r
.72435 .21548 m .73533 .20977 L .73331 .21495 L p F P
0 g
s
.79 .411 .339 r
.29079 .38442 m .29022 .38508 L .28974 .3841 L closepath p F P
0 g
s
.628 .95 .939 r
.64413 .43495 m .64433 .43498 L .63473 .44089 L p F P
0 g
s
.628 .95 .939 r
.63473 .44089 m .63248 .44063 L .64413 .43495 L p F P
0 g
s
.646 .757 .93 r
.365 .4776 m .37625 .47422 L .37954 .47742 L p F P
0 g
s
.667 .737 .902 r
.37625 .47422 m .365 .4776 L .36168 .47453 L p F P
0 g
s
0 .155 .627 r
.06889 .38566 m .07283 .38857 L .07673 .39186 L p F P
0 g
s
0 .163 .64 r
.07283 .38857 m .06889 .38566 L .06511 .38236 L p F P
0 g
s
0 .365 .796 r
.11001 .41443 m .1073 .41313 L .10354 .41027 L p F P
0 g
s
0 0 0 r
.78444 .32046 m .78015 .32608 L .7836 .31968 L p F P
0 g
s
0 0 0 r
.78514 .31916 m .78444 .32046 L p .7836 .31968 L F P
0 g
s
0 0 0 r
.7836 .31968 m .78601 .31653 L .78514 .31916 L p F P
0 g
s
.822 .407 .256 r
.26223 .36996 m .26832 .37247 L .26585 .36811 L p F P
0 g
s
.822 .407 .256 r
.26585 .36811 m .25992 .36555 L .26223 .36996 L p F P
0 g
s
.796 .993 .875 r
.66374 .2542 m .6627 .25506 L .66333 .25418 L closepath p F P
0 g
s
.796 .994 .872 r
.66104 .25411 m .657 .25764 L p .6627 .25506 L F P
0 g
s
.796 .994 .872 r
.6627 .25506 m .66333 .25418 L .66104 .25411 L p F P
0 g
s
.613 .852 .989 r
.52206 .46901 m .52325 .46971 L .5116 .47304 L p F P
0 g
s
.613 .852 .989 r
.5116 .47304 m .51056 .47243 L .52206 .46901 L p F P
0 g
s
.781 .992 .881 r
.67369 .24627 m .66374 .2542 L .66333 .25418 L p F P
0 g
s
.772 .916 .935 r
.70999 .22023 m .71233 .22195 L .71198 .22265 L p F P
0 g
s
.772 .916 .935 r
.69887 .22763 m .70999 .22023 L p .71198 .22265 L F P
0 g
s
.772 .916 .935 r
.69859 .22809 m .69887 .22763 L p .71198 .22265 L F P
0 g
s
.776 .889 .926 r
.71268 .22221 m .71198 .22265 L .71233 .22195 L closepath p F P
0 g
s
.611 .928 .968 r
.60392 .45003 m .60639 .45059 L .59479 .45539 L p F P
0 g
s
.611 .928 .968 r
.59479 .45539 m .59371 .45513 L .60392 .45003 L p F P
0 g
s
.793 .412 .334 r
.28499 .38639 m .2829 .38186 L .28974 .3841 L p F P
0 g
s
.793 .412 .334 r
.28815 .3874 m .28499 .38639 L p .28974 .3841 L F P
0 g
s
.793 .412 .334 r
.28974 .3841 m .29022 .38508 L .28815 .3874 L p F P
0 g
s
0 0 0 r
.7561 .35775 m .75436 .35969 L .75559 .35838 L closepath p F P
0 g
s
.727 .43 .477 r
.35869 .42055 m .36528 .42124 L .364 .41636 L p F P
0 g
s
.727 .43 .477 r
.364 .41636 m .35957 .4159 L .35869 .42055 L p F P
0 g
s
.215 .196 .62 r
.80551 .25397 m .80255 .25932 L .80013 .25484 L p F P
0 g
s
.215 .196 .62 r
.80013 .25484 m .80301 .24952 L .80551 .25397 L p F P
0 g
s
.764 .888 .933 r
.72166 .21309 m .72435 .21548 L .71268 .22221 L p F P
0 g
s
.764 .888 .933 r
.71516 .21708 m .72166 .21309 L p .71268 .22221 L F P
0 g
s
.764 .888 .933 r
.71268 .22221 m .71233 .22195 L .71516 .21708 L p F P
0 g
s
.652 .753 .924 r
.37954 .47742 m .39082 .47389 L .39408 .47719 L p F P
0 g
s
.672 .729 .893 r
.39082 .47389 m .37954 .47742 L .37625 .47422 L p F P
0 g
s
.574 .912 .688 r
.72177 .38981 m .71897 .39204 L .72105 .3902 L closepath p F P
0 g
s
.602 .936 .739 r
.71925 .39089 m .72105 .3902 L .71897 .39204 L p F P
0 g
s
.602 .936 .739 r
.7143 .39468 m .71925 .39089 L p .71897 .39204 L F P
0 g
s
.602 .936 .739 r
.70943 .39903 m .7143 .39468 L p .71897 .39204 L F P
0 g
s
0 .321 .764 r
.09978 .40732 m .09547 .40501 L .09963 .40818 L p F P
0 g
s
0 .321 .764 r
.09963 .40818 m .10354 .41027 L .09978 .40732 L p F P
0 g
s
.612 .877 .991 r
.55121 .46492 m .53967 .46867 L .53664 .46719 L p F P
0 g
s
.603 .873 .992 r
.52512 .47075 m .53664 .46719 L .53967 .46867 L p F P
0 g
s
.109 .555 .916 r
.16022 .44042 m .16027 .44043 L .16007 .44032 L closepath p F P
0 g
s
.539 .841 .521 r
.75258 .36139 m .74704 .36731 L .75436 .35969 L p F P
0 g
s
.539 .841 .521 r
.75376 .36015 m .75258 .36139 L p .75436 .35969 L F P
0 g
s
.539 .841 .521 r
.75436 .35969 m .75559 .35838 L .75376 .36015 L p F P
0 g
s
.636 .354 .474 r
.43388 .41613 m .43367 .41766 L .43283 .41622 L closepath p F P
0 g
s
.635 .351 .471 r
.43326 .42092 m .43367 .41766 L .43283 .41622 L p F P
0 g
s
.635 .351 .471 r
.41951 .42203 m .43326 .42092 L p .43283 .41622 L F P
0 g
s
.749 .434 .45 r
.34326 .4106 m .34431 .41392 L .34242 .41361 L closepath p F P
0 g
s
.19 .599 .944 r
.16483 .43974 m .16974 .44259 L .16027 .44043 L p F P
0 g
s
.19 .599 .944 r
.15653 .43787 m .16483 .43974 L p .16027 .44043 L F P
0 g
s
.19 .599 .944 r
.16027 .44043 m .16007 .44032 L .15653 .43787 L p F P
0 g
s
0 0 0 r
.56983 .33822 m .56932 .33857 L .57106 .33543 L p F P
0 g
s
0 0 0 r
.57106 .33543 m .57878 .33008 L .56983 .33822 L p F P
0 g
s
.787 .287 0 r
.21006 .32315 m .21083 .32423 L .2153 .32736 L p F P
0 g
s
.797 .303 0 r
.21365 .32838 m .2182 .33147 L .2153 .32736 L p F P
0 g
s
.797 .303 0 r
.2153 .32736 m .21083 .32423 L .21365 .32838 L p F P
0 g
s
.706 .415 .48 r
.37547 .41876 m .37644 .42204 L .37494 .42195 L closepath p F P
0 g
s
.621 .34 .471 r
.44658 .41935 m .44717 .41455 L .43388 .41613 L p F P
0 g
s
.621 .34 .471 r
.43575 .42061 m .44658 .41935 L p .43388 .41613 L F P
0 g
s
.621 .34 .471 r
.43388 .41613 m .43367 .41766 L .43575 .42061 L p F P
0 g
s
.826 .371 .145 r
.24105 .353 m .24644 .35577 L .24375 .35153 L p F P
0 g
s
.826 .371 .145 r
.24375 .35153 m .23849 .34871 L .24105 .353 L p F P
0 g
s
.596 .922 .692 r
.72948 .38345 m .72177 .38981 L .72105 .3902 L p F P
0 g
s
.094 .54 .909 r
.16007 .44032 m .15653 .43787 L .1554 .43757 L closepath p F P
0 g
s
0 .197 .667 r
.07781 .39202 m .08172 .39531 L .07673 .39186 L p F P
0 g
s
0 .197 .667 r
.07673 .39186 m .07283 .38857 L .07781 .39202 L p F P
0 g
s
.624 .961 .86 r
.6818 .41546 m .68446 .41517 L .67285 .42221 L p F P
0 g
s
.624 .961 .86 r
.67799 .41778 m .6818 .41546 L p .67285 .42221 L F P
0 g
s
.624 .961 .86 r
.67285 .42221 m .67191 .42233 L .67799 .41778 L p F P
0 g
s
.024 .487 .878 r
.13878 .42965 m .13757 .42924 L .14221 .4322 L p F P
0 g
s
.024 .487 .878 r
.14221 .4322 m .1425 .43229 L .13878 .42965 L p F P
0 g
s
.655 .752 .921 r
.39408 .47719 m .40539 .4736 L .40863 .47693 L p F P
0 g
s
.673 .725 .889 r
.40539 .4736 m .39408 .47719 L .39082 .47389 L p F P
0 g
s
.425 .735 .991 r
.24229 .46591 m .25314 .46562 L .25668 .46799 L p F P
0 g
s
.44 .736 .99 r
.25314 .46562 m .24229 .46591 L .23872 .46356 L p F P
0 g
s
.315 .684 .978 r
.21006 .45792 m .22076 .45869 L .22436 .46102 L p F P
0 g
s
.338 .687 .98 r
.22076 .45869 m .21006 .45792 L .20644 .45555 L p F P
0 g
s
.56 .27 .431 r
.47245 .40995 m .47318 .40535 L .46076 .40788 L p F P
0 g
s
.56 .27 .431 r
.46076 .40788 m .45998 .41244 L .47245 .40995 L p F P
0 g
s
.584 .291 .437 r
.45705 .41291 m .45998 .41244 L .46076 .40788 L p F P
0 g
s
.575 .766 .969 r
.3001 .4715 m .28906 .4733 L .28559 .47079 L p F P
0 g
s
0 0 .204 r
.79622 .29648 m .79462 .29897 L .79499 .29479 L p F P
0 g
s
0 0 .204 r
.79499 .29479 m .79758 .29074 L .79622 .29648 L p F P
0 g
s
0 .432 .841 r
.12485 .42325 m .12551 .42352 L .12165 .42094 L closepath p F P
0 g
s
.73 .434 .478 r
.35501 .42015 m .35869 .42055 L .35957 .4159 L p F P
0 g
s
.73 .434 .478 r
.35957 .4159 m .35378 .41526 L .35501 .42015 L p F P
0 g
s
.527 0 0 r
.18568 .30113 m .18393 .29949 L .18791 .30283 L p F P
0 g
s
.527 0 0 r
.18791 .30283 m .18931 .30414 L .18568 .30113 L p F P
0 g
s
.808 .978 .898 r
.67526 .24502 m .67369 .24627 L .67459 .24488 L closepath p F P
0 g
s
.781 .992 .881 r
.67256 .24445 m .67459 .24488 L .67369 .24627 L p F P
0 g
s
.781 .992 .881 r
.66692 .24919 m .67256 .24445 L p .67369 .24627 L F P
0 g
s
.781 .992 .881 r
.66333 .25418 m .66692 .24919 L p .67369 .24627 L F P
0 g
s
.645 .706 .891 r
.7533 .21093 m .76524 .20747 L .76796 .21165 L p F P
0 g
s
.66 .725 .897 r
.76524 .20747 m .7533 .21093 L .7506 .20744 L p F P
0 g
s
.692 .764 .907 r
.73877 .21231 m .7506 .20744 L .7533 .21093 L p F P
0 g
s
.087 .528 .905 r
.15063 .43467 m .1425 .43229 L .13878 .42965 L p F P
0 g
s
.766 .89 .932 r
.71233 .22195 m .70999 .22023 L .71516 .21708 L closepath p F P
0 g
s
.792 .977 .907 r
.68558 .23719 m .67526 .24502 L .67459 .24488 L p F P
0 g
s
.577 .88 .586 r
.74463 .36921 m .75258 .36139 L .74704 .36731 L p F P
0 g
s
.577 .88 .586 r
.74303 .37094 m .74463 .36921 L p .74704 .36731 L F P
0 g
s
.577 .88 .586 r
.74704 .36731 m .74473 .36958 L .74303 .37094 L p F P
0 g
s
.189 .609 .945 r
.17433 .44529 m .17482 .44538 L .18014 .44808 L p F P
0 g
s
.213 .619 .952 r
.18487 .44704 m .17482 .44538 L .18014 .44808 L p F P
0 g
s
.213 .619 .952 r
.18014 .44808 m .18853 .44951 L .18487 .44704 L p F P
0 g
s
.768 .448 .445 r
.32672 .41078 m .33517 .41246 L .33369 .40768 L p F P
0 g
s
.768 .448 .445 r
.32542 .40601 m .32672 .41078 L p .33369 .40768 L F P
0 g
s
.768 .448 .445 r
.33369 .40768 m .32544 .40595 L .32542 .40601 L p F P
0 g
s
.565 .893 .636 r
.73327 .38015 m .72948 .38345 L .73224 .38083 L closepath p F P
0 g
s
.596 .922 .692 r
.73081 .38154 m .73224 .38083 L .72948 .38345 L p F P
0 g
s
.596 .922 .692 r
.72566 .38581 m .73081 .38154 L p .72948 .38345 L F P
0 g
s
.596 .922 .692 r
.72105 .3902 m .72566 .38581 L p .72948 .38345 L F P
0 g
s
.654 .754 .923 r
.40863 .47693 m .41996 .47336 L .42318 .47665 L p F P
0 g
s
.671 .726 .891 r
.41996 .47336 m .40863 .47693 L .40539 .4736 L p F P
0 g
s
.795 .994 .872 r
.66333 .25418 m .66104 .25411 L .66692 .24919 L closepath p F P
0 g
s
.554 .869 .581 r
.74473 .36958 m .73876 .37523 L .74303 .37094 L closepath p F P
0 g
s
.521 .219 .396 r
.48605 .39793 m .48571 .3996 L .47951 .39953 L closepath p F P
0 g
s
.521 .225 .405 r
.4852 .40236 m .48571 .3996 L .47951 .39953 L p F P
0 g
s
.521 .225 .405 r
.47318 .40535 m .4852 .40236 L p .47951 .39953 L F P
0 g
s
.789 .454 .42 r
.30948 .40225 m .31711 .40421 L .31543 .39951 L p F P
0 g
s
.789 .454 .42 r
.31543 .39951 m .30797 .3975 L .30948 .40225 L p F P
0 g
s
.587 .903 .641 r
.73876 .37523 m .73327 .38015 L .73224 .38083 L p F P
0 g
s
.562 .876 .591 r
.61692 .29449 m .6151 .29593 L .62123 .29016 L closepath p F P
0 g
s
.813 .44 .351 r
.29022 .38508 m .2917 .38866 L .28815 .3874 L closepath p F P
0 g
s
.587 .903 .641 r
.74232 .37138 m .74303 .37094 L .73876 .37523 L p F P
0 g
s
.587 .903 .641 r
.73569 .37735 m .74232 .37138 L p .73876 .37523 L F P
0 g
s
.587 .903 .641 r
.73224 .38083 m .73569 .37735 L p .73876 .37523 L F P
0 g
s
.616 .86 .989 r
.53464 .46607 m .53664 .46719 L .52512 .47075 L p F P
0 g
s
.616 .86 .989 r
.52512 .47075 m .52325 .46971 L .53464 .46607 L p F P
0 g
s
.705 .78 .91 r
.7506 .20744 m .73877 .21231 L .73608 .20938 L p F P
0 g
s
.65 .76 .93 r
.42318 .47665 m .43453 .47315 L .43774 .47633 L p F P
0 g
s
.666 .731 .898 r
.43453 .47315 m .42318 .47665 L .41996 .47336 L p F P
0 g
s
.054 .5 .891 r
.12854 .42321 m .13301 .42625 L .12551 .42352 L p F P
0 g
s
.054 .5 .891 r
.1211 .42054 m .12854 .42321 L p .12551 .42352 L F P
0 g
s
.054 .5 .891 r
.12551 .42352 m .12165 .42094 L .1211 .42054 L p F P
0 g
s
.834 .395 .189 r
.25177 .35799 m .25203 .35847 L .25117 .35802 L closepath p F P
0 g
s
.618 .944 .945 r
.62967 .44026 m .63248 .44063 L .62085 .44606 L p F P
0 g
s
.618 .944 .945 r
.62891 .44061 m .62967 .44026 L p .62085 .44606 L F P
0 g
s
.618 .944 .945 r
.62085 .44606 m .61975 .4459 L .62891 .44061 L p F P
0 g
s
.64 .965 .828 r
.69738 .40733 m .69607 .4076 L .70131 .40404 L closepath p F P
0 g
s
.83 .437 .307 r
.27038 .37698 m .27646 .37949 L .2744 .37497 L p F P
0 g
s
.83 .437 .307 r
.26904 .37385 m .27038 .37698 L p .2744 .37497 L F P
0 g
s
.83 .437 .307 r
.2744 .37497 m .27011 .37315 L .26904 .37385 L p F P
0 g
s
.796 .3 0 r
.22111 .33561 m .22594 .3386 L .22293 .3345 L p F P
0 g
s
.796 .3 0 r
.22293 .3345 m .2182 .33147 L .22111 .33561 L p F P
0 g
s
.744 .448 .481 r
.34538 .41885 m .35501 .42015 L .35378 .41526 L p F P
0 g
s
.744 .448 .481 r
.35378 .41526 m .34431 .41392 L .34538 .41885 L p F P
0 g
s
.626 .956 .916 r
.65803 .42925 m .64689 .43508 L .64433 .43498 L p F P
0 g
s
.645 .771 .94 r
.43774 .47633 m .44911 .47293 L .4523 .47593 L p F P
0 g
s
.66 .742 .91 r
.44911 .47293 m .43774 .47633 L .43453 .47315 L p F P
0 g
s
.641 .961 .794 r
.70943 .39903 m .70767 .39954 L .7143 .39468 L closepath p F P
0 g
s
.626 .834 .98 r
.52206 .46901 m .51056 .47243 L .50747 .47038 L p F P
0 g
s
.62 .833 .982 r
.49599 .47369 m .50747 .47038 L .51056 .47243 L p F P
0 g
s
.805 .45 .384 r
.2934 .39334 m .30044 .3955 L .29858 .39088 L p F P
0 g
s
.805 .45 .384 r
.29858 .39088 m .2917 .38866 L .2934 .39334 L p F P
0 g
s
.638 .965 .857 r
.68489 .41511 m .68446 .41517 L .68631 .414 L closepath p F P
0 g
s
.589 .769 .965 r
.30354 .47412 m .31464 .47184 L .31805 .47461 L p F P
0 g
s
.611 .763 .952 r
.31464 .47184 m .30354 .47412 L .3001 .4715 L p F P
0 g
s
.295 .295 .689 r
.80517 .24555 m .80301 .24952 L .79944 .24542 L p F P
0 g
s
.295 .295 .689 r
.8043 .24221 m .80517 .24555 L p .79944 .24542 L F P
0 g
s
.295 .295 .689 r
.79944 .24542 m .80228 .24008 L .8043 .24221 L p F P
0 g
s
.435 .504 .831 r
.79567 .22286 m .78602 .2208 L .78586 .22118 L p F P
0 g
s
.435 .504 .831 r
.79309 .22816 m .79567 .22286 L p .78586 .22118 L F P
0 g
s
.493 .55 .843 r
.78565 .22075 m .78602 .2208 L .78586 .22118 L closepath p F P
0 g
s
0 0 .116 r
.794 .30284 m .79041 .30793 L .79252 .30196 L p F P
0 g
s
0 0 .116 r
.79252 .30196 m .79462 .29897 L .794 .30284 L p F P
0 g
s
.616 .339 .475 r
.43367 .41766 m .43575 .42061 L .43326 .42092 L closepath p F P
0 g
s
.605 .677 .892 r
.77292 .21092 m .76796 .21165 L .76524 .20747 L p F P
0 g
s
.843 .417 .222 r
.24889 .36012 m .25428 .36288 L .25203 .35847 L p F P
0 g
s
.843 .417 .222 r
.24804 .3584 m .24889 .36012 L p .25203 .35847 L F P
0 g
s
.843 .417 .222 r
.25203 .35847 m .25117 .35802 L .24804 .3584 L p F P
0 g
s
.639 .784 .951 r
.4523 .47593 m .4637 .47262 L .46686 .4754 L p F P
0 g
s
.653 .757 .925 r
.4637 .47262 m .4523 .47593 L .44911 .47293 L p F P
0 g
s
.691 .171 0 r
.18931 .30414 m .19143 .30667 L .19549 .30998 L p F P
0 g
s
.694 .174 0 r
.1947 .31062 m .19881 .31391 L .19549 .30998 L p F P
0 g
s
.694 .174 0 r
.19549 .30998 m .19143 .30667 L .1947 .31062 L p F P
0 g
s
.383 .712 .987 r
.23515 .46114 m .22716 .46108 L .23336 .46346 L p F P
0 g
s
.383 .712 .987 r
.23336 .46346 m .23872 .46356 L .23515 .46114 L p F P
0 g
s
.374 .714 .987 r
.22436 .46102 m .22716 .46108 L .23336 .46346 L p F P
0 g
s
.616 .914 .98 r
.59189 .45459 m .58029 .45904 L .57735 .45808 L p F P
0 g
s
0 0 0 r
.78037 .32707 m .78444 .32046 L .78015 .32608 L p F P
0 g
s
0 0 0 r
.77624 .33255 m .78037 .32707 L p .78015 .32608 L F P
0 g
s
0 0 0 r
.78015 .32608 m .77628 .33246 L .77624 .33255 L p F P
0 g
s
0 0 0 r
.58218 .32607 m .58068 .32839 L .58745 .32204 L closepath p F P
0 g
s
.808 .955 .912 r
.6868 .23626 m .68558 .23719 L .68624 .23604 L closepath p F P
0 g
s
.792 .977 .907 r
.6841 .23524 m .68624 .23604 L .68558 .23719 L p F P
0 g
s
.792 .977 .907 r
.6775 .24053 m .6841 .23524 L p .68558 .23719 L F P
0 g
s
.792 .977 .907 r
.67459 .24488 m .6775 .24053 L p .68558 .23719 L F P
0 g
s
.573 .857 .529 r
.75559 .35838 m .75376 .36015 L .75954 .35387 L closepath p F P
0 g
s
.522 .77 .987 r
.27111 .46968 m .27177 .4696 L .27939 .4715 L p F P
0 g
s
.519 .756 .982 r
.28211 .46818 m .27177 .4696 L .27939 .4715 L p F P
0 g
s
.519 .756 .982 r
.27939 .4715 m .28559 .47079 L .28211 .46818 L p F P
0 g
s
.51 .572 .854 r
.78602 .2208 m .78565 .22075 L .78285 .21524 L p F P
0 g
s
.631 .815 .971 r
.50747 .47038 m .49599 .47369 L .49288 .4714 L p F P
0 g
s
.625 .817 .974 r
.48143 .47467 m .49288 .4714 L .49599 .47369 L p F P
0 g
s
.632 .8 .963 r
.46686 .4754 m .47829 .47213 L .48143 .47467 L p F P
0 g
s
.646 .775 .942 r
.47829 .47213 m .46686 .4754 L .4637 .47262 L p F P
0 g
s
.102 .032 .483 r
.80112 .26942 m .80116 .26936 L .80125 .27026 L closepath p F P
0 g
s
.365 .028 .254 r
.52322 .37399 m .52228 .37446 L .52318 .37412 L closepath p F P
0 g
s
.383 .059 .287 r
.52203 .37811 m .52318 .37412 L .52228 .37446 L p F P
0 g
s
.383 .059 .287 r
.51108 .38235 m .52203 .37811 L p .52228 .37446 L F P
0 g
s
.801 .955 .916 r
.69568 .22652 m .69837 .22796 L .6868 .23626 L p F P
0 g
s
.801 .955 .916 r
.68905 .23153 m .69568 .22652 L p .6868 .23626 L F P
0 g
s
.801 .955 .916 r
.6868 .23626 m .68624 .23604 L .68905 .23153 L p F P
0 g
s
.638 .795 .958 r
.49288 .4714 m .48143 .47467 L .47829 .47213 L p F P
0 g
s
.005 0 .452 r
.8048 .26915 m .80408 .2641 L .80116 .26936 L p F P
0 g
s
.005 0 .452 r
.80183 .27447 m .8048 .26915 L p .80116 .26936 L F P
0 g
s
.005 0 .452 r
.80116 .26936 m .80125 .27026 L .80183 .27447 L p F P
0 g
s
.51 .572 .854 r
.78285 .21524 m .78811 .21563 L .78602 .2208 L p F P
0 g
s
.481 .539 .84 r
.79684 .22049 m .79567 .22286 L .78602 .2208 L p F P
0 g
s
.481 .539 .84 r
.79524 .21677 m .79684 .22049 L p .78602 .2208 L F P
0 g
s
.481 .539 .84 r
.78602 .2208 m .78811 .21563 L .79524 .21677 L p F P
0 g
s
.622 .922 .975 r
.60351 .44991 m .60392 .45003 L .59371 .45513 L p F P
0 g
s
.622 .922 .975 r
.59371 .45513 m .59189 .45459 L .60351 .44991 L p F P
0 g
s
0 .256 .717 r
.08234 .39569 m .08172 .39531 L .0857 .39856 L p F P
0 g
s
0 .256 .717 r
.0857 .39856 m .08611 .39881 L .08234 .39569 L p F P
0 g
s
.393 .08 .31 r
.52095 .3822 m .52203 .37811 L .51108 .38235 L p F P
0 g
s
.393 .08 .31 r
.51108 .38235 m .51001 .38647 L .52095 .3822 L p F P
0 g
s
.324 0 .238 r
.53381 .36948 m .53471 .36667 L .52322 .37399 L p F P
0 g
s
.324 0 .238 r
.52322 .37399 m .52318 .37412 L .53381 .36948 L p F P
0 g
s
.26 .651 .965 r
.19219 .4519 m .19658 .45244 L .20213 .45506 L p F P
0 g
s
.277 .657 .969 r
.20281 .45312 m .19658 .45244 L .20213 .45506 L p F P
0 g
s
.277 .657 .969 r
.20213 .45506 m .20644 .45555 L .20281 .45312 L p F P
0 g
s
.817 .37 .177 r
.25117 .35802 m .24804 .3584 L .24644 .35577 L closepath p F P
0 g
s
.804 .979 .898 r
.67459 .24488 m .67256 .24445 L .6775 .24053 L closepath p F P
0 g
s
.681 .411 .507 r
.40527 .42262 m .40189 .42265 L .4029 .42764 L p F P
0 g
s
.686 .414 .506 r
.38992 .4276 m .4029 .42764 L .40189 .42265 L p F P
0 g
s
.686 .414 .506 r
.40189 .42265 m .39043 .42261 L .38992 .4276 L p F P
0 g
s
.592 .318 .47 r
.45705 .41291 m .44717 .41455 L .44658 .41935 L p F P
0 g
s
.443 .135 .347 r
.50902 .3907 m .51001 .38647 L .49872 .3903 L p F P
0 g
s
.443 .135 .347 r
.49872 .3903 m .49772 .39454 L .50902 .3907 L p F P
0 g
s
.665 .397 .505 r
.41721 .42214 m .40527 .42262 L .4048 .42763 L p F P
0 g
s
.681 .411 .507 r
.4029 .42764 m .4048 .42763 L .40527 .42262 L p F P
0 g
s
.477 .749 .989 r
.27056 .4693 m .27111 .46968 L p .25668 .46799 L F P
0 g
s
.477 .749 .989 r
.25668 .46799 m .26511 .46738 L .27056 .4693 L p F P
0 g
s
.496 .753 .987 r
.26511 .46738 m .25668 .46799 L .25314 .46562 L p F P
0 g
s
.698 .425 .507 r
.38939 .42758 m .38992 .4276 L .39043 .42261 L p F P
0 g
s
.698 .425 .507 r
.39043 .42261 m .38849 .42256 L .38939 .42758 L p F P
0 g
s
0 0 .301 r
.80105 .2853 m .79758 .29074 L .79831 .28522 L p F P
0 g
s
0 0 .301 r
.79831 .28522 m .80181 .27976 L .80105 .2853 L p F P
0 g
s
.337 .018 .268 r
.53263 .37342 m .53381 .36948 L .52318 .37412 L p F P
0 g
s
.337 .018 .268 r
.52318 .37412 m .52203 .37811 L .53263 .37342 L p F P
0 g
s
.274 .656 .968 r
.19658 .45244 m .19219 .4519 L .18853 .44951 L p F P
0 g
s
.705 .433 .511 r
.37718 .42711 m .38939 .42758 L .38849 .42256 L p F P
0 g
s
.705 .433 .511 r
.38849 .42256 m .37644 .42204 L .37718 .42711 L p F P
0 g
s
.618 .764 .95 r
.31805 .47461 m .3292 .47183 L .33258 .47481 L p F P
0 g
s
.64 .754 .931 r
.3292 .47183 m .31805 .47461 L .31464 .47184 L p F P
0 g
s
.64 .953 .755 r
.72105 .3902 m .71925 .39089 L .72566 .38581 L closepath p F P
0 g
s
0 .365 .796 r
.10354 .41027 m .10572 .41131 L .11001 .41443 L p F P
0 g
s
0 .399 .824 r
.11239 .41428 m .11665 .41741 L .11001 .41443 L p F P
0 g
s
0 .399 .824 r
.11001 .41443 m .10572 .41131 L .11239 .41428 L p F P
0 g
s
.68 .164 0 r
.19143 .30667 m .18931 .30414 L .18568 .30113 L p F P
0 g
s
.067 .005 .47 r
.80125 .27026 m .80183 .27447 L .80169 .2747 L closepath p F P
0 g
s
.825 .353 .072 r
.23086 .34139 m .23095 .34152 L .2306 .3413 L closepath p F P
0 g
s
0 .295 .746 r
.08611 .39881 m .09138 .4018 L .09547 .40501 L p F P
0 g
s
0 .301 .756 r
.09138 .4018 m .08611 .39881 L .08234 .39569 L p F P
0 g
s
.734 .854 .937 r
.73533 .20977 m .72435 .21548 L .72166 .21309 L p F P
0 g
s
.369 .387 .748 r
.80322 .23831 m .80228 .24008 L .79726 .23647 L p F P
0 g
s
.369 .387 .748 r
.80114 .23182 m .80322 .23831 L p .79726 .23647 L F P
0 g
s
.369 .387 .748 r
.79726 .23647 m .80003 .23113 L .80114 .23182 L p F P
0 g
s
.84 .381 .113 r
.22859 .34284 m .23344 .34582 L .23095 .34152 L p F P
0 g
s
.84 .381 .113 r
.22718 .34035 m .22859 .34284 L p .23095 .34152 L F P
0 g
s
.84 .381 .113 r
.23095 .34152 m .2306 .3413 L .22718 .34035 L p F P
0 g
s
.646 .968 .864 r
.68631 .414 m .68446 .41517 L .6818 .41546 L p F P
0 g
s
.645 .966 .891 r
.67191 .42233 m .67016 .42239 L .67799 .41778 L closepath p F P
0 g
s
.786 .287 0 r
.21083 .32423 m .21006 .32315 L .20641 .32092 L p F P
0 g
s
.816 .439 .341 r
.27838 .38406 m .28499 .38639 L .2829 .38186 L p F P
0 g
s
.816 .439 .341 r
.2829 .38186 m .27646 .37949 L .27838 .38406 L p F P
0 g
s
.249 0 .181 r
.53507 .36565 m .53471 .36667 L .53795 .36421 L closepath p F P
0 g
s
.691 .161 0 r
.20219 .31784 m .19881 .31391 L .20308 .31713 L p F P
0 g
s
.691 .161 0 r
.20584 .32055 m .20219 .31784 L p .20308 .31713 L F P
0 g
s
.691 .161 0 r
.20308 .31713 m .20641 .32092 L .20584 .32055 L p F P
0 g
s
.49 .192 .387 r
.49719 .39723 m .49772 .39454 L .48605 .39793 L p F P
0 g
s
.49 .192 .387 r
.48605 .39793 m .48571 .3996 L .49719 .39723 L p F P
0 g
s
.43 .467 .797 r
.80055 .23011 m .80003 .23113 L .79309 .22816 L p F P
0 g
s
.43 .467 .797 r
.79815 .22373 m .80055 .23011 L p .79309 .22816 L F P
0 g
s
.43 .467 .797 r
.79309 .22816 m .79567 .22286 L .79815 .22373 L p F P
0 g
s
.792 .438 .386 r
.30775 .39693 m .30797 .3975 L .3075 .39736 L closepath p F P
0 g
s
.798 .308 .029 r
.2306 .3413 m .22718 .34035 L .22594 .3386 L closepath p F P
0 g
s
.663 .396 .505 r
.41951 .42203 m .41721 .42214 L .41843 .42707 L p F P
0 g
s
.665 .397 .505 r
.4048 .42763 m .41843 .42707 L .41721 .42214 L p F P
0 g
s
.836 .422 .256 r
.25645 .36734 m .26223 .36996 L .25992 .36555 L p F P
0 g
s
.836 .422 .256 r
.25992 .36555 m .25428 .36288 L .25645 .36734 L p F P
0 g
s
.762 .441 .444 r
.32544 .40595 m .32542 .40601 L .3254 .40595 L closepath p F P
0 g
s
.762 .441 .444 r
.31848 .40902 m .31711 .40421 L .3254 .40595 L p F P
0 g
s
.762 .441 .444 r
.3241 .41019 m .31848 .40902 L p .3254 .40595 L F P
0 g
s
.762 .441 .444 r
.3254 .40595 m .32542 .40601 L .3241 .41019 L p F P
0 g
s
.781 .919 .93 r
.69859 .22809 m .69837 .22796 L .69887 .22763 L closepath p F P
0 g
s
.626 .96 .83 r
.69607 .4076 m .68631 .414 L .69375 .40806 L closepath p F P
0 g
s
.646 .968 .864 r
.69345 .40809 m .69375 .40806 L .68631 .414 L p F P
0 g
s
.646 .968 .864 r
.6818 .41546 m .69345 .40809 L p .68631 .414 L F P
0 g
s
.775 .456 .448 r
.32542 .40601 m .32672 .41078 L .3241 .41019 L closepath p F P
0 g
s
.39 .72 .988 r
.22716 .46108 m .22436 .46102 L .22076 .45869 L p F P
0 g
s
.712 .438 .509 r
.37442 .42695 m .37718 .42711 L .37644 .42204 L p F P
0 g
s
.712 .438 .509 r
.37644 .42204 m .37494 .42195 L .37442 .42695 L p F P
0 g
s
.647 .381 .503 r
.43288 .42597 m .43326 .42092 L .41951 .42203 L p F P
0 g
s
.647 .381 .503 r
.41951 .42203 m .41908 .42704 L .43288 .42597 L p F P
0 g
s
.663 .396 .505 r
.41843 .42707 m .41908 .42704 L .41951 .42203 L p F P
0 g
s
.64 .757 .933 r
.33258 .47481 m .34378 .47156 L .34713 .47476 L p F P
0 g
s
.662 .742 .909 r
.34378 .47156 m .33258 .47481 L .3292 .47183 L p F P
0 g
s
.753 .453 .477 r
.34147 .41822 m .34538 .41885 L .34431 .41392 L p F P
0 g
s
.753 .453 .477 r
.34431 .41392 m .34242 .41361 L .34147 .41822 L p F P
0 g
s
.655 .942 .691 r
.62761 .28455 m .62658 .28514 L .6298 .28216 L closepath p F P
0 g
s
.802 .957 .915 r
.68624 .23604 m .6841 .23524 L .68905 .23153 L closepath p F P
0 g
s
.719 .445 .51 r
.36594 .42633 m .37442 .42695 L .37494 .42195 L p F P
0 g
s
.719 .445 .51 r
.37494 .42195 m .36528 .42124 L .36594 .42633 L p F P
0 g
s
.613 .902 .986 r
.56581 .46231 m .56576 .46229 L .56642 .46206 L closepath p F P
0 g
s
.627 .893 .987 r
.56642 .46206 m .56576 .46229 L .56279 .46098 L p F P
0 g
s
.613 .889 .989 r
.55121 .46492 m .56279 .46098 L .56576 .46229 L p F P
0 g
s
.796 .457 .414 r
.30568 .40115 m .30948 .40225 L .30797 .3975 L p F P
0 g
s
.796 .457 .414 r
.30797 .3975 m .3075 .39736 L .30568 .40115 L p F P
0 g
s
.488 0 0 r
.1764 .2926 m .1801 .29608 L .17619 .29239 L p F P
0 g
s
.488 0 0 r
.17619 .29239 m .17251 .28892 L .1764 .2926 L p F P
0 g
s
.779 .93 .932 r
.69887 .22763 m .69837 .22796 L .69568 .22652 L p F P
0 g
s
.751 .452 .478 r
.33624 .41739 m .34147 .41822 L .34242 .41361 L p F P
0 g
s
.751 .452 .478 r
.34242 .41361 m .33517 .41246 L .33624 .41739 L p F P
0 g
s
.795 .931 .923 r
.69887 .22763 m .70999 .22023 L .70731 .21836 L p F P
0 g
s
.795 .931 .923 r
.70731 .21836 m .70208 .22205 L .69887 .22763 L p F P
0 g
s
.779 .93 .932 r
.69568 .22652 m .70208 .22205 L .69887 .22763 L p F P
0 g
s
.811 .407 .284 r
.27011 .37315 m .26904 .37385 L .26832 .37247 L closepath p F P
0 g
s
.631 .941 .958 r
.61975 .4459 m .61802 .44555 L .62891 .44061 L closepath p F P
0 g
s
.657 .747 .916 r
.34713 .47476 m .35837 .4711 L .36168 .47453 L p F P
0 g
s
.677 .728 .888 r
.35837 .4711 m .34713 .47476 L .34378 .47156 L p F P
0 g
s
0 0 0 r
.77628 .33246 m .77615 .33266 L .77624 .33255 L closepath p F P
0 g
s
0 0 0 r
.78601 .31653 m .78514 .31916 L .78773 .3141 L closepath p F P
0 g
s
.617 .903 .985 r
.57735 .45808 m .56642 .46206 L .5764 .45771 L closepath p F P
0 g
s
.627 .893 .987 r
.5744 .45685 m .5764 .45771 L .56642 .46206 L p F P
0 g
s
.627 .893 .987 r
.56279 .46098 m .5744 .45685 L p .56642 .46206 L F P
0 g
s
.786 .444 .41 r
.30208 .40021 m .30568 .40115 L .3075 .39736 L p F P
0 g
s
.786 .444 .41 r
.3075 .39736 m .30044 .3955 L .30208 .40021 L p F P
0 g
s
0 0 0 r
.77468 .33532 m .77125 .33952 L .77615 .33266 L p F P
0 g
s
0 0 0 r
.77615 .33266 m .77624 .33255 L .77468 .33532 L p F P
0 g
s
.623 .934 .964 r
.61517 .44489 m .61802 .44555 L .60639 .45059 L p F P
0 g
s
.623 .934 .964 r
.60634 .44872 m .61517 .44489 L p .60639 .45059 L F P
0 g
s
.623 .934 .964 r
.60639 .45059 m .60392 .45003 L .60634 .44872 L p F P
0 g
s
.166 0 .111 r
.54672 .35691 m .54621 .35819 L .54988 .35513 L closepath p F P
0 g
s
0 0 0 r
.5931 .31645 m .59216 .31768 L .59597 .31405 L closepath p F P
0 g
s
.535 .251 .431 r
.48451 .40698 m .4852 .40236 L .47318 .40535 L p F P
0 g
s
.535 .251 .431 r
.47318 .40535 m .47245 .40995 L .48451 .40698 L p F P
0 g
s
0 0 0 r
.77579 .33385 m .77468 .33532 L .77624 .33255 L p F P
0 g
s
0 0 0 r
.77624 .33255 m .78037 .32707 L .77579 .33385 L p F P
0 g
s
.836 .384 .142 r
.23589 .35014 m .24105 .353 L .23849 .34871 L p F P
0 g
s
.836 .384 .142 r
.23849 .34871 m .23344 .34582 L .23589 .35014 L p F P
0 g
s
.197 .61 .947 r
.17433 .44529 m .17482 .44538 L .17318 .44452 L closepath p F P
0 g
s
.104 .542 .913 r
.15282 .43526 m .15063 .43467 L .1554 .43757 L p F P
0 g
s
.104 .542 .913 r
.1554 .43757 m .15653 .43787 L .15282 .43526 L p F P
0 g
s
.667 .737 .902 r
.36168 .47453 m .37296 .47058 L .37625 .47422 L p F P
0 g
s
.685 .714 .87 r
.37296 .47058 m .36168 .47453 L .35837 .4711 L p F P
0 g
s
.522 .77 .988 r
.27111 .46968 m .27177 .4696 L .27056 .4693 L closepath p F P
0 g
s
0 .163 .64 r
.06511 .38236 m .069 .38524 L .07283 .38857 L p F P
0 g
s
.786 .287 0 r
.20641 .32092 m .2065 .32105 L .21083 .32423 L p F P
0 g
s
.8 .308 0 r
.20925 .32521 m .21365 .32838 L .21083 .32423 L p F P
0 g
s
.8 .308 0 r
.21083 .32423 m .2065 .32105 L .20925 .32521 L p F P
0 g
s
.637 .942 .712 r
.73224 .38083 m .73081 .38154 L .73569 .37735 L closepath p F P
0 g
s
.731 .453 .507 r
.35811 .42551 m .36594 .42633 L .36528 .42124 L p F P
0 g
s
.731 .453 .507 r
.36528 .42124 m .35869 .42055 L .35811 .42551 L p F P
0 g
s
.605 .677 .892 r
.76524 .20747 m .77554 .20555 L .77292 .21092 L p F P
0 g
s
.58 .642 .876 r
.77731 .20526 m .77554 .20555 L .77292 .21092 L p F P
0 g
s
.58 .642 .876 r
.77292 .21092 m .78007 .2101 L .77731 .20526 L p F P
0 g
s
.621 .854 .987 r
.5336 .46546 m .53464 .46607 L .52325 .46971 L p F P
0 g
s
.621 .854 .987 r
.52325 .46971 m .52206 .46901 L .5336 .46546 L p F P
0 g
s
0 .327 .773 r
.09601 .40428 m .09138 .4018 L .09547 .40501 L p F P
0 g
s
0 .327 .773 r
.09547 .40501 m .09978 .40732 L .09601 .40428 L p F P
0 g
s
.614 .956 .896 r
.65852 .42898 m .65803 .42925 L .65843 .42898 L closepath p F P
0 g
s
.626 .956 .916 r
.65578 .42882 m .65843 .42898 L .65803 .42925 L p F P
0 g
s
.626 .956 .916 r
.64519 .43441 m .65578 .42882 L p .65803 .42925 L F P
0 g
s
.626 .956 .916 r
.64433 .43498 m .64519 .43441 L p .65803 .42925 L F P
0 g
s
0 0 0 r
.79156 .30859 m .78773 .3141 L .79041 .30793 L p F P
0 g
s
0 0 0 r
.79385 .30341 m .79156 .30859 L p .79041 .30793 L F P
0 g
s
0 0 0 r
.79041 .30793 m .794 .30284 L .79385 .30341 L p F P
0 g
s
.036 .49 .883 r
.13505 .42693 m .13301 .42625 L .13757 .42924 L p F P
0 g
s
.036 .49 .883 r
.13757 .42924 m .13878 .42965 L .13505 .42693 L p F P
0 g
s
0 .37 .804 r
.10572 .41131 m .10354 .41027 L .09978 .40732 L p F P
0 g
s
.264 .643 .965 r
.18308 .4458 m .18487 .44704 L .17482 .44538 L p F P
0 g
s
.264 .643 .965 r
.1805 .44437 m .18308 .4458 L p .17482 .44538 L F P
0 g
s
.264 .643 .965 r
.17066 .44278 m .1805 .44437 L p .17482 .44538 L F P
0 g
s
.264 .643 .965 r
.17482 .44538 m .17318 .44452 L .17066 .44278 L p F P
0 g
s
.672 .729 .893 r
.37625 .47422 m .38755 .47009 L .39082 .47389 L p F P
0 g
s
.689 .702 .858 r
.38755 .47009 m .37625 .47422 L .37296 .47058 L p F P
0 g
s
.278 0 .216 r
.53795 .36421 m .53471 .36667 L .53381 .36948 L p F P
0 g
s
.141 .103 .551 r
.80708 .25875 m .80408 .2641 L .80255 .25932 L p F P
0 g
s
.141 .103 .551 r
.80255 .25932 m .80551 .25397 L .80708 .25875 L p F P
0 g
s
.538 .771 .984 r
.27863 .46544 m .28211 .46818 L .27177 .4696 L p F P
0 g
s
.538 .771 .984 r
.2676 .46718 m .27863 .46544 L p .27177 .4696 L F P
0 g
s
.538 .771 .984 r
.27177 .4696 m .27056 .4693 L .2676 .46718 L p F P
0 g
s
.634 .962 .896 r
.66762 .42245 m .67016 .42239 L .65852 .42898 L p F P
0 g
s
.634 .962 .896 r
.65852 .42898 m .65843 .42898 L .66762 .42245 L p F P
0 g
s
.816 .456 .375 r
.2868 .39102 m .2934 .39334 L .2917 .38866 L p F P
0 g
s
.816 .456 .375 r
.28637 .38976 m .2868 .39102 L p .2917 .38866 L F P
0 g
s
.816 .456 .375 r
.2917 .38866 m .28815 .3874 L .28637 .38976 L p F P
0 g
s
.595 .319 .468 r
.45998 .41244 m .45962 .41539 L .45705 .41291 L closepath p F P
0 g
s
.592 .318 .47 r
.4594 .41723 m .45962 .41539 L .45705 .41291 L p F P
0 g
s
.592 .318 .47 r
.44658 .41935 m .4594 .41723 L p .45705 .41291 L F P
0 g
s
.815 .408 .275 r
.26444 .37442 m .26223 .36996 L .26832 .37247 L p F P
0 g
s
.815 .408 .275 r
.26654 .37527 m .26444 .37442 L p .26832 .37247 L F P
0 g
s
.815 .408 .275 r
.26832 .37247 m .26904 .37385 L .26654 .37527 L p F P
0 g
s
0 .43 .842 r
.12165 .42094 m .1211 .42054 L .121 .4205 L closepath p F P
0 g
s
0 .205 .679 r
.07399 .38868 m .07781 .39202 L .07283 .38857 L p F P
0 g
s
0 .205 .679 r
.07283 .38857 m .069 .38524 L .07399 .38868 L p F P
0 g
s
.626 .366 .505 r
.43575 .42061 m .43326 .42092 L .43288 .42597 L p F P
0 g
s
.639 .951 .944 r
.64413 .43495 m .63248 .44063 L .62967 .44026 L p F P
0 g
s
.65 .963 .92 r
.66745 .42244 m .66762 .42245 L .65843 .42898 L p F P
0 g
s
.65 .963 .92 r
.65843 .42898 m .65578 .42882 L .66745 .42244 L p F P
0 g
s
.621 .882 .989 r
.56279 .46098 m .55121 .46492 L .5482 .46345 L p F P
0 g
s
.612 .877 .991 r
.53664 .46719 m .5482 .46345 L .55121 .46492 L p F P
0 g
s
.673 .725 .889 r
.39082 .47389 m .40214 .46971 L .40539 .4736 L p F P
0 g
s
.688 .695 .852 r
.40214 .46971 m .39082 .47389 L .38755 .47009 L p F P
0 g
s
.643 .966 .83 r
.70131 .40404 m .69607 .4076 L .69375 .40806 L p F P
0 g
s
.248 0 .171 r
.54621 .35819 m .53795 .36421 L .54535 .36056 L closepath p F P
0 g
s
.278 0 .216 r
.54406 .36434 m .54535 .36056 L .53795 .36421 L p F P
0 g
s
.278 0 .216 r
.53381 .36948 m .54406 .36434 L p .53795 .36421 L F P
0 g
s
.508 0 0 r
.18205 .29792 m .1801 .29608 L .18393 .29949 L p F P
0 g
s
.508 0 0 r
.18393 .29949 m .18568 .30113 L .18205 .29792 L p F P
0 g
s
.495 .203 .398 r
.49687 .39895 m .49719 .39723 L .48571 .3996 L p F P
0 g
s
.495 .203 .398 r
.48571 .3996 m .4852 .40236 L .49687 .39895 L p F P
0 g
s
.485 .75 .988 r
.27056 .4693 m .2676 .46718 L .26511 .46738 L closepath p F P
0 g
s
.528 .588 .858 r
.78811 .21563 m .78285 .21524 L .78007 .2101 L p F P
0 g
s
.072 0 .029 r
.55813 .34788 m .5577 .34883 L .56027 .34654 L closepath p F P
0 g
s
.17 .581 .937 r
.16483 .43974 m .15653 .43787 L .15282 .43526 L p F P
0 g
s
.4 .715 .987 r
.23158 .45865 m .22095 .4587 L .22716 .46108 L p F P
0 g
s
.4 .715 .987 r
.22716 .46108 m .23515 .46114 L .23158 .45865 L p F P
0 g
s
.39 .72 .988 r
.22076 .45869 m .22095 .4587 L .22716 .46108 L p F P
0 g
s
.628 .367 .504 r
.44658 .41935 m .43575 .42061 L .43746 .42541 L p F P
0 g
s
.626 .366 .505 r
.43288 .42597 m .43746 .42541 L .43575 .42061 L p F P
0 g
s
.66 .725 .897 r
.7506 .20744 m .76252 .20351 L .76524 .20747 L p F P
0 g
s
.674 .742 .901 r
.76252 .20351 m .7506 .20744 L .7479 .2041 L p F P
0 g
s
.705 .78 .91 r
.73608 .20938 m .7479 .2041 L .7506 .20744 L p F P
0 g
s
.671 .726 .891 r
.40539 .4736 m .41674 .46949 L .41996 .47336 L p F P
0 g
s
.684 .693 .852 r
.41674 .46949 m .40539 .4736 L .40214 .46971 L p F P
0 g
s
.734 .456 .508 r
.35565 .42524 m .35811 .42551 L .35869 .42055 L p F P
0 g
s
.734 .456 .508 r
.35869 .42055 m .35501 .42015 L .35565 .42524 L p F P
0 g
s
.768 .468 .479 r
.32765 .41576 m .33624 .41739 L .33517 .41246 L p F P
0 g
s
.768 .468 .479 r
.33517 .41246 m .32672 .41078 L .32765 .41576 L p F P
0 g
s
.573 .299 .463 r
.47189 .41474 m .47245 .40995 L .45998 .41244 L p F P
0 g
s
.573 .299 .463 r
.46185 .41673 m .47189 .41474 L p .45998 .41244 L F P
0 g
s
.573 .299 .463 r
.45998 .41244 m .45962 .41539 L .46185 .41673 L p F P
0 g
s
0 .434 .848 r
.11736 .4177 m .11665 .41741 L .121 .4205 L p F P
0 g
s
0 .434 .848 r
.121 .4205 m .1211 .42054 L .11736 .4177 L p F P
0 g
s
.82 .369 .16 r
.24357 .35732 m .24105 .353 L .24644 .35577 L p F P
0 g
s
.82 .369 .16 r
.24588 .35848 m .24357 .35732 L p .24644 .35577 L F P
0 g
s
.82 .369 .16 r
.24644 .35577 m .24804 .3584 L .24588 .35848 L p F P
0 g
s
.801 .308 0 r
.21647 .33254 m .22111 .33561 L .2182 .33147 L p F P
0 g
s
.801 .308 0 r
.2182 .33147 m .21365 .32838 L .21647 .33254 L p F P
0 g
s
0 0 0 r
.77042 .34088 m .76586 .34655 L .77125 .33952 L p F P
0 g
s
0 0 0 r
.77409 .33613 m .77042 .34088 L p .77125 .33952 L F P
0 g
s
0 0 0 r
.77125 .33952 m .77468 .33532 L .77409 .33613 L p F P
0 g
s
.026 .475 .878 r
.12854 .42321 m .1211 .42054 L .11736 .4177 L p F P
0 g
s
.787 .467 .447 r
.3107 .40711 m .31848 .40902 L .31711 .40421 L p F P
0 g
s
.787 .467 .447 r
.31711 .40421 m .30948 .40225 L .3107 .40711 L p F P
0 g
s
.575 .766 .969 r
.28559 .47079 m .29666 .46873 L .3001 .4715 L p F P
0 g
s
.596 .762 .958 r
.29666 .46873 m .28559 .47079 L .28211 .46818 L p F P
0 g
s
.44 .736 .99 r
.23872 .46356 m .2496 .46317 L .25314 .46562 L p F P
0 g
s
.46 .736 .987 r
.2496 .46317 m .23872 .46356 L .23515 .46114 L p F P
0 g
s
0 0 .383 r
.80169 .2747 m .80182 .2777 L .80183 .27447 L closepath p F P
0 g
s
0 0 .097 r
.79427 .30241 m .794 .30284 L .79462 .29897 L p F P
0 g
s
0 0 .097 r
.79462 .29897 m .79622 .29648 L .79427 .30241 L p F P
0 g
s
.087 .528 .905 r
.13878 .42965 m .14593 .43172 L .15063 .43467 L p F P
0 g
s
.099 .531 .91 r
.14593 .43172 m .13878 .42965 L .13505 .42693 L p F P
0 g
s
.352 .691 .982 r
.21531 .45612 m .20644 .45555 L .20281 .45312 L p F P
0 g
s
.338 .687 .98 r
.2205 .45852 m .22076 .45869 L p .20644 .45555 L F P
0 g
s
.338 .687 .98 r
.20644 .45555 m .21531 .45612 L .2205 .45852 L p F P
0 g
s
.666 .731 .898 r
.41996 .47336 m .43133 .46941 L .43453 .47315 L p F P
0 g
s
.679 .697 .86 r
.43133 .46941 m .41996 .47336 L .41674 .46949 L p F P
0 g
s
.173 .59 .939 r
.17318 .44452 m .17066 .44278 L .16974 .44259 L closepath p F P
0 g
s
.765 .898 .936 r
.71516 .21708 m .70999 .22023 L .70731 .21836 L p F P
0 g
s
.626 .956 .796 r
.70767 .39954 m .70131 .40404 L .70607 .39999 L closepath p F P
0 g
s
.643 .966 .83 r
.70508 .40016 m .70607 .39999 L .70131 .40404 L p F P
0 g
s
.643 .966 .83 r
.69463 .40731 m .70508 .40016 L p .70131 .40404 L F P
0 g
s
.643 .966 .83 r
.69375 .40806 m .69463 .40731 L p .70131 .40404 L F P
0 g
s
0 0 .193 r
.79964 .29106 m .79622 .29648 L .79758 .29074 L p F P
0 g
s
0 0 .193 r
.79758 .29074 m .80105 .2853 L .79964 .29106 L p F P
0 g
s
.624 .863 .988 r
.54578 .46211 m .5482 .46345 L .53664 .46719 L p F P
0 g
s
.624 .863 .988 r
.53664 .46719 m .53464 .46607 L .54578 .46211 L p F P
0 g
s
.745 .467 .51 r
.3459 .42398 m .35565 .42524 L .35501 .42015 L p F P
0 g
s
.745 .467 .51 r
.35501 .42015 m .34538 .41885 L .3459 .42398 L p F P
0 g
s
.622 .68 .884 r
.77554 .20555 m .76524 .20747 L .76252 .20351 L p F P
0 g
s
.734 .826 .921 r
.73608 .20938 m .73533 .20977 L .73564 .20891 L closepath p F P
0 g
s
.734 .854 .937 r
.7334 .20661 m .73564 .20891 L .73533 .20977 L p F P
0 g
s
.734 .854 .937 r
.72166 .21309 m .7334 .20661 L p .73533 .20977 L F P
0 g
s
0 0 .381 r
.80479 .27445 m .8048 .26915 L .80183 .27447 L p F P
0 g
s
0 0 .381 r
.8019 .27961 m .80479 .27445 L p .80183 .27447 L F P
0 g
s
0 0 .381 r
.80183 .27447 m .80182 .2777 L .8019 .27961 L p F P
0 g
s
.724 .981 .771 r
.6382 .27444 m .63805 .2745 L .63848 .27411 L closepath p F P
0 g
s
.274 .656 .968 r
.18853 .44951 m .1911 .4498 L .19658 .45244 L p F P
0 g
s
.291 .66 .971 r
.19918 .45063 m .1911 .4498 L .19658 .45244 L p F P
0 g
s
.291 .66 .971 r
.19658 .45244 m .20281 .45312 L .19918 .45063 L p F P
0 g
s
.204 0 .153 r
.54988 .35513 m .54621 .35819 L .54535 .36056 L p F P
0 g
s
.66 .742 .91 r
.43453 .47315 m .44593 .46939 L .44911 .47293 L p F P
0 g
s
.672 .707 .874 r
.44593 .46939 m .43453 .47315 L .43133 .46941 L p F P
0 g
s
.559 .827 .47 r
.76536 .34717 m .76511 .34745 L .76586 .34655 L closepath p F P
0 g
s
.718 .822 .929 r
.7452 .20091 m .7479 .2041 L .73608 .20938 L p F P
0 g
s
.718 .822 .929 r
.73831 .20425 m .7452 .20091 L p .73608 .20938 L F P
0 g
s
.718 .822 .929 r
.73608 .20938 m .73564 .20891 L .73831 .20425 L p F P
0 g
s
.629 .919 .978 r
.60351 .44991 m .59189 .45459 L .58897 .45363 L p F P
0 g
s
.616 .914 .98 r
.57735 .45808 m .58897 .45363 L .59189 .45459 L p F P
0 g
s
.68 .164 0 r
.18568 .30113 m .18749 .30331 L .19143 .30667 L p F P
0 g
s
.685 .169 0 r
.19073 .30727 m .1947 .31062 L .19143 .30667 L p F P
0 g
s
.685 .169 0 r
.19143 .30667 m .18749 .30331 L .19073 .30727 L p F P
0 g
s
.831 .455 .34 r
.27216 .3816 m .27838 .38406 L .27646 .37949 L p F P
0 g
s
.831 .455 .34 r
.27646 .37949 m .27038 .37698 L .27216 .3816 L p F P
0 g
s
.837 .444 .303 r
.26904 .37385 m .27038 .37698 L .26654 .37527 L closepath p F P
0 g
s
0 0 0 r
.60383 .30658 m .60363 .30679 L .60436 .30609 L closepath p F P
0 g
s
.162 0 .097 r
.5577 .34883 m .54988 .35513 L .55665 .35138 L closepath p F P
0 g
s
.204 0 .153 r
.55524 .35497 m .55665 .35138 L .54988 .35513 L p F P
0 g
s
.204 0 .153 r
.54535 .36056 m .55524 .35497 L p .54988 .35513 L F P
0 g
s
.696 .968 .744 r
.63848 .27411 m .63805 .2745 L .63532 .2757 L p F P
0 g
s
.681 .95 .691 r
.6298 .28216 m .63805 .2745 L .63532 .2757 L p F P
0 g
s
.767 .995 .809 r
.64339 .26803 m .63848 .27411 L .64755 .26594 L p F P
0 g
s
.696 .968 .744 r
.63532 .2757 m .64339 .26803 L .63848 .27411 L p F P
0 g
s
.803 .462 .411 r
.29487 .39809 m .30208 .40021 L .30044 .3955 L p F P
0 g
s
.803 .462 .411 r
.30044 .3955 m .2934 .39334 L .29487 .39809 L p F P
0 g
s
.802 .436 .364 r
.28815 .3874 m .28637 .38976 L .28499 .38639 L closepath p F P
0 g
s
.681 .95 .691 r
.63532 .2757 m .63502 .27599 L .6298 .28216 L p F P
0 g
s
.616 .917 .652 r
.62706 .28382 m .63502 .27599 L .6298 .28216 L p F P
0 g
s
.616 .917 .652 r
.6249 .28625 m .62706 .28382 L p .6298 .28216 L F P
0 g
s
.616 .917 .652 r
.6298 .28216 m .62658 .28514 L .6249 .28625 L p F P
0 g
s
.624 .92 .654 r
.62658 .28514 m .62123 .29016 L .6249 .28625 L closepath p F P
0 g
s
.767 .995 .809 r
.64682 .26477 m .64339 .26803 L p .64755 .26594 L F P
0 g
s
.767 .995 .809 r
.64755 .26594 m .64879 .26431 L .64682 .26477 L p F P
0 g
s
.769 .996 .815 r
.64954 .26415 m .64755 .26594 L .64879 .26431 L closepath p F P
0 g
s
.653 .757 .925 r
.44911 .47293 m .46053 .46935 L .4637 .47262 L p F P
0 g
s
.665 .723 .892 r
.46053 .46935 m .44911 .47293 L .44593 .46939 L p F P
0 g
s
.755 .994 .817 r
.657 .25764 m .64954 .26415 L .64879 .26431 L p F P
0 g
s
.51 .837 .54 r
.62383 .28698 m .6249 .28625 L .62123 .29016 L p F P
0 g
s
.51 .837 .54 r
.6192 .29161 m .62383 .28698 L p .62123 .29016 L F P
0 g
s
.51 .837 .54 r
.61444 .29652 m .6192 .29161 L p .62123 .29016 L F P
0 g
s
.51 .837 .54 r
.62123 .29016 m .6151 .29593 L .61444 .29652 L p F P
0 g
s
.631 .837 .979 r
.5336 .46546 m .52206 .46901 L .51899 .46694 L p F P
0 g
s
.626 .834 .98 r
.50747 .47038 m .51899 .46694 L .52206 .46901 L p F P
0 g
s
.611 .763 .952 r
.3001 .4715 m .31123 .46886 L .31464 .47184 L p F P
0 g
s
.632 .755 .936 r
.31123 .46886 m .3001 .4715 L .29666 .46873 L p F P
0 g
s
0 .262 .726 r
.07856 .39248 m .07781 .39202 L .08172 .39531 L p F P
0 g
s
0 .262 .726 r
.08172 .39531 m .08234 .39569 L .07856 .39248 L p F P
0 g
s
.51 .837 .54 r
.6151 .29593 m .61276 .29814 L .61444 .29652 L closepath p F P
0 g
s
.644 .962 .797 r
.7143 .39468 m .70767 .39954 L .70607 .39999 L p F P
0 g
s
.688 .439 .541 r
.4048 .42763 m .4029 .42764 L .40283 .43299 L p F P
0 g
s
.693 .443 .541 r
.38977 .43294 m .40283 .43299 L .4029 .42764 L p F P
0 g
s
.693 .443 .541 r
.4029 .42764 m .38992 .4276 L .38977 .43294 L p F P
0 g
s
.501 .828 .527 r
.61143 .29937 m .60436 .30609 L .61276 .29814 L p F P
0 g
s
.501 .828 .527 r
.61235 .29846 m .61143 .29937 L p .61276 .29814 L F P
0 g
s
.501 .828 .527 r
.61276 .29814 m .61444 .29652 L .61235 .29846 L p F P
0 g
s
.796 .302 .003 r
.22349 .33904 m .22111 .33561 L .22594 .3386 L p F P
0 g
s
.796 .302 .003 r
.22594 .3386 m .22718 .34035 L .22349 .33904 L p F P
0 g
s
.848 .436 .254 r
.25094 .36461 m .25645 .36734 L .25428 .36288 L p F P
0 g
s
.848 .436 .254 r
.25428 .36288 m .24889 .36012 L .25094 .36461 L p F P
0 g
s
.673 .427 .541 r
.41843 .42707 m .4048 .42763 L .40467 .43298 L p F P
0 g
s
.688 .439 .541 r
.40283 .43299 m .40467 .43298 L .4048 .42763 L p F P
0 g
s
.802 .997 .858 r
.66104 .25411 m .657 .25764 L .6594 .25414 L closepath p F P
0 g
s
.755 .994 .817 r
.65833 .25418 m .6594 .25414 L .657 .25764 L p F P
0 g
s
.755 .994 .817 r
.65203 .25999 m .65833 .25418 L p .657 .25764 L F P
0 g
s
.755 .994 .817 r
.64879 .26431 m .65203 .25999 L p .657 .25764 L F P
0 g
s
0 0 0 r
.56932 .33857 m .5692 .33881 L .56983 .33822 L closepath p F P
0 g
s
.703 .452 .542 r
.38929 .43293 m .38977 .43294 L .38992 .4276 L p F P
0 g
s
.703 .452 .542 r
.38992 .4276 m .38939 .42758 L .38929 .43293 L p F P
0 g
s
.632 .927 .665 r
.74303 .37094 m .74232 .37138 L .74463 .36921 L closepath p F P
0 g
s
.708 .457 .542 r
.37705 .43246 m .38929 .43293 L .38939 .42758 L p F P
0 g
s
.708 .457 .542 r
.38939 .42758 m .37718 .42711 L .37705 .43246 L p F P
0 g
s
.217 .196 .62 r
.80657 .25204 m .80551 .25397 L .80301 .24952 L p F P
0 g
s
.217 .196 .62 r
.80301 .24952 m .80517 .24555 L .80657 .25204 L p F P
0 g
s
.646 .775 .942 r
.4637 .47262 m .47514 .46917 L .47829 .47213 L p F P
0 g
s
.657 .743 .913 r
.47514 .46917 m .4637 .47262 L .46053 .46935 L p F P
0 g
s
.786 .996 .864 r
.66692 .24919 m .66104 .25411 L .6594 .25414 L p F P
0 g
s
.78 .888 .922 r
.71516 .21708 m .72166 .21309 L .71897 .2108 L p F P
0 g
s
.78 .888 .922 r
.71897 .2108 m .7175 .21177 L .71516 .21708 L p F P
0 g
s
.765 .898 .936 r
.70731 .21836 m .7175 .21177 L .71516 .21708 L p F P
0 g
s
.119 0 .078 r
.56027 .34654 m .5577 .34883 L .55665 .35138 L p F P
0 g
s
0 0 0 r
.60383 .30709 m .61143 .29937 L .60436 .30609 L p F P
0 g
s
0 0 0 r
.60169 .3091 m .60383 .30709 L p .60436 .30609 L F P
0 g
s
0 0 0 r
.60436 .30609 m .60363 .30679 L .60169 .3091 L p F P
0 g
s
0 .37 .804 r
.09978 .40732 m .10152 .40816 L .10572 .41131 L p F P
0 g
s
0 .406 .833 r
.10821 .41111 m .11239 .41428 L .10572 .41131 L p F P
0 g
s
0 .406 .833 r
.10572 .41131 m .10152 .40816 L .10821 .41111 L p F P
0 g
s
.563 .829 .473 r
.76444 .34811 m .77042 .34088 L .76586 .34655 L p F P
0 g
s
.563 .829 .473 r
.76336 .34946 m .76444 .34811 L p .76586 .34655 L F P
0 g
s
.563 .829 .473 r
.76586 .34655 m .76511 .34745 L .76336 .34946 L p F P
0 g
s
0 0 0 r
.60363 .30679 m .59597 .31405 L .60169 .3091 L closepath p F P
0 g
s
.06 0 .009 r
.5692 .33881 m .56027 .34654 L .56773 .3419 L closepath p F P
0 g
s
.119 0 .078 r
.56635 .34493 m .56773 .3419 L .56027 .34654 L p F P
0 g
s
.119 0 .078 r
.5654 .34581 m .56635 .34493 L p .56027 .34654 L F P
0 g
s
.119 0 .078 r
.55665 .35138 m .5654 .34581 L p .56027 .34654 L F P
0 g
s
.719 .823 .929 r
.73564 .20891 m .7334 .20661 L .73831 .20425 L closepath p F P
0 g
s
.636 .815 .969 r
.51899 .46694 m .50747 .47038 L .50437 .46803 L p F P
0 g
s
.631 .815 .971 r
.49288 .4714 m .50437 .46803 L .50747 .47038 L p F P
0 g
s
.605 .348 .501 r
.45907 .4223 m .4594 .41723 L .44658 .41935 L p F P
0 g
s
.605 .348 .501 r
.44658 .41935 m .44621 .42439 L .45907 .4223 L p F P
0 g
s
.628 .367 .504 r
.43746 .42541 m .44621 .42439 L .44658 .41935 L p F P
0 g
s
0 0 0 r
.78826 .31497 m .79156 .30859 L .78773 .3141 L p F P
0 g
s
0 0 0 r
.78492 .31983 m .78826 .31497 L p .78773 .3141 L F P
0 g
s
0 0 0 r
.78773 .3141 m .78514 .31916 L .78492 .31983 L p F P
0 g
s
.538 .817 .467 r
.76511 .34745 m .75954 .35387 L .76336 .34946 L closepath p F P
0 g
s
.638 .795 .958 r
.47829 .47213 m .48976 .46876 L .49288 .4714 L p F P
0 g
s
.649 .767 .935 r
.48976 .46876 m .47829 .47213 L .47514 .46917 L p F P
0 g
s
0 0 0 r
.60086 .31012 m .60169 .3091 L .59597 .31405 L p F P
0 g
s
0 0 0 r
.59623 .3148 m .60086 .31012 L p .59597 .31405 L F P
0 g
s
0 0 0 r
.59111 .3192 m .59623 .3148 L p .59597 .31405 L F P
0 g
s
0 0 0 r
.59597 .31405 m .59216 .31768 L .59111 .3192 L p F P
0 g
s
.642 .792 .954 r
.50437 .46803 m .49288 .4714 L .48976 .46876 L p F P
0 g
s
0 0 0 r
.59216 .31768 m .58745 .32204 L .59111 .3192 L closepath p F P
0 g
s
.816 .984 .886 r
.67256 .24445 m .66692 .24919 L .67009 .24404 L closepath p F P
0 g
s
.786 .996 .864 r
.66985 .244 m .67009 .24404 L .66692 .24919 L p F P
0 g
s
.786 .996 .864 r
.66099 .25184 m .66985 .244 L p .66692 .24919 L F P
0 g
s
.786 .996 .864 r
.6594 .25414 m .66099 .25184 L p .66692 .24919 L F P
0 g
s
0 0 0 r
.58937 .3218 m .59111 .3192 L .58745 .32204 L p F P
0 g
s
0 0 0 r
.58864 .32251 m .58937 .3218 L p .58745 .32204 L F P
0 g
s
0 0 0 r
.58031 .32902 m .58864 .32251 L p .58745 .32204 L F P
0 g
s
0 0 0 r
.58745 .32204 m .58068 .32839 L .58031 .32902 L p F P
0 g
s
0 0 0 r
.57858 .33214 m .56983 .33822 L .57878 .33008 L p F P
0 g
s
.02 0 0 r
.57787 .33348 m .57858 .33214 L .56983 .33822 L p F P
0 g
s
.02 0 0 r
.57325 .33801 m .57787 .33348 L p .56983 .33822 L F P
0 g
s
.02 0 0 r
.56773 .3419 m .57325 .33801 L p .56983 .33822 L F P
0 g
s
.02 0 0 r
.56983 .33822 m .5692 .33881 L .56773 .3419 L p F P
0 g
s
.692 .169 0 r
.19802 .31457 m .20219 .31784 L .19881 .31391 L p F P
0 g
s
.692 .169 0 r
.19881 .31391 m .1947 .31062 L .19802 .31457 L p F P
0 g
s
0 0 0 r
.58068 .32839 m .57878 .33008 L .58031 .32902 L closepath p F P
0 g
s
0 0 0 r
.57878 .33008 m .58031 .32902 L .57858 .33214 L p F P
0 g
s
.648 .967 .893 r
.67799 .41778 m .67016 .42239 L .66762 .42245 L p F P
0 g
s
0 .301 .756 r
.08234 .39569 m .08738 .39855 L .09138 .4018 L p F P
0 g
s
0 .307 .765 r
.08738 .39855 m .08234 .39569 L .07856 .39248 L p F P
0 g
s
.64 .754 .931 r
.31464 .47184 m .32582 .46859 L .3292 .47183 L p F P
0 g
s
.662 .742 .91 r
.32582 .46859 m .31464 .47184 L .31123 .46886 L p F P
0 g
s
.717 .464 .542 r
.37425 .4323 m .37705 .43246 L .37718 .42711 L p F P
0 g
s
.717 .464 .542 r
.37718 .42711 m .37442 .42695 L .37425 .4323 L p F P
0 g
s
.671 .425 .541 r
.41908 .42704 m .41843 .42707 L .41839 .43242 L p F P
0 g
s
.673 .427 .541 r
.40467 .43298 m .41839 .43242 L .41843 .42707 L p F P
0 g
s
.644 .962 .797 r
.71671 .39169 m .71793 .39139 L .7143 .39468 L p F P
0 g
s
.644 .962 .797 r
.70867 .39762 m .71671 .39169 L p .7143 .39468 L F P
0 g
s
.644 .962 .797 r
.70607 .39999 m .70867 .39762 L p .7143 .39468 L F P
0 g
s
.624 .948 .756 r
.71925 .39089 m .7143 .39468 L .71793 .39139 L closepath p F P
0 g
s
.799 .984 .895 r
.6775 .24053 m .67256 .24445 L .67009 .24404 L p F P
0 g
s
.667 .154 0 r
.18749 .30331 m .18568 .30113 L .18205 .29792 L p F P
0 g
s
.656 .413 .54 r
.43278 .43132 m .43288 .42597 L .41908 .42704 L p F P
0 g
s
.656 .413 .54 r
.41908 .42704 m .41896 .43239 L .43278 .43132 L p F P
0 g
s
.671 .425 .541 r
.41839 .43242 m .41896 .43239 L .41908 .42704 L p F P
0 g
s
.496 .753 .987 r
.25314 .46562 m .25856 .46512 L .26511 .46738 L p F P
0 g
s
.514 .759 .985 r
.25856 .46512 m .25314 .46562 L .2496 .46317 L p F P
0 g
s
.778 .475 .474 r
.32303 .41471 m .32765 .41576 L .32672 .41078 L p F P
0 g
s
.778 .475 .474 r
.32672 .41078 m .3241 .41019 L .32303 .41471 L p F P
0 g
s
.403 .1 .332 r
.52023 .38529 m .52095 .3822 L .51001 .38647 L p F P
0 g
s
.403 .1 .332 r
.51495 .38837 m .52023 .38529 L p .51001 .38647 L F P
0 g
s
.403 .1 .332 r
.51001 .38647 m .50902 .3907 L .51495 .38837 L p F P
0 g
s
.756 .475 .507 r
.34084 .42315 m .3459 .42398 L .34538 .41885 L p F P
0 g
s
.756 .475 .507 r
.34538 .41885 m .34147 .41822 L .34084 .42315 L p F P
0 g
s
.723 .469 .543 r
.36579 .43168 m .37425 .4323 L .37442 .42695 L p F P
0 g
s
.723 .469 .543 r
.37442 .42695 m .36594 .42633 L .36579 .43168 L p F P
0 g
s
.288 .66 .971 r
.1911 .4498 m .18853 .44951 L .18487 .44704 L p F P
0 g
s
.458 .163 .376 r
.5087 .39237 m .50902 .3907 L .49772 .39454 L p F P
0 g
s
.458 .163 .376 r
.49772 .39454 m .49719 .39723 L .5087 .39237 L p F P
0 g
s
.639 .939 .962 r
.62891 .44061 m .61802 .44555 L .61517 .44489 L p F P
0 g
s
.491 .746 .985 r
.26409 .46457 m .25856 .46512 L .26511 .46738 L p F P
0 g
s
.491 .746 .985 r
.26511 .46738 m .2676 .46718 L .26409 .46457 L p F P
0 g
s
.643 .956 .935 r
.64433 .43498 m .64413 .43495 L .64519 .43441 L closepath p F P
0 g
s
.806 .437 .359 r
.28013 .38871 m .27838 .38406 L .28499 .38639 L p F P
0 g
s
.806 .437 .359 r
.2857 .3906 m .28013 .38871 L p .28499 .38639 L F P
0 g
s
.806 .437 .359 r
.28499 .38639 m .28637 .38976 L .2857 .3906 L p F P
0 g
s
.845 .394 .137 r
.23094 .3472 m .23589 .35014 L .23344 .34582 L p F P
0 g
s
.845 .394 .137 r
.23344 .34582 m .22859 .34284 L .23094 .3472 L p F P
0 g
s
.823 .976 .89 r
.6775 .24053 m .6841 .23524 L .68141 .23432 L p F P
0 g
s
.823 .976 .89 r
.68141 .23432 m .68063 .23497 L .6775 .24053 L p F P
0 g
s
.799 .984 .895 r
.67041 .24354 m .68063 .23497 L .6775 .24053 L p F P
0 g
s
.799 .984 .895 r
.67009 .24404 m .67041 .24354 L p .6775 .24053 L F P
0 g
s
.577 .859 .533 r
.7628 .34995 m .76336 .34946 L .75954 .35387 L p F P
0 g
s
.577 .859 .533 r
.75757 .35561 m .7628 .34995 L p .75954 .35387 L F P
0 g
s
.577 .859 .533 r
.75341 .36049 m .75757 .35561 L p .75954 .35387 L F P
0 g
s
.577 .859 .533 r
.75954 .35387 m .75376 .36015 L .75341 .36049 L p F P
0 g
s
.662 .742 .909 r
.3292 .47183 m .34044 .46801 L .34378 .47156 L p F P
0 g
s
.682 .725 .882 r
.34044 .46801 m .3292 .47183 L .32582 .46859 L p F P
0 g
s
.628 .906 .984 r
.58679 .45282 m .58897 .45363 L .57735 .45808 L p F P
0 g
s
.628 .906 .984 r
.57735 .45808 m .5764 .45771 L .58679 .45282 L p F P
0 g
s
.345 .034 .287 r
.53177 .37657 m .53263 .37342 L .52203 .37811 L p F P
0 g
s
.345 .034 .287 r
.52882 .37867 m .53177 .37657 L p .52203 .37811 L F P
0 g
s
.345 .034 .287 r
.52203 .37811 m .52095 .3822 L .52882 .37867 L p F P
0 g
s
.643 .955 .758 r
.72566 .38581 m .71925 .39089 L .71793 .39139 L p F P
0 g
s
.509 .23 .427 r
.49621 .40358 m .49687 .39895 L .4852 .40236 L p F P
0 g
s
.509 .23 .427 r
.4852 .40236 m .48451 .40698 L .49621 .40358 L p F P
0 g
s
.835 .432 .281 r
.25852 .37184 m .26444 .37442 L .26223 .36996 L p F P
0 g
s
.835 .432 .281 r
.26223 .36996 m .25645 .36734 L .25852 .37184 L p F P
0 g
s
.014 0 .394 r
.80182 .2777 m .80181 .27976 L .8019 .27961 L closepath p F P
0 g
s
.571 .301 .468 r
.45962 .41539 m .46185 .41673 L .4594 .41723 L closepath p F P
0 g
s
.116 .545 .917 r
.14911 .43258 m .14593 .43172 L .15063 .43467 L p F P
0 g
s
.116 .545 .917 r
.15063 .43467 m .15282 .43526 L .14911 .43258 L p F P
0 g
s
.799 .474 .438 r
.30411 .4052 m .3107 .40711 L .30948 .40225 L p F P
0 g
s
.799 .474 .438 r
.30948 .40225 m .30568 .40115 L .30411 .4052 L p F P
0 g
s
.639 .951 .944 r
.62967 .44026 m .64134 .43454 L .64413 .43495 L p F P
0 g
s
.654 .956 .942 r
.64519 .43441 m .64413 .43495 L .64134 .43454 L p F P
0 g
s
.756 .842 .916 r
.7334 .20661 m .72166 .21309 L .71897 .2108 L p F P
0 g
s
.779 .279 0 r
.20641 .32092 m .2065 .32105 L .20584 .32055 L closepath p F P
0 g
s
.677 .728 .888 r
.34378 .47156 m .35505 .46723 L .35837 .4711 L p F P
0 g
s
.695 .706 .856 r
.35505 .46723 m .34378 .47156 L .34044 .46801 L p F P
0 g
s
.182 .591 .941 r
.16697 .44018 m .16483 .43974 L .16974 .44259 L p F P
0 g
s
.182 .591 .941 r
.16974 .44259 m .17066 .44278 L .16697 .44018 L p F P
0 g
s
.394 .719 .988 r
.22076 .45869 m .22095 .4587 L .2205 .45852 L closepath p F P
0 g
s
.771 .468 .473 r
.31946 .41398 m .32303 .41471 L .3241 .41019 L p F P
0 g
s
.771 .468 .473 r
.3241 .41019 m .31848 .40902 L .31946 .41398 L p F P
0 g
s
.552 .595 .85 r
.79051 .21035 m .78007 .2101 L .77731 .20526 L p F P
0 g
s
.528 .588 .858 r
.78007 .2101 m .79051 .21035 L .78811 .21563 L p F P
0 g
s
.8 .963 .914 r
.68905 .23153 m .6841 .23524 L .68141 .23432 L p F P
0 g
s
.294 .294 .689 r
.80228 .24008 m .80322 .23831 L .8043 .24221 L closepath p F P
0 g
s
.805 .317 0 r
.20501 .32198 m .20925 .32521 L .2065 .32105 L p F P
0 g
s
.805 .317 0 r
.20276 .31853 m .20501 .32198 L p .2065 .32105 L F P
0 g
s
.805 .317 0 r
.2065 .32105 m .20584 .32055 L .20276 .31853 L p F P
0 g
s
.848 .421 .212 r
.24804 .3584 m .24889 .36012 L .24588 .35848 L closepath p F P
0 g
s
.736 .48 .542 r
.35791 .43086 m .36579 .43168 L .36594 .42633 L p F P
0 g
s
.736 .48 .542 r
.36594 .42633 m .35811 .42551 L .35791 .43086 L p F P
0 g
s
.754 .473 .507 r
.33677 .42252 m .34084 .42315 L .34147 .41822 L p F P
0 g
s
.754 .473 .507 r
.34147 .41822 m .33624 .41739 L .33677 .42252 L p F P
0 g
s
.639 .959 .923 r
.65578 .42882 m .64519 .43441 L .65369 .42867 L closepath p F P
0 g
s
.654 .956 .942 r
.65302 .42858 m .65369 .42867 L .64519 .43441 L p F P
0 g
s
.654 .956 .942 r
.64134 .43454 m .65302 .42858 L p .64519 .43441 L F P
0 g
s
.62 .936 .713 r
.73081 .38154 m .72566 .38581 L .72936 .38224 L closepath p F P
0 g
s
.643 .955 .758 r
.7283 .3826 m .72936 .38224 L .72566 .38581 L p F P
0 g
s
.643 .955 .758 r
.72095 .38846 m .7283 .3826 L p .72566 .38581 L F P
0 g
s
.643 .955 .758 r
.71793 .39139 m .72095 .38846 L p .72566 .38581 L F P
0 g
s
.43 .73 .989 r
.22799 .45609 m .23158 .45865 L .22095 .4587 L p F P
0 g
s
.43 .73 .989 r
.21716 .45621 m .22799 .45609 L p .22095 .4587 L F P
0 g
s
.43 .73 .989 r
.22095 .4587 m .2205 .45852 L .21716 .45621 L p F P
0 g
s
.771 .996 .808 r
.64879 .26431 m .64682 .26477 L .65203 .25999 L closepath p F P
0 g
s
.685 .714 .87 r
.35837 .4711 m .36968 .46639 L .37296 .47058 L p F P
0 g
s
.701 .688 .834 r
.36968 .46639 m .35837 .4711 L .35505 .46723 L p F P
0 g
s
.552 .848 .527 r
.75376 .36015 m .75258 .36139 L .75341 .36049 L closepath p F P
0 g
s
.047 .493 .888 r
.13132 .42414 m .12854 .42321 L .13301 .42625 L p F P
0 g
s
.047 .493 .888 r
.13301 .42625 m .13505 .42693 L .13132 .42414 L p F P
0 g
s
.486 .532 .83 r
.79239 .21053 m .79051 .21035 L .78811 .21563 L p F P
0 g
s
.486 .532 .83 r
.78811 .21563 m .79524 .21677 L .79239 .21053 L p F P
0 g
s
0 0 0 r
.58101 .33024 m .57858 .33214 L .58031 .32902 L p F P
0 g
s
0 0 0 r
.58031 .32902 m .58864 .32251 L .58101 .33024 L p F P
0 g
s
.607 .902 .616 r
.75001 .36333 m .74463 .36921 L .75258 .36139 L p F P
0 g
s
.607 .902 .616 r
.75138 .36198 m .75001 .36333 L p .75258 .36139 L F P
0 g
s
.607 .902 .616 r
.75258 .36139 m .75341 .36049 L .75138 .36198 L p F P
0 g
s
.277 0 .233 r
.54331 .36674 m .54406 .36434 L .53381 .36948 L p F P
0 g
s
.277 0 .233 r
.53927 .37004 m .54331 .36674 L p .53381 .36948 L F P
0 g
s
.277 0 .233 r
.53381 .36948 m .53263 .37342 L .53927 .37004 L p F P
0 g
s
.548 .28 .46 r
.48399 .4118 m .48451 .40698 L .47245 .40995 L p F P
0 g
s
.548 .28 .46 r
.47245 .40995 m .47189 .41474 L .48399 .4118 L p F P
0 g
s
.354 .693 .982 r
.2205 .45852 m .21716 .45621 L .21531 .45612 L closepath p F P
0 g
s
.539 .847 .538 r
.61444 .29652 m .61235 .29846 L .6192 .29161 L closepath p F P
0 g
s
.689 .702 .858 r
.37296 .47058 m .38429 .46564 L .38755 .47009 L p F P
0 g
s
.702 .677 .823 r
.37296 .47058 m .38429 .46564 L .3823 .46244 L p F P
0 g
s
.702 .677 .823 r
.36968 .46639 m .37296 .47058 L p .3823 .46244 L F P
0 g
s
0 .332 .782 r
.09224 .40115 m .08738 .39855 L .09138 .4018 L p F P
0 g
s
0 .332 .782 r
.09138 .4018 m .09601 .40428 L .09224 .40115 L p F P
0 g
s
0 0 0 r
.78514 .31916 m .78444 .32046 L .78492 .31983 L closepath p F P
0 g
s
.058 .001 .469 r
.80781 .2638 m .8048 .26915 L .80408 .2641 L p F P
0 g
s
.058 .001 .469 r
.80408 .2641 m .80708 .25875 L .80781 .2638 L p F P
0 g
s
.64 .944 .715 r
.73569 .37735 m .73081 .38154 L .72936 .38224 L p F P
0 g
s
0 0 .078 r
.79764 .29702 m .79427 .30241 L .79622 .29648 L p F P
0 g
s
0 0 .078 r
.79622 .29648 m .79964 .29106 L .79764 .29702 L p F P
0 g
s
.843 .384 .103 r
.22859 .34284 m .22718 .34035 L .22349 .33904 L p F P
0 g
s
.635 .396 .539 r
.43746 .42541 m .43288 .42597 L .43278 .43132 L p F P
0 g
s
.688 .695 .852 r
.38755 .47009 m .39891 .46512 L .40214 .46971 L p F P
0 g
s
.699 .667 .816 r
.38755 .47009 m .39891 .46512 L .3975 .46275 L p F P
0 g
s
.699 .667 .816 r
.38429 .46564 m .38755 .47009 L p .3975 .46275 L F P
0 g
s
.614 .92 .665 r
.74232 .37138 m .73569 .37735 L .74037 .37255 L closepath p F P
0 g
s
.64 .944 .715 r
.73987 .37277 m .74037 .37255 L .73569 .37735 L p F P
0 g
s
.64 .944 .715 r
.73179 .37973 m .73987 .37277 L p .73569 .37735 L F P
0 g
s
.64 .944 .715 r
.72936 .38224 m .73179 .37973 L p .73569 .37735 L F P
0 g
s
.819 .954 .905 r
.68905 .23153 m .69568 .22652 L .69299 .22517 L p F P
0 g
s
.819 .954 .905 r
.69299 .22517 m .69185 .22608 L .68905 .23153 L p F P
0 g
s
.8 .963 .914 r
.68141 .23432 m .69185 .22608 L .68905 .23153 L p F P
0 g
s
.635 .928 .668 r
.74145 .37136 m .75001 .36333 L .74463 .36921 L p F P
0 g
s
.635 .928 .668 r
.74037 .37255 m .74145 .37136 L p .74463 .36921 L F P
0 g
s
.635 .928 .668 r
.74463 .36921 m .74232 .37138 L .74037 .37255 L p F P
0 g
s
.838 .392 .164 r
.2383 .3545 m .24357 .35732 L .24105 .353 L p F P
0 g
s
.838 .392 .164 r
.24105 .353 m .23589 .35014 L .2383 .3545 L p F P
0 g
s
.636 .965 .869 r
.6818 .41546 m .67799 .41778 L .68094 .41554 L closepath p F P
0 g
s
.648 .967 .893 r
.67912 .41554 m .68094 .41554 L .67799 .41778 L p F P
0 g
s
.648 .967 .893 r
.66818 .42202 m .67912 .41554 L p .67799 .41778 L F P
0 g
s
.648 .967 .893 r
.66762 .42245 m .66818 .42202 L p .67799 .41778 L F P
0 g
s
.717 .194 0 r
.20584 .32055 m .20276 .31853 L .20219 .31784 L closepath p F P
0 g
s
.249 .628 .96 r
.1805 .44437 m .17066 .44278 L .16697 .44018 L p F P
0 g
s
.573 .759 .966 r
.27863 .46544 m .2676 .46718 L .26409 .46457 L p F P
0 g
s
0 0 0 r
.78356 .32281 m .78037 .32707 L .78444 .32046 L p F P
0 g
s
0 0 0 r
.78444 .32046 m .78492 .31983 L .78356 .32281 L p F P
0 g
s
0 .376 .812 r
.10152 .40816 m .09978 .40732 L .09601 .40428 L p F P
0 g
s
.82 .479 .41 r
.28815 .39582 m .29487 .39809 L .2934 .39334 L p F P
0 g
s
.82 .479 .41 r
.2934 .39334 m .2868 .39102 L .28815 .39582 L p F P
0 g
s
.684 .693 .852 r
.40214 .46971 m .41352 .46488 L .41674 .46949 L p F P
0 g
s
.693 .662 .814 r
.40214 .46971 m .41352 .46488 L .41212 .46248 L p F P
0 g
s
.693 .662 .814 r
.39891 .46512 m .40214 .46971 L p .41212 .46248 L F P
0 g
s
.633 .928 .972 r
.60392 .45003 m .60351 .44991 L .60634 .44872 L closepath p F P
0 g
s
.486 0 0 r
.17843 .29452 m .1764 .2926 L .1801 .29608 L p F P
0 g
s
.486 0 0 r
.1801 .29608 m .18205 .29792 L .17843 .29452 L p F P
0 g
s
.629 .887 .987 r
.5744 .45685 m .56279 .46098 L .5598 .45953 L p F P
0 g
s
.621 .882 .989 r
.5482 .46345 m .5598 .45953 L .56279 .46098 L p F P
0 g
s
.804 .313 0 r
.21201 .32939 m .21647 .33254 L .21365 .32838 L p F P
0 g
s
.804 .313 0 r
.21365 .32838 m .20925 .32521 L .21201 .32939 L p F P
0 g
s
.842 .463 .333 r
.26627 .37903 m .27216 .3816 L .27038 .37698 L p F P
0 g
s
.842 .463 .333 r
.26524 .37621 m .26627 .37903 L p .27038 .37698 L F P
0 g
s
.842 .463 .333 r
.27038 .37698 m .26654 .37527 L .26524 .37621 L p F P
0 g
s
0 0 .292 r
.80179 .28411 m .80105 .2853 L .80181 .27976 L p F P
0 g
s
0 0 .292 r
.80181 .27976 m .8019 .27961 L .80179 .28411 L p F P
0 g
s
.368 .388 .749 r
.80003 .23113 m .80055 .23011 L .80114 .23182 L closepath p F P
0 g
s
.628 .857 .986 r
.54518 .46176 m .54578 .46211 L .53464 .46607 L p F P
0 g
s
.628 .857 .986 r
.53464 .46607 m .5336 .46546 L .54518 .46176 L p F P
0 g
s
0 .438 .854 r
.11361 .41477 m .11239 .41428 L .11665 .41741 L p F P
0 g
s
0 .438 .854 r
.11665 .41741 m .11736 .4177 L .11361 .41477 L p F P
0 g
s
.737 .481 .542 r
.35549 .4306 m .35791 .43086 L .35811 .42551 L p F P
0 g
s
.737 .481 .542 r
.35811 .42551 m .35565 .42524 L .35549 .4306 L p F P
0 g
s
.288 .66 .971 r
.18487 .44704 m .18569 .44713 L .1911 .4498 L p F P
0 g
s
.304 .663 .973 r
.19553 .44807 m .18569 .44713 L .1911 .4498 L p F P
0 g
s
.304 .663 .973 r
.1911 .4498 m .19918 .45063 L .19553 .44807 L p F P
0 g
s
.767 .486 .509 r
.32808 .4209 m .33677 .42252 L .33624 .41739 L p F P
0 g
s
.767 .486 .509 r
.33624 .41739 m .32765 .41576 L .32808 .4209 L p F P
0 g
s
.788 .461 .434 r
.30343 .40503 m .30411 .4052 L .30568 .40115 L p F P
0 g
s
.788 .461 .434 r
.30568 .40115 m .30208 .40021 L .30343 .40503 L p F P
0 g
s
0 0 .273 r
.80412 .27997 m .80179 .28411 L .8019 .27961 L p F P
0 g
s
0 0 .273 r
.8019 .27961 m .80479 .27445 L .80412 .27997 L p F P
0 g
s
.679 .697 .86 r
.41674 .46949 m .42813 .46492 L .43133 .46941 L p F P
0 g
s
.687 .661 .819 r
.41674 .46949 m .42813 .46492 L .42623 .46169 L p F P
0 g
s
.687 .661 .819 r
.41352 .46488 m .41674 .46949 L p .42623 .46169 L F P
0 g
s
.431 .467 .796 r
.79567 .22286 m .79684 .22049 L .79815 .22373 L closepath p F P
0 g
s
.638 .398 .539 r
.44621 .42439 m .43746 .42541 L .43745 .43075 L p F P
0 g
s
.635 .396 .539 r
.43278 .43132 m .43745 .43075 L .43746 .42541 L p F P
0 g
s
.792 .937 .925 r
.70208 .22205 m .69568 .22652 L .69299 .22517 L p F P
0 g
s
.198 0 .167 r
.55484 .35611 m .55524 .35497 L .54535 .36056 L p F P
0 g
s
.198 0 .167 r
.54854 .36179 m .55484 .35611 L p .54535 .36056 L F P
0 g
s
.198 0 .167 r
.54535 .36056 m .54406 .36434 L .54854 .36179 L p F P
0 g
s
.583 .331 .501 r
.46185 .41673 m .4594 .41723 L .45907 .4223 L p F P
0 g
s
.637 .914 .62 r
.75341 .36049 m .75138 .36198 L .75757 .35561 L closepath p F P
0 g
s
.656 .971 .869 r
.6908 .40828 m .69345 .40809 L .6818 .41546 L p F P
0 g
s
.656 .971 .869 r
.68646 .41104 m .6908 .40828 L p .6818 .41546 L F P
0 g
s
.656 .971 .869 r
.6818 .41546 m .68094 .41554 L .68646 .41104 L p F P
0 g
s
.633 .898 .985 r
.58604 .45251 m .58679 .45282 L .5764 .45771 L p F P
0 g
s
.633 .898 .985 r
.5764 .45771 m .5744 .45685 L .58604 .45251 L p F P
0 g
s
.674 .742 .901 r
.7479 .2041 m .75981 .19973 L .76252 .20351 L p F P
0 g
s
.688 .758 .905 r
.75981 .19973 m .7479 .2041 L .7452 .20091 L p F P
0 g
s
.746 .489 .542 r
.34572 .42934 m .35549 .4306 L .35565 .42524 L p F P
0 g
s
.746 .489 .542 r
.35565 .42524 m .3459 .42398 L .34572 .42934 L p F P
0 g
s
.786 .483 .475 r
.31155 .41211 m .31946 .41398 L .31848 .40902 L p F P
0 g
s
.786 .483 .475 r
.31848 .40902 m .3107 .40711 L .31155 .41211 L p F P
0 g
s
0 0 0 r
.78445 .32151 m .78356 .32281 L .78492 .31983 L p F P
0 g
s
0 0 0 r
.78492 .31983 m .78826 .31497 L .78445 .32151 L p F P
0 g
s
.17 .581 .937 r
.15282 .43526 m .16 .43685 L .16483 .43974 L p F P
0 g
s
.182 .584 .94 r
.16 .43685 m .15282 .43526 L .14911 .43258 L p F P
0 g
s
.622 .68 .884 r
.77647 .20386 m .77554 .20555 L p .76252 .20351 L F P
0 g
s
.622 .68 .884 r
.76252 .20351 m .77457 .20075 L .77647 .20386 L p F P
0 g
s
.638 .699 .89 r
.77457 .20075 m .76252 .20351 L .75981 .19973 L p F P
0 g
s
.645 .923 .976 r
.60634 .44872 m .60351 .44991 L .60062 .44895 L p F P
0 g
s
.629 .919 .978 r
.58897 .45363 m .60062 .44895 L .60351 .44991 L p F P
0 g
s
.672 .707 .874 r
.43133 .46941 m .44274 .46515 L .44593 .46939 L p F P
0 g
s
.68 .666 .83 r
.43133 .46941 m .44274 .46515 L .43978 .46034 L p F P
0 g
s
.68 .666 .83 r
.42813 .46492 m .43133 .46941 L p .43978 .46034 L F P
0 g
s
.026 .475 .878 r
.11736 .4177 m .12416 .42013 L .12854 .42321 L p F P
0 g
s
.038 .479 .883 r
.12416 .42013 m .11736 .4177 L .11361 .41477 L p F P
0 g
s
.857 .444 .247 r
.24567 .3618 m .25094 .36461 L .24889 .36012 L p F P
0 g
s
.857 .444 .247 r
.2443 .35866 m .24567 .3618 L p .24889 .36012 L F P
0 g
s
.857 .444 .247 r
.24889 .36012 m .24588 .35848 L .2443 .35866 L p F P
0 g
s
.694 .472 .581 r
.40467 .43298 m .40283 .43299 L .40127 .43882 L p F P
0 g
s
.699 .477 .582 r
.39008 .43878 m .40127 .43882 L .40283 .43299 L p F P
0 g
s
.699 .477 .582 r
.40283 .43299 m .38977 .43294 L .39008 .43878 L p F P
0 g
s
.667 .154 0 r
.18205 .29792 m .18368 .2999 L .18749 .30331 L p F P
0 g
s
.674 .162 0 r
.1869 .30386 m .19073 .30727 L .18749 .30331 L p F P
0 g
s
.674 .162 0 r
.18749 .30331 m .18368 .2999 L .1869 .30386 L p F P
0 g
s
.681 .461 .582 r
.41839 .43242 m .40467 .43298 L .40498 .43879 L p F P
0 g
s
.694 .472 .581 r
.40127 .43882 m .40498 .43879 L .40467 .43298 L p F P
0 g
s
.596 .762 .958 r
.28211 .46818 m .29321 .4658 L .29666 .46873 L p F P
0 g
s
.616 .757 .946 r
.29321 .4658 m .28211 .46818 L .27863 .46544 L p F P
0 g
s
.709 .484 .582 r
.38785 .43871 m .39008 .43878 L .38977 .43294 L p F P
0 g
s
.709 .484 .582 r
.38977 .43294 m .38929 .43293 L .38785 .43871 L p F P
0 g
s
.586 .332 .498 r
.47189 .41474 m .46185 .41673 L .46509 .42106 L p F P
0 g
s
.583 .331 .501 r
.45907 .4223 m .46509 .42106 L .46185 .41673 L p F P
0 g
s
.713 .484 .578 r
.37579 .43819 m .38785 .43871 L .38929 .43293 L p F P
0 g
s
.713 .484 .578 r
.38929 .43293 m .37705 .43246 L .37579 .43819 L p F P
0 g
s
.099 .531 .91 r
.13505 .42693 m .14133 .42874 L .14593 .43172 L p F P
0 g
s
.111 .534 .914 r
.14133 .42874 m .13505 .42693 L .13132 .42414 L p F P
0 g
s
.63 .868 .987 r
.55679 .4579 m .5598 .45953 L .5482 .46345 L p F P
0 g
s
.63 .868 .987 r
.55533 .45839 m .55679 .4579 L p .5482 .46345 L F P
0 g
s
.63 .868 .987 r
.5482 .46345 m .54578 .46211 L .55533 .45839 L p F P
0 g
s
.798 .304 0 r
.21929 .33672 m .21647 .33254 L .22111 .33561 L p F P
0 g
s
.798 .304 0 r
.22167 .33825 m .21929 .33672 L p .22111 .33561 L F P
0 g
s
.798 .304 0 r
.22111 .33561 m .22349 .33904 L .22167 .33825 L p F P
0 g
s
.46 .736 .987 r
.2473 .46153 m .2496 .46317 L p .23515 .46114 L F P
0 g
s
.46 .736 .987 r
.23515 .46114 m .24519 .46066 L .2473 .46153 L p F P
0 g
s
.478 .738 .985 r
.24519 .46066 m .23515 .46114 L .23158 .45865 L p F P
0 g
s
.311 .336 .726 r
.80114 .23182 m .80477 .23484 L .80322 .23831 L closepath p F P
0 g
s
.204 .234 .671 r
.8082 .23899 m .80477 .23484 L .80322 .23831 L p F P
0 g
s
.204 .234 .671 r
.80581 .24419 m .8082 .23899 L p .80322 .23831 L F P
0 g
s
.204 .234 .671 r
.80322 .23831 m .8043 .24221 L .80581 .24419 L p F P
0 g
s
.283 .333 .738 r
.80055 .23011 m .80114 .23182 L .80477 .23484 L p F P
0 g
s
.352 .691 .982 r
.20281 .45312 m .20977 .4535 L .21531 .45612 L p F P
0 g
s
.366 .695 .983 r
.20977 .4535 m .20281 .45312 L .19918 .45063 L p F P
0 g
s
.465 .177 .39 r
.50821 .39513 m .5087 .39237 L .49719 .39723 L p F P
0 g
s
.465 .177 .39 r
.49719 .39723 m .49687 .39895 L .50821 .39513 L p F P
0 g
s
.808 .923 .913 r
.70208 .22205 m .70731 .21836 L .70461 .21659 L p F P
0 g
s
.808 .923 .913 r
.70461 .21659 m .70442 .21673 L .70208 .22205 L p F P
0 g
s
.792 .937 .925 r
.69299 .22517 m .70442 .21673 L .70208 .22205 L p F P
0 g
s
.665 .723 .892 r
.44593 .46939 m .45736 .46546 L .46053 .46935 L p F P
0 g
s
.673 .684 .852 r
.45736 .46546 m .44593 .46939 L .44274 .46515 L p F P
0 g
s
.373 .414 .775 r
.79815 .22373 m .8023 .22593 L .80055 .23011 L closepath p F P
0 g
s
.283 .333 .738 r
.8071 .22963 m .8023 .22593 L .80055 .23011 L p F P
0 g
s
.283 .333 .738 r
.80477 .23484 m .8071 .22963 L p .80055 .23011 L F P
0 g
s
.514 .759 .985 r
.2496 .46317 m .25179 .46292 L .25856 .46512 L p F P
0 g
s
.51 .747 .981 r
.26057 .46186 m .25179 .46292 L .25856 .46512 L p F P
0 g
s
.51 .747 .981 r
.25856 .46512 m .26409 .46457 L .26057 .46186 L p F P
0 g
s
.83 .466 .367 r
.27377 .3863 m .28013 .38871 L .27838 .38406 L p F P
0 g
s
.83 .466 .367 r
.27838 .38406 m .27216 .3816 L .27377 .3863 L p F P
0 g
s
0 0 0 r
.59111 .3192 m .58937 .3218 L .59623 .3148 L closepath p F P
0 g
s
.801 .476 .439 r
.29607 .40296 m .30343 .40503 L .30208 .40021 L p F P
0 g
s
.801 .476 .439 r
.30208 .40021 m .29487 .39809 L .29607 .40296 L p F P
0 g
s
0 0 0 r
.77468 .33532 m .77409 .33613 L .77579 .33385 L closepath p F P
0 g
s
0 .268 .736 r
.07478 .38917 m .07399 .38868 L .07781 .39202 L p F P
0 g
s
0 .268 .736 r
.07781 .39202 m .07856 .39248 L .07478 .38917 L p F P
0 g
s
0 0 0 r
.794 .30284 m .79385 .30341 L .79427 .30241 L closepath p F P
0 g
s
.597 .663 .885 r
.77554 .20555 m .77647 .20386 L .77731 .20526 L closepath p F P
0 g
s
.634 .932 .968 r
.61517 .44489 m .60634 .44872 L .61385 .44454 L closepath p F P
0 g
s
.645 .923 .976 r
.61229 .44404 m .61385 .44454 L .60634 .44872 L p F P
0 g
s
.645 .923 .976 r
.60062 .44895 m .61229 .44404 L p .60634 .44872 L F P
0 g
s
.63 .945 .951 r
.62967 .44026 m .62891 .44061 L .62955 .44024 L closepath p F P
0 g
s
.639 .939 .962 r
.62684 .43959 m .62955 .44024 L .62891 .44061 L p F P
0 g
s
.639 .939 .962 r
.61517 .44489 m .62684 .43959 L p .62891 .44061 L F P
0 g
s
.616 .381 .538 r
.45901 .42766 m .45907 .4223 L .44621 .42439 L p F P
0 g
s
.616 .381 .538 r
.44621 .42439 m .44613 .42974 L .45901 .42766 L p F P
0 g
s
.638 .398 .539 r
.43745 .43075 m .44613 .42974 L .44621 .42439 L p F P
0 g
s
.8 .998 .854 r
.6594 .25414 m .65833 .25418 L .66099 .25184 L closepath p F P
0 g
s
0 .376 .812 r
.09601 .40428 m .09742 .40495 L .10152 .40816 L p F P
0 g
s
0 .412 .84 r
.10412 .4079 m .10821 .41111 L .10152 .40816 L p F P
0 g
s
0 .412 .84 r
.10152 .40816 m .09742 .40495 L .10412 .4079 L p F P
0 g
s
.24 .247 .665 r
.8043 .24221 m .80581 .24419 L .80517 .24555 L closepath p F P
0 g
s
.721 .493 .579 r
.37453 .43811 m .37579 .43819 L .37705 .43246 L p F P
0 g
s
.721 .493 .579 r
.37705 .43246 m .37425 .4323 L .37453 .43811 L p F P
0 g
s
.824 .464 .374 r
.28637 .38976 m .2868 .39102 L .2857 .3906 L closepath p F P
0 g
s
0 0 0 r
.77989 .3283 m .77579 .33385 L .78037 .32707 L p F P
0 g
s
0 0 0 r
.78304 .32366 m .77989 .3283 L p .78037 .32707 L F P
0 g
s
0 0 0 r
.78037 .32707 m .78356 .32281 L .78304 .32366 L p F P
0 g
s
.104 0 .086 r
.5572 .35373 m .55524 .35497 L .55665 .35138 L p F P
0 g
s
.104 0 .086 r
.55665 .35138 m .5654 .34581 L .5572 .35373 L p F P
0 g
s
.719 .833 .935 r
.73831 .20425 m .7334 .20661 L .73071 .20396 L p F P
0 g
s
.756 .842 .916 r
.71897 .2108 m .73071 .20396 L .7334 .20661 L p F P
0 g
s
.673 .976 .839 r
.70607 .39999 m .70508 .40016 L .70867 .39762 L closepath p F P
0 g
s
.679 .46 .581 r
.41896 .43239 m .41839 .43242 L .41663 .43831 L p F P
0 g
s
.681 .461 .582 r
.40498 .43879 m .41663 .43831 L .41839 .43242 L p F P
0 g
s
.663 .448 .582 r
.43306 .43707 m .43278 .43132 L .41896 .43239 L p F P
0 g
s
.663 .448 .582 r
.41896 .43239 m .41928 .43819 L .43306 .43707 L p F P
0 g
s
.679 .46 .581 r
.41663 .43831 m .41928 .43819 L .41896 .43239 L p F P
0 g
s
.657 .743 .913 r
.46053 .46935 m .47199 .46567 L .47514 .46917 L p F P
0 g
s
.665 .706 .877 r
.47199 .46567 m .46053 .46935 L .45736 .46546 L p F P
0 g
s
.655 .964 .922 r
.66472 .42219 m .66745 .42244 L .65578 .42882 L p F P
0 g
s
.655 .964 .922 r
.65605 .42696 m .66472 .42219 L p .65578 .42882 L F P
0 g
s
.655 .964 .922 r
.65578 .42882 m .65369 .42867 L .65605 .42696 L p F P
0 g
s
.669 .975 .866 r
.69375 .40806 m .69345 .40809 L .69463 .40731 L closepath p F P
0 g
s
.645 .95 .949 r
.63907 .43417 m .64134 .43454 L .62967 .44026 L p F P
0 g
s
.645 .95 .949 r
.62967 .44026 m .62955 .44024 L .63907 .43417 L p F P
0 g
s
.137 .101 .55 r
.80753 .25793 m .80708 .25875 L .80551 .25397 L p F P
0 g
s
.137 .101 .55 r
.80551 .25397 m .80657 .25204 L .80753 .25793 L p F P
0 g
s
.636 .841 .979 r
.54518 .46176 m .5336 .46546 L .53055 .46338 L p F P
0 g
s
.631 .837 .979 r
.51899 .46694 m .53055 .46338 L .5336 .46546 L p F P
0 g
s
.727 .497 .579 r
.36456 .4374 m .37453 .43811 L .37425 .4323 L p F P
0 g
s
.727 .497 .579 r
.37425 .4323 m .36579 .43168 L .36456 .4374 L p F P
0 g
s
.632 .755 .936 r
.29666 .46873 m .30781 .46566 L .31123 .46886 L p F P
0 g
s
.653 .747 .918 r
.30781 .46566 m .29666 .46873 L .29321 .4658 L p F P
0 g
s
.682 .165 0 r
.19401 .31123 m .19802 .31457 L .1947 .31062 L p F P
0 g
s
.682 .165 0 r
.1947 .31062 m .19073 .30727 L .19401 .31123 L p F P
0 g
s
.778 .907 .93 r
.7175 .21177 m .70731 .21836 L .70461 .21659 L p F P
0 g
s
.848 .446 .279 r
.25289 .36916 m .25852 .37184 L .25645 .36734 L p F P
0 g
s
.848 .446 .279 r
.25645 .36734 m .25094 .36461 L .25289 .36916 L p F P
0 g
s
.64 .923 .646 r
.6249 .28625 m .62383 .28698 L .62706 .28382 L closepath p F P
0 g
s
0 0 0 r
.79509 .30316 m .79764 .29702 L .79427 .30241 L p F P
0 g
s
0 0 0 r
.79309 .30635 m .79509 .30316 L p .79427 .30241 L F P
0 g
s
0 0 0 r
.79427 .30241 m .79385 .30341 L .79309 .30635 L p F P
0 g
s
.654 .943 .96 r
.63854 .43405 m .63907 .43417 L .62955 .44024 L p F P
0 g
s
.654 .943 .96 r
.62955 .44024 m .62684 .43959 L .63854 .43405 L p F P
0 g
s
.759 .5 .541 r
.34062 .4285 m .34572 .42934 L .3459 .42398 L p F P
0 g
s
.759 .5 .541 r
.3459 .42398 m .34084 .42315 L .34062 .4285 L p F P
0 g
s
.649 .767 .935 r
.47514 .46917 m .48662 .46566 L .48976 .46876 L p F P
0 g
s
.658 .732 .905 r
.48662 .46566 m .47514 .46917 L .47199 .46567 L p F P
0 g
s
.171 .166 .609 r
.80816 .24871 m .80657 .25204 L .80517 .24555 L p F P
0 g
s
.171 .166 .609 r
.80517 .24555 m .80581 .24419 L .80816 .24871 L p F P
0 g
s
.843 .384 .103 r
.22349 .33904 m .22391 .33979 L .22859 .34284 L p F P
0 g
s
.853 .403 .131 r
.22619 .34417 m .23094 .3472 L .22859 .34284 L p F P
0 g
s
.853 .403 .131 r
.22859 .34284 m .22391 .33979 L .22619 .34417 L p F P
0 g
s
.824 .433 .311 r
.26654 .37527 m .26524 .37621 L .26444 .37442 L closepath p F P
0 g
s
.781 .496 .505 r
.32232 .4196 m .32808 .4209 L .32765 .41576 L p F P
0 g
s
.781 .496 .505 r
.32765 .41576 m .32303 .41471 L .32232 .4196 L p F P
0 g
s
.639 .818 .969 r
.53055 .46338 m .51899 .46694 L .51591 .46456 L p F P
0 g
s
.636 .815 .969 r
.50437 .46803 m .51591 .46456 L .51899 .46694 L p F P
0 g
s
.352 .418 .79 r
.79684 .22049 m .79815 .22373 L .8023 .22593 L p F P
0 g
s
.676 .974 .808 r
.71793 .39139 m .71671 .39169 L .72095 .38846 L closepath p F P
0 g
s
0 .307 .765 r
.07856 .39248 m .08347 .39526 L .08738 .39855 L p F P
0 g
s
0 .313 .774 r
.08347 .39526 m .07856 .39248 L .07478 .38917 L p F P
0 g
s
.642 .792 .954 r
.48976 .46876 m .50127 .46531 L .50437 .46803 L p F P
0 g
s
.651 .762 .931 r
.50127 .46531 m .48976 .46876 L .48662 .46566 L p F P
0 g
s
.552 .595 .85 r
.79139 .20847 m .79051 .21035 L p .77731 .20526 L F P
0 g
s
.552 .595 .85 r
.77731 .20526 m .78958 .20487 L .79139 .20847 L p F P
0 g
s
.54 .635 .894 r
.77647 .20386 m .77731 .20526 L .78958 .20487 L p F P
0 g
s
0 0 0 r
.79385 .30341 m .79156 .30859 L .79309 .30635 L closepath p F P
0 g
s
.644 .791 .953 r
.51591 .46456 m .50437 .46803 L .50127 .46531 L p F P
0 g
s
.662 .742 .91 r
.31123 .46886 m .32245 .46505 L .32582 .46859 L p F P
0 g
s
.682 .729 .886 r
.32245 .46505 m .31123 .46886 L .30781 .46566 L p F P
0 g
s
.36 .692 .982 r
.21355 .45366 m .20977 .4535 L .21531 .45612 L p F P
0 g
s
.36 .692 .982 r
.21531 .45612 m .21716 .45621 L .21355 .45366 L p F P
0 g
s
.677 .977 .873 r
.69463 .40731 m .69345 .40809 L .6908 .40828 L p F P
0 g
s
.673 .974 .897 r
.68094 .41554 m .67912 .41554 L .68646 .41104 L closepath p F P
0 g
s
.65 .143 0 r
.18368 .2999 m .18205 .29792 L .17843 .29452 L p F P
0 g
s
.636 .913 .981 r
.59771 .4479 m .60062 .44895 L .58897 .45363 L p F P
0 g
s
.636 .913 .981 r
.59195 .4502 m .59771 .4479 L p .58897 .45363 L F P
0 g
s
.636 .913 .981 r
.58897 .45363 m .58679 .45282 L .59195 .4502 L p F P
0 g
s
.127 .547 .92 r
.1454 .42982 m .14133 .42874 L .14593 .43172 L p F P
0 g
s
.127 .547 .92 r
.14593 .43172 m .14911 .43258 L .1454 .42982 L p F P
0 g
s
.739 .51 .582 r
.35823 .43673 m .36456 .4374 L .36579 .43168 L p F P
0 g
s
.739 .51 .582 r
.36579 .43168 m .35791 .43086 L .35823 .43673 L p F P
0 g
s
.659 .972 .841 r
.69463 .40731 m .70508 .40016 L .70248 .40057 L p F P
0 g
s
.659 .972 .841 r
.70248 .40057 m .70205 .40087 L .69463 .40731 L p F P
0 g
s
.677 .977 .873 r
.6908 .40828 m .70205 .40087 L .69463 .40731 L p F P
0 g
s
.193 .594 .944 r
.16328 .43752 m .16 .43685 L .16483 .43974 L p F P
0 g
s
.193 .594 .944 r
.16483 .43974 m .16697 .44018 L .16328 .43752 L p F P
0 g
s
.828 .483 .403 r
.2835 .39407 m .28815 .39582 L .2868 .39102 L p F P
0 g
s
.828 .483 .403 r
.2868 .39102 m .2857 .3906 L .2835 .39407 L p F P
0 g
s
.682 .725 .882 r
.32582 .46859 m .3371 .46405 L .34044 .46801 L p F P
0 g
s
.701 .707 .852 r
.3371 .46405 m .32582 .46859 L .32245 .46505 L p F P
0 g
s
.832 .398 .203 r
.24588 .35848 m .2443 .35866 L .24357 .35732 L closepath p F P
0 g
s
.803 .496 .47 r
.30425 .41003 m .31155 .41211 L .3107 .40711 L p F P
0 g
s
.803 .496 .47 r
.30372 .40663 m .30425 .41003 L p .3107 .40711 L F P
0 g
s
.803 .496 .47 r
.3107 .40711 m .30411 .4052 L .30372 .40663 L p F P
0 g
s
.695 .706 .856 r
.34044 .46801 m .35175 .46281 L .35505 .46723 L p F P
0 g
s
.711 .689 .827 r
.34044 .46801 m .35175 .46281 L .34979 .4598 L p F P
0 g
s
.711 .689 .827 r
.3371 .46405 m .34044 .46801 L p .34979 .4598 L F P
0 g
s
.702 .677 .823 r
.3823 .46244 m .37758 .46226 L .36968 .46639 L p F P
0 g
s
.706 .69 .832 r
.37758 .46226 m .36968 .46639 L .36641 .46151 L p F P
0 g
s
.701 .688 .834 r
.35505 .46723 m .36641 .46151 L .36968 .46639 L p F P
0 g
s
.512 .761 .986 r
.2496 .46317 m .25179 .46292 L .2473 .46153 L closepath p F P
0 g
s
.713 .671 .807 r
.35505 .46723 m .36641 .46151 L .36635 .4614 L p F P
0 g
s
.713 .671 .807 r
.35175 .46281 m .35505 .46723 L p .36635 .4614 L F P
0 g
s
.481 .207 .421 r
.50756 .39976 m .50821 .39513 L .49687 .39895 L p F P
0 g
s
.481 .207 .421 r
.49687 .39895 m .49621 .40358 L .50756 .39976 L p F P
0 g
s
.699 .667 .816 r
.3975 .46275 m .38998 .46268 L .38429 .46564 L p F P
0 g
s
.701 .675 .822 r
.38998 .46268 m .3823 .46244 L .38429 .46564 L closepath p F P
0 g
s
.703 .181 0 r
.19911 .3159 m .19802 .31457 L .20219 .31784 L p F P
0 g
s
.703 .181 0 r
.20219 .31784 m .20276 .31853 L .19911 .3159 L p F P
0 g
s
.293 .66 .971 r
.18487 .44704 m .18569 .44713 L .18308 .4458 L closepath p F P
0 g
s
0 0 .375 r
.80779 .26911 m .80479 .27445 L .8048 .26915 L p F P
0 g
s
0 0 .375 r
.8048 .26915 m .80781 .2638 L .80779 .26911 L p F P
0 g
s
.427 .482 .814 r
.79524 .21677 m .79795 .21764 L .79684 .22049 L closepath p F P
0 g
s
.352 .418 .79 r
.80452 .22073 m .79795 .21764 L .79684 .22049 L p F P
0 g
s
.352 .418 .79 r
.8023 .22593 m .80452 .22073 L p .79684 .22049 L F P
0 g
s
.733 .825 .922 r
.73831 .20425 m .7452 .20091 L .74251 .19785 L p F P
0 g
s
.733 .825 .922 r
.74251 .19785 m .74016 .19907 L .73831 .20425 L p F P
0 g
s
.719 .833 .935 r
.73071 .20396 m .74016 .19907 L .73831 .20425 L p F P
0 g
s
.059 .496 .892 r
.12758 .42127 m .12416 .42013 L .12854 .42321 L p F P
0 g
s
.059 .496 .892 r
.12854 .42321 m .13132 .42414 L .12758 .42127 L p F P
0 g
s
.645 .43 .577 r
.43745 .43075 m .43278 .43132 L .43306 .43707 L p F P
0 g
s
.523 .259 .457 r
.49571 .40841 m .49621 .40358 L .48451 .40698 L p F P
0 g
s
.523 .259 .457 r
.48451 .40698 m .48399 .4118 L .49571 .40841 L p F P
0 g
s
0 0 .183 r
.8014 .28825 m .79964 .29106 L .80105 .2853 L p F P
0 g
s
0 0 .183 r
.80105 .2853 m .80179 .28411 L .8014 .28825 L p F P
0 g
s
.756 .498 .542 r
.33658 .42788 m .34062 .4285 L .34084 .42315 L p F P
0 g
s
.756 .498 .542 r
.34084 .42315 m .33677 .42252 L .33658 .42788 L p F P
0 g
s
.422 .133 .366 r
.50902 .3907 m .5087 .39237 L .51495 .38837 L closepath p F P
0 g
s
.848 .403 .16 r
.23325 .35159 m .2383 .3545 L .23589 .35014 L p F P
0 g
s
.848 .403 .16 r
.23589 .35014 m .23094 .3472 L .23325 .35159 L p F P
0 g
s
.693 .662 .814 r
.41212 .46248 m .40379 .46266 L .39891 .46512 L p F P
0 g
s
.694 .665 .817 r
.40379 .46266 m .3975 .46275 L .39891 .46512 L closepath p F P
0 g
s
.83 .435 .302 r
.26046 .37641 m .25852 .37184 L .26444 .37442 L p F P
0 g
s
.83 .435 .302 r
.2631 .37753 m .26046 .37641 L p .26444 .37442 L F P
0 g
s
.83 .435 .302 r
.26444 .37442 m .26524 .37621 L .2631 .37753 L p F P
0 g
s
0 0 0 r
.77473 .33527 m .77989 .3283 L .77579 .33385 L p F P
0 g
s
0 0 0 r
.77579 .33385 m .77409 .33613 L .77287 .3378 L p F P
0 g
s
0 0 0 r
.77287 .3378 m .77473 .33527 L p .77579 .33385 L F P
0 g
s
.813 .463 .394 r
.28167 .39345 m .2835 .39407 L .2857 .3906 L p F P
0 g
s
.813 .463 .394 r
.2857 .3906 m .28013 .38871 L .28167 .39345 L p F P
0 g
s
0 0 0 r
.56773 .3419 m .56635 .34493 L .57325 .33801 L closepath p F P
0 g
s
0 .337 .789 r
.08846 .39792 m .08347 .39526 L .08738 .39855 L p F P
0 g
s
0 .337 .789 r
.08738 .39855 m .09224 .40115 L .08846 .39792 L p F P
0 g
s
.578 .659 .892 r
.77457 .20075 m .77742 .20041 L .77647 .20386 L closepath p F P
0 g
s
.54 .635 .894 r
.78679 .19962 m .77742 .20041 L .77647 .20386 L p F P
0 g
s
.54 .635 .894 r
.78958 .20487 m .78679 .19962 L p .77647 .20386 L F P
0 g
s
.562 .312 .495 r
.48368 .41685 m .48399 .4118 L .47189 .41474 L p F P
0 g
s
.562 .312 .495 r
.47189 .41474 m .47156 .41979 L .48368 .41685 L p F P
0 g
s
.586 .332 .498 r
.46509 .42106 m .47156 .41979 L .47189 .41474 L p F P
0 g
s
.687 .661 .819 r
.42623 .46169 m .4195 .46205 L .41352 .46488 L p F P
0 g
s
.686 .659 .817 r
.4195 .46205 m .41212 .46248 L .41352 .46488 L closepath p F P
0 g
s
.773 .489 .505 r
.31993 .41911 m .32232 .4196 L .32303 .41471 L p F P
0 g
s
.773 .489 .505 r
.32303 .41471 m .31946 .41398 L .31993 .41911 L p F P
0 g
s
.678 .969 .772 r
.72936 .38224 m .7283 .3826 L .73179 .37973 L closepath p F P
0 g
s
.345 .682 .979 r
.19188 .44544 m .19553 .44807 L .18569 .44713 L p F P
0 g
s
.345 .682 .979 r
.18121 .44448 m .19188 .44544 L p .18569 .44713 L F P
0 g
s
.345 .682 .979 r
.18569 .44713 m .18308 .4458 L .18121 .44448 L p F P
0 g
s
.361 .061 .315 r
.52095 .3822 m .52023 .38529 L .52882 .37867 L closepath p F P
0 g
s
.74 .511 .582 r
.35426 .43631 m .35823 .43673 L .35791 .43086 L p F P
0 g
s
.74 .511 .582 r
.35791 .43086 m .35549 .4306 L .35426 .43631 L p F P
0 g
s
0 0 0 r
.77409 .33613 m .77042 .34088 L .77287 .3378 L closepath p F P
0 g
s
.435 .722 .986 r
.22799 .45609 m .21716 .45621 L .21355 .45366 L p F P
0 g
s
.778 .907 .93 r
.71628 .20866 m .71812 .21012 L .7175 .21177 L p F P
0 g
s
.778 .907 .93 r
.70461 .21659 m .71628 .20866 L p .7175 .21177 L F P
0 g
s
.78 .88 .919 r
.71897 .2108 m .7175 .21177 L .71812 .21012 L closepath p F P
0 g
s
0 0 0 r
.60169 .3091 m .60086 .31012 L .60383 .30709 L closepath p F P
0 g
s
.171 .17 .615 r
.81062 .24348 m .80816 .24871 L .80581 .24419 L p F P
0 g
s
.171 .17 .615 r
.80581 .24419 m .8082 .23899 L .81062 .24348 L p F P
0 g
s
.648 .433 .578 r
.44613 .42974 m .43745 .43075 L .43517 .43682 L p F P
0 g
s
.645 .43 .577 r
.43306 .43707 m .43517 .43682 L .43745 .43075 L p F P
0 g
s
.7 .508 .626 r
.40498 .43879 m .40127 .43882 L .39767 .44529 L p F P
0 g
s
.704 .514 .628 r
.39104 .44527 m .39767 .44529 L .40127 .43882 L p F P
0 g
s
.704 .514 .628 r
.40127 .43882 m .39008 .43878 L .39104 .44527 L p F P
0 g
s
.796 .306 0 r
.20501 .32198 m .20276 .31853 L .19911 .3159 L p F P
0 g
s
.805 .316 0 r
.20771 .32618 m .21201 .32939 L .20925 .32521 L p F P
0 g
s
.805 .316 0 r
.20925 .32521 m .20501 .32198 L .20771 .32618 L p F P
0 g
s
.688 .5 .627 r
.41663 .43831 m .40498 .43879 L .4059 .44522 L p F P
0 g
s
.7 .508 .626 r
.39767 .44529 m .4059 .44522 L .40498 .43879 L p F P
0 g
s
.713 .52 .627 r
.38456 .44509 m .39104 .44527 L .39008 .43878 L p F P
0 g
s
.713 .52 .627 r
.39008 .43878 m .38785 .43871 L .38456 .44509 L p F P
0 g
s
.812 .985 .886 r
.67009 .24404 m .66985 .244 L .67041 .24354 L closepath p F P
0 g
s
.768 .508 .542 r
.32787 .42627 m .33658 .42788 L .33677 .42252 L p F P
0 g
s
.768 .508 .542 r
.33677 .42252 m .32808 .4209 L .32787 .42627 L p F P
0 g
s
.766 .878 .928 r
.72801 .20142 m .73071 .20396 L .71897 .2108 L p F P
0 g
s
.766 .878 .928 r
.71999 .20638 m .72801 .20142 L p .71897 .2108 L F P
0 g
s
.766 .878 .928 r
.71897 .2108 m .71812 .21012 L .71999 .20638 L p F P
0 g
s
.718 .516 .615 r
.37552 .44465 m .38456 .44509 L .38785 .43871 L p F P
0 g
s
.718 .516 .615 r
.37483 .44042 m .37552 .44465 L p .38785 .43871 L F P
0 g
s
.718 .516 .615 r
.38785 .43871 m .37579 .43819 L .37483 .44042 L p F P
0 g
s
.748 .515 .579 r
.34461 .43501 m .35426 .43631 L .35549 .4306 L p F P
0 g
s
.748 .515 .579 r
.35549 .4306 m .34572 .42934 L .34461 .43501 L p F P
0 g
s
.628 .891 .567 r
.76336 .34946 m .7628 .34995 L .76444 .34811 L closepath p F P
0 g
s
.666 .968 .916 r
.66762 .42245 m .66745 .42244 L .66818 .42202 L closepath p F P
0 g
s
.818 .492 .438 r
.28922 .40072 m .29607 .40296 L .29487 .39809 L p F P
0 g
s
.818 .492 .438 r
.29487 .39809 m .28815 .39582 L .28922 .40072 L p F P
0 g
s
.088 .067 .536 r
.80964 .25351 m .80753 .25793 L .80657 .25204 L p F P
0 g
s
.088 .067 .536 r
.80657 .25204 m .80816 .24871 L .80964 .25351 L p F P
0 g
s
.68 .666 .83 r
.43978 .46034 m .43843 .46046 L .42813 .46492 L p F P
0 g
s
.678 .659 .824 r
.43843 .46046 m .42623 .46169 L .42813 .46492 L closepath p F P
0 g
s
0 .441 .859 r
.10985 .41177 m .10821 .41111 L .11239 .41428 L p F P
0 g
s
0 .441 .859 r
.11239 .41428 m .11361 .41477 L .10985 .41177 L p F P
0 g
s
.638 .892 .986 r
.58604 .45251 m .5744 .45685 L .57143 .45542 L p F P
0 g
s
.629 .887 .987 r
.5598 .45953 m .57143 .45542 L .5744 .45685 L p F P
0 g
s
.53 .763 .982 r
.25704 .45906 m .26057 .46186 L .25179 .46292 L p F P
0 g
s
.53 .763 .982 r
.24604 .46061 m .25704 .45906 L p .25179 .46292 L F P
0 g
s
.53 .763 .982 r
.25179 .46292 m .2473 .46153 L .24604 .46061 L p F P
0 g
s
.447 .504 .824 r
.79795 .21764 m .79524 .21677 L .79239 .21053 L p F P
0 g
s
.676 .977 .842 r
.70867 .39762 m .70508 .40016 L .70248 .40057 L p F P
0 g
s
0 .381 .82 r
.09742 .40495 m .09601 .40428 L .09224 .40115 L p F P
0 g
s
.595 .364 .536 r
.46509 .42106 m .45907 .4223 L .45901 .42766 L p F P
0 g
s
.79 .998 .846 r
.66099 .25184 m .65833 .25418 L .65568 .2544 L p F P
0 g
s
.808 .999 .839 r
.65833 .25418 m .65203 .25999 L .65568 .2544 L closepath p F P
0 g
s
.645 .936 .966 r
.624 .43886 m .62684 .43959 L .61517 .44489 L p F P
0 g
s
.645 .936 .966 r
.62157 .43995 m .624 .43886 L p .61517 .44489 L F P
0 g
s
.645 .936 .966 r
.61517 .44489 m .61385 .44454 L .62157 .43995 L p F P
0 g
s
.754 .991 .792 r
.65561 .25441 m .65568 .2544 L .65203 .25999 L p F P
0 g
s
.754 .991 .792 r
.64766 .26214 m .65561 .25441 L p .65203 .25999 L F P
0 g
s
.754 .991 .792 r
.64549 .26516 m .64766 .26214 L p .65203 .25999 L F P
0 g
s
.754 .991 .792 r
.65203 .25999 m .64682 .26477 L .64549 .26516 L p F P
0 g
s
.771 .994 .789 r
.64682 .26477 m .64339 .26803 L .64549 .26516 L closepath p F P
0 g
s
.816 .998 .843 r
.66099 .25184 m .66985 .244 L .66715 .24374 L p F P
0 g
s
.816 .998 .843 r
.66715 .24374 m .66454 .24616 L .66099 .25184 L p F P
0 g
s
.79 .998 .846 r
.65577 .25426 m .66454 .24616 L .66099 .25184 L p F P
0 g
s
.79 .998 .846 r
.65568 .2544 m .65577 .25426 L p .66099 .25184 L F P
0 g
s
.837 .398 .186 r
.24056 .35874 m .2383 .3545 L .24357 .35732 L p F P
0 g
s
.837 .398 .186 r
.24357 .35732 m .2443 .35866 L .24056 .35874 L p F P
0 g
s
.695 .961 .717 r
.64409 .2656 m .64549 .26516 L .64339 .26803 L p F P
0 g
s
.695 .961 .717 r
.63977 .26996 m .64409 .2656 L p .64339 .26803 L F P
0 g
s
.695 .961 .717 r
.63522 .27575 m .63977 .26996 L p .64339 .26803 L F P
0 g
s
.695 .961 .717 r
.64339 .26803 m .63532 .2757 L .63522 .27575 L p F P
0 g
s
.249 .628 .96 r
.16697 .44018 m .17555 .44153 L .1805 .44437 L p F P
0 g
s
.261 .63 .961 r
.17555 .44153 m .16697 .44018 L .16328 .43752 L p F P
0 g
s
0 0 0 r
.79195 .30957 m .78826 .31497 L .79156 .30859 L p F P
0 g
s
0 0 0 r
.79156 .30859 m .79309 .30635 L .79195 .30957 L p F P
0 g
s
.844 .481 .366 r
.26776 .38376 m .27377 .3863 L .27216 .3816 L p F P
0 g
s
.844 .481 .366 r
.27216 .3816 m .26627 .37903 L .26776 .38376 L p F P
0 g
s
.702 .604 .743 r
.3975 .46275 m .40379 .46266 L p .40782 .45266 L F P
0 g
s
.702 .604 .743 r
.3957 .45926 m .3975 .46275 L p .40782 .45266 L F P
0 g
s
.704 .644 .787 r
.3957 .45926 m .38998 .46268 L .3975 .46275 L closepath p F P
0 g
s
.573 .759 .966 r
.26409 .46457 m .27514 .46257 L .27863 .46544 L p F P
0 g
s
.591 .757 .957 r
.27514 .46257 m .26409 .46457 L .26057 .46186 L p F P
0 g
s
.675 .968 .923 r
.66818 .42202 m .66745 .42244 L .66472 .42219 L p F P
0 g
s
.711 .613 .747 r
.38998 .46268 m .3957 .45926 L .39302 .45277 L p F P
0 g
s
.711 .613 .747 r
.3823 .46244 m .38998 .46268 L p .39302 .45277 L F P
0 g
s
.293 0 .258 r
.53263 .37342 m .53177 .37657 L .53927 .37004 L closepath p F P
0 g
s
.804 .99 .88 r
.67041 .24354 m .66985 .244 L .66715 .24374 L p F P
0 g
s
.785 .501 .507 r
.31192 .41727 m .31993 .41911 L .31946 .41398 L p F P
0 g
s
.785 .501 .507 r
.31946 .41398 m .31155 .41211 L .31192 .41727 L p F P
0 g
s
.697 .638 .786 r
.41032 .45893 m .40379 .46266 L .41212 .46248 L closepath p F P
0 g
s
.702 .604 .743 r
.40379 .46266 m .41032 .45893 L .40782 .45266 L p F P
0 g
s
.686 .498 .626 r
.41928 .43819 m .41663 .43831 L .4125 .44496 L p F P
0 g
s
.688 .5 .627 r
.4059 .44522 m .4125 .44496 L .41663 .43831 L p F P
0 g
s
.828 .971 .89 r
.67382 .23789 m .67041 .24354 L .68063 .23497 L p F P
0 g
s
.804 .99 .88 r
.66715 .24374 m .67382 .23789 L .67041 .24354 L p F P
0 g
s
.709 .966 .718 r
.63532 .2757 m .63502 .27599 L .63522 .27575 L closepath p F P
0 g
s
0 0 .163 r
.80284 .2857 m .8014 .28825 L .80179 .28411 L p F P
0 g
s
0 0 .163 r
.80179 .28411 m .80412 .27997 L .80284 .2857 L p F P
0 g
s
.704 .962 .708 r
.63205 .27771 m .62706 .28382 L .63502 .27599 L p F P
0 g
s
.704 .962 .708 r
.63259 .27716 m .63205 .27771 L p .63502 .27599 L F P
0 g
s
.704 .962 .708 r
.63502 .27599 m .63522 .27575 L .63259 .27716 L p F P
0 g
s
.596 .856 .507 r
.76887 .34247 m .76444 .34811 L .77042 .34088 L p F P
0 g
s
.596 .856 .507 r
.77183 .3389 m .76887 .34247 L p .77042 .34088 L F P
0 g
s
.596 .856 .507 r
.77042 .34088 m .77287 .3378 L .77183 .3389 L p F P
0 g
s
.66 .97 .901 r
.67912 .41554 m .66818 .42202 L .67657 .41552 L closepath p F P
0 g
s
.675 .968 .923 r
.67643 .4155 m .67657 .41552 L .66818 .42202 L p F P
0 g
s
.675 .968 .923 r
.66472 .42219 m .67643 .4155 L p .66818 .42202 L F P
0 g
s
.661 .97 .81 r
.71671 .39169 m .70867 .39762 L .7145 .39223 L closepath p F P
0 g
s
.676 .977 .842 r
.71414 .39228 m .7145 .39223 L .70867 .39762 L p F P
0 g
s
.676 .977 .842 r
.70248 .40057 m .71414 .39228 L p .70867 .39762 L F P
0 g
s
.671 .487 .628 r
.43333 .43933 m .43306 .43707 L .41928 .43819 L p F P
0 g
s
.671 .487 .628 r
.43002 .44378 m .43333 .43933 L p .41928 .43819 L F P
0 g
s
.671 .487 .628 r
.41928 .43819 m .4202 .44462 L .43002 .44378 L p F P
0 g
s
.686 .498 .626 r
.4125 .44496 m .4202 .44462 L .41928 .43819 L p F P
0 g
s
.724 .523 .617 r
.37579 .43819 m .37453 .43811 L .37483 .44042 L closepath p F P
0 g
s
.693 .599 .746 r
.41212 .46248 m .4195 .46205 L p .42202 .45196 L F P
0 g
s
.693 .599 .746 r
.41032 .45893 m .41212 .46248 L p .42202 .45196 L F P
0 g
s
.638 .699 .89 r
.75981 .19973 m .77184 .19647 L .77457 .20075 L p F P
0 g
s
.653 .717 .895 r
.77184 .19647 m .75981 .19973 L .7571 .19612 L p F P
0 g
s
.688 .758 .905 r
.7452 .20091 m .7571 .19612 L .75981 .19973 L p F P
0 g
s
.729 .529 .621 r
.37275 .44448 m .37483 .44042 L .37453 .43811 L p F P
0 g
s
.729 .529 .621 r
.36185 .44359 m .37275 .44448 L p .37453 .43811 L F P
0 g
s
.729 .529 .621 r
.37453 .43811 m .36456 .4374 L .36185 .44359 L p F P
0 g
s
.669 .664 .836 r
.43978 .46034 m .44274 .46515 L .45419 .46071 L p F P
0 g
s
.673 .684 .852 r
.44274 .46515 m .45419 .46071 L .45736 .46546 L p F P
0 g
s
.711 .613 .747 r
.38106 .46018 m .3823 .46244 L p .39302 .45277 L F P
0 g
s
.709 .655 .795 r
.38106 .46018 m .37758 .46226 L .3823 .46244 L closepath p F P
0 g
s
.715 .965 .709 r
.63522 .27575 m .63259 .27716 L .63977 .26996 L closepath p F P
0 g
s
.807 .318 0 r
.21475 .3336 m .21929 .33672 L .21647 .33254 L p F P
0 g
s
.807 .318 0 r
.21647 .33254 m .21201 .32939 L .21475 .3336 L p F P
0 g
s
.6 .896 .607 r
.62473 .28534 m .63205 .27771 L .62706 .28382 L p F P
0 g
s
.6 .896 .607 r
.62233 .28815 m .62473 .28534 L p .62706 .28382 L F P
0 g
s
.6 .896 .607 r
.62706 .28382 m .62383 .28698 L .62233 .28815 L p F P
0 g
s
.657 .955 .944 r
.65025 .42809 m .65302 .42858 L .64134 .43454 L p F P
0 g
s
.657 .955 .944 r
.64113 .43275 m .65025 .42809 L p .64134 .43454 L F P
0 g
s
.657 .955 .944 r
.64134 .43454 m .63907 .43417 L .64113 .43275 L p F P
0 g
s
.433 .149 .38 r
.51495 .38837 m .5087 .39237 L .50821 .39513 L p F P
0 g
s
.85 .469 .328 r
.26524 .37621 m .26627 .37903 L .2631 .37753 L closepath p F P
0 g
s
.701 .772 .907 r
.7571 .19612 m .7452 .20091 L .74251 .19785 L p F P
0 g
s
.723 .639 .765 r
.37758 .46226 m .38106 .46018 L .37787 .45298 L p F P
0 g
s
.723 .639 .765 r
.37787 .45298 m .36655 .46142 L .37758 .46226 L p F P
0 g
s
.706 .69 .832 r
.36641 .46151 m .36655 .46142 L .37758 .46226 L p F P
0 g
s
.61 .9 .609 r
.62383 .28698 m .6192 .29161 L .62233 .28815 L closepath p F P
0 g
s
.827 .969 .892 r
.68141 .23432 m .68063 .23497 L .68103 .23421 L closepath p F P
0 g
s
.828 .971 .89 r
.6787 .23357 m .67382 .23789 L p .68063 .23497 L F P
0 g
s
.828 .971 .89 r
.68063 .23497 m .68103 .23421 L .6787 .23357 L p F P
0 g
s
.65 .143 0 r
.17843 .29452 m .17999 .29642 L .18368 .2999 L p F P
0 g
s
.658 .152 0 r
.1832 .30039 m .1869 .30386 L .18368 .2999 L p F P
0 g
s
.658 .152 0 r
.18368 .2999 m .17999 .29642 L .1832 .30039 L p F P
0 g
s
.81 .97 .904 r
.69185 .22608 m .68141 .23432 L .68103 .23421 L p F P
0 g
s
.627 .417 .579 r
.4593 .4334 m .45901 .42766 L .44613 .42974 L p F P
0 g
s
.627 .417 .579 r
.44613 .42974 m .44644 .43552 L .4593 .4334 L p F P
0 g
s
.648 .433 .578 r
.43517 .43682 m .44644 .43552 L .44613 .42974 L p F P
0 g
s
.844 .382 .081 r
.22349 .33904 m .22391 .33979 L .22167 .33825 L closepath p F P
0 g
s
.253 .269 .684 r
.81066 .23374 m .8082 .23899 L .80477 .23484 L p F P
0 g
s
.253 .269 .684 r
.80477 .23484 m .8071 .22963 L .81066 .23374 L p F P
0 g
s
.634 .861 .985 r
.54578 .46211 m .54518 .46176 L .55533 .45839 L closepath p F P
0 g
s
.182 .584 .94 r
.14911 .43258 m .15526 .43392 L .16 .43685 L p F P
0 g
s
.193 .587 .942 r
.15526 .43392 m .14911 .43258 L .1454 .42982 L p F P
0 g
s
.038 .479 .883 r
.11361 .41477 m .11987 .41701 L .12416 .42013 L p F P
0 g
s
.05 .482 .887 r
.11987 .41701 m .11361 .41477 L .10985 .41177 L p F P
0 g
s
0 0 0 r
.62109 .28915 m .62233 .28815 L .6192 .29161 L p F P
0 g
s
0 0 0 r
.61751 .29295 m .62109 .28915 L p .6192 .29161 L F P
0 g
s
0 0 0 r
.6192 .29161 m .61235 .29846 L .61208 .29873 L p F P
0 g
s
0 0 0 r
.61208 .29873 m .61751 .29295 L p .6192 .29161 L F P
0 g
s
.69 .639 .793 r
.42494 .4592 m .4195 .46205 L .42623 .46169 L closepath p F P
0 g
s
.693 .599 .746 r
.4195 .46205 m .42494 .4592 L .42202 .45196 L p F P
0 g
s
.259 .636 .962 r
.18308 .4458 m .18121 .44448 L .1805 .44437 L closepath p F P
0 g
s
.791 .483 .468 r
.30411 .4052 m .30372 .40663 L .30343 .40503 L closepath p F P
0 g
s
.635 .877 .986 r
.57143 .45542 m .5598 .45953 L .55679 .4579 L p F P
0 g
s
.86 .459 .277 r
.24752 .36638 m .25289 .36916 L .25094 .36461 L p F P
0 g
s
.86 .459 .277 r
.25094 .36461 m .24567 .3618 L .24752 .36638 L p F P
0 g
s
0 0 0 r
.57858 .33214 m .57787 .33348 L .58101 .33024 L closepath p F P
0 g
s
.505 .558 .844 r
.79051 .21035 m .79139 .20847 L .79239 .21053 L closepath p F P
0 g
s
.616 .757 .946 r
.27863 .46544 m .28975 .4627 L .29321 .4658 L p F P
0 g
s
.636 .752 .932 r
.28975 .4627 m .27863 .46544 L .27514 .46257 L p F P
0 g
s
.665 .706 .877 r
.45736 .46546 m .46883 .46144 L .47199 .46567 L p F P
0 g
s
.669 .659 .831 r
.45736 .46546 m .46883 .46144 L .46583 .45649 L p F P
0 g
s
.669 .659 .831 r
.45419 .46071 m .45736 .46546 L p .46583 .45649 L F P
0 g
s
.111 .534 .914 r
.13132 .42414 m .13682 .42571 L .14133 .42874 L p F P
0 g
s
.122 .537 .917 r
.13682 .42571 m .13132 .42414 L .12758 .42127 L p F P
0 g
s
.794 .485 .466 r
.2969 .40796 m .29607 .40296 L .30343 .40503 L p F P
0 g
s
.794 .485 .466 r
.30289 .40961 m .2969 .40796 L p .30343 .40503 L F P
0 g
s
.794 .485 .466 r
.30343 .40503 m .30372 .40663 L .30289 .40961 L p F P
0 g
s
.677 .96 .733 r
.74037 .37255 m .73987 .37277 L .74145 .37136 L closepath p F P
0 g
s
.678 .975 .81 r
.72095 .38846 m .71671 .39169 L .7145 .39223 L p F P
0 g
s
.726 .535 .632 r
.37483 .44042 m .37275 .44448 L .37552 .44465 L closepath p F P
0 g
s
.762 .529 .58 r
.34095 .43441 m .34461 .43501 L .34572 .42934 L p F P
0 g
s
.762 .529 .58 r
.34572 .42934 m .34062 .4285 L .34095 .43441 L p F P
0 g
s
.767 .88 .928 r
.71812 .21012 m .71628 .20866 L .71999 .20638 L closepath p F P
0 g
s
0 0 0 r
.61235 .29846 m .61143 .29937 L .61208 .29873 L closepath p F P
0 g
s
0 .381 .82 r
.09224 .40115 m .0934 .4017 L .09742 .40495 L p F P
0 g
s
0 .417 .847 r
.10012 .40465 m .10412 .4079 L .09742 .40495 L p F P
0 g
s
0 .417 .847 r
.09742 .40495 m .0934 .4017 L .10012 .40465 L p F P
0 g
s
.828 .479 .395 r
.27517 .39108 m .28167 .39345 L .28013 .38871 L p F P
0 g
s
.828 .479 .395 r
.28013 .38871 m .27377 .3863 L .27517 .39108 L p F P
0 g
s
.631 .893 .57 r
.7623 .3499 m .76887 .34247 L .76444 .34811 L p F P
0 g
s
.631 .893 .57 r
.7611 .35144 m .7623 .3499 L p .76444 .34811 L F P
0 g
s
.631 .893 .57 r
.76444 .34811 m .7628 .34995 L .7611 .35144 L p F P
0 g
s
.216 0 .194 r
.54406 .36434 m .54331 .36674 L .54854 .36179 L closepath p F P
0 g
s
.702 .604 .743 r
.40782 .45266 m .40483 .45271 L .3957 .45926 L p F P
0 g
s
.705 .609 .747 r
.40483 .45271 m .39302 .45277 L .3957 .45926 L closepath p F P
0 g
s
.741 .543 .626 r
.35926 .44331 m .36185 .44359 L .36456 .4374 L p F P
0 g
s
.741 .543 .626 r
.36456 .4374 m .35823 .43673 L .35926 .44331 L p F P
0 g
s
0 0 0 r
.60985 .30112 m .60383 .30709 L .61143 .29937 L p F P
0 g
s
0 0 0 r
.61143 .29937 m .61208 .29873 L .60985 .30112 L p F P
0 g
s
.863 .45 .241 r
.24567 .3618 m .2443 .35866 L .24056 .35874 L p F P
0 g
s
.048 0 .466 r
.80809 .2633 m .80781 .2638 L .80708 .25875 L p F P
0 g
s
.048 0 .466 r
.80708 .25875 m .80753 .25793 L .80809 .2633 L p F P
0 g
s
.711 .613 .747 r
.39302 .45277 m .39099 .45273 L .38106 .46018 L p F P
0 g
s
.716 .624 .754 r
.39099 .45273 m .38106 .46018 L .37787 .45298 L p F P
0 g
s
.68 .634 .797 r
.42494 .4592 m .42623 .46169 L .43843 .46046 L p F P
0 g
s
.599 .367 .536 r
.47156 .41979 m .46509 .42106 L .46519 .42639 L p F P
0 g
s
.595 .364 .536 r
.45901 .42766 m .46519 .42639 L .46509 .42106 L p F P
0 g
s
.478 .738 .985 r
.23158 .45865 m .23935 .45814 L .24519 .46066 L p F P
0 g
s
.494 .743 .983 r
.23935 .45814 m .23158 .45865 L .22799 .45609 L p F P
0 g
s
.366 .695 .983 r
.19918 .45063 m .20427 .45085 L .20977 .4535 L p F P
0 g
s
.374 .695 .982 r
.20993 .45105 m .20427 .45085 L .20977 .4535 L p F P
0 g
s
.374 .695 .982 r
.20977 .4535 m .21355 .45366 L .20993 .45105 L p F P
0 g
s
.609 .884 .566 r
.7628 .34995 m .75757 .35561 L .7611 .35144 L closepath p F P
0 g
s
.379 .699 .983 r
.20427 .45085 m .19918 .45063 L .19553 .44807 L p F P
0 g
s
.859 .412 .127 r
.22161 .34108 m .22619 .34417 L .22391 .33979 L p F P
0 g
s
.859 .412 .127 r
.2198 .33752 m .22161 .34108 L p .22391 .33979 L F P
0 g
s
.859 .412 .127 r
.22391 .33979 m .22167 .33825 L .2198 .33752 L p F P
0 g
s
0 0 .069 r
.80074 .29205 m .79764 .29702 L .79964 .29106 L p F P
0 g
s
0 0 .069 r
.79964 .29106 m .8014 .28825 L .80074 .29205 L p F P
0 g
s
.81 .97 .904 r
.68103 .23421 m .68375 .22941 L p .69185 .22608 L F P
0 g
s
.821 .972 .895 r
.68103 .23421 m .6787 .23357 L .68375 .22941 L closepath p F P
0 g
s
.821 .945 .905 r
.69299 .22517 m .69185 .22608 L .6924 .2249 L closepath p F P
0 g
s
.81 .97 .904 r
.69029 .22396 m .6924 .2249 L .69185 .22608 L p F P
0 g
s
.81 .97 .904 r
.68375 .22941 m .69029 .22396 L p .69185 .22608 L F P
0 g
s
.669 .156 0 r
.19016 .30783 m .19401 .31123 L .19073 .30727 L p F P
0 g
s
.669 .156 0 r
.19073 .30727 m .1869 .30386 L .19016 .30783 L p F P
0 g
s
.468 .738 .986 r
.2473 .46153 m .24604 .46061 L .24519 .46066 L closepath p F P
0 g
s
.662 .964 .774 r
.7283 .3826 m .72095 .38846 L .72618 .38331 L closepath p F P
0 g
s
.678 .975 .81 r
.72578 .38339 m .72618 .38331 L .72095 .38846 L p F P
0 g
s
.678 .975 .81 r
.71536 .39138 m .72578 .38339 L p .72095 .38846 L F P
0 g
s
.678 .975 .81 r
.7145 .39223 m .71536 .39138 L p .72095 .38846 L F P
0 g
s
.704 .547 .672 r
.4059 .44522 m .39767 .44529 L .39253 .45122 L p F P
0 g
s
.708 .553 .676 r
.39767 .44529 m .39104 .44527 L .39253 .45122 L closepath p F P
0 g
s
.693 .599 .746 r
.42202 .45196 m .42079 .45202 L .41032 .45893 L p F P
0 g
s
.693 .599 .746 r
.42079 .45202 m .40782 .45266 L .41032 .45893 L closepath p F P
0 g
s
.594 .673 .895 r
.77742 .20041 m .77457 .20075 L .77184 .19647 L p F P
0 g
s
.715 .559 .676 r
.39099 .45273 m .39253 .45122 L .39104 .44527 L p F P
0 g
s
.715 .559 .676 r
.3786 .45231 m .39099 .45273 L p .39104 .44527 L F P
0 g
s
.715 .559 .676 r
.39104 .44527 m .38456 .44509 L .3786 .45231 L p F P
0 g
s
.783 .521 .54 r
.32207 .42496 m .32787 .42627 L .32808 .4209 L p F P
0 g
s
.783 .521 .54 r
.32808 .4209 m .32232 .4196 L .32207 .42496 L p F P
0 g
s
.803 .945 .917 r
.70442 .21673 m .69299 .22517 L .6924 .2249 L p F P
0 g
s
.693 .539 .674 r
.4125 .44496 m .4059 .44522 L .40717 .45053 L closepath p F P
0 g
s
.704 .547 .672 r
.40483 .45271 m .40717 .45053 L .4059 .44522 L p F P
0 g
s
.704 .547 .672 r
.39302 .45277 m .40483 .45271 L p .4059 .44522 L F P
0 g
s
.704 .547 .672 r
.39253 .45122 m .39302 .45277 L p .4059 .44522 L F P
0 g
s
.415 .116 .347 r
.52023 .38529 m .51495 .38837 L .51999 .38643 L closepath p F P
0 g
s
.433 .149 .38 r
.5192 .39088 m .51999 .38643 L .51495 .38837 L p F P
0 g
s
.433 .149 .38 r
.50821 .39513 m .5192 .39088 L p .51495 .38837 L F P
0 g
s
.717 .669 .802 r
.36655 .46142 m .36635 .4614 L .36641 .46151 L closepath p F P
0 g
s
.654 .465 .616 r
.43517 .43682 m .43306 .43707 L .43333 .43933 L closepath p F P
0 g
s
.723 .606 .726 r
.36655 .46142 m .37787 .45298 L .3776 .45226 L p F P
0 g
s
.723 .606 .726 r
.36635 .4614 m .36655 .46142 L p .3776 .45226 L F P
0 g
s
.333 .366 .746 r
.80889 .22568 m .8071 .22963 L .8023 .22593 L p F P
0 g
s
.333 .366 .746 r
.80811 .22325 m .80889 .22568 L p .8023 .22593 L F P
0 g
s
.333 .366 .746 r
.8023 .22593 m .80452 .22073 L .80811 .22325 L p F P
0 g
s
.723 .606 .726 r
.36318 .45513 m .36635 .4614 L p .3776 .45226 L F P
0 g
s
.721 .646 .774 r
.36318 .45513 m .35551 .46057 L .36635 .4614 L closepath p F P
0 g
s
.713 .671 .807 r
.36635 .4614 m .35551 .46057 L .35175 .46281 L p F P
0 g
s
.658 .732 .905 r
.47199 .46567 m .48348 .46196 L .48662 .46566 L p F P
0 g
s
.663 .691 .867 r
.48348 .46196 m .47199 .46567 L .46883 .46144 L p F P
0 g
s
0 0 0 r
.60958 .30141 m .60985 .30112 L .60383 .30709 L p F P
0 g
s
0 0 0 r
.60351 .30801 m .60958 .30141 L p .60383 .30709 L F P
0 g
s
0 0 0 r
.59965 .31176 m .60351 .30801 L p .60383 .30709 L F P
0 g
s
0 0 0 r
.60383 .30709 m .60086 .31012 L .59965 .31176 L p F P
0 g
s
.722 .57 .682 r
.3776 .45226 m .3786 .45231 L .38456 .44509 L p F P
0 g
s
.722 .57 .682 r
.38456 .44509 m .37552 .44465 L .3776 .45226 L p F P
0 g
s
.653 .747 .918 r
.29321 .4658 m .3044 .46222 L .30781 .46566 L p F P
0 g
s
.673 .737 .898 r
.3044 .46222 m .29321 .4658 L .28975 .4627 L p F P
0 g
s
.644 .843 .977 r
.55533 .45839 m .54518 .46176 L .54214 .4597 L p F P
0 g
s
.636 .841 .979 r
.53055 .46338 m .54214 .4597 L .54518 .46176 L p F P
0 g
s
.447 .504 .824 r
.79239 .21053 m .79995 .21248 L .79795 .21764 L p F P
0 g
s
.4 .451 .798 r
.80605 .21722 m .80452 .22073 L .79795 .21764 L p F P
0 g
s
.4 .451 .798 r
.80507 .2146 m .80605 .21722 L p .79795 .21764 L F P
0 g
s
.4 .451 .798 r
.79795 .21764 m .79995 .21248 L .80507 .2146 L p F P
0 g
s
.646 .92 .977 r
.61229 .44404 m .60062 .44895 L .59771 .4479 L p F P
0 g
s
0 0 .269 r
.80709 .27465 m .80412 .27997 L .80479 .27445 L p F P
0 g
s
0 0 .269 r
.80479 .27445 m .80779 .26911 L .80709 .27465 L p F P
0 g
s
.138 .55 .924 r
.14167 .427 m .13682 .42571 L .14133 .42874 L p F P
0 g
s
.138 .55 .924 r
.14133 .42874 m .1454 .42982 L .14167 .427 L p F P
0 g
s
.204 .596 .946 r
.15958 .43479 m .15526 .43392 L .16 .43685 L p F P
0 g
s
.204 .596 .946 r
.16 .43685 m .16328 .43752 L .15958 .43479 L p F P
0 g
s
0 0 0 r
.60086 .31012 m .59623 .3148 L .59965 .31176 L closepath p F P
0 g
s
.719 .688 .819 r
.35551 .46057 m .34979 .4598 L .35175 .46281 L closepath p F P
0 g
s
.692 .537 .673 r
.4202 .44462 m .4125 .44496 L .40717 .45053 L p F P
0 g
s
.64 .916 .623 r
.76044 .35187 m .7611 .35144 L .75757 .35561 L p F P
0 g
s
.64 .916 .623 r
.75486 .35759 m .76044 .35187 L p .75757 .35561 L F P
0 g
s
.64 .916 .623 r
.75095 .36229 m .75486 .35759 L p .75757 .35561 L F P
0 g
s
.64 .916 .623 r
.75757 .35561 m .75138 .36198 L .75095 .36229 L p F P
0 g
s
.657 .469 .618 r
.44644 .43552 m .43517 .43682 L .43333 .43933 L p F P
0 g
s
.848 .457 .306 r
.25471 .37377 m .26046 .37641 L .25852 .37184 L p F P
0 g
s
.848 .457 .306 r
.25852 .37184 m .25289 .36916 L .25471 .37377 L p F P
0 g
s
.666 .96 .938 r
.65369 .42867 m .65302 .42858 L .65605 .42696 L closepath p F P
0 g
s
0 0 0 r
.60966 .30157 m .61274 .29804 L p .61042 .30051 L F P
0 g
s
0 0 0 r
.61004 .30091 m .61208 .29873 L p .61042 .30051 L F P
0 g
s
0 0 0 r
.61208 .29873 m .61751 .29295 L .61042 .30051 L p F P
0 g
s
.587 .87 .549 r
.61609 .2942 m .61042 .30051 L .61751 .29295 L p F P
0 g
s
0 0 0 r
.61274 .29804 m .61609 .2942 L .61042 .30051 L p F P
0 g
s
0 0 0 r
.61042 .30051 m .60985 .30112 L .61004 .30091 L p F P
0 g
s
0 0 0 r
.78812 .31606 m .78445 .32151 L .78826 .31497 L p F P
0 g
s
0 0 0 r
.79191 .30965 m .78812 .31606 L p .78826 .31497 L F P
0 g
s
0 0 0 r
.78826 .31497 m .79195 .30957 L .79191 .30965 L p F P
0 g
s
.68 .97 .775 r
.73179 .37973 m .7283 .3826 L .72618 .38331 L p F P
0 g
s
.742 .544 .626 r
.35153 .4425 m .35926 .44331 L .35823 .43673 L p F P
0 g
s
.742 .544 .626 r
.35823 .43673 m .35426 .43631 L .35153 .4425 L p F P
0 g
s
.733 .845 .933 r
.74016 .19907 m .73071 .20396 L .72801 .20142 L p F P
0 g
s
0 .313 .774 r
.07478 .38917 m .07964 .39192 L .08347 .39526 L p F P
0 g
s
.431 .516 .845 r
.79139 .20847 m .79239 .21053 L .79995 .21248 L p F P
0 g
s
.651 .762 .931 r
.48662 .46566 m .49815 .46212 L .50127 .46531 L p F P
0 g
s
.656 .725 .9 r
.49815 .46212 m .48662 .46566 L .48348 .46196 L p F P
0 g
s
.682 .729 .886 r
.30781 .46566 m .31907 .46115 L .32245 .46505 L p F P
0 g
s
.7 .714 .86 r
.31907 .46115 m .30781 .46566 L .3044 .46222 L p F P
0 g
s
.758 .526 .582 r
.33541 .43356 m .34095 .43441 L .34062 .4285 L p F P
0 g
s
.758 .526 .582 r
.34062 .4285 m .33658 .42788 L .33541 .43356 L p F P
0 g
s
0 0 0 r
.59808 .31396 m .59965 .31176 L .59623 .3148 L p F P
0 g
s
0 0 0 r
.59664 .31551 m .59808 .31396 L p .59623 .3148 L F P
0 g
s
0 0 0 r
.5892 .32207 m .59664 .31551 L p .59623 .3148 L F P
0 g
s
0 0 0 r
.59623 .3148 m .58937 .3218 L .5892 .32207 L p F P
0 g
s
.711 .689 .827 r
.34979 .4598 m .3456 .45937 L .3371 .46405 L p F P
0 g
s
.718 .712 .843 r
.3456 .45937 m .3371 .46405 L .33377 .45959 L p F P
0 g
s
.701 .707 .852 r
.32245 .46505 m .33377 .45959 L .3371 .46405 L p F P
0 g
s
.68 .634 .797 r
.43956 .45993 m .4364 .45259 L .42494 .4592 L p F P
0 g
s
.68 .634 .797 r
.43843 .46046 m .43956 .45993 L p .42494 .4592 L F P
0 g
s
.68 .594 .752 r
.42202 .45196 m .42494 .4592 L .4364 .45259 L p F P
0 g
s
0 0 .449 r
.81036 .25858 m .80809 .2633 L .80753 .25793 L p F P
0 g
s
0 0 .449 r
.80753 .25793 m .80964 .25351 L .81036 .25858 L p F P
0 g
s
.662 .956 .735 r
.73987 .37277 m .73179 .37973 L .73742 .37383 L closepath p F P
0 g
s
.68 .97 .775 r
.73739 .37384 m .73742 .37383 L .73179 .37973 L p F P
0 g
s
.68 .97 .775 r
.72706 .38237 m .73739 .37384 L p .73179 .37973 L F P
0 g
s
.68 .97 .775 r
.72618 .38331 m .72706 .38237 L p .73179 .37973 L F P
0 g
s
.641 .905 .983 r
.58679 .45282 m .58604 .45251 L .59195 .4502 L closepath p F P
0 g
s
.642 .822 .969 r
.54214 .4597 m .53055 .46338 L .52748 .46101 L p F P
0 g
s
.639 .818 .969 r
.51591 .46456 m .52748 .46101 L .53055 .46338 L p F P
0 g
s
.713 .578 .703 r
.39253 .45122 m .39099 .45273 L .39302 .45277 L closepath p F P
0 g
s
.856 .413 .154 r
.22841 .34859 m .23325 .35159 L .23094 .3472 L p F P
0 g
s
.856 .413 .154 r
.23094 .3472 m .22619 .34417 L .22841 .34859 L p F P
0 g
s
.726 .572 .681 r
.36702 .45163 m .3776 .45226 L .37552 .44465 L p F P
0 g
s
.726 .572 .681 r
.37552 .44465 m .37275 .44448 L .36702 .45163 L p F P
0 g
s
.717 .695 .828 r
.32245 .46505 m .33377 .45959 L .33217 .45719 L p F P
0 g
s
.717 .695 .828 r
.31907 .46115 m .32245 .46505 L p .33217 .45719 L F P
0 g
s
0 0 0 r
.78356 .32281 m .78304 .32366 L .78445 .32151 L closepath p F P
0 g
s
.675 .974 .899 r
.68646 .41104 m .67912 .41554 L .67657 .41552 L p F P
0 g
s
.81 .503 .47 r
.30372 .40663 m .30425 .41003 L .30289 .40961 L closepath p F P
0 g
s
.678 .531 .678 r
.43002 .44378 m .4202 .44462 L .42179 .4512 L closepath p F P
0 g
s
.692 .537 .673 r
.42079 .45202 m .42179 .4512 L .4202 .44462 L p F P
0 g
s
.692 .537 .673 r
.40782 .45266 m .42079 .45202 L p .4202 .44462 L F P
0 g
s
.692 .537 .673 r
.40717 .45053 m .40782 .45266 L p .4202 .44462 L F P
0 g
s
.716 .624 .754 r
.37787 .45298 m .3786 .45231 L .39099 .45273 L p F P
0 g
s
.618 .907 .62 r
.75138 .36198 m .75001 .36333 L .75095 .36229 L closepath p F P
0 g
s
.803 .517 .505 r
.30457 .41521 m .31192 .41727 L .31155 .41211 L p F P
0 g
s
.803 .517 .505 r
.31155 .41211 m .30425 .41003 L .30457 .41521 L p F P
0 g
s
.702 .568 .701 r
.40717 .45053 m .40483 .45271 L .40782 .45266 L closepath p F P
0 g
s
.661 .945 .695 r
.74664 .36553 m .74145 .37136 L .75001 .36333 L p F P
0 g
s
.661 .945 .695 r
.74895 .36336 m .74664 .36553 L p .75001 .36333 L F P
0 g
s
.661 .945 .695 r
.75001 .36333 m .75095 .36229 L .74895 .36336 L p F P
0 g
s
.831 .502 .432 r
.28281 .39833 m .28922 .40072 L .28815 .39582 L p F P
0 g
s
.831 .502 .432 r
.2824 .39633 m .28281 .39833 L p .28815 .39582 L F P
0 g
s
.831 .502 .432 r
.28815 .39582 m .2835 .39407 L .2824 .39633 L p F P
0 g
s
.653 .928 .973 r
.61385 .44454 m .61229 .44404 L .62157 .43995 L closepath p F P
0 g
s
.692 .174 0 r
.19547 .31302 m .19401 .31123 L .19802 .31457 L p F P
0 g
s
.692 .174 0 r
.19802 .31457 m .19911 .3159 L .19547 .31302 L p F P
0 g
s
.644 .791 .953 r
.50127 .46531 m .51281 .46182 L .51591 .46456 L p F P
0 g
s
.65 .76 .929 r
.51281 .46182 m .50127 .46531 L .49815 .46212 L p F P
0 g
s
.657 .469 .618 r
.43333 .43933 m .43396 .44347 L p .44644 .43552 L F P
0 g
s
.673 .492 .632 r
.43333 .43933 m .43002 .44378 L .43396 .44347 L closepath p F P
0 g
s
.07 .499 .896 r
.12383 .41833 m .11987 .41701 L .12416 .42013 L p F P
0 g
s
.07 .499 .896 r
.12416 .42013 m .12758 .42127 L .12383 .41833 L p F P
0 g
s
.68 .962 .735 r
.74145 .37136 m .73987 .37277 L .73742 .37383 L p F P
0 g
s
.645 .793 .953 r
.52748 .46101 m .51591 .46456 L .51281 .46182 L p F P
0 g
s
.733 .564 .663 r
.36151 .4511 m .36702 .45163 L .37275 .44448 L p F P
0 g
s
.733 .564 .663 r
.36002 .44632 m .36151 .4511 L p .37275 .44448 L F P
0 g
s
.733 .564 .663 r
.37275 .44448 m .36185 .44359 L .36002 .44632 L p F P
0 g
s
.68 .962 .735 r
.73748 .37376 m .74664 .36553 L .74145 .37136 L p F P
0 g
s
.68 .962 .735 r
.73742 .37383 m .73748 .37376 L p .74145 .37136 L F P
0 g
s
0 0 0 r
.79201 .30948 m .79195 .30957 L .79309 .30635 L p F P
0 g
s
0 0 0 r
.79309 .30635 m .79509 .30316 L .79201 .30948 L p F P
0 g
s
.751 .548 .62 r
.34224 .44109 m .35153 .4425 L .35426 .43631 L p F P
0 g
s
.751 .548 .62 r
.35426 .43631 m .34461 .43501 L .34224 .44109 L p F P
0 g
s
.474 .734 .984 r
.24249 .45792 m .23935 .45814 L .24519 .46066 L p F P
0 g
s
.474 .734 .984 r
.24519 .46066 m .24604 .46061 L .24249 .45792 L p F P
0 g
s
0 0 0 r
.58937 .3218 m .58864 .32251 L .5892 .32207 L closepath p F P
0 g
s
.266 .635 .963 r
.17754 .44181 m .17555 .44153 L .1805 .44437 L p F P
0 g
s
.266 .635 .963 r
.1805 .44437 m .18121 .44448 L .17754 .44181 L p F P
0 g
s
0 0 0 r
.58744 .32513 m .58101 .33024 L .58864 .32251 L p F P
0 g
s
0 0 0 r
.58864 .32251 m .5892 .32207 L .58744 .32513 L p F P
0 g
s
.73 .626 .743 r
.35551 .46057 m .36318 .45513 L .36151 .4511 L p F P
0 g
s
.73 .626 .743 r
.34979 .4598 m .35551 .46057 L p .36151 .4511 L F P
0 g
s
.128 0 .12 r
.55524 .35497 m .55484 .35611 L .5572 .35373 L closepath p F P
0 g
s
.378 .084 .334 r
.52882 .37867 m .52023 .38529 L .51999 .38643 L p F P
0 g
s
.538 .293 .492 r
.49542 .41347 m .49571 .40841 L .48399 .4118 L p F P
0 g
s
.538 .293 .492 r
.48399 .4118 m .48368 .41685 L .49542 .41347 L p F P
0 g
s
.803 .945 .917 r
.6924 .2249 m .69466 .2206 L p .70442 .21673 L F P
0 g
s
.813 .948 .91 r
.6924 .2249 m .69029 .22396 L .69466 .2206 L closepath p F P
0 g
s
.682 .646 .807 r
.43956 .45993 m .43843 .46046 L .43978 .46034 L closepath p F P
0 g
s
.495 .237 .452 r
.50707 .40458 m .50756 .39976 L .49621 .40358 L p F P
0 g
s
.495 .237 .452 r
.49621 .40358 m .49571 .40841 L .50707 .40458 L p F P
0 g
s
.809 .918 .912 r
.70461 .21659 m .70442 .21673 L .7045 .21652 L closepath p F P
0 g
s
.803 .945 .917 r
.70192 .21496 m .7045 .21652 L .70442 .21673 L p F P
0 g
s
.803 .945 .917 r
.69466 .2206 m .70192 .21496 L p .70442 .21673 L F P
0 g
s
.721 .601 .722 r
.3786 .45231 m .3776 .45226 L .37787 .45298 L closepath p F P
0 g
s
.796 .918 .92 r
.71359 .20662 m .71628 .20866 L .70461 .21659 L p F P
0 g
s
.796 .918 .92 r
.70708 .21129 m .71359 .20662 L p .70461 .21659 L F P
0 g
s
.796 .918 .92 r
.70461 .21659 m .7045 .21652 L .70708 .21129 L p F P
0 g
s
.578 .35 .534 r
.48365 .42222 m .48368 .41685 L .47156 .41979 L p F P
0 g
s
.578 .35 .534 r
.47156 .41979 m .47151 .42515 L .48365 .42222 L p F P
0 g
s
.599 .367 .536 r
.46519 .42639 m .47151 .42515 L .47156 .41979 L p F P
0 g
s
.723 .606 .726 r
.3776 .45226 m .36702 .45163 L .36318 .45513 L p F P
0 g
s
.769 .534 .579 r
.32681 .43192 m .33541 .43356 L .33658 .42788 L p F P
0 g
s
.769 .534 .579 r
.33658 .42788 m .32787 .42627 L .32681 .43192 L p F P
0 g
s
.594 .673 .895 r
.77184 .19647 m .77907 .19531 L .77742 .20041 L p F P
0 g
s
.567 .631 .875 r
.78402 .19466 m .77907 .19531 L .77742 .20041 L p F P
0 g
s
.567 .631 .875 r
.77742 .20041 m .78679 .19962 L .78402 .19466 L p F P
0 g
s
.675 .643 .81 r
.43956 .45993 m .43978 .46034 L .4531 .45872 L p F P
0 g
s
.669 .664 .836 r
.45419 .46071 m .4531 .45872 L .43978 .46034 L p F P
0 g
s
.431 .516 .845 r
.80212 .20724 m .79246 .2052 L .79139 .20847 L p F P
0 g
s
.431 .516 .845 r
.80214 .20728 m .80212 .20724 L p .79139 .20847 L F P
0 g
s
.431 .516 .845 r
.79995 .21248 m .80214 .20728 L p .79139 .20847 L F P
0 g
s
.491 .562 .855 r
.78958 .20487 m .79246 .2052 L .79139 .20847 L closepath p F P
0 g
s
.559 .753 .968 r
.25704 .45906 m .24604 .46061 L .24249 .45792 L p F P
0 g
s
.854 .488 .358 r
.26206 .38111 m .26776 .38376 L .26627 .37903 L p F P
0 g
s
.854 .488 .358 r
.2614 .37891 m .26206 .38111 L p .26627 .37903 L F P
0 g
s
.854 .488 .358 r
.26627 .37903 m .2631 .37753 L .2614 .37891 L p F P
0 g
s
0 .342 .797 r
.08468 .39461 m .07964 .39192 L .08347 .39526 L p F P
0 g
s
0 .342 .797 r
.08347 .39526 m .08846 .39792 L .08468 .39461 L p F P
0 g
s
.798 .92 .919 r
.7045 .21652 m .70192 .21496 L .70708 .21129 L closepath p F P
0 g
s
0 0 0 r
.58657 .32671 m .58744 .32513 L .58101 .33024 L p F P
0 g
s
0 0 0 r
.58316 .33043 m .58657 .32671 L p .58101 .33024 L F P
0 g
s
0 0 0 r
.57694 .33539 m .58316 .33043 L p .58101 .33024 L F P
0 g
s
0 0 0 r
.58101 .33024 m .57787 .33348 L .57694 .33539 L p F P
0 g
s
.775 .514 .541 r
.31972 .42448 m .32207 .42496 L .32232 .4196 L p F P
0 g
s
.775 .514 .541 r
.32232 .4196 m .31993 .41911 L .31972 .42448 L p F P
0 g
s
.66 .942 .962 r
.63854 .43405 m .62684 .43959 L .624 .43886 L p F P
0 g
s
.334 .668 .975 r
.19188 .44544 m .18121 .44448 L .17754 .44181 L p F P
0 g
s
.675 .643 .81 r
.4531 .45872 m .45103 .45435 L .43956 .45993 L p F P
0 g
s
.674 .572 .733 r
.43956 .45993 m .45103 .45435 L .44913 .4492 L p F P
0 g
s
.674 .572 .733 r
.4364 .45259 m .43956 .45993 L p .44913 .4492 L F P
0 g
s
0 0 0 r
.58989 .32297 m .58744 .32513 L .5892 .32207 L p F P
0 g
s
0 0 0 r
.5892 .32207 m .59664 .31551 L .58989 .32297 L p F P
0 g
s
.608 .401 .575 r
.46519 .42639 m .45901 .42766 L .4593 .4334 L p F P
0 g
s
.771 .993 .782 r
.64549 .26516 m .64409 .2656 L .64766 .26214 L closepath p F P
0 g
s
.692 .564 .706 r
.42179 .4512 m .42079 .45202 L .42202 .45196 L closepath p F P
0 g
s
.448 .179 .411 r
.51855 .39549 m .5192 .39088 L .50821 .39513 L p F P
0 g
s
.448 .179 .411 r
.50821 .39513 m .50756 .39976 L .51855 .39549 L p F P
0 g
s
.817 .336 .035 r
.22167 .33825 m .2198 .33752 L .21929 .33672 L closepath p F P
0 g
s
.843 .401 .174 r
.23549 .35601 m .23325 .35159 L .2383 .3545 L p F P
0 g
s
.843 .401 .174 r
.24034 .35873 m .23549 .35601 L p .2383 .3545 L F P
0 g
s
.843 .401 .174 r
.2383 .3545 m .24056 .35874 L .24034 .35873 L p F P
0 g
s
.796 .306 0 r
.19911 .3159 m .20091 .31869 L .20501 .32198 L p F P
0 g
s
.803 .316 0 r
.20356 .3229 m .20771 .32618 L .20501 .32198 L p F P
0 g
s
.803 .316 0 r
.20501 .32198 m .20091 .31869 L .20356 .3229 L p F P
0 g
s
.68 .533 .68 r
.42179 .4512 m .42202 .45196 L p .43396 .44347 L F P
0 g
s
.68 .533 .68 r
.43396 .44347 m .43002 .44378 L .42179 .4512 L p F P
0 g
s
.68 .533 .68 r
.42202 .45196 m .4358 .45082 L .43396 .44347 L p F P
0 g
s
.68 .594 .752 r
.4364 .45259 m .4358 .45082 L .42202 .45196 L p F P
0 g
s
0 0 0 r
.57787 .33348 m .57325 .33801 L .57694 .33539 L closepath p F P
0 g
s
.675 .959 .943 r
.65605 .42696 m .65302 .42858 L .65025 .42809 L p F P
0 g
s
.088 .069 .539 r
.81215 .24828 m .80964 .25351 L .80816 .24871 L p F P
0 g
s
.088 .069 .539 r
.80816 .24871 m .81062 .24348 L .81215 .24828 L p F P
0 g
s
.357 .049 .298 r
.53177 .37657 m .52882 .37867 L .53154 .37748 L closepath p F P
0 g
s
.378 .084 .334 r
.53063 .38175 m .53154 .37748 L .52882 .37867 L p F P
0 g
s
.378 .084 .334 r
.51999 .38643 m .53063 .38175 L p .52882 .37867 L F P
0 g
s
.047 0 .04 r
.57539 .33876 m .57694 .33539 L .57325 .33801 L p F P
0 g
s
.047 0 .04 r
.56619 .34531 m .57539 .33876 L p .57325 .33801 L F P
0 g
s
.047 0 .04 r
.57325 .33801 m .56635 .34493 L .56619 .34531 L p F P
0 g
s
.638 .459 .624 r
.45944 .43454 m .4593 .4334 L .44644 .43552 L p F P
0 g
s
.638 .459 .624 r
.45316 .44088 m .45944 .43454 L p .44644 .43552 L F P
0 g
s
.638 .459 .624 r
.44644 .43552 m .44729 .44185 L .45316 .44088 L p F P
0 g
s
.657 .469 .618 r
.43396 .44347 m .44729 .44185 L .44644 .43552 L p F P
0 g
s
.002 .444 .864 r
.10609 .40869 m .10412 .4079 L .10821 .41111 L p F P
0 g
s
.002 .444 .864 r
.10821 .41111 m .10985 .41177 L .10609 .40869 L p F P
0 g
s
.652 .896 .982 r
.59195 .4502 m .58604 .45251 L .58309 .4511 L p F P
0 g
s
.638 .892 .986 r
.57143 .45542 m .58309 .4511 L .58604 .45251 L p F P
0 g
s
.816 .508 .469 r
.28996 .40575 m .2969 .40796 L .29607 .40296 L p F P
0 g
s
.816 .508 .469 r
.29607 .40296 m .28922 .40072 L .28996 .40575 L p F P
0 g
s
.741 .575 .668 r
.36185 .44359 m .35926 .44331 L .36002 .44632 L closepath p F P
0 g
s
.687 .954 .696 r
.75095 .36229 m .74895 .36336 L .75486 .35759 L closepath p F P
0 g
s
.73 .626 .743 r
.34847 .45753 m .34979 .4598 L p .36151 .4511 L F P
0 g
s
.721 .668 .798 r
.34847 .45753 m .3456 .45937 L .34979 .4598 L closepath p F P
0 g
s
.666 .974 .878 r
.6908 .40828 m .68646 .41104 L .68972 .40834 L closepath p F P
0 g
s
.675 .974 .899 r
.68813 .40829 m .68972 .40834 L .68646 .41104 L p F P
0 g
s
.675 .974 .899 r
.67699 .41517 m .68813 .40829 L p .68646 .41104 L F P
0 g
s
.675 .974 .899 r
.67657 .41552 m .67699 .41517 L p .68646 .41104 L F P
0 g
s
.732 .621 .735 r
.36702 .45163 m .36151 .4511 L .36318 .45513 L closepath p F P
0 g
s
.784 .523 .541 r
.31169 .42265 m .31972 .42448 L .31993 .41911 L p F P
0 g
s
.784 .523 .541 r
.31993 .41911 m .31192 .41727 L .31169 .42265 L p F P
0 g
s
.664 .525 .684 r
.4479 .44469 m .44729 .44185 L .43396 .44347 L p F P
0 g
s
.664 .525 .684 r
.44033 .45023 m .4479 .44469 L p .43396 .44347 L F P
0 g
s
.664 .525 .684 r
.43396 .44347 m .4358 .45082 L .44033 .45023 L p F P
0 g
s
.629 .87 .514 r
.77287 .3378 m .77183 .3389 L .77473 .33527 L closepath p F P
0 g
s
.435 .722 .986 r
.21355 .45366 m .22439 .45345 L .22799 .45609 L p F P
0 g
s
.446 .723 .984 r
.22439 .45345 m .21355 .45366 L .20993 .45105 L p F P
0 g
s
0 0 0 r
.78374 .32279 m .78812 .31606 L .78445 .32151 L p F P
0 g
s
0 0 0 r
.78194 .32548 m .78374 .32279 L p .78445 .32151 L F P
0 g
s
0 0 0 r
.78445 .32151 m .78304 .32366 L .78194 .32548 L p F P
0 g
s
.317 .015 .284 r
.53927 .37004 m .53177 .37657 L .53154 .37748 L p F P
0 g
s
.086 0 .057 r
.56635 .34493 m .5654 .34581 L .56619 .34531 L closepath p F P
0 g
s
.111 0 .093 r
.56481 .34892 m .5572 .35373 L .5654 .34581 L p F P
0 g
s
.111 0 .093 r
.5654 .34581 m .56619 .34531 L .56481 .34892 L p F P
0 g
s
.393 .114 .367 r
.52983 .38616 m .53063 .38175 L .51999 .38643 L p F P
0 g
s
.393 .114 .367 r
.51999 .38643 m .5192 .39088 L .52983 .38616 L p F P
0 g
s
.74 .579 .675 r
.35642 .45064 m .36002 .44632 L .35926 .44331 L p F P
0 g
s
.74 .579 .675 r
.34666 .44938 m .35642 .45064 L p .35926 .44331 L F P
0 g
s
.74 .579 .675 r
.35926 .44331 m .35153 .4425 L .34666 .44938 L p F P
0 g
s
0 0 0 r
.7984 .29778 m .79509 .30316 L .79764 .29702 L p F P
0 g
s
0 0 0 r
.80059 .29261 m .7984 .29778 L p .79764 .29702 L F P
0 g
s
0 0 0 r
.79764 .29702 m .80074 .29205 L .80059 .29261 L p F P
0 g
s
0 .385 .826 r
.0934 .4017 m .09224 .40115 L .08846 .39792 L p F P
0 g
s
.79 .301 0 r
.20091 .31869 m .19911 .3159 L .19547 .31302 L p F P
0 g
s
.664 .964 .927 r
.66472 .42219 m .65605 .42696 L .6628 .42199 L closepath p F P
0 g
s
.675 .959 .943 r
.66197 .42185 m .6628 .42199 L .65605 .42696 L p F P
0 g
s
.675 .959 .943 r
.65025 .42809 m .66197 .42185 L p .65605 .42696 L F P
0 g
s
.289 0 .243 r
.54331 .36674 m .53927 .37004 L .54287 .36825 L closepath p F P
0 g
s
.317 .015 .284 r
.54183 .37235 m .54287 .36825 L .53927 .37004 L p F P
0 g
s
.317 .015 .284 r
.53154 .37748 m .54183 .37235 L p .53927 .37004 L F P
0 g
s
.843 .494 .394 r
.26905 .38857 m .27517 .39108 L .27377 .3863 L p F P
0 g
s
.843 .494 .394 r
.27377 .3863 m .26776 .38376 L .26905 .38857 L p F P
0 g
s
.809 .322 0 r
.21039 .3304 m .21475 .3336 L .21201 .32939 L p F P
0 g
s
.809 .322 0 r
.21201 .32939 m .20771 .32618 L .21039 .3304 L p F P
0 g
s
.669 .659 .831 r
.46583 .45649 m .46441 .45671 L .45419 .46071 L p F P
0 g
s
.664 .641 .817 r
.46441 .45671 m .4531 .45872 L .45419 .46071 L closepath p F P
0 g
s
.762 .56 .624 r
.34203 .44106 m .34224 .44109 L .34461 .43501 L p F P
0 g
s
.762 .56 .624 r
.34461 .43501 m .34095 .43441 L .34203 .44106 L p F P
0 g
s
.167 0 .159 r
.56351 .35247 m .56481 .34892 L .5572 .35373 L p F P
0 g
s
.167 0 .159 r
.56327 .35273 m .56351 .35247 L p .5572 .35373 L F P
0 g
s
.167 0 .159 r
.55397 .35874 m .56327 .35273 L p .5572 .35373 L F P
0 g
s
.167 0 .159 r
.5572 .35373 m .55484 .35611 L .55397 .35874 L p F P
0 g
s
.737 .658 .771 r
.3456 .45937 m .34847 .45753 L .34523 .45088 L p F P
0 g
s
.737 .658 .771 r
.34523 .45088 m .33625 .45799 L .3456 .45937 L p F P
0 g
s
.718 .712 .843 r
.33377 .45959 m .33625 .45799 L .3456 .45937 L p F P
0 g
s
.863 .45 .241 r
.24056 .35874 m .24062 .3589 L .24567 .3618 L p F P
0 g
s
.87 .47 .274 r
.24238 .36351 m .24752 .36638 L .24567 .3618 L p F P
0 g
s
.87 .47 .274 r
.24567 .3618 m .24062 .3589 L .24238 .36351 L p F P
0 g
s
.209 0 .176 r
.55484 .35611 m .54854 .36179 L .55397 .35874 L closepath p F P
0 g
s
.247 0 .227 r
.55278 .36264 m .55397 .35874 L .54854 .36179 L p F P
0 g
s
.247 0 .227 r
.54287 .36825 m .55278 .36264 L p .54854 .36179 L F P
0 g
s
.247 0 .227 r
.54854 .36179 m .54331 .36674 L .54287 .36825 L p F P
0 g
s
.735 .59 .694 r
.36002 .44632 m .35642 .45064 L .36151 .4511 L closepath p F P
0 g
s
0 0 0 r
.78304 .32366 m .77989 .3283 L .78194 .32548 L closepath p F P
0 g
s
.591 .757 .957 r
.26057 .46186 m .27165 .45958 L .27514 .46257 L p F P
0 g
s
.609 .754 .948 r
.27165 .45958 m .26057 .46186 L .25704 .45906 L p F P
0 g
s
.73 .626 .743 r
.36151 .4511 m .35642 .45064 L .34847 .45753 L p F P
0 g
s
.261 .63 .961 r
.16328 .43752 m .17068 .43864 L .17555 .44153 L p F P
0 g
s
.272 .633 .963 r
.17068 .43864 m .16328 .43752 L .15958 .43479 L p F P
0 g
s
.653 .717 .895 r
.7571 .19612 m .76911 .19239 L .77184 .19647 L p F P
0 g
s
.667 .733 .9 r
.76911 .19239 m .7571 .19612 L .7544 .19266 L p F P
0 g
s
.701 .772 .907 r
.74251 .19785 m .7544 .19266 L .7571 .19612 L p F P
0 g
s
.681 .978 .877 r
.70205 .40087 m .6908 .40828 L .68972 .40834 L p F P
0 g
s
.733 .817 .917 r
.74251 .19785 m .74016 .19907 L .74089 .19609 L closepath p F P
0 g
s
.733 .845 .933 r
.73981 .19492 m .74089 .19609 L .74016 .19907 L p F P
0 g
s
.733 .845 .933 r
.72801 .20142 m .73981 .19492 L p .74016 .19907 L F P
0 g
s
.039 0 .062 r
.57505 .33956 m .57539 .33876 L .56619 .34531 L p F P
0 g
s
.039 0 .062 r
.56982 .34532 m .57505 .33956 L p .56619 .34531 L F P
0 g
s
.039 0 .062 r
.56619 .34531 m .56481 .34892 L .56982 .34532 L p F P
0 g
s
.816 .483 .424 r
.2835 .39407 m .2824 .39633 L .28167 .39345 L closepath p F P
0 g
s
.767 .888 .931 r
.71999 .20638 m .71628 .20866 L .71359 .20662 L p F P
0 g
s
.674 .572 .733 r
.44913 .4492 m .44033 .45023 L .4364 .45259 L p F P
0 g
s
.67 .564 .727 r
.44033 .45023 m .4358 .45082 L .4364 .45259 L closepath p F P
0 g
s
.379 .699 .983 r
.19553 .44807 m .19883 .44818 L .20427 .45085 L p F P
0 g
s
.387 .697 .982 r
.2063 .44837 m .19883 .44818 L .20427 .45085 L p F P
0 g
s
.387 .697 .982 r
.20427 .45085 m .20993 .45105 L .2063 .44837 L p F P
0 g
s
.742 .648 .756 r
.35642 .45064 m .34847 .45753 L .34523 .45088 L p F P
0 g
s
0 0 .048 r
.80099 .29162 m .80074 .29205 L .8014 .28825 L p F P
0 g
s
0 0 .048 r
.8014 .28825 m .80284 .2857 L .80099 .29162 L p F P
0 g
s
0 0 .369 r
.80829 .26819 m .80779 .26911 L .80781 .2638 L p F P
0 g
s
0 0 .369 r
.80781 .2638 m .80809 .2633 L .80829 .26819 L p F P
0 g
s
.613 .407 .578 r
.47151 .42515 m .46519 .42639 L .46111 .43303 L p F P
0 g
s
.608 .401 .575 r
.4593 .4334 m .46111 .43303 L .46519 .42639 L p F P
0 g
s
.509 .58 .862 r
.79246 .2052 m .78958 .20487 L .78679 .19962 L p F P
0 g
s
.625 .902 .601 r
.62233 .28815 m .62109 .28915 L .62473 .28534 L closepath p F P
0 g
s
.836 .46 .339 r
.2631 .37753 m .2614 .37891 L .26046 .37641 L closepath p F P
0 g
s
0 0 .152 r
.80577 .2804 m .80284 .2857 L .80412 .27997 L p F P
0 g
s
0 0 .152 r
.80412 .27997 m .80709 .27465 L .80577 .2804 L p F P
0 g
s
.811 .524 .502 r
.30208 .41444 m .30457 .41521 L .30425 .41003 L p F P
0 g
s
.811 .524 .502 r
.30425 .41003 m .30289 .40961 L .30208 .41444 L p F P
0 g
s
.643 .883 .985 r
.58309 .4511 m .57143 .45542 L .56844 .45383 L p F P
0 g
s
.635 .877 .986 r
.55679 .4579 m .56844 .45383 L .57143 .45542 L p F P
0 g
s
.757 .557 .626 r
.33291 .43969 m .34203 .44106 L .34095 .43441 L p F P
0 g
s
.757 .557 .626 r
.34095 .43441 m .33541 .43356 L .33291 .43969 L p F P
0 g
s
.784 .549 .58 r
.32244 .43093 m .32681 .43192 L .32787 .42627 L p F P
0 g
s
.784 .549 .58 r
.32787 .42627 m .32207 .42496 L .32244 .43093 L p F P
0 g
s
.327 .04 .315 r
.54087 .37655 m .54183 .37235 L .53154 .37748 L p F P
0 g
s
.327 .04 .315 r
.53154 .37748 m .53063 .38175 L .54087 .37655 L p F P
0 g
s
.742 .648 .756 r
.34523 .45088 m .34666 .44938 L .35642 .45064 L p F P
0 g
s
.756 .581 .66 r
.34448 .44904 m .34666 .44938 L .35153 .4425 L p F P
0 g
s
.756 .581 .66 r
.3421 .44133 m .34448 .44904 L p .35153 .4425 L F P
0 g
s
.756 .581 .66 r
.35153 .4425 m .34224 .44109 L .3421 .44133 L p F P
0 g
s
.663 .612 .788 r
.45103 .45435 m .4531 .45872 L .46441 .45671 L p F P
0 g
s
.713 .811 .926 r
.75169 .18932 m .7544 .19266 L .74251 .19785 L p F P
0 g
s
.713 .811 .926 r
.74204 .19387 m .75169 .18932 L p .74251 .19785 L F P
0 g
s
.713 .811 .926 r
.74251 .19785 m .74089 .19609 L .74204 .19387 L p F P
0 g
s
.815 .331 .009 r
.21612 .33577 m .21475 .3336 L .21929 .33672 L p F P
0 g
s
.815 .331 .009 r
.21929 .33672 m .2198 .33752 L .21612 .33577 L p F P
0 g
s
.05 .482 .887 r
.10985 .41177 m .11567 .41384 L .11987 .41701 L p F P
0 g
s
.062 .485 .891 r
.11567 .41384 m .10985 .41177 L .10609 .40869 L p F P
0 g
s
.663 .691 .867 r
.46883 .46144 m .48034 .45745 L .48348 .46196 L p F P
0 g
s
.657 .658 .839 r
.46583 .45649 m .46883 .46144 L .48034 .45745 L p F P
0 g
s
0 .385 .826 r
.08846 .39792 m .08948 .39841 L .0934 .4017 L p F P
0 g
s
0 .422 .853 r
.09621 .40135 m .10012 .40465 L .0934 .4017 L p F P
0 g
s
0 .422 .853 r
.0934 .4017 m .08948 .39841 L .09621 .40135 L p F P
0 g
s
.86 .471 .304 r
.24923 .37102 m .25471 .37377 L .25289 .36916 L p F P
0 g
s
.86 .471 .304 r
.25289 .36916 m .24752 .36638 L .24923 .37102 L p F P
0 g
s
.193 .587 .942 r
.1454 .42982 m .1506 .43094 L .15526 .43392 L p F P
0 g
s
.204 .589 .945 r
.1506 .43094 m .1454 .42982 L .14167 .427 L p F P
0 g
s
.61 .671 .883 r
.77907 .19531 m .77184 .19647 L .76911 .19239 L p F P
0 g
s
.666 .949 .956 r
.63907 .43417 m .63854 .43405 L .64113 .43275 L closepath p F P
0 g
s
.188 .186 .625 r
.81242 .23967 m .81062 .24348 L .8082 .23899 L p F P
0 g
s
.188 .186 .625 r
.8114 .23501 m .81242 .23967 L p .8082 .23899 L F P
0 g
s
.188 .186 .625 r
.8082 .23899 m .81066 .23374 L .8114 .23501 L p F P
0 g
s
.821 .486 .421 r
.2763 .39596 m .27517 .39108 L .28167 .39345 L p F P
0 g
s
.821 .486 .421 r
.28161 .39785 m .2763 .39596 L p .28167 .39345 L F P
0 g
s
.821 .486 .421 r
.28167 .39345 m .2824 .39633 L .28161 .39785 L p F P
0 g
s
.636 .752 .932 r
.27514 .46257 m .2863 .45941 L .28975 .4627 L p F P
0 g
s
.655 .746 .917 r
.2863 .45941 m .27514 .46257 L .27165 .45958 L p F P
0 g
s
.781 .882 .919 r
.71999 .20638 m .72801 .20142 L .72532 .19897 L p F P
0 g
s
.781 .882 .919 r
.72532 .19897 m .72202 .20113 L .71999 .20638 L p F P
0 g
s
.767 .888 .931 r
.71359 .20662 m .72202 .20113 L .71999 .20638 L p F P
0 g
s
0 0 .349 r
.81038 .26388 m .80829 .26819 L .80809 .2633 L p F P
0 g
s
0 0 .349 r
.80809 .2633 m .81036 .25858 L .81038 .26388 L p F P
0 g
s
.593 .829 .449 r
.77872 .32974 m .77473 .33527 L .77989 .3283 L p F P
0 g
s
.593 .829 .449 r
.78083 .32688 m .77872 .32974 L p .77989 .3283 L F P
0 g
s
.593 .829 .449 r
.77989 .3283 m .78194 .32548 L .78083 .32688 L p F P
0 g
s
.8 .512 .502 r
.29727 .41312 m .30208 .41444 L .30289 .40961 L p F P
0 g
s
.8 .512 .502 r
.30289 .40961 m .2969 .40796 L .29727 .41312 L p F P
0 g
s
.66 .924 .974 r
.62157 .43995 m .61229 .44404 L .60941 .443 L p F P
0 g
s
.646 .92 .977 r
.59771 .4479 m .60941 .443 L .61229 .44404 L p F P
0 g
s
.122 .537 .917 r
.12758 .42127 m .1324 .42264 L .13682 .42571 L p F P
0 g
s
.134 .539 .92 r
.1324 .42264 m .12758 .42127 L .12383 .41833 L p F P
0 g
s
.641 .854 .981 r
.55679 .4579 m .55533 .45839 L .55669 .45783 L closepath p F P
0 g
s
.644 .843 .977 r
.55377 .45589 m .55669 .45783 L .55533 .45839 L p F P
0 g
s
.644 .843 .977 r
.54214 .4597 m .55377 .45589 L p .55533 .45839 L F P
0 g
s
.669 .537 .694 r
.4479 .44469 m .44033 .45023 L .44913 .4492 L closepath p F P
0 g
s
.652 .145 0 r
.18645 .30436 m .19016 .30783 L .1869 .30386 L p F P
0 g
s
.652 .145 0 r
.1869 .30386 m .1832 .30039 L .18645 .30436 L p F P
0 g
s
.731 .694 .816 r
.33625 .45799 m .33217 .45719 L .33377 .45959 L closepath p F P
0 g
s
.645 .908 .982 r
.59771 .4479 m .59195 .4502 L .59693 .44757 L closepath p F P
0 g
s
.652 .896 .982 r
.59478 .44658 m .59693 .44757 L .59195 .4502 L p F P
0 g
s
.652 .896 .982 r
.58309 .4511 m .59478 .44658 L p .59195 .4502 L F P
0 g
s
.214 .598 .948 r
.15587 .43199 m .1506 .43094 L .15526 .43392 L p F P
0 g
s
.214 .598 .948 r
.15526 .43392 m .15958 .43479 L .15587 .43199 L p F P
0 g
s
.148 .552 .926 r
.13794 .4241 m .1324 .42264 L .13682 .42571 L p F P
0 g
s
.148 .552 .926 r
.13682 .42571 m .14167 .427 L .13794 .4241 L p F P
0 g
s
0 0 0 r
.59965 .31176 m .59808 .31396 L .60351 .30801 L closepath p F P
0 g
s
.494 .743 .983 r
.22799 .45609 m .23346 .45563 L .23935 .45814 L p F P
0 g
s
.49 .736 .981 r
.23892 .45515 m .23346 .45563 L .23935 .45814 L p F P
0 g
s
.49 .736 .981 r
.23935 .45814 m .24249 .45792 L .23892 .45515 L p F P
0 g
s
.648 .5 .668 r
.45316 .44088 m .44729 .44185 L .4479 .44469 L closepath p F P
0 g
s
.509 .747 .981 r
.23346 .45563 m .22799 .45609 L .22439 .45345 L p F P
0 g
s
.863 .421 .146 r
.22376 .34552 m .22841 .34859 L .22619 .34417 L p F P
0 g
s
.863 .421 .146 r
.22619 .34417 m .22161 .34108 L .22376 .34552 L p F P
0 g
s
.673 .737 .898 r
.28975 .4627 m .30099 .4585 L .3044 .46222 L p F P
0 g
s
.692 .726 .876 r
.30099 .4585 m .28975 .4627 L .2863 .45941 L p F P
0 g
s
.392 .702 .983 r
.19883 .44818 m .19553 .44807 L .19188 .44544 L p F P
0 g
s
.741 .633 .739 r
.33625 .45799 m .34523 .45088 L .34448 .44904 L p F P
0 g
s
.741 .633 .739 r
.33217 .45719 m .33625 .45799 L p .34448 .44904 L F P
0 g
s
.656 .725 .9 r
.48348 .46196 m .49502 .45828 L .49815 .46212 L p F P
0 g
s
.658 .681 .861 r
.49502 .45828 m .48348 .46196 L .48034 .45745 L p F P
0 g
s
.86 .411 .111 r
.22161 .34108 m .2198 .33752 L .21612 .33577 L p F P
0 g
s
.717 .695 .828 r
.33217 .45719 m .32723 .4565 L .31907 .46115 L p F P
0 g
s
.725 .721 .846 r
.32723 .4565 m .31907 .46115 L .31571 .45685 L p F P
0 g
s
.7 .714 .86 r
.3044 .46222 m .31571 .45685 L .31907 .46115 L p F P
0 g
s
.648 .855 .979 r
.56721 .45307 m .56844 .45383 L .55679 .4579 L p F P
0 g
s
.648 .855 .979 r
.55679 .4579 m .55669 .45783 L .56721 .45307 L p F P
0 g
s
.771 .565 .621 r
.3246 .43795 m .33291 .43969 L .33541 .43356 L p F P
0 g
s
.771 .565 .621 r
.33541 .43356 m .32681 .43192 L .3246 .43795 L p F P
0 g
s
.802 .538 .539 r
.30433 .42058 m .31169 .42265 L .31192 .41727 L p F P
0 g
s
.802 .538 .539 r
.31192 .41727 m .30457 .41521 L .30433 .42058 L p F P
0 g
s
.68 .969 .925 r
.67371 .41517 m .67643 .4155 L .66472 .42219 L p F P
0 g
s
.68 .969 .925 r
.66537 .41996 m .67371 .41517 L p .66472 .42219 L F P
0 g
s
.68 .969 .925 r
.66472 .42219 m .6628 .42199 L .66537 .41996 L p F P
0 g
s
.718 .705 .837 r
.3044 .46222 m .31571 .45685 L .31328 .45341 L p F P
0 g
s
.718 .705 .837 r
.30099 .4585 m .3044 .46222 L p .31328 .45341 L F P
0 g
s
.647 .848 .977 r
.56544 .45193 m .56721 .45307 L .55669 .45783 L p F P
0 g
s
.647 .848 .977 r
.55669 .45783 m .55377 .45589 L .56544 .45193 L p F P
0 g
s
.67 .975 .851 r
.70248 .40057 m .70205 .40087 L .70236 .40059 L closepath p F P
0 g
s
.681 .978 .877 r
.69984 .40067 m .70236 .40059 L .70205 .40087 L p F P
0 g
s
.681 .978 .877 r
.69395 .40457 m .69984 .40067 L p .70205 .40087 L F P
0 g
s
.681 .978 .877 r
.68972 .40834 m .69395 .40457 L p .70205 .40087 L F P
0 g
s
.62 .438 .614 r
.46111 .43303 m .4593 .4334 L .45944 .43454 L closepath p F P
0 g
s
.277 .637 .965 r
.17386 .43908 m .17068 .43864 L .17555 .44153 L p F P
0 g
s
.277 .637 .965 r
.17555 .44153 m .17754 .44181 L .17386 .43908 L p F P
0 g
s
.691 .981 .849 r
.71154 .39256 m .71414 .39228 L .70248 .40057 L p F P
0 g
s
.691 .981 .849 r
.70858 .39467 m .71154 .39256 L p .70248 .40057 L F P
0 g
s
.691 .981 .849 r
.70248 .40057 m .70236 .40059 L .70858 .39467 L p F P
0 g
s
.804 .999 .835 r
.65568 .2544 m .65561 .25441 L .65577 .25426 L closepath p F P
0 g
s
.843 .463 .33 r
.25637 .37844 m .25471 .37377 L .26046 .37641 L p F P
0 g
s
.843 .463 .33 r
.25982 .37999 m .25637 .37844 L p .26046 .37641 L F P
0 g
s
.843 .463 .33 r
.26046 .37641 m .2614 .37891 L .25982 .37999 L p F P
0 g
s
.248 0 .252 r
.55197 .36559 m .55278 .36264 L .54287 .36825 L p F P
0 g
s
.248 0 .252 r
.55005 .3676 m .55197 .36559 L p .54287 .36825 L F P
0 g
s
.248 0 .252 r
.54287 .36825 m .54183 .37235 L .55005 .3676 L p F P
0 g
s
0 0 0 r
.79525 .30412 m .79201 .30948 L .79509 .30316 L p F P
0 g
s
0 0 0 r
.79509 .30316 m .7984 .29778 L .79525 .30412 L p F P
0 g
s
.663 .612 .788 r
.46567 .45618 m .46253 .4487 L .45103 .45435 L p F P
0 g
s
.663 .612 .788 r
.46441 .45671 m .46567 .45618 L p .45103 .45435 L F P
0 g
s
.659 .57 .743 r
.44913 .4492 m .45103 .45435 L .46253 .4487 L p F P
0 g
s
.674 .946 .96 r
.64113 .43275 m .63854 .43405 L .63571 .43329 L p F P
0 g
s
.66 .942 .962 r
.624 .43886 m .63571 .43329 L .63854 .43405 L p F P
0 g
s
.593 .392 .578 r
.484 .428 m .48365 .42222 L .47151 .42515 L p F P
0 g
s
.593 .392 .578 r
.47151 .42515 m .47186 .43093 L .484 .428 L p F P
0 g
s
.613 .407 .578 r
.46111 .43303 m .47186 .43093 L .47151 .42515 L p F P
0 g
s
.081 .501 .899 r
.12008 .41531 m .11567 .41384 L .11987 .41701 L p F P
0 g
s
.081 .501 .899 r
.11987 .41701 m .12383 .41833 L .12008 .41531 L p F P
0 g
s
.814 .993 .868 r
.67382 .23789 m .66715 .24374 L .66593 .24367 L p F P
0 g
s
.832 .992 .858 r
.66715 .24374 m .66454 .24616 L .66593 .24367 L closepath p F P
0 g
s
.832 .523 .467 r
.28347 .40338 m .28996 .40575 L .28922 .40072 L p F P
0 g
s
.832 .523 .467 r
.28922 .40072 m .28281 .39833 L .28347 .40338 L p F P
0 g
s
.654 .509 .675 r
.4479 .44469 m .44913 .4492 L p .46021 .43979 L F P
0 g
s
.654 .509 .675 r
.46021 .43979 m .45316 .44088 L .4479 .44469 L p F P
0 g
s
.833 .994 .854 r
.65938 .24855 m .65577 .25426 L .66454 .24616 L p F P
0 g
s
.833 .994 .854 r
.66443 .24361 m .65938 .24855 L p .66454 .24616 L F P
0 g
s
.833 .994 .854 r
.66454 .24616 m .66593 .24367 L .66443 .24361 L p F P
0 g
s
.677 .164 0 r
.19183 .30989 m .19016 .30783 L .19401 .31123 L p F P
0 g
s
.677 .164 0 r
.19401 .31123 m .19547 .31302 L .19183 .30989 L p F P
0 g
s
.791 .999 .823 r
.65289 .25485 m .65938 .24855 L .65577 .25426 L p F P
0 g
s
.791 .999 .823 r
.65577 .25426 m .65561 .25441 L .65289 .25485 L p F P
0 g
s
.797 .996 .78 r
.64766 .26214 m .65561 .25441 L .65289 .25485 L p F P
0 g
s
.836 .974 .882 r
.6787 .23357 m .67382 .23789 L .67624 .23297 L closepath p F P
0 g
s
.814 .993 .868 r
.67599 .23291 m .67624 .23297 L .67382 .23789 L p F P
0 g
s
.814 .993 .868 r
.66773 .24057 m .67599 .23291 L p .67382 .23789 L F P
0 g
s
.814 .993 .868 r
.66593 .24367 m .66773 .24057 L p .67382 .23789 L F P
0 g
s
.705 .984 .88 r
.70236 .40059 m .69984 .40067 L .70858 .39467 L closepath p F P
0 g
s
.555 .332 .531 r
.49541 .41884 m .49542 .41347 L .48368 .41685 L p F P
0 g
s
.555 .332 .531 r
.48368 .41685 m .48365 .42222 L .49541 .41884 L p F P
0 g
s
.749 .628 .727 r
.34666 .44938 m .34448 .44904 L .34523 .45088 L closepath p F P
0 g
s
.775 .542 .583 r
.31859 .43016 m .32244 .43093 L .32207 .42496 L p F P
0 g
s
.775 .542 .583 r
.32207 .42496 m .31972 .42448 L .31859 .43016 L p F P
0 g
s
.65 .76 .929 r
.49815 .46212 m .50971 .45858 L .51281 .46182 L p F P
0 g
s
.653 .721 .899 r
.50971 .45858 m .49815 .46212 L .49502 .45828 L p F P
0 g
s
.644 .828 .971 r
.55377 .45589 m .54214 .4597 L .53909 .45737 L p F P
0 g
s
.642 .822 .969 r
.52748 .46101 m .53909 .45737 L .54214 .4597 L p F P
0 g
s
.818 .976 .894 r
.68375 .22941 m .6787 .23357 L .67624 .23297 L p F P
0 g
s
.626 .447 .62 r
.45944 .43454 m .46021 .43979 L p .47186 .43093 L F P
0 g
s
.626 .447 .62 r
.47186 .43093 m .46111 .43303 L .45944 .43454 L p F P
0 g
s
.644 .468 .631 r
.45944 .43454 m .45316 .44088 L .46021 .43979 L closepath p F P
0 g
s
0 0 0 r
.57651 .33787 m .57539 .33876 L .57694 .33539 L p F P
0 g
s
0 0 0 r
.57694 .33539 m .58316 .33043 L .57651 .33787 L p F P
0 g
s
.256 .27 .683 r
.81095 .23309 m .81066 .23374 L .8071 .22963 L p F P
0 g
s
.256 .27 .683 r
.8071 .22963 m .80889 .22568 L .81095 .23309 L p F P
0 g
s
.465 .516 .826 r
.79925 .20084 m .79419 .20009 L .79246 .2052 L p F P
0 g
s
.465 .516 .826 r
.79246 .2052 m .80212 .20724 L .79925 .20084 L p F P
0 g
s
.509 .58 .862 r
.78679 .19962 m .79419 .20009 L .79246 .2052 L p F P
0 g
s
.797 .996 .78 r
.65289 .25485 m .65135 .25642 L .64766 .26214 L p F P
0 g
s
.754 .987 .765 r
.64382 .26413 m .65135 .25642 L .64766 .26214 L p F P
0 g
s
.754 .987 .765 r
.64235 .26624 m .64382 .26413 L p .64766 .26214 L F P
0 g
s
.754 .987 .765 r
.64766 .26214 m .64409 .2656 L .64235 .26624 L p F P
0 g
s
.76 .587 .662 r
.34224 .44109 m .34203 .44106 L .3421 .44133 L closepath p F P
0 g
s
.859 .424 .178 r
.23056 .35305 m .23549 .35601 L .23325 .35159 L p F P
0 g
s
.859 .424 .178 r
.23325 .35159 m .22841 .34859 L .23056 .35305 L p F P
0 g
s
.659 .57 .743 r
.46253 .4487 m .46199 .44707 L .44913 .4492 L p F P
0 g
s
.654 .509 .675 r
.44913 .4492 m .46199 .44707 L .46021 .43979 L p F P
0 g
s
.754 .591 .675 r
.3371 .44805 m .3421 .44133 L .34203 .44106 L p F P
0 g
s
.754 .591 .675 r
.32848 .44642 m .3371 .44805 L p .34203 .44106 L F P
0 g
s
.754 .591 .675 r
.34203 .44106 m .33291 .43969 L .32848 .44642 L p F P
0 g
s
.703 .984 .848 r
.7145 .39223 m .71414 .39228 L .71536 .39138 L closepath p F P
0 g
s
.632 .872 .517 r
.77299 .33691 m .77872 .32974 L .77473 .33527 L p F P
0 g
s
.632 .872 .517 r
.77081 .33997 m .77299 .33691 L p .77473 .33527 L F P
0 g
s
.632 .872 .517 r
.77473 .33527 m .77183 .3389 L .77081 .33997 L p F P
0 g
s
.748 .596 .687 r
.3421 .44133 m .3371 .44805 L .34448 .44904 L closepath p F P
0 g
s
.773 .99 .763 r
.64409 .2656 m .63977 .26996 L .64235 .26624 L closepath p F P
0 g
s
.754 .832 .912 r
.73981 .19492 m .72801 .20142 L .72532 .19897 L p F P
0 g
s
.645 .793 .953 r
.51281 .46182 m .5244 .45827 L .52748 .46101 L p F P
0 g
s
.649 .761 .931 r
.5244 .45827 m .51281 .46182 L .50971 .45858 L p F P
0 g
s
.646 .797 .955 r
.53909 .45737 m .52748 .46101 L .5244 .45827 L p F P
0 g
s
.838 .966 .886 r
.68375 .22941 m .69029 .22396 L .68759 .22284 L p F P
0 g
s
.838 .966 .886 r
.68759 .22284 m .68622 .22403 L .68375 .22941 L p F P
0 g
s
.818 .976 .894 r
.67652 .23245 m .68622 .22403 L .68375 .22941 L p F P
0 g
s
.818 .976 .894 r
.67624 .23297 m .67652 .23245 L p .68375 .22941 L F P
0 g
s
.512 .272 .488 r
.50679 .40964 m .50707 .40458 L .49571 .40841 L p F P
0 g
s
.512 .272 .488 r
.49571 .40841 m .49542 .41347 L .50679 .40964 L p F P
0 g
s
.684 .938 .65 r
.7611 .35144 m .76044 .35187 L .7623 .3499 L closepath p F P
0 g
s
.741 .633 .739 r
.33046 .45431 m .33217 .45719 L p .34448 .44904 L F P
0 g
s
.728 .674 .797 r
.33046 .45431 m .32723 .4565 L .33217 .45719 L closepath p F P
0 g
s
.741 .633 .739 r
.34448 .44904 m .3371 .44805 L .33046 .45431 L p F P
0 g
s
.665 .954 .948 r
.65025 .42809 m .64113 .43275 L .64834 .42772 L closepath p F P
0 g
s
.674 .946 .96 r
.64745 .42749 m .64834 .42772 L .64113 .43275 L p F P
0 g
s
.674 .946 .96 r
.63571 .43329 m .64745 .42749 L p .64113 .43275 L F P
0 g
s
.698 .979 .902 r
.68972 .40834 m .68813 .40829 L .69395 .40457 L closepath p F P
0 g
s
.688 .95 .683 r
.64136 .26664 m .64235 .26624 L .63977 .26996 L p F P
0 g
s
.688 .95 .683 r
.63658 .27174 m .64136 .26664 L p .63977 .26996 L F P
0 g
s
.688 .95 .683 r
.63239 .27728 m .63658 .27174 L p .63977 .26996 L F P
0 g
s
.688 .95 .683 r
.63977 .26996 m .63259 .27716 L .63239 .27728 L p F P
0 g
s
.784 .549 .58 r
.31063 .42829 m .31859 .43016 L .31972 .42448 L p F P
0 g
s
.784 .549 .58 r
.31972 .42448 m .31169 .42265 L .31063 .42829 L p F P
0 g
s
.79 .301 0 r
.19547 .31302 m .19695 .31533 L .20091 .31869 L p F P
0 g
s
.8 .315 0 r
.19957 .31956 m .20356 .3229 L .20091 .31869 L p F P
0 g
s
.8 .315 0 r
.20091 .31869 m .19695 .31533 L .19957 .31956 L p F P
0 g
s
.856 .508 .392 r
.26326 .38595 m .26905 .38857 L .26776 .38376 L p F P
0 g
s
.856 .508 .392 r
.26776 .38376 m .26206 .38111 L .26326 .38595 L p F P
0 g
s
0 0 .45 r
.81288 .25334 m .81036 .25858 L .80964 .25351 L p F P
0 g
s
0 0 .45 r
.80964 .25351 m .81215 .24828 L .81288 .25334 L p F P
0 g
s
.811 .952 .91 r
.69466 .2206 m .69029 .22396 L .68759 .22284 L p F P
0 g
s
.654 .91 .98 r
.60683 .44198 m .60941 .443 L .59771 .4479 L p F P
0 g
s
.654 .91 .98 r
.59771 .4479 m .59693 .44757 L .60683 .44198 L p F P
0 g
s
.609 .862 .512 r
.77183 .3389 m .76887 .34247 L .77081 .33997 L closepath p F P
0 g
s
.815 .527 .502 r
.29026 .41094 m .29727 .41312 L .2969 .40796 L p F P
0 g
s
.815 .527 .502 r
.2969 .40796 m .28996 .40575 L .29026 .41094 L p F P
0 g
s
.705 .955 .684 r
.63259 .27716 m .63205 .27771 L .63239 .27728 L closepath p F P
0 g
s
.699 .95 .673 r
.62945 .27932 m .62473 .28534 L .63205 .27771 L p F P
0 g
s
.699 .95 .673 r
.62984 .2789 m .62945 .27932 L p .63205 .27771 L F P
0 g
s
.699 .95 .673 r
.63205 .27771 m .63239 .27728 L .62984 .2789 L p F P
0 g
s
.559 .753 .968 r
.24249 .45792 m .25351 .45615 L .25704 .45906 L p F P
0 g
s
.574 .752 .962 r
.25351 .45615 m .24249 .45792 L .23892 .45515 L p F P
0 g
s
.335 .366 .745 r
.80452 .22073 m .80605 .21722 L .80811 .22325 L closepath p F P
0 g
s
.014 .447 .868 r
.10232 .40553 m .10012 .40465 L .10412 .4079 L p F P
0 g
s
.014 .447 .868 r
.10412 .4079 m .10609 .40869 L .10232 .40553 L p F P
0 g
s
.464 .21 .444 r
.51806 .40029 m .51855 .39549 L .50756 .39976 L p F P
0 g
s
.464 .21 .444 r
.50756 .39976 m .50707 .40458 L .51806 .40029 L p F P
0 g
s
.669 .638 .811 r
.46567 .45618 m .46441 .45671 L .46583 .45649 L closepath p F P
0 g
s
.868 .451 .227 r
.24056 .35874 m .24062 .3589 L .24034 .35873 L closepath p F P
0 g
s
.334 .668 .975 r
.18847 .44294 m .19188 .44544 L p .17754 .44181 L F P
0 g
s
.334 .668 .975 r
.17754 .44181 m .18813 .44274 L .18847 .44294 L p F P
0 g
s
.345 .67 .975 r
.18813 .44274 m .17754 .44181 L .17386 .43908 L p F P
0 g
s
.404 .449 .794 r
.79995 .21248 m .80214 .20728 L .80507 .2146 L closepath p F P
0 g
s
.827 .944 .9 r
.69466 .2206 m .70192 .21496 L .69921 .21341 L p F P
0 g
s
.827 .944 .9 r
.69921 .21341 m .69692 .21528 L .69466 .2206 L p F P
0 g
s
.811 .952 .91 r
.68759 .22284 m .69692 .21528 L .69466 .2206 L p F P
0 g
s
0 0 .028 r
.80387 .28634 m .80099 .29162 L .80284 .2857 L p F P
0 g
s
0 0 .028 r
.80284 .2857 m .80577 .2804 L .80387 .28634 L p F P
0 g
s
.838 .509 .43 r
.2824 .39633 m .28281 .39833 L .28161 .39785 L closepath p F P
0 g
s
.709 .986 .854 r
.71536 .39138 m .71414 .39228 L .71154 .39256 L p F P
0 g
s
.876 .475 .265 r
.23746 .36055 m .24238 .36351 L .24062 .3589 L p F P
0 g
s
.876 .475 .265 r
.2368 .3588 m .23746 .36055 L p .24062 .3589 L F P
0 g
s
.876 .475 .265 r
.24062 .3589 m .24034 .35873 L .2368 .3588 L p F P
0 g
s
.708 .984 .819 r
.72618 .38331 m .72578 .38339 L .72706 .38237 L closepath p F P
0 g
s
.714 .813 .926 r
.74089 .19609 m .73981 .19492 L .74204 .19387 L closepath p F P
0 g
s
.747 .669 .774 r
.32723 .4565 m .33046 .45431 L .3272 .44788 L p F P
0 g
s
.747 .669 .774 r
.3272 .44788 m .31874 .45484 L .32723 .4565 L p F P
0 g
s
.725 .721 .846 r
.31571 .45685 m .31874 .45484 L .32723 .4565 L p F P
0 g
s
.696 .981 .822 r
.71536 .39138 m .72578 .38339 L .72322 .38388 L p F P
0 g
s
.696 .981 .822 r
.72322 .38388 m .72132 .38533 L .71536 .39138 L p F P
0 g
s
.709 .986 .854 r
.71154 .39256 m .72132 .38533 L .71536 .39138 L p F P
0 g
s
.661 .635 .813 r
.46567 .45618 m .46583 .45649 L .4784 .45404 L p F P
0 g
s
.657 .658 .839 r
.48034 .45745 m .4784 .45404 L .46583 .45649 L p F P
0 g
s
.528 .595 .865 r
.79419 .20009 m .78679 .19962 L .78402 .19466 L p F P
0 g
s
.661 .915 .602 r
.76659 .34429 m .7623 .3499 L .76887 .34247 L p F P
0 g
s
.661 .915 .602 r
.7695 .341 m .76659 .34429 L p .76887 .34247 L F P
0 g
s
.661 .915 .602 r
.76887 .34247 m .77081 .33997 L .7695 .341 L p F P
0 g
s
.159 0 .176 r
.55657 .3602 m .55278 .36264 L .55397 .35874 L p F P
0 g
s
.159 0 .176 r
.55397 .35874 m .56327 .35273 L .55657 .3602 L p F P
0 g
s
.808 .323 0 r
.20621 .32714 m .21039 .3304 L .20771 .32618 L p F P
0 g
s
.808 .323 0 r
.20771 .32618 m .20356 .3229 L .20621 .32714 L p F P
0 g
s
.854 .43 .218 r
.24034 .35873 m .2368 .3588 L .23549 .35601 L closepath p F P
0 g
s
.653 .564 .742 r
.46567 .45618 m .47719 .45159 L .47449 .44454 L p F P
0 g
s
.653 .564 .742 r
.46253 .4487 m .46567 .45618 L p .47449 .44454 L F P
0 g
s
.661 .635 .813 r
.4784 .45404 m .47719 .45159 L .46567 .45618 L p F P
0 g
s
.709 .953 .674 r
.63239 .27728 m .62984 .2789 L .63658 .27174 L closepath p F P
0 g
s
.782 .579 .625 r
.32367 .43774 m .3246 .43795 L .32681 .43192 L p F P
0 g
s
.782 .579 .625 r
.32681 .43192 m .32244 .43093 L .32367 .43774 L p F P
0 g
s
0 0 .26 r
.80817 .27267 m .80709 .27465 L .80779 .26911 L p F P
0 g
s
0 0 .26 r
.80779 .26911 m .80829 .26819 L .80817 .27267 L p F P
0 g
s
.4 .7 .982 r
.20267 .44562 m .19344 .44548 L .19883 .44818 L p F P
0 g
s
.4 .7 .982 r
.19883 .44818 m .2063 .44837 L .20267 .44562 L p F P
0 g
s
.392 .702 .983 r
.19188 .44544 m .19344 .44548 L .19883 .44818 L p F P
0 g
s
.585 .874 .561 r
.62275 .28677 m .62945 .27932 L .62473 .28534 L p F P
0 g
s
.585 .874 .561 r
.61988 .29022 m .62275 .28677 L p .62473 .28534 L F P
0 g
s
.585 .874 .561 r
.62473 .28534 m .62109 .28915 L .61988 .29022 L p F P
0 g
s
.654 .934 .969 r
.624 .43886 m .62157 .43995 L .62357 .43873 L closepath p F P
0 g
s
.66 .924 .974 r
.62113 .43785 m .62357 .43873 L .62157 .43995 L p F P
0 g
s
.66 .924 .974 r
.60941 .443 m .62113 .43785 L p .62157 .43995 L F P
0 g
s
.689 .972 .92 r
.67657 .41552 m .67643 .4155 L .67699 .41517 L closepath p F P
0 g
s
0 .39 .833 r
.08948 .39841 m .08846 .39792 L .08468 .39461 L p F P
0 g
s
.841 .509 .425 r
.27008 .39349 m .2763 .39596 L .27517 .39108 L p F P
0 g
s
.841 .509 .425 r
.27517 .39108 m .26905 .38857 L .27008 .39349 L p F P
0 g
s
.756 .659 .755 r
.3272 .44788 m .32848 .44642 L .3371 .44805 L p F P
0 g
s
.756 .659 .755 r
.3371 .44805 m .33046 .45431 L .3272 .44788 L p F P
0 g
s
.798 .925 .92 r
.70708 .21129 m .70192 .21496 L .69921 .21341 L p F P
0 g
s
.446 .723 .984 r
.20993 .45105 m .22079 .45075 L .22439 .45345 L p F P
0 g
s
.462 .722 .981 r
.22079 .45075 m .20993 .45105 L .2063 .44837 L p F P
0 g
s
0 0 0 r
.79195 .30957 m .79191 .30965 L .79201 .30948 L closepath p F P
0 g
s
.626 .447 .62 r
.46021 .43979 m .47274 .43729 L .47186 .43093 L p F P
0 g
s
.637 .505 .685 r
.47405 .44304 m .47274 .43729 L .46021 .43979 L p F P
0 g
s
.637 .505 .685 r
.46927 .44556 m .47405 .44304 L p .46021 .43979 L F P
0 g
s
.637 .505 .685 r
.46021 .43979 m .46199 .44707 L .46927 .44556 L p F P
0 g
s
.597 .879 .565 r
.62109 .28915 m .61751 .29295 L .61988 .29022 L closepath p F P
0 g
s
0 0 0 r
.79162 .31063 m .79525 .30412 L .79201 .30948 L p F P
0 g
s
0 0 0 r
.79052 .31244 m .79162 .31063 L p .79201 .30948 L F P
0 g
s
0 0 0 r
.79201 .30948 m .79191 .30965 L .79052 .31244 L p F P
0 g
s
.407 .142 .397 r
.52915 .39073 m .52983 .38616 L .5192 .39088 L p F P
0 g
s
.407 .142 .397 r
.5192 .39088 m .51855 .39549 L .52915 .39073 L p F P
0 g
s
0 0 0 r
.79191 .30965 m .78812 .31606 L .79052 .31244 L closepath p F P
0 g
s
.773 .598 .662 r
.32636 .44596 m .32848 .44642 L .33291 .43969 L p F P
0 g
s
.773 .598 .662 r
.32403 .43901 m .32636 .44596 L p .33291 .43969 L F P
0 g
s
.773 .598 .662 r
.33291 .43969 m .3246 .43795 L .32403 .43901 L p F P
0 g
s
.698 .972 .925 r
.67699 .41517 m .67643 .4155 L .67371 .41517 L p F P
0 g
s
.861 .494 .353 r
.2614 .37891 m .26206 .38111 L .25982 .37999 L closepath p F P
0 g
s
.871 .482 .301 r
.24401 .36817 m .24923 .37102 L .24752 .36638 L p F P
0 g
s
.871 .482 .301 r
.24752 .36638 m .24238 .36351 L .24401 .36817 L p F P
0 g
s
.812 .547 .538 r
.3018 .4198 m .30433 .42058 L .30457 .41521 L p F P
0 g
s
.812 .547 .538 r
.30457 .41521 m .30208 .41444 L .3018 .4198 L p F P
0 g
s
.782 .295 0 r
.19695 .31533 m .19547 .31302 L .19183 .30989 L p F P
0 g
s
.688 .975 .908 r
.67699 .41517 m .68813 .40829 L .68545 .40817 L p F P
0 g
s
.688 .975 .908 r
.68545 .40817 m .68471 .40862 L .67699 .41517 L p F P
0 g
s
.698 .972 .925 r
.67371 .41517 m .68471 .40862 L .67699 .41517 L p F P
0 g
s
.61 .671 .883 r
.78141 .19022 m .77907 .19531 L p .76911 .19239 L F P
0 g
s
.584 .653 .884 r
.77907 .19531 m .78141 .19022 L .78402 .19466 L closepath p F P
0 g
s
.68 .748 .903 r
.76639 .18848 m .7544 .19266 L .75169 .18932 L p F P
0 g
s
.667 .733 .9 r
.7544 .19266 m .76639 .18848 L .76911 .19239 L p F P
0 g
s
0 0 0 r
.60985 .30112 m .60958 .30141 L .61042 .30051 L closepath p F P
0 g
s
.587 .87 .549 r
.61833 .29167 m .61609 .2942 L p .61751 .29295 L F P
0 g
s
.587 .87 .549 r
.61751 .29295 m .61988 .29022 L .61833 .29167 L p F P
0 g
s
.609 .754 .948 r
.25704 .45906 m .26815 .45645 L .27165 .45958 L p F P
0 g
s
.627 .752 .937 r
.26815 .45645 m .25704 .45906 L .25351 .45615 L p F P
0 g
s
.628 .844 .458 r
.78194 .32548 m .78083 .32688 L .78374 .32279 L closepath p F P
0 g
s
.686 .94 .652 r
.75946 .35191 m .76659 .34429 L .7623 .3499 L p F P
0 g
s
.686 .94 .652 r
.75856 .3531 m .75946 .35191 L p .7623 .3499 L F P
0 g
s
.686 .94 .652 r
.7623 .3499 m .76044 .35187 L .75856 .3531 L p F P
0 g
s
.713 .986 .824 r
.72706 .38237 m .72578 .38339 L .72322 .38388 L p F P
0 g
s
.814 .33 0 r
.21244 .33369 m .21039 .3304 L .21475 .3336 L p F P
0 g
s
.814 .33 0 r
.21475 .3336 m .21612 .33577 L .21244 .33369 L p F P
0 g
s
.657 .902 .981 r
.6065 .44184 m .60683 .44198 L .59693 .44757 L p F P
0 g
s
.657 .902 .981 r
.59693 .44757 m .59478 .44658 L .6065 .44184 L p F P
0 g
s
.272 .633 .963 r
.15958 .43479 m .16589 .43572 L .17068 .43864 L p F P
0 g
s
.282 .634 .964 r
.16589 .43572 m .15958 .43479 L .15587 .43199 L p F P
0 g
s
.666 .937 .967 r
.63303 .43253 m .63571 .43329 L .624 .43886 L p F P
0 g
s
.666 .937 .967 r
.624 .43886 m .62357 .43873 L .63303 .43253 L p F P
0 g
s
.651 .889 .983 r
.59478 .44658 m .58309 .4511 L .58012 .44956 L p F P
0 g
s
.643 .883 .985 r
.56844 .45383 m .58012 .44956 L .58309 .4511 L p F P
0 g
s
.713 .986 .824 r
.72322 .38388 m .73252 .37647 L .72706 .38237 L p F P
0 g
s
.699 .978 .789 r
.72706 .38237 m .73739 .37384 L .73487 .37452 L p F P
0 g
s
.699 .978 .789 r
.73487 .37452 m .73252 .37647 L .72706 .38237 L p F P
0 g
s
.509 .747 .981 r
.22439 .45345 m .2275 .45314 L .23346 .45563 L p F P
0 g
s
.506 .738 .978 r
.23535 .4523 m .2275 .45314 L .23346 .45563 L p F P
0 g
s
.506 .738 .978 r
.23346 .45563 m .23892 .45515 L .23535 .4523 L p F P
0 g
s
.667 .934 .651 r
.76044 .35187 m .75486 .35759 L .75856 .3531 L closepath p F P
0 g
s
.812 .915 .908 r
.70708 .21129 m .71359 .20662 L .71089 .20464 L p F P
0 g
s
.812 .915 .908 r
.71089 .20464 m .70901 .20606 L .70708 .21129 L p F P
0 g
s
.798 .925 .92 r
.69921 .21341 m .70901 .20606 L .70708 .21129 L p F P
0 g
s
.61 .671 .883 r
.76911 .19239 m .78126 .18997 L .78141 .19022 L p F P
0 g
s
.626 .688 .888 r
.78126 .18997 m .76911 .19239 L .76639 .18848 L p F P
0 g
s
0 0 .238 r
.80976 .2694 m .80817 .27267 L .80829 .26819 L p F P
0 g
s
0 0 .238 r
.80829 .26819 m .81038 .26388 L .80976 .2694 L p F P
0 g
s
0 0 0 r
.58744 .32513 m .58657 .32671 L .58989 .32297 L closepath p F P
0 g
s
0 .39 .833 r
.08468 .39461 m .08565 .39507 L .08948 .39841 L p F P
0 g
s
0 .426 .858 r
.09238 .398 m .09621 .40135 L .08948 .39841 L p F P
0 g
s
0 .426 .858 r
.08948 .39841 m .08565 .39507 L .09238 .398 L p F P
0 g
s
.826 .994 .857 r
.66593 .24367 m .66443 .24361 L .66773 .24057 L closepath p F P
0 g
s
.204 .589 .945 r
.14167 .427 m .14605 .42793 L .1506 .43094 L p F P
0 g
s
.225 .599 .95 r
.15216 .42912 m .14605 .42793 L .1506 .43094 L p F P
0 g
s
.225 .599 .95 r
.1506 .43094 m .15587 .43199 L .15216 .42912 L p F P
0 g
s
.679 .958 .946 r
.6592 .42128 m .66197 .42185 L .65025 .42809 L p F P
0 g
s
.679 .958 .946 r
.65132 .42548 m .6592 .42128 L p .65025 .42809 L F P
0 g
s
.679 .958 .946 r
.65025 .42809 m .64834 .42772 L .65132 .42548 L p F P
0 g
s
.608 .438 .627 r
.48486 .43432 m .484 .428 L .47186 .43093 L p F P
0 g
s
.608 .438 .627 r
.47186 .43093 m .47274 .43729 L .48486 .43432 L p F P
0 g
s
.773 .574 .629 r
.31616 .43625 m .32367 .43774 L .32244 .43093 L p F P
0 g
s
.773 .574 .629 r
.32244 .43093 m .31859 .43016 L .31616 .43625 L p F P
0 g
s
.658 .681 .861 r
.48034 .45745 m .49188 .45359 L .49502 .45828 L p F P
0 g
s
.652 .644 .83 r
.4784 .45404 m .48034 .45745 L .49188 .45359 L p F P
0 g
s
.84 .529 .462 r
.28011 .40204 m .28347 .40338 L .28281 .39833 L p F P
0 g
s
.84 .529 .462 r
.28281 .39833 m .28161 .39785 L .28011 .40204 L p F P
0 g
s
.69 .955 .699 r
.75804 .35334 m .75856 .3531 L .75486 .35759 L p F P
0 g
s
.69 .955 .699 r
.75139 .35981 m .75804 .35334 L p .75486 .35759 L F P
0 g
s
.69 .955 .699 r
.7482 .36375 m .75139 .35981 L p .75486 .35759 L F P
0 g
s
.69 .955 .699 r
.75486 .35759 m .74895 .36336 L .7482 .36375 L p F P
0 g
s
.062 .485 .891 r
.10609 .40869 m .11156 .41063 L .11567 .41384 L p F P
0 g
s
.073 .487 .894 r
.11156 .41063 m .10609 .40869 L .10232 .40553 L p F P
0 g
s
.712 .981 .787 r
.73742 .37383 m .73739 .37384 L .73748 .37376 L closepath p F P
0 g
s
0 0 0 r
.60774 .30368 m .60966 .30157 L p .61042 .30051 L F P
0 g
s
0 0 0 r
.61042 .30051 m .60958 .30141 L .60774 .30368 L p F P
0 g
s
.653 .564 .742 r
.47449 .44454 m .46927 .44556 L .46253 .4487 L p F P
0 g
s
.646 .547 .728 r
.46927 .44556 m .46199 .44707 L .46253 .4487 L closepath p F P
0 g
s
.739 .707 .821 r
.31874 .45484 m .31328 .45341 L .31571 .45685 L closepath p F P
0 g
s
.088 .069 .539 r
.8134 .24561 m .81215 .24828 L .81062 .24348 L p F P
0 g
s
.088 .069 .539 r
.81062 .24348 m .81242 .23967 L .8134 .24561 L p F P
0 g
s
.802 .563 .577 r
.30336 .42621 m .31063 .42829 L .31169 .42265 L p F P
0 g
s
.802 .563 .577 r
.31169 .42265 m .30433 .42058 L .30336 .42621 L p F P
0 g
s
.134 .539 .92 r
.12383 .41833 m .12807 .41952 L .1324 .42264 L p F P
0 g
s
.159 .554 .929 r
.1342 .42113 m .12807 .41952 L .1324 .42264 L p F P
0 g
s
.159 .554 .929 r
.1324 .42264 m .13794 .4241 L .1342 .42113 L p F P
0 g
s
.86 .484 .333 r
.25079 .37573 m .25637 .37844 L .25471 .37377 L p F P
0 g
s
.86 .484 .333 r
.25471 .37377 m .24923 .37102 L .25079 .37573 L p F P
0 g
s
.719 .984 .794 r
.73748 .37376 m .73739 .37384 L .73487 .37452 L p F P
0 g
s
.702 .973 .758 r
.74247 .36798 m .73748 .37376 L .74664 .36553 L p F P
0 g
s
.719 .984 .794 r
.73487 .37452 m .74247 .36798 L .73748 .37376 L p F P
0 g
s
0 0 0 r
.60958 .30141 m .60351 .30801 L .60774 .30368 L closepath p F P
0 g
s
.8 .537 .54 r
.29702 .4185 m .3018 .4198 L .30208 .41444 L p F P
0 g
s
.8 .537 .54 r
.30208 .41444 m .29727 .41312 L .29702 .4185 L p F P
0 g
s
.671 .949 .698 r
.74895 .36336 m .74664 .36553 L .7482 .36375 L closepath p F P
0 g
s
.702 .973 .758 r
.74648 .36438 m .74247 .36798 L p .74664 .36553 L F P
0 g
s
.702 .973 .758 r
.74664 .36553 m .7482 .36375 L .74648 .36438 L p F P
0 g
s
.86 .411 .111 r
.21612 .33577 m .21719 .33792 L .22161 .34108 L p F P
0 g
s
.868 .428 .137 r
.21929 .34238 m .22376 .34552 L .22161 .34108 L p F P
0 g
s
.868 .428 .137 r
.22161 .34108 m .21719 .33792 L .21929 .34238 L p F P
0 g
s
.214 .591 .946 r
.14605 .42793 m .14167 .427 L .13794 .4241 L p F P
0 g
s
.655 .746 .917 r
.27165 .45958 m .28284 .45592 L .2863 .45941 L p F P
0 g
s
.673 .739 .9 r
.28284 .45592 m .27165 .45958 L .26815 .45645 L p F P
0 g
s
.714 .822 .932 r
.74204 .19387 m .73981 .19492 L .73711 .19211 L p F P
0 g
s
.754 .832 .912 r
.72532 .19897 m .73711 .19211 L .73981 .19492 L p F P
0 g
s
.342 .066 .343 r
.54041 .37897 m .54087 .37655 L .53063 .38175 L p F P
0 g
s
.342 .066 .343 r
.53725 .38236 m .54041 .37897 L p .53063 .38175 L F P
0 g
s
.342 .066 .343 r
.53063 .38175 m .52983 .38616 L .53725 .38236 L p F P
0 g
s
.67 .928 .972 r
.63288 .43248 m .63303 .43253 L .62357 .43873 L p F P
0 g
s
.67 .928 .972 r
.62357 .43873 m .62113 .43785 L .63288 .43248 L p F P
0 g
s
0 0 0 r
.80074 .29205 m .80059 .29261 L .80099 .29162 L closepath p F P
0 g
s
.144 .541 .923 r
.12807 .41952 m .12383 .41833 L .12008 .41531 L p F P
0 g
s
.287 .639 .966 r
.17017 .43628 m .16589 .43572 L .17068 .43864 L p F P
0 g
s
.287 .639 .966 r
.17068 .43864 m .17386 .43908 L .17017 .43628 L p F P
0 g
s
.78 .895 .925 r
.72202 .20113 m .71359 .20662 L .71089 .20464 L p F P
0 g
s
.826 .512 .458 r
.27709 .40097 m .28011 .40204 L .28161 .39785 L p F P
0 g
s
.826 .512 .458 r
.28161 .39785 m .2763 .39596 L .27709 .40097 L p F P
0 g
s
.751 .646 .745 r
.31874 .45484 m .3272 .44788 L .32636 .44596 L p F P
0 g
s
.751 .646 .745 r
.31328 .45341 m .31874 .45484 L p .32636 .44596 L F P
0 g
s
.718 .705 .837 r
.31328 .45341 m .31084 .45298 L .30099 .4585 L p F P
0 g
s
.727 .736 .858 r
.31084 .45298 m .30099 .4585 L .29758 .45448 L p F P
0 g
s
.692 .726 .876 r
.2863 .45941 m .29758 .45448 L .30099 .4585 L p F P
0 g
s
.053 0 .081 r
.56481 .34892 m .56351 .35247 L .56982 .34532 L closepath p F P
0 g
s
.572 .375 .576 r
.49576 .42462 m .49541 .41884 L .48365 .42222 L p F P
0 g
s
.572 .375 .576 r
.48365 .42222 m .484 .428 L .49576 .42462 L p F P
0 g
s
.709 .715 .854 r
.29758 .45448 m .2863 .45941 L .28284 .45592 L p F P
0 g
s
.651 .864 .98 r
.57758 .44807 m .58012 .44956 L .56844 .45383 L p F P
0 g
s
.651 .864 .98 r
.56844 .45383 m .56721 .45307 L .57758 .44807 L p F P
0 g
s
0 0 0 r
.60682 .30486 m .60774 .30368 L .60351 .30801 L p F P
0 g
s
0 0 0 r
.60336 .3089 m .60682 .30486 L p .60351 .30801 L F P
0 g
s
0 0 0 r
.59769 .31455 m .60336 .3089 L p .60351 .30801 L F P
0 g
s
0 0 0 r
.60351 .30801 m .59808 .31396 L .59769 .31455 L p F P
0 g
s
.83 .541 .5 r
.28372 .40858 m .29026 .41094 L .28996 .40575 L p F P
0 g
s
.83 .541 .5 r
.28996 .40575 m .28347 .40338 L .28372 .40858 L p F P
0 g
s
.784 .58 .624 r
.30845 .43431 m .31616 .43625 L .31859 .43016 L p F P
0 g
s
.784 .58 .624 r
.31859 .43016 m .31063 .42829 L .30845 .43431 L p F P
0 g
s
.688 .963 .94 r
.6628 .42199 m .66197 .42185 L .66537 .41996 L closepath p F P
0 g
s
.092 .503 .903 r
.11632 .41221 m .11156 .41063 L .11567 .41384 L p F P
0 g
s
.092 .503 .903 r
.11567 .41384 m .12008 .41531 L .11632 .41221 L p F P
0 g
s
.764 .643 .727 r
.32848 .44642 m .32636 .44596 L .3272 .44788 L closepath p F P
0 g
s
.729 .821 .922 r
.74204 .19387 m .75169 .18932 L .74898 .1861 L p F P
0 g
s
.729 .821 .922 r
.74898 .1861 m .74406 .1886 L .74204 .19387 L p F P
0 g
s
.714 .822 .932 r
.73711 .19211 m .74406 .1886 L .74204 .19387 L p F P
0 g
s
0 0 0 r
.80144 .29246 m .80387 .28634 L .80099 .29162 L p F P
0 g
s
0 0 0 r
.79979 .29548 m .80144 .29246 L p .80099 .29162 L F P
0 g
s
0 0 0 r
.80099 .29162 m .80059 .29261 L .79979 .29548 L p F P
0 g
s
0 0 0 r
.7873 .31736 m .78374 .32279 L .78812 .31606 L p F P
0 g
s
0 0 0 r
.78978 .31355 m .7873 .31736 L p .78812 .31606 L F P
0 g
s
0 0 0 r
.78812 .31606 m .79052 .31244 L .78978 .31355 L p F P
0 g
s
.653 .721 .899 r
.49502 .45828 m .50659 .45469 L .50971 .45858 L p F P
0 g
s
.651 .676 .86 r
.50659 .45469 m .49502 .45828 L .49188 .45359 L p F P
0 g
s
.867 .433 .171 r
.22584 .35 m .23056 .35305 L .22841 .34859 L p F P
0 g
s
.867 .433 .171 r
.22841 .34859 m .22376 .34552 L .22584 .35 L p F P
0 g
s
.524 .751 .979 r
.2275 .45314 m .22439 .45345 L .22079 .45075 L p F P
0 g
s
.659 .152 0 r
.1882 .30651 m .18645 .30436 L .19016 .30783 L p F P
0 g
s
.659 .152 0 r
.19016 .30783 m .19183 .30989 L .1882 .30651 L p F P
0 g
s
.865 .514 .384 r
.25775 .38322 m .26326 .38595 L .26206 .38111 L p F P
0 g
s
.865 .514 .384 r
.2575 .38217 m .25775 .38322 L p .26206 .38111 L F P
0 g
s
.865 .514 .384 r
.26206 .38111 m .25982 .37999 L .2575 .38217 L p F P
0 g
s
.394 .701 .983 r
.19188 .44544 m .19344 .44548 L .18847 .44294 L closepath p F P
0 g
s
.7 .979 .904 r
.69395 .40457 m .68813 .40829 L .68545 .40817 L p F P
0 g
s
0 0 0 r
.80059 .29261 m .7984 .29778 L .79979 .29548 L closepath p F P
0 g
s
.779 .606 .665 r
.3246 .43795 m .32367 .43774 L .32403 .43901 L closepath p F P
0 g
s
.531 .313 .528 r
.50679 .41502 m .50679 .40964 L .49542 .41347 L p F P
0 g
s
.531 .313 .528 r
.49542 .41347 m .49541 .41884 L .50679 .41502 L p F P
0 g
s
0 0 0 r
.59808 .31396 m .59664 .31551 L .59769 .31455 L closepath p F P
0 g
s
0 0 .347 r
.81289 .25866 m .81038 .26388 L .81036 .25858 L p F P
0 g
s
0 0 .347 r
.81036 .25858 m .81288 .25334 L .81289 .25866 L p F P
0 g
s
.761 .611 .692 r
.32403 .43901 m .31983 .4448 L .32636 .44596 L closepath p F P
0 g
s
.751 .646 .745 r
.31236 .45198 m .31328 .45341 L p .32636 .44596 L F P
0 g
s
.751 .646 .745 r
.32636 .44596 m .31983 .4448 L .31236 .45198 L p F P
0 g
s
.647 .836 .973 r
.56544 .45193 m .55377 .45589 L .55074 .45362 L p F P
0 g
s
.644 .828 .971 r
.53909 .45737 m .55074 .45362 L .55377 .45589 L p F P
0 g
s
.69 .924 .605 r
.77081 .33997 m .7695 .341 L .77299 .33691 L closepath p F P
0 g
s
0 0 0 r
.59586 .31751 m .58989 .32297 L .59664 .31551 L p F P
0 g
s
0 0 0 r
.59664 .31551 m .59769 .31455 L .59586 .31751 L p F P
0 g
s
.65 .616 .802 r
.47719 .45159 m .4784 .45404 L .49052 .45109 L p F P
0 g
s
.652 .644 .83 r
.49188 .45359 m .49052 .45109 L .4784 .45404 L p F P
0 g
s
.768 .607 .679 r
.31983 .4448 m .32403 .43901 L .32367 .43774 L p F P
0 g
s
.768 .607 .679 r
.31187 .44295 m .31983 .4448 L p .32367 .43774 L F P
0 g
s
.768 .607 .679 r
.32367 .43774 m .31616 .43625 L .31187 .44295 L p F P
0 g
s
.663 .919 .976 r
.61825 .43674 m .62113 .43785 L .60941 .443 L p F P
0 g
s
.663 .919 .976 r
.60833 .44106 m .61825 .43674 L p .60941 .443 L F P
0 g
s
.663 .919 .976 r
.60941 .443 m .60683 .44198 L .60833 .44106 L p F P
0 g
s
.649 .761 .931 r
.50971 .45858 m .52131 .45506 L .5244 .45827 L p F P
0 g
s
.649 .722 .902 r
.52131 .45506 m .50971 .45858 L .50659 .45469 L p F P
0 g
s
0 0 .142 r
.80775 .27676 m .80577 .2804 L .80709 .27465 L p F P
0 g
s
0 0 .142 r
.80709 .27465 m .80817 .27267 L .80775 .27676 L p F P
0 g
s
.528 .595 .865 r
.78402 .19466 m .79622 .19487 L .79419 .20009 L p F P
0 g
s
.516 .618 .892 r
.78141 .19022 m .78402 .19466 L .79622 .19487 L p F P
0 g
s
.782 .295 0 r
.19183 .30989 m .19312 .31192 L .19695 .31533 L p F P
0 g
s
.794 .31 0 r
.19572 .31615 m .19957 .31956 L .19695 .31533 L p F P
0 g
s
.794 .31 0 r
.19695 .31533 m .19312 .31192 L .19572 .31615 L p F P
0 g
s
.813 .549 .539 r
.28999 .41632 m .29702 .4185 L .29727 .41312 L p F P
0 g
s
.813 .549 .539 r
.29727 .41312 m .29026 .41094 L .28999 .41632 L p F P
0 g
s
.271 .311 .72 r
.80811 .22325 m .80936 .22441 L .80889 .22568 L closepath p F P
0 g
s
.206 .237 .673 r
.81264 .22862 m .81095 .23309 L .80889 .22568 L p F P
0 g
s
.206 .237 .673 r
.80889 .22568 m .80936 .22441 L .81264 .22862 L p F P
0 g
s
.241 .305 .729 r
.80605 .21722 m .80811 .22325 L .80936 .22441 L p F P
0 g
s
.266 0 .279 r
.54355 .37501 m .54087 .37655 L .54183 .37235 L p F P
0 g
s
.266 0 .279 r
.54183 .37235 m .55005 .3676 L .54355 .37501 L p F P
0 g
s
.862 .411 .094 r
.21719 .33792 m .21612 .33577 L .21244 .33369 L p F P
0 g
s
.859 .43 .2 r
.23263 .35755 m .23056 .35305 L .23549 .35601 L p F P
0 g
s
.859 .43 .2 r
.23432 .35855 m .23263 .35755 L p .23549 .35601 L F P
0 g
s
.859 .43 .2 r
.23549 .35601 m .2368 .3588 L .23432 .35855 L p F P
0 g
s
.181 .184 .625 r
.81066 .23374 m .81095 .23309 L .8114 .23501 L closepath p F P
0 g
s
.78 .868 .913 r
.72532 .19897 m .72202 .20113 L .72315 .19707 L closepath p F P
0 g
s
.78 .895 .925 r
.72261 .19661 m .72315 .19707 L .72202 .20113 L p F P
0 g
s
.78 .895 .925 r
.71089 .20464 m .72261 .19661 L p .72202 .20113 L F P
0 g
s
.855 .523 .423 r
.2642 .39089 m .27008 .39349 L .26905 .38857 L p F P
0 g
s
.855 .523 .423 r
.26905 .38857 m .26326 .38595 L .2642 .39089 L p F P
0 g
s
.647 .805 .959 r
.55074 .45362 m .53909 .45737 L .53603 .45468 L p F P
0 g
s
.646 .797 .955 r
.5244 .45827 m .53603 .45468 L .53909 .45737 L p F P
0 g
s
.648 .766 .935 r
.53603 .45468 m .5244 .45827 L .52131 .45506 L p F P
0 g
s
.647 .53 .707 r
.47405 .44304 m .46927 .44556 L .47449 .44454 L closepath p F P
0 g
s
.771 .988 .754 r
.64235 .26624 m .64136 .26664 L .64382 .26413 L closepath p F P
0 g
s
.43 .714 .983 r
.19902 .44282 m .20267 .44562 L .19344 .44548 L p F P
0 g
s
.43 .714 .983 r
.18822 .44275 m .19902 .44282 L p .19344 .44548 L F P
0 g
s
.43 .714 .983 r
.19344 .44548 m .18847 .44294 L .18822 .44275 L p F P
0 g
s
.34 .393 .771 r
.80507 .2146 m .80663 .21554 L .80605 .21722 L closepath p F P
0 g
s
.241 .305 .729 r
.81118 .21932 m .80663 .21554 L .80605 .21722 L p F P
0 g
s
.241 .305 .729 r
.80936 .22441 m .81118 .21932 L p .80605 .21722 L F P
0 g
s
.621 .487 .677 r
.4856 .43776 m .48486 .43432 L .47274 .43729 L p F P
0 g
s
.621 .487 .677 r
.47274 .43729 m .47405 .44304 L .4856 .43776 L p F P
0 g
s
.025 .45 .872 r
.09854 .40229 m .09621 .40135 L .10012 .40465 L p F P
0 g
s
.025 .45 .872 r
.10012 .40465 m .10232 .40553 L .09854 .40229 L p F P
0 g
s
.482 .248 .482 r
.51779 .40535 m .51806 .40029 L .50707 .40458 L p F P
0 g
s
.482 .248 .482 r
.50707 .40458 m .50679 .40964 L .51779 .40535 L p F P
0 g
s
.693 .981 .884 r
.69984 .40067 m .69395 .40457 L .69823 .40071 L closepath p F P
0 g
s
.7 .979 .904 r
.69718 .40063 m .69823 .40071 L .69395 .40457 L p F P
0 g
s
.7 .979 .904 r
.68545 .40817 m .69718 .40063 L p .69395 .40457 L F P
0 g
s
.725 .979 .757 r
.7482 .36375 m .74648 .36438 L .75139 .35981 L closepath p F P
0 g
s
.731 .687 .808 r
.31236 .45198 m .31084 .45298 L .31328 .45341 L closepath p F P
0 g
s
0 0 0 r
.5953 .31847 m .59586 .31751 L .58989 .32297 L p F P
0 g
s
0 0 0 r
.59115 .32344 m .5953 .31847 L p .58989 .32297 L F P
0 g
s
0 0 0 r
.58576 .32831 m .59115 .32344 L p .58989 .32297 L F P
0 g
s
0 0 0 r
.58989 .32297 m .58657 .32671 L .58576 .32831 L p F P
0 g
s
.639 .566 .756 r
.47449 .44454 m .47719 .45159 L .48874 .44732 L p F P
0 g
s
.65 .616 .802 r
.49052 .45109 m .48874 .44732 L .47719 .45159 L p F P
0 g
s
.848 .487 .367 r
.25982 .37999 m .2575 .38217 L .25637 .37844 L closepath p F P
0 g
s
.763 .865 .924 r
.73441 .18939 m .73711 .19211 L .72532 .19897 L p F P
0 g
s
.763 .865 .924 r
.72359 .19601 m .73441 .18939 L p .72532 .19897 L F P
0 g
s
.763 .865 .924 r
.72532 .19897 m .72315 .19707 L .72359 .19601 L p F P
0 g
s
.805 .321 0 r
.20218 .3238 m .20621 .32714 L .20356 .3229 L p F P
0 g
s
.805 .321 0 r
.20356 .3229 m .19957 .31956 L .20218 .3238 L p F P
0 g
s
.317 .395 .785 r
.80214 .20728 m .80507 .2146 L .80663 .21554 L p F P
0 g
s
.61 .88 .555 r
.61988 .29022 m .61833 .29167 L .62275 .28677 L closepath p F P
0 g
s
.574 .752 .962 r
.23892 .45515 m .24997 .45315 L .25351 .45615 L p F P
0 g
s
.589 .752 .955 r
.24997 .45315 m .23892 .45515 L .23535 .4523 L p F P
0 g
s
.631 .847 .461 r
.78236 .32429 m .7873 .31736 L .78374 .32279 L p F P
0 g
s
.631 .847 .461 r
.78006 .32784 m .78236 .32429 L p .78374 .32279 L F P
0 g
s
.631 .847 .461 r
.78374 .32279 m .78083 .32688 L .78006 .32784 L p F P
0 g
s
.073 .11 .595 r
.81497 .23315 m .81264 .22862 L .81095 .23309 L p F P
0 g
s
.073 .11 .595 r
.81299 .23826 m .81497 .23315 L p .81095 .23309 L F P
0 g
s
.073 .11 .595 r
.81095 .23309 m .8114 .23501 L .81299 .23826 L p F P
0 g
s
.811 .573 .578 r
.30222 .42585 m .30336 .42621 L .30433 .42058 L p F P
0 g
s
.811 .573 .578 r
.30433 .42058 m .3018 .4198 L .30222 .42585 L p F P
0 g
s
.881 .493 .297 r
.23901 .36524 m .24401 .36817 L .24238 .36351 L p F P
0 g
s
.881 .493 .297 r
.24238 .36351 m .23746 .36055 L .23901 .36524 L p F P
0 g
s
.694 .961 .943 r
.66537 .41996 m .66197 .42185 L .6592 .42128 L p F P
0 g
s
.677 .944 .961 r
.64464 .42666 m .64745 .42749 L .63571 .43329 L p F P
0 g
s
.677 .944 .961 r
.6336 .43213 m .64464 .42666 L p .63571 .43329 L F P
0 g
s
.677 .944 .961 r
.63571 .43329 m .63303 .43253 L .6336 .43213 L p F P
0 g
s
0 0 0 r
.59719 .31619 m .59586 .31751 L .59769 .31455 L p F P
0 g
s
0 0 0 r
.59769 .31455 m .60336 .3089 L .59719 .31619 L p F P
0 g
s
.524 .751 .979 r
.22079 .45075 m .2214 .45068 L .2275 .45314 L p F P
0 g
s
.522 .739 .974 r
.23177 .44938 m .2214 .45068 L .2275 .45314 L p F P
0 g
s
.522 .739 .974 r
.2275 .45314 m .23535 .4523 L .23177 .44938 L p F P
0 g
s
.345 .67 .975 r
.17386 .43908 m .18326 .43985 L .18813 .44274 L p F P
0 g
s
.355 .671 .975 r
.18326 .43985 m .17386 .43908 L .17017 .43628 L p F P
0 g
s
.829 .977 .885 r
.67624 .23297 m .67599 .23291 L .67652 .23245 L closepath p F P
0 g
s
.651 .856 .978 r
.57714 .4478 m .57758 .44807 L .56721 .45307 L p F P
0 g
s
.651 .856 .978 r
.56721 .45307 m .56544 .45193 L .57714 .4478 L p F P
0 g
s
0 0 0 r
.58657 .32671 m .58316 .33043 L .58576 .32831 L closepath p F P
0 g
s
.84 .526 .458 r
.27078 .39853 m .27709 .40097 L .2763 .39596 L p F P
0 g
s
.84 .526 .458 r
.2763 .39596 m .27008 .39349 L .27078 .39853 L p F P
0 g
s
.748 .679 .784 r
.31084 .45298 m .31236 .45198 L .30905 .44614 L p F P
0 g
s
.748 .679 .784 r
.30905 .44614 m .30267 .4512 L .31084 .45298 L p F P
0 g
s
.727 .736 .858 r
.29758 .45448 m .30267 .4512 L .31084 .45298 L p F P
0 g
s
.769 .68 .765 r
.30905 .44614 m .31187 .44295 L .31983 .4448 L p F P
0 g
s
.769 .68 .765 r
.31983 .4448 m .31236 .45198 L .30905 .44614 L p F P
0 g
s
0 0 0 r
.57539 .33876 m .57505 .33956 L .57651 .33787 L closepath p F P
0 g
s
.482 .543 .842 r
.79641 .19489 m .79622 .19487 L .79419 .20009 L p F P
0 g
s
.482 .543 .842 r
.79419 .20009 m .79925 .20084 L .79641 .19489 L p F P
0 g
s
.123 .134 .598 r
.8114 .23501 m .81299 .23826 L .81242 .23967 L closepath p F P
0 g
s
.633 .522 .71 r
.48666 .44163 m .4856 .43776 L .47405 .44304 L p F P
0 g
s
.633 .522 .71 r
.47405 .44304 m .47449 .44454 L .48666 .44163 L p F P
0 g
s
.802 .591 .616 r
.30368 .43291 m .30845 .43431 L .31063 .42829 L p F P
0 g
s
.802 .591 .616 r
.30269 .42835 m .30368 .43291 L p .31063 .42829 L F P
0 g
s
.802 .591 .616 r
.31063 .42829 m .30336 .42621 L .30269 .42835 L p F P
0 g
s
.707 .984 .882 r
.70858 .39467 m .69984 .40067 L .69823 .40071 L p F P
0 g
s
0 0 0 r
.58417 .33162 m .57651 .33787 L .58316 .33043 L p F P
0 g
s
0 0 0 r
.58316 .33043 m .58576 .32831 L .58417 .33162 L p F P
0 g
s
.209 .245 .68 r
.81458 .22349 m .81264 .22862 L .80936 .22441 L p F P
0 g
s
.209 .245 .68 r
.80936 .22441 m .81118 .21932 L .81458 .22349 L p F P
0 g
s
.811 .327 0 r
.20877 .3313 m .20621 .32714 L .21039 .3304 L p F P
0 g
s
.811 .327 0 r
.21039 .3304 m .21244 .33369 L .20877 .3313 L p F P
0 g
s
0 0 0 r
.79849 .29875 m .79525 .30412 L .7984 .29778 L p F P
0 g
s
0 0 0 r
.79864 .29845 m .79849 .29875 L p .7984 .29778 L F P
0 g
s
0 0 0 r
.7984 .29778 m .79979 .29548 L .79864 .29845 L p F P
0 g
s
.639 .566 .756 r
.48874 .44732 m .48666 .44163 L .47449 .44454 L p F P
0 g
s
.825 .982 .882 r
.67652 .23245 m .67599 .23291 L .67328 .2324 L p F P
0 g
s
.844 .992 .848 r
.66773 .24057 m .67599 .23291 L .67328 .2324 L p F P
0 g
s
.843 .959 .885 r
.67925 .22698 m .67652 .23245 L .68622 .22403 L p F P
0 g
s
.825 .982 .882 r
.67328 .2324 m .67925 .22698 L .67652 .23245 L p F P
0 g
s
.651 .889 .983 r
.58012 .44956 m .59184 .44508 L .59478 .44658 L p F P
0 g
s
.659 .896 .981 r
.6065 .44184 m .59478 .44658 L .59184 .44508 L p F P
0 g
s
.844 .992 .848 r
.67328 .2324 m .6705 .2351 L .66773 .24057 L p F P
0 g
s
.821 .996 .853 r
.66227 .24305 m .6705 .2351 L .66773 .24057 L p F P
0 g
s
.821 .996 .853 r
.66197 .24359 m .66227 .24305 L p .66773 .24057 L F P
0 g
s
.821 .996 .853 r
.66773 .24057 m .66443 .24361 L .66197 .24359 L p F P
0 g
s
.841 .995 .843 r
.66443 .24361 m .65938 .24855 L .66197 .24359 L closepath p F P
0 g
s
.686 .968 .929 r
.67371 .41517 m .66537 .41996 L .67165 .4149 L closepath p F P
0 g
s
.694 .961 .943 r
.67097 .41475 m .67165 .4149 L .66537 .41996 L p F P
0 g
s
.694 .961 .943 r
.6592 .42128 m .67097 .41475 L p .66537 .41996 L F P
0 g
s
.426 .177 .432 r
.52885 .39368 m .52915 .39073 L .51855 .39549 L p F P
0 g
s
.426 .177 .432 r
.52657 .39646 m .52885 .39368 L p .51855 .39549 L F P
0 g
s
.426 .177 .432 r
.51855 .39549 m .51806 .40029 L .52657 .39646 L p F P
0 g
s
.872 .496 .33 r
.24548 .37291 m .25079 .37573 L .24923 .37102 L p F P
0 g
s
.872 .496 .33 r
.24923 .37102 m .24401 .36817 L .24548 .37291 L p F P
0 g
s
.784 .616 .671 r
.30675 .44151 m .31187 .44295 L .31616 .43625 L p F P
0 g
s
.784 .616 .671 r
.30579 .43906 m .30675 .44151 L p .31616 .43625 L F P
0 g
s
.784 .616 .671 r
.31616 .43625 m .30845 .43431 L .30579 .43906 L p F P
0 g
s
.462 .722 .981 r
.2199 .45007 m .22079 .45075 L p .2063 .44837 L F P
0 g
s
.462 .722 .981 r
.2063 .44837 m .21596 .44799 L .2199 .45007 L p F P
0 g
s
.475 .725 .979 r
.21596 .44799 m .2063 .44837 L .20267 .44562 L p F P
0 g
s
.607 .836 .455 r
.78083 .32688 m .77872 .32974 L .78006 .32784 L closepath p F P
0 g
s
.771 .287 0 r
.19312 .31192 m .19183 .30989 L .1882 .30651 L p F P
0 g
s
.59 .424 .624 r
.49663 .43094 m .49576 .42462 L .484 .428 L p F P
0 g
s
.59 .424 .624 r
.484 .428 m .48486 .43432 L .49663 .43094 L p F P
0 g
s
.8 .999 .808 r
.6617 .24359 m .66197 .24359 L .65938 .24855 L p F P
0 g
s
.8 .999 .808 r
.65475 .25077 m .6617 .24359 L p .65938 .24855 L F P
0 g
s
.8 .999 .808 r
.65219 .25499 m .65475 .25077 L p .65938 .24855 L F P
0 g
s
.8 .999 .808 r
.65938 .24855 m .65289 .25485 L .65219 .25499 L p F P
0 g
s
.799 .564 .582 r
.29593 .42416 m .30222 .42585 L .3018 .4198 L p F P
0 g
s
.799 .564 .582 r
.3018 .4198 m .29702 .4185 L .29593 .42416 L p F P
0 g
s
.641 .705 .893 r
.77852 .18556 m .76639 .18848 L .76367 .18472 L p F P
0 g
s
.68 .748 .903 r
.75169 .18932 m .76367 .18472 L .76639 .18848 L p F P
0 g
s
.626 .688 .888 r
.76639 .18848 m .77852 .18556 L .78126 .18997 L p F P
0 g
s
.693 .762 .905 r
.76367 .18472 m .75169 .18932 L .74898 .1861 L p F P
0 g
s
.214 .591 .946 r
.13794 .4241 m .14159 .42486 L .14605 .42793 L p F P
0 g
s
.234 .601 .951 r
.14844 .42618 m .14159 .42486 L .14605 .42793 L p F P
0 g
s
.234 .601 .951 r
.14605 .42793 m .15216 .42912 L .14844 .42618 L p F P
0 g
s
.841 .957 .887 r
.68759 .22284 m .68622 .22403 L .68682 .22255 L closepath p F P
0 g
s
.843 .959 .885 r
.68487 .22184 m .67925 .22698 L p .68622 .22403 L F P
0 g
s
.843 .959 .885 r
.68622 .22403 m .68682 .22255 L .68487 .22184 L p F P
0 g
s
.822 .958 .902 r
.69692 .21528 m .68759 .22284 L .68682 .22255 L p F P
0 g
s
.18 0 .206 r
.55278 .36264 m .55197 .36559 L .55657 .3602 L closepath p F P
0 g
s
.627 .752 .937 r
.25351 .45615 m .26465 .45318 L .26815 .45645 L p F P
0 g
s
.643 .749 .926 r
.26465 .45318 m .25351 .45615 L .24997 .45315 L p F P
0 g
s
.842 .55 .496 r
.27912 .40674 m .28372 .40858 L .28347 .40338 L p F P
0 g
s
.842 .55 .496 r
.28347 .40338 m .28011 .40204 L .27912 .40674 L p F P
0 g
s
.819 1 .802 r
.65289 .25485 m .65135 .25642 L .65219 .25499 L closepath p F P
0 g
s
.685 .95 .956 r
.64834 .42772 m .64745 .42749 L .65132 .42548 L closepath p F P
0 g
s
0 0 .448 r
.81398 .251 m .81288 .25334 L .81215 .24828 L p F P
0 g
s
0 0 .448 r
.81215 .24828 m .8134 .24561 L .81398 .251 L p F P
0 g
s
.282 .634 .964 r
.15587 .43199 m .1612 .43275 L .16589 .43572 L p F P
0 g
s
.292 .636 .965 r
.1612 .43275 m .15587 .43199 L .15216 .42912 L p F P
0 g
s
.818 .999 .795 r
.6474 .25842 m .64382 .26413 L .65135 .25642 L p F P
0 g
s
.818 .999 .795 r
.65016 .25545 m .6474 .25842 L p .65135 .25642 L F P
0 g
s
.818 .999 .795 r
.65135 .25642 m .65219 .25499 L .65016 .25545 L p F P
0 g
s
.144 .541 .923 r
.12008 .41531 m .12384 .41636 L .12807 .41952 L p F P
0 g
s
.169 .555 .931 r
.13046 .41809 m .12384 .41636 L .12807 .41952 L p F P
0 g
s
.169 .555 .931 r
.12807 .41952 m .1342 .42113 L .13046 .41809 L p F P
0 g
s
0 0 .119 r
.80855 .27512 m .80775 .27676 L .80817 .27267 L p F P
0 g
s
0 0 .119 r
.80817 .27267 m .80976 .2694 L .80855 .27512 L p F P
0 g
s
.862 .411 .094 r
.21244 .33369 m .21293 .33469 L .21719 .33792 L p F P
0 g
s
.872 .433 .126 r
.21498 .33917 m .21929 .34238 L .21719 .33792 L p F P
0 g
s
.872 .433 .126 r
.21719 .33792 m .21293 .33469 L .21498 .33917 L p F P
0 g
s
.664 .896 .552 r
.77685 .33141 m .77299 .33691 L .77872 .32974 L p F P
0 g
s
.664 .896 .552 r
.77855 .32926 m .77685 .33141 L p .77872 .32974 L F P
0 g
s
.664 .896 .552 r
.77872 .32974 m .78006 .32784 L .77855 .32926 L p F P
0 g
s
.317 .395 .785 r
.80663 .21554 m .80833 .21048 L p .80214 .20728 L F P
0 g
s
.291 .343 .744 r
.81307 .21419 m .81118 .21932 L .80663 .21554 L p F P
0 g
s
.291 .343 .744 r
.80663 .21554 m .80833 .21048 L .81307 .21419 L p F P
0 g
s
0 0 .033 r
.58377 .33252 m .58417 .33162 L .57651 .33787 L p F P
0 g
s
0 0 .033 r
.57946 .33783 m .58377 .33252 L p .57651 .33787 L F P
0 g
s
0 0 .033 r
.57397 .34231 m .57946 .33783 L p .57651 .33787 L F P
0 g
s
0 0 .033 r
.57651 .33787 m .57505 .33956 L .57397 .34231 L p F P
0 g
s
.297 .64 .966 r
.16647 .43343 m .1612 .43275 L .16589 .43572 L p F P
0 g
s
.297 .64 .966 r
.16589 .43572 m .17017 .43628 L .16647 .43343 L p F P
0 g
s
.399 .464 .812 r
.80212 .20724 m .80215 .20725 L .80214 .20728 L closepath p F P
0 g
s
.317 .395 .785 r
.80833 .21048 m .80215 .20725 L .80214 .20728 L p F P
0 g
s
.416 .487 .825 r
.80215 .20725 m .80212 .20724 L .79925 .20084 L p F P
0 g
s
.651 .676 .86 r
.49188 .45359 m .50346 .44992 L .50659 .45469 L p F P
0 g
s
.645 .634 .824 r
.49052 .45109 m .49188 .45359 L .50346 .44992 L p F P
0 g
s
.416 .487 .825 r
.79925 .20084 m .80361 .20223 L .80215 .20725 L p F P
0 g
s
.365 .432 .798 r
.81011 .20536 m .80833 .21048 L .80215 .20725 L p F P
0 g
s
.365 .432 .798 r
.80215 .20725 m .80361 .20223 L .81011 .20536 L p F P
0 g
s
.073 .487 .894 r
.10232 .40553 m .10754 .40738 L .11156 .41063 L p F P
0 g
s
.084 .489 .897 r
.10754 .40738 m .10232 .40553 L .09854 .40229 L p F P
0 g
s
.741 .724 .836 r
.30267 .4512 m .29758 .45448 L .29418 .45012 L p F P
0 g
s
.709 .715 .854 r
.28284 .45592 m .29418 .45012 L .29758 .45448 L p F P
0 g
s
.024 0 .046 r
.57505 .33956 m .56982 .34532 L .57397 .34231 L closepath p F P
0 g
s
.856 .491 .359 r
.25215 .38052 m .25079 .37573 L .25637 .37844 L p F P
0 g
s
.856 .491 .359 r
.2568 .38272 m .25215 .38052 L p .25637 .37844 L F P
0 g
s
.856 .491 .359 r
.25637 .37844 m .2575 .38217 L .2568 .38272 L p F P
0 g
s
.829 .931 .898 r
.69921 .21341 m .69692 .21528 L .69785 .21266 L closepath p F P
0 g
s
.822 .958 .902 r
.69651 .21195 m .69785 .21266 L .69692 .21528 L p F P
0 g
s
.822 .958 .902 r
.68865 .21865 m .69651 .21195 L p .69692 .21528 L F P
0 g
s
.822 .958 .902 r
.68682 .22255 m .68865 .21865 L p .69692 .21528 L F P
0 g
s
.032 .031 .521 r
.81443 .24309 m .8134 .24561 L .81242 .23967 L p F P
0 g
s
.032 .031 .521 r
.81242 .23967 m .81299 .23826 L .81443 .24309 L p F P
0 g
s
.699 .984 .859 r
.71154 .39256 m .70858 .39467 L .71068 .39264 L closepath p F P
0 g
s
.707 .984 .882 r
.70891 .39263 m .71068 .39264 L .70858 .39467 L p F P
0 g
s
.707 .984 .882 r
.70069 .3983 m .70891 .39263 L p .70858 .39467 L F P
0 g
s
.707 .984 .882 r
.69823 .40071 m .70069 .3983 L p .70858 .39467 L F P
0 g
s
.673 .739 .9 r
.26815 .45645 m .27939 .45222 L .28284 .45592 L p F P
0 g
s
.691 .733 .883 r
.27939 .45222 m .26815 .45645 L .26465 .45318 L p F P
0 g
s
.754 .981 .737 r
.6404 .26598 m .6474 .25842 L .64382 .26413 L p F P
0 g
s
.754 .981 .737 r
.63936 .26754 m .6404 .26598 L p .64382 .26413 L F P
0 g
s
.754 .981 .737 r
.64382 .26413 m .64136 .26664 L .63936 .26754 L p F P
0 g
s
.809 .932 .913 r
.70901 .20606 m .69921 .21341 L .69785 .21266 L p F P
0 g
s
.829 .563 .536 r
.28345 .41397 m .28999 .41632 L .29026 .41094 L p F P
0 g
s
.829 .563 .536 r
.29026 .41094 m .28372 .40858 L .28345 .41397 L p F P
0 g
s
0 0 .015 r
.80675 .28104 m .80387 .28634 L .80577 .2804 L p F P
0 g
s
0 0 .015 r
.80722 .27956 m .80675 .28104 L p .80577 .2804 L F P
0 g
s
0 0 .015 r
.80577 .2804 m .80775 .27676 L .80722 .27956 L p F P
0 g
s
.881 .477 .251 r
.2368 .3588 m .23746 .36055 L .23432 .35855 L closepath p F P
0 g
s
.774 .985 .735 r
.64136 .26664 m .63658 .27174 L .63936 .26754 L closepath p F P
0 g
s
.224 .592 .948 r
.14159 .42486 m .13794 .4241 L .1342 .42113 L p F P
0 g
s
.726 .712 .838 r
.28284 .45592 m .29418 .45012 L .29269 .44807 L p F P
0 g
s
.726 .712 .838 r
.27939 .45222 m .28284 .45592 L p .29269 .44807 L F P
0 g
s
.873 .44 .161 r
.22131 .34688 m .22584 .35 L .22376 .34552 L p F P
0 g
s
.873 .44 .161 r
.22376 .34552 m .21929 .34238 L .22131 .34688 L p F P
0 g
s
.656 .873 .98 r
.58888 .44342 m .59184 .44508 L .58012 .44956 L p F P
0 g
s
.656 .873 .98 r
.58035 .44662 m .58888 .44342 L p .58012 .44956 L F P
0 g
s
.656 .873 .98 r
.58012 .44956 m .57758 .44807 L .58035 .44662 L p F P
0 g
s
0 0 .23 r
.81224 .26419 m .80976 .2694 L .81038 .26388 L p F P
0 g
s
0 0 .23 r
.81038 .26388 m .81289 .25866 L .81224 .26419 L p F P
0 g
s
.155 .543 .925 r
.12384 .41636 m .12008 .41531 L .11632 .41221 L p F P
0 g
s
.714 .987 .857 r
.72132 .38533 m .71154 .39256 L .71068 .39264 L p F P
0 g
s
.551 .359 .574 r
.50717 .4208 m .50679 .41502 L .49541 .41884 L p F P
0 g
s
.551 .359 .574 r
.49541 .41884 m .49576 .42462 L .50717 .4208 L p F P
0 g
s
.362 .101 .377 r
.53147 .38954 m .52915 .39073 L .52983 .38616 L p F P
0 g
s
.362 .101 .377 r
.52983 .38616 m .53725 .38236 L .53147 .38954 L p F P
0 g
s
.102 .505 .905 r
.11256 .40904 m .10754 .40738 L .11156 .41063 L p F P
0 g
s
.102 .505 .905 r
.11156 .41063 m .11632 .41221 L .11256 .40904 L p F P
0 g
s
.097 0 .122 r
.57262 .34596 m .57397 .34231 L .56982 .34532 L p F P
0 g
s
.097 0 .122 r
.56347 .3526 m .57262 .34596 L p .56982 .34532 L F P
0 g
s
.097 0 .122 r
.56982 .34532 m .56351 .35247 L .56347 .3526 L p F P
0 g
s
.728 .833 .93 r
.74406 .1886 m .73711 .19211 L .73441 .18939 L p F P
0 g
s
.562 .647 .892 r
.78126 .18997 m .78146 .18995 L .78141 .19022 L closepath p F P
0 g
s
.516 .618 .892 r
.79361 .18947 m .78146 .18995 L .78141 .19022 L p F P
0 g
s
.516 .618 .892 r
.7963 .19466 m .79361 .18947 L p .78141 .19022 L F P
0 g
s
.516 .618 .892 r
.79622 .19487 m .7963 .19466 L p .78141 .19022 L F P
0 g
s
.673 .925 .973 r
.63288 .43248 m .62113 .43785 L .61825 .43674 L p F P
0 g
s
.682 .937 .647 r
.63862 .2679 m .63936 .26754 L .63658 .27174 L p F P
0 g
s
.682 .937 .647 r
.63375 .27341 m .63862 .2679 L p .63658 .27174 L F P
0 g
s
.682 .937 .647 r
.62969 .279 m .63375 .27341 L p .63658 .27174 L F P
0 g
s
.682 .937 .647 r
.63658 .27174 m .62984 .2789 L .62969 .279 L p F P
0 g
s
.867 .535 .421 r
.25863 .38819 m .2642 .39089 L .26326 .38595 L p F P
0 g
s
.867 .535 .421 r
.26326 .38595 m .25775 .38322 L .25863 .38819 L p F P
0 g
s
.757 .664 .759 r
.30267 .4512 m .30905 .44614 L .30675 .44151 L p F P
0 g
s
.757 .664 .759 r
.29561 .44907 m .30267 .4512 L p .30675 .44151 L F P
0 g
s
.741 .724 .836 r
.29418 .45012 m .29561 .44907 L .30267 .4512 L p F P
0 g
s
.699 .971 .927 r
.68471 .40862 m .67371 .41517 L .67165 .4149 L p F P
0 g
s
.577 .664 .898 r
.78146 .18995 m .78126 .18997 L .77852 .18556 L p F P
0 g
s
.625 .815 .399 r
.79052 .31244 m .78978 .31355 L .79162 .31063 L closepath p F P
0 g
s
.693 .926 .608 r
.77057 .33877 m .77685 .33141 L .77299 .33691 L p F P
0 g
s
.693 .926 .608 r
.76846 .34181 m .77057 .33877 L p .77299 .33691 L F P
0 g
s
.693 .926 .608 r
.77299 .33691 m .7695 .341 L .76846 .34181 L p F P
0 g
s
.811 .574 .58 r
.28896 .42196 m .29593 .42416 L .29702 .4185 L p F P
0 g
s
.811 .574 .58 r
.29702 .4185 m .28999 .41632 L .28896 .42196 L p F P
0 g
s
.777 .663 .738 r
.31187 .44295 m .30675 .44151 L .30905 .44614 L closepath p F P
0 g
s
.348 .674 .977 r
.18847 .44294 m .18822 .44275 L .18813 .44274 L closepath p F P
0 g
s
.64 .603 .796 r
.48874 .44732 m .49052 .45109 L .50228 .44773 L p F P
0 g
s
.645 .634 .824 r
.50346 .44992 m .50228 .44773 L .49052 .45109 L p F P
0 g
s
.577 .664 .898 r
.77852 .18556 m .7823 .18509 L .78146 .18995 L p F P
0 g
s
.549 .616 .872 r
.79082 .18435 m .7823 .18509 L .78146 .18995 L p F P
0 g
s
.549 .616 .872 r
.78146 .18995 m .79361 .18947 L .79082 .18435 L p F P
0 g
s
.832 .96 .894 r
.68682 .22255 m .68487 .22184 L .68865 .21865 L closepath p F P
0 g
s
.726 .97 .718 r
.75856 .3531 m .75804 .35334 L .75946 .35191 L closepath p F P
0 g
s
0 0 0 r
.79477 .3053 m .79162 .31063 L .79525 .30412 L p F P
0 g
s
0 0 0 r
.79525 .30412 m .79849 .29875 L .79477 .3053 L p F P
0 g
s
.649 .722 .902 r
.50659 .45469 m .5182 .4512 L .52131 .45506 L p F P
0 g
s
.645 .676 .865 r
.5182 .4512 m .50659 .45469 L .50346 .44992 L p F P
0 g
s
.827 .534 .494 r
.27743 .40615 m .27912 .40674 L .28011 .40204 L p F P
0 g
s
.827 .534 .494 r
.28011 .40204 m .27709 .40097 L .27743 .40615 L p F P
0 g
s
.871 .445 .197 r
.22783 .35453 m .23263 .35755 L .23056 .35305 L p F P
0 g
s
.871 .445 .197 r
.23056 .35305 m .22584 .35 L .22783 .35453 L p F P
0 g
s
.524 .751 .978 r
.22079 .45075 m .2214 .45068 L .2199 .45007 L closepath p F P
0 g
s
.354 .673 .976 r
.18455 .43994 m .18326 .43985 L .18813 .44274 L p F P
0 g
s
.354 .673 .976 r
.18813 .44274 m .18822 .44275 L .18455 .43994 L p F P
0 g
s
.812 .904 .905 r
.71089 .20464 m .70901 .20606 L .7097 .20382 L closepath p F P
0 g
s
.809 .932 .913 r
.70818 .20278 m .7097 .20382 L .70901 .20606 L p F P
0 g
s
.809 .932 .913 r
.69901 .21 m .70818 .20278 L p .70901 .20606 L F P
0 g
s
.809 .932 .913 r
.69785 .21266 m .69901 .21 L p .70901 .20606 L F P
0 g
s
.814 .999 .796 r
.65219 .25499 m .65016 .25545 L .65475 .25077 L closepath p F P
0 g
s
.428 .705 .98 r
.19902 .44282 m .18822 .44275 L .18455 .43994 L p F P
0 g
s
.701 .943 .65 r
.62984 .2789 m .62945 .27932 L .62969 .279 L closepath p F P
0 g
s
.652 .844 .974 r
.57714 .4478 m .56544 .45193 L .56243 .44974 L p F P
0 g
s
.647 .836 .973 r
.55074 .45362 m .56243 .44974 L .56544 .45193 L p F P
0 g
s
.797 .904 .916 r
.71991 .19436 m .72261 .19661 L .71089 .20464 L p F P
0 g
s
.797 .904 .916 r
.71092 .20083 m .71991 .19436 L p .71089 .20464 L F P
0 g
s
.797 .904 .916 r
.71089 .20464 m .7097 .20382 L .71092 .20083 L p F P
0 g
s
0 0 0 r
.58525 .33065 m .58417 .33162 L .58576 .32831 L p F P
0 g
s
0 0 0 r
.58576 .32831 m .59115 .32344 L .58525 .33065 L p F P
0 g
s
.692 .947 .958 r
.65132 .42548 m .64745 .42749 L .64464 .42666 L p F P
0 g
s
.694 .937 .637 r
.62712 .28089 m .62275 .28677 L .62945 .27932 L p F P
0 g
s
.694 .937 .637 r
.62945 .27932 m .62969 .279 L .62712 .28089 L p F P
0 g
s
.672 .92 .606 r
.7695 .341 m .76659 .34429 L .76846 .34181 L closepath p F P
0 g
s
.134 0 .138 r
.56351 .35247 m .56327 .35273 L .56347 .3526 L closepath p F P
0 g
s
.809 .598 .618 r
.30336 .42621 m .30222 .42585 L .30269 .42835 L closepath p F P
0 g
s
.541 .753 .975 r
.22818 .44639 m .23177 .44938 L .2214 .45068 L p F P
0 g
s
.541 .753 .975 r
.21718 .44794 m .22818 .44639 L p .2214 .45068 L F P
0 g
s
.541 .753 .975 r
.2214 .45068 m .2199 .45007 L .21718 .44794 L p F P
0 g
s
.163 0 .179 r
.56231 .3565 m .55657 .3602 L .56327 .35273 L p F P
0 g
s
.163 0 .179 r
.56327 .35273 m .56347 .3526 L .56231 .3565 L p F P
0 g
s
.771 .287 0 r
.1882 .30651 m .18942 .30844 L .19312 .31192 L p F P
0 g
s
.784 .303 0 r
.19202 .31267 m .19572 .31615 L .19312 .31192 L p F P
0 g
s
.784 .303 0 r
.19312 .31192 m .18942 .30844 L .19202 .31267 L p F P
0 g
s
.606 .471 .671 r
.49718 .43356 m .49663 .43094 L .48486 .43432 L p F P
0 g
s
.606 .471 .671 r
.48486 .43432 m .4856 .43776 L .49718 .43356 L p F P
0 g
s
.795 .63 .677 r
.30845 .43431 m .30368 .43291 L .30579 .43906 L closepath p F P
0 g
s
.704 .984 .83 r
.72322 .38388 m .72132 .38533 L .72264 .38398 L closepath p F P
0 g
s
.714 .987 .857 r
.72063 .3841 m .72264 .38398 L .72132 .38533 L p F P
0 g
s
.714 .987 .857 r
.71454 .38862 m .72063 .3841 L p .72132 .38533 L F P
0 g
s
.714 .987 .857 r
.71068 .39264 m .71454 .38862 L p .72132 .38533 L F P
0 g
s
.854 .54 .457 r
.26483 .39596 m .27078 .39853 L .27008 .39349 L p F P
0 g
s
.854 .54 .457 r
.27008 .39349 m .2642 .39089 L .26483 .39596 L p F P
0 g
s
0 0 0 r
.60774 .30368 m .60682 .30486 L .60966 .30157 L closepath p F P
0 g
s
0 0 0 r
.79979 .29548 m .79864 .29845 L .80144 .29246 L closepath p F P
0 g
s
.094 0 .151 r
.57224 .34714 m .57262 .34596 L .56347 .3526 L p F P
0 g
s
.094 0 .151 r
.56839 .35204 m .57224 .34714 L p .56347 .3526 L F P
0 g
s
.094 0 .151 r
.56347 .3526 m .56231 .3565 L .56839 .35204 L p F P
0 g
s
.72 .988 .828 r
.73252 .37647 m .72322 .38388 L .72264 .38398 L p F P
0 g
s
.026 .029 .523 r
.81645 .23797 m .81443 .24309 L .81299 .23826 L p F P
0 g
s
.026 .029 .523 r
.81299 .23826 m .81497 .23315 L .81645 .23797 L p F P
0 g
s
.504 .292 .524 r
.51781 .41073 m .51779 .40535 L .50679 .40964 L p F P
0 g
s
.504 .292 .524 r
.50679 .40964 m .50679 .41502 L .51781 .41073 L p F P
0 g
s
.703 .94 .638 r
.62716 .28083 m .62712 .28089 L .62969 .279 L p F P
0 g
s
.703 .94 .638 r
.62969 .279 m .63375 .27341 L .62716 .28083 L p F P
0 g
s
.712 .956 .681 r
.76359 .34635 m .75946 .35191 L .76659 .34429 L p F P
0 g
s
.712 .956 .681 r
.76713 .34257 m .76359 .34635 L p .76659 .34429 L F P
0 g
s
.712 .956 .681 r
.76659 .34429 m .76846 .34181 L .76713 .34257 L p F P
0 g
s
.648 .766 .935 r
.52131 .45506 m .53295 .45154 L .53603 .45468 L p F P
0 g
s
.646 .728 .909 r
.53295 .45154 m .52131 .45506 L .5182 .4512 L p F P
0 g
s
.889 .502 .292 r
.23421 .36223 m .23901 .36524 L .23746 .36055 L p F P
0 g
s
.889 .502 .292 r
.23303 .35856 m .23421 .36223 L p .23746 .36055 L F P
0 g
s
.889 .502 .292 r
.23746 .36055 m .23432 .35855 L .23303 .35856 L p F P
0 g
s
.794 .593 .629 r
.30107 .43226 m .30269 .42835 L .30222 .42585 L p F P
0 g
s
.794 .593 .629 r
.29367 .43021 m .30107 .43226 L p .30222 .42585 L F P
0 g
s
.794 .593 .629 r
.30222 .42585 m .29593 .42416 L .29367 .43021 L p F P
0 g
s
.036 .453 .876 r
.09477 .39896 m .09238 .398 L .09621 .40135 L p F P
0 g
s
.036 .453 .876 r
.09621 .40135 m .09854 .40229 L .09477 .39896 L p F P
0 g
s
.649 .814 .963 r
.56243 .44974 m .55074 .45362 L .54769 .45102 L p F P
0 g
s
.647 .805 .959 r
.53603 .45468 m .54769 .45102 L .55074 .45362 L p F P
0 g
s
.695 .907 .556 r
.78006 .32784 m .77855 .32926 L .78236 .32429 L closepath p F P
0 g
s
.629 .553 .75 r
.48666 .44163 m .48874 .44732 L .50032 .44349 L p F P
0 g
s
.64 .603 .796 r
.50228 .44773 m .50032 .44349 L .48874 .44732 L p F P
0 g
s
.647 .775 .942 r
.54769 .45102 m .53603 .45468 L .53295 .45154 L p F P
0 g
s
.798 .316 0 r
.19831 .3204 m .20218 .3238 L .19957 .31956 L p F P
0 g
s
.798 .316 0 r
.19957 .31956 m .19572 .31615 L .19831 .3204 L p F P
0 g
s
.438 .507 .833 r
.80361 .20223 m .79925 .20084 L .79641 .19489 L p F P
0 g
s
.765 .867 .924 r
.72315 .19707 m .72261 .19661 L .72359 .19601 L closepath p F P
0 g
s
.666 .91 .978 r
.60683 .44198 m .6065 .44184 L .60833 .44106 L closepath p F P
0 g
s
.617 .504 .703 r
.49844 .43827 m .49718 .43356 L .4856 .43776 L p F P
0 g
s
.617 .504 .703 r
.4856 .43776 m .48666 .44163 L .49844 .43827 L p F P
0 g
s
.469 .725 .981 r
.2199 .45007 m .21718 .44794 L .21596 .44799 L closepath p F P
0 g
s
.57 .851 .517 r
.62709 .28091 m .62712 .28089 L .62275 .28677 L p F P
0 g
s
.57 .851 .517 r
.62102 .28811 m .62709 .28091 L p .62275 .28677 L F P
0 g
s
.57 .851 .517 r
.61755 .29246 m .62102 .28811 L p .62275 .28677 L F P
0 g
s
.57 .851 .517 r
.62275 .28677 m .61833 .29167 L .61755 .29246 L p F P
0 g
s
.291 .02 .318 r
.54087 .37655 m .54041 .37897 L .54355 .37501 L closepath p F P
0 g
s
.213 0 .236 r
.56122 .3605 m .56231 .3565 L .55657 .3602 L p F P
0 g
s
.213 0 .236 r
.5517 .36666 m .56122 .3605 L p .55657 .3602 L F P
0 g
s
.213 0 .236 r
.55657 .3602 m .55197 .36559 L .5517 .36666 L p F P
0 g
s
.685 .957 .949 r
.6592 .42128 m .65132 .42548 L .65736 .42087 L closepath p F P
0 g
s
.692 .947 .958 r
.65642 .42059 m .65736 .42087 L .65132 .42548 L p F P
0 g
s
.692 .947 .958 r
.64464 .42666 m .65642 .42059 L p .65132 .42548 L F P
0 g
s
.837 .546 .495 r
.27105 .40372 m .27743 .40615 L .27709 .40097 L p F P
0 g
s
.837 .546 .495 r
.27709 .40097 m .27078 .39853 L .27105 .40372 L p F P
0 g
s
.72 .988 .828 r
.73232 .37496 m .73412 .37472 L .73252 .37647 L p F P
0 g
s
.72 .988 .828 r
.72671 .37944 m .73232 .37496 L p .73252 .37647 L F P
0 g
s
.72 .988 .828 r
.72264 .38398 m .72671 .37944 L p .73252 .37647 L F P
0 g
s
.708 .981 .797 r
.73487 .37452 m .73252 .37647 L .73412 .37472 L closepath p F P
0 g
s
.74 .821 .914 r
.74406 .1886 m .74898 .1861 L .74627 .18298 L p F P
0 g
s
.74 .821 .914 r
.74627 .18298 m .74501 .18367 L .74406 .1886 L p F P
0 g
s
.728 .833 .93 r
.73441 .18939 m .74501 .18367 L .74406 .1886 L p F P
0 g
s
.728 .971 .72 r
.75592 .35414 m .76359 .34635 L .75946 .35191 L p F P
0 g
s
.728 .971 .72 r
.75572 .35441 m .75592 .35414 L p .75946 .35191 L F P
0 g
s
.728 .971 .72 r
.75946 .35191 m .75804 .35334 L .75572 .35441 L p F P
0 g
s
.787 .593 .637 r
.30269 .42835 m .30107 .43226 L .30368 .43291 L closepath p F P
0 g
s
.862 .411 .076 r
.21293 .33469 m .21244 .33369 L .20877 .3313 L p F P
0 g
s
.724 .985 .796 r
.74247 .36798 m .73487 .37452 L .73412 .37472 L p F P
0 g
s
.882 .507 .326 r
.24041 .37 m .24548 .37291 L .24401 .36817 L p F P
0 g
s
.882 .507 .326 r
.24401 .36817 m .23901 .36524 L .24041 .37 L p F P
0 g
s
.711 .967 .721 r
.75804 .35334 m .75139 .35981 L .75572 .35441 L closepath p F P
0 g
s
.729 .988 .884 r
.71068 .39264 m .70891 .39263 L .71454 .38862 L closepath p F P
0 g
s
.629 .553 .75 r
.50032 .44349 m .49844 .43827 L .48666 .44163 L p F P
0 g
s
0 0 .427 r
.81514 .24817 m .81398 .251 L .8134 .24561 L p F P
0 g
s
0 0 .427 r
.8134 .24561 m .81443 .24309 L .81514 .24817 L p F P
0 g
s
.589 .752 .955 r
.23535 .4523 m .24642 .45006 L .24997 .45315 L p F P
0 g
s
.603 .751 .948 r
.24642 .45006 m .23535 .4523 L .23177 .44938 L p F P
0 g
s
.72 .982 .904 r
.69823 .40071 m .69718 .40063 L .70069 .3983 L closepath p F P
0 g
s
.757 .664 .759 r
.30675 .44151 m .30431 .44096 L .29561 .44907 L p F P
0 g
s
.77 .633 .709 r
.30579 .43906 m .30431 .44096 L .30675 .44151 L closepath p F P
0 g
s
.674 .9 .977 r
.60833 .44106 m .6065 .44184 L .60358 .44038 L p F P
0 g
s
.659 .896 .981 r
.59184 .44508 m .60358 .44038 L .6065 .44184 L p F P
0 g
s
0 0 0 r
.80426 .28719 m .80144 .29246 L .80387 .28634 L p F P
0 g
s
0 0 0 r
.80387 .28634 m .80675 .28104 L .80426 .28719 L p F P
0 g
s
.71 .976 .76 r
.74648 .36438 m .74247 .36798 L .74514 .36486 L closepath p F P
0 g
s
.724 .985 .796 r
.74398 .36511 m .74514 .36486 L .74247 .36798 L p F P
0 g
s
.724 .985 .796 r
.73751 .37068 m .74398 .36511 L p .74247 .36798 L F P
0 g
s
.724 .985 .796 r
.73412 .37472 m .73751 .37068 L p .74247 .36798 L F P
0 g
s
.727 .98 .759 r
.7556 .35445 m .75572 .35441 L .75139 .35981 L p F P
0 g
s
.727 .98 .759 r
.74718 .36227 m .7556 .35445 L p .75139 .35981 L F P
0 g
s
.727 .98 .759 r
.74514 .36486 m .74718 .36227 L p .75139 .35981 L F P
0 g
s
.727 .98 .759 r
.75139 .35981 m .74648 .36438 L .74514 .36486 L p F P
0 g
s
.807 .323 0 r
.20477 .32807 m .20218 .3238 L .20621 .32714 L p F P
0 g
s
.807 .323 0 r
.2082 .33088 m .20477 .32807 L p .20621 .32714 L F P
0 g
s
.807 .323 0 r
.20621 .32714 m .20877 .3313 L .2082 .33088 L p F P
0 g
s
.585 .858 .521 r
.61833 .29167 m .61609 .2942 L .61755 .29246 L closepath p F P
0 g
s
.355 .671 .975 r
.17017 .43628 m .17848 .43692 L .18326 .43985 L p F P
0 g
s
.365 .673 .975 r
.17848 .43692 m .17017 .43628 L .16647 .43343 L p F P
0 g
s
.818 .934 .907 r
.69785 .21266 m .69651 .21195 L .69901 .21 L closepath p F P
0 g
s
.628 .818 .402 r
.79058 .31199 m .79477 .3053 L .79162 .31063 L p F P
0 g
s
.628 .818 .402 r
.78883 .31499 m .79058 .31199 L p .79162 .31063 L F P
0 g
s
.628 .818 .402 r
.79162 .31063 m .78978 .31355 L .78883 .31499 L p F P
0 g
s
.694 .976 .912 r
.68545 .40817 m .68471 .40862 L .68525 .40816 L closepath p F P
0 g
s
.699 .971 .927 r
.68273 .40776 m .68525 .40816 L .68471 .40862 L p F P
0 g
s
.699 .971 .927 r
.67352 .41328 m .68273 .40776 L p .68471 .40862 L F P
0 g
s
.699 .971 .927 r
.67165 .4149 m .67352 .41328 L p .68471 .40862 L F P
0 g
s
.78 .626 .689 r
.30431 .44096 m .30579 .43906 L .30368 .43291 L p F P
0 g
s
.841 .574 .534 r
.27881 .4121 m .28345 .41397 L .28372 .40858 L p F P
0 g
s
.841 .574 .534 r
.28372 .40858 m .27912 .40674 L .27881 .4121 L p F P
0 g
s
.252 0 .251 r
.55197 .36559 m .55005 .3676 L .5517 .36666 L closepath p F P
0 g
s
.559 .819 .454 r
.61488 .2954 m .61532 .29485 L .61513 .29508 L p F P
0 g
s
.574 .847 .504 r
.61488 .2954 m .60966 .30157 L .61335 .29735 L p F P
0 g
s
0 0 0 r
.60907 .30258 m .61488 .2954 L .60966 .30157 L p F P
0 g
s
.559 .819 .454 r
.61513 .29508 m .61321 .29741 L p .61488 .2954 L F P
0 g
s
.574 .847 .504 r
.61335 .29735 m .61609 .2942 L p .61488 .2954 L F P
0 g
s
.574 .847 .504 r
.61557 .29456 m .61488 .2954 L p .61609 .2942 L F P
0 g
s
.574 .847 .504 r
.61609 .2942 m .61755 .29246 L .61557 .29456 L p F P
0 g
s
.765 .875 .927 r
.72359 .19601 m .72261 .19661 L .71991 .19436 L p F P
0 g
s
.224 .592 .948 r
.1342 .42113 m .13722 .42175 L .14159 .42486 L p F P
0 g
s
.244 .602 .952 r
.1447 .42318 m .13722 .42175 L .14159 .42486 L p F P
0 g
s
.244 .602 .952 r
.14159 .42486 m .14844 .42618 L .1447 .42318 L p F P
0 g
s
0 0 .342 r
.81419 .2559 m .81289 .25866 L .81288 .25334 L p F P
0 g
s
0 0 .342 r
.81288 .25334 m .81398 .251 L .81419 .2559 L p F P
0 g
s
.711 .98 .909 r
.6945 .40041 m .69718 .40063 L .68545 .40817 L p F P
0 g
s
.711 .98 .909 r
.69149 .40234 m .6945 .40041 L p .68545 .40817 L F P
0 g
s
.711 .98 .909 r
.68545 .40817 m .68525 .40816 L .69149 .40234 L p F P
0 g
s
.738 .992 .861 r
.72264 .38398 m .72063 .3841 L .72671 .37944 L closepath p F P
0 g
s
.449 .219 .473 r
.52326 .40289 m .51779 .40535 L .51806 .40029 L p F P
0 g
s
.449 .219 .473 r
.51806 .40029 m .52657 .39646 L .52326 .40289 L p F P
0 g
s
.873 .52 .378 r
.2575 .38217 m .25775 .38322 L .2568 .38272 L closepath p F P
0 g
s
.277 0 .289 r
.55078 .3709 m .54355 .37501 L .55005 .3676 L p F P
0 g
s
.277 0 .289 r
.55005 .3676 m .5517 .36666 L .55078 .3709 L p F P
0 g
s
.78 .626 .689 r
.29665 .439 m .30431 .44096 L p .30368 .43291 L F P
0 g
s
.78 .626 .689 r
.30368 .43291 m .30107 .43226 L .29665 .439 L p F P
0 g
s
.872 .511 .363 r
.24675 .37773 m .25215 .38052 L .25079 .37573 L p F P
0 g
s
.872 .511 .363 r
.25079 .37573 m .24548 .37291 L .24675 .37773 L p F P
0 g
s
.669 .914 .976 r
.61825 .43674 m .60833 .44106 L .61641 .43595 L closepath p F P
0 g
s
.674 .9 .977 r
.61535 .43544 m .61641 .43595 L .60833 .44106 L p F P
0 g
s
.674 .9 .977 r
.60358 .44038 m .61535 .43544 L p .60833 .44106 L F P
0 g
s
.765 .875 .927 r
.71991 .19436 m .72552 .19075 L .72359 .19601 L p F P
0 g
s
.779 .877 .919 r
.72359 .19601 m .73441 .18939 L .7317 .18674 L p F P
0 g
s
.779 .877 .919 r
.7317 .18674 m .72552 .19075 L .72359 .19601 L p F P
0 g
s
.755 .714 .814 r
.29561 .44907 m .29269 .44807 L .29418 .45012 L closepath p F P
0 g
s
.641 .705 .893 r
.76367 .18472 m .77578 .18133 L .77852 .18556 L p F P
0 g
s
.655 .721 .898 r
.77578 .18133 m .76367 .18472 L .76095 .1811 L p F P
0 g
s
.693 .762 .905 r
.74898 .1861 m .76095 .1811 L .76367 .18472 L p F P
0 g
s
.127 .146 .61 r
.81698 .22801 m .81497 .23315 L .81264 .22862 L p F P
0 g
s
.127 .146 .61 r
.81264 .22862 m .81458 .22349 L .81698 .22801 L p F P
0 g
s
.769 .662 .744 r
.29269 .44807 m .29561 .44907 L .30431 .44096 L p F P
0 g
s
.769 .662 .744 r
.2908 .4452 m .29269 .44807 L p .30431 .44096 L F P
0 g
s
.769 .662 .744 r
.30431 .44096 m .29665 .439 L .2908 .4452 L p F P
0 g
s
.572 .41 .624 r
.50806 .42714 m .50717 .4208 L .49576 .42462 L p F P
0 g
s
.572 .41 .624 r
.49576 .42462 m .49663 .43094 L .50806 .42714 L p F P
0 g
s
0 0 .104 r
.81101 .26993 m .80855 .27512 L .80976 .2694 L p F P
0 g
s
0 0 .104 r
.80976 .2694 m .81224 .26419 L .81101 .26993 L p F P
0 g
s
.292 .636 .965 r
.15216 .42912 m .15661 .42974 L .1612 .43275 L p F P
0 g
s
.306 .641 .967 r
.16277 .43051 m .15661 .42974 L .1612 .43275 L p F P
0 g
s
.306 .641 .967 r
.1612 .43275 m .16647 .43343 L .16277 .43051 L p F P
0 g
s
.862 .411 .076 r
.20877 .3313 m .20882 .3314 L .21293 .33469 L p F P
0 g
s
.875 .436 .113 r
.21083 .33589 m .21498 .33917 L .21293 .33469 L p F P
0 g
s
.875 .436 .113 r
.21293 .33469 m .20882 .3314 L .21083 .33589 L p F P
0 g
s
.155 .543 .925 r
.11632 .41221 m .11971 .41316 L .12384 .41636 L p F P
0 g
s
.178 .556 .932 r
.12671 .41497 m .11971 .41316 L .12384 .41636 L p F P
0 g
s
.178 .556 .932 r
.12384 .41636 m .13046 .41809 L .12671 .41497 L p F P
0 g
s
.717 .974 .926 r
.68525 .40816 m .68273 .40776 L .69149 .40234 L closepath p F P
0 g
s
.475 .725 .979 r
.20267 .44562 m .21081 .4452 L .21596 .44799 L p F P
0 g
s
.486 .727 .978 r
.21081 .4452 m .20267 .44562 L .19902 .44282 L p F P
0 g
s
.827 .587 .577 r
.28249 .41959 m .28896 .42196 L .28999 .41632 L p F P
0 g
s
.827 .587 .577 r
.28999 .41632 m .28345 .41397 L .28249 .41959 L p F P
0 g
s
.66 .746 .914 r
.26114 .44978 m .24997 .45315 L .24642 .45006 L p F P
0 g
s
.643 .749 .926 r
.24997 .45315 m .26114 .44978 L .26465 .45318 L p F P
0 g
s
.799 .906 .916 r
.7097 .20382 m .70818 .20278 L .71092 .20083 L closepath p F P
0 g
s
.68 .935 .967 r
.63303 .43253 m .63288 .43248 L .6336 .43213 L closepath p F P
0 g
s
.705 .774 .906 r
.76095 .1811 m .74898 .1861 L .74627 .18298 L p F P
0 g
s
.603 .807 .396 r
.78978 .31355 m .7873 .31736 L .78883 .31499 L closepath p F P
0 g
s
.809 .604 .626 r
.2869 .42794 m .29367 .43021 L .29593 .42416 L p F P
0 g
s
.809 .604 .626 r
.29593 .42416 m .28896 .42196 L .2869 .42794 L p F P
0 g
s
.301 .637 .965 r
.15661 .42974 m .15216 .42912 L .14844 .42618 L p F P
0 g
s
0 0 0 r
.60573 .30638 m .60907 .30258 L p .60966 .30157 L F P
0 g
s
0 0 0 r
.60966 .30157 m .60682 .30486 L .60573 .30638 L p F P
0 g
s
.689 .928 .969 r
.6336 .43213 m .63288 .43248 L .63002 .43136 L p F P
0 g
s
.673 .925 .973 r
.61825 .43674 m .63002 .43136 L .63288 .43248 L p F P
0 g
s
.084 .489 .897 r
.09854 .40229 m .10362 .40408 L .10754 .40738 L p F P
0 g
s
.095 .491 .9 r
.10362 .40408 m .09854 .40229 L .09477 .39896 L p F P
0 g
s
.79 .629 .682 r
.28974 .43679 m .29665 .439 L .30107 .43226 L p F P
0 g
s
.79 .629 .682 r
.30107 .43226 m .29367 .43021 L .28974 .43679 L p F P
0 g
s
.878 .445 .15 r
.21695 .34368 m .22131 .34688 L .21929 .34238 L p F P
0 g
s
.878 .445 .15 r
.21929 .34238 m .21498 .33917 L .21695 .34368 L p F P
0 g
s
.875 .54 .413 r
.25413 .38583 m .25863 .38819 L .25775 .38322 L p F P
0 g
s
.875 .54 .413 r
.25775 .38322 m .2568 .38272 L .25413 .38583 L p F P
0 g
s
.735 .744 .858 r
.28822 .44702 m .27939 .45222 L .27593 .44831 L p F P
0 g
s
.691 .733 .883 r
.26465 .45318 m .27593 .44831 L .27939 .45222 L p F P
0 g
s
.726 .712 .838 r
.29269 .44807 m .28822 .44702 L .27939 .45222 L p F P
0 g
s
.314 .046 .337 r
.54998 .37528 m .55078 .3709 L .54355 .37501 L p F P
0 g
s
.314 .046 .337 r
.54007 .38094 m .54998 .37528 L p .54355 .37501 L F P
0 g
s
.314 .046 .337 r
.54355 .37501 m .54041 .37897 L .54007 .38094 L p F P
0 g
s
0 0 .042 r
.57386 .34496 m .57262 .34596 L .57397 .34231 L p F P
0 g
s
0 0 .042 r
.57397 .34231 m .57946 .33783 L .57386 .34496 L p F P
0 g
s
.699 .96 .946 r
.66821 .4141 m .67097 .41475 L .6592 .42128 L p F P
0 g
s
.699 .96 .946 r
.66008 .41862 m .66821 .4141 L p .6592 .42128 L F P
0 g
s
.699 .96 .946 r
.6592 .42128 m .65736 .42087 L .66008 .41862 L p F P
0 g
s
.707 .726 .865 r
.27593 .44831 m .26465 .45318 L .26114 .44978 L p F P
0 g
s
.645 .676 .865 r
.50346 .44992 m .51508 .44648 L .5182 .4512 L p F P
0 g
s
.639 .629 .824 r
.50228 .44773 m .50346 .44992 L .51508 .44648 L p F P
0 g
s
.682 .941 .963 r
.64464 .42666 m .6336 .43213 L .6422 .4259 L closepath p F P
0 g
s
.689 .928 .969 r
.64181 .42575 m .6422 .4259 L .6336 .43213 L p F P
0 g
s
.689 .928 .969 r
.63002 .43136 m .64181 .42575 L p .6336 .43213 L F P
0 g
s
.661 .887 .98 r
.60358 .44038 m .59184 .44508 L .58888 .44342 L p F P
0 g
s
.869 .459 .247 r
.23432 .35855 m .23303 .35856 L .23263 .35755 L closepath p F P
0 g
s
.215 0 .267 r
.56069 .36273 m .56122 .3605 L .5517 .36666 L p F P
0 g
s
.215 0 .267 r
.55829 .36598 m .56069 .36273 L p .5517 .36666 L F P
0 g
s
.215 0 .267 r
.5517 .36666 m .55078 .3709 L .55829 .36598 L p F P
0 g
s
0 0 0 r
.80775 .27676 m .80722 .27956 L .80855 .27512 L closepath p F P
0 g
s
.592 .676 .898 r
.7823 .18509 m .77852 .18556 L .77578 .18133 L p F P
0 g
s
0 0 0 r
.60682 .30486 m .60336 .3089 L .60573 .30638 L closepath p F P
0 g
s
.745 .993 .834 r
.73412 .37472 m .73232 .37496 L .73751 .37068 L closepath p F P
0 g
s
0 0 0 r
.59586 .31751 m .5953 .31847 L .59719 .31619 L closepath p F P
0 g
s
.112 .507 .908 r
.10879 .40578 m .10362 .40408 L .10754 .40738 L p F P
0 g
s
.112 .507 .908 r
.10754 .40738 m .11256 .40904 L .10879 .40578 L p F P
0 g
s
.502 .567 .854 r
.79622 .19487 m .7963 .19466 L .79641 .19489 L closepath p F P
0 g
s
.234 .593 .949 r
.13722 .42175 m .1342 .42113 L .13046 .41809 L p F P
0 g
s
.225 .261 .689 r
.8161 .21952 m .81458 .22349 L .81118 .21932 L p F P
0 g
s
.225 .261 .689 r
.81534 .21679 m .8161 .21952 L p .81118 .21932 L F P
0 g
s
.225 .261 .689 r
.81118 .21932 m .81307 .21419 L .81534 .21679 L p F P
0 g
s
.165 .544 .927 r
.11971 .41316 m .11632 .41221 L .11256 .40904 L p F P
0 g
s
.665 .874 .499 r
.78581 .31888 m .78236 .32429 L .7873 .31736 L p F P
0 g
s
.665 .874 .499 r
.78756 .31641 m .78581 .31888 L p .7873 .31736 L F P
0 g
s
.665 .874 .499 r
.7873 .31736 m .78883 .31499 L .78756 .31641 L p F P
0 g
s
.86 .516 .4 r
.25325 .38541 m .25413 .38583 L .2568 .38272 L p F P
0 g
s
.86 .516 .4 r
.2568 .38272 m .25215 .38052 L .25325 .38541 L p F P
0 g
s
.866 .552 .454 r
.2592 .39327 m .26483 .39596 L .2642 .39089 L p F P
0 g
s
.866 .552 .454 r
.2642 .39089 m .25863 .38819 L .2592 .39327 L p F P
0 g
s
.438 .507 .833 r
.79641 .19489 m .80517 .19716 L .80361 .20223 L p F P
0 g
s
.42 .52 .854 r
.7963 .19466 m .79641 .19489 L .80517 .19716 L p F P
0 g
s
.742 .695 .807 r
.2908 .4452 m .28822 .44702 L .29269 .44807 L closepath p F P
0 g
s
.657 .866 .978 r
.57758 .44807 m .57714 .4478 L .58035 .44662 L closepath p F P
0 g
s
.878 .453 .188 r
.22323 .35143 m .22783 .35453 L .22584 .35 L p F P
0 g
s
.878 .453 .188 r
.22584 .35 m .22131 .34688 L .22323 .35143 L p F P
0 g
s
.737 .962 .681 r
.76846 .34181 m .76713 .34257 L .77057 .33877 L closepath p F P
0 g
s
.364 .674 .976 r
.18088 .43707 m .17848 .43692 L .18326 .43985 L p F P
0 g
s
.364 .674 .976 r
.18326 .43985 m .18455 .43994 L .18088 .43707 L p F P
0 g
s
.42 .52 .854 r
.80625 .19185 m .79738 .18992 L .7963 .19466 L p F P
0 g
s
.42 .52 .854 r
.80664 .19272 m .80625 .19185 L p .7963 .19466 L F P
0 g
s
.42 .52 .854 r
.80517 .19716 m .80664 .19272 L p .7963 .19466 L F P
0 g
s
.483 .566 .864 r
.79361 .18947 m .79738 .18992 L .7963 .19466 L closepath p F P
0 g
s
.472 .722 .979 r
.21356 .44504 m .21081 .4452 L .21596 .44799 L p F P
0 g
s
.472 .722 .979 r
.21596 .44799 m .21718 .44794 L .21356 .44504 L p F P
0 g
s
.351 .076 .349 r
.54041 .37897 m .53725 .38236 L .54007 .38094 L closepath p F P
0 g
s
.388 .144 .419 r
.52915 .39073 m .52885 .39368 L .53147 .38954 L closepath p F P
0 g
s
.833 .997 .842 r
.66197 .24359 m .6617 .24359 L .66227 .24305 L closepath p F P
0 g
s
0 0 0 r
.6033 .30975 m .59719 .31619 L .60336 .3089 L p F P
0 g
s
0 0 0 r
.60404 .30882 m .6033 .30975 L p .60336 .3089 L F P
0 g
s
0 0 0 r
.60336 .3089 m .60573 .30638 L .60404 .30882 L p F P
0 g
s
.724 .982 .907 r
.70069 .3983 m .69718 .40063 L .6945 .40041 L p F P
0 g
s
.596 .857 .51 r
.61755 .29246 m .61557 .29456 L .62102 .28811 L closepath p F P
0 g
s
0 0 0 r
.80126 .2935 m .80426 .28719 L .80144 .29246 L p F P
0 g
s
0 0 0 r
.79858 .2986 m .80126 .2935 L p .80144 .29246 L F P
0 g
s
0 0 0 r
.80144 .29246 m .79864 .29845 L .79858 .2986 L p F P
0 g
s
.374 .115 .387 r
.53945 .38556 m .53147 .38954 L .53725 .38236 L p F P
0 g
s
.374 .115 .387 r
.53725 .38236 m .54007 .38094 L .53945 .38556 L p F P
0 g
s
.631 .595 .795 r
.50032 .44349 m .50228 .44773 L .51372 .44397 L p F P
0 g
s
.639 .629 .824 r
.51508 .44648 m .51372 .44397 L .50228 .44773 L p F P
0 g
s
.528 .342 .572 r
.51821 .41654 m .51781 .41073 L .50679 .41502 L p F P
0 g
s
.528 .342 .572 r
.50679 .41502 m .50717 .4208 L .51821 .41654 L p F P
0 g
s
.836 .984 .872 r
.67925 .22698 m .67328 .2324 L .67177 .23216 L p F P
0 g
s
.855 .982 .858 r
.67328 .2324 m .6705 .2351 L .67177 .23216 L closepath p F P
0 g
s
.857 .972 .866 r
.67925 .22698 m .68487 .22184 L .68215 .22091 L p F P
0 g
s
.857 .972 .866 r
.68215 .22091 m .68131 .22171 L .67925 .22698 L p F P
0 g
s
.836 .984 .872 r
.67294 .22972 m .68131 .22171 L .67925 .22698 L p F P
0 g
s
.836 .984 .872 r
.67177 .23216 m .67294 .22972 L p .67925 .22698 L F P
0 g
s
.83 .963 .893 r
.68865 .21865 m .68487 .22184 L .68215 .22091 L p F P
0 g
s
.856 .983 .854 r
.6651 .23755 m .66227 .24305 L .6705 .2351 L p F P
0 g
s
.856 .983 .854 r
.67055 .23198 m .6651 .23755 L p .6705 .2351 L F P
0 g
s
.856 .983 .854 r
.6705 .2351 m .67177 .23216 L .67055 .23198 L p F P
0 g
s
.826 .559 .536 r
.27716 .41153 m .27881 .4121 L .27912 .40674 L p F P
0 g
s
.826 .559 .536 r
.27912 .40674 m .27743 .40615 L .27716 .41153 L p F P
0 g
s
.707 .965 .94 r
.67165 .4149 m .67097 .41475 L .67352 .41328 L closepath p F P
0 g
s
.852 .559 .493 r
.26505 .40117 m .27105 .40372 L .27078 .39853 L p F P
0 g
s
.852 .559 .493 r
.27078 .39853 m .26483 .39596 L .26505 .40117 L p F P
0 g
s
.74 .842 .927 r
.74501 .18367 m .73441 .18939 L .7317 .18674 L p F P
0 g
s
.846 .956 .883 r
.68865 .21865 m .69651 .21195 L .69379 .21058 L p F P
0 g
s
.846 .956 .883 r
.69379 .21058 m .69065 .21339 L .68865 .21865 L p F P
0 g
s
.83 .963 .893 r
.68215 .22091 m .69065 .21339 L .68865 .21865 L p F P
0 g
s
.314 .365 .755 r
.8139 .21191 m .81307 .21419 L .80833 .21048 L p F P
0 g
s
.314 .365 .755 r
.81217 .20681 m .8139 .21191 L p .80833 .21048 L F P
0 g
s
.314 .365 .755 r
.80833 .21048 m .81011 .20536 L .81217 .20681 L p F P
0 g
s
.665 .848 .97 r
.58035 .44662 m .57714 .4478 L .57415 .4457 L p F P
0 g
s
.652 .844 .974 r
.56243 .44974 m .57415 .4457 L .57714 .4478 L p F P
0 g
s
.875 .461 .23 r
.22927 .35811 m .22783 .35453 L .23263 .35755 L p F P
0 g
s
.875 .461 .23 r
.23263 .35755 m .23303 .35856 L .22927 .35811 L p F P
0 g
s
.387 .452 .806 r
.81087 .20315 m .81011 .20536 L .80361 .20223 L p F P
0 g
s
.387 .452 .806 r
.80917 .19883 m .81087 .20315 L p .80361 .20223 L F P
0 g
s
.387 .452 .806 r
.80361 .20223 m .80517 .19716 L .80917 .19883 L p F P
0 g
s
0 0 .425 r
.81718 .24305 m .81514 .24817 L .81443 .24309 L p F P
0 g
s
0 0 .425 r
.81443 .24309 m .81645 .23797 L .81718 .24305 L p F P
0 g
s
.646 .728 .909 r
.5182 .4512 m .52985 .44779 L .53295 .45154 L p F P
0 g
s
.64 .682 .874 r
.52985 .44779 m .5182 .4512 L .51508 .44648 L p F P
0 g
s
.557 .744 .964 r
.22818 .44639 m .21718 .44794 L .21356 .44504 L p F P
0 g
s
.827 .998 .836 r
.65897 .24375 m .6651 .23755 L .66227 .24305 L p F P
0 g
s
.827 .998 .836 r
.66227 .24305 m .6617 .24359 L .65897 .24375 L p F P
0 g
s
.842 .999 .797 r
.65475 .25077 m .6617 .24359 L .65897 .24375 L p F P
0 g
s
.77 .981 .725 r
.63936 .26754 m .63862 .2679 L .6404 .26598 L closepath p F P
0 g
s
.717 .985 .888 r
.70891 .39263 m .70069 .3983 L .70646 .3926 L closepath p F P
0 g
s
.724 .982 .907 r
.70627 .39258 m .70646 .3926 L .70069 .3983 L p F P
0 g
s
.724 .982 .907 r
.6945 .40041 m .70627 .39258 L p .70069 .3983 L F P
0 g
s
.428 .705 .98 r
.18455 .43994 m .19537 .43996 L .19902 .44282 L p F P
0 g
s
.435 .705 .979 r
.19537 .43996 m .18455 .43994 L .18088 .43707 L p F P
0 g
s
.591 .459 .669 r
.5088 .43059 m .50806 .42714 L .49663 .43094 L p F P
0 g
s
.591 .459 .669 r
.49663 .43094 m .49718 .43356 L .5088 .43059 L p F P
0 g
s
.817 .939 .908 r
.69901 .21 m .69651 .21195 L .69379 .21058 L p F P
0 g
s
0 0 .319 r
.81518 .25348 m .81419 .2559 L .81398 .251 L p F P
0 g
s
0 0 .319 r
.81398 .251 m .81514 .24817 L .81518 .25348 L p F P
0 g
s
.787 .692 .761 r
.28744 .43961 m .28974 .43679 L .29665 .439 L p F P
0 g
s
.787 .692 .761 r
.29665 .439 m .2908 .4452 L .28744 .43961 L p F P
0 g
s
.831 .935 .897 r
.69901 .21 m .70818 .20278 L .70547 .20099 L p F P
0 g
s
.831 .935 .897 r
.70547 .20099 m .70091 .20475 L .69901 .21 L p F P
0 g
s
.817 .939 .908 r
.69379 .21058 m .70091 .20475 L .69901 .21 L p F P
0 g
s
.835 .568 .536 r
.27075 .40912 m .27716 .41153 L .27743 .40615 L p F P
0 g
s
.835 .568 .536 r
.27743 .40615 m .27105 .40372 L .27075 .40912 L p F P
0 g
s
.76 .695 .79 r
.28822 .44702 m .2908 .4452 L .28744 .43961 L p F P
0 g
s
.76 .695 .79 r
.28744 .43961 m .28105 .4449 L .28822 .44702 L p F P
0 g
s
.735 .744 .858 r
.27593 .44831 m .28105 .4449 L .28822 .44702 L p F P
0 g
s
0 0 0 r
.59781 .31684 m .6033 .30975 L .59719 .31619 L p F P
0 g
s
0 0 0 r
.59414 .32062 m .59781 .31684 L p .59719 .31619 L F P
0 g
s
0 0 0 r
.59719 .31619 m .5953 .31847 L .59414 .32062 L p F P
0 g
s
.892 .517 .321 r
.23555 .36702 m .24041 .37 L .23901 .36524 L p F P
0 g
s
.892 .517 .321 r
.23901 .36524 m .23421 .36223 L .23555 .36702 L p F P
0 g
s
.842 .999 .797 r
.65897 .24375 m .65755 .24529 L .65475 .25077 L p F P
0 g
s
.805 .998 .787 r
.65056 .25284 m .65755 .24529 L .65475 .25077 L p F P
0 g
s
.805 .998 .787 r
.64886 .2558 m .65056 .25284 L p .65475 .25077 L F P
0 g
s
.805 .998 .787 r
.65475 .25077 m .65016 .25545 L .64886 .2558 L p F P
0 g
s
.789 .309 0 r
.1946 .31693 m .19831 .3204 L .19572 .31615 L p F P
0 g
s
.789 .309 0 r
.19572 .31615 m .19202 .31267 L .1946 .31693 L p F P
0 g
s
.698 .909 .559 r
.78033 .326 m .78581 .31888 L .78236 .32429 L p F P
0 g
s
.698 .909 .559 r
.77791 .32987 m .78033 .326 L p .78236 .32429 L F P
0 g
s
.698 .909 .559 r
.78236 .32429 m .77855 .32926 L .77791 .32987 L p F P
0 g
s
.652 .825 .966 r
.57415 .4457 m .56243 .44974 L .55939 .44724 L p F P
0 g
s
.649 .814 .963 r
.54769 .45102 m .55939 .44724 L .56243 .44974 L p F P
0 g
s
.678 .917 .974 r
.62714 .43017 m .63002 .43136 L .61825 .43674 L p F P
0 g
s
.678 .917 .974 r
.62053 .43316 m .62714 .43017 L p .61825 .43674 L F P
0 g
s
.678 .917 .974 r
.61825 .43674 m .61641 .43595 L .62053 .43316 L p F P
0 g
s
.647 .775 .942 r
.53295 .45154 m .54463 .44799 L .54769 .45102 L p F P
0 g
s
.644 .739 .918 r
.54463 .44799 m .53295 .45154 L .52985 .44779 L p F P
0 g
s
0 0 0 r
.80921 .27585 m .81101 .26993 L .80855 .27512 L p F P
0 g
s
0 0 0 r
.80704 .28048 m .80921 .27585 L p .80855 .27512 L F P
0 g
s
0 0 0 r
.80855 .27512 m .80722 .27956 L .80704 .28048 L p F P
0 g
s
.601 .492 .702 r
.50986 .43447 m .5088 .43059 L .49718 .43356 L p F P
0 g
s
.601 .492 .702 r
.49718 .43356 m .49844 .43827 L .50986 .43447 L p F P
0 g
s
.401 .159 .429 r
.53899 .39037 m .53945 .38556 L .53147 .38954 L p F P
0 g
s
.401 .159 .429 r
.52868 .39554 m .53899 .39037 L p .53147 .38954 L F P
0 g
s
.401 .159 .429 r
.53147 .38954 m .52885 .39368 L .52868 .39554 L p F P
0 g
s
.619 .545 .749 r
.49844 .43827 m .50032 .44349 L .51195 .44018 L p F P
0 g
s
.631 .595 .795 r
.51372 .44397 m .51195 .44018 L .50032 .44349 L p F P
0 g
s
.592 .676 .898 r
.77578 .18133 m .78354 .18008 L .7823 .18509 L p F P
0 g
s
.565 .637 .881 r
.78805 .17948 m .78354 .18008 L .7823 .18509 L p F P
0 g
s
.565 .637 .881 r
.7823 .18509 m .79082 .18435 L .78805 .17948 L p F P
0 g
s
.826 .998 .781 r
.65016 .25545 m .6474 .25842 L .64886 .2558 L closepath p F P
0 g
s
0 0 .224 r
.81405 .26035 m .81224 .26419 L .81289 .25866 L p F P
0 g
s
0 0 .224 r
.81289 .25866 m .81419 .2559 L .81405 .26035 L p F P
0 g
s
0 0 0 r
.5953 .31847 m .59115 .32344 L .59414 .32062 L closepath p F P
0 g
s
.894 .504 .279 r
.23421 .36223 m .23303 .35856 L .22927 .35811 L p F P
0 g
s
.648 .787 .949 r
.55939 .44724 m .54769 .45102 L .54463 .44799 L p F P
0 g
s
.839 .599 .576 r
.27938 .41833 m .28249 .41959 L .28345 .41397 L p F P
0 g
s
.839 .599 .576 r
.28345 .41397 m .27881 .4121 L .27938 .41833 L p F P
0 g
s
.752 .992 .805 r
.74514 .36486 m .74398 .36511 L .74718 .36227 L closepath p F P
0 g
s
.662 .864 .976 r
.58888 .44342 m .58035 .44662 L .58759 .44259 L closepath p F P
0 g
s
.665 .848 .97 r
.5859 .44147 m .58759 .44259 L .58035 .44662 L p F P
0 g
s
.665 .848 .97 r
.57415 .4457 m .5859 .44147 L p .58035 .44662 L F P
0 g
s
.806 .638 .675 r
.28496 .43504 m .28974 .43679 L .29367 .43021 L p F P
0 g
s
.806 .638 .675 r
.28412 .43314 m .28496 .43504 L p .29367 .43021 L F P
0 g
s
.806 .638 .675 r
.29367 .43021 m .2869 .42794 L .28412 .43314 L p F P
0 g
s
.824 .997 .773 r
.64384 .26031 m .6404 .26598 L .6474 .25842 L p F P
0 g
s
.824 .997 .773 r
.64742 .25623 m .64384 .26031 L p .6474 .25842 L F P
0 g
s
.824 .997 .773 r
.6474 .25842 m .64886 .2558 L .64742 .25623 L p F P
0 g
s
.883 .523 .359 r
.24161 .37485 m .24675 .37773 L .24548 .37291 L p F P
0 g
s
.883 .523 .359 r
.24548 .37291 m .24041 .37 L .24161 .37485 L p F P
0 g
s
.799 .911 .917 r
.71092 .20083 m .70818 .20278 L .70547 .20099 L p F P
0 g
s
.824 .615 .62 r
.2812 .42576 m .2869 .42794 L .28896 .42196 L p F P
0 g
s
.824 .615 .62 r
.2809 .42465 m .2812 .42576 L p .28896 .42196 L F P
0 g
s
.824 .615 .62 r
.28896 .42196 m .28249 .41959 L .2809 .42465 L p F P
0 g
s
.804 .323 0 r
.20089 .32468 m .20477 .32807 L .20218 .3238 L p F P
0 g
s
.804 .323 0 r
.20218 .3238 m .19831 .3204 L .20089 .32468 L p F P
0 g
s
.114 0 .179 r
.5632 .35905 m .56122 .3605 L .56231 .3565 L p F P
0 g
s
.114 0 .179 r
.56231 .3565 m .56839 .35204 L .5632 .35905 L p F P
0 g
s
.619 .545 .749 r
.51195 .44018 m .50986 .43447 L .49844 .43827 L p F P
0 g
s
.731 .988 .885 r
.71454 .38862 m .70891 .39263 L .70646 .3926 L p F P
0 g
s
.713 .962 .943 r
.67352 .41328 m .67097 .41475 L .66821 .4141 L p F P
0 g
s
.323 .073 .372 r
.54931 .37982 m .54998 .37528 L .54007 .38094 L p F P
0 g
s
.323 .073 .372 r
.54007 .38094 m .53945 .38556 L .54931 .37982 L p F P
0 g
s
.234 .593 .949 r
.13046 .41809 m .13297 .4186 L .13722 .42175 L p F P
0 g
s
.252 .603 .953 r
.14097 .42011 m .13297 .4186 L .13722 .42175 L p F P
0 g
s
.252 .603 .953 r
.13722 .42175 m .1447 .42318 L .14097 .42011 L p F P
0 g
s
.603 .751 .948 r
.23177 .44938 m .24287 .44687 L .24642 .45006 L p F P
0 g
s
.617 .75 .941 r
.24287 .44687 m .23177 .44938 L .22818 .44639 L p F P
0 g
s
.474 .268 .519 r
.52315 .40833 m .51781 .41073 L .51779 .40535 L p F P
0 g
s
.474 .268 .519 r
.51779 .40535 m .52326 .40289 L .52315 .40833 L p F P
0 g
s
.676 .902 .556 r
.77855 .32926 m .77685 .33141 L .77791 .32987 L closepath p F P
0 g
s
.812 .908 .906 r
.71092 .20083 m .71991 .19436 L .7172 .19217 L p F P
0 g
s
.812 .908 .906 r
.7172 .19217 m .71261 .19564 L .71092 .20083 L p F P
0 g
s
.799 .911 .917 r
.70547 .20099 m .71261 .19564 L .71092 .20083 L p F P
0 g
s
.694 .944 .96 r
.65361 .41969 m .65642 .42059 L .64464 .42666 L p F P
0 g
s
.694 .944 .96 r
.64342 .42494 m .65361 .41969 L p .64464 .42666 L F P
0 g
s
.694 .944 .96 r
.64464 .42666 m .6422 .4259 L .64342 .42494 L p F P
0 g
s
0 0 0 r
.58417 .33162 m .58377 .33252 L .58525 .33065 L closepath p F P
0 g
s
0 0 0 r
.59239 .32391 m .58525 .33065 L .59115 .32344 L p F P
0 g
s
0 0 0 r
.59251 .32375 m .59239 .32391 L p .59115 .32344 L F P
0 g
s
0 0 0 r
.59115 .32344 m .59414 .32062 L .59251 .32375 L p F P
0 g
s
.301 .637 .965 r
.14844 .42618 m .15211 .42668 L .15661 .42974 L p F P
0 g
s
.315 .642 .967 r
.15906 .42752 m .15211 .42668 L .15661 .42974 L p F P
0 g
s
.315 .642 .967 r
.15661 .42974 m .16277 .43051 L .15906 .42752 L p F P
0 g
s
0 0 0 r
.79864 .29845 m .79849 .29875 L .79858 .2986 L closepath p F P
0 g
s
.365 .673 .975 r
.16647 .43343 m .17379 .43394 L .17848 .43692 L p F P
0 g
s
.373 .674 .975 r
.17379 .43394 m .16647 .43343 L .16277 .43051 L p F P
0 g
s
.86 .408 .054 r
.20877 .3313 m .20882 .3314 L .2082 .33088 L closepath p F P
0 g
s
.707 .971 .93 r
.68273 .40776 m .67352 .41328 L .68023 .40736 L closepath p F P
0 g
s
.713 .962 .943 r
.68001 .4073 m .68023 .40736 L .67352 .41328 L p F P
0 g
s
.713 .962 .943 r
.66821 .4141 m .68001 .4073 L p .67352 .41328 L F P
0 g
s
0 0 0 r
.79707 .30134 m .79477 .3053 L .79849 .29875 L p F P
0 g
s
0 0 0 r
.79849 .29875 m .79858 .2986 L .79707 .30134 L p F P
0 g
s
.872 .529 .398 r
.24777 .38265 m .25325 .38541 L .25215 .38052 L p F P
0 g
s
.872 .529 .398 r
.25215 .38052 m .24675 .37773 L .24777 .38265 L p F P
0 g
s
.754 .974 .708 r
.63734 .26771 m .64384 .26031 L .6404 .26598 L p F P
0 g
s
.754 .974 .708 r
.63651 .26903 m .63734 .26771 L p .6404 .26598 L F P
0 g
s
.754 .974 .708 r
.6404 .26598 m .63862 .2679 L .63651 .26903 L p F P
0 g
s
.72 .945 .639 r
.77428 .3333 m .77057 .33877 L .77685 .33141 L p F P
0 g
s
.72 .945 .639 r
.77621 .33102 m .77428 .3333 L p .77685 .33141 L F P
0 g
s
.72 .945 .639 r
.77685 .33141 m .77791 .32987 L .77621 .33102 L p F P
0 g
s
.88 .445 .11 r
.20683 .33254 m .21083 .33589 L .20882 .3314 L p F P
0 g
s
.88 .445 .11 r
.2051 .32866 m .20683 .33254 L p .20882 .3314 L F P
0 g
s
.88 .445 .11 r
.20882 .3314 m .2082 .33088 L .2051 .32866 L p F P
0 g
s
.434 .186 .437 r
.52885 .39368 m .52657 .39646 L .52868 .39554 L closepath p F P
0 g
s
.725 .989 .865 r
.72063 .3841 m .71454 .38862 L .71871 .38421 L closepath p F P
0 g
s
.731 .988 .885 r
.71802 .38418 m .71871 .38421 L .71454 .38862 L p F P
0 g
s
.731 .988 .885 r
.70685 .39219 m .71802 .38418 L p .71454 .38862 L F P
0 g
s
.731 .988 .885 r
.70646 .3926 m .70685 .39219 L p .71454 .38862 L F P
0 g
s
.697 .885 .504 r
.78883 .31499 m .78756 .31641 L .79058 .31199 L closepath p F P
0 g
s
.165 .544 .927 r
.11256 .40904 m .11568 .4099 L .11971 .41316 L p F P
0 g
s
.188 .557 .933 r
.12295 .41178 m .11568 .4099 L .11971 .41316 L p F P
0 g
s
.188 .557 .933 r
.11971 .41316 m .12671 .41497 L .12295 .41178 L p F P
0 g
s
.636 .791 .345 r
.79779 .29998 m .79707 .30134 L .79858 .2986 L p F P
0 g
s
.636 .791 .345 r
.79858 .2986 m .80126 .2935 L .79779 .29998 L p F P
0 g
s
.031 .034 .526 r
.81849 .23282 m .81645 .23797 L .81497 .23315 L p F P
0 g
s
.031 .034 .526 r
.81497 .23315 m .81698 .22801 L .81849 .23282 L p F P
0 g
s
.655 .721 .898 r
.76095 .1811 m .77304 .17726 L .77578 .18133 L p F P
0 g
s
.668 .736 .901 r
.77304 .17726 m .76095 .1811 L .75824 .1776 L p F P
0 g
s
.705 .774 .906 r
.74627 .18298 m .75824 .1776 L .76095 .1811 L p F P
0 g
s
.776 .978 .707 r
.63862 .2679 m .63375 .27341 L .63651 .26903 L closepath p F P
0 g
s
.502 .582 .868 r
.79738 .18992 m .79361 .18947 L .79082 .18435 L p F P
0 g
s
.75 .736 .84 r
.28105 .4449 m .27593 .44831 L .27248 .44416 L p F P
0 g
s
.707 .726 .865 r
.26114 .44978 m .27248 .44416 L .27593 .44831 L p F P
0 g
s
.457 .228 .478 r
.52844 .40062 m .52326 .40289 L .52657 .39646 L p F P
0 g
s
.457 .228 .478 r
.52657 .39646 m .52868 .39554 L .52844 .40062 L p F P
0 g
s
.882 .449 .137 r
.21277 .34042 m .21695 .34368 L .21498 .33917 L p F P
0 g
s
.882 .449 .137 r
.21498 .33917 m .21083 .33589 L .21277 .34042 L p F P
0 g
s
.66 .746 .914 r
.24642 .45006 m .25764 .44623 L .26114 .44978 L p F P
0 g
s
.675 .743 .902 r
.25764 .44623 m .24642 .45006 L .24287 .44687 L p F P
0 g
s
.74 .816 .912 r
.74627 .18298 m .74501 .18367 L .74525 .18185 L closepath p F P
0 g
s
.74 .842 .927 r
.74356 .17997 m .74525 .18185 L .74501 .18367 L p F P
0 g
s
.74 .842 .927 r
.7317 .18674 m .74356 .17997 L p .74501 .18367 L F P
0 g
s
0 0 0 r
.60573 .30638 m .60404 .30882 L .60907 .30258 L closepath p F P
0 g
s
.877 .562 .45 r
.25385 .39048 m .2592 .39327 L .25863 .38819 L p F P
0 g
s
.877 .562 .45 r
.25348 .38703 m .25385 .39048 L p .25863 .38819 L F P
0 g
s
.877 .562 .45 r
.25863 .38819 m .25413 .38583 L .25348 .38703 L p F P
0 g
s
.486 .727 .978 r
.19902 .44282 m .20569 .44239 L .21081 .4452 L p F P
0 g
s
.497 .729 .976 r
.20569 .44239 m .19902 .44282 L .19537 .43996 L p F P
0 g
s
.67 .894 .978 r
.61535 .43544 m .60358 .44038 L .60064 .43878 L p F P
0 g
s
.661 .887 .98 r
.58888 .44342 m .60064 .43878 L .60358 .44038 L p F P
0 g
s
.83 .357 0 r
.2082 .33088 m .2051 .32866 L .20477 .32807 L closepath p F P
0 g
s
.702 .951 .954 r
.65736 .42087 m .65642 .42059 L .66008 .41862 L closepath p F P
0 g
s
.739 .992 .862 r
.72671 .37944 m .72063 .3841 L .71871 .38421 L p F P
0 g
s
.554 .398 .624 r
.51914 .42292 m .51821 .41654 L .50717 .4208 L p F P
0 g
s
.554 .398 .624 r
.50717 .4208 m .50806 .42714 L .51914 .42292 L p F P
0 g
s
.777 .881 .922 r
.72552 .19075 m .71991 .19436 L .7172 .19217 L p F P
0 g
s
.095 .491 .9 r
.09477 .39896 m .09979 .40073 L .10362 .40408 L p F P
0 g
s
.608 .674 .887 r
.78354 .18008 m .77578 .18133 L .77304 .17726 L p F P
0 g
s
.717 .81 .923 r
.75552 .1742 m .75824 .1776 L .74627 .18298 L p F P
0 g
s
.717 .81 .923 r
.74665 .17849 m .75552 .1742 L p .74627 .18298 L F P
0 g
s
.717 .81 .923 r
.74627 .18298 m .74525 .18185 L .74665 .17849 L p F P
0 g
s
.771 .974 .695 r
.63122 .27499 m .62716 .28083 L .63375 .27341 L p F P
0 g
s
.771 .974 .695 r
.63587 .26939 m .63122 .27499 L p .63375 .27341 L F P
0 g
s
.771 .974 .695 r
.63375 .27341 m .63651 .26903 L .63587 .26939 L p F P
0 g
s
0 0 .006 r
.80722 .27956 m .80675 .28104 L .80704 .28048 L closepath p F P
0 g
s
.724 .726 .851 r
.26114 .44978 m .27248 .44416 L .26937 .44023 L p F P
0 g
s
.724 .726 .851 r
.25764 .44623 m .26114 .44978 L p .26937 .44023 L F P
0 g
s
0 0 0 r
.58724 .3309 m .59239 .32391 L .58525 .33065 L p F P
0 g
s
0 0 0 r
.58271 .33511 m .58724 .3309 L p .58525 .33065 L F P
0 g
s
0 0 0 r
.58525 .33065 m .58377 .33252 L .58271 .33511 L p F P
0 g
s
.484 .723 .977 r
.20994 .44209 m .20569 .44239 L .21081 .4452 L p F P
0 g
s
.484 .723 .977 r
.21081 .4452 m .21356 .44504 L .20994 .44209 L p F P
0 g
s
.31 .638 .965 r
.15211 .42668 m .14844 .42618 L .1447 .42318 L p F P
0 g
s
.739 .963 .683 r
.76746 .34084 m .77428 .3333 L .77057 .33877 L p F P
0 g
s
.739 .963 .683 r
.76581 .3433 m .76746 .34084 L p .77057 .33877 L F P
0 g
s
.739 .963 .683 r
.77057 .33877 m .76713 .34257 L .76581 .3433 L p F P
0 g
s
.373 .675 .975 r
.17719 .43414 m .17379 .43394 L .17848 .43692 L p F P
0 g
s
.373 .675 .975 r
.17848 .43692 m .18088 .43707 L .17719 .43414 L p F P
0 g
s
.884 .459 .177 r
.21883 .34825 m .22323 .35143 L .22131 .34688 L p F P
0 g
s
.884 .459 .177 r
.22131 .34688 m .21695 .34368 L .21883 .34825 L p F P
0 g
s
.865 .572 .491 r
.25939 .39849 m .26505 .40117 L .26483 .39596 L p F P
0 g
s
.865 .572 .491 r
.26483 .39596 m .2592 .39327 L .25939 .39849 L p F P
0 g
s
.122 .508 .909 r
.10502 .40245 m .09979 .40073 L .10362 .40408 L p F P
0 g
s
.122 .508 .909 r
.10362 .40408 m .10879 .40578 L .10502 .40245 L p F P
0 g
s
.795 .681 .738 r
.28974 .43679 m .28496 .43504 L .28744 .43961 L closepath p F P
0 g
s
0 0 0 r
.58377 .33252 m .57946 .33783 L .58271 .33511 L closepath p F P
0 g
s
.846 .985 .861 r
.67177 .23216 m .67055 .23198 L .67294 .22972 L closepath p F P
0 g
s
.733 .991 .839 r
.73232 .37496 m .72671 .37944 L .73047 .3752 L closepath p F P
0 g
s
.739 .992 .862 r
.72976 .37522 m .73047 .3752 L .72671 .37944 L p F P
0 g
s
.739 .992 .862 r
.72005 .38268 m .72976 .37522 L p .72671 .37944 L F P
0 g
s
.739 .992 .862 r
.71871 .38421 m .72005 .38268 L p .72671 .37944 L F P
0 g
s
.769 .681 .766 r
.28105 .4449 m .28744 .43961 L .28496 .43504 L p F P
0 g
s
.769 .681 .766 r
.27467 .44252 m .28105 .4449 L p .28496 .43504 L F P
0 g
s
.75 .736 .84 r
.27248 .44416 m .27467 .44252 L .28105 .4449 L p F P
0 g
s
.64 .682 .874 r
.51508 .44648 m .52674 .44323 L .52985 .44779 L p F P
0 g
s
.634 .629 .827 r
.51372 .44397 m .51508 .44648 L .52674 .44323 L p F P
0 g
s
.822 .587 .583 r
.27606 .41719 m .27938 .41833 L .27881 .4121 L p F P
0 g
s
.822 .587 .583 r
.27881 .4121 m .27716 .41153 L .27606 .41719 L p F P
0 g
s
.721 .959 .683 r
.76713 .34257 m .76359 .34635 L .76581 .3433 L closepath p F P
0 g
s
.174 .545 .928 r
.11568 .4099 m .11256 .40904 L .10879 .40578 L p F P
0 g
s
0 0 0 r
.80603 .28382 m .80426 .28719 L .80675 .28104 L p F P
0 g
s
0 0 0 r
.80675 .28104 m .80704 .28048 L .80603 .28382 L p F P
0 g
s
.243 .594 .949 r
.13297 .4186 m .13046 .41809 L .12671 .41497 L p F P
0 g
s
.849 .582 .534 r
.26475 .40656 m .27075 .40912 L .27105 .40372 L p F P
0 g
s
.849 .582 .534 r
.27105 .40372 m .26505 .40117 L .26475 .40656 L p F P
0 g
s
.422 .2 .471 r
.53875 .39544 m .53899 .39037 L .52868 .39554 L p F P
0 g
s
.422 .2 .471 r
.52868 .39554 m .52844 .40062 L .53875 .39544 L p F P
0 g
s
0 0 .312 r
.81722 .24837 m .81518 .25348 L .81514 .24817 L p F P
0 g
s
0 0 .312 r
.81514 .24817 m .81718 .24305 L .81722 .24837 L p F P
0 g
s
.694 .931 .621 r
.62712 .28089 m .62709 .28091 L .62716 .28083 L closepath p F P
0 g
s
.747 .994 .836 r
.73751 .37068 m .73232 .37496 L .73047 .3752 L p F P
0 g
s
.881 .464 .213 r
.22505 .35604 m .22323 .35143 L .22783 .35453 L p F P
0 g
s
.881 .464 .213 r
.22752 .35768 m .22505 .35604 L p .22783 .35453 L F P
0 g
s
.881 .464 .213 r
.22783 .35453 m .22927 .35811 L .22752 .35768 L p F P
0 g
s
.749 .982 .744 r
.75987 .34863 m .75592 .35414 L .76359 .34635 L p F P
0 g
s
.749 .982 .744 r
.76471 .34372 m .75987 .34863 L p .76359 .34635 L F P
0 g
s
.749 .982 .744 r
.76359 .34635 m .76581 .3433 L .76471 .34372 L p F P
0 g
s
.238 0 .301 r
.55379 .37277 m .54998 .37528 L .55078 .3709 L p F P
0 g
s
.238 0 .301 r
.55078 .3709 m .55829 .36598 L .55379 .37277 L p F P
0 g
s
.719 .973 .927 r
.69149 .40234 m .68273 .40776 L .68023 .40736 L p F P
0 g
s
.666 .913 .594 r
.62517 .28225 m .63122 .27499 L .62716 .28083 L p F P
0 g
s
.666 .913 .594 r
.62467 .28297 m .62517 .28225 L p .62716 .28083 L F P
0 g
s
.666 .913 .594 r
.62716 .28083 m .62709 .28091 L .62467 .28297 L p F P
0 g
s
.689 .921 .598 r
.62709 .28091 m .62102 .28811 L .62467 .28297 L closepath p F P
0 g
s
.789 .872 .909 r
.72552 .19075 m .7317 .18674 L .72899 .18416 L p F P
0 g
s
.789 .872 .909 r
.72899 .18416 m .72671 .18572 L .72552 .19075 L p F P
0 g
s
.777 .881 .922 r
.7172 .19217 m .72671 .18572 L .72552 .19075 L p F P
0 g
s
.127 .146 .61 r
.81765 .22625 m .81698 .22801 L .81458 .22349 L p F P
0 g
s
.127 .146 .61 r
.81458 .22349 m .8161 .21952 L .81765 .22625 L p F P
0 g
s
.746 .951 .64 r
.77791 .32987 m .77621 .33102 L .78033 .326 L closepath p F P
0 g
s
.665 .849 .444 r
.79363 .30668 m .79058 .31199 L .79477 .3053 L p F P
0 g
s
.665 .849 .444 r
.7965 .30211 m .79363 .30668 L p .79477 .3053 L F P
0 g
s
.665 .849 .444 r
.79477 .3053 m .79707 .30134 L .7965 .30211 L p F P
0 g
s
.757 .989 .772 r
.75572 .35441 m .7556 .35445 L .75592 .35414 L closepath p F P
0 g
s
.739 .99 .809 r
.74398 .36511 m .73751 .37068 L .74174 .36558 L closepath p F P
0 g
s
.747 .994 .836 r
.74146 .36561 m .74174 .36558 L .73751 .37068 L p F P
0 g
s
.747 .994 .836 r
.73175 .37363 m .74146 .36561 L p .73751 .37068 L F P
0 g
s
.747 .994 .836 r
.73047 .3752 m .73175 .37363 L p .73751 .37068 L F P
0 g
s
.666 .865 .975 r
.59769 .43701 m .60064 .43878 L .58888 .44342 L p F P
0 g
s
.666 .865 .975 r
.59612 .43761 m .59769 .43701 L p .58888 .44342 L F P
0 g
s
.666 .865 .975 r
.58888 .44342 m .58759 .44259 L .59612 .43761 L p F P
0 g
s
.817 .653 .68 r
.2869 .42794 m .2812 .42576 L .28412 .43314 L closepath p F P
0 g
s
0 0 .095 r
.81345 .26472 m .81101 .26993 L .81224 .26419 L p F P
0 g
s
0 0 .095 r
.81369 .26361 m .81345 .26472 L p .81224 .26419 L F P
0 g
s
0 0 .095 r
.81224 .26419 m .81405 .26035 L .81369 .26361 L p F P
0 g
s
.831 .595 .581 r
.26969 .41477 m .27606 .41719 L .27716 .41153 L p F P
0 g
s
.831 .595 .581 r
.27716 .41153 m .27075 .40912 L .26969 .41477 L p F P
0 g
s
0 0 .013 r
.58133 .3387 m .57386 .34496 L .57946 .33783 L p F P
0 g
s
0 0 .013 r
.57946 .33783 m .58271 .33511 L .58133 .3387 L p F P
0 g
s
0 0 0 r
.80691 .28195 m .80603 .28382 L .80704 .28048 L p F P
0 g
s
0 0 0 r
.80704 .28048 m .80921 .27585 L .80691 .28195 L p F P
0 g
s
.687 .924 .97 r
.64181 .42575 m .63002 .43136 L .62714 .43017 L p F P
0 g
s
0 0 .199 r
.81461 .259 m .81405 .26035 L .81419 .2559 L p F P
0 g
s
0 0 .199 r
.81419 .2559 m .81518 .25348 L .81461 .259 L p F P
0 g
s
.004 0 .084 r
.57262 .34596 m .57224 .34714 L .57386 .34496 L closepath p F P
0 g
s
.762 .991 .777 r
.75312 .35516 m .75987 .34863 L .75592 .35414 L p F P
0 g
s
.762 .991 .777 r
.75592 .35414 m .7556 .35445 L .75312 .35516 L p F P
0 g
s
.744 .986 .773 r
.74718 .36227 m .7556 .35445 L .75312 .35516 L p F P
0 g
s
.753 .993 .806 r
.74718 .36227 m .74398 .36511 L .74174 .36558 L p F P
0 g
s
.833 .626 .622 r
.28249 .41959 m .27938 .41833 L .2809 .42465 L closepath p F P
0 g
s
.744 .986 .773 r
.75312 .35516 m .75153 .35664 L .74718 .36227 L p F P
0 g
s
.753 .993 .806 r
.74222 .36496 m .75153 .35664 L .74718 .36227 L p F P
0 g
s
.753 .993 .806 r
.74174 .36558 m .74222 .36496 L p .74718 .36227 L F P
0 g
s
.679 .907 .975 r
.61641 .43595 m .61535 .43544 L .62053 .43316 L closepath p F P
0 g
s
.819 .997 .774 r
.64886 .2558 m .64742 .25623 L .65056 .25284 L closepath p F P
0 g
s
.894 .504 .279 r
.22927 .35811 m .2296 .35915 L .23421 .36223 L p F P
0 g
s
.9 .526 .316 r
.23089 .36395 m .23555 .36702 L .23421 .36223 L p F P
0 g
s
.9 .526 .316 r
.23421 .36223 m .2296 .35915 L .23089 .36395 L p F P
0 g
s
.623 .594 .8 r
.51195 .44018 m .51372 .44397 L .52482 .43979 L p F P
0 g
s
.634 .629 .827 r
.52674 .44323 m .52482 .43979 L .51372 .44397 L p F P
0 g
s
.557 .744 .964 r
.21356 .44504 m .22459 .44333 L .22818 .44639 L p F P
0 g
s
.568 .745 .96 r
.22459 .44333 m .21356 .44504 L .20994 .44209 L p F P
0 g
s
.718 .811 .923 r
.74525 .18185 m .74356 .17997 L .74665 .17849 L closepath p F P
0 g
s
.708 .947 .956 r
.66008 .41862 m .65642 .42059 L .65361 .41969 L p F P
0 g
s
.48 .273 .521 r
.52847 .40601 m .52315 .40833 L .52326 .40289 L p F P
0 g
s
.48 .273 .521 r
.52326 .40289 m .52844 .40062 L .52847 .40601 L p F P
0 g
s
.435 .705 .979 r
.18088 .43707 m .1917 .43703 L .19537 .43996 L p F P
0 g
s
.442 .704 .977 r
.1917 .43703 m .18088 .43707 L .17719 .43414 L p F P
0 g
s
.644 .739 .918 r
.52985 .44779 m .54155 .44442 L .54463 .44799 L p F P
0 g
s
.636 .694 .887 r
.54155 .44442 m .52985 .44779 L .52674 .44323 L p F P
0 g
s
.502 .582 .868 r
.79082 .18435 m .79865 .1849 L .79738 .18992 L p F P
0 g
s
.455 .519 .835 r
.80339 .18565 m .79865 .1849 L .79738 .18992 L p F P
0 g
s
.455 .519 .835 r
.79738 .18992 m .80625 .19185 L .80339 .18565 L p F P
0 g
s
.558 .828 .474 r
.62434 .28327 m .62467 .28297 L .62102 .28811 L p F P
0 g
s
.558 .828 .474 r
.61951 .28939 m .62434 .28327 L p .62102 .28811 L F P
0 g
s
.558 .828 .474 r
.61532 .29485 m .61951 .28939 L p .62102 .28811 L F P
0 g
s
.558 .828 .474 r
.62102 .28811 m .61557 .29456 L .61532 .29485 L p F P
0 g
s
.893 .533 .354 r
.23669 .37188 m .24161 .37485 L .24041 .37 L p F P
0 g
s
.893 .533 .354 r
.24041 .37 m .23555 .36702 L .23669 .37188 L p F P
0 g
s
.758 .828 .906 r
.74356 .17997 m .7317 .18674 L .72899 .18416 L p F P
0 g
s
.656 .837 .969 r
.5859 .44147 m .57415 .4457 L .57113 .44333 L p F P
0 g
s
.652 .825 .966 r
.55939 .44724 m .57113 .44333 L .57415 .4457 L p F P
0 g
s
.579 .453 .673 r
.52047 .4287 m .51914 .42292 L .50806 .42714 L p F P
0 g
s
.579 .453 .673 r
.50806 .42714 m .5088 .43059 L .52047 .4287 L p F P
0 g
s
.224 .26 .69 r
.81307 .21419 m .8139 .21191 L .81534 .21679 L closepath p F P
0 g
s
.501 .322 .571 r
.52729 .41246 m .51821 .41654 L .51781 .41073 L p F P
0 g
s
.501 .322 .571 r
.51781 .41073 m .52315 .40833 L .52729 .41246 L p F P
0 g
s
0 0 0 r
.59414 .32062 m .59251 .32375 L .59781 .31684 L closepath p F P
0 g
s
.716 .979 .914 r
.6945 .40041 m .69149 .40234 L .69363 .40032 L closepath p F P
0 g
s
.719 .973 .927 r
.6918 .39997 m .69363 .40032 L .69149 .40234 L p F P
0 g
s
.719 .973 .927 r
.68076 .40685 m .6918 .39997 L p .69149 .40234 L F P
0 g
s
.719 .973 .927 r
.68023 .40736 m .68076 .40685 L p .69149 .40234 L F P
0 g
s
.794 .315 0 r
.19717 .32121 m .20089 .32468 L .19831 .3204 L p F P
0 g
s
.794 .315 0 r
.19831 .3204 m .1946 .31693 L .19717 .32121 L p F P
0 g
s
.648 .787 .949 r
.54463 .44799 m .55635 .44438 L .55939 .44724 L p F P
0 g
s
.643 .753 .929 r
.55635 .44438 m .54463 .44799 L .54155 .44442 L p F P
0 g
s
.884 .541 .395 r
.24256 .37979 m .24777 .38265 L .24675 .37773 L p F P
0 g
s
.884 .541 .395 r
.24675 .37773 m .24161 .37485 L .24256 .37979 L p F P
0 g
s
.048 0 .122 r
.58098 .33972 m .58133 .3387 L .57386 .34496 L p F P
0 g
s
.048 0 .122 r
.57749 .34473 m .58098 .33972 L p .57386 .34496 L F P
0 g
s
.048 0 .122 r
.57142 .3498 m .57749 .34473 L p .57386 .34496 L F P
0 g
s
.048 0 .122 r
.57386 .34496 m .57224 .34714 L .57142 .3498 L p F P
0 g
s
.65 .801 .955 r
.57113 .44333 m .55939 .44724 L .55635 .44438 L p F P
0 g
s
.785 .652 .716 r
.28412 .43314 m .28309 .4345 L .28496 .43504 L closepath p F P
0 g
s
.769 .681 .766 r
.28496 .43504 m .28309 .4345 L .27467 .44252 L p F P
0 g
s
.52 .597 .871 r
.79865 .1849 m .79082 .18435 L .78805 .17948 L p F P
0 g
s
.703 .958 .948 r
.66821 .4141 m .66008 .41862 L .66609 .41357 L closepath p F P
0 g
s
.708 .947 .956 r
.66543 .41336 m .66609 .41357 L .66008 .41862 L p F P
0 g
s
.708 .947 .956 r
.65361 .41969 m .66543 .41336 L p .66008 .41862 L F P
0 g
s
.243 .594 .949 r
.12671 .41497 m .12881 .41539 L .13297 .4186 L p F P
0 g
s
.261 .603 .953 r
.13722 .41696 m .12881 .41539 L .13297 .4186 L p F P
0 g
s
.261 .603 .953 r
.13297 .4186 m .14097 .42011 L .13722 .41696 L p F P
0 g
s
.862 .54 .441 r
.25413 .38583 m .25348 .38703 L .25325 .38541 L closepath p F P
0 g
s
.611 .543 .753 r
.50986 .43447 m .51195 .44018 L .52362 .43733 L p F P
0 g
s
.623 .594 .8 r
.52482 .43979 m .52362 .43733 L .51195 .44018 L p F P
0 g
s
.7 .888 .507 r
.78891 .31356 m .79363 .30668 L .79058 .31199 L p F P
0 g
s
.7 .888 .507 r
.78686 .3172 m .78891 .31356 L p .79058 .31199 L F P
0 g
s
.7 .888 .507 r
.79058 .31199 m .78756 .31641 L .78686 .3172 L p F P
0 g
s
.31 .638 .965 r
.1447 .42318 m .14772 .42357 L .15211 .42668 L p F P
0 g
s
.323 .643 .967 r
.15534 .42448 m .14772 .42357 L .15211 .42668 L p F P
0 g
s
.323 .643 .967 r
.15211 .42668 m .15906 .42752 L .15534 .42448 L p F P
0 g
s
.575 .836 .479 r
.61557 .29456 m .61488 .2954 L .61532 .29485 L closepath p F P
0 g
s
.587 .486 .707 r
.52091 .43022 m .52047 .4287 L .5088 .43059 L p F P
0 g
s
.587 .486 .707 r
.5088 .43059 m .50986 .43447 L .52091 .43022 L p F P
0 g
s
.314 .365 .755 r
.81011 .20536 m .81087 .20315 L .81217 .20681 L closepath p F P
0 g
s
.389 .451 .804 r
.80517 .19716 m .80664 .19272 L .80917 .19883 L closepath p F P
0 g
s
.84 .967 .884 r
.69065 .21339 m .68215 .22091 L .68165 .22075 L p F P
0 g
s
.86 .964 .868 r
.68215 .22091 m .68131 .22171 L .68165 .22075 L closepath p F P
0 g
s
.862 .966 .865 r
.67514 .22439 m .67294 .22972 L .68131 .22171 L p F P
0 g
s
.862 .966 .865 r
.67942 .22009 m .67514 .22439 L p .68131 .22171 L F P
0 g
s
.862 .966 .865 r
.68131 .22171 m .68165 .22075 L .67942 .22009 L p F P
0 g
s
.815 .617 .635 r
.28052 .42554 m .2809 .42465 L .27938 .41833 L p F P
0 g
s
.815 .617 .635 r
.2738 .42324 m .28052 .42554 L p .27938 .41833 L F P
0 g
s
.815 .617 .635 r
.27938 .41833 m .27606 .41719 L .2738 .42324 L p F P
0 g
s
.796 .647 .697 r
.28309 .4345 m .28412 .43314 L .2812 .42576 L p F P
0 g
s
.347 .114 .411 r
.54916 .38136 m .54931 .37982 L .53945 .38556 L p F P
0 g
s
.347 .114 .411 r
.54699 .3857 m .54916 .38136 L p .53945 .38556 L F P
0 g
s
.347 .114 .411 r
.53945 .38556 m .53899 .39037 L .54699 .3857 L p F P
0 g
s
.077 0 .134 r
.57224 .34714 m .56839 .35204 L .57142 .3498 L closepath p F P
0 g
s
.733 .982 .91 r
.7036 .39224 m .70627 .39258 L .6945 .40041 L p F P
0 g
s
.733 .982 .91 r
.69762 .39623 m .7036 .39224 L p .6945 .40041 L F P
0 g
s
.733 .982 .91 r
.6945 .40041 m .69363 .40032 L .69762 .39623 L p F P
0 g
s
.559 .819 .454 r
.61321 .29741 m .60907 .30258 L .61488 .2954 L p F P
0 g
s
0 0 0 r
.804 .28825 m .80126 .2935 L .80426 .28719 L p F P
0 g
s
0 0 0 r
.8053 .2855 m .804 .28825 L p .80426 .28719 L F P
0 g
s
0 0 0 r
.80426 .28719 m .80603 .28382 L .8053 .2855 L p F P
0 g
s
.617 .75 .941 r
.22818 .44639 m .23931 .4436 L .24287 .44687 L p F P
0 g
s
.63 .75 .934 r
.23931 .4436 m .22818 .44639 L .22459 .44333 L p F P
0 g
s
0 0 .426 r
.81922 .23791 m .81718 .24305 L .81645 .23797 L p F P
0 g
s
0 0 .426 r
.81645 .23797 m .81849 .23282 L .81922 .23791 L p F P
0 g
s
.848 .94 .883 r
.69379 .21058 m .69065 .21339 L .69178 .2096 L closepath p F P
0 g
s
.84 .967 .884 r
.69107 .20927 m .69178 .2096 L .69065 .21339 L p F P
0 g
s
.84 .967 .884 r
.68342 .21641 m .69107 .20927 L p .69065 .21339 L F P
0 g
s
.84 .967 .884 r
.68165 .22075 m .68342 .21641 L p .69065 .21339 L F P
0 g
s
.823 .35 0 r
.20145 .32568 m .20089 .32468 L .20477 .32807 L p F P
0 g
s
.823 .35 0 r
.20477 .32807 m .2051 .32866 L .20145 .32568 L p F P
0 g
s
.871 .547 .435 r
.24846 .38769 m .24777 .38265 L .25325 .38541 L p F P
0 g
s
.871 .547 .435 r
.25197 .38944 m .24846 .38769 L p .25325 .38541 L F P
0 g
s
.871 .547 .435 r
.25325 .38541 m .25348 .38703 L .25197 .38944 L p F P
0 g
s
.828 .942 .9 r
.70091 .20475 m .69379 .21058 L .69178 .2096 L p F P
0 g
s
.844 .987 .859 r
.66781 .23166 m .67514 .22439 L .67294 .22972 L p F P
0 g
s
.844 .987 .859 r
.67294 .22972 m .67055 .23198 L .66781 .23166 L p F P
0 g
s
.763 .73 .822 r
.27467 .44252 m .26937 .44023 L .27248 .44416 L closepath p F P
0 g
s
.867 .99 .828 r
.6651 .23755 m .67055 .23198 L .66781 .23166 L p F P
0 g
s
.796 .647 .697 r
.27618 .43227 m .28309 .4345 L p .2812 .42576 L F P
0 g
s
.779 .681 .755 r
.26937 .44023 m .27467 .44252 L .28309 .4345 L p F P
0 g
s
.779 .681 .755 r
.26903 .43976 m .26937 .44023 L p .28309 .4345 L F P
0 g
s
.779 .681 .755 r
.28309 .4345 m .27618 .43227 L .26903 .43976 L p F P
0 g
s
.174 .545 .928 r
.10879 .40578 m .11175 .4066 L .11568 .4099 L p F P
0 g
s
.196 .558 .934 r
.11918 .40851 m .11175 .4066 L .11568 .4099 L p F P
0 g
s
.196 .558 .934 r
.11568 .4099 m .12295 .41178 L .11918 .40851 L p F P
0 g
s
.611 .543 .753 r
.52362 .43733 m .52091 .43022 L .50986 .43447 L p F P
0 g
s
.666 .858 .973 r
.58759 .44259 m .5859 .44147 L .59612 .43761 L closepath p F P
0 g
s
.373 .674 .975 r
.16277 .43051 m .16919 .43092 L .17379 .43394 L p F P
0 g
s
.381 .674 .974 r
.16919 .43092 m .16277 .43051 L .15906 .42752 L p F P
0 g
s
.685 .898 .973 r
.62053 .43316 m .61535 .43544 L .61243 .4339 L p F P
0 g
s
.67 .894 .978 r
.60064 .43878 m .61243 .4339 L .61535 .43544 L p F P
0 g
s
.144 0 .221 r
.56122 .3605 m .56069 .36273 L .5632 .35905 L closepath p F P
0 g
s
.876 .583 .487 r
.25401 .39571 m .25939 .39849 L .2592 .39327 L p F P
0 g
s
.876 .583 .487 r
.2592 .39327 m .25385 .39048 L .25401 .39571 L p F P
0 g
s
.668 .736 .901 r
.75824 .1776 m .77031 .17333 L .77304 .17726 L p F P
0 g
s
.681 .749 .903 r
.77031 .17333 m .75824 .1776 L .75552 .1742 L p F P
0 g
s
.884 .451 .122 r
.20874 .33708 m .21277 .34042 L .21083 .33589 L p F P
0 g
s
.884 .451 .122 r
.21083 .33589 m .20683 .33254 L .20874 .33708 L p F P
0 g
s
.867 .99 .828 r
.66781 .23166 m .66726 .23225 L .6651 .23755 L p F P
0 g
s
.837 .999 .823 r
.66018 .23984 m .66726 .23225 L .6651 .23755 L p F P
0 g
s
.837 .999 .823 r
.65822 .24381 m .66018 .23984 L p .6651 .23755 L F P
0 g
s
.837 .999 .823 r
.6651 .23755 m .65897 .24375 L .65822 .24381 L p F P
0 g
s
.841 .926 .887 r
.70091 .20475 m .70547 .20099 L .70275 .19924 L p F P
0 g
s
.841 .926 .887 r
.70275 .19924 m .70223 .19969 L .70091 .20475 L p F P
0 g
s
.828 .942 .9 r
.69229 .20823 m .70223 .19969 L .70091 .20475 L p F P
0 g
s
.828 .942 .9 r
.69178 .2096 m .69229 .20823 L p .70091 .20475 L F P
0 g
s
.497 .729 .976 r
.19537 .43996 m .20063 .43955 L .20569 .44239 L p F P
0 g
s
.496 .725 .974 r
.2063 .43908 m .20063 .43955 L .20569 .44239 L p F P
0 g
s
.496 .725 .974 r
.20569 .44239 m .20994 .44209 L .2063 .43908 L p F P
0 g
s
.58 .83 .46 r
.61389 .29653 m .61321 .29741 L .61532 .29485 L p F P
0 g
s
.58 .83 .46 r
.61532 .29485 m .61951 .28939 L .61389 .29653 L p F P
0 g
s
.608 .674 .887 r
.78541 .17504 m .78354 .18008 L p .77304 .17726 L F P
0 g
s
.582 .657 .888 r
.78354 .18008 m .78541 .17504 L .78805 .17948 L closepath p F P
0 g
s
.696 .935 .965 r
.6422 .4259 m .64181 .42575 L .64342 .42494 L closepath p F P
0 g
s
.874 .434 .077 r
.20683 .33254 m .2051 .32866 L .20145 .32568 L p F P
0 g
s
.678 .88 .504 r
.78756 .31641 m .78581 .31888 L .78686 .3172 L closepath p F P
0 g
s
.807 .617 .646 r
.2809 .42465 m .28052 .42554 L .2812 .42576 L closepath p F P
0 g
s
.103 0 .17 r
.57032 .35377 m .5632 .35905 L .56839 .35204 L p F P
0 g
s
.103 0 .17 r
.56839 .35204 m .57142 .3498 L .57032 .35377 L p F P
0 g
s
.81 .915 .91 r
.71261 .19564 m .70547 .20099 L .70275 .19924 L p F P
0 g
s
.69 .741 .89 r
.25412 .44256 m .24287 .44687 L .23931 .4436 L p F P
0 g
s
.675 .743 .902 r
.24287 .44687 m .25412 .44256 L .25764 .44623 L p F P
0 g
s
.608 .674 .887 r
.77304 .17726 m .78528 .17483 L .78541 .17504 L p F P
0 g
s
.623 .69 .891 r
.78528 .17483 m .77304 .17726 L .77031 .17333 L p F P
0 g
s
.796 .647 .697 r
.2812 .42576 m .28052 .42554 L .27618 .43227 L p F P
0 g
s
.862 .594 .531 r
.25908 .40389 m .26475 .40656 L .26505 .40117 L p F P
0 g
s
.862 .594 .531 r
.26505 .40117 m .25939 .39849 L .25908 .40389 L p F P
0 g
s
.381 .676 .975 r
.1735 .43116 m .16919 .43092 L .17379 .43394 L p F P
0 g
s
.381 .676 .975 r
.17379 .43394 m .17719 .43414 L .1735 .43116 L p F P
0 g
s
.857 .996 .812 r
.65897 .24375 m .65755 .24529 L .65822 .24381 L closepath p F P
0 g
s
.724 .726 .851 r
.26937 .44023 m .26865 .44002 L .25764 .44623 L p F P
0 g
s
.733 .757 .872 r
.26865 .44002 m .25764 .44623 L .25412 .44256 L p F P
0 g
s
0 0 0 r
.81161 .27067 m .80921 .27585 L .81101 .26993 L p F P
0 g
s
0 0 0 r
.81101 .26993 m .81345 .26472 L .81161 .27067 L p F P
0 g
s
.85 .968 .875 r
.68165 .22075 m .67942 .22009 L .68342 .21641 L closepath p F P
0 g
s
.888 .464 .164 r
.21461 .345 m .21883 .34825 L .21695 .34368 L p F P
0 g
s
.888 .464 .164 r
.21695 .34368 m .21277 .34042 L .21461 .345 L p F P
0 g
s
.857 .997 .806 r
.6533 .24737 m .65056 .25284 L .65755 .24529 L p F P
0 g
s
.857 .997 .806 r
.65623 .24404 m .6533 .24737 L p .65755 .24529 L F P
0 g
s
.857 .997 .806 r
.65755 .24529 m .65822 .24381 L .65623 .24404 L p F P
0 g
s
0 0 .186 r
.81663 .2539 m .81461 .259 L .81518 .25348 L p F P
0 g
s
0 0 .186 r
.81518 .25348 m .81722 .24837 L .81663 .2539 L p F P
0 g
s
.507 .731 .974 r
.20063 .43955 m .19537 .43996 L .1917 .43703 L p F P
0 g
s
.804 .649 .69 r
.26985 .42985 m .27618 .43227 L .28052 .42554 L p F P
0 g
s
.804 .649 .69 r
.28052 .42554 m .2738 .42324 L .26985 .42985 L p F P
0 g
s
0 0 0 r
.6128 .29794 m .61321 .29741 L .60907 .30258 L p F P
0 g
s
0 0 0 r
.60859 .30356 m .6128 .29794 L p .60907 .30258 L F P
0 g
s
0 0 0 r
.6038 .3092 m .60859 .30356 L p .60907 .30258 L F P
0 g
s
0 0 0 r
.60907 .30258 m .60404 .30882 L .6038 .3092 L p F P
0 g
s
.845 .607 .579 r
.26373 .4122 m .26969 .41477 L .27075 .40912 L p F P
0 g
s
.845 .607 .579 r
.27075 .40912 m .26475 .40656 L .26373 .4122 L p F P
0 g
s
.9 .507 .265 r
.22927 .35811 m .2296 .35915 L .22752 .35768 L closepath p F P
0 g
s
.726 .93 .594 r
.78364 .32062 m .78033 .326 L .78581 .31888 L p F P
0 g
s
.726 .93 .594 r
.78527 .3185 m .78364 .32062 L p .78581 .31888 L F P
0 g
s
.726 .93 .594 r
.78581 .31888 m .78686 .3172 L .78527 .3185 L p F P
0 g
s
.741 .984 .905 r
.70646 .3926 m .70627 .39258 L .70685 .39219 L closepath p F P
0 g
s
.826 .625 .631 r
.26758 .42077 m .2738 .42324 L .27606 .41719 L p F P
0 g
s
.826 .625 .631 r
.27606 .41719 m .26969 .41477 L .26758 .42077 L p F P
0 g
s
.885 .569 .445 r
.25348 .38703 m .25385 .39048 L .25197 .38944 L closepath p F P
0 g
s
.717 .961 .944 r
.67725 .40656 m .68001 .4073 L .66821 .4141 L p F P
0 g
s
.717 .961 .944 r
.66776 .41206 m .67725 .40656 L p .66821 .4141 L F P
0 g
s
.717 .961 .944 r
.66821 .4141 m .66609 .41357 L .66776 .41206 L p F P
0 g
s
.318 .638 .965 r
.14772 .42357 m .1447 .42318 L .14097 .42011 L p F P
0 g
s
0 0 0 r
.58225 .33785 m .58133 .3387 L .58271 .33511 L p F P
0 g
s
0 0 0 r
.58271 .33511 m .58724 .3309 L .58225 .33785 L p F P
0 g
s
.77 .985 .741 r
.76581 .3433 m .76471 .34372 L .76746 .34084 L closepath p F P
0 g
s
.702 .928 .965 r
.64342 .42494 m .64181 .42575 L .63896 .42456 L p F P
0 g
s
.687 .924 .97 r
.62714 .43017 m .63896 .42456 L .64181 .42575 L p F P
0 g
s
.448 .248 .515 r
.5388 .40083 m .53875 .39544 L .52844 .40062 L p F P
0 g
s
.448 .248 .515 r
.52844 .40062 m .52847 .40601 L .5388 .40083 L p F P
0 g
s
.89 .475 .208 r
.22059 .35287 m .22505 .35604 L .22323 .35143 L p F P
0 g
s
.89 .475 .208 r
.22323 .35143 m .21883 .34825 L .22059 .35287 L p F P
0 g
s
.751 .99 .886 r
.71871 .38421 m .71802 .38418 L .72005 .38268 L closepath p F P
0 g
s
.718 .818 .927 r
.74665 .17849 m .74356 .17997 L .74085 .17705 L p F P
0 g
s
.758 .828 .906 r
.72899 .18416 m .74085 .17705 L .74356 .17997 L p F P
0 g
s
.822 .901 .896 r
.71261 .19564 m .7172 .19217 L .71448 .19002 L p F P
0 g
s
.822 .901 .896 r
.71448 .19002 m .71371 .19063 L .71261 .19564 L p F P
0 g
s
.81 .915 .91 r
.70275 .19924 m .71371 .19063 L .71261 .19564 L p F P
0 g
s
.24 .302 .727 r
.81217 .20681 m .81468 .20913 L .8139 .21191 L closepath p F P
0 g
s
.111 .184 .661 r
.8179 .21337 m .81468 .20913 L .8139 .21191 L p F P
0 g
s
.111 .184 .661 r
.81645 .21837 m .8179 .21337 L p .8139 .21191 L F P
0 g
s
.111 .184 .661 r
.8139 .21191 m .81534 .21679 L .81645 .21837 L p F P
0 g
s
.747 .983 .909 r
.70685 .39219 m .70627 .39258 L .7036 .39224 L p F P
0 g
s
.81 .995 .766 r
.64677 .25479 m .6533 .24737 L .65056 .25284 L p F P
0 g
s
.81 .995 .766 r
.64567 .25681 m .64677 .25479 L p .65056 .25284 L F P
0 g
s
.81 .995 .766 r
.65056 .25284 m .64742 .25623 L .64567 .25681 L p F P
0 g
s
.183 .545 .929 r
.11175 .4066 m .10879 .40578 L .10502 .40245 L p F P
0 g
s
.743 .988 .894 r
.70685 .39219 m .71802 .38418 L .71539 .38402 L p F P
0 g
s
.743 .988 .894 r
.71539 .38402 m .71222 .38629 L .70685 .39219 L p F P
0 g
s
.747 .983 .909 r
.7036 .39224 m .71222 .38629 L .70685 .39219 L p F P
0 g
s
.685 .898 .973 r
.62425 .42877 m .62574 .42952 L .62053 .43316 L p F P
0 g
s
.685 .898 .973 r
.61243 .4339 m .62425 .42877 L p .62053 .43316 L F P
0 g
s
.682 .913 .974 r
.62714 .43017 m .62053 .43316 L .62574 .42952 L closepath p F P
0 g
s
.697 .942 .961 r
.65361 .41969 m .64342 .42494 L .65109 .41883 L closepath p F P
0 g
s
.702 .928 .965 r
.65079 .41871 m .65109 .41883 L .64342 .42494 L p F P
0 g
s
.702 .928 .965 r
.63896 .42456 m .65079 .41871 L p .64342 .42494 L F P
0 g
s
.251 .594 .949 r
.12881 .41539 m .12671 .41497 L .12295 .41178 L p F P
0 g
s
.736 .974 .925 r
.69363 .40032 m .6918 .39997 L .69762 .39623 L closepath p F P
0 g
s
.671 .884 .977 r
.61243 .4339 m .60064 .43878 L .59769 .43701 L p F P
0 g
s
.208 .296 .735 r
.81087 .20315 m .81217 .20681 L .81468 .20913 L p F P
0 g
s
.77 .973 .695 r
.63651 .26903 m .63587 .26939 L .63734 .26771 L closepath p F P
0 g
s
.788 .887 .916 r
.72671 .18572 m .7172 .19217 L .71448 .19002 L p F P
0 g
s
.024 .03 .525 r
.8187 .23228 m .81849 .23282 L .81698 .22801 L p F P
0 g
s
.024 .03 .525 r
.81698 .22801 m .81765 .22625 L .8187 .23228 L p F P
0 g
s
.153 .201 .659 r
.81534 .21679 m .81645 .21837 L .8161 .21952 L closepath p F P
0 g
s
.907 .534 .311 r
.2264 .36081 m .23089 .36395 L .2296 .35915 L p F P
0 g
s
.907 .534 .311 r
.22551 .3574 m .2264 .36081 L p .2296 .35915 L F P
0 g
s
.907 .534 .311 r
.2296 .35915 m .22752 .35768 L .22551 .3574 L p F P
0 g
s
.832 .996 .759 r
.64742 .25623 m .64384 .26031 L .64567 .25681 L closepath p F P
0 g
s
.526 .376 .62 r
.52983 .41822 m .51914 .42292 L .51821 .41654 L p F P
0 g
s
.526 .376 .62 r
.529 .41293 m .52983 .41822 L p .51821 .41654 L F P
0 g
s
.526 .376 .62 r
.51821 .41654 m .52729 .41246 L .529 .41293 L p F P
0 g
s
.505 .323 .568 r
.52885 .41178 m .52729 .41246 L .52315 .40833 L p F P
0 g
s
.505 .323 .568 r
.52315 .40833 m .52847 .40601 L .52885 .41178 L p F P
0 g
s
.636 .694 .887 r
.52674 .44323 m .53845 .44012 L .54155 .44442 L p F P
0 g
s
.632 .635 .835 r
.52482 .43979 m .52674 .44323 L .53845 .44012 L p F P
0 g
s
.652 .806 .365 r
.80045 .29476 m .79779 .29998 L .80126 .2935 L p F P
0 g
s
.652 .806 .365 r
.80126 .2935 m .804 .28825 L .80045 .29476 L p F P
0 g
s
0 0 0 r
.60404 .30882 m .6033 .30975 L .6038 .3092 L closepath p F P
0 g
s
.178 0 .248 r
.56944 .35738 m .57032 .35377 L .5632 .35905 L p F P
0 g
s
.178 0 .248 r
.56891 .35821 m .56944 .35738 L p .5632 .35905 L F P
0 g
s
.178 0 .248 r
.56026 .36468 m .56891 .35821 L p .5632 .35905 L F P
0 g
s
.178 0 .248 r
.5632 .35905 m .56069 .36273 L .56026 .36468 L p F P
0 g
s
.315 .389 .779 r
.80917 .19883 m .81158 .20032 L .81087 .20315 L closepath p F P
0 g
s
.208 .296 .735 r
.81604 .20413 m .81158 .20032 L .81087 .20315 L p F P
0 g
s
.208 .296 .735 r
.81468 .20913 m .81604 .20413 L p .81087 .20315 L F P
0 g
s
0 0 0 r
.60201 .3122 m .59781 .31684 L .6033 .30975 L p F P
0 g
s
0 0 0 r
.6033 .30975 m .6038 .3092 L .60201 .3122 L p F P
0 g
s
.066 .105 .592 r
.81868 .22295 m .81765 .22625 L .8161 .21952 L p F P
0 g
s
.066 .105 .592 r
.8161 .21952 m .81645 .21837 L .81868 .22295 L p F P
0 g
s
.731 .816 .917 r
.74665 .17849 m .75552 .1742 L .7528 .17089 L p F P
0 g
s
.731 .816 .917 r
.7528 .17089 m .74794 .1734 L .74665 .17849 L p F P
0 g
s
.718 .818 .927 r
.74085 .17705 m .74794 .1734 L .74665 .17849 L p F P
0 g
s
.266 .019 .341 r
.55003 .37935 m .54931 .37982 L .54998 .37528 L p F P
0 g
s
.266 .019 .341 r
.54998 .37528 m .55379 .37277 L .55003 .37935 L p F P
0 g
s
.902 .543 .349 r
.23198 .36883 m .23669 .37188 L .23555 .36702 L p F P
0 g
s
.902 .543 .349 r
.23555 .36702 m .23089 .36395 L .23198 .36883 L p F P
0 g
s
.748 .952 .642 r
.77764 .32792 m .78364 .32062 L .78033 .326 L p F P
0 g
s
.748 .952 .642 r
.77545 .33154 m .77764 .32792 L p .78033 .326 L F P
0 g
s
.748 .952 .642 r
.78033 .326 m .77621 .33102 L .77545 .33154 L p F P
0 g
s
.761 .995 .865 r
.73047 .3752 m .72976 .37522 L .73175 .37363 L closepath p F P
0 g
s
0 0 .071 r
.81405 .26035 m .81369 .26361 L .81461 .259 L closepath p F P
0 g
s
.698 .861 .451 r
.79707 .30134 m .7965 .30211 L .79779 .29998 L closepath p F P
0 g
s
.83 .994 .75 r
.6406 .26209 m .63734 .26771 L .64384 .26031 L p F P
0 g
s
.83 .994 .75 r
.64467 .25718 m .6406 .26209 L p .64384 .26031 L F P
0 g
s
.83 .994 .75 r
.64384 .26031 m .64567 .25681 L .64467 .25718 L p F P
0 g
s
.848 .998 .811 r
.65822 .24381 m .65623 .24404 L .66018 .23984 L closepath p F P
0 g
s
.52 .597 .871 r
.78805 .17948 m .80014 .1798 L .79865 .1849 L p F P
0 g
s
.508 .619 .897 r
.78541 .17504 m .78805 .17948 L .80014 .1798 L p F P
0 g
s
.799 .717 .774 r
.2656 .43485 m .26985 .42985 L .27618 .43227 L p F P
0 g
s
.799 .717 .774 r
.27618 .43227 m .26903 .43976 L .2656 .43485 L p F P
0 g
s
.894 .552 .391 r
.23759 .37684 m .24256 .37979 L .24161 .37485 L p F P
0 g
s
.894 .552 .391 r
.24161 .37485 m .23669 .37188 L .23759 .37684 L p F P
0 g
s
.568 .745 .96 r
.20994 .44209 m .22098 .44021 L .22459 .44333 L p F P
0 g
s
.578 .745 .956 r
.22098 .44021 m .20994 .44209 L .2063 .43908 L p F P
0 g
s
0 0 0 r
.6034 .31056 m .60201 .3122 L .6038 .3092 L p F P
0 g
s
0 0 0 r
.6038 .3092 m .60859 .30356 L .6034 .31056 L p F P
0 g
s
.656 .837 .969 r
.57113 .44333 m .58291 .43922 L .5859 .44147 L p F P
0 g
s
.672 .841 .964 r
.59612 .43761 m .5859 .44147 L .58291 .43922 L p F P
0 g
s
.211 0 .26 r
.56069 .36273 m .55829 .36598 L .56026 .36468 L closepath p F P
0 g
s
.442 .704 .977 r
.17719 .43414 m .18803 .43405 L .1917 .43703 L p F P
0 g
s
.448 .704 .976 r
.18803 .43405 m .17719 .43414 L .1735 .43116 L p F P
0 g
s
.755 .99 .89 r
.72005 .38268 m .71802 .38418 L .71539 .38402 L p F P
0 g
s
.292 .39 .792 r
.80664 .19272 m .80917 .19883 L .81158 .20032 L p F P
0 g
s
.754 .937 .595 r
.78686 .3172 m .78527 .3185 L .78891 .31356 L closepath p F P
0 g
s
.742 .712 .824 r
.26903 .43976 m .26865 .44002 L .26937 .44023 L closepath p F P
0 g
s
.73 .948 .642 r
.77621 .33102 m .77428 .3333 L .77545 .33154 L closepath p F P
0 g
s
.724 .965 .938 r
.68023 .40736 m .68001 .4073 L .68076 .40685 L closepath p F P
0 g
s
.751 .993 .871 r
.72005 .38268 m .72976 .37522 L .72716 .37523 L p F P
0 g
s
.751 .993 .871 r
.72716 .37523 m .72499 .3769 L .72005 .38268 L p F P
0 g
s
.755 .99 .89 r
.71539 .38402 m .72499 .3769 L .72005 .38268 L p F P
0 g
s
.643 .753 .929 r
.54155 .44442 m .55328 .44102 L .55635 .44438 L p F P
0 g
s
.634 .712 .903 r
.55328 .44102 m .54155 .44442 L .53845 .44012 L p F P
0 g
s
.883 .561 .435 r
.2432 .38485 m .24846 .38769 L .24777 .38265 L p F P
0 g
s
.883 .561 .435 r
.24777 .38265 m .24256 .37979 L .2432 .38485 L p F P
0 g
s
.788 .887 .916 r
.72627 .18165 m .72722 .18252 L .72671 .18572 L p F P
0 g
s
.788 .887 .916 r
.71448 .19002 m .72627 .18165 L p .72671 .18572 L F P
0 g
s
.788 .862 .904 r
.72899 .18416 m .72671 .18572 L .72722 .18252 L closepath p F P
0 g
s
.037 0 .143 r
.57303 .35152 m .57032 .35377 L .57142 .3498 L p F P
0 g
s
.037 0 .143 r
.57142 .3498 m .57749 .34473 L .57303 .35152 L p F P
0 g
s
.757 .709 .807 r
.26865 .44002 m .26903 .43976 L .2656 .43485 L p F P
0 g
s
.757 .709 .807 r
.2656 .43485 m .26178 .43777 L .26865 .44002 L p F P
0 g
s
.733 .757 .872 r
.25412 .44256 m .26178 .43777 L .26865 .44002 L p F P
0 g
s
.251 .594 .949 r
.12295 .41178 m .12476 .41214 L .12881 .41539 L p F P
0 g
s
.268 .603 .953 r
.13347 .41375 m .12476 .41214 L .12881 .41539 L p F P
0 g
s
.268 .603 .953 r
.12881 .41539 m .13722 .41696 L .13347 .41375 L p F P
0 g
s
.754 .965 .679 r
.63458 .26935 m .6406 .26209 L .63734 .26771 L p F P
0 g
s
.754 .965 .679 r
.63377 .27069 m .63458 .26935 L p .63734 .26771 L F P
0 g
s
.754 .965 .679 r
.63734 .26771 m .63587 .26939 L .63377 .27069 L p F P
0 g
s
.318 .638 .965 r
.14097 .42011 m .14343 .42042 L .14772 .42357 L p F P
0 g
s
.331 .643 .966 r
.15161 .42137 m .14343 .42042 L .14772 .42357 L p F P
0 g
s
.331 .643 .966 r
.14772 .42357 m .15534 .42448 L .15161 .42137 L p F P
0 g
s
0 0 .309 r
.81925 .24324 m .81722 .24837 L .81718 .24305 L p F P
0 g
s
0 0 .309 r
.81718 .24305 m .81922 .23791 L .81925 .24324 L p F P
0 g
s
.761 .976 .71 r
.77102 .33541 m .76746 .34084 L .77428 .3333 L p F P
0 g
s
.761 .976 .71 r
.77383 .3323 m .77102 .33541 L p .77428 .3333 L F P
0 g
s
.761 .976 .71 r
.77428 .3333 m .77545 .33154 L .77383 .3323 L p F P
0 g
s
0 0 0 r
.80925 .27679 m .80691 .28195 L .80921 .27585 L p F P
0 g
s
0 0 0 r
.80921 .27585 m .81161 .27067 L .80925 .27679 L p F P
0 g
s
0 0 0 r
.60127 .31351 m .60201 .3122 L .59781 .31684 L p F P
0 g
s
0 0 0 r
.59843 .3175 m .60127 .31351 L p .59781 .31684 L F P
0 g
s
0 0 0 r
.59248 .32383 m .59843 .3175 L p .59781 .31684 L F P
0 g
s
0 0 0 r
.59781 .31684 m .59251 .32375 L .59248 .32383 L p F P
0 g
s
.062 .107 .597 r
.8202 .21792 m .81868 .22295 L .81645 .21837 L p F P
0 g
s
.062 .107 .597 r
.81645 .21837 m .8179 .21337 L .8202 .21792 L p F P
0 g
s
.691 .915 .971 r
.63609 .4233 m .63896 .42456 L .62714 .43017 L p F P
0 g
s
.691 .915 .971 r
.63058 .42587 m .63609 .4233 L p .62714 .43017 L F P
0 g
s
.691 .915 .971 r
.62714 .43017 m .62574 .42952 L .63058 .42587 L p F P
0 g
s
.654 .816 .961 r
.58291 .43922 m .57113 .44333 L .5681 .44063 L p F P
0 g
s
.65 .801 .955 r
.55635 .44438 m .5681 .44063 L .57113 .44333 L p F P
0 g
s
.779 .97 .678 r
.63587 .26939 m .63122 .27499 L .63377 .27069 L closepath p F P
0 g
s
.24 0 .303 r
.55947 .36906 m .55379 .37277 L .55829 .36598 L p F P
0 g
s
.24 0 .303 r
.55829 .36598 m .56026 .36468 L .55947 .36906 L p F P
0 g
s
.614 .598 .811 r
.52362 .43733 m .52482 .43979 L .53549 .43509 L p F P
0 g
s
.632 .635 .835 r
.53845 .44012 m .53549 .43509 L .52482 .43979 L p F P
0 g
s
.73 .962 .941 r
.68076 .40685 m .68001 .4073 L .67725 .40656 L p F P
0 g
s
.767 .858 .918 r
.73813 .17419 m .74085 .17705 L .72899 .18416 L p F P
0 g
s
.767 .858 .918 r
.72779 .18071 m .73813 .17419 L p .72899 .18416 L F P
0 g
s
.767 .858 .918 r
.72899 .18416 m .72722 .18252 L .72779 .18071 L p F P
0 g
s
.891 .494 .265 r
.22752 .35768 m .22551 .3574 L .22505 .35604 L closepath p F P
0 g
s
0 0 0 r
.80603 .28382 m .8053 .2855 L .80691 .28195 L closepath p F P
0 g
s
.885 .59 .483 r
.25057 .3938 m .25401 .39571 L .25385 .39048 L p F P
0 g
s
.885 .59 .483 r
.25385 .39048 m .25197 .38944 L .25057 .3938 L p F P
0 g
s
.645 .771 .94 r
.5681 .44063 m .55635 .44438 L .55328 .44102 L p F P
0 g
s
.727 .97 .932 r
.68076 .40685 m .6918 .39997 L .68908 .39943 L p F P
0 g
s
.727 .97 .932 r
.68908 .39943 m .68708 .40068 L .68076 .40685 L p F P
0 g
s
.73 .962 .941 r
.67725 .40656 m .68708 .40068 L .68076 .40685 L p F P
0 g
s
.818 .659 .686 r
.26396 .42727 m .26985 .42985 L .2738 .42324 L p F P
0 g
s
.818 .659 .686 r
.2738 .42324 m .26758 .42077 L .26396 .42727 L p F P
0 g
s
.375 .162 .456 r
.54521 .39168 m .53875 .39544 L .53899 .39037 L p F P
0 g
s
.375 .162 .456 r
.53899 .39037 m .54699 .3857 L .54521 .39168 L p F P
0 g
s
0 0 .502 r
.82011 .22779 m .8187 .23228 L .81765 .22625 L p F P
0 g
s
0 0 .502 r
.81765 .22625 m .81868 .22295 L .82011 .22779 L p F P
0 g
s
.814 .343 0 r
.19781 .32235 m .19717 .32121 L .20089 .32468 L p F P
0 g
s
.814 .343 0 r
.20089 .32468 m .20145 .32568 L .19781 .32235 L p F P
0 g
s
.507 .731 .974 r
.1917 .43703 m .1956 .43669 L .20063 .43955 L p F P
0 g
s
.506 .726 .972 r
.20266 .43602 m .1956 .43669 L .20063 .43955 L p F P
0 g
s
.506 .726 .972 r
.20063 .43955 m .2063 .43908 L .20266 .43602 L p F P
0 g
s
0 0 .068 r
.81547 .25962 m .81663 .2539 L .81461 .259 L p F P
0 g
s
0 0 .068 r
.8136 .26439 m .81547 .25962 L p .81461 .259 L F P
0 g
s
0 0 .068 r
.81461 .259 m .81369 .26361 L .8136 .26439 L p F P
0 g
s
.874 .604 .528 r
.2537 .40111 m .25908 .40389 L .25939 .39849 L p F P
0 g
s
.874 .604 .528 r
.25939 .39849 m .25401 .39571 L .2537 .40111 L p F P
0 g
s
.701 .863 .454 r
.79646 .30141 m .80045 .29476 L .79779 .29998 L p F P
0 g
s
.701 .863 .454 r
.79528 .30373 m .79646 .30141 L p .79779 .29998 L F P
0 g
s
.701 .863 .454 r
.79779 .29998 m .7965 .30211 L .79528 .30373 L p F P
0 g
s
.769 .997 .841 r
.74174 .36558 m .74146 .36561 L .74222 .36496 L closepath p F P
0 g
s
.183 .545 .929 r
.10502 .40245 m .10792 .40325 L .11175 .4066 L p F P
0 g
s
.205 .558 .935 r
.11541 .40517 m .10792 .40325 L .11175 .4066 L p F P
0 g
s
.205 .558 .935 r
.11175 .4066 m .11918 .40851 L .11541 .40517 L p F P
0 g
s
.764 .994 .868 r
.73175 .37363 m .72976 .37522 L .72716 .37523 L p F P
0 g
s
.63 .75 .934 r
.22459 .44333 m .23575 .44024 L .23931 .4436 L p F P
0 g
s
.643 .749 .927 r
.23575 .44024 m .22459 .44333 L .22098 .44021 L p F P
0 g
s
.858 .618 .575 r
.25811 .40951 m .26373 .4122 L .26475 .40656 L p F P
0 g
s
.858 .618 .575 r
.26475 .40656 m .25908 .40389 L .25811 .40951 L p F P
0 g
s
.84 .636 .628 r
.26175 .41816 m .26758 .42077 L .26969 .41477 L p F P
0 g
s
.84 .636 .628 r
.26969 .41477 m .26373 .4122 L .26175 .41816 L p F P
0 g
s
.836 .944 .893 r
.69178 .2096 m .69107 .20927 L .69229 .20823 L closepath p F P
0 g
s
.57 .454 .682 r
.53165 .42557 m .52983 .41822 L .51914 .42292 L p F P
0 g
s
.57 .454 .682 r
.52532 .42826 m .53165 .42557 L p .51914 .42292 L F P
0 g
s
.57 .454 .682 r
.51914 .42292 m .52047 .4287 L .52532 .42826 L p F P
0 g
s
.71 .944 .957 r
.66263 .41238 m .66543 .41336 L .65361 .41969 L p F P
0 g
s
.71 .944 .957 r
.65189 .41814 m .66263 .41238 L p .65361 .41969 L F P
0 g
s
.71 .944 .957 r
.65361 .41969 m .65109 .41883 L .65189 .41814 L p F P
0 g
s
.772 .986 .743 r
.76368 .34313 m .77102 .33541 L .76746 .34084 L p F P
0 g
s
.772 .986 .743 r
.76285 .34442 m .76368 .34313 L p .76746 .34084 L F P
0 g
s
.772 .986 .743 r
.76746 .34084 m .76471 .34372 L .76285 .34442 L p F P
0 g
s
.472 .545 .85 r
.80055 .17984 m .80014 .1798 L .79865 .1849 L p F P
0 g
s
.472 .545 .85 r
.79865 .1849 m .80339 .18565 L .80055 .17984 L p F P
0 g
s
.761 .996 .846 r
.73175 .37363 m .74146 .36561 L .7389 .36579 L p F P
0 g
s
.761 .996 .846 r
.7389 .36579 m .73628 .36796 L .73175 .37363 L p F P
0 g
s
.764 .994 .868 r
.72716 .37523 m .73628 .36796 L .73175 .37363 L p F P
0 g
s
.884 .452 .104 r
.20487 .33368 m .20874 .33708 L .20683 .33254 L p F P
0 g
s
.884 .452 .104 r
.20683 .33254 m .20298 .32914 L .20487 .33368 L p F P
0 g
s
.874 .434 .077 r
.20145 .32568 m .20298 .32914 L .20683 .33254 L p F P
0 g
s
.757 .984 .745 r
.76471 .34372 m .75987 .34863 L .76285 .34442 L closepath p F P
0 g
s
.773 .965 .664 r
.62893 .2765 m .62517 .28225 L .63122 .27499 L p F P
0 g
s
.773 .965 .664 r
.63312 .27113 m .62893 .2765 L p .63122 .27499 L F P
0 g
s
.773 .965 .664 r
.63122 .27499 m .63377 .27069 L .63312 .27113 L p F P
0 g
s
.389 .676 .974 r
.1698 .42811 m .16468 .42786 L .16919 .43092 L p F P
0 g
s
.389 .676 .974 r
.16919 .43092 m .1735 .43116 L .1698 .42811 L p F P
0 g
s
.381 .674 .974 r
.15906 .42752 m .16468 .42786 L .16919 .43092 L p F P
0 g
s
.614 .598 .811 r
.53549 .43509 m .53533 .43479 L .52362 .43733 L p F P
0 g
s
.607 .548 .762 r
.52091 .43022 m .52362 .43733 L .53533 .43479 L p F P
0 g
s
.389 .674 .973 r
.16468 .42786 m .15906 .42752 L .15534 .42448 L p F P
0 g
s
.679 .855 .45 r
.7965 .30211 m .79363 .30668 L .79528 .30373 L closepath p F P
0 g
s
.623 .69 .891 r
.77031 .17333 m .78253 .17042 L .78528 .17483 L p F P
0 g
s
.638 .705 .896 r
.78253 .17042 m .77031 .17333 L .76758 .16953 L p F P
0 g
s
.681 .749 .903 r
.75552 .1742 m .76758 .16953 L .77031 .17333 L p F P
0 g
s
.746 .753 .858 r
.26178 .43777 m .25412 .44256 L .25061 .43876 L p F P
0 g
s
.69 .741 .89 r
.23931 .4436 m .25061 .43876 L .25412 .44256 L p F P
0 g
s
.38 .462 .82 r
.80625 .19185 m .80678 .19206 L .80664 .19272 L closepath p F P
0 g
s
.292 .39 .792 r
.81281 .19534 m .80678 .19206 L .80664 .19272 L p F P
0 g
s
.292 .39 .792 r
.81158 .20032 m .81281 .19534 L p .80664 .19272 L F P
0 g
s
.165 .224 .679 r
.81938 .20834 m .8179 .21337 L .81468 .20913 L p F P
0 g
s
.165 .224 .679 r
.81468 .20913 m .81604 .20413 L .81938 .20834 L p F P
0 g
s
.693 .76 .904 r
.76758 .16953 m .75552 .1742 L .7528 .17089 L p F P
0 g
s
.686 .914 .581 r
.62467 .28297 m .62434 .28327 L .62517 .28225 L closepath p F P
0 g
s
.768 .992 .779 r
.76226 .34455 m .76285 .34442 L .75987 .34863 L p F P
0 g
s
.768 .992 .779 r
.75543 .35113 m .76226 .34455 L p .75987 .34863 L F P
0 g
s
.768 .992 .779 r
.75253 .35532 m .75543 .35113 L p .75987 .34863 L F P
0 g
s
.768 .992 .779 r
.75987 .34863 m .75312 .35516 L .75253 .35532 L p F P
0 g
s
.891 .467 .149 r
.21055 .34167 m .21461 .345 L .21277 .34042 L p F P
0 g
s
.891 .467 .149 r
.21277 .34042 m .20874 .33708 L .21055 .34167 L p F P
0 g
s
.774 .997 .845 r
.74222 .36496 m .74146 .36561 L .7389 .36579 L p F P
0 g
s
0 0 0 r
.59251 .32375 m .59239 .32391 L .59248 .32383 L closepath p F P
0 g
s
.704 .738 .878 r
.25061 .43876 m .23931 .4436 L .23575 .44024 L p F P
0 g
s
.478 .303 .565 r
.53922 .40665 m .5388 .40083 L .52847 .40601 L p F P
0 g
s
.478 .303 .565 r
.52847 .40601 m .52885 .41178 L .53922 .40665 L p F P
0 g
s
.767 .996 .823 r
.74635 .35939 m .74222 .36496 L .75153 .35664 L p F P
0 g
s
.774 .997 .845 r
.7389 .36579 m .74635 .35939 L .74222 .36496 L p F P
0 g
s
0 0 0 r
.59098 .32725 m .58724 .3309 L .59239 .32391 L p F P
0 g
s
0 0 0 r
.59239 .32391 m .59248 .32383 L .59098 .32725 L p F P
0 g
s
0 0 0 r
.59369 .32438 m .59098 .32725 L .59248 .32383 L p F P
0 g
s
0 0 0 r
.59248 .32383 m .59843 .3175 L .59369 .32438 L p F P
0 g
s
.753 .99 .782 r
.75312 .35516 m .75153 .35664 L .75253 .35532 L closepath p F P
0 g
s
.767 .996 .823 r
.75061 .35559 m .74635 .35939 L p .75153 .35664 L F P
0 g
s
.767 .996 .823 r
.75153 .35664 m .75253 .35532 L .75061 .35559 L p F P
0 g
s
.398 .485 .832 r
.80678 .19206 m .80625 .19185 L .80339 .18565 L p F P
0 g
s
.871 .431 .055 r
.20298 .32914 m .20145 .32568 L .19781 .32235 L p F P
0 g
s
.87 .572 .48 r
.24873 .39289 m .25057 .3938 L .25197 .38944 L p F P
0 g
s
.87 .572 .48 r
.25197 .38944 m .24846 .38769 L .24873 .39289 L p F P
0 g
s
.178 0 .281 r
.56522 .36477 m .55947 .36906 L .56026 .36468 L p F P
0 g
s
.178 0 .281 r
.56026 .36468 m .56891 .35821 L .56522 .36477 L p F P
0 g
s
.895 .481 .195 r
.21633 .34963 m .22059 .35287 L .21883 .34825 L p F P
0 g
s
.895 .481 .195 r
.21883 .34825 m .21461 .345 L .21633 .34963 L p F P
0 g
s
.574 .486 .718 r
.52047 .4287 m .52532 .42826 L .52091 .43022 L closepath p F P
0 g
s
.268 .022 .343 r
.55883 .37361 m .55003 .37935 L .55379 .37277 L p F P
0 g
s
.268 .022 .343 r
.55379 .37277 m .55947 .36906 L .55883 .37361 L p F P
0 g
s
.517 .733 .972 r
.1956 .43669 m .1917 .43703 L .18803 .43405 L p F P
0 g
s
.607 .548 .762 r
.53219 .42721 m .52532 .42826 L .52091 .43022 L p F P
0 g
s
.607 .548 .762 r
.53533 .43479 m .53219 .42721 L p .52091 .43022 L F P
0 g
s
.258 .33 .747 r
.81744 .1991 m .81604 .20413 L .81158 .20032 L p F P
0 g
s
.258 .33 .747 r
.81158 .20032 m .81281 .19534 L .81744 .1991 L p F P
0 g
s
.398 .485 .832 r
.80339 .18565 m .80778 .18714 L .80678 .19206 L p F P
0 g
s
.34 .426 .804 r
.8141 .19032 m .81281 .19534 L .80678 .19206 L p F P
0 g
s
.34 .426 .804 r
.80678 .19206 m .80778 .18714 L .8141 .19032 L p F P
0 g
s
.68 .892 .975 r
.62425 .42877 m .61243 .4339 L .6095 .43221 L p F P
0 g
s
.671 .884 .977 r
.59769 .43701 m .6095 .43221 L .61243 .4339 L p F P
0 g
s
.325 .638 .964 r
.14343 .42042 m .14097 .42011 L .13722 .41696 L p F P
0 g
s
.783 .979 .707 r
.77545 .33154 m .77383 .3323 L .77764 .32792 L closepath p F P
0 g
s
.659 .896 .556 r
.62339 .28361 m .62893 .2765 L .62517 .28225 L p F P
0 g
s
.659 .896 .556 r
.62233 .2852 m .62339 .28361 L p .62517 .28225 L F P
0 g
s
.659 .896 .556 r
.62517 .28225 m .62434 .28327 L .62233 .2852 L p F P
0 g
s
.718 .951 .952 r
.66609 .41357 m .66543 .41336 L .66776 .41206 L closepath p F P
0 g
s
.836 .948 .893 r
.69229 .20823 m .69107 .20927 L .68833 .20805 L p F P
0 g
s
.864 .962 .865 r
.68342 .21641 m .69107 .20927 L .68833 .20805 L p F P
0 g
s
.897 .497 .248 r
.22175 .35632 m .22059 .35287 L .22505 .35604 L p F P
0 g
s
.897 .497 .248 r
.22505 .35604 m .22551 .3574 L .22175 .35632 L p F P
0 g
s
.844 .922 .884 r
.69398 .20302 m .69229 .20823 L .70223 .19969 L p F P
0 g
s
.836 .948 .893 r
.68833 .20805 m .69398 .20302 L .69229 .20823 L p F P
0 g
s
.685 .906 .561 r
.62434 .28327 m .61951 .28939 L .62233 .2852 L closepath p F P
0 g
s
.864 .962 .865 r
.68833 .20805 m .68507 .21123 L .68342 .21641 L p F P
0 g
s
.849 .969 .875 r
.67677 .21924 m .68507 .21123 L .68342 .21641 L p F P
0 g
s
.849 .969 .875 r
.67673 .21933 m .67677 .21924 L p .68342 .21641 L F P
0 g
s
.849 .969 .875 r
.68342 .21641 m .67942 .22009 L .67673 .21933 L p F P
0 g
s
0 0 .421 r
.8193 .23771 m .81922 .23791 L .81849 .23282 L p F P
0 g
s
0 0 .421 r
.81849 .23282 m .8187 .23228 L .8193 .23771 L p F P
0 g
s
.869 .966 .858 r
.67942 .22009 m .67514 .22439 L .67673 .21933 L closepath p F P
0 g
s
.738 .973 .927 r
.69762 .39623 m .6918 .39997 L .68908 .39943 L p F P
0 g
s
.732 .912 .547 r
.79184 .30828 m .78891 .31356 L .79363 .30668 L p F P
0 g
s
.732 .912 .547 r
.79428 .30472 m .79184 .30828 L p .79363 .30668 L F P
0 g
s
.732 .912 .547 r
.79363 .30668 m .79528 .30373 L .79428 .30472 L p F P
0 g
s
.808 .709 .756 r
.26218 .42962 m .26396 .42727 L .26985 .42985 L p F P
0 g
s
.808 .709 .756 r
.26985 .42985 m .2656 .43485 L .26218 .42962 L p F P
0 g
s
0 0 0 r
.8064 .28308 m .80925 .27679 L .80691 .28195 L p F P
0 g
s
0 0 0 r
.80473 .28679 m .8064 .28308 L p .80691 .28195 L F P
0 g
s
0 0 0 r
.80691 .28195 m .8053 .2855 L .80473 .28679 L p F P
0 g
s
.259 .594 .949 r
.12476 .41214 m .12295 .41178 L .11918 .40851 L p F P
0 g
s
.853 .988 .848 r
.67669 .21931 m .67673 .21933 L .67514 .22439 L p F P
0 g
s
.853 .988 .848 r
.66946 .22691 m .67669 .21931 L p .67514 .22439 L F P
0 g
s
.853 .988 .848 r
.66749 .23163 m .66946 .22691 L p .67514 .22439 L F P
0 g
s
.853 .988 .848 r
.67514 .22439 m .66781 .23166 L .66749 .23163 L p F P
0 g
s
.91 .551 .343 r
.22746 .3657 m .23198 .36883 L .23089 .36395 L p F P
0 g
s
.91 .551 .343 r
.23089 .36395 m .2264 .36081 L .22746 .3657 L p F P
0 g
s
.841 .919 .886 r
.70275 .19924 m .70223 .19969 L .70238 .19901 L closepath p F P
0 g
s
.844 .922 .884 r
.70002 .19759 m .69398 .20302 L p .70223 .19969 L F P
0 g
s
.844 .922 .884 r
.70223 .19969 m .70238 .19901 L .70002 .19759 L p F P
0 g
s
.731 .827 .924 r
.74794 .1734 m .74085 .17705 L .73813 .17419 L p F P
0 g
s
.555 .648 .896 r
.78528 .17483 m .78543 .17482 L .78541 .17504 L closepath p F P
0 g
s
.508 .619 .897 r
.79774 .17449 m .78543 .17482 L .78541 .17504 L p F P
0 g
s
.508 .619 .897 r
.80028 .17932 m .79774 .17449 L p .78541 .17504 L F P
0 g
s
.508 .619 .897 r
.80014 .1798 m .80028 .17932 L p .78541 .17504 L F P
0 g
s
.82 .92 .903 r
.71371 .19063 m .70275 .19924 L .70238 .19901 L p F P
0 g
s
.775 .716 .796 r
.26178 .43777 m .2656 .43485 L .26218 .42962 L p F P
0 g
s
.775 .716 .796 r
.26218 .42962 m .25566 .43528 L .26178 .43777 L p F P
0 g
s
.746 .753 .858 r
.25061 .43876 m .25566 .43528 L .26178 .43777 L p F P
0 g
s
.691 .905 .972 r
.62574 .42952 m .62425 .42877 L .63058 .42587 L closepath p F P
0 g
s
.57 .664 .902 r
.78543 .17482 m .78528 .17483 L .78253 .17042 L p F P
0 g
s
0 0 0 r
.5891 .33121 m .58225 .33785 L .58724 .3309 L p F P
0 g
s
0 0 0 r
.58974 .33027 m .5891 .33121 L p .58724 .3309 L F P
0 g
s
0 0 0 r
.58724 .3309 m .59098 .32725 L .58974 .33027 L p F P
0 g
s
0 0 .085 r
.81369 .26361 m .81345 .26472 L .8136 .26439 L closepath p F P
0 g
s
.57 .664 .902 r
.78253 .17042 m .78579 .17006 L .78543 .17482 L p F P
0 g
s
.541 .616 .876 r
.79494 .1694 m .78579 .17006 L .78543 .17482 L p F P
0 g
s
.541 .616 .876 r
.78543 .17482 m .79774 .17449 L .79494 .1694 L p F P
0 g
s
.873 .984 .833 r
.66781 .23166 m .66726 .23225 L .66749 .23163 L closepath p F P
0 g
s
0 0 .394 r
.82083 .23289 m .8193 .23771 L .8187 .23228 L p F P
0 g
s
0 0 .394 r
.8187 .23228 m .82011 .22779 L .82083 .23289 L p F P
0 g
s
.67 .858 .971 r
.59769 .43701 m .59612 .43761 L .5974 .43682 L closepath p F P
0 g
s
.672 .841 .964 r
.59471 .43491 m .5974 .43682 L .59612 .43761 L p F P
0 g
s
.672 .841 .964 r
.58291 .43922 m .59471 .43491 L p .59612 .43761 L F P
0 g
s
.904 .562 .386 r
.23284 .3738 m .23759 .37684 L .23669 .37188 L p F P
0 g
s
.904 .562 .386 r
.23669 .37188 m .23198 .36883 L .23284 .3738 L p F P
0 g
s
.874 .986 .829 r
.66234 .23453 m .66018 .23984 L .66726 .23225 L p F P
0 g
s
.874 .986 .829 r
.66507 .23147 m .66234 .23453 L p .66726 .23225 L F P
0 g
s
.874 .986 .829 r
.66726 .23225 m .66749 .23163 L .66507 .23147 L p F P
0 g
s
.823 .994 .752 r
.64567 .25681 m .64467 .25718 L .64677 .25479 L closepath p F P
0 g
s
.786 .998 .818 r
.75253 .35532 m .75061 .35559 L .75543 .35113 L closepath p F P
0 g
s
.301 .074 .393 r
.54931 .37982 m .54916 .38136 L .55003 .37935 L closepath p F P
0 g
s
0 0 .178 r
.81864 .24878 m .81663 .2539 L .81722 .24837 L p F P
0 g
s
0 0 .178 r
.81722 .24837 m .81925 .24324 L .81864 .24878 L p F P
0 g
s
.736 .98 .914 r
.7036 .39224 m .69762 .39623 L .70171 .39198 L closepath p F P
0 g
s
.738 .973 .927 r
.70091 .3918 m .70171 .39198 L .69762 .39623 L p F P
0 g
s
.738 .973 .927 r
.68908 .39943 m .70091 .3918 L p .69762 .39623 L F P
0 g
s
.634 .712 .903 r
.53845 .44012 m .5502 .43703 L .55328 .44102 L p F P
0 g
s
.632 .647 .847 r
.53549 .43509 m .53845 .44012 L .5502 .43703 L p F P
0 g
s
.894 .572 .431 r
.23818 .38191 m .2432 .38485 L .24256 .37979 L p F P
0 g
s
.894 .572 .431 r
.24256 .37979 m .23759 .37684 L .23818 .38191 L p F P
0 g
s
0 0 .032 r
.58133 .3387 m .58098 .33972 L .58225 .33785 L closepath p F P
0 g
s
.7 .924 .967 r
.65079 .41871 m .63896 .42456 L .63609 .4233 L p F P
0 g
s
.674 .895 .541 r
.61815 .29063 m .61389 .29653 L .61951 .28939 L p F P
0 g
s
.674 .895 .541 r
.62157 .28598 m .61815 .29063 L p .61951 .28939 L F P
0 g
s
.674 .895 .541 r
.61951 .28939 m .62233 .2852 L .62157 .28598 L p F P
0 g
s
.82 .92 .903 r
.70238 .19901 m .7038 .19452 L p .71371 .19063 L F P
0 g
s
.828 .923 .898 r
.70238 .19901 m .70002 .19759 L .7038 .19452 L closepath p F P
0 g
s
0 0 0 r
.81281 .26799 m .81161 .27067 L .81345 .26472 L p F P
0 g
s
0 0 0 r
.81345 .26472 m .8136 .26439 L .81281 .26799 L p F P
0 g
s
.831 .668 .68 r
.25935 .42504 m .26396 .42727 L .26758 .42077 L p F P
0 g
s
.831 .668 .68 r
.25877 .42395 m .25935 .42504 L p .26758 .42077 L F P
0 g
s
.831 .668 .68 r
.26758 .42077 m .26175 .41816 L .25877 .42395 L p F P
0 g
s
.674 .859 .97 r
.60686 .43055 m .6095 .43221 L .59769 .43701 L p F P
0 g
s
.674 .859 .97 r
.59769 .43701 m .5974 .43682 L .60686 .43055 L p F P
0 g
s
.769 .86 .917 r
.72722 .18252 m .72627 .18165 L .72779 .18071 L closepath p F P
0 g
s
.912 .535 .295 r
.2264 .36081 m .22551 .3574 L .22175 .35632 L p F P
0 g
s
.723 .947 .953 r
.66776 .41206 m .66543 .41336 L .66263 .41238 L p F P
0 g
s
.528 .372 .613 r
.52729 .41246 m .52885 .41178 L .529 .41293 L closepath p F P
0 g
s
.821 .894 .894 r
.71448 .19002 m .71371 .19063 L .7139 .18958 L closepath p F P
0 g
s
.82 .92 .903 r
.71175 .18797 m .7139 .18958 L .71371 .19063 L p F P
0 g
s
.82 .92 .903 r
.7038 .19452 m .71175 .18797 L p .71371 .19063 L F P
0 g
s
.562 .812 .434 r
.61321 .29741 m .6128 .29794 L .61389 .29653 L closepath p F P
0 g
s
.803 .893 .908 r
.72355 .17922 m .72627 .18165 L .71448 .19002 L p F P
0 g
s
.803 .893 .908 r
.7151 .18551 m .72355 .17922 L p .71448 .19002 L F P
0 g
s
.803 .893 .908 r
.71448 .19002 m .7139 .18958 L .7151 .18551 L p F P
0 g
s
.863 .988 .837 r
.66749 .23163 m .66507 .23147 L .66946 .22691 L closepath p F P
0 g
s
.845 .999 .807 r
.65566 .242 m .66234 .23453 L .66018 .23984 L p F P
0 g
s
.845 .999 .807 r
.65462 .24425 m .65566 .242 L p .66018 .23984 L F P
0 g
s
.845 .999 .807 r
.66018 .23984 m .65623 .24404 L .65462 .24425 L p F P
0 g
s
.881 .583 .479 r
.24342 .39006 m .24873 .39289 L .24846 .38769 L p F P
0 g
s
.881 .583 .479 r
.24846 .38769 m .2432 .38485 L .24342 .39006 L p F P
0 g
s
.578 .745 .956 r
.2063 .43908 m .21737 .43703 L .22098 .44021 L p F P
0 g
s
.587 .745 .952 r
.21737 .43703 m .2063 .43908 L .20266 .43602 L p F P
0 g
s
0 0 0 r
.8053 .2855 m .804 .28825 L .80473 .28679 L closepath p F P
0 g
s
0 0 0 r
.81378 .26553 m .81281 .26799 L .8136 .26439 L p F P
0 g
s
0 0 0 r
.8136 .26439 m .81547 .25962 L .81378 .26553 L p F P
0 g
s
.32 .093 .404 r
.55835 .37839 m .55883 .37361 L .55003 .37935 L p F P
0 g
s
.32 .093 .404 r
.54886 .38463 m .55835 .37839 L p .55003 .37935 L F P
0 g
s
.32 .093 .404 r
.55003 .37935 m .54916 .38136 L .54886 .38463 L p F P
0 g
s
.325 .638 .964 r
.13722 .41696 m .13926 .41722 L .14343 .42042 L p F P
0 g
s
.338 .643 .965 r
.14787 .4182 m .13926 .41722 L .14343 .42042 L p F P
0 g
s
.338 .643 .965 r
.14343 .42042 m .15161 .42137 L .14787 .4182 L p F P
0 g
s
.852 .646 .624 r
.25625 .41544 m .26175 .41816 L .26373 .4122 L p F P
0 g
s
.852 .646 .624 r
.26373 .4122 m .25811 .40951 L .25625 .41544 L p F P
0 g
s
.448 .704 .976 r
.1735 .43116 m .18435 .43101 L .18803 .43405 L p F P
0 g
s
.454 .703 .974 r
.18435 .43101 m .1735 .43116 L .1698 .42811 L p F P
0 g
s
.673 .852 .968 r
.60655 .43034 m .60686 .43055 L .5974 .43682 L p F P
0 g
s
.673 .852 .968 r
.5974 .43682 m .59471 .43491 L .60655 .43034 L p F P
0 g
s
.756 .938 .598 r
.78661 .31534 m .79184 .30828 L .78891 .31356 L p F P
0 g
s
.756 .938 .598 r
.78459 .31905 m .78661 .31534 L p .78891 .31356 L F P
0 g
s
.756 .938 .598 r
.78891 .31356 m .78527 .3185 L .78459 .31905 L p F P
0 g
s
.883 .613 .524 r
.25019 .39916 m .2537 .40111 L .25401 .39571 L p F P
0 g
s
.883 .613 .524 r
.25401 .39571 m .25057 .3938 L .25019 .39916 L p F P
0 g
s
.259 .594 .949 r
.11918 .40851 m .12082 .40884 L .12476 .41214 L p F P
0 g
s
.276 .603 .953 r
.12971 .41047 m .12082 .40884 L .12476 .41214 L p F P
0 g
s
.276 .603 .953 r
.12476 .41214 m .13347 .41375 L .12971 .41047 L p F P
0 g
s
.869 .628 .572 r
.25278 .40672 m .25811 .40951 L .25908 .40389 L p F P
0 g
s
.869 .628 .572 r
.25908 .40389 m .2537 .40111 L .25278 .40672 L p F P
0 g
s
.419 .504 .84 r
.80778 .18714 m .80339 .18565 L .80055 .17984 L p F P
0 g
s
.866 .996 .796 r
.65623 .24404 m .6533 .24737 L .65462 .24425 L closepath p F P
0 g
s
.719 .959 .946 r
.67725 .40656 m .66776 .41206 L .67453 .4058 L closepath p F P
0 g
s
.723 .947 .953 r
.67449 .40579 m .67453 .4058 L .66776 .41206 L p F P
0 g
s
.723 .947 .953 r
.66263 .41238 m .67449 .40579 L p .66776 .41206 L F P
0 g
s
.517 .733 .972 r
.18803 .43405 m .19063 .43379 L .1956 .43669 L p F P
0 g
s
.516 .727 .969 r
.19901 .43291 m .19063 .43379 L .1956 .43669 L p F P
0 g
s
.516 .727 .969 r
.1956 .43669 m .20266 .43602 L .19901 .43291 L p F P
0 g
s
0 0 .504 r
.82167 .22277 m .82011 .22779 L .81868 .22295 L p F P
0 g
s
0 0 .504 r
.81868 .22295 m .8202 .21792 L .82167 .22277 L p F P
0 g
s
.748 .982 .91 r
.71222 .38629 m .7036 .39224 L .70171 .39198 L p F P
0 g
s
.408 .217 .507 r
.5452 .39711 m .5388 .40083 L .53875 .39544 L p F P
0 g
s
.408 .217 .507 r
.53875 .39544 m .54521 .39168 L .5452 .39711 L p F P
0 g
s
.66 .831 .965 r
.59471 .43491 m .58291 .43922 L .5799 .4367 L p F P
0 g
s
.654 .816 .961 r
.5681 .44063 m .5799 .4367 L .58291 .43922 L p F P
0 g
s
.588 .513 .738 r
.52532 .42826 m .53165 .42557 L .53219 .42721 L closepath p F P
0 g
s
0 0 .07 r
.58486 .33793 m .5891 .33121 L .58225 .33785 L p F P
0 g
s
0 0 .07 r
.58009 .34248 m .58486 .33793 L p .58225 .33785 L F P
0 g
s
0 0 .07 r
.58225 .33785 m .58098 .33972 L .58009 .34248 L p F P
0 g
s
.518 .365 .612 r
.54017 .41305 m .53922 .40665 L .52885 .41178 L p F P
0 g
s
.518 .365 .612 r
.53541 .41538 m .54017 .41305 L p .52885 .41178 L F P
0 g
s
.518 .365 .612 r
.52885 .41178 m .529 .41293 L .53541 .41538 L p F P
0 g
s
.645 .771 .94 r
.55328 .44102 m .56506 .43752 L .5681 .44063 L p F P
0 g
s
.635 .733 .919 r
.56506 .43752 m .55328 .44102 L .5502 .43703 L p F P
0 g
s
.866 .996 .788 r
.6494 .24935 m .64677 .25479 L .6533 .24737 L p F P
0 g
s
.866 .996 .788 r
.65348 .24444 m .6494 .24935 L p .6533 .24737 L F P
0 g
s
.866 .996 .788 r
.6533 .24737 m .65462 .24425 L .65348 .24444 L p F P
0 g
s
.742 .816 .91 r
.74794 .1734 m .7528 .17089 L .75007 .16765 L p F P
0 g
s
.742 .816 .91 r
.75007 .16765 m .7484 .16858 L .74794 .1734 L p F P
0 g
s
.731 .827 .924 r
.73813 .17419 m .7484 .16858 L .74794 .1734 L p F P
0 g
s
.352 .119 .413 r
.54916 .38136 m .54699 .3857 L .54886 .38463 L closepath p F P
0 g
s
0 0 0 r
.61308 .2976 m .61815 .29063 L .61389 .29653 L p F P
0 g
s
0 0 0 r
.61389 .29653 m .6128 .29794 L .61121 .30013 L p F P
0 g
s
0 0 0 r
.61121 .30013 m .61308 .2976 L p .61389 .29653 L F P
0 g
s
.649 .79 .95 r
.5799 .4367 m .5681 .44063 L .56506 .43752 L p F P
0 g
s
.672 .821 .384 r
.80309 .28952 m .80045 .29476 L .804 .28825 L p F P
0 g
s
.672 .821 .384 r
.80319 .28932 m .80309 .28952 L p .804 .28825 L F P
0 g
s
.672 .821 .384 r
.804 .28825 m .80473 .28679 L .80319 .28932 L p F P
0 g
s
.805 .896 .907 r
.7139 .18958 m .71175 .18797 L .7151 .18551 L closepath p F P
0 g
s
0 0 .078 r
.58098 .33972 m .57749 .34473 L .58009 .34248 L closepath p F P
0 g
s
.389 .674 .973 r
.15534 .42448 m .16028 .42475 L .16468 .42786 L p F P
0 g
s
.396 .676 .973 r
.16609 .42501 m .16028 .42475 L .16468 .42786 L p F P
0 g
s
.396 .676 .973 r
.16468 .42786 m .1698 .42811 L .16609 .42501 L p F P
0 g
s
.51 .375 .633 r
.529 .41293 m .53541 .41538 L .52983 .41822 L closepath p F P
0 g
s
0 0 0 r
.6128 .29794 m .60859 .30356 L .61121 .30013 L closepath p F P
0 g
s
.738 .934 .598 r
.78527 .3185 m .78364 .32062 L .78459 .31905 L closepath p F P
0 g
s
.643 .749 .927 r
.22098 .44021 m .23217 .43681 L .23575 .44024 L p F P
0 g
s
.654 .75 .92 r
.23217 .43681 m .22098 .44021 L .21737 .43703 L p F P
0 g
s
.871 .431 .055 r
.19781 .32235 m .19927 .32566 L .20298 .32914 L p F P
0 g
s
.882 .45 .083 r
.20115 .33021 m .20487 .33368 L .20298 .32914 L p F P
0 g
s
.882 .45 .083 r
.20298 .32914 m .19927 .32566 L .20115 .33021 L p F P
0 g
s
.065 0 .181 r
.57032 .35377 m .56944 .35738 L .57303 .35152 L closepath p F P
0 g
s
.759 .75 .845 r
.25566 .43528 m .25061 .43876 L .24709 .43484 L p F P
0 g
s
.704 .738 .878 r
.23575 .44024 m .24709 .43484 L .25061 .43876 L p F P
0 g
s
.77 .866 .92 r
.72779 .18071 m .72627 .18165 L .72355 .17922 L p F P
0 g
s
.892 .468 .131 r
.20666 .33827 m .21055 .34167 L .20874 .33708 L p F P
0 g
s
.892 .468 .131 r
.20874 .33708 m .20487 .33368 L .20666 .33827 L p F P
0 g
s
.771 .967 .673 r
.78081 .32258 m .77764 .32792 L .78364 .32062 L p F P
0 g
s
.771 .967 .673 r
.78292 .32 m .78081 .32258 L p .78364 .32062 L F P
0 g
s
.771 .967 .673 r
.78364 .32062 m .78459 .31905 L .78292 .32 L p F P
0 g
s
.638 .705 .896 r
.76758 .16953 m .77978 .16617 L .78253 .17042 L p F P
0 g
s
.651 .72 .899 r
.77978 .16617 m .76758 .16953 L .76485 .16583 L p F P
0 g
s
.693 .76 .904 r
.7528 .17089 m .76485 .16583 L .76758 .16953 L p F P
0 g
s
.815 .992 .744 r
.64329 .25664 m .6494 .24935 L .64677 .25479 L p F P
0 g
s
.815 .992 .744 r
.64259 .258 m .64329 .25664 L p .64677 .25479 L F P
0 g
s
.815 .992 .744 r
.64677 .25479 m .64467 .25718 L .64259 .258 L p F P
0 g
s
.395 .674 .972 r
.16028 .42475 m .15534 .42448 L .15161 .42137 L p F P
0 g
s
.746 .987 .896 r
.71539 .38402 m .71222 .38629 L .71433 .38394 L closepath p F P
0 g
s
.748 .982 .91 r
.71273 .38367 m .71433 .38394 L .71222 .38629 L p F P
0 g
s
.748 .982 .91 r
.70324 .39025 m .71273 .38367 L p .71222 .38629 L F P
0 g
s
.748 .982 .91 r
.70171 .39198 m .70324 .39025 L p .71222 .38629 L F P
0 g
s
.77 .866 .92 r
.72355 .17922 m .72904 .17561 L .72779 .18071 L p F P
0 g
s
.782 .866 .911 r
.72779 .18071 m .73813 .17419 L .73541 .17138 L p F P
0 g
s
.782 .866 .911 r
.73541 .17138 m .72904 .17561 L .72779 .18071 L p F P
0 g
s
.717 .737 .867 r
.24709 .43484 m .23575 .44024 L .23217 .43681 L p F P
0 g
s
.696 .896 .969 r
.63058 .42587 m .62425 .42877 L .62134 .42715 L p F P
0 g
s
.68 .892 .975 r
.6095 .43221 m .62134 .42715 L .62425 .42877 L p F P
0 g
s
0 0 0 r
.60201 .3122 m .60127 .31351 L .6034 .31056 L closepath p F P
0 g
s
.817 .703 .739 r
.26396 .42727 m .25935 .42504 L .26218 .42962 L closepath p F P
0 g
s
.899 .485 .18 r
.21224 .34632 m .21633 .34963 L .21461 .345 L p F P
0 g
s
.899 .485 .18 r
.21461 .345 m .21055 .34167 L .21224 .34632 L p F P
0 g
s
.839 .992 .738 r
.64467 .25718 m .6406 .26209 L .64259 .258 L closepath p F P
0 g
s
.704 .771 .904 r
.76485 .16583 m .7528 .17089 L .75007 .16765 L p F P
0 g
s
.07 .115 .602 r
.82173 .21288 m .8202 .21792 L .8179 .21337 L p F P
0 g
s
.07 .115 .602 r
.8179 .21337 m .81938 .20834 L .82173 .21288 L p F P
0 g
s
.759 .989 .892 r
.72499 .3769 m .71539 .38402 L .71433 .38394 L p F P
0 g
s
.76 .919 .549 r
.79528 .30373 m .79428 .30472 L .79646 .30141 L closepath p F P
0 g
s
.783 .703 .776 r
.25566 .43528 m .26218 .42962 L .25935 .42504 L p F P
0 g
s
.783 .703 .776 r
.25004 .43261 m .25566 .43528 L p .25935 .42504 L F P
0 g
s
.759 .75 .845 r
.24709 .43484 m .25004 .43261 L .25566 .43528 L p F P
0 g
s
.709 .934 .962 r
.65109 .41883 m .65079 .41871 L .65189 .41814 L closepath p F P
0 g
s
0 0 .299 r
.8195 .24259 m .81925 .24324 L .81922 .23791 L p F P
0 g
s
0 0 .299 r
.81922 .23791 m .8193 .23771 L .8195 .24259 L p F P
0 g
s
.004 0 .116 r
.57896 .3464 m .57303 .35152 L .57749 .34473 L p F P
0 g
s
.004 0 .116 r
.57749 .34473 m .58009 .34248 L .57896 .3464 L p F P
0 g
s
.77 .964 .664 r
.63377 .27069 m .63312 .27113 L .63458 .26935 L closepath p F P
0 g
s
0 0 0 r
.60817 .30452 m .6034 .31056 L .60859 .30356 L p F P
0 g
s
0 0 0 r
.61003 .30185 m .60817 .30452 L p .60859 .30356 L F P
0 g
s
0 0 0 r
.60859 .30356 m .61121 .30013 L .61003 .30185 L p F P
0 g
s
0 0 0 r
.81157 .27162 m .80925 .27679 L .81161 .27067 L p F P
0 g
s
0 0 0 r
.81188 .27078 m .81157 .27162 L p .81161 .27067 L F P
0 g
s
0 0 0 r
.81161 .27067 m .81281 .26799 L .81188 .27078 L p F P
0 g
s
.73 .961 .942 r
.68708 .40068 m .67725 .40656 L .67453 .4058 L p F P
0 g
s
.902 .499 .229 r
.2179 .35434 m .21633 .34963 L .22059 .35287 L p F P
0 g
s
.902 .499 .229 r
.21881 .35502 m .2179 .35434 L p .22059 .35287 L F P
0 g
s
.902 .499 .229 r
.22059 .35287 m .22175 .35632 L .21881 .35502 L p F P
0 g
s
.61 .611 .827 r
.53533 .43479 m .53663 .43453 L .53549 .43509 L closepath p F P
0 g
s
.632 .647 .847 r
.5471 .43218 m .53663 .43453 L .53549 .43509 L p F P
0 g
s
.632 .647 .847 r
.5502 .43703 m .5471 .43218 L p .53549 .43509 L F P
0 g
s
0 0 .27 r
.82089 .23821 m .8195 .24259 L .8193 .23771 L p F P
0 g
s
0 0 .27 r
.8193 .23771 m .82083 .23289 L .82089 .23821 L p F P
0 g
s
.382 .168 .459 r
.54864 .38971 m .54521 .39168 L .54699 .3857 L p F P
0 g
s
.382 .168 .459 r
.54699 .3857 m .54886 .38463 L .54864 .38971 L p F P
0 g
s
.587 .574 .806 r
.53663 .43453 m .53533 .43479 L .53219 .42721 L p F P
0 g
s
.525 .734 .97 r
.19063 .43379 m .18803 .43405 L .18435 .43101 L p F P
0 g
s
.868 .599 .528 r
.24842 .39829 m .25019 .39916 L .25057 .3938 L p F P
0 g
s
.868 .599 .528 r
.25057 .3938 m .24873 .39289 L .24842 .39829 L p F P
0 g
s
.793 .997 .788 r
.76285 .34442 m .76226 .34455 L .76368 .34313 L closepath p F P
0 g
s
.332 .637 .963 r
.13926 .41722 m .13722 .41696 L .13347 .41375 L p F P
0 g
s
.209 0 .323 r
.56213 .37115 m .55883 .37361 L .55947 .36906 L p F P
0 g
s
.209 0 .323 r
.55947 .36906 m .56522 .36477 L .56213 .37115 L p F P
0 g
s
.785 .98 .709 r
.77429 .33005 m .78081 .32258 L .77764 .32792 L p F P
0 g
s
.785 .98 .709 r
.77268 .33283 m .77429 .33005 L p .77764 .32792 L F P
0 g
s
.785 .98 .709 r
.77764 .32792 m .77383 .3323 L .77268 .33283 L p F P
0 g
s
0 0 .04 r
.81744 .25452 m .81547 .25962 L .81663 .2539 L p F P
0 g
s
0 0 .04 r
.81663 .2539 m .81864 .24878 L .81744 .25452 L p F P
0 g
s
.707 .834 .393 r
.80473 .28679 m .80319 .28932 L .8064 .28308 L closepath p F P
0 g
s
.912 .535 .295 r
.22175 .35632 m .22209 .3576 L .2264 .36081 L p F P
0 g
s
.918 .559 .335 r
.22311 .3625 m .22746 .3657 L .2264 .36081 L p F P
0 g
s
.918 .559 .335 r
.2264 .36081 m .22209 .3576 L .22311 .3625 L p F P
0 g
s
.837 .99 .726 r
.63763 .26379 m .63458 .26935 L .6406 .26209 L p F P
0 g
s
.837 .99 .726 r
.64191 .2583 m .63763 .26379 L p .6406 .26209 L F P
0 g
s
.837 .99 .726 r
.6406 .26209 m .64259 .258 L .64191 .2583 L p F P
0 g
s
.715 .927 .962 r
.65189 .41814 m .65079 .41871 L .64794 .41745 L p F P
0 g
s
.7 .924 .967 r
.63609 .4233 m .64794 .41745 L .65079 .41871 L p F P
0 g
s
.491 .567 .86 r
.80014 .1798 m .80028 .17932 L .80055 .17984 L closepath p F P
0 g
s
.585 .675 .902 r
.78579 .17006 m .78253 .17042 L .77978 .16617 L p F P
0 g
s
.539 .435 .685 r
.54206 .42049 m .53165 .42557 L .52983 .41822 L p F P
0 g
s
.539 .435 .685 r
.5408 .41592 m .54206 .42049 L p .52983 .41822 L F P
0 g
s
.539 .435 .685 r
.52983 .41822 m .53541 .41538 L .5408 .41592 L p F P
0 g
s
.912 .57 .38 r
.22828 .37069 m .23284 .3738 L .23198 .36883 L p F P
0 g
s
.912 .57 .38 r
.23198 .36883 m .22746 .3657 L .22828 .37069 L p F P
0 g
s
.844 .685 .685 r
.25542 .41724 m .25625 .41544 L .26175 .41816 L p F P
0 g
s
.844 .685 .685 r
.26175 .41816 m .25877 .42395 L .25542 .41724 L p F P
0 g
s
.712 .936 .96 r
.65189 .41814 m .66263 .41238 L .65982 .41134 L p F P
0 g
s
.712 .936 .96 r
.65982 .41134 m .65926 .41164 L .65189 .41814 L p F P
0 g
s
.715 .927 .962 r
.64794 .41745 m .65926 .41164 L .65189 .41814 L p F P
0 g
s
.727 .882 .481 r
.79901 .29621 m .79646 .30141 L .80045 .29476 L p F P
0 g
s
.727 .882 .481 r
.80045 .29476 m .80309 .28952 L .79901 .29621 L p F P
0 g
s
.419 .504 .84 r
.80055 .17984 m .80884 .18217 L .80778 .18714 L p F P
0 g
s
.401 .515 .859 r
.80028 .17932 m .80055 .17984 L .80884 .18217 L p F P
0 g
s
.266 .593 .949 r
.12082 .40884 m .11918 .40851 L .11541 .40517 L p F P
0 g
s
.587 .574 .806 r
.54602 .43016 m .53663 .43453 L p .53219 .42721 L F P
0 g
s
.618 .62 .831 r
.53663 .43453 m .54602 .43016 L .5471 .43218 L closepath p F P
0 g
s
.756 .993 .875 r
.72716 .37523 m .72499 .3769 L .7264 .37522 L closepath p F P
0 g
s
.759 .989 .892 r
.72454 .37502 m .7264 .37522 L .72499 .3769 L p F P
0 g
s
.759 .989 .892 r
.71716 .3805 m .72454 .37502 L p .72499 .3769 L F P
0 g
s
.759 .989 .892 r
.71433 .38394 m .71716 .3805 L p .72499 .3769 L F P
0 g
s
.182 .241 .689 r
.82046 .20462 m .81938 .20834 L .81604 .20413 L p F P
0 g
s
.182 .241 .689 r
.81959 .20164 m .82046 .20462 L p .81604 .20413 L F P
0 g
s
.182 .241 .689 r
.81604 .20413 m .81744 .1991 L .81959 .20164 L p F P
0 g
s
.904 .582 .427 r
.23339 .37889 m .23818 .38191 L .23759 .37684 L p F P
0 g
s
.904 .582 .427 r
.23759 .37684 m .23284 .3738 L .23339 .37889 L p F P
0 g
s
.77 .978 .711 r
.77383 .3323 m .77102 .33541 L .77268 .33283 L closepath p F P
0 g
s
.467 .564 .869 r
.79774 .17449 m .80088 .17492 L .80028 .17932 L closepath p F P
0 g
s
.401 .515 .859 r
.81001 .17716 m .80088 .17492 L .80028 .17932 L p F P
0 g
s
.401 .515 .859 r
.80884 .18217 m .81001 .17716 L p .80028 .17932 L F P
0 g
s
.769 .994 .871 r
.73628 .36796 m .72716 .37523 L .7264 .37522 L p F P
0 g
s
.795 .97 .67 r
.78459 .31905 m .78292 .32 L .78661 .31534 L closepath p F P
0 g
s
.892 .595 .476 r
.23836 .38714 m .24342 .39006 L .2432 .38485 L p F P
0 g
s
.892 .595 .476 r
.2432 .38485 m .23818 .38191 L .23836 .38714 L p F P
0 g
s
.682 .875 .971 r
.61841 .42539 m .62134 .42715 L .6095 .43221 L p F P
0 g
s
.682 .875 .971 r
.60793 .42978 m .61841 .42539 L p .6095 .43221 L F P
0 g
s
.682 .875 .971 r
.6095 .43221 m .60686 .43055 L .60793 .42978 L p F P
0 g
s
0 0 0 r
.59098 .32725 m .58974 .33027 L .59369 .32438 L closepath p F P
0 g
s
.864 .653 .616 r
.25401 .41425 m .25625 .41544 L .25811 .40951 L p F P
0 g
s
.864 .653 .616 r
.25217 .40885 m .25401 .41425 L p .25811 .40951 L F P
0 g
s
.864 .653 .616 r
.25811 .40951 m .25278 .40672 L .25217 .40885 L p F P
0 g
s
.788 .993 .765 r
.76706 .33775 m .76368 .34313 L .77102 .33541 L p F P
0 g
s
.788 .993 .765 r
.7714 .33319 m .76706 .33775 L p .77102 .33541 L F P
0 g
s
.788 .993 .765 r
.77102 .33541 m .77268 .33283 L .7714 .33319 L p F P
0 g
s
.693 .912 .971 r
.63609 .4233 m .63058 .42587 L .63477 .42265 L closepath p F P
0 g
s
.696 .896 .969 r
.6332 .42182 m .63477 .42265 L .63058 .42587 L p F P
0 g
s
.696 .896 .969 r
.62134 .42715 m .6332 .42182 L p .63058 .42587 L F P
0 g
s
.742 .834 .921 r
.7484 .16858 m .73813 .17419 L .73541 .17138 L p F P
0 g
s
.877 .608 .527 r
.24308 .39547 m .24842 .39829 L .24873 .39289 L p F P
0 g
s
.877 .608 .527 r
.24873 .39289 m .24342 .39006 L .24308 .39547 L p F P
0 g
s
.879 .638 .571 r
.25119 .40584 m .25278 .40672 L .2537 .40111 L p F P
0 g
s
.879 .638 .571 r
.2537 .40111 m .25019 .39916 L .25119 .40584 L p F P
0 g
s
.333 .13 .447 r
.55811 .38343 m .55835 .37839 L .54886 .38463 L p F P
0 g
s
.333 .13 .447 r
.54886 .38463 m .54864 .38971 L .55811 .38343 L p F P
0 g
s
0 0 0 r
.60357 .31136 m .60817 .30452 L .6034 .31056 L p F P
0 g
s
0 0 0 r
.60031 .31534 m .60357 .31136 L p .6034 .31056 L F P
0 g
s
0 0 0 r
.6034 .31056 m .60127 .31351 L .60031 .31534 L p F P
0 g
s
.36 .444 .811 r
.81479 .18758 m .8141 .19032 L .80778 .18714 L p F P
0 g
s
.36 .444 .811 r
.81345 .18424 m .81479 .18758 L p .80778 .18714 L F P
0 g
s
.36 .444 .811 r
.80778 .18714 m .80884 .18217 L .81345 .18424 L p F P
0 g
s
.281 .352 .759 r
.81809 .19674 m .81744 .1991 L .81281 .19534 L p F P
0 g
s
.281 .352 .759 r
.81645 .19205 m .81809 .19674 L p .81281 .19534 L F P
0 g
s
.281 .352 .759 r
.81281 .19534 m .8141 .19032 L .81645 .19205 L p F P
0 g
s
.755 .956 .649 r
.63206 .27092 m .63763 .26379 L .63458 .26935 L p F P
0 g
s
.755 .956 .649 r
.63115 .27252 m .63206 .27092 L p .63458 .26935 L F P
0 g
s
.755 .956 .649 r
.63458 .26935 m .63312 .27113 L .63115 .27252 L p F P
0 g
s
.587 .574 .806 r
.53219 .42721 m .54397 .42571 L .54602 .43016 L p F P
0 g
s
.583 .51 .738 r
.53165 .42557 m .53219 .42721 L .54397 .42571 L p F P
0 g
s
.103 0 .21 r
.57821 .34938 m .57896 .3464 L .57303 .35152 L p F P
0 g
s
.103 0 .21 r
.57721 .35114 m .57821 .34938 L p .57303 .35152 L F P
0 g
s
.103 0 .21 r
.56933 .35789 m .57721 .35114 L p .57303 .35152 L F P
0 g
s
.103 0 .21 r
.57303 .35152 m .56944 .35738 L .56933 .35789 L p F P
0 g
s
.583 .51 .738 r
.54397 .42571 m .54206 .42049 L .53165 .42557 L p F P
0 g
s
.525 .734 .97 r
.18435 .43101 m .18572 .43086 L .19063 .43379 L p F P
0 g
s
.524 .728 .967 r
.19534 .42975 m .18572 .43086 L .19063 .43379 L p F P
0 g
s
.524 .728 .967 r
.19063 .43379 m .19901 .43291 L .19534 .42975 L p F P
0 g
s
.765 .996 .851 r
.7389 .36579 m .73628 .36796 L .73794 .36584 L closepath p F P
0 g
s
.769 .994 .871 r
.73632 .36576 m .73794 .36584 L .73628 .36796 L p F P
0 g
s
.769 .994 .871 r
.72946 .37124 m .73632 .36576 L p .73628 .36796 L F P
0 g
s
.769 .994 .871 r
.7264 .37522 m .72946 .37124 L p .73628 .36796 L F P
0 g
s
.442 .279 .563 r
.54754 .40182 m .53922 .40665 L .5388 .40083 L p F P
0 g
s
.442 .279 .563 r
.5388 .40083 m .5452 .39711 L .54754 .40182 L p F P
0 g
s
.782 .962 .65 r
.63312 .27113 m .62893 .2765 L .63115 .27252 L closepath p F P
0 g
s
.332 .637 .963 r
.13347 .41375 m .13519 .41396 L .13926 .41722 L p F P
0 g
s
.344 .642 .964 r
.14413 .41496 m .13519 .41396 L .13926 .41722 L p F P
0 g
s
.344 .642 .964 r
.13926 .41722 m .14787 .4182 L .14413 .41496 L p F P
0 g
s
.779 .998 .847 r
.74635 .35939 m .7389 .36579 L .73794 .36584 L p F P
0 g
s
.796 .997 .791 r
.75977 .34507 m .76706 .33775 L .76368 .34313 L p F P
0 g
s
.796 .997 .791 r
.76368 .34313 m .76226 .34455 L .75977 .34507 L p F P
0 g
s
.73 .969 .934 r
.68908 .39943 m .68708 .40068 L .68847 .39929 L closepath p F P
0 g
s
.73 .961 .942 r
.68634 .39866 m .68847 .39929 L .68708 .40068 L p F P
0 g
s
.73 .961 .942 r
.67461 .40572 m .68634 .39866 L p .68708 .40068 L F P
0 g
s
.73 .961 .942 r
.67453 .4058 m .67461 .40572 L p .68708 .40068 L F P
0 g
s
.781 .995 .79 r
.75543 .35113 m .76226 .34455 L .75977 .34507 L p F P
0 g
s
.846 .949 .884 r
.69398 .20302 m .68833 .20805 L .68606 .20705 L p F P
0 g
s
.866 .945 .866 r
.68833 .20805 m .68507 .21123 L .68606 .20705 L closepath p F P
0 g
s
0 0 .394 r
.82239 .22786 m .82083 .23289 L .82011 .22779 L p F P
0 g
s
0 0 .394 r
.82011 .22779 m .82167 .22277 L .82239 .22786 L p F P
0 g
s
.856 .997 .794 r
.65462 .24425 m .65348 .24444 L .65566 .242 L closepath p F P
0 g
s
.587 .745 .952 r
.20266 .43602 m .21375 .4338 L .21737 .43703 L p F P
0 g
s
.596 .746 .948 r
.21375 .4338 m .20266 .43602 L .19901 .43291 L p F P
0 g
s
.266 .593 .949 r
.11541 .40517 m .117 .40548 L .12082 .40884 L p F P
0 g
s
.282 .602 .952 r
.12595 .40712 m .117 .40548 L .12082 .40884 L p F P
0 g
s
.282 .602 .952 r
.12082 .40884 m .12971 .41047 L .12595 .40712 L p F P
0 g
s
0 0 0 r
.60127 .31351 m .59843 .3175 L .60031 .31534 L closepath p F P
0 g
s
.774 .997 .823 r
.75061 .35559 m .74635 .35939 L .74898 .35581 L closepath p F P
0 g
s
.779 .998 .847 r
.74807 .35582 m .74898 .35581 L .74635 .35939 L p F P
0 g
s
.779 .998 .847 r
.74042 .36239 m .74807 .35582 L p .74635 .35939 L F P
0 g
s
.779 .998 .847 r
.73794 .36584 m .74042 .36239 L p .74635 .35939 L F P
0 g
s
.859 .936 .873 r
.69398 .20302 m .70002 .19759 L .69728 .19596 L p F P
0 g
s
.859 .936 .873 r
.69728 .19596 m .69513 .19798 L .69398 .20302 L p F P
0 g
s
.846 .949 .884 r
.68634 .20616 m .69513 .19798 L .69398 .20302 L p F P
0 g
s
.846 .949 .884 r
.68606 .20705 m .68634 .20616 L p .69398 .20302 L F P
0 g
s
.869 .948 .863 r
.67858 .214 m .67677 .21924 L .68507 .21123 L p F P
0 g
s
.869 .948 .863 r
.68559 .20685 m .67858 .214 L p .68507 .21123 L F P
0 g
s
.869 .948 .863 r
.68507 .21123 m .68606 .20705 L .68559 .20685 L p F P
0 g
s
.781 .995 .79 r
.75977 .34507 m .75918 .34565 L .75543 .35113 L p F P
0 g
s
.787 .999 .819 r
.75028 .35387 m .75918 .34565 L .75543 .35113 L p F P
0 g
s
.787 .999 .819 r
.74898 .35581 m .75028 .35387 L p .75543 .35113 L F P
0 g
s
.787 .999 .819 r
.75543 .35113 m .75061 .35559 L .74898 .35581 L p F P
0 g
s
.635 .733 .919 r
.5502 .43703 m .56199 .43387 L .56506 .43752 L p F P
0 g
s
.62 .687 .891 r
.56199 .43387 m .5502 .43703 L .5471 .43218 L p F P
0 g
s
.585 .675 .902 r
.77978 .16617 m .7864 .1652 L .78579 .17006 L p F P
0 g
s
.557 .635 .884 r
.79216 .16454 m .7864 .1652 L .78579 .17006 L p F P
0 g
s
.557 .635 .884 r
.78579 .17006 m .79494 .1694 L .79216 .16454 L p F P
0 g
s
.828 .925 .898 r
.7038 .19452 m .70002 .19759 L .69728 .19596 L p F P
0 g
s
.454 .703 .974 r
.1698 .42811 m .18066 .42792 L .18435 .43101 L p F P
0 g
s
.461 .702 .972 r
.18066 .42792 m .1698 .42811 L .16609 .42501 L p F P
0 g
s
.679 .897 .542 r
.62233 .2852 m .62157 .28598 L .62339 .28361 L closepath p F P
0 g
s
.764 .982 .908 r
.71433 .38394 m .71273 .38367 L .71716 .3805 L closepath p F P
0 g
s
.859 .971 .865 r
.67673 .21933 m .67669 .21931 L .67677 .21924 L closepath p F P
0 g
s
.745 .971 .929 r
.6982 .39115 m .70091 .3918 L .68908 .39943 L p F P
0 g
s
.745 .971 .929 r
.69271 .39469 m .6982 .39115 L p .68908 .39943 L F P
0 g
s
.745 .971 .929 r
.68908 .39943 m .68847 .39929 L .69271 .39469 L p F P
0 g
s
.803 .679 .727 r
.25877 .42395 m .25827 .42462 L .25935 .42504 L closepath p F P
0 g
s
.783 .703 .776 r
.25935 .42504 m .25827 .42462 L .25004 .43261 L p F P
0 g
s
.667 .845 .968 r
.60655 .43034 m .59471 .43491 L .59172 .43255 L p F P
0 g
s
.66 .831 .965 r
.5799 .4367 m .59172 .43255 L .59471 .43491 L p F P
0 g
s
.857 .974 .864 r
.67394 .21866 m .67858 .214 L .67677 .21924 L p F P
0 g
s
.857 .974 .864 r
.67677 .21924 m .67669 .21931 L .67394 .21866 L p F P
0 g
s
.881 .98 .83 r
.66946 .22691 m .67669 .21931 L .67394 .21866 L p F P
0 g
s
.84 .918 .887 r
.7038 .19452 m .71175 .18797 L .70902 .18595 L p F P
0 g
s
.84 .918 .887 r
.70902 .18595 m .70493 .18947 L .7038 .19452 L p F P
0 g
s
.828 .925 .898 r
.69728 .19596 m .70493 .18947 L .7038 .19452 L p F P
0 g
s
.659 .778 .31 r
.80865 .27793 m .8064 .28308 L .80925 .27679 L p F P
0 g
s
.659 .778 .31 r
.80925 .27679 m .81157 .27162 L .80865 .27793 L p F P
0 g
s
.752 .974 .923 r
.70171 .39198 m .70091 .3918 L .70324 .39025 L closepath p F P
0 g
s
.763 .921 .551 r
.79451 .30305 m .79901 .29621 L .79646 .30141 L p F P
0 g
s
.763 .921 .551 r
.7932 .30576 m .79451 .30305 L p .79646 .30141 L F P
0 g
s
.763 .921 .551 r
.79646 .30141 m .79428 .30472 L .7932 .30576 L p F P
0 g
s
0 0 .091 r
.58087 .34459 m .57896 .3464 L .58009 .34248 L p F P
0 g
s
0 0 .091 r
.58009 .34248 m .58486 .33793 L .58087 .34459 L p F P
0 g
s
.395 .674 .972 r
.15161 .42137 m .15599 .42159 L .16028 .42475 L p F P
0 g
s
.403 .676 .972 r
.16237 .42186 m .15599 .42159 L .16028 .42475 L p F P
0 g
s
.403 .676 .972 r
.16028 .42475 m .16609 .42501 L .16237 .42186 L p F P
0 g
s
.816 .678 .712 r
.25827 .42462 m .25877 .42395 L .25542 .41724 L p F P
0 g
s
.775 .955 .634 r
.62684 .27794 m .62339 .28361 L .62893 .2765 L p F P
0 g
s
.775 .955 .634 r
.63035 .27313 m .62684 .27794 L p .62893 .2765 L F P
0 g
s
.775 .955 .634 r
.62893 .2765 m .63115 .27252 L .63035 .27313 L p F P
0 g
s
.703 .914 .967 r
.64508 .41612 m .64794 .41745 L .63609 .4233 L p F P
0 g
s
.703 .914 .967 r
.63907 .41904 m .64508 .41612 L p .63609 .4233 L F P
0 g
s
.703 .914 .967 r
.63609 .4233 m .63477 .42265 L .63907 .41904 L p F P
0 g
s
.771 .748 .832 r
.25004 .43261 m .24709 .43484 L .24356 .43081 L p F P
0 g
s
.717 .737 .867 r
.23217 .43681 m .24356 .43081 L .24709 .43484 L p F P
0 g
s
.816 .678 .712 r
.25542 .41724 m .25222 .42208 L .25827 .42462 L p F P
0 g
s
.792 .705 .769 r
.24477 .42982 m .25004 .43261 L .25827 .42462 L p F P
0 g
s
.792 .705 .769 r
.25827 .42462 m .25222 .42208 L .24477 .42982 L p F P
0 g
s
.776 .989 .891 r
.7264 .37522 m .72454 .37502 L .72946 .37124 L closepath p F P
0 g
s
.413 .221 .509 r
.5487 .39511 m .5452 .39711 L .54521 .39168 L p F P
0 g
s
.413 .221 .509 r
.54521 .39168 m .54864 .38971 L .5487 .39511 L p F P
0 g
s
.805 .898 .908 r
.7151 .18551 m .71175 .18797 L .70902 .18595 L p F P
0 g
s
.649 .79 .95 r
.56506 .43752 m .57687 .43383 L .5799 .4367 L p F P
0 g
s
.639 .757 .933 r
.57687 .43383 m .56506 .43752 L .56199 .43387 L p F P
0 g
s
.655 .809 .957 r
.59172 .43255 m .5799 .4367 L .57687 .43383 L p F P
0 g
s
0 0 0 r
.59869 .31861 m .59369 .32438 L .59843 .3175 L p F P
0 g
s
0 0 0 r
.59843 .3175 m .60031 .31534 L .59869 .31861 L p F P
0 g
s
.881 .98 .83 r
.67394 .21866 m .67114 .22173 L .66946 .22691 L p F P
0 g
s
.862 .989 .836 r
.6642 .2293 m .67114 .22173 L .66946 .22691 L p F P
0 g
s
.862 .989 .836 r
.6634 .23137 m .6642 .2293 L p .66946 .22691 L F P
0 g
s
.862 .989 .836 r
.66946 .22691 m .66507 .23147 L .6634 .23137 L p F P
0 g
s
0 0 0 r
.81281 .26799 m .81188 .27078 L .81378 .26553 L closepath p F P
0 g
s
.771 .748 .832 r
.24356 .43081 m .24477 .42982 L .25004 .43261 L p F P
0 g
s
.917 .538 .281 r
.22175 .35632 m .22209 .3576 L .21881 .35502 L closepath p F P
0 g
s
0 0 .165 r
.81932 .24697 m .81864 .24878 L .81925 .24324 L p F P
0 g
s
0 0 .165 r
.81925 .24324 m .8195 .24259 L .81932 .24697 L p F P
0 g
s
.654 .75 .92 r
.21737 .43703 m .22859 .43331 L .23217 .43681 L p F P
0 g
s
.665 .75 .914 r
.22859 .43331 m .21737 .43703 L .21375 .4338 L p F P
0 g
s
.724 .943 .955 r
.67449 .40579 m .66263 .41238 L .65982 .41134 L p F P
0 g
s
0 0 0 r
.81571 .26045 m .81378 .26553 L .81547 .25962 L p F P
0 g
s
0 0 0 r
.81547 .25962 m .81744 .25452 L .81571 .26045 L p F P
0 g
s
.817 .894 .897 r
.7151 .18551 m .72355 .17922 L .72081 .17682 L p F P
0 g
s
.817 .894 .897 r
.72081 .17682 m .71611 .18049 L .7151 .18551 L p F P
0 g
s
.805 .898 .908 r
.70902 .18595 m .71611 .18049 L .7151 .18551 L p F P
0 g
s
.129 0 .22 r
.56944 .35738 m .56891 .35821 L .56933 .35789 L closepath p F P
0 g
s
.892 .467 .11 r
.20294 .33481 m .20666 .33827 L .20487 .33368 L p F P
0 g
s
.892 .467 .11 r
.20487 .33368 m .20115 .33021 L .20294 .33481 L p F P
0 g
s
.744 .916 .55 r
.79428 .30472 m .79184 .30828 L .7932 .30576 L closepath p F P
0 g
s
.882 .984 .82 r
.66507 .23147 m .66234 .23453 L .6634 .23137 L closepath p F P
0 g
s
.651 .72 .899 r
.76485 .16583 m .77704 .16205 L .77978 .16617 L p F P
0 g
s
.664 .732 .901 r
.77704 .16205 m .76485 .16583 L .76212 .16223 L p F P
0 g
s
.704 .771 .904 r
.75007 .16765 m .76212 .16223 L .76485 .16583 L p F P
0 g
s
.167 0 .272 r
.56853 .36225 m .56522 .36477 L .56891 .35821 L p F P
0 g
s
.167 0 .272 r
.56891 .35821 m .56933 .35789 L .56853 .36225 L p F P
0 g
s
.731 .742 .86 r
.23217 .43681 m .24356 .43081 L .24072 .4275 L p F P
0 g
s
.731 .742 .86 r
.22859 .43331 m .23217 .43681 L p .24072 .4275 L F P
0 g
s
.902 .487 .162 r
.20834 .34293 m .21224 .34632 L .21055 .34167 L p F P
0 g
s
.902 .487 .162 r
.21055 .34167 m .20666 .33827 L .20834 .34293 L p F P
0 g
s
.744 .961 .939 r
.68847 .39929 m .68634 .39866 L .69271 .39469 L closepath p F P
0 g
s
.401 .673 .971 r
.15599 .42159 m .15161 .42137 L .14787 .4182 L p F P
0 g
s
.884 .986 .814 r
.65779 .23669 m .65566 .242 L .66234 .23453 L p F P
0 g
s
.884 .986 .814 r
.66232 .23134 m .65779 .23669 L p .66234 .23453 L F P
0 g
s
.884 .986 .814 r
.66234 .23453 m .6634 .23137 L .66232 .23134 L p F P
0 g
s
.741 .81 .907 r
.75007 .16765 m .7484 .16858 L .74845 .16577 L closepath p F P
0 g
s
.742 .834 .921 r
.74735 .16449 m .74845 .16577 L .7484 .16858 L p F P
0 g
s
.742 .834 .921 r
.73541 .17138 m .74735 .16449 L p .7484 .16858 L F P
0 g
s
.486 .579 .874 r
.80088 .17492 m .79774 .17449 L .79494 .1694 L p F P
0 g
s
.862 .627 .582 r
.24732 .40396 m .25119 .40584 L .25019 .39916 L p F P
0 g
s
.862 .627 .582 r
.25019 .39916 m .24842 .39829 L .24732 .40396 L p F P
0 g
s
0 0 .507 r
.82322 .21771 m .82167 .22277 L .8202 .21792 L p F P
0 g
s
0 0 .507 r
.8202 .21792 m .82173 .21288 L .82322 .21771 L p F P
0 g
s
.106 0 .25 r
.57403 .35756 m .56853 .36225 L .56933 .35789 L p F P
0 g
s
.106 0 .25 r
.56933 .35789 m .57721 .35114 L .57403 .35756 L p F P
0 g
s
0 0 .137 r
.82036 .24374 m .81932 .24697 L .8195 .24259 L p F P
0 g
s
0 0 .137 r
.8195 .24259 m .82089 .23821 L .82036 .24374 L p F P
0 g
s
.907 .505 .216 r
.21379 .35103 m .2179 .35434 L .21633 .34963 L p F P
0 g
s
.907 .505 .216 r
.21633 .34963 m .21224 .34632 L .21379 .35103 L p F P
0 g
s
.851 .682 .671 r
.25625 .41544 m .25401 .41425 L .25542 .41724 L closepath p F P
0 g
s
0 0 0 r
.61121 .30013 m .61003 .30185 L .61308 .2976 L closepath p F P
0 g
s
.655 .88 .519 r
.62178 .28491 m .62684 .27794 L .62339 .28361 L p F P
0 g
s
.655 .88 .519 r
.62009 .28758 m .62178 .28491 L p .62339 .28361 L F P
0 g
s
.655 .88 .519 r
.62339 .28361 m .62157 .28598 L .62009 .28758 L p F P
0 g
s
.539 .429 .676 r
.53541 .41538 m .54017 .41305 L .5408 .41592 L closepath p F P
0 g
s
.781 .956 .633 r
.7894 .31008 m .78661 .31534 L .79184 .30828 L p F P
0 g
s
.781 .956 .633 r
.79198 .30659 m .7894 .31008 L p .79184 .30828 L F P
0 g
s
.781 .956 .633 r
.79184 .30828 m .7932 .30576 L .79198 .30659 L p F P
0 g
s
.714 .803 .92 r
.75939 .15871 m .76212 .16223 L .75007 .16765 L p F P
0 g
s
.714 .803 .92 r
.74916 .16363 m .75939 .15871 L p .75007 .16765 L F P
0 g
s
.714 .803 .92 r
.75007 .16765 m .74845 .16577 L .74916 .16363 L p F P
0 g
s
.78 .87 .914 r
.72904 .17561 m .72355 .17922 L .72081 .17682 L p F P
0 g
s
.787 .995 .871 r
.73794 .36584 m .73632 .36576 L .74042 .36239 L closepath p F P
0 g
s
.925 .568 .333 r
.21893 .35924 m .22311 .3625 L .22209 .3576 L p F P
0 g
s
.925 .568 .333 r
.21801 .35476 m .21893 .35924 L p .22209 .3576 L F P
0 g
s
.925 .568 .333 r
.22209 .3576 m .21881 .35502 L .21801 .35476 L p F P
0 g
s
.756 .972 .925 r
.70324 .39025 m .70091 .3918 L .6982 .39115 L p F P
0 g
s
.599 .684 .901 r
.7864 .1652 m .77978 .16617 L .77704 .16205 L p F P
0 g
s
.808 .994 .76 r
.77268 .33283 m .7714 .33319 L .77429 .33005 L closepath p F P
0 g
s
.92 .578 .374 r
.2239 .3675 m .22828 .37069 L .22746 .3657 L p F P
0 g
s
.92 .578 .374 r
.22746 .3657 m .22311 .3625 L .2239 .3675 L p F P
0 g
s
.684 .891 .526 r
.62157 .28598 m .61815 .29063 L .62009 .28758 L closepath p F P
0 g
s
.853 .998 .791 r
.65149 .24406 m .65779 .23669 L .65566 .242 L p F P
0 g
s
.853 .998 .791 r
.65114 .24487 m .65149 .24406 L p .65566 .242 L F P
0 g
s
.853 .998 .791 r
.65566 .242 m .65348 .24444 L .65114 .24487 L p F P
0 g
s
.532 .735 .968 r
.18572 .43086 m .18435 .43101 L .18066 .42792 L p F P
0 g
s
0 0 0 r
.5985 .31905 m .59869 .31861 L .59369 .32438 L p F P
0 g
s
0 0 0 r
.59491 .32487 m .5985 .31905 L p .59369 .32438 L F P
0 g
s
0 0 0 r
.58954 .33076 m .59491 .32487 L p .59369 .32438 L F P
0 g
s
0 0 0 r
.59369 .32438 m .58974 .33027 L .58954 .33076 L p F P
0 g
s
.913 .592 .422 r
.2288 .37579 m .23339 .37889 L .23284 .3738 L p F P
0 g
s
.913 .592 .422 r
.23284 .3738 m .22828 .37069 L .2288 .37579 L p F P
0 g
s
.338 .636 .962 r
.13519 .41396 m .13347 .41375 L .12971 .41047 L p F P
0 g
s
.755 .979 .915 r
.70324 .39025 m .71273 .38367 L .71006 .3832 L p F P
0 g
s
.755 .979 .915 r
.71006 .3832 m .70828 .38442 L .70324 .39025 L p F P
0 g
s
.756 .972 .925 r
.6982 .39115 m .70828 .38442 L .70324 .39025 L p F P
0 g
s
.871 .661 .616 r
.25278 .40672 m .25119 .40584 L .25217 .40885 L closepath p F P
0 g
s
.476 .341 .617 r
.55013 .40739 m .54017 .41305 L .53922 .40665 L p F P
0 g
s
.476 .341 .617 r
.54943 .40321 m .55013 .40739 L p .53922 .40665 L F P
0 g
s
.476 .341 .617 r
.53922 .40665 m .54754 .40182 L .54943 .40321 L p F P
0 g
s
.711 .837 .396 r
.80529 .2844 m .80865 .27793 L .8064 .28308 L p F P
0 g
s
.711 .837 .396 r
.80314 .2894 m .80529 .2844 L p .8064 .28308 L F P
0 g
s
.711 .837 .396 r
.8064 .28308 m .80319 .28932 L .80314 .2894 L p F P
0 g
s
.825 .68 .703 r
.25222 .42208 m .25542 .41724 L .25401 .41425 L p F P
0 g
s
.903 .605 .472 r
.23354 .38413 m .23836 .38714 L .23818 .38191 L p F P
0 g
s
.903 .605 .472 r
.23818 .38191 m .23339 .37889 L .23354 .38413 L p F P
0 g
s
.689 .891 .971 r
.6332 .42182 m .62134 .42715 L .61841 .42539 L p F P
0 g
s
.244 .027 .372 r
.55983 .37729 m .55835 .37839 L .55883 .37361 L p F P
0 g
s
.244 .027 .372 r
.55883 .37361 m .56213 .37115 L .55983 .37729 L p F P
0 g
s
.889 .62 .525 r
.23802 .39255 m .24308 .39547 L .24342 .39006 L p F P
0 g
s
.889 .62 .525 r
.24342 .39006 m .23836 .38714 L .23802 .39255 L p F P
0 g
s
.875 .994 .779 r
.65348 .24444 m .6494 .24935 L .65114 .24487 L closepath p F P
0 g
s
.871 .636 .58 r
.242 .40114 m .24732 .40396 L .24842 .39829 L p F P
0 g
s
.871 .636 .58 r
.24842 .39829 m .24308 .39547 L .242 .40114 L p F P
0 g
s
.791 .862 .902 r
.72904 .17561 m .73541 .17138 L .73267 .16862 L p F P
0 g
s
.791 .862 .902 r
.73267 .16862 m .7297 .1707 L .72904 .17561 L p F P
0 g
s
.78 .87 .914 r
.72081 .17682 m .7297 .1707 L .72904 .17561 L p F P
0 g
s
.828 .99 .729 r
.64259 .258 m .64191 .2583 L .64329 .25664 L closepath p F P
0 g
s
.368 .187 .5 r
.55818 .38883 m .55811 .38343 L .54864 .38971 L p F P
0 g
s
.368 .187 .5 r
.54864 .38971 m .5487 .39511 L .55818 .38883 L p F P
0 g
s
.701 .904 .968 r
.63477 .42265 m .6332 .42182 L .63907 .41904 L closepath p F P
0 g
s
.62 .687 .891 r
.5471 .43218 m .5589 .42951 L .56199 .43387 L p F P
0 g
s
.619 .62 .831 r
.54602 .43016 m .5471 .43218 L .5589 .42951 L p F P
0 g
s
.532 .735 .968 r
.18066 .42792 m .18089 .4279 L .18572 .43086 L p F P
0 g
s
.532 .729 .964 r
.19167 .42655 m .18089 .4279 L .18572 .43086 L p F P
0 g
s
.532 .729 .964 r
.18572 .43086 m .19534 .42975 L .19167 .42655 L p F P
0 g
s
.069 .114 .602 r
.82213 .21152 m .82173 .21288 L .81938 .20834 L p F P
0 g
s
.069 .114 .602 r
.81938 .20834 m .82046 .20462 L .82213 .21152 L p F P
0 g
s
.841 .651 .646 r
.25217 .40885 m .25065 .41274 L .25401 .41425 L closepath p F P
0 g
s
.825 .68 .703 r
.24658 .41939 m .25222 .42208 L p .25401 .41425 L F P
0 g
s
.825 .68 .703 r
.25401 .41425 m .25065 .41274 L .24658 .41939 L p F P
0 g
s
.671 .878 .504 r
.61691 .29183 m .61308 .2976 L .61815 .29063 L p F P
0 g
s
.671 .878 .504 r
.6188 .28906 m .61691 .29183 L p .61815 .29063 L F P
0 g
s
.671 .878 .504 r
.61815 .29063 m .62009 .28758 L .6188 .28906 L p F P
0 g
s
0 0 0 r
.59905 .31817 m .59869 .31861 L .60031 .31534 L p F P
0 g
s
0 0 0 r
.60031 .31534 m .60357 .31136 L .59905 .31817 L p F P
0 g
s
.797 .971 .672 r
.78367 .31731 m .7894 .31008 L .78661 .31534 L p F P
0 g
s
.797 .971 .672 r
.782 .32051 m .78367 .31731 L p .78661 .31534 L F P
0 g
s
.797 .971 .672 r
.78661 .31534 m .78292 .32 L .782 .32051 L p F P
0 g
s
.199 0 .317 r
.56788 .36679 m .56213 .37115 L .56522 .36477 L p F P
0 g
s
.199 0 .317 r
.56522 .36477 m .56853 .36225 L .56788 .36679 L p F P
0 g
s
0 0 .266 r
.82245 .23319 m .82089 .23821 L .82083 .23289 L p F P
0 g
s
0 0 .266 r
.82083 .23289 m .82239 .22786 L .82245 .23319 L p F P
0 g
s
.875 .994 .77 r
.64578 .25123 m .64329 .25664 L .6494 .24935 L p F P
0 g
s
.875 .994 .77 r
.65072 .24496 m .64578 .25123 L p .6494 .24935 L F P
0 g
s
.875 .994 .77 r
.6494 .24935 m .65114 .24487 L .65072 .24496 L p F P
0 g
s
.85 .656 .64 r
.25065 .41274 m .25217 .40885 L .25119 .40584 L p F P
0 g
s
.85 .656 .64 r
.24511 .41 m .25065 .41274 L p .25119 .40584 L F P
0 g
s
.85 .656 .64 r
.25119 .40584 m .24732 .40396 L .24511 .41 L p F P
0 g
s
.681 .867 .969 r
.60686 .43055 m .60655 .43034 L .60793 .42978 L closepath p F P
0 g
s
.732 .951 .948 r
.67453 .4058 m .67449 .40579 L .67461 .40572 L closepath p F P
0 g
s
.737 .945 .95 r
.67461 .40572 m .67449 .40579 L .6717 .40472 L p F P
0 g
s
.724 .943 .955 r
.65982 .41134 m .6717 .40472 L .67449 .40579 L p F P
0 g
s
.338 .636 .962 r
.12971 .41047 m .13125 .41066 L .13519 .41396 L p F P
0 g
s
.35 .641 .963 r
.14038 .41166 m .13125 .41066 L .13519 .41396 L p F P
0 g
s
.35 .641 .963 r
.13519 .41396 m .14413 .41496 L .14038 .41166 L p F P
0 g
s
.736 .954 .946 r
.67461 .40572 m .68634 .39866 L .68359 .39779 L p F P
0 g
s
.736 .954 .946 r
.68359 .39779 m .68044 .39967 L .67461 .40572 L p F P
0 g
s
.737 .945 .95 r
.6717 .40472 m .68044 .39967 L .67461 .40572 L p F P
0 g
s
.486 .579 .874 r
.79494 .1694 m .8016 .17003 L .80088 .17492 L p F P
0 g
s
.447 .542 .86 r
.81015 .17652 m .81001 .17716 L .80088 .17492 L p F P
0 g
s
.447 .542 .86 r
.80765 .17118 m .81015 .17652 L p .80088 .17492 L F P
0 g
s
.447 .542 .86 r
.80088 .17492 m .8016 .17003 L .80765 .17118 L p F P
0 g
s
.714 .922 .963 r
.65926 .41164 m .64794 .41745 L .64508 .41612 L p F P
0 g
s
.766 .981 .91 r
.71716 .3805 m .71273 .38367 L .71006 .3832 L p F P
0 g
s
0 0 0 r
.81348 .26655 m .81571 .26045 L .81378 .26553 L p F P
0 g
s
0 0 0 r
.81174 .27122 m .81348 .26655 L p .81378 .26553 L F P
0 g
s
0 0 0 r
.81378 .26553 m .81188 .27078 L .81174 .27122 L p F P
0 g
s
.804 .713 .765 r
.24072 .4275 m .24477 .42982 L .25222 .42208 L p F P
0 g
s
.804 .713 .765 r
.24003 .42667 m .24072 .4275 L p .25222 .42208 L F P
0 g
s
.804 .713 .765 r
.25222 .42208 m .24658 .41939 L .24003 .42667 L p F P
0 g
s
0 0 0 r
.58974 .33027 m .5891 .33121 L .58954 .33076 L closepath p F P
0 g
s
.758 .821 .901 r
.74735 .16449 m .73541 .17138 L .73267 .16862 L p F P
0 g
s
.59 .576 .806 r
.54397 .42571 m .54602 .43016 L .55602 .42458 L p F P
0 g
s
.619 .62 .831 r
.5589 .42951 m .55602 .42458 L .54602 .43016 L p F P
0 g
s
.686 .85 .961 r
.60793 .42978 m .60655 .43034 L .60358 .42814 L p F P
0 g
s
.667 .845 .968 r
.59172 .43255 m .60358 .42814 L .60655 .43034 L p F P
0 g
s
0 0 .026 r
.81881 .25091 m .81744 .25452 L .81864 .24878 L p F P
0 g
s
0 0 .026 r
.81864 .24878 m .81932 .24697 L .81881 .25091 L p F P
0 g
s
0 0 .006 r
.58827 .33448 m .58486 .33793 L .5891 .33121 L p F P
0 g
s
0 0 .006 r
.5891 .33121 m .58954 .33076 L .58827 .33448 L p F P
0 g
s
.446 .281 .562 r
.54912 .40092 m .54754 .40182 L .5452 .39711 L p F P
0 g
s
.446 .281 .562 r
.5452 .39711 m .5487 .39511 L .54912 .40092 L p F P
0 g
s
.596 .746 .948 r
.19901 .43291 m .21012 .43052 L .21375 .4338 L p F P
0 g
s
.603 .746 .945 r
.21012 .43052 m .19901 .43291 L .19534 .42975 L p F P
0 g
s
.781 .969 .674 r
.78292 .32 m .78081 .32258 L .782 .32051 L closepath p F P
0 g
s
.798 .998 .849 r
.74898 .35581 m .74807 .35582 L .75028 .35387 L closepath p F P
0 g
s
.765 .988 .897 r
.71716 .3805 m .72454 .37502 L .7219 .37471 L p F P
0 g
s
.765 .988 .897 r
.7219 .37471 m .72183 .37477 L .71716 .3805 L p F P
0 g
s
.766 .981 .91 r
.71006 .3832 m .72183 .37477 L .71716 .3805 L p F P
0 g
s
.18 .24 .689 r
.81744 .1991 m .81809 .19674 L .81959 .20164 L closepath p F P
0 g
s
.461 .702 .972 r
.17983 .42721 m .18066 .42792 L p .16609 .42501 L F P
0 g
s
.461 .702 .972 r
.16609 .42501 m .17649 .42478 L .17983 .42721 L p F P
0 g
s
.467 .702 .97 r
.17649 .42478 m .16609 .42501 L .16237 .42186 L p F P
0 g
s
.781 .746 .821 r
.24477 .42982 m .24072 .4275 L .24356 .43081 L closepath p F P
0 g
s
.401 .673 .971 r
.14787 .4182 m .15181 .41838 L .15599 .42159 L p F P
0 g
s
.409 .676 .97 r
.15865 .41865 m .15181 .41838 L .15599 .42159 L p F P
0 g
s
.409 .676 .97 r
.15599 .42159 m .16237 .42186 L .15865 .41865 L p F P
0 g
s
.684 .871 .969 r
.61841 .42539 m .60793 .42978 L .61598 .42379 L closepath p F P
0 g
s
.686 .85 .961 r
.61547 .42344 m .61598 .42379 L .60793 .42978 L p F P
0 g
s
.686 .85 .961 r
.60358 .42814 m .61547 .42344 L p .60793 .42978 L F P
0 g
s
.821 .988 .722 r
.64008 .25841 m .64578 .25123 L .64329 .25664 L p F P
0 g
s
.821 .988 .722 r
.63963 .25935 m .64008 .25841 L p .64329 .25664 L F P
0 g
s
.821 .988 .722 r
.64329 .25664 m .64191 .2583 L .63963 .25935 L p F P
0 g
s
.802 .989 .735 r
.7773 .32475 m .77429 .33005 L .78081 .32258 L p F P
0 g
s
.802 .989 .735 r
.78053 .32104 m .7773 .32475 L p .78081 .32258 L F P
0 g
s
.802 .989 .735 r
.78081 .32258 m .782 .32051 L .78053 .32104 L p F P
0 g
s
.687 .828 .391 r
.80319 .28932 m .80309 .28952 L .80314 .2894 L closepath p F P
0 g
s
0 0 0 r
.59098 .33151 m .58827 .33448 L .58954 .33076 L p F P
0 g
s
0 0 0 r
.58954 .33076 m .59491 .32487 L .59098 .33151 L p F P
0 g
s
.747 .895 .501 r
.80123 .29161 m .79901 .29621 L .80309 .28952 L p F P
0 g
s
.747 .895 .501 r
.80309 .28952 m .80314 .2894 L .80123 .29161 L p F P
0 g
s
.854 .95 .877 r
.68606 .20705 m .68559 .20685 L .68634 .20616 L closepath p F P
0 g
s
.716 .804 .92 r
.74845 .16577 m .74735 .16449 L .74916 .16363 L closepath p F P
0 g
s
.639 .757 .933 r
.56199 .43387 m .57382 .43052 L .57687 .43383 L p F P
0 g
s
.625 .716 .912 r
.57382 .43052 m .56199 .43387 L .5589 .42951 L p F P
0 g
s
.777 .902 .503 r
.80148 .29102 m .80123 .29161 L .80314 .2894 L p F P
0 g
s
.777 .902 .503 r
.80314 .2894 m .80529 .2844 L .80148 .29102 L p F P
0 g
s
.847 .988 .716 r
.64191 .2583 m .63763 .26379 L .63963 .25935 L closepath p F P
0 g
s
.538 .428 .676 r
.55204 .41486 m .55013 .40739 L .54017 .41305 L p F P
0 g
s
.538 .428 .676 r
.54859 .41676 m .55204 .41486 L p .54017 .41305 L F P
0 g
s
.538 .428 .676 r
.54017 .41305 m .5408 .41592 L .54859 .41676 L p F P
0 g
s
.364 .443 .808 r
.81052 .17735 m .81001 .17716 L .80884 .18217 L p F P
0 g
s
.364 .443 .808 r
.80884 .18217 m .81345 .18424 L .81052 .17735 L p F P
0 g
s
0 0 0 r
.61235 .29866 m .61691 .29183 L .61308 .2976 L p F P
0 g
s
.613 .801 .377 r
.61235 .29866 m .61574 .29301 L .61195 .29923 L p F P
0 g
s
0 0 0 r
.6093 .30297 m .61235 .29866 L .60784 .30547 L p F P
0 g
s
.613 .801 .377 r
.61195 .29923 m .61167 .2997 L p .61235 .29866 L F P
0 g
s
0 0 0 r
.61308 .2976 m .61273 .2981 L .61235 .29866 L F
.6093 .30297 m .61235 .29866 L p .61273 .2981 L F P
0 g
s
0 0 0 r
.61308 .2976 m .61003 .30185 L .6093 .30297 L p F P
0 g
s
.503 .594 .877 r
.8016 .17003 m .79494 .1694 L .79216 .16454 L p F P
0 g
s
.805 .958 .63 r
.7932 .30576 m .79198 .30659 L .79451 .30305 L closepath p F P
0 g
s
.281 .352 .759 r
.8141 .19032 m .81479 .18758 L .81645 .19205 L closepath p F P
0 g
s
.662 .827 .962 r
.60358 .42814 m .59172 .43255 L .58872 .42991 L p F P
0 g
s
.655 .809 .957 r
.57687 .43383 m .58872 .42991 L .59172 .43255 L p F P
0 g
s
.777 .989 .892 r
.72946 .37124 m .72454 .37502 L .7219 .37471 L p F P
0 g
s
.872 .989 .824 r
.6634 .23137 m .66232 .23134 L .6642 .2293 L closepath p F P
0 g
s
.912 .532 .286 r
.21881 .35502 m .21801 .35476 L .2179 .35434 L closepath p F P
0 g
s
.834 .687 .7 r
.24128 .41658 m .24658 .41939 L .25065 .41274 L p F P
0 g
s
.834 .687 .7 r
.25065 .41274 m .24511 .41 L .24128 .41658 L p F P
0 g
s
.77 .954 .634 r
.63115 .27252 m .63035 .27313 L .63206 .27092 L closepath p F P
0 g
s
.665 .75 .914 r
.21375 .4338 m .225 .42976 L .22859 .43331 L p F P
0 g
s
.675 .751 .908 r
.225 .42976 m .21375 .4338 L .21012 .43052 L p F P
0 g
s
.646 .781 .946 r
.58872 .42991 m .57687 .43383 L .57382 .43052 L p F P
0 g
s
.59 .576 .806 r
.55602 .42458 m .5558 .42415 L .54397 .42571 L p F P
0 g
s
.586 .529 .758 r
.54206 .42049 m .54397 .42571 L .5558 .42415 L p F P
0 g
s
.599 .684 .901 r
.77704 .16205 m .78749 .16015 L .7864 .1652 L p F P
0 g
s
.573 .654 .891 r
.78939 .15986 m .78749 .16015 L .7864 .1652 L p F P
0 g
s
.573 .654 .891 r
.7864 .1652 m .79216 .16454 L .78939 .15986 L p F P
0 g
s
.534 .453 .711 r
.5408 .41592 m .54859 .41676 L .54206 .42049 L closepath p F P
0 g
s
.731 .742 .86 r
.24072 .4275 m .23954 .42701 L .22859 .43331 L p F P
0 g
s
.737 .766 .876 r
.23954 .42701 m .22859 .43331 L .225 .42976 L p F P
0 g
s
.809 .995 .762 r
.7703 .33239 m .7773 .32475 L .77429 .33005 L p F P
0 g
s
.809 .995 .762 r
.76956 .33371 m .7703 .33239 L p .77429 .33005 L F P
0 g
s
.809 .995 .762 r
.77429 .33005 m .7714 .33319 L .76956 .33371 L p F P
0 g
s
.902 .487 .141 r
.2046 .33947 m .20834 .34293 L .20666 .33827 L p F P
0 g
s
.902 .487 .141 r
.20666 .33827 m .20294 .33481 L .2046 .33947 L p F P
0 g
s
.776 .994 .877 r
.73632 .36576 m .72946 .37124 L .73373 .36562 L closepath p F P
0 g
s
.777 .989 .892 r
.73372 .36562 m .73373 .36562 L .72946 .37124 L p F P
0 g
s
.777 .989 .892 r
.7219 .37471 m .73372 .36562 L p .72946 .37124 L F P
0 g
s
0 0 .395 r
.82386 .2231 m .82239 .22786 L .82167 .22277 L p F P
0 g
s
0 0 .395 r
.82335 .21857 m .82386 .2231 L p .82167 .22277 L F P
0 g
s
0 0 .395 r
.82167 .22277 m .82322 .21771 L .82335 .21857 L p F P
0 g
s
.837 .926 .891 r
.70493 .18947 m .69728 .19596 L .69562 .19499 L p F P
0 g
s
.858 .924 .871 r
.69728 .19596 m .69513 .19798 L .69562 .19499 L closepath p F P
0 g
s
.861 .926 .869 r
.68773 .20103 m .68634 .20616 L .69513 .19798 L p F P
0 g
s
.861 .926 .869 r
.69454 .19438 m .68773 .20103 L p .69513 .19798 L F P
0 g
s
.861 .926 .869 r
.69513 .19798 m .69562 .19499 L .69454 .19438 L p F P
0 g
s
.676 .744 .902 r
.77429 .15805 m .76212 .16223 L .75939 .15871 L p F P
0 g
s
.664 .732 .901 r
.76212 .16223 m .77429 .15805 L .77704 .16205 L p F P
0 g
s
0 0 .137 r
.57896 .3464 m .57821 .34938 L .58087 .34459 L closepath p F P
0 g
s
.236 .019 .368 r
.56742 .37156 m .55983 .37729 L .56213 .37115 L p F P
0 g
s
.236 .019 .368 r
.56213 .37115 m .56788 .36679 L .56742 .37156 L p F P
0 g
s
.854 .953 .877 r
.68284 .20574 m .68773 .20103 L .68634 .20616 L p F P
0 g
s
.854 .953 .877 r
.68634 .20616 m .68559 .20685 L .68284 .20574 L p F P
0 g
s
.882 .962 .846 r
.67858 .214 m .68559 .20685 L .68284 .20574 L p F P
0 g
s
.911 .509 .199 r
.20986 .34765 m .21379 .35103 L .21224 .34632 L p F P
0 g
s
.911 .509 .199 r
.21224 .34632 m .20834 .34293 L .20986 .34765 L p F P
0 g
s
0 0 0 r
.61003 .30185 m .60817 .30452 L .6093 .30297 L closepath p F P
0 g
s
.796 .994 .766 r
.7714 .33319 m .76706 .33775 L .76956 .33371 L closepath p F P
0 g
s
.844 .984 .703 r
.63488 .26543 m .63206 .27092 L .63763 .26379 L p F P
0 g
s
.844 .984 .703 r
.63915 .2596 m .63488 .26543 L p .63763 .26379 L F P
0 g
s
.844 .984 .703 r
.63763 .26379 m .63963 .25935 L .63915 .2596 L p F P
0 g
s
.407 .672 .969 r
.15181 .41838 m .14787 .4182 L .14413 .41496 L p F P
0 g
s
.586 .529 .758 r
.55265 .41667 m .54859 .41676 L .54206 .42049 L p F P
0 g
s
.586 .529 .758 r
.5558 .42415 m .55265 .41667 L p .54206 .42049 L F P
0 g
s
.86 .666 .638 r
.23988 .40715 m .24511 .41 L .24732 .40396 L p F P
0 g
s
.86 .666 .638 r
.24732 .40396 m .242 .40114 L .23988 .40715 L p F P
0 g
s
.847 .91 .877 r
.70493 .18947 m .70902 .18595 L .70628 .18394 L p F P
0 g
s
.847 .91 .877 r
.70628 .18394 m .70559 .18456 L .70493 .18947 L p F P
0 g
s
.837 .926 .891 r
.69613 .19297 m .70559 .18456 L .70493 .18947 L p F P
0 g
s
.837 .926 .891 r
.69562 .19499 m .69613 .19297 L p .70493 .18947 L F P
0 g
s
0 0 .041 r
.58707 .33831 m .58087 .34459 L .58486 .33793 L p F P
0 g
s
0 0 .041 r
.58486 .33793 m .58827 .33448 L .58707 .33831 L p F P
0 g
s
0 0 0 r
.81188 .27078 m .81157 .27162 L .81174 .27122 L closepath p F P
0 g
s
.747 .959 .939 r
.69271 .39469 m .68634 .39866 L .68359 .39779 L p F P
0 g
s
.706 .895 .965 r
.63907 .41904 m .6332 .42182 L .6303 .42014 L p F P
0 g
s
.689 .891 .971 r
.61841 .42539 m .6303 .42014 L .6332 .42182 L p F P
0 g
s
.918 .536 .27 r
.21428 .35286 m .21379 .35103 L .2179 .35434 L p F P
0 g
s
.918 .536 .27 r
.2179 .35434 m .21801 .35476 L .21428 .35286 L p F P
0 g
s
.788 .995 .872 r
.74042 .36239 m .73632 .36576 L .73373 .36562 L p F P
0 g
s
.815 .9 .901 r
.71611 .18049 m .70902 .18595 L .70628 .18394 L p F P
0 g
s
.614 .686 .894 r
.78749 .16015 m .77704 .16205 L .77429 .15805 L p F P
0 g
s
.928 .586 .366 r
.2197 .36424 m .2239 .3675 L .22311 .3625 L p F P
0 g
s
.928 .586 .366 r
.22311 .3625 m .21893 .35924 L .2197 .36424 L p F P
0 g
s
.803 .998 .794 r
.76894 .33379 m .76956 .33371 L .76706 .33775 L p F P
0 g
s
.803 .998 .794 r
.76242 .3403 m .76894 .33379 L p .76706 .33775 L F P
0 g
s
.803 .998 .794 r
.75953 .34512 m .76242 .3403 L p .76706 .33775 L F P
0 g
s
.803 .998 .794 r
.76706 .33775 m .75977 .34507 L .75953 .34512 L p F P
0 g
s
.882 .962 .846 r
.68284 .20574 m .67985 .20892 L .67858 .214 L p F P
0 g
s
.867 .972 .855 r
.67252 .21662 m .67985 .20892 L .67858 .214 L p F P
0 g
s
.867 .972 .855 r
.67202 .21821 m .67252 .21662 L p .67858 .214 L F P
0 g
s
.867 .972 .855 r
.67858 .214 m .67394 .21866 L .67202 .21821 L p F P
0 g
s
.882 .647 .578 r
.23695 .39821 m .242 .40114 L .24308 .39547 L p F P
0 g
s
.882 .647 .578 r
.24308 .39547 m .23802 .39255 L .23695 .39821 L p F P
0 g
s
0 0 0 r
.81928 .24945 m .81881 .25091 L .81932 .24697 L p F P
0 g
s
0 0 0 r
.81932 .24697 m .82036 .24374 L .81928 .24945 L p F P
0 g
s
.922 .6 .416 r
.2244 .37261 m .2288 .37579 L .22828 .37069 L p F P
0 g
s
.922 .6 .416 r
.22828 .37069 m .2239 .3675 L .2244 .37261 L p F P
0 g
s
.912 .615 .468 r
.22894 .38103 m .23354 .38413 L .23339 .37889 L p F P
0 g
s
.912 .615 .468 r
.23339 .37889 m .2288 .37579 L .22894 .38103 L p F P
0 g
s
.899 .63 .522 r
.23319 .38954 m .23802 .39255 L .23836 .38714 L p F P
0 g
s
.899 .63 .522 r
.23836 .38714 m .23354 .38413 L .23319 .38954 L p F P
0 g
s
.788 .998 .854 r
.74042 .36239 m .74807 .35582 L .74551 .35583 L p F P
0 g
s
.788 .998 .854 r
.74551 .35583 m .74431 .35686 L .74042 .36239 L p F P
0 g
s
.788 .995 .872 r
.73373 .36561 m .74431 .35686 L .74042 .36239 L p F P
0 g
s
.788 .995 .872 r
.73373 .36562 m .73373 .36561 L p .74042 .36239 L F P
0 g
s
.682 .796 .332 r
.81033 .27402 m .80865 .27793 L .81157 .27162 L p F P
0 g
s
.682 .796 .332 r
.81157 .27162 m .81174 .27122 L .81033 .27402 L p F P
0 g
s
.929 .568 .314 r
.21893 .35924 m .21801 .35476 L .21428 .35286 L p F P
0 g
s
0 0 0 r
.60749 .30596 m .60357 .31136 L .60817 .30452 L p F P
0 g
s
0 0 0 r
.60817 .30452 m .6093 .30297 L .60749 .30596 L p F P
0 g
s
.887 .967 .836 r
.67394 .21866 m .67114 .22173 L .67202 .21821 L closepath p F P
0 g
s
.142 0 .297 r
.57138 .36381 m .56788 .36679 L .56853 .36225 L p F P
0 g
s
.142 0 .297 r
.56853 .36225 m .57403 .35756 L .57138 .36381 L p F P
0 g
s
.79 .941 .59 r
.79694 .29788 m .79451 .30305 L .79901 .29621 L p F P
0 g
s
.79 .941 .59 r
.80097 .29182 m .79694 .29788 L p .79901 .29621 L F P
0 g
s
.79 .941 .59 r
.79901 .29621 m .80123 .29161 L .80097 .29182 L p F P
0 g
s
.79 .997 .798 r
.75977 .34507 m .75918 .34565 L .75953 .34512 L closepath p F P
0 g
s
.8 .998 .851 r
.75028 .35387 m .74807 .35582 L .74551 .35583 L p F P
0 g
s
.797 .999 .835 r
.75381 .34845 m .75028 .35387 L .75918 .34565 L p F P
0 g
s
.797 .999 .835 r
.75725 .34525 m .75381 .34845 L p .75918 .34565 L F P
0 g
s
.797 .999 .835 r
.75918 .34565 m .75953 .34512 L .75725 .34525 L p F P
0 g
s
.714 .934 .96 r
.65982 .41134 m .65926 .41164 L .65966 .41128 L closepath p F P
0 g
s
.714 .922 .963 r
.65698 .41003 m .65966 .41128 L .65926 .41164 L p F P
0 g
s
.714 .922 .963 r
.64508 .41612 m .65698 .41003 L p .65926 .41164 L F P
0 g
s
.8 .998 .851 r
.74551 .35583 m .75381 .34845 L .75028 .35387 L p F P
0 g
s
.411 .255 .557 r
.55866 .39471 m .55818 .38883 L .5487 .39511 L p F P
0 g
s
.411 .255 .557 r
.5487 .39511 m .54912 .40092 L .55866 .39471 L p F P
0 g
s
.716 .809 .923 r
.74916 .16363 m .74735 .16449 L .74461 .16141 L p F P
0 g
s
.758 .821 .901 r
.73267 .16862 m .74461 .16141 L .74735 .16449 L p F P
0 g
s
.343 .634 .961 r
.13125 .41066 m .12971 .41047 L .12595 .40712 L p F P
0 g
s
.726 .936 .956 r
.66889 .40361 m .6717 .40472 L .65982 .41134 L p F P
0 g
s
.726 .936 .956 r
.66555 .40545 m .66889 .40361 L p .65982 .41134 L F P
0 g
s
.726 .936 .956 r
.65982 .41134 m .65966 .41128 L .66555 .40545 L p F P
0 g
s
.825 .887 .888 r
.71611 .18049 m .72081 .17682 L .71807 .17445 L p F P
0 g
s
.825 .887 .888 r
.71807 .17445 m .71665 .17561 L .71611 .18049 L p F P
0 g
s
.815 .9 .901 r
.70628 .18394 m .71665 .17561 L .71611 .18049 L p F P
0 g
s
.889 .969 .832 r
.6659 .2241 m .6642 .2293 L .67114 .22173 L p F P
0 g
s
.889 .969 .832 r
.67118 .21803 m .6659 .2241 L p .67114 .22173 L F P
0 g
s
.889 .969 .832 r
.67114 .22173 m .67202 .21821 L .67118 .21803 L p F P
0 g
s
.534 .733 .966 r
.18066 .42792 m .18089 .4279 L .17983 .42721 L closepath p F P
0 g
s
.72 .809 .341 r
.81078 .27281 m .81033 .27402 L .81174 .27122 L p F P
0 g
s
.72 .809 .341 r
.81174 .27122 m .81348 .26655 L .81078 .27281 L p F P
0 g
s
0 0 .126 r
.8219 .23873 m .82036 .24374 L .82089 .23821 L p F P
0 g
s
0 0 .126 r
.82089 .23821 m .82245 .23319 L .8219 .23873 L p F P
0 g
s
.549 .737 .963 r
.18799 .42331 m .19167 .42655 L .18089 .4279 L p F P
0 g
s
.549 .737 .963 r
.17697 .42476 m .18799 .42331 L p .18089 .4279 L F P
0 g
s
.549 .737 .963 r
.18089 .4279 m .17983 .42721 L .17697 .42476 L p F P
0 g
s
.285 .088 .428 r
.55852 .38313 m .55811 .38343 L .55835 .37839 L p F P
0 g
s
.285 .088 .428 r
.55835 .37839 m .55983 .37729 L .55852 .38313 L p F P
0 g
s
.674 .879 .504 r
.62009 .28758 m .6188 .28906 L .62178 .28491 L closepath p F P
0 g
s
0 0 0 r
.81761 .25536 m .81571 .26045 L .81744 .25452 L p F P
0 g
s
0 0 0 r
.81829 .25304 m .81761 .25536 L p .81744 .25452 L F P
0 g
s
0 0 0 r
.81744 .25452 m .81881 .25091 L .81829 .25304 L p F P
0 g
s
.196 .282 .726 r
.81645 .19205 m .81859 .19413 L .81809 .19674 L closepath p F P
0 g
s
.053 .154 .653 r
.82173 .19841 m .81859 .19413 L .81809 .19674 L p F P
0 g
s
.053 .154 .653 r
.82074 .20332 m .82173 .19841 L p .81809 .19674 L F P
0 g
s
.053 .154 .653 r
.81809 .19674 m .81959 .20164 L .82074 .20332 L p F P
0 g
s
.822 .989 .729 r
.782 .32051 m .78053 .32104 L .78367 .31731 L closepath p F P
0 g
s
.724 .926 .959 r
.65966 .41128 m .65698 .41003 L .66555 .40545 L closepath p F P
0 g
s
.757 .947 .621 r
.62974 .27243 m .63488 .26543 L .63206 .27092 L p F P
0 g
s
.757 .947 .621 r
.62862 .27451 m .62974 .27243 L p .63206 .27092 L F P
0 g
s
.757 .947 .621 r
.63206 .27092 m .63035 .27313 L .62862 .27451 L p F P
0 g
s
.728 .81 .915 r
.74916 .16363 m .75939 .15871 L .75665 .15526 L p F P
0 g
s
.728 .81 .915 r
.75665 .15526 m .75021 .15856 L .74916 .16363 L p F P
0 g
s
.716 .809 .923 r
.74461 .16141 m .75021 .15856 L .74916 .16363 L p F P
0 g
s
.746 .969 .931 r
.6982 .39115 m .69271 .39469 L .69637 .39068 L closepath p F P
0 g
s
.747 .959 .939 r
.69548 .39039 m .69637 .39068 L .69271 .39469 L p F P
0 g
s
.747 .959 .939 r
.68359 .39779 m .69548 .39039 L p .69271 .39469 L F P
0 g
s
.79 .874 .909 r
.7297 .1707 m .72081 .17682 L .71807 .17445 L p F P
0 g
s
.099 .173 .653 r
.81959 .20164 m .82074 .20332 L .82046 .20462 L closepath p F P
0 g
s
.814 1 .828 r
.75953 .34512 m .75725 .34525 L .76242 .3403 L closepath p F P
0 g
s
.819 .74 .778 r
.23651 .4223 m .24128 .41658 L .24658 .41939 L p F P
0 g
s
.819 .74 .778 r
.24658 .41939 m .24003 .42667 L .23651 .4223 L p F P
0 g
s
.752 .732 .834 r
.24003 .42667 m .23954 .42701 L .24072 .4275 L closepath p F P
0 g
s
.161 .274 .732 r
.81479 .18758 m .81645 .19205 L .81859 .19413 L p F P
0 g
s
0 0 .505 r
.82324 .21765 m .82322 .21771 L .82173 .21288 L p F P
0 g
s
0 0 .505 r
.82173 .21288 m .82213 .21152 L .82324 .21765 L p F P
0 g
s
0 .066 .578 r
.82292 .20792 m .82213 .21152 L .82046 .20462 L p F P
0 g
s
0 .066 .578 r
.82046 .20462 m .82074 .20332 L .82292 .20792 L p F P
0 g
s
.871 .99 .823 r
.65956 .23128 m .6659 .2241 L .6642 .2293 L p F P
0 g
s
.871 .99 .823 r
.6642 .2293 m .66232 .23134 L .65956 .23128 L p F P
0 g
s
.787 .953 .622 r
.63035 .27313 m .62684 .27794 L .62862 .27451 L closepath p F P
0 g
s
.704 .912 .967 r
.64508 .41612 m .63907 .41904 L .64347 .4153 L closepath p F P
0 g
s
.706 .895 .965 r
.64221 .4146 m .64347 .4153 L .63907 .41904 L p F P
0 g
s
.706 .895 .965 r
.6303 .42014 m .64221 .4146 L p .63907 .41904 L F P
0 g
s
.895 .986 .789 r
.65779 .23669 m .66232 .23134 L .65956 .23128 L p F P
0 g
s
.467 .704 .972 r
.17983 .42721 m .17697 .42476 L .17649 .42478 L closepath p F P
0 g
s
.691 .873 .967 r
.62738 .41832 m .6303 .42014 L .61841 .42539 L p F P
0 g
s
.691 .873 .967 r
.61742 .42262 m .62738 .41832 L p .61841 .42539 L F P
0 g
s
.691 .873 .967 r
.61841 .42539 m .61598 .42379 L .61742 .42262 L p F P
0 g
s
.343 .634 .961 r
.12595 .40712 m .12742 .4073 L .13125 .41066 L p F P
0 g
s
.355 .64 .962 r
.13662 .4083 m .12742 .4073 L .13125 .41066 L p F P
0 g
s
.355 .64 .962 r
.13125 .41066 m .14038 .41166 L .13662 .4083 L p F P
0 g
s
.017 0 .166 r
.58698 .33867 m .58707 .33831 L .58087 .34459 L p F P
0 g
s
.017 0 .166 r
.58402 .34453 m .58698 .33867 L p .58087 .34459 L F P
0 g
s
.017 0 .166 r
.57795 .35049 m .58402 .34453 L p .58087 .34459 L F P
0 g
s
.017 0 .166 r
.58087 .34459 m .57821 .34938 L .57795 .35049 L p F P
0 g
s
.765 .734 .824 r
.23954 .42701 m .24003 .42667 L .23651 .4223 L p F P
0 g
s
.765 .734 .824 r
.23651 .4223 m .23378 .42436 L .23954 .42701 L p F P
0 g
s
.737 .766 .876 r
.225 .42976 m .23378 .42436 L .23954 .42701 L p F P
0 g
s
.279 .374 .782 r
.81345 .18424 m .81516 .18536 L .81479 .18758 L closepath p F P
0 g
s
.161 .274 .732 r
.81947 .18923 m .81516 .18536 L .81479 .18758 L p F P
0 g
s
.161 .274 .732 r
.81859 .19413 m .81947 .18923 L p .81479 .18758 L F P
0 g
s
.758 .97 .927 r
.70828 .38442 m .6982 .39115 L .69637 .39068 L p F P
0 g
s
0 0 0 r
.60373 .31216 m .59905 .31817 L .60357 .31136 L p F P
0 g
s
0 0 0 r
.60726 .30638 m .60373 .31216 L p .60357 .31136 L F P
0 g
s
0 0 0 r
.60357 .31136 m .60749 .30596 L .60726 .30638 L p F P
0 g
s
.807 .96 .632 r
.79195 .30488 m .79694 .29788 L .79451 .30305 L p F P
0 g
s
.807 .96 .632 r
.79079 .3074 m .79195 .30488 L p .79451 .30305 L F P
0 g
s
.807 .96 .632 r
.79451 .30305 m .79198 .30659 L .79079 .3074 L p F P
0 g
s
.278 .083 .426 r
.56718 .3766 m .55852 .38313 L .55983 .37729 L p F P
0 g
s
.278 .083 .426 r
.55983 .37729 m .56742 .37156 L .56718 .3766 L p F P
0 g
s
0 0 0 r
.60784 .30547 m .60749 .30596 L .6093 .30297 L p F P
0 g
s
.625 .645 .85 r
.55602 .42458 m .5589 .42951 L .57076 .42664 L p F P
0 g
s
.625 .716 .912 r
.5589 .42951 m .57076 .42664 L .57382 .43052 L p F P
0 g
s
.503 .594 .877 r
.79216 .16454 m .80247 .16508 L .8016 .17003 L p F P
0 g
s
.526 .599 .87 r
.80247 .16508 m .79216 .16454 L .78939 .15986 L p F P
0 g
s
.79 .874 .909 r
.71807 .17445 m .7299 .16592 L .7297 .1707 L p F P
0 g
s
.799 .858 .893 r
.7297 .1707 m .73267 .16862 L .72994 .16589 L p F P
0 g
s
.799 .858 .893 r
.72994 .16589 m .7299 .16592 L .7297 .1707 L p F P
0 g
s
.407 .672 .969 r
.14413 .41496 m .14775 .41512 L .15181 .41838 L p F P
0 g
s
.414 .675 .969 r
.15491 .41538 m .14775 .41512 L .15181 .41838 L p F P
0 g
s
.414 .675 .969 r
.15181 .41838 m .15865 .41865 L .15491 .41538 L p F P
0 g
s
.603 .746 .945 r
.19534 .42975 m .20648 .4272 L .21012 .43052 L p F P
0 g
s
.61 .747 .942 r
.20648 .4272 m .19534 .42975 L .19167 .42655 L p F P
0 g
s
.895 .986 .789 r
.65956 .23128 m .65934 .23155 L .65779 .23669 L p F P
0 g
s
.895 .987 .785 r
.65354 .23876 m .65149 .24406 L .65779 .23669 L p F P
0 g
s
.895 .987 .785 r
.65779 .23669 m .65934 .23155 L .65354 .23876 L p F P
0 g
s
.478 .34 .614 r
.54754 .40182 m .54912 .40092 L .54943 .40321 L closepath p F P
0 g
s
.779 .945 .604 r
.62489 .27934 m .62178 .28491 L .62684 .27794 L p F P
0 g
s
.779 .945 .604 r
.62758 .2754 m .62489 .27934 L p .62684 .27794 L F P
0 g
s
.779 .945 .604 r
.62684 .27794 m .62862 .27451 L .62758 .2754 L p F P
0 g
s
.748 .869 .446 r
.80743 .27928 m .80529 .2844 L .80865 .27793 L p F P
0 g
s
.748 .869 .446 r
.80981 .27475 m .80743 .27928 L p .80865 .27793 L F P
0 g
s
.748 .869 .446 r
.80865 .27793 m .81033 .27402 L .80981 .27475 L p F P
0 g
s
.863 .996 .776 r
.65114 .24487 m .65072 .24496 L .65149 .24406 L closepath p F P
0 g
s
.845 .696 .697 r
.23625 .41367 m .24128 .41658 L .24511 .41 L p F P
0 g
s
.845 .696 .697 r
.24511 .41 m .23988 .40715 L .23625 .41367 L p F P
0 g
s
.467 .702 .97 r
.16237 .42186 m .17228 .42158 L .17649 .42478 L p F P
0 g
s
.471 .702 .969 r
.17228 .42158 m .16237 .42186 L .15865 .41865 L p F P
0 g
s
.3 .398 .796 r
.81516 .18536 m .81345 .18424 L .81052 .17735 L p F P
0 g
s
.767 .826 .899 r
.74461 .16141 m .73267 .16862 L .72994 .16589 L p F P
0 g
s
0 .067 .582 r
.82397 .20299 m .82292 .20792 L .82074 .20332 L p F P
0 g
s
0 .067 .582 r
.82074 .20332 m .82173 .19841 L .82397 .20299 L p F P
0 g
s
.791 .958 .634 r
.79198 .30659 m .7894 .31008 L .79079 .3074 L closepath p F P
0 g
s
0 0 .476 r
.82433 .21279 m .82324 .21765 L .82213 .21152 L p F P
0 g
s
0 0 .476 r
.82213 .21152 m .82292 .20792 L .82433 .21279 L p F P
0 g
s
.845 .928 .885 r
.69562 .19499 m .69454 .19438 L .69613 .19297 L closepath p F P
0 g
s
.672 .843 .965 r
.61547 .42344 m .60358 .42814 L .6006 .4257 L p F P
0 g
s
.662 .827 .962 r
.58872 .42991 m .6006 .4257 L .60358 .42814 L p F P
0 g
s
0 0 .26 r
.824 .22816 m .82245 .23319 L .82239 .22786 L p F P
0 g
s
0 0 .26 r
.82398 .22608 m .824 .22816 L p .82239 .22786 L F P
0 g
s
0 0 .26 r
.82239 .22786 m .82386 .2231 L .82398 .22608 L p F P
0 g
s
.453 .537 .853 r
.8048 .1654 m .80247 .16508 L .8016 .17003 L p F P
0 g
s
.453 .537 .853 r
.8016 .17003 m .80765 .17118 L .8048 .1654 L p F P
0 g
s
.715 .914 .963 r
.65413 .40863 m .65698 .41003 L .64508 .41612 L p F P
0 g
s
.715 .914 .963 r
.6464 .41253 m .65413 .40863 L p .64508 .41612 L F P
0 g
s
.715 .914 .963 r
.64508 .41612 m .64347 .4153 L .6464 .41253 L p F P
0 g
s
0 0 0 r
.59869 .31861 m .5985 .31905 L .59905 .31817 L closepath p F P
0 g
s
.031 0 .171 r
.57821 .34938 m .57721 .35114 L .57795 .35049 L closepath p F P
0 g
s
.737 .942 .951 r
.68044 .39967 m .6717 .40472 L .66889 .40361 L p F P
0 g
s
.871 .675 .635 r
.2349 .40421 m .23988 .40715 L .242 .40114 L p F P
0 g
s
.871 .675 .635 r
.242 .40114 m .23695 .39821 L .2349 .40421 L p F P
0 g
s
.646 .781 .946 r
.57382 .43052 m .58569 .42691 L .58872 .42991 L p F P
0 g
s
.633 .747 .93 r
.58569 .42691 m .57382 .43052 L .57076 .42664 L p F P
0 g
s
.675 .751 .908 r
.21012 .43052 m .2214 .42617 L .225 .42976 L p F P
0 g
s
.684 .752 .903 r
.2214 .42617 m .21012 .43052 L .20648 .4272 L p F P
0 g
s
.747 .766 .868 r
.23378 .42436 m .225 .42976 L .2214 .42617 L p F P
0 g
s
.861 .996 .773 r
.64795 .2456 m .65354 .23876 L .65149 .24406 L p F P
0 g
s
.861 .996 .773 r
.65149 .24406 m .65072 .24496 L .64795 .2456 L p F P
0 g
s
.815 .982 .701 r
.78631 .31209 m .78367 .31731 L .7894 .31008 L p F P
0 g
s
.815 .982 .701 r
.78963 .30791 m .78631 .31209 L p .7894 .31008 L F P
0 g
s
.815 .982 .701 r
.7894 .31008 m .79079 .3074 L .78963 .30791 L p F P
0 g
s
.758 .978 .917 r
.71006 .3832 m .70828 .38442 L .70943 .38307 L closepath p F P
0 g
s
.758 .97 .927 r
.70736 .38249 m .70943 .38307 L .70828 .38442 L p F P
0 g
s
.758 .97 .927 r
.69792 .38881 m .70736 .38249 L p .70828 .38442 L F P
0 g
s
.758 .97 .927 r
.69637 .39068 m .69792 .38881 L p .70828 .38442 L F P
0 g
s
.655 .804 .955 r
.6006 .4257 m .58872 .42991 L .58569 .42691 L p F P
0 g
s
.481 .342 .615 r
.55972 .40123 m .55866 .39471 L .54912 .40092 L p F P
0 g
s
.481 .342 .615 r
.55285 .40563 m .55972 .40123 L p .54912 .40092 L F P
0 g
s
.481 .342 .615 r
.54912 .40092 m .54943 .40321 L .55285 .40563 L p F P
0 g
s
.881 .99 .738 r
.64578 .25123 m .65072 .24496 L .64795 .2456 L p F P
0 g
s
0 0 0 r
.81533 .26149 m .81348 .26655 L .81571 .26045 L p F P
0 g
s
0 0 0 r
.81571 .26045 m .81761 .25536 L .81533 .26149 L p F P
0 g
s
.892 .657 .576 r
.23214 .3952 m .23695 .39821 L .23802 .39255 L p F P
0 g
s
.892 .657 .576 r
.23802 .39255 m .23319 .38954 L .23214 .3952 L p F P
0 g
s
0 0 0 r
.59981 .3188 m .60373 .31216 L .59905 .31817 L p F P
0 g
s
0 0 0 r
.59723 .32207 m .59981 .3188 L p .59905 .31817 L F P
0 g
s
0 0 0 r
.59905 .31817 m .5985 .31905 L .59723 .32207 L p F P
0 g
s
.913 .51 .178 r
.20612 .34419 m .20986 .34765 L .20834 .34293 L p F P
0 g
s
.913 .51 .178 r
.20834 .34293 m .2046 .33947 L .20612 .34419 L p F P
0 g
s
.77 .979 .912 r
.72183 .37477 m .71006 .3832 L .70943 .38307 L p F P
0 g
s
.074 0 .228 r
.57713 .3548 m .57403 .35756 L .57721 .35114 L p F P
0 g
s
.074 0 .228 r
.57721 .35114 m .57795 .35049 L .57713 .3548 L p F P
0 g
s
0 0 0 r
.8208 .24446 m .81928 .24945 L .82036 .24374 L p F P
0 g
s
0 0 0 r
.82036 .24374 m .8219 .23873 L .8208 .24446 L p F P
0 g
s
.108 .196 .674 r
.82271 .19348 m .82173 .19841 L .81859 .19413 L p F P
0 g
s
.108 .196 .674 r
.81859 .19413 m .81947 .18923 L .82271 .19348 L p F P
0 g
s
.909 .64 .518 r
.22857 .38645 m .23319 .38954 L .23354 .38413 L p F P
0 g
s
.909 .64 .518 r
.23354 .38413 m .22894 .38103 L .22857 .38645 L p F P
0 g
s
.676 .744 .902 r
.75939 .15871 m .77155 .15415 L .77429 .15805 L p F P
0 g
s
.687 .754 .903 r
.77155 .15415 m .75939 .15871 L .75665 .15526 L p F P
0 g
s
.923 .539 .251 r
.21058 .35032 m .20986 .34765 L .21379 .35103 L p F P
0 g
s
.923 .539 .251 r
.21379 .35103 m .21428 .35286 L .21058 .35032 L p F P
0 g
s
0 0 0 r
.5985 .31905 m .59491 .32487 L .59723 .32207 L closepath p F P
0 g
s
.651 .863 .483 r
.62029 .28618 m .62489 .27934 L .62178 .28491 L p F P
0 g
s
.651 .863 .483 r
.61795 .29009 m .62029 .28618 L p .62178 .28491 L F P
0 g
s
.651 .863 .483 r
.62178 .28491 m .6188 .28906 L .61795 .29009 L p F P
0 g
s
.921 .624 .463 r
.22452 .37786 m .22894 .38103 L .2288 .37579 L p F P
0 g
s
.921 .624 .463 r
.2288 .37579 m .2244 .37261 L .22452 .37786 L p F P
0 g
s
0 0 .021 r
.58727 .33809 m .58707 .33831 L .58827 .33448 L p F P
0 g
s
0 0 .021 r
.58827 .33448 m .59098 .33151 L .58727 .33809 L p F P
0 g
s
.411 .671 .968 r
.14775 .41512 m .14413 .41496 L .14038 .41166 L p F P
0 g
s
.93 .608 .41 r
.22017 .36936 m .2244 .37261 L .2239 .3675 L p F P
0 g
s
.93 .608 .41 r
.2239 .3675 m .2197 .36424 L .22017 .36936 L p F P
0 g
s
.929 .568 .314 r
.21428 .35286 m .2149 .3559 L .21893 .35924 L p F P
0 g
s
.934 .592 .358 r
.21565 .36091 m .2197 .36424 L .21893 .35924 L p F P
0 g
s
.934 .592 .358 r
.21893 .35924 m .2149 .3559 L .21565 .36091 L p F P
0 g
s
.628 .7 .897 r
.78662 .15537 m .77429 .15805 L .77155 .15415 L p F P
0 g
s
.614 .686 .894 r
.78813 .15781 m .78749 .16015 L p .77429 .15805 L F P
0 g
s
.614 .686 .894 r
.77429 .15805 m .78662 .15537 L .78813 .15781 L p F P
0 g
s
.385 .468 .823 r
.81001 .17716 m .81015 .17652 L .81052 .17735 L closepath p F P
0 g
s
.559 .5 .746 r
.54859 .41676 m .55204 .41486 L .55265 .41667 L closepath p F P
0 g
s
.462 .346 .635 r
.54943 .40321 m .55285 .40563 L .55013 .40739 L closepath p F P
0 g
s
.3 .398 .796 r
.81052 .17735 m .81589 .18049 L .81516 .18536 L p F P
0 g
s
.213 .311 .748 r
.82036 .18431 m .81947 .18923 L .81516 .18536 L p F P
0 g
s
.213 .311 .748 r
.81516 .18536 m .81589 .18049 L .82036 .18431 L p F P
0 g
s
.79 .912 .522 r
.80356 .28593 m .80148 .29102 L .80529 .2844 L p F P
0 g
s
.79 .912 .522 r
.80529 .2844 m .80743 .27928 L .80356 .28593 L p F P
0 g
s
.02 0 .207 r
.58116 .35085 m .57713 .3548 L .57795 .35049 L p F P
0 g
s
.02 0 .207 r
.57795 .35049 m .58402 .34453 L .58116 .35085 L p F P
0 g
s
.828 .739 .767 r
.23298 .41787 m .23625 .41367 L .24128 .41658 L p F P
0 g
s
.828 .739 .767 r
.24128 .41658 m .23651 .4223 L .23298 .41787 L p F P
0 g
s
.876 .973 .845 r
.67202 .21821 m .67118 .21803 L .67252 .21662 L closepath p F P
0 g
s
.469 .703 .97 r
.17326 .42155 m .17228 .42158 L .17649 .42478 L p F P
0 g
s
.469 .703 .97 r
.17649 .42478 m .17697 .42476 L .17326 .42155 L p F P
0 g
s
.881 .99 .738 r
.64795 .2456 m .64765 .24601 L .64578 .25123 L p F P
0 g
s
.881 .988 .73 r
.64241 .25304 m .64008 .25841 L .64578 .25123 L p F P
0 g
s
.881 .988 .73 r
.64578 .25123 m .64765 .24601 L .64241 .25304 L p F P
0 g
s
.33 .158 .49 r
.55854 .38857 m .55818 .38883 L .55811 .38343 L p F P
0 g
s
.33 .158 .49 r
.55811 .38343 m .55852 .38313 L .55854 .38857 L p F P
0 g
s
.824 .99 .731 r
.7801 .31949 m .78631 .31209 L .78367 .31731 L p F P
0 g
s
.824 .99 .731 r
.77907 .32156 m .7801 .31949 L p .78367 .31731 L F P
0 g
s
.824 .99 .731 r
.78367 .31731 m .78053 .32104 L .77907 .32156 L p F P
0 g
s
.274 .399 .808 r
.81015 .17652 m .81052 .17735 L .81589 .18049 L p F P
0 g
s
.182 0 .351 r
.5694 .36987 m .56742 .37156 L .56788 .36679 L p F P
0 g
s
.182 0 .351 r
.56788 .36679 m .57138 .36381 L .5694 .36987 L p F P
0 g
s
.833 .984 .705 r
.63963 .25935 m .63915 .2596 L .64008 .25841 L closepath p F P
0 g
s
.684 .876 .492 r
.6188 .28906 m .61691 .29183 L .61795 .29009 L closepath p F P
0 g
s
.823 1 .801 r
.76956 .33371 m .76894 .33379 L .7703 .33239 L closepath p F P
0 g
s
.589 .67 .896 r
.78749 .16015 m .78813 .15781 L .78939 .15986 L closepath p F P
0 g
s
.593 .604 .833 r
.5558 .42415 m .55697 .42398 L .55602 .42458 L closepath p F P
0 g
s
.625 .645 .85 r
.56767 .422 m .55697 .42398 L .55602 .42458 L p F P
0 g
s
.625 .645 .85 r
.57076 .42664 m .56767 .422 L p .55602 .42458 L F P
0 g
s
.547 .731 .96 r
.18799 .42331 m .17697 .42476 L .17326 .42155 L p F P
0 g
s
0 0 0 r
.81881 .25091 m .81829 .25304 L .81928 .24945 L closepath p F P
0 g
s
.368 .473 .836 r
.80765 .17118 m .81061 .17231 L .81015 .17652 L closepath p F P
0 g
s
.274 .399 .808 r
.81665 .17559 m .81061 .17231 L .81015 .17652 L p F P
0 g
s
.274 .399 .808 r
.81589 .18049 m .81665 .17559 L p .81015 .17652 L F P
0 g
s
.737 .953 .946 r
.68359 .39779 m .68044 .39967 L .68257 .39744 L closepath p F P
0 g
s
.737 .942 .951 r
.68081 .39673 m .68257 .39744 L .68044 .39967 L p F P
0 g
s
.737 .942 .951 r
.66889 .40361 m .68081 .39673 L p .68044 .39967 L F P
0 g
s
.325 .154 .489 r
.56726 .38201 m .55854 .38857 L .55852 .38313 L p F P
0 g
s
.325 .154 .489 r
.55852 .38313 m .56718 .3766 L .56726 .38201 L p F P
0 g
s
.845 .93 .885 r
.69613 .19297 m .69454 .19438 L .69178 .19284 L p F P
0 g
s
.875 .941 .857 r
.68773 .20103 m .69454 .19438 L .69178 .19284 L p F P
0 g
s
.559 .575 .826 r
.55697 .42398 m .5558 .42415 L .55265 .41667 L p F P
0 g
s
.85 .905 .874 r
.69713 .18794 m .69613 .19297 L .70559 .18456 L p F P
0 g
s
.845 .93 .885 r
.69178 .19284 m .69713 .18794 L .69613 .19297 L p F P
0 g
s
.77 .979 .912 r
.70943 .38307 m .71276 .37875 L p .72183 .37477 L F P
0 g
s
.771 .97 .923 r
.70943 .38307 m .70736 .38249 L .71276 .37875 L closepath p F P
0 g
s
.727 .816 .92 r
.75021 .15856 m .74461 .16141 L .74188 .15837 L p F P
0 g
s
.767 .826 .899 r
.72994 .16589 m .74188 .15837 L .74461 .16141 L p F P
0 g
s
.698 .891 .968 r
.64221 .4146 m .6303 .42014 L .62738 .41832 L p F P
0 g
s
.77 .986 .9 r
.7219 .37471 m .72183 .37477 L .72187 .37471 L closepath p F P
0 g
s
.77 .979 .912 r
.71923 .3741 m .72187 .37471 L .72183 .37477 L p F P
0 g
s
.77 .979 .912 r
.71276 .37875 m .71923 .3741 L p .72183 .37477 L F P
0 g
s
.778 .74 .818 r
.23378 .42436 m .23651 .4223 L .23298 .41787 L p F P
0 g
s
.778 .74 .818 r
.23298 .41787 m .22847 .42154 L .23378 .42436 L p F P
0 g
s
.747 .766 .868 r
.2214 .42617 m .22847 .42154 L .23378 .42436 L p F P
0 g
s
.787 .987 .894 r
.73109 .36515 m .73372 .36562 L .7219 .37471 L p F P
0 g
s
.787 .987 .894 r
.72579 .36923 m .73109 .36515 L p .7219 .37471 L F P
0 g
s
.787 .987 .894 r
.7219 .37471 m .72187 .37471 L .72579 .36923 L p F P
0 g
s
0 0 .388 r
.82322 .21771 m .82324 .21765 L .82335 .21857 L closepath p F P
0 g
s
.81 .99 .735 r
.78053 .32104 m .7773 .32475 L .77907 .32156 L closepath p F P
0 g
s
.784 .978 .909 r
.72187 .37471 m .71923 .3741 L .72579 .36923 L closepath p F P
0 g
s
0 0 .326 r
.82505 .2179 m .82433 .21279 L .82324 .21765 L p F P
0 g
s
0 0 .326 r
.82393 .22282 m .82505 .2179 L p .82324 .21765 L F P
0 g
s
0 0 .326 r
.82324 .21765 m .82335 .21857 L .82393 .22282 L p F P
0 g
s
.846 .903 .876 r
.70628 .18394 m .70559 .18456 L .70568 .18352 L closepath p F P
0 g
s
.85 .905 .874 r
.70353 .182 m .69713 .18794 L p .70559 .18456 L F P
0 g
s
.85 .905 .874 r
.70559 .18456 m .70568 .18352 L .70353 .182 L p F P
0 g
s
.824 .903 .895 r
.71665 .17561 m .70628 .18394 L .70568 .18352 L p F P
0 g
s
.875 .941 .857 r
.69178 .19284 m .68863 .19605 L .68773 .20103 L p F P
0 g
s
.863 .951 .868 r
.68078 .20394 m .68863 .19605 L .68773 .20103 L p F P
0 g
s
.863 .951 .868 r
.68056 .20482 m .68078 .20394 L p .68773 .20103 L F P
0 g
s
.863 .951 .868 r
.68773 .20103 m .68284 .20574 L .68056 .20482 L p F P
0 g
s
.934 .572 .301 r
.2149 .3559 m .21428 .35286 L .21058 .35032 L p F P
0 g
s
.883 .946 .848 r
.68284 .20574 m .67985 .20892 L .68056 .20482 L closepath p F P
0 g
s
.67 .861 .468 r
.61574 .29301 m .61235 .29866 L .61691 .29183 L p F P
0 g
s
.67 .861 .468 r
.61603 .29256 m .61574 .29301 L p .61691 .29183 L F P
0 g
s
.67 .861 .468 r
.61691 .29183 m .61795 .29009 L .61603 .29256 L p F P
0 g
s
0 0 0 r
.59585 .32564 m .59098 .33151 L .59491 .32487 L p F P
0 g
s
0 0 0 r
.59491 .32487 m .59723 .32207 L .59585 .32564 L p F P
0 g
s
.559 .575 .826 r
.56582 .41868 m .55697 .42398 L p .55265 .41667 L F P
0 g
s
.605 .627 .846 r
.55697 .42398 m .56582 .41868 L .56767 .422 L closepath p F P
0 g
s
.751 .955 .94 r
.69273 .38942 m .69548 .39039 L .68359 .39779 L p F P
0 g
s
.751 .955 .94 r
.68575 .39375 m .69273 .38942 L p .68359 .39779 L F P
0 g
s
.751 .955 .94 r
.68359 .39779 m .68257 .39744 L .68575 .39375 L p F P
0 g
s
.822 .998 .782 r
.77313 .32713 m .7703 .33239 L .7773 .32475 L p F P
0 g
s
.822 .998 .782 r
.7781 .32174 m .77313 .32713 L p .7773 .32475 L F P
0 g
s
.822 .998 .782 r
.7773 .32475 m .77907 .32156 L .7781 .32174 L p F P
0 g
s
.503 .422 .697 r
.56163 .40871 m .55204 .41486 L .55013 .40739 L p F P
0 g
s
.503 .422 .697 r
.56139 .40793 m .56163 .40871 L p .55013 .40739 L F P
0 g
s
.503 .422 .697 r
.55013 .40739 m .55285 .40563 L .56139 .40793 L p F P
0 g
s
.813 .944 .588 r
.80123 .29161 m .80097 .29182 L .80148 .29102 L closepath p F P
0 g
s
.526 .599 .87 r
.80305 .162 m .80247 .16508 L p .78939 .15986 L F P
0 g
s
.526 .599 .87 r
.78939 .15986 m .80197 .15996 L .80305 .162 L p F P
0 g
s
.511 .631 .905 r
.78813 .15781 m .78939 .15986 L .80197 .15996 L p F P
0 g
s
.886 .949 .844 r
.67387 .21151 m .67252 .21662 L .67985 .20892 L p F P
0 g
s
.886 .949 .844 r
.68008 .20463 m .67387 .21151 L p .67985 .20892 L F P
0 g
s
.886 .949 .844 r
.67985 .20892 m .68056 .20482 L .68008 .20463 L p F P
0 g
s
0 0 .361 r
.82335 .21857 m .82393 .22282 L .82386 .2231 L closepath p F P
0 g
s
.689 .865 .965 r
.61598 .42379 m .61547 .42344 L .61742 .42262 L closepath p F P
0 g
s
.828 .983 .7 r
.6371 .2601 m .64241 .25304 L .64008 .25841 L p F P
0 g
s
.828 .983 .7 r
.63676 .26086 m .6371 .2601 L p .64008 .25841 L F P
0 g
s
.828 .983 .7 r
.64008 .25841 m .63915 .2596 L .63676 .26086 L p F P
0 g
s
.758 .96 .935 r
.69637 .39068 m .69548 .39039 L .69792 .38881 L closepath p F P
0 g
s
.113 0 .279 r
.57646 .35931 m .57138 .36381 L .57403 .35756 L p F P
0 g
s
.113 0 .279 r
.57403 .35756 m .57713 .3548 L .57646 .35931 L p F P
0 g
s
.855 .704 .695 r
.23144 .41068 m .23625 .41367 L .23988 .40715 L p F P
0 g
s
.855 .704 .695 r
.23988 .40715 m .2349 .40421 L .23144 .41068 L p F P
0 g
s
.824 .879 .885 r
.71807 .17445 m .71665 .17561 L .71678 .17334 L closepath p F P
0 g
s
.824 .903 .895 r
.71533 .17212 m .71678 .17334 L .71665 .17561 L p F P
0 g
s
.824 .903 .895 r
.70647 .17956 m .71533 .17212 L p .71665 .17561 L F P
0 g
s
.824 .903 .895 r
.70568 .18352 m .70647 .17956 L p .71665 .17561 L F P
0 g
s
.737 .823 .362 r
.81258 .26777 m .81078 .27281 L .81348 .26655 L p F P
0 g
s
.737 .823 .362 r
.81348 .26655 m .81533 .26149 L .81258 .26777 L p F P
0 g
s
.726 .921 .958 r
.66555 .40545 m .65698 .41003 L .65413 .40863 L p F P
0 g
s
.855 .982 .693 r
.63915 .2596 m .63488 .26543 L .63676 .26086 L closepath p F P
0 g
s
.8 .877 .904 r
.7299 .16592 m .71807 .17445 L .71678 .17334 L p F P
0 g
s
.712 .904 .964 r
.64347 .4153 m .64221 .4146 L .6464 .41253 L closepath p F P
0 g
s
.792 .988 .89 r
.73373 .36562 m .73372 .36562 L .73373 .36561 L closepath p F P
0 g
s
.796 .986 .893 r
.73373 .36561 m .73372 .36562 L .73109 .36515 L p F P
0 g
s
.794 .991 .882 r
.73735 .36017 m .73373 .36561 L .74431 .35686 L p F P
0 g
s
.796 .986 .893 r
.73109 .36515 m .73735 .36017 L .73373 .36561 L p F P
0 g
s
.411 .671 .968 r
.14038 .41166 m .14381 .41181 L .14775 .41512 L p F P
0 g
s
.418 .674 .968 r
.15117 .41206 m .14381 .41181 L .14775 .41512 L p F P
0 g
s
.418 .674 .968 r
.14775 .41512 m .15491 .41538 L .15117 .41206 L p F P
0 g
s
0 0 .116 r
.82342 .23371 m .8219 .23873 L .82245 .23319 L p F P
0 g
s
0 0 .116 r
.82245 .23319 m .824 .22816 L .82342 .23371 L p F P
0 g
s
.875 .974 .845 r
.66842 .21746 m .67387 .21151 L .67252 .21662 L p F P
0 g
s
.875 .974 .845 r
.67252 .21662 m .67118 .21803 L .66842 .21746 L p F P
0 g
s
.771 .943 .603 r
.62862 .27451 m .62758 .2754 L .62974 .27243 L closepath p F P
0 g
s
.826 1 .803 r
.76645 .33409 m .77313 .32713 L .7703 .33239 L p F P
0 g
s
.826 1 .803 r
.7703 .33239 m .76894 .33379 L .76645 .33409 L p F P
0 g
s
.831 .906 .891 r
.70568 .18352 m .70353 .182 L .70647 .17956 L closepath p F P
0 g
s
.816 .945 .591 r
.79928 .29271 m .80356 .28593 L .80148 .29102 L p F P
0 g
s
.816 .945 .591 r
.799 .29341 m .79928 .29271 L p .80148 .29102 L F P
0 g
s
.816 .945 .591 r
.80148 .29102 m .80097 .29182 L .799 .29341 L p F P
0 g
s
.813 1 .804 r
.76242 .3403 m .76894 .33379 L .76645 .33409 L p F P
0 g
s
.9 .974 .811 r
.6659 .2241 m .67118 .21803 L .66842 .21746 L p F P
0 g
s
.61 .747 .942 r
.19167 .42655 m .20282 .42385 L .20648 .4272 L p F P
0 g
s
.616 .748 .94 r
.20282 .42385 m .19167 .42655 L .18799 .42331 L p F P
0 g
s
.738 .81 .908 r
.75021 .15856 m .75665 .15526 L .75391 .15187 L p F P
0 g
s
.738 .81 .908 r
.75391 .15187 m .75045 .15375 L .75021 .15856 L p F P
0 g
s
.727 .816 .92 r
.74188 .15837 m .75045 .15375 L .75021 .15856 L p F P
0 g
s
.559 .575 .826 r
.55265 .41667 m .56455 .41612 L .56582 .41868 L p F P
0 g
s
.565 .503 .745 r
.55204 .41486 m .55265 .41667 L .56455 .41612 L p F P
0 g
s
.835 .982 .695 r
.79079 .3074 m .78963 .30791 L .79195 .30488 L closepath p F P
0 g
s
.801 .944 .592 r
.80097 .29182 m .79694 .29788 L .799 .29341 L closepath p F P
0 g
s
.565 .503 .745 r
.56455 .41612 m .56163 .40871 L .55204 .41486 L p F P
0 g
s
0 0 0 r
.81918 .25036 m .8208 .24446 L .81928 .24945 L p F P
0 g
s
0 0 0 r
.81795 .25441 m .81918 .25036 L p .81928 .24945 L F P
0 g
s
0 0 0 r
.81928 .24945 m .81829 .25304 L .81795 .25441 L p F P
0 g
s
.693 .849 .958 r
.61742 .42262 m .61547 .42344 L .61251 .42118 L p F P
0 g
s
.672 .843 .965 r
.6006 .4257 m .61251 .42118 L .61547 .42344 L p F P
0 g
s
.793 .997 .859 r
.74551 .35583 m .74431 .35686 L .74502 .35582 L closepath p F P
0 g
s
.794 .991 .882 r
.74292 .35557 m .73735 .36017 L p .74431 .35686 L F P
0 g
s
.794 .991 .882 r
.74431 .35686 m .74502 .35582 L .74292 .35557 L p F P
0 g
s
.881 .685 .633 r
.23015 .40118 m .2349 .40421 L .23695 .39821 L p F P
0 g
s
.881 .685 .633 r
.23695 .39821 m .23214 .3952 L .23015 .40118 L p F P
0 g
s
.471 .702 .969 r
.15865 .41865 m .16817 .41834 L .17228 .42158 L p F P
0 g
s
.475 .701 .967 r
.16817 .41834 m .15865 .41865 L .15491 .41538 L p F P
0 g
s
.813 1 .804 r
.76645 .33409 m .76559 .33496 L .76242 .3403 L p F P
0 g
s
.815 1 .829 r
.7571 .34307 m .76559 .33496 L .76242 .3403 L p F P
0 g
s
.815 1 .829 r
.7558 .34533 m .7571 .34307 L p .76242 .3403 L F P
0 g
s
.815 1 .829 r
.76242 .3403 m .75725 .34525 L .7558 .34533 L p F P
0 g
s
.805 .998 .853 r
.75381 .34845 m .74551 .35583 L .74502 .35582 L p F P
0 g
s
0 0 .477 r
.82541 .20786 m .82433 .21279 L .82292 .20792 L p F P
0 g
s
0 0 .477 r
.82292 .20792 m .82397 .20299 L .82541 .20786 L p F P
0 g
s
.778 .876 .45 r
.81033 .27402 m .80981 .27475 L .81078 .27281 L closepath p F P
0 g
s
.804 1 .834 r
.75725 .34525 m .75381 .34845 L .7558 .34533 L closepath p F P
0 g
s
.805 .998 .853 r
.75471 .34526 m .7558 .34533 L .75381 .34845 L p F P
0 g
s
.805 .998 .853 r
.74772 .35147 m .75471 .34526 L p .75381 .34845 L F P
0 g
s
.805 .998 .853 r
.74502 .35582 m .74772 .35147 L p .75381 .34845 L F P
0 g
s
.614 .704 .909 r
.58265 .42346 m .57076 .42664 L .56767 .422 L p F P
0 g
s
.633 .747 .93 r
.57076 .42664 m .58265 .42346 L .58569 .42691 L p F P
0 g
s
.613 .801 .377 r
.61167 .2997 m .60784 .30547 L .61235 .29866 L p F P
0 g
s
.388 .492 .844 r
.81061 .17231 m .80765 .17118 L .8048 .1654 L p F P
0 g
s
.902 .666 .573 r
.22754 .39211 m .23214 .3952 L .23319 .38954 L p F P
0 g
s
.902 .666 .573 r
.23319 .38954 m .22857 .38645 L .22754 .39211 L p F P
0 g
s
.9 .974 .811 r
.66842 .21746 m .66709 .21904 L .6659 .2241 L p F P
0 g
s
.88 .988 .813 r
.66099 .22636 m .66709 .21904 L .6659 .2241 L p F P
0 g
s
.88 .988 .813 r
.65941 .23128 m .66099 .22636 L p .6659 .2241 L F P
0 g
s
.88 .988 .813 r
.6659 .2241 m .65956 .23128 L .65941 .23128 L p F P
0 g
s
.691 .871 .966 r
.62738 .41832 m .61742 .42262 L .62477 .41656 L closepath p F P
0 g
s
.693 .849 .958 r
.62444 .41633 m .62477 .41656 L .61742 .42262 L p F P
0 g
s
.693 .849 .958 r
.61251 .42118 m .62444 .41633 L p .61742 .42262 L F P
0 g
s
.851 .978 .679 r
.63231 .267 m .62974 .27243 L .63488 .26543 L p F P
0 g
s
.851 .978 .679 r
.63637 .26109 m .63231 .267 L p .63488 .26543 L F P
0 g
s
.851 .978 .679 r
.63488 .26543 m .63676 .26086 L .63637 .26109 L p F P
0 g
s
.757 .767 .861 r
.22847 .42154 m .2214 .42617 L .21779 .42255 L p F P
0 g
s
.684 .752 .903 r
.20648 .4272 m .21779 .42255 L .2214 .42617 L p F P
0 g
s
.555 .657 .904 r
.78662 .15537 m .7881 .15525 L .78813 .15781 L closepath p F P
0 g
s
.511 .631 .905 r
.79917 .15484 m .7881 .15525 L .78813 .15781 L p F P
0 g
s
.511 .631 .905 r
.80197 .15996 m .79917 .15484 L p .78813 .15781 L F P
0 g
s
0 0 0 r
.59272 .33186 m .58727 .33809 L .59098 .33151 L p F P
0 g
s
0 0 0 r
.59573 .32598 m .59272 .33186 L p .59098 .33151 L F P
0 g
s
0 0 0 r
.59098 .33151 m .59585 .32564 L .59573 .32598 L p F P
0 g
s
.669 .861 .468 r
.61795 .29009 m .61603 .29256 L .62029 .28618 L closepath p F P
0 g
s
.692 .754 .899 r
.21779 .42255 m .20648 .4272 L .20282 .42385 L p F P
0 g
s
.918 .649 .515 r
.22415 .38328 m .22857 .38645 L .22894 .38103 L p F P
0 g
s
.918 .649 .515 r
.22894 .38103 m .22452 .37786 L .22415 .38328 L p F P
0 g
s
.8 .877 .904 r
.72719 .16323 m .7299 .16586 L .7299 .16592 L p F P
0 g
s
.8 .877 .904 r
.71726 .17068 m .72719 .16323 L p .7299 .16592 L F P
0 g
s
.8 .877 .904 r
.71678 .17334 m .71726 .17068 L p .7299 .16592 L F P
0 g
s
.799 .855 .892 r
.72994 .16589 m .7299 .16592 L .7299 .16586 L closepath p F P
0 g
s
.775 .852 .908 r
.73913 .15536 m .74188 .15837 L .72994 .16589 L p F P
0 g
s
.775 .852 .908 r
.73077 .16089 m .73913 .15536 L p .72994 .16589 L F P
0 g
s
.775 .852 .908 r
.72994 .16589 m .7299 .16586 L .73077 .16089 L p F P
0 g
s
.665 .825 .96 r
.61251 .42118 m .6006 .4257 L .59759 .42298 L p F P
0 g
s
.655 .804 .955 r
.58569 .42691 m .59759 .42298 L .6006 .4257 L p F P
0 g
s
.777 .854 .908 r
.7299 .16586 m .72719 .16323 L .73077 .16089 L closepath p F P
0 g
s
.748 .944 .946 r
.68257 .39744 m .68081 .39673 L .68575 .39375 L closepath p F P
0 g
s
.93 .632 .458 r
.22028 .37461 m .22452 .37786 L .2244 .37261 L p F P
0 g
s
.93 .632 .458 r
.2244 .37261 m .22017 .36936 L .22028 .37461 L p F P
0 g
s
.762 .956 .936 r
.69792 .38881 m .69548 .39039 L .69273 .38942 L p F P
0 g
s
.504 .42 .694 r
.55285 .40563 m .55972 .40123 L .56139 .40793 L closepath p F P
0 g
s
.643 .776 .944 r
.59759 .42298 m .58569 .42691 L .58265 .42346 L p F P
0 g
s
.937 .616 .402 r
.21612 .36604 m .22017 .36936 L .2197 .36424 L p F P
0 g
s
.937 .616 .402 r
.2197 .36424 m .21565 .36091 L .21612 .36604 L p F P
0 g
s
.926 .541 .231 r
.20691 .34714 m .20612 .34419 L .20986 .34765 L p F P
0 g
s
.926 .541 .231 r
.20986 .34765 m .21058 .35032 L .20691 .34714 L p F P
0 g
s
.934 .572 .301 r
.21058 .35032 m .21102 .35251 L .2149 .3559 L p F P
0 g
s
.94 .598 .348 r
.21176 .35752 m .21565 .36091 L .2149 .3559 L p F P
0 g
s
.94 .598 .348 r
.2149 .3559 m .21102 .35251 L .21176 .35752 L p F P
0 g
s
.809 .992 .874 r
.74502 .35582 m .74292 .35557 L .74772 .35147 L closepath p F P
0 g
s
.628 .7 .897 r
.77155 .15415 m .78386 .15104 L .78662 .15537 L p F P
0 g
s
.641 .712 .899 r
.78386 .15104 m .77155 .15415 L .7688 .15034 L p F P
0 g
s
.687 .754 .903 r
.75665 .15526 m .7688 .15034 L .77155 .15415 L p F P
0 g
s
.827 .973 .665 r
.79425 .29974 m .79195 .30488 L .79694 .29788 L p F P
0 g
s
.827 .973 .665 r
.79868 .29358 m .79425 .29974 L p .79694 .29788 L F P
0 g
s
.827 .973 .665 r
.79694 .29788 m .799 .29341 L .79868 .29358 L p F P
0 g
s
.726 .934 .956 r
.66889 .40361 m .66555 .40545 L .66785 .40316 L closepath p F P
0 g
s
.726 .921 .958 r
.66607 .40229 m .66785 .40316 L .66555 .40545 L p F P
0 g
s
.726 .921 .958 r
.65413 .40863 m .66607 .40229 L p .66555 .40545 L F P
0 g
s
.836 .739 .757 r
.22944 .41341 m .23144 .41068 L .23625 .41367 L p F P
0 g
s
.836 .739 .757 r
.23625 .41367 m .23298 .41787 L .22944 .41341 L p F P
0 g
s
.378 .235 .558 r
.56035 .39346 m .55866 .39471 L .55818 .38883 L p F P
0 g
s
.378 .235 .558 r
.55818 .38883 m .55854 .38857 L .56035 .39346 L p F P
0 g
s
.414 .669 .966 r
.14381 .41181 m .14038 .41166 L .13662 .4083 L p F P
0 g
s
.9 .981 .796 r
.65956 .23128 m .65934 .23155 L .65941 .23128 L closepath p F P
0 g
s
.762 .965 .93 r
.69792 .38881 m .70736 .38249 L .70464 .3817 L p F P
0 g
s
.762 .965 .93 r
.70464 .3817 m .70258 .38307 L .69792 .38881 L p F P
0 g
s
.762 .956 .936 r
.69273 .38942 m .70258 .38307 L .69792 .38881 L p F P
0 g
s
.901 .982 .789 r
.65502 .23363 m .65354 .23876 L .65934 .23155 L p F P
0 g
s
.901 .982 .789 r
.65678 .23135 m .65502 .23363 L p .65934 .23155 L F P
0 g
s
.901 .982 .789 r
.65934 .23155 m .65941 .23128 L .65678 .23135 L p F P
0 g
s
.697 .763 .903 r
.7688 .15034 m .75665 .15526 L .75391 .15187 L p F P
0 g
s
0 .074 .587 r
.825 .19805 m .82397 .20299 L .82173 .19841 L p F P
0 g
s
0 .074 .587 r
.82173 .19841 m .82271 .19348 L .825 .19805 L p F P
0 g
s
0 0 0 r
.60749 .30596 m .60726 .30638 L .60784 .30547 L closepath p F P
0 g
s
0 0 0 r
.81829 .25304 m .81761 .25536 L .81795 .25441 L closepath p F P
0 g
s
.781 .878 .453 r
.80938 .2742 m .81258 .26777 L .81078 .27281 L p F P
0 g
s
.781 .878 .453 r
.8086 .27642 m .80938 .2742 L p .81078 .27281 L F P
0 g
s
.781 .878 .453 r
.81078 .27281 m .80981 .27475 L .8086 .27642 L p F P
0 g
s
.157 0 .337 r
.57597 .36405 m .5694 .36987 L .57138 .36381 L p F P
0 g
s
.157 0 .337 r
.57138 .36381 m .57646 .35931 L .57597 .36405 L p F P
0 g
s
0 0 .228 r
.82386 .2231 m .82398 .22608 L .82393 .22282 L closepath p F P
0 g
s
.716 .895 .961 r
.6464 .41253 m .64221 .4146 L .63931 .41286 L p F P
0 g
s
.698 .891 .968 r
.62738 .41832 m .63931 .41286 L .64221 .4146 L p F P
0 g
s
.375 .234 .558 r
.56776 .38791 m .56035 .39346 L .55854 .38857 L p F P
0 g
s
.375 .234 .558 r
.55854 .38857 m .56726 .38201 L .56776 .38791 L p F P
0 g
s
.471 .559 .864 r
.80247 .16508 m .80305 .162 L .8048 .1654 L closepath p F P
0 g
s
.889 .987 .8 r
.65941 .23128 m .65678 .23135 L .66099 .22636 L closepath p F P
0 g
s
.805 .88 .901 r
.71678 .17334 m .71533 .17212 L .71726 .17068 L closepath p F P
0 g
s
.474 .702 .969 r
.16955 .41829 m .16817 .41834 L .17228 .42158 L p F P
0 g
s
.474 .702 .969 r
.17228 .42158 m .17326 .42155 L .16955 .41829 L p F P
0 g
s
.79 .746 .812 r
.22847 .42154 m .23298 .41787 L .22944 .41341 L p F P
0 g
s
.79 .746 .812 r
.22944 .41341 m .2235 .41861 L .22847 .42154 L p F P
0 g
s
.757 .767 .861 r
.21779 .42255 m .2235 .41861 L .22847 .42154 L p F P
0 g
s
0 0 .226 r
.82513 .22323 m .82505 .2179 L .82393 .22282 L p F P
0 g
s
0 0 .226 r
.82405 .22798 m .82513 .22323 L p .82393 .22282 L F P
0 g
s
0 0 .226 r
.82393 .22282 m .82398 .22608 L .82405 .22798 L p F P
0 g
s
.76 .937 .592 r
.62758 .27389 m .63231 .267 L .62974 .27243 L p F P
0 g
s
.76 .937 .592 r
.6262 .27664 m .62758 .27389 L p .62974 .27243 L F P
0 g
s
.76 .937 .592 r
.62974 .27243 m .62758 .2754 L .6262 .27664 L p F P
0 g
s
0 0 0 r
.59604 .3254 m .59585 .32564 L .59723 .32207 L p F P
0 g
s
0 0 0 r
.59723 .32207 m .59981 .3188 L .59604 .3254 L p F P
0 g
s
.739 .937 .951 r
.67801 .39553 m .68081 .39673 L .66889 .40361 L p F P
0 g
s
.739 .937 .951 r
.67122 .39942 m .67801 .39553 L p .66889 .40361 L F P
0 g
s
.739 .937 .951 r
.66889 .40361 m .66785 .40316 L .67122 .39942 L p F P
0 g
s
0 0 0 r
.60768 .30636 m .61167 .2997 L .60784 .30547 L p F P
0 g
s
0 0 0 r
.60582 .30913 m .60768 .30636 L p .60784 .30547 L F P
0 g
s
0 0 0 r
.60784 .30547 m .60726 .30638 L .60582 .30913 L p F P
0 g
s
.762 .874 .451 r
.80981 .27475 m .80743 .27928 L .8086 .27642 L closepath p F P
0 g
s
.229 .045 .411 r
.5683 .37566 m .56718 .3766 L .56742 .37156 L p F P
0 g
s
.229 .045 .411 r
.56742 .37156 m .5694 .36987 L .5683 .37566 L p F P
0 g
s
0 0 0 r
.60726 .30638 m .60373 .31216 L .60582 .30913 L closepath p F P
0 g
s
.547 .731 .96 r
.17326 .42155 m .1843 .42003 L .18799 .42331 L p F P
0 g
s
.55 .73 .958 r
.1843 .42003 m .17326 .42155 L .16955 .41829 L p F P
0 g
s
0 0 .087 r
.58707 .33831 m .58698 .33867 L .58727 .33809 L closepath p F P
0 g
s
.118 .205 .68 r
.82369 .18853 m .82271 .19348 L .81947 .18923 L p F P
0 g
s
.118 .205 .68 r
.81947 .18923 m .82036 .18431 L .82369 .18853 L p F P
0 g
s
.061 0 .26 r
.57878 .35703 m .57646 .35931 L .57713 .3548 L p F P
0 g
s
.061 0 .26 r
.57713 .3548 m .58116 .35085 L .57878 .35703 L p F P
0 g
s
.684 .759 .266 r
.81676 .25746 m .81533 .26149 L .81761 .25536 L p F P
0 g
s
.684 .759 .266 r
.81761 .25536 m .81795 .25441 L .81676 .25746 L p F P
0 g
s
.839 .998 .775 r
.77907 .32156 m .7781 .32174 L .7801 .31949 L closepath p F P
0 g
s
.871 .994 .764 r
.64955 .24075 m .65502 .23363 L .65354 .23876 L p F P
0 g
s
.871 .994 .764 r
.64776 .24565 m .64955 .24075 L p .65354 .23876 L F P
0 g
s
.871 .994 .764 r
.65354 .23876 m .64795 .2456 L .64776 .24565 L p F P
0 g
s
.792 .944 .595 r
.62758 .2754 m .62489 .27934 L .6262 .27664 L closepath p F P
0 g
s
.569 .669 .906 r
.7881 .15525 m .78662 .15537 L .78386 .15104 L p F P
0 g
s
0 0 .115 r
.58971 .33824 m .59272 .33186 L .58727 .33809 L p F P
0 g
s
0 0 .115 r
.58606 .34238 m .58971 .33824 L p .58727 .33809 L F P
0 g
s
0 0 .115 r
.58727 .33809 m .58698 .33867 L .58606 .34238 L p F P
0 g
s
0 0 0 r
.82228 .23946 m .8208 .24446 L .8219 .23873 L p F P
0 g
s
0 0 0 r
.8219 .23873 m .82342 .23371 L .82228 .23946 L p F P
0 g
s
.716 .895 .961 r
.65126 .4071 m .65182 .40741 L .6464 .41253 L p F P
0 g
s
.716 .895 .961 r
.63931 .41286 m .65126 .4071 L p .6464 .41253 L F P
0 g
s
.715 .912 .963 r
.65413 .40863 m .6464 .41253 L .65182 .40741 L closepath p F P
0 g
s
.837 .983 .697 r
.78879 .30691 m .79425 .29974 L .79195 .30488 L p F P
0 g
s
.837 .983 .697 r
.78804 .30861 m .78879 .30691 L p .79195 .30488 L F P
0 g
s
.837 .983 .697 r
.79195 .30488 m .78963 .30791 L .78804 .30861 L p F P
0 g
s
.864 .712 .692 r
.22683 .40761 m .23144 .41068 L .2349 .40421 L p F P
0 g
s
.864 .712 .692 r
.2349 .40421 m .23015 .40118 L .22683 .40761 L p F P
0 g
s
.773 .968 .924 r
.71276 .37875 m .70736 .38249 L .70464 .3817 L p F P
0 g
s
0 0 .114 r
.58698 .33867 m .58402 .34453 L .58606 .34238 L closepath p F P
0 g
s
.388 .492 .844 r
.8048 .1654 m .81114 .16746 L .81061 .17231 L p F P
0 g
s
.318 .425 .813 r
.81743 .17066 m .81665 .17559 L .81061 .17231 L p F P
0 g
s
.318 .425 .813 r
.81061 .17231 m .81114 .16746 L .81743 .17066 L p F P
0 g
s
.227 .324 .755 r
.82119 .17976 m .82036 .18431 L .81589 .18049 L p F P
0 g
s
.227 .324 .755 r
.82094 .17907 m .82119 .17976 L p .81589 .18049 L F P
0 g
s
.227 .324 .755 r
.81589 .18049 m .81665 .17559 L .82094 .17907 L p F P
0 g
s
.738 .822 .917 r
.75045 .15375 m .74188 .15837 L .73913 .15536 L p F P
0 g
s
.37 .5 .859 r
.80305 .162 m .8048 .1654 L .81114 .16746 L p F P
0 g
s
.824 .983 .701 r
.78963 .30791 m .78631 .31209 L .78804 .30861 L closepath p F P
0 g
s
.569 .669 .906 r
.78386 .15104 m .78804 .15055 L .7881 .15525 L p F P
0 g
s
.54 .626 .886 r
.79637 .14991 m .78804 .15055 L .7881 .15525 L p F P
0 g
s
.54 .626 .886 r
.7881 .15525 m .79917 .15484 L .79637 .14991 L p F P
0 g
s
.938 .576 .287 r
.21102 .35251 m .21058 .35032 L .20691 .34714 L p F P
0 g
s
.699 .873 .963 r
.6364 .411 m .63931 .41286 L .62738 .41832 L p F P
0 g
s
.699 .873 .963 r
.62555 .41585 m .6364 .411 L p .62738 .41832 L F P
0 g
s
.699 .873 .963 r
.62738 .41832 m .62477 .41656 L .62555 .41585 L p F P
0 g
s
.774 .977 .914 r
.71923 .3741 m .71276 .37875 L .71676 .37352 L closepath p F P
0 g
s
.773 .968 .924 r
.71655 .37346 m .71676 .37352 L .71276 .37875 L p F P
0 g
s
.773 .968 .924 r
.70464 .3817 m .71655 .37346 L p .71276 .37875 L F P
0 g
s
.871 .953 .86 r
.68056 .20482 m .68008 .20463 L .68078 .20394 L closepath p F P
0 g
s
.783 .934 .574 r
.62307 .28071 m .62029 .28618 L .62489 .27934 L p F P
0 g
s
.783 .934 .574 r
.6248 .27798 m .62307 .28071 L p .62489 .27934 L F P
0 g
s
.783 .934 .574 r
.62489 .27934 m .6262 .27664 L .6248 .27798 L p F P
0 g
s
.414 .669 .966 r
.13662 .4083 m .13998 .40844 L .14381 .41181 L p F P
0 g
s
.422 .673 .966 r
.14742 .40868 m .13998 .40844 L .14381 .41181 L p F P
0 g
s
.422 .673 .966 r
.14381 .41181 m .15117 .41206 L .14742 .40868 L p F P
0 g
s
.807 .926 .547 r
.8056 .28083 m .80356 .28593 L .80743 .27928 L p F P
0 g
s
.807 .926 .547 r
.80761 .27737 m .8056 .28083 L p .80743 .27928 L F P
0 g
s
.807 .926 .547 r
.80743 .27928 m .8086 .27642 L .80761 .27737 L p F P
0 g
s
.724 .774 .279 r
.81707 .25644 m .81676 .25746 L .81795 .25441 L p F P
0 g
s
.724 .774 .279 r
.81795 .25441 m .81918 .25036 L .81707 .25644 L p F P
0 g
s
.89 .693 .631 r
.22561 .39807 m .23015 .40118 L .23214 .3952 L p F P
0 g
s
.89 .693 .631 r
.23214 .3952 m .22754 .39211 L .22561 .39807 L p F P
0 g
s
.614 .704 .909 r
.56767 .422 m .57958 .41943 L .58265 .42346 L p F P
0 g
s
.616 .631 .843 r
.56582 .41868 m .56767 .422 L .57958 .41943 L p F P
0 g
s
.893 .989 .751 r
.64795 .2456 m .64765 .24601 L .64776 .24565 L closepath p F P
0 g
s
.893 .988 .741 r
.64413 .24785 m .64241 .25304 L .64765 .24601 L p F P
0 g
s
.893 .988 .741 r
.64517 .24639 m .64413 .24785 L p .64765 .24601 L F P
0 g
s
.893 .988 .741 r
.64765 .24601 m .64776 .24565 L .64517 .24639 L p F P
0 g
s
.831 .906 .891 r
.70647 .17956 m .70353 .182 L .70076 .18006 L p F P
0 g
s
.863 .919 .865 r
.69713 .18794 m .70353 .182 L .70076 .18006 L p F P
0 g
s
.821 .996 .854 r
.7558 .34533 m .75471 .34526 L .7571 .34307 L closepath p F P
0 g
s
.853 .929 .877 r
.69713 .18794 m .69178 .19284 L .6891 .19134 L p F P
0 g
s
.874 .925 .856 r
.69178 .19284 m .68863 .19605 L .6891 .19134 L closepath p F P
0 g
s
.863 .919 .865 r
.70076 .18006 m .69768 .18305 L .69713 .18794 L p F P
0 g
s
.853 .929 .877 r
.68913 .19117 m .69768 .18305 L .69713 .18794 L p F P
0 g
s
.853 .929 .877 r
.6891 .19134 m .68913 .19117 L p .69713 .18794 L F P
0 g
s
0 0 .351 r
.82614 .21297 m .82505 .2179 L .82433 .21279 L p F P
0 g
s
0 0 .351 r
.82433 .21279 m .82541 .20786 L .82614 .21297 L p F P
0 g
s
0 0 0 r
.60386 .31298 m .59981 .3188 L .60373 .31216 L p F P
0 g
s
0 0 0 r
.60449 .31185 m .60386 .31298 L p .60373 .31216 L F P
0 g
s
0 0 0 r
.60373 .31216 m .60582 .30913 L .60449 .31185 L p F P
0 g
s
0 0 .249 r
.82398 .22608 m .824 .22816 L .82405 .22798 L closepath p F P
0 g
s
.837 .995 .754 r
.78259 .31431 m .7801 .31949 L .78631 .31209 L p F P
0 g
s
.837 .995 .754 r
.78723 .30881 m .78259 .31431 L p .78631 .31209 L F P
0 g
s
.837 .995 .754 r
.78631 .31209 m .78804 .30861 L .78723 .30881 L p F P
0 g
s
.841 .903 .88 r
.70647 .17956 m .71533 .17212 L .71257 .16982 L p F P
0 g
s
.841 .903 .88 r
.71257 .16982 m .70707 .17463 L .70647 .17956 L p F P
0 g
s
.831 .906 .891 r
.70076 .18006 m .70707 .17463 L .70647 .17956 L p F P
0 g
s
.616 .748 .94 r
.18799 .42331 m .19916 .42048 L .20282 .42385 L p F P
0 g
s
.62 .749 .938 r
.19916 .42048 m .18799 .42331 L .1843 .42003 L p F P
0 g
s
.735 .926 .954 r
.66785 .40316 m .66607 .40229 L .67122 .39942 L closepath p F P
0 g
s
.877 .927 .853 r
.68183 .19889 m .68078 .20394 L .68863 .19605 L p F P
0 g
s
.877 .927 .853 r
.68901 .19129 m .68183 .19889 L p .68863 .19605 L F P
0 g
s
.877 .927 .853 r
.68863 .19605 m .6891 .19134 L .68901 .19129 L p F P
0 g
s
.88 .991 .749 r
.64776 .24565 m .64517 .24639 L .64955 .24075 L closepath p F P
0 g
s
.475 .701 .967 r
.15491 .41538 m .16416 .41505 L .16817 .41834 L p F P
0 g
s
.477 .7 .966 r
.16416 .41505 m .15491 .41538 L .15117 .41206 L p F P
0 g
s
.911 .676 .57 r
.22313 .38894 m .22754 .39211 L .22857 .38645 L p F P
0 g
s
.911 .676 .57 r
.22857 .38645 m .22415 .38328 L .22313 .38894 L p F P
0 g
s
.208 .027 .402 r
.57574 .36908 m .5683 .37566 L .5694 .36987 L p F P
0 g
s
.208 .027 .402 r
.5694 .36987 m .57597 .36405 L .57574 .36908 L p F P
0 g
s
.428 .319 .627 r
.56464 .3976 m .55972 .40123 L .55866 .39471 L p F P
0 g
s
.428 .319 .627 r
.55866 .39471 m .56035 .39346 L .56464 .3976 L p F P
0 g
s
.785 .978 .909 r
.72579 .36923 m .71923 .3741 L .71676 .37352 L p F P
0 g
s
.805 .882 .901 r
.71726 .17068 m .71533 .17212 L .71257 .16982 L p F P
0 g
s
.75 .94 .946 r
.68575 .39375 m .68081 .39673 L .67801 .39553 L p F P
0 g
s
.871 .954 .86 r
.67731 .20359 m .68183 .19889 L .68078 .20394 L p F P
0 g
s
.871 .954 .86 r
.68078 .20394 m .68008 .20463 L .67731 .20359 L p F P
0 g
s
.898 .958 .827 r
.67387 .21151 m .68008 .20463 L .67731 .20359 L p F P
0 g
s
.765 .768 .855 r
.2235 .41861 m .21779 .42255 L .21418 .41892 L p F P
0 g
s
.692 .754 .899 r
.20282 .42385 m .21418 .41892 L .21779 .42255 L p F P
0 g
s
.926 .658 .511 r
.21991 .38004 m .22415 .38328 L .22452 .37786 L p F P
0 g
s
.926 .658 .511 r
.22452 .37786 m .22028 .37461 L .21991 .38004 L p F P
0 g
s
.816 .881 .892 r
.71726 .17068 m .72719 .16323 L .72444 .16058 L p F P
0 g
s
.816 .881 .892 r
.72444 .16058 m .71784 .16575 L .71726 .17068 L p F P
0 g
s
.805 .882 .901 r
.71257 .16982 m .71784 .16575 L .71726 .17068 L p F P
0 g
s
.726 .915 .958 r
.66322 .40082 m .66607 .40229 L .65413 .40863 L p F P
0 g
s
.726 .915 .958 r
.65292 .40624 m .66322 .40082 L p .65413 .40863 L F P
0 g
s
.726 .915 .958 r
.65413 .40863 m .65182 .40741 L .65292 .40624 L p F P
0 g
s
.665 .825 .96 r
.59759 .42298 m .60953 .41869 L .61251 .42118 L p F P
0 g
s
.677 .843 .963 r
.62444 .41633 m .61251 .42118 L .60953 .41869 L p F P
0 g
s
0 0 .166 r
.58518 .34662 m .58116 .35085 L .58402 .34453 L p F P
0 g
s
0 0 .166 r
.58402 .34453 m .58606 .34238 L .58518 .34662 L p F P
0 g
s
.937 .641 .452 r
.21621 .3713 m .22028 .37461 L .22017 .36936 L p F P
0 g
s
.937 .641 .452 r
.22017 .36936 m .21612 .36604 L .21621 .3713 L p F P
0 g
s
.7 .756 .896 r
.21418 .41892 m .20282 .42385 L .19916 .42048 L p F P
0 g
s
.844 .74 .749 r
.22589 .40896 m .22683 .40761 L .23144 .41068 L p F P
0 g
s
.844 .74 .749 r
.23144 .41068 m .22944 .41341 L .22589 .40896 L p F P
0 g
s
.787 .985 .898 r
.73109 .36515 m .72579 .36923 L .72896 .36477 L closepath p F P
0 g
s
.785 .978 .909 r
.72844 .36463 m .72896 .36477 L .72579 .36923 L p F P
0 g
s
.785 .978 .909 r
.71704 .37311 m .72844 .36463 L p .72579 .36923 L F P
0 g
s
.785 .978 .909 r
.71676 .37352 m .71704 .37311 L p .72579 .36923 L F P
0 g
s
.84 .998 .776 r
.77591 .32187 m .78259 .31431 L .7801 .31949 L p F P
0 g
s
.84 .998 .776 r
.77578 .32217 m .77591 .32187 L p .7801 .31949 L F P
0 g
s
.84 .998 .776 r
.7801 .31949 m .7781 .32174 L .77578 .32217 L p F P
0 g
s
.759 .844 .392 r
.81433 .26272 m .81258 .26777 L .81533 .26149 L p F P
0 g
s
.759 .844 .392 r
.81633 .25819 m .81433 .26272 L p .81533 .26149 L F P
0 g
s
.759 .844 .392 r
.81533 .26149 m .81676 .25746 L .81633 .25819 L p F P
0 g
s
.747 .81 .902 r
.75045 .15375 m .75391 .15187 L .75116 .14853 L p F P
0 g
s
.747 .81 .902 r
.75116 .14853 m .75016 .1491 L .75045 .15375 L p F P
0 g
s
.738 .822 .917 r
.73913 .15536 m .75016 .1491 L .75045 .15375 L p F P
0 g
s
.944 .622 .394 r
.21222 .36265 m .21612 .36604 L .21565 .36091 L p F P
0 g
s
.944 .622 .394 r
.21565 .36091 m .21176 .35752 L .21222 .36265 L p F P
0 g
s
.37 .5 .859 r
.81171 .16258 m .80314 .16017 L .80305 .162 L p F P
0 g
s
.37 .5 .859 r
.81114 .16746 m .81171 .16258 L p .80305 .162 L F P
0 g
s
.442 .553 .872 r
.80197 .15996 m .80314 .16017 L .80305 .162 L closepath p F P
0 g
s
.643 .776 .944 r
.58265 .42346 m .59457 .4199 L .59759 .42298 L p F P
0 g
s
.627 .742 .93 r
.59457 .4199 m .58265 .42346 L .57958 .41943 L p F P
0 g
s
.938 .576 .287 r
.20691 .34714 m .2073 .34904 L .21102 .35251 L p F P
0 g
s
.946 .603 .337 r
.20803 .35406 m .21176 .35752 L .21102 .35251 L p F P
0 g
s
.946 .603 .337 r
.21102 .35251 m .2073 .34904 L .20803 .35406 L p F P
0 g
s
.886 .984 .708 r
.63925 .25478 m .6371 .2601 L .64241 .25304 L p F P
0 g
s
.886 .984 .708 r
.64241 .25304 m .64413 .24785 L .63925 .25478 L p F P
0 g
s
.65 .847 .45 r
.6189 .28743 m .62307 .28071 L .62029 .28618 L p F P
0 g
s
.65 .847 .45 r
.61589 .29274 m .6189 .28743 L p .62029 .28618 L F P
0 g
s
.65 .847 .45 r
.62029 .28618 m .61603 .29256 L .61589 .29274 L p F P
0 g
s
0 0 .099 r
.82383 .23229 m .82342 .23371 L .824 .22816 L p F P
0 g
s
0 0 .099 r
.824 .22816 m .82405 .22798 L .82383 .23229 L p F P
0 g
s
.829 .998 .781 r
.7781 .32174 m .77313 .32713 L .77578 .32217 L closepath p F P
0 g
s
.898 .958 .827 r
.67731 .20359 m .67475 .20653 L .67387 .21151 L p F P
0 g
s
.884 .972 .836 r
.66824 .21399 m .67475 .20653 L .67387 .21151 L p F P
0 g
s
.884 .972 .836 r
.66742 .21726 m .66824 .21399 L p .67387 .21151 L F P
0 g
s
.884 .972 .836 r
.67387 .21151 m .66842 .21746 L .66742 .21726 L p F P
0 g
s
.576 .584 .824 r
.56455 .41612 m .57022 .41557 L .56582 .41868 L closepath p F P
0 g
s
.616 .631 .843 r
.57649 .41464 m .57022 .41557 L .56582 .41868 L p F P
0 g
s
.616 .631 .843 r
.57958 .41943 m .57649 .41464 L p .56582 .41868 L F P
0 g
s
.656 .803 .954 r
.60953 .41869 m .59759 .42298 L .59457 .4199 L p F P
0 g
s
.641 .712 .899 r
.7688 .15034 m .78109 .14682 L .78386 .15104 L p F P
0 g
s
.653 .724 .901 r
.78109 .14682 m .7688 .15034 L .76605 .1466 L p F P
0 g
s
.697 .763 .903 r
.75391 .15187 m .76605 .1466 L .7688 .15034 L p F P
0 g
s
.751 .953 .942 r
.69273 .38942 m .68575 .39375 L .69026 .38852 L closepath p F P
0 g
s
.75 .94 .946 r
.68996 .38839 m .69026 .38852 L .68575 .39375 L p F P
0 g
s
.75 .94 .946 r
.67801 .39553 m .68996 .38839 L p .68575 .39375 L F P
0 g
s
.801 .751 .807 r
.2235 .41861 m .22944 .41341 L .22589 .40896 L p F P
0 g
s
.801 .751 .807 r
.22589 .40896 m .21878 .41558 L .2235 .41861 L p F P
0 g
s
.765 .768 .855 r
.21418 .41892 m .21878 .41558 L .2235 .41861 L p F P
0 g
s
0 0 .069 r
.82464 .22877 m .82383 .23229 L .82405 .22798 L p F P
0 g
s
0 0 .069 r
.82405 .22798 m .82513 .22323 L .82464 .22877 L p F P
0 g
s
.798 .985 .893 r
.73735 .36017 m .73109 .36515 L .72896 .36477 L p F P
0 g
s
.834 .953 .608 r
.80124 .28765 m .79928 .29271 L .80356 .28593 L p F P
0 g
s
.834 .953 .608 r
.80356 .28593 m .8056 .28083 L .80124 .28765 L p F P
0 g
s
0 0 0 r
.82062 .24538 m .81918 .25036 L .8208 .24446 L p F P
0 g
s
0 0 0 r
.8208 .24446 m .82228 .23946 L .82062 .24538 L p F P
0 g
s
0 0 .479 r
.82647 .20291 m .82541 .20786 L .82397 .20299 L p F P
0 g
s
0 0 .479 r
.82397 .20299 m .825 .19805 L .82647 .20291 L p F P
0 g
s
.778 .856 .909 r
.73077 .16089 m .72719 .16323 L .72444 .16058 L p F P
0 g
s
.839 .978 .681 r
.63676 .26086 m .63637 .26109 L .6371 .2601 L closepath p F P
0 g
s
.478 .702 .967 r
.16582 .41498 m .16416 .41505 L .16817 .41834 L p F P
0 g
s
.478 .702 .967 r
.16817 .41834 m .16955 .41829 L .16582 .41498 L p F P
0 g
s
.427 .319 .628 r
.56884 .39446 m .56464 .3976 L .56035 .39346 L p F P
0 g
s
.427 .319 .628 r
.56035 .39346 m .56776 .38791 L .56884 .39446 L p F P
0 g
s
.832 1 .805 r
.77563 .32217 m .77578 .32217 L .77313 .32713 L p F P
0 g
s
.832 1 .805 r
.76831 .32973 m .77563 .32217 L p .77313 .32713 L F P
0 g
s
.832 1 .805 r
.76606 .33413 m .76831 .32973 L p .77313 .32713 L F P
0 g
s
.832 1 .805 r
.77313 .32713 m .76645 .33409 L .76606 .33413 L p F P
0 g
s
0 0 0 r
.60049 .31946 m .59604 .3254 L .59981 .3188 L p F P
0 g
s
0 0 0 r
.59981 .3188 m .60386 .31298 L .60049 .31946 L p F P
0 g
s
.707 .772 .903 r
.76605 .1466 m .75391 .15187 L .75116 .14853 L p F P
0 g
s
.903 .964 .816 r
.66842 .21746 m .66709 .21904 L .66742 .21726 L closepath p F P
0 g
s
.799 .991 .88 r
.74292 .35557 m .73735 .36017 L .74059 .35527 L closepath p F P
0 g
s
.798 .985 .893 r
.74031 .35521 m .74059 .35527 L .73735 .36017 L p F P
0 g
s
.798 .985 .893 r
.72964 .36371 m .74031 .35521 L p .73735 .36017 L F P
0 g
s
.798 .985 .893 r
.72896 .36477 m .72964 .36371 L p .73735 .36017 L F P
0 g
s
.281 .121 .479 r
.56834 .3811 m .56726 .38201 L .56718 .3766 L p F P
0 g
s
.281 .121 .479 r
.56718 .3766 m .5683 .37566 L .56834 .3811 L p F P
0 g
s
.906 .966 .81 r
.66216 .2213 m .66099 .22636 L .66709 .21904 L p F P
0 g
s
.906 .966 .81 r
.66564 .21694 m .66216 .2213 L p .66709 .21904 L F P
0 g
s
.906 .966 .81 r
.66709 .21904 m .66742 .21726 L .66564 .21694 L p F P
0 g
s
.81 .991 .875 r
.74772 .35147 m .74292 .35557 L .74059 .35527 L p F P
0 g
s
.577 .539 .775 r
.56163 .40871 m .56455 .41612 L .57022 .41557 L p F P
0 g
s
.459 .569 .879 r
.80314 .16017 m .80197 .15996 L .79917 .15484 L p F P
0 g
s
.778 .856 .909 r
.72444 .16058 m .73111 .15603 L .73077 .16089 L p F P
0 g
s
.788 .852 .899 r
.73077 .16089 m .73913 .15536 L .73638 .15238 L p F P
0 g
s
.788 .852 .899 r
.73638 .15238 m .73111 .15603 L .73077 .16089 L p F P
0 g
s
.82 1 .811 r
.76645 .33409 m .76559 .33496 L .76606 .33413 L closepath p F P
0 g
s
.822 .998 .842 r
.76005 .33779 m .7571 .34307 L .76559 .33496 L p F P
0 g
s
.822 .998 .842 r
.76392 .33408 m .76005 .33779 L p .76559 .33496 L F P
0 g
s
.822 .998 .842 r
.76559 .33496 m .76606 .33413 L .76392 .33408 L p F P
0 g
s
.519 .429 .694 r
.5702 .39989 m .56464 .3976 L .55972 .40123 L p F P
0 g
s
.519 .429 .694 r
.57086 .40206 m .5702 .39989 L p .55972 .40123 L F P
0 g
s
.519 .429 .694 r
.56243 .40814 m .57086 .40206 L p .55972 .40123 L F P
0 g
s
.519 .429 .694 r
.55972 .40123 m .56139 .40793 L .56243 .40814 L p F P
0 g
s
.583 .679 .906 r
.78804 .15055 m .78386 .15104 L .78109 .14682 L p F P
0 g
s
.812 .996 .86 r
.74772 .35147 m .75471 .34526 L .75214 .34507 L p F P
0 g
s
.812 .996 .86 r
.75214 .34507 m .751 .34609 L .74772 .35147 L p F P
0 g
s
.81 .991 .875 r
.74091 .35472 m .751 .34609 L .74772 .35147 L p F P
0 g
s
.81 .991 .875 r
.74059 .35527 m .74091 .35472 L p .74772 .35147 L F P
0 g
s
.847 .972 .66 r
.799 .29341 m .79868 .29358 L .79928 .29271 L closepath p F P
0 g
s
.872 .72 .69 r
.2224 .40446 m .22683 .40761 L .23015 .40118 L p F P
0 g
s
.872 .72 .69 r
.23015 .40118 m .22561 .39807 L .2224 .40446 L p F P
0 g
s
.823 .995 .855 r
.75214 .34507 m .76005 .33779 L .7571 .34307 L p F P
0 g
s
.823 .995 .855 r
.7571 .34307 m .75471 .34526 L .75214 .34507 L p F P
0 g
s
.55 .73 .958 r
.16955 .41829 m .1806 .41671 L .1843 .42003 L p F P
0 g
s
.553 .73 .957 r
.1806 .41671 m .16955 .41829 L .16582 .41498 L p F P
0 g
s
.835 .977 .677 r
.63431 .26174 m .63925 .25478 L .6371 .2601 L p F P
0 g
s
.835 .977 .677 r
.63399 .26252 m .63431 .26174 L p .6371 .2601 L F P
0 g
s
.835 .977 .677 r
.6371 .2601 m .63637 .26109 L .63399 .26252 L p F P
0 g
s
.773 .932 .573 r
.6262 .27664 m .6248 .27798 L .62758 .27389 L closepath p F P
0 g
s
.761 .954 .937 r
.70258 .38307 m .69273 .38942 L .69026 .38852 L p F P
0 g
s
.686 .862 .46 r
.61603 .29256 m .61574 .29301 L .61589 .29274 L closepath p F P
0 g
s
.863 .976 .671 r
.63637 .26109 m .63231 .267 L .63399 .26252 L closepath p F P
0 g
s
.707 .891 .964 r
.65126 .4071 m .63931 .41286 L .6364 .411 L p F P
0 g
s
.664 .839 .423 r
.61397 .29558 m .61167 .2997 L .61574 .29301 L p F P
0 g
s
.664 .839 .423 r
.61574 .29301 m .61589 .29274 L .61397 .29558 L p F P
0 g
s
.831 .928 .546 r
.8086 .27642 m .80761 .27737 L .80938 .2742 L closepath p F P
0 g
s
.016 .094 .602 r
.82559 .1951 m .825 .19805 L .82271 .19348 L p F P
0 g
s
.016 .094 .602 r
.82416 .18942 m .82559 .1951 L p .82271 .19348 L F P
0 g
s
.016 .094 .602 r
.82271 .19348 m .82369 .18853 L .82416 .18942 L p F P
0 g
s
.109 0 .32 r
.57701 .36303 m .57597 .36405 L .57646 .35931 L p F P
0 g
s
.109 0 .32 r
.57646 .35931 m .57878 .35703 L .57701 .36303 L p F P
0 g
s
.411 .526 .864 r
.81228 .15806 m .81171 .16258 L .80314 .16017 L p F P
0 g
s
.411 .526 .864 r
.81205 .15758 m .81228 .15806 L p .80314 .16017 L F P
0 g
s
.411 .526 .864 r
.80314 .16017 m .8033 .15541 L .81205 .15758 L p F P
0 g
s
.459 .569 .879 r
.79917 .15484 m .8033 .15541 L .80314 .16017 L p F P
0 g
s
.005 0 .224 r
.58446 .35106 m .57878 .35703 L .58116 .35085 L p F P
0 g
s
.005 0 .224 r
.58116 .35085 m .58518 .34662 L .58446 .35106 L p F P
0 g
s
.66 .837 .421 r
.61479 .29413 m .61397 .29558 L .61589 .29274 L p F P
0 g
s
.66 .837 .421 r
.61589 .29274 m .6189 .28743 L .61479 .29413 L p F P
0 g
s
.264 .109 .474 r
.57583 .3745 m .56834 .3811 L .5683 .37566 L p F P
0 g
s
.264 .109 .474 r
.5683 .37566 m .57574 .36908 L .57583 .3745 L p F P
0 g
s
.849 .973 .662 r
.79649 .2946 m .80124 .28765 L .79928 .29271 L p F P
0 g
s
.849 .973 .662 r
.79642 .29478 m .79649 .2946 L p .79928 .29271 L F P
0 g
s
.849 .973 .662 r
.79928 .29271 m .79868 .29358 L .79642 .29478 L p F P
0 g
s
.889 .987 .801 r
.65635 .22853 m .66216 .2213 L .66099 .22636 L p F P
0 g
s
.889 .987 .801 r
.65553 .23138 m .65635 .22853 L p .66099 .22636 L F P
0 g
s
.889 .987 .801 r
.66099 .22636 m .65678 .23135 L .65553 .23138 L p F P
0 g
s
.838 .997 .834 r
.76606 .33413 m .76392 .33408 L .76831 .32973 L closepath p F P
0 g
s
.805 .894 .477 r
.81107 .26918 m .80938 .2742 L .81258 .26777 L p F P
0 g
s
.805 .894 .477 r
.81258 .26777 m .81433 .26272 L .81107 .26918 L p F P
0 g
s
0 0 .149 r
.58705 .34451 m .58518 .34662 L .58606 .34238 L p F P
0 g
s
0 0 .149 r
.58606 .34238 m .58971 .33824 L .58705 .34451 L p F P
0 g
s
.508 .454 .732 r
.56139 .40793 m .56243 .40814 L .56163 .40871 L closepath p F P
0 g
s
.577 .539 .775 r
.57337 .4085 m .56243 .40814 L .56163 .40871 L p F P
0 g
s
.577 .539 .775 r
.57513 .41216 m .57337 .4085 L p .56163 .40871 L F P
0 g
s
.577 .539 .775 r
.57022 .41557 m .57513 .41216 L p .56163 .40871 L F P
0 g
s
.898 .702 .629 r
.22124 .39489 m .22561 .39807 L .22754 .39211 L p F P
0 g
s
.898 .702 .629 r
.22754 .39211 m .22313 .38894 L .22124 .39489 L p F P
0 g
s
0 0 .208 r
.82622 .21831 m .82513 .22323 L .82505 .2179 L p F P
0 g
s
0 0 .208 r
.82505 .2179 m .82614 .21297 L .82622 .21831 L p F P
0 g
s
.836 .974 .666 r
.79868 .29358 m .79425 .29974 L .79642 .29478 L closepath p F P
0 g
s
0 0 0 r
.60582 .30913 m .60449 .31185 L .60768 .30636 L closepath p F P
0 g
s
.738 .92 .953 r
.67122 .39942 m .66607 .40229 L .66322 .40082 L p F P
0 g
s
0 0 0 r
.59585 .32564 m .59573 .32598 L .59604 .3254 L closepath p F P
0 g
s
.748 .827 .913 r
.75016 .1491 m .73913 .15536 L .73638 .15238 L p F P
0 g
s
0 0 0 r
.59733 .32589 m .60049 .31946 L .59604 .3254 L p F P
0 g
s
0 0 0 r
.59463 .32945 m .59733 .32589 L p .59604 .3254 L F P
0 g
s
0 0 0 r
.59604 .3254 m .59573 .32598 L .59463 .32945 L p F P
0 g
s
.118 .205 .68 r
.82379 .18799 m .82369 .18853 L .82036 .18431 L p F P
0 g
s
.118 .205 .68 r
.82036 .18431 m .82119 .17976 L .82379 .18799 L p F P
0 g
s
.696 .865 .962 r
.62477 .41656 m .62444 .41633 L .62555 .41585 L closepath p F P
0 g
s
.909 .979 .782 r
.65678 .23135 m .65502 .23363 L .65553 .23138 L closepath p F P
0 g
s
0 0 0 r
.59573 .32598 m .59272 .33186 L .59463 .32945 L closepath p F P
0 g
s
.919 .684 .568 r
.2189 .38569 m .22313 .38894 L .22415 .38328 L p F P
0 g
s
.919 .684 .568 r
.22415 .38328 m .21991 .38004 L .2189 .38569 L p F P
0 g
s
.854 .993 .746 r
.78804 .30861 m .78723 .30881 L .78879 .30691 L closepath p F P
0 g
s
.541 .516 .778 r
.56243 .40814 m .57086 .40206 L .57337 .4085 L closepath p F P
0 g
s
.892 .972 .825 r
.66742 .21726 m .66564 .21694 L .66824 .21399 L closepath p F P
0 g
s
.343 .447 .823 r
.81752 .17004 m .81743 .17066 L .81114 .16746 L p F P
0 g
s
.343 .447 .823 r
.81496 .16402 m .81752 .17004 L p .81114 .16746 L F P
0 g
s
.343 .447 .823 r
.81114 .16746 m .81171 .16258 L .81496 .16402 L p F P
0 g
s
.859 .971 .655 r
.62988 .26854 m .62758 .27389 L .63231 .267 L p F P
0 g
s
.859 .971 .655 r
.63359 .26278 m .62988 .26854 L p .63231 .267 L F P
0 g
s
.859 .971 .655 r
.63231 .267 m .63399 .26252 L .63359 .26278 L p F P
0 g
s
.62 .749 .938 r
.1843 .42003 m .19549 .41708 L .19916 .42048 L p F P
0 g
s
.624 .75 .937 r
.19549 .41708 m .1843 .42003 L .1806 .41671 L p F P
0 g
s
.743 .789 .3 r
.81848 .25147 m .81707 .25644 L .81918 .25036 L p F P
0 g
s
.743 .789 .3 r
.81918 .25036 m .82062 .24538 L .81848 .25147 L p F P
0 g
s
.764 .964 .931 r
.70464 .3817 m .70258 .38307 L .70387 .38145 L closepath p F P
0 g
s
.761 .954 .937 r
.70191 .38069 m .70387 .38145 L .70258 .38307 L p F P
0 g
s
.761 .954 .937 r
.69072 .38791 m .70191 .38069 L p .70258 .38307 L F P
0 g
s
.761 .954 .937 r
.69026 .38852 m .69072 .38791 L p .70258 .38307 L F P
0 g
s
0 0 0 r
.82323 .23612 m .82228 .23946 L .82342 .23371 L p F P
0 g
s
0 0 0 r
.82342 .23371 m .82383 .23229 L .82323 .23612 L p F P
0 g
s
.231 .325 .754 r
.8179 .171 m .81743 .17066 L .81665 .17559 L p F P
0 g
s
.231 .325 .754 r
.81665 .17559 m .82094 .17907 L .8179 .171 L p F P
0 g
s
.911 .979 .775 r
.65093 .23564 m .64955 .24075 L .65502 .23363 L p F P
0 g
s
.911 .979 .775 r
.654 .23146 m .65093 .23564 L p .65502 .23363 L F P
0 g
s
.911 .979 .775 r
.65502 .23363 m .65553 .23138 L .654 .23146 L p F P
0 g
s
.477 .7 .966 r
.15117 .41206 m .16025 .41172 L .16416 .41505 L p F P
0 g
s
.479 .698 .965 r
.16025 .41172 m .15117 .41206 L .14742 .40868 L p F P
0 g
s
.7 .849 .954 r
.62555 .41585 m .62444 .41633 L .62149 .41403 L p F P
0 g
s
.677 .843 .963 r
.60953 .41869 m .62149 .41403 L .62444 .41633 L p F P
0 g
s
.934 .667 .506 r
.21583 .37673 m .21991 .38004 L .22028 .37461 L p F P
0 g
s
.934 .667 .506 r
.22028 .37461 m .21621 .3713 L .21583 .37673 L p F P
0 g
s
.583 .679 .906 r
.78109 .14682 m .78817 .14577 L .78804 .15055 L p F P
0 g
s
.555 .643 .892 r
.79358 .14514 m .78817 .14577 L .78804 .15055 L p F P
0 g
s
.555 .643 .892 r
.78804 .15055 m .79637 .14991 L .79358 .14514 L p F P
0 g
s
.773 .769 .85 r
.21878 .41558 m .21418 .41892 L .21054 .41528 L p F P
0 g
s
.7 .756 .896 r
.19916 .42048 m .21054 .41528 L .21418 .41892 L p F P
0 g
s
.739 .935 .952 r
.67801 .39553 m .67122 .39942 L .67568 .39448 L closepath p F P
0 g
s
.738 .92 .953 r
.6752 .39423 m .67568 .39448 L .67122 .39942 L p F P
0 g
s
.738 .92 .953 r
.66322 .40082 m .6752 .39423 L p .67122 .39942 L F P
0 g
s
.778 .965 .924 r
.71384 .37254 m .71655 .37346 L .70464 .3817 L p F P
0 g
s
.778 .965 .924 r
.7067 .37747 m .71384 .37254 L p .70464 .3817 L F P
0 g
s
.778 .965 .924 r
.70464 .3817 m .70387 .38145 L .7067 .37747 L p F P
0 g
s
.851 .989 .724 r
.79094 .3018 m .78879 .30691 L .79425 .29974 L p F P
0 g
s
.851 .989 .724 r
.79633 .29481 m .79094 .3018 L p .79425 .29974 L F P
0 g
s
.851 .989 .724 r
.79425 .29974 m .79642 .29478 L .79633 .29481 L p F P
0 g
s
.852 .742 .742 r
.22233 .40457 m .2224 .40446 L .22683 .40761 L p F P
0 g
s
.852 .742 .742 r
.22683 .40761 m .22589 .40896 L .22233 .40457 L p F P
0 g
s
.645 .817 .39 r
.61101 .30074 m .60768 .30636 L .61167 .2997 L p F P
0 g
s
.645 .817 .39 r
.61325 .29673 m .61101 .30074 L p .61167 .2997 L F P
0 g
s
.645 .817 .39 r
.61167 .2997 m .61397 .29558 L .61325 .29673 L p F P
0 g
s
.694 .855 .96 r
.62555 .41585 m .6364 .411 L .63347 .40899 L p F P
0 g
s
.694 .855 .96 r
.63347 .40899 m .63243 .40943 L .62555 .41585 L p F P
0 g
s
.7 .849 .954 r
.62149 .41403 m .63243 .40943 L .62555 .41585 L p F P
0 g
s
.945 .648 .446 r
.21231 .36791 m .21621 .3713 L .21612 .36604 L p F P
0 g
s
.945 .648 .446 r
.21612 .36604 m .21222 .36265 L .21231 .36791 L p F P
0 g
s
.627 .742 .93 r
.57958 .41943 m .59153 .41639 L .59457 .4199 L p F P
0 g
s
.604 .699 .911 r
.59153 .41639 m .57958 .41943 L .57649 .41464 L p F P
0 g
s
.722 .904 .959 r
.65182 .40741 m .65126 .4071 L .65292 .40624 L closepath p F P
0 g
s
.706 .759 .894 r
.21054 .41528 m .19916 .42048 L .19549 .41708 L p F P
0 g
s
.81 .756 .802 r
.21878 .41558 m .22589 .40896 L .22233 .40457 L p F P
0 g
s
.95 .629 .385 r
.20848 .35919 m .21222 .36265 L .21176 .35752 L p F P
0 g
s
.95 .629 .385 r
.21176 .35752 m .20803 .35406 L .20848 .35919 L p F P
0 g
s
.81 .756 .802 r
.22233 .40457 m .21428 .41247 L .21878 .41558 L p F P
0 g
s
.773 .769 .85 r
.21054 .41528 m .21428 .41247 L .21878 .41558 L p F P
0 g
s
.593 .617 .845 r
.57022 .41557 m .57513 .41216 L .57649 .41464 L closepath p F P
0 g
s
.839 .906 .884 r
.70707 .17463 m .70076 .18006 L .69799 .17811 L p F P
0 g
s
.869 .909 .856 r
.69768 .18305 m .70076 .18006 L .69799 .17811 L p F P
0 g
s
.869 .909 .856 r
.69799 .17811 m .69785 .17825 L .69768 .18305 L p F P
0 g
s
.868 .909 .857 r
.68991 .18619 m .68913 .19117 L .69768 .18305 L p F P
0 g
s
.868 .909 .857 r
.69768 .18305 m .69785 .17825 L .68991 .18619 L p F P
0 g
s
.86 .931 .871 r
.6891 .19134 m .68901 .19129 L .68913 .19117 L closepath p F P
0 g
s
0 0 .349 r
.8272 .20803 m .82614 .21297 L .82541 .20786 L p F P
0 g
s
0 0 .349 r
.82541 .20786 m .82647 .20291 L .8272 .20803 L p F P
0 g
s
.847 .895 .871 r
.70707 .17463 m .71257 .16982 L .7098 .16752 L p F P
0 g
s
.847 .895 .871 r
.7098 .16752 m .70726 .16982 L .70707 .17463 L p F P
0 g
s
.839 .906 .884 r
.69799 .17811 m .70726 .16982 L .70707 .17463 L p F P
0 g
s
.669 .826 .959 r
.62149 .41403 m .60953 .41869 L .60653 .41592 L p F P
0 g
s
.656 .803 .954 r
.59457 .4199 m .60653 .41592 L .60953 .41869 L p F P
0 g
s
.834 .929 .548 r
.8074 .27579 m .81107 .26918 L .80938 .2742 L p F P
0 g
s
.834 .929 .548 r
.80653 .27839 m .8074 .27579 L p .80938 .2742 L F P
0 g
s
.834 .929 .548 r
.80938 .2742 m .80761 .27737 L .80653 .27839 L p F P
0 g
s
.86 .932 .871 r
.68624 .1898 m .68991 .18619 L .68913 .19117 L p F P
0 g
s
.86 .932 .871 r
.68913 .19117 m .68901 .19129 L .68624 .1898 L p F P
0 g
s
.889 .941 .84 r
.68183 .19889 m .68901 .19129 L .68624 .1898 L p F P
0 g
s
.476 .584 .883 r
.8033 .15541 m .79917 .15484 L .79637 .14991 L p F P
0 g
s
.814 .883 .895 r
.71784 .16575 m .71257 .16982 L .7098 .16752 L p F P
0 g
s
.653 .724 .901 r
.76605 .1466 m .77833 .1427 L .78109 .14682 L p F P
0 g
s
.664 .734 .902 r
.77833 .1427 m .76605 .1466 L .7633 .14293 L p F P
0 g
s
.707 .772 .903 r
.75116 .14853 m .7633 .14293 L .76605 .1466 L p F P
0 g
s
.337 .206 .551 r
.56994 .38607 m .56776 .38791 L .56726 .38201 L p F P
0 g
s
.337 .206 .551 r
.56726 .38201 m .56834 .3811 L .56994 .38607 L p F P
0 g
s
.789 .851 .398 r
.81676 .25746 m .81633 .25819 L .81707 .25644 L closepath p F P
0 g
s
.066 0 .3 r
.58324 .35661 m .57701 .36303 L .57878 .35703 L p F P
0 g
s
.066 0 .3 r
.58431 .35257 m .58324 .35661 L p .57878 .35703 L F P
0 g
s
.066 0 .3 r
.57878 .35703 m .58446 .35106 L .58431 .35257 L p F P
0 g
s
.643 .776 .945 r
.60653 .41592 m .59457 .4199 L .59153 .41639 L p F P
0 g
s
.88 .991 .749 r
.64578 .24266 m .65093 .23564 L .64955 .24075 L p F P
0 g
s
.88 .991 .749 r
.64449 .24659 m .64578 .24266 L p .64955 .24075 L F P
0 g
s
.88 .991 .749 r
.64955 .24075 m .64517 .24639 L .64449 .24659 L p F P
0 g
s
.481 .701 .966 r
.16209 .41164 m .16025 .41172 L .16416 .41505 L p F P
0 g
s
.481 .701 .966 r
.16416 .41505 m .16582 .41498 L .16209 .41164 L p F P
0 g
s
.785 .968 .919 r
.71676 .37352 m .71655 .37346 L .71704 .37311 L closepath p F P
0 g
s
.764 .927 .565 r
.62556 .27531 m .62988 .26854 L .62758 .27389 L p F P
0 g
s
.764 .927 .565 r
.62387 .27891 m .62556 .27531 L p .62758 .27389 L F P
0 g
s
.764 .927 .565 r
.62758 .27389 m .6248 .27798 L .62387 .27891 L p F P
0 g
s
0 0 0 r
.82361 .23448 m .82323 .23612 L .82383 .23229 L p F P
0 g
s
0 0 0 r
.82383 .23229 m .82464 .22877 L .82361 .23448 L p F P
0 g
s
0 0 .024 r
.59354 .3334 m .58971 .33824 L .59272 .33186 L p F P
0 g
s
0 0 .024 r
.59272 .33186 m .59463 .32945 L .59354 .3334 L p F P
0 g
s
.726 .895 .956 r
.65292 .40624 m .65126 .4071 L .64837 .40531 L p F P
0 g
s
.707 .891 .964 r
.6364 .411 m .64837 .40531 L .65126 .4071 L p F P
0 g
s
.752 .937 .946 r
.68717 .3871 m .68996 .38839 L .67801 .39553 L p F P
0 g
s
.752 .937 .946 r
.67647 .3935 m .68717 .3871 L p .67801 .39553 L F P
0 g
s
.752 .937 .946 r
.67801 .39553 m .67568 .39448 L .67647 .3935 L p F P
0 g
s
.855 .994 .748 r
.78502 .30913 m .79094 .3018 L .78879 .30691 L p F P
0 g
s
.855 .994 .748 r
.78492 .30938 m .78502 .30913 L p .78879 .30691 L F P
0 g
s
.855 .994 .748 r
.78879 .30691 m .78723 .30881 L .78492 .30938 L p F P
0 g
s
.823 .875 .883 r
.71784 .16575 m .72444 .16058 L .72167 .15794 L p F P
0 g
s
.823 .875 .883 r
.72167 .15794 m .71799 .16095 L .71784 .16575 L p F P
0 g
s
.814 .883 .895 r
.7098 .16752 m .71799 .16095 L .71784 .16575 L p F P
0 g
s
.747 .807 .9 r
.75116 .14853 m .75016 .1491 L .74995 .14708 L closepath p F P
0 g
s
.748 .827 .913 r
.74841 .14523 m .74995 .14708 L .75016 .1491 L p F P
0 g
s
.748 .827 .913 r
.73638 .15238 m .74841 .14523 L p .75016 .1491 L F P
0 g
s
.889 .941 .84 r
.68624 .1898 m .68243 .19397 L .68183 .19889 L p F P
0 g
s
.879 .951 .852 r
.67536 .20162 m .68243 .19397 L .68183 .19889 L p F P
0 g
s
.879 .951 .852 r
.67515 .20276 m .67536 .20162 L p .68183 .19889 L F P
0 g
s
.879 .951 .852 r
.68183 .19889 m .67731 .20359 L .67515 .20276 L p F P
0 g
s
.881 .726 .686 r
.22197 .40415 m .2224 .40446 L .22561 .39807 L p F P
0 g
s
.881 .726 .686 r
.21876 .40001 m .22197 .40415 L p .22561 .39807 L F P
0 g
s
.881 .726 .686 r
.22561 .39807 m .22124 .39489 L .21876 .40001 L p F P
0 g
s
.788 .964 .92 r
.71704 .37311 m .71655 .37346 L .71384 .37254 L p F P
0 g
s
.773 .954 .932 r
.70387 .38145 m .70191 .38069 L .7067 .37747 L closepath p F P
0 g
s
.596 .687 .905 r
.78817 .14577 m .78109 .14682 L .77833 .1427 L p F P
0 g
s
.791 .971 .913 r
.71704 .37311 m .72844 .36463 L .72577 .36386 L p F P
0 g
s
.791 .971 .913 r
.72577 .36386 m .72065 .36765 L .71704 .37311 L p F P
0 g
s
.788 .964 .92 r
.71384 .37254 m .72065 .36765 L .71704 .37311 L p F P
0 g
s
.716 .798 .915 r
.76054 .13931 m .7633 .14293 L .75116 .14853 L p F P
0 g
s
.716 .798 .915 r
.75052 .14421 m .76054 .13931 L p .75116 .14853 L F P
0 g
s
.716 .798 .915 r
.75116 .14853 m .74995 .14708 L .75052 .14421 L p F P
0 g
s
.844 .995 .753 r
.78723 .30881 m .78259 .31431 L .78492 .30938 L closepath p F P
0 g
s
.798 .976 .905 r
.72896 .36477 m .72844 .36463 L .72964 .36371 L closepath p F P
0 g
s
.818 .929 .55 r
.80761 .27737 m .8056 .28083 L .80653 .27839 L closepath p F P
0 g
s
.726 .895 .956 r
.64837 .40531 m .65854 .40021 L .65292 .40624 L p F P
0 g
s
.723 .903 .959 r
.65292 .40624 m .66322 .40082 L .66037 .39927 L p F P
0 g
s
.723 .903 .959 r
.66037 .39927 m .65854 .40021 L .65292 .40624 L p F P
0 g
s
.898 .944 .829 r
.67731 .20359 m .67475 .20653 L .67515 .20276 L closepath p F P
0 g
s
.786 .858 .903 r
.73111 .15603 m .72444 .16058 L .72167 .15794 L p F P
0 g
s
0 0 0 r
.60752 .30726 m .61101 .30074 L .60768 .30636 L p F P
0 g
s
0 0 0 r
.60422 .31242 m .60752 .30726 L p .60768 .30636 L F P
0 g
s
0 0 0 r
.60768 .30636 m .60449 .31185 L .60422 .31242 L p F P
0 g
s
.325 .199 .551 r
.57636 .38042 m .56994 .38607 L .56834 .3811 L p F P
0 g
s
.325 .199 .551 r
.56834 .3811 m .57583 .3745 L .57636 .38042 L p F P
0 g
s
0 0 .056 r
.82571 .22385 m .82464 .22877 L .82513 .22323 L p F P
0 g
s
0 0 .056 r
.82513 .22323 m .82622 .21831 L .82571 .22385 L p F P
0 g
s
.553 .73 .957 r
.16582 .41498 m .17689 .41337 L .1806 .41671 L p F P
0 g
s
.555 .729 .956 r
.17689 .41337 m .16582 .41498 L .16209 .41164 L p F P
0 g
s
.902 .985 .735 r
.64517 .24639 m .64413 .24785 L .64449 .24659 L closepath p F P
0 g
s
.793 .853 .401 r
.81588 .25772 m .81848 .25147 L .81707 .25644 L p F P
0 g
s
.793 .853 .401 r
.81522 .26006 m .81588 .25772 L p .81707 .25644 L F P
0 g
s
.793 .853 .401 r
.81707 .25644 m .81633 .25819 L .81522 .26006 L p F P
0 g
s
.799 .934 .569 r
.6248 .27798 m .62307 .28071 L .62387 .27891 L closepath p F P
0 g
s
.474 .4 .693 r
.56464 .3976 m .56884 .39446 L .5702 .39989 L closepath p F P
0 g
s
.902 .946 .825 r
.66915 .20899 m .66824 .21399 L .67475 .20653 L p F P
0 g
s
.902 .946 .825 r
.67452 .20253 m .66915 .20899 L p .67475 .20653 L F P
0 g
s
.902 .946 .825 r
.67475 .20653 m .67515 .20276 L .67452 .20253 L p F P
0 g
s
.897 .985 .787 r
.65553 .23138 m .654 .23146 L .65635 .22853 L closepath p F P
0 g
s
0 0 .476 r
.82678 .20135 m .82647 .20291 L .825 .19805 L p F P
0 g
s
0 0 .476 r
.825 .19805 m .82559 .1951 L .82678 .20135 L p F P
0 g
s
.849 .998 .794 r
.77823 .31674 m .77591 .32187 L .78259 .31431 L p F P
0 g
s
.849 .998 .794 r
.7848 .30939 m .77823 .31674 L p .78259 .31431 L F P
0 g
s
.849 .998 .794 r
.78259 .31431 m .78492 .30938 L .7848 .30939 L p F P
0 g
s
.902 .983 .724 r
.6408 .24964 m .63925 .25478 L .64413 .24785 L p F P
0 g
s
.902 .983 .724 r
.64238 .24729 m .6408 .24964 L p .64413 .24785 L F P
0 g
s
.902 .983 .724 r
.64413 .24785 m .64449 .24659 L .64238 .24729 L p F P
0 g
s
.681 .715 .195 r
.82203 .24039 m .82062 .24538 L .82228 .23946 L p F P
0 g
s
.681 .715 .195 r
.82262 .23824 m .82203 .24039 L p .82228 .23946 L F P
0 g
s
.681 .715 .195 r
.82228 .23946 m .82323 .23612 L .82262 .23824 L p F P
0 g
s
.164 0 .389 r
.57602 .3688 m .57574 .36908 L .57597 .36405 L p F P
0 g
s
.164 0 .389 r
.57597 .36405 m .57701 .36303 L .57602 .3688 L p F P
0 g
s
.906 .71 .627 r
.21703 .39164 m .22124 .39489 L .22313 .38894 L p F P
0 g
s
.906 .71 .627 r
.22313 .38894 m .2189 .38569 L .21703 .39164 L p F P
0 g
s
.847 .962 .63 r
.80314 .28258 m .80124 .28765 L .8056 .28083 L p F P
0 g
s
.847 .962 .63 r
.80533 .27915 m .80314 .28258 L p .8056 .28083 L F P
0 g
s
.847 .962 .63 r
.8056 .28083 m .80653 .27839 L .80533 .27915 L p F P
0 g
s
.773 .849 .398 r
.81633 .25819 m .81433 .26272 L .81522 .26006 L closepath p F P
0 g
s
.8 .973 .907 r
.72964 .36371 m .72844 .36463 L .72577 .36386 L p F P
0 g
s
.789 .923 .546 r
.62133 .28205 m .6189 .28743 L .62307 .28071 L p F P
0 g
s
.789 .923 .546 r
.62202 .28089 m .62133 .28205 L p .62307 .28071 L F P
0 g
s
.789 .923 .546 r
.62307 .28071 m .62387 .27891 L .62202 .28089 L p F P
0 g
s
.795 .849 .891 r
.73111 .15603 m .73638 .15238 L .73362 .14941 L p F P
0 g
s
.795 .849 .891 r
.73362 .14941 m .73102 .15129 L .73111 .15603 L p F P
0 g
s
.786 .858 .903 r
.72167 .15794 m .73102 .15129 L .73111 .15603 L p F P
0 g
s
.8 .973 .907 r
.72577 .36386 m .73295 .35833 L .72964 .36371 L p F P
0 g
s
.804 .98 .898 r
.72964 .36371 m .74031 .35521 L .73767 .35458 L p F P
0 g
s
.804 .98 .898 r
.73767 .35458 m .73295 .35833 L .72964 .36371 L p F P
0 g
s
.848 .998 .809 r
.77578 .32217 m .77563 .32217 L .77591 .32187 L closepath p F P
0 g
s
.76 .944 .941 r
.69026 .38852 m .68996 .38839 L .69072 .38791 L closepath p F P
0 g
s
.811 .983 .89 r
.74059 .35527 m .74031 .35521 L .74091 .35472 L closepath p F P
0 g
s
.893 .97 .826 r
.66288 .21637 m .66915 .20899 L .66824 .21399 L p F P
0 g
s
.893 .97 .826 r
.66287 .21642 m .66288 .21637 L p .66824 .21399 L F P
0 g
s
.893 .97 .826 r
.66824 .21399 m .66564 .21694 L .66287 .21642 L p F P
0 g
s
.705 .882 .963 r
.64837 .40531 m .6364 .411 L .63347 .40899 L p F P
0 g
s
.927 .693 .565 r
.21483 .38238 m .2189 .38569 L .21991 .38004 L p F P
0 g
s
.927 .693 .565 r
.21991 .38004 m .21583 .37673 L .21483 .38238 L p F P
0 g
s
.851 .997 .813 r
.77313 .32222 m .77823 .31674 L .77591 .32187 L p F P
0 g
s
.851 .997 .813 r
.77591 .32187 m .77563 .32217 L .77313 .32222 L p F P
0 g
s
.841 .999 .815 r
.76831 .32973 m .77563 .32217 L .77313 .32222 L p F P
0 g
s
.604 .699 .911 r
.57649 .41464 m .58847 .41232 L .59153 .41639 L p F P
0 g
s
.608 .625 .842 r
.57513 .41216 m .57649 .41464 L .58847 .41232 L p F P
0 g
s
0 0 .208 r
.58482 .35066 m .58446 .35106 L .58518 .34662 L p F P
0 g
s
0 0 .208 r
.58518 .34662 m .58705 .34451 L .58482 .35066 L p F P
0 g
s
.912 .962 .804 r
.66564 .21694 m .66216 .2213 L .66287 .21642 L closepath p F P
0 g
s
0 0 .09 r
.59193 .33847 m .58705 .34451 L .58971 .33824 L p F P
0 g
s
0 0 .09 r
.59301 .3357 m .59193 .33847 L p .58971 .33824 L F P
0 g
s
0 0 .09 r
.58971 .33824 m .59354 .3334 L .59301 .3357 L p F P
0 g
s
.476 .584 .883 r
.79637 .14991 m .80352 .15061 L .8033 .15541 L p F P
0 g
s
.422 .519 .852 r
.80919 .15173 m .80352 .15061 L .8033 .15541 L p F P
0 g
s
.422 .519 .852 r
.8033 .15541 m .81205 .15758 L .80919 .15173 L p F P
0 g
s
0 0 0 r
.60449 .31185 m .60386 .31298 L .60422 .31242 L closepath p F P
0 g
s
.718 .799 .915 r
.74995 .14708 m .74841 .14523 L .75052 .14421 L closepath p F P
0 g
s
.761 .814 .895 r
.74841 .14523 m .73638 .15238 L .73362 .14941 L p F P
0 g
s
.763 .938 .941 r
.69072 .38791 m .68996 .38839 L .68717 .3871 L p F P
0 g
s
.814 .98 .892 r
.74091 .35472 m .74031 .35521 L .73767 .35458 L p F P
0 g
s
.624 .75 .937 r
.1806 .41671 m .19181 .41367 L .19549 .41708 L p F P
0 g
s
.627 .751 .936 r
.19181 .41367 m .1806 .41671 L .17689 .41337 L p F P
0 g
s
.004 .088 .6 r
.82369 .18853 m .82379 .18799 L .82416 .18942 L closepath p F P
0 g
s
.144 0 .387 r
.58241 .36234 m .57602 .3688 L .57701 .36303 L p F P
0 g
s
.144 0 .387 r
.57701 .36303 m .58324 .35661 L .58241 .36234 L p F P
0 g
s
.813 .986 .883 r
.74393 .34942 m .74091 .35472 L .751 .34609 L p F P
0 g
s
.814 .98 .892 r
.73767 .35458 m .74393 .34942 L .74091 .35472 L p F P
0 g
s
.942 .675 .502 r
.21192 .37335 m .21583 .37673 L .21621 .3713 L p F P
0 g
s
.942 .675 .502 r
.21621 .3713 m .21231 .36791 L .21192 .37335 L p F P
0 g
s
.764 .946 .938 r
.69072 .38791 m .70191 .38069 L .69915 .37958 L p F P
0 g
s
.764 .946 .938 r
.69915 .37958 m .6949 .3823 L .69072 .38791 L p F P
0 g
s
.763 .938 .941 r
.68717 .3871 m .6949 .3823 L .69072 .38791 L p F P
0 g
s
.395 .297 .625 r
.5737 .39039 m .56884 .39446 L .56776 .38791 L p F P
0 g
s
.395 .297 .625 r
.56776 .38791 m .56994 .38607 L .5737 .39039 L p F P
0 g
s
.841 .999 .815 r
.77313 .32222 m .77092 .32451 L .76831 .32973 L p F P
0 g
s
.839 .997 .835 r
.76284 .33253 m .77092 .32451 L .76831 .32973 L p F P
0 g
s
.839 .997 .835 r
.76211 .33402 m .76284 .33253 L p .76831 .32973 L F P
0 g
s
.839 .997 .835 r
.76831 .32973 m .76392 .33408 L .76211 .33402 L p F P
0 g
s
.889 .988 .732 r
.64449 .24659 m .64238 .24729 L .64578 .24266 L closepath p F P
0 g
s
.779 .771 .846 r
.21428 .41247 m .21054 .41528 L .2069 .41166 L p F P
0 g
s
.706 .759 .894 r
.19549 .41708 m .2069 .41166 L .21054 .41528 L p F P
0 g
s
.859 .746 .736 r
.2224 .40446 m .22197 .40415 L .22233 .40457 L closepath p F P
0 g
s
.479 .698 .965 r
.14742 .40868 m .15644 .40833 L .16025 .41172 L p F P
0 g
s
.812 .751 .796 r
.21428 .41247 m .22233 .40457 L .22197 .40415 L p F P
0 g
s
0 0 0 r
.60278 .31592 m .60049 .31946 L .60386 .31298 L p F P
0 g
s
0 0 0 r
.60386 .31298 m .60422 .31242 L .60278 .31592 L p F P
0 g
s
.892 .978 .688 r
.63625 .25648 m .63431 .26174 L .63925 .25478 L p F P
0 g
s
.892 .978 .688 r
.63925 .25478 m .6408 .24964 L .63625 .25648 L p F P
0 g
s
.828 .998 .841 r
.76392 .33408 m .76005 .33779 L .76211 .33402 L closepath p F P
0 g
s
.827 .994 .857 r
.76137 .33392 m .76211 .33402 L .76005 .33779 L p F P
0 g
s
.827 .994 .857 r
.75383 .34084 m .76137 .33392 L p .76005 .33779 L F P
0 g
s
.827 .994 .857 r
.75163 .34503 m .75383 .34084 L p .76005 .33779 L F P
0 g
s
.827 .994 .857 r
.76005 .33779 m .75214 .34507 L .75163 .34503 L p F P
0 g
s
.816 .994 .863 r
.75214 .34507 m .751 .34609 L .75163 .34503 L closepath p F P
0 g
s
.813 .986 .883 r
.74954 .34462 m .74393 .34942 L p .751 .34609 L F P
0 g
s
.813 .986 .883 r
.751 .34609 m .75163 .34503 L .74954 .34462 L p F P
0 g
s
0 0 .012 r
.59441 .33224 m .59354 .3334 L .59463 .32945 L p F P
0 g
s
0 0 .012 r
.59463 .32945 m .59733 .32589 L .59441 .33224 L p F P
0 g
s
.735 .916 .955 r
.6752 .39423 m .66322 .40082 L .66037 .39927 L p F P
0 g
s
.952 .656 .438 r
.20856 .36446 m .21231 .36791 L .21222 .36265 L p F P
0 g
s
.952 .656 .438 r
.21222 .36265 m .20848 .35919 L .20856 .36446 L p F P
0 g
s
.134 .246 .716 r
.82094 .17907 m .82123 .17938 L .82119 .17976 L closepath p F P
0 g
s
.039 .151 .655 r
.82425 .1837 m .82379 .18799 L .82119 .17976 L p F P
0 g
s
.039 .151 .655 r
.82119 .17976 m .82123 .17938 L .82425 .1837 L p F P
0 g
s
.493 .597 .886 r
.80352 .15061 m .79637 .14991 L .79358 .14514 L p F P
0 g
s
.915 .963 .798 r
.65747 .22348 m .65635 .22853 L .66216 .2213 L p F P
0 g
s
.915 .963 .798 r
.66284 .21642 m .65747 .22348 L p .66216 .2213 L F P
0 g
s
.915 .963 .798 r
.66216 .2213 m .66287 .21642 L .66284 .21642 L p F P
0 g
s
.812 .751 .796 r
.20995 .40928 m .21428 .41247 L p .22197 .40415 L F P
0 g
s
.779 .771 .846 r
.2069 .41166 m .20995 .40928 L .21428 .41247 L p F P
0 g
s
0 0 .201 r
.82726 .21338 m .82622 .21831 L .82614 .21297 L p F P
0 g
s
0 0 .201 r
.82614 .21297 m .8272 .20803 L .82726 .21338 L p F P
0 g
s
.812 .751 .796 r
.22197 .40415 m .2178 .40136 L .20995 .40928 L p F P
0 g
s
.845 .736 .744 r
.21876 .40001 m .2178 .40136 L .22197 .40415 L closepath p F P
0 g
s
.152 .272 .734 r
.82123 .17938 m .82094 .17907 L .8179 .171 L p F P
0 g
s
0 0 .54 r
.82642 .18832 m .82425 .1837 L .82379 .18799 L p F P
0 g
s
0 0 .54 r
.82585 .19315 m .82642 .18832 L p .82379 .18799 L F P
0 g
s
0 0 .54 r
.82379 .18799 m .82416 .18942 L .82585 .19315 L p F P
0 g
s
.823 .907 .502 r
.81272 .26416 m .81107 .26918 L .81433 .26272 L p F P
0 g
s
.823 .907 .502 r
.81418 .26124 m .81272 .26416 L p .81433 .26272 L F P
0 g
s
.823 .907 .502 r
.81433 .26272 m .81522 .26006 L .81418 .26124 L p F P
0 g
s
.863 .977 .675 r
.79831 .28957 m .79649 .2946 L .80124 .28765 L p F P
0 g
s
.863 .977 .675 r
.80124 .28765 m .80314 .28258 L .79831 .28957 L p F P
0 g
s
.711 .762 .893 r
.2069 .41166 m .19549 .41708 L .19181 .41367 L p F P
0 g
s
0 .016 .554 r
.82416 .18942 m .82585 .19315 L .82559 .1951 L closepath p F P
0 g
s
0 0 0 r
.60418 .31374 m .60278 .31592 L .60422 .31242 L p F P
0 g
s
0 0 0 r
.60422 .31242 m .60752 .30726 L .60418 .31374 L p F P
0 g
s
.562 .572 .822 r
.57337 .4085 m .58023 .40813 L .57513 .41216 L closepath p F P
0 g
s
.608 .625 .842 r
.58538 .40752 m .58023 .40813 L .57513 .41216 L p F P
0 g
s
.608 .625 .842 r
.58847 .41232 m .58538 .40752 L p .57513 .41216 L F P
0 g
s
.694 .833 .95 r
.63243 .40943 m .62149 .41403 L .61851 .41151 L p F P
0 g
s
.669 .826 .959 r
.60653 .41592 m .61851 .41151 L .62149 .41403 L p F P
0 g
s
.845 .971 .657 r
.63399 .26252 m .63359 .26278 L .63431 .26174 L closepath p F P
0 g
s
.152 .272 .734 r
.8179 .171 m .82163 .17458 L .82123 .17938 L p F P
0 g
s
.036 .156 .661 r
.82473 .17888 m .82425 .1837 L .82123 .17938 L p F P
0 g
s
.036 .156 .661 r
.82123 .17938 m .82163 .17458 L .82473 .17888 L p F P
0 g
s
.748 .881 .47 r
.61758 .28865 m .61479 .29413 L .6189 .28743 L p F P
0 g
s
.748 .881 .47 r
.6189 .28743 m .62133 .28205 L .61758 .28865 L p F P
0 g
s
.345 .447 .822 r
.81171 .16258 m .81228 .15806 L .81496 .16402 L closepath p F P
0 g
s
.639 .814 .388 r
.61397 .29558 m .61325 .29673 L .61479 .29413 L closepath p F P
0 g
s
.776 .92 .544 r
.62387 .27891 m .62202 .28089 L .62556 .27531 L closepath p F P
0 g
s
.596 .687 .905 r
.77833 .1427 m .78863 .14086 L .78817 .14577 L p F P
0 g
s
.57 .659 .897 r
.79079 .14053 m .78863 .14086 L .78817 .14577 L p F P
0 g
s
.57 .659 .897 r
.78817 .14577 m .79358 .14514 L .79079 .14053 L p F P
0 g
s
.643 .776 .945 r
.59153 .41639 m .60351 .41283 L .60653 .41592 L p F P
0 g
s
.624 .743 .932 r
.60351 .41283 m .59153 .41639 L .58847 .41232 L p F P
0 g
s
.253 .353 .773 r
.81743 .17066 m .81752 .17004 L .8179 .171 L closepath p F P
0 g
s
.664 .734 .902 r
.7633 .14293 m .77557 .13867 L .77833 .1427 L p F P
0 g
s
.674 .744 .903 r
.77557 .13867 m .7633 .14293 L .76054 .13931 L p F P
0 g
s
.484 .7 .964 r
.15835 .40825 m .15644 .40833 L .16025 .41172 L p F P
0 g
s
.484 .7 .964 r
.16025 .41172 m .16209 .41164 L .15835 .40825 L p F P
0 g
s
0 0 0 r
.82466 .22958 m .82361 .23448 L .82464 .22877 L p F P
0 g
s
0 0 0 r
.82464 .22877 m .82571 .22385 L .82466 .22958 L p F P
0 g
s
.758 .803 .319 r
.81983 .24651 m .81848 .25147 L .82062 .24538 L p F P
0 g
s
.758 .803 .319 r
.82062 .24538 m .82203 .24039 L .81983 .24651 L p F P
0 g
s
.659 .806 .953 r
.61851 .41151 m .60653 .41592 L .60351 .41283 L p F P
0 g
s
.827 .986 .875 r
.75163 .34503 m .74954 .34462 L .75383 .34084 L closepath p F P
0 g
s
.889 .738 .688 r
.21518 .3956 m .21703 .39164 L .22124 .39489 L p F P
0 g
s
.889 .738 .688 r
.22124 .39489 m .21876 .40001 L .21518 .3956 L p F P
0 g
s
.898 .985 .788 r
.65195 .23063 m .65747 .22348 L .65635 .22853 L p F P
0 g
s
.898 .985 .788 r
.65171 .23157 m .65195 .23063 L p .65635 .22853 L F P
0 g
s
.898 .985 .788 r
.65635 .22853 m .654 .23146 L .65171 .23157 L p F P
0 g
s
.867 .961 .624 r
.80653 .27839 m .80533 .27915 L .8074 .27579 L closepath p F P
0 g
s
.843 .971 .656 r
.63168 .26333 m .63625 .25648 L .63431 .26174 L p F P
0 g
s
.843 .971 .656 r
.63131 .26431 m .63168 .26333 L p .63431 .26174 L F P
0 g
s
.843 .971 .656 r
.63431 .26174 m .63359 .26278 L .63131 .26431 L p F P
0 g
s
.61 .688 .899 r
.78863 .14086 m .77833 .1427 L .77557 .13867 L p F P
0 g
s
.117 .263 .738 r
.81752 .17004 m .8179 .171 L .82163 .17458 L p F P
0 g
s
.775 .951 .932 r
.7067 .37747 m .70191 .38069 L .69915 .37958 L p F P
0 g
s
0 0 .44 r
.82723 .19804 m .82678 .20135 L .82559 .1951 L p F P
0 g
s
0 0 .44 r
.82559 .1951 m .82585 .19315 L .82723 .19804 L p F P
0 g
s
.872 .969 .65 r
.63359 .26278 m .62988 .26854 L .63131 .26431 L closepath p F P
0 g
s
.246 .37 .792 r
.81496 .16402 m .81775 .16587 L .81752 .17004 L closepath p F P
0 g
s
.117 .263 .738 r
.822 .16977 m .81775 .16587 L .81752 .17004 L p F P
0 g
s
.117 .263 .738 r
.82163 .17458 m .822 .16977 L p .81752 .17004 L F P
0 g
s
.867 .987 .716 r
.79642 .29478 m .79633 .29481 L .79649 .2946 L closepath p F P
0 g
s
.565 .53 .775 r
.57086 .40206 m .57337 .4085 L .58023 .40813 L p F P
0 g
s
.846 .906 .877 r
.70726 .16982 m .69799 .17811 L .69785 .17801 L p F P
0 g
s
.868 .904 .855 r
.69799 .17811 m .69785 .17825 L .69785 .17801 L closepath p F P
0 g
s
.871 .906 .852 r
.69027 .18133 m .68991 .18619 L .69785 .17825 L p F P
0 g
s
.871 .906 .852 r
.69521 .1762 m .69027 .18133 L p .69785 .17825 L F P
0 g
s
.871 .906 .852 r
.69785 .17825 m .69785 .17801 L .69521 .1762 L p F P
0 g
s
.747 .926 .949 r
.67568 .39448 m .6752 .39423 L .67647 .3935 L closepath p F P
0 g
s
.499 .416 .693 r
.57908 .39315 m .5737 .39039 L .56884 .39446 L p F P
0 g
s
.499 .416 .693 r
.57959 .39475 m .57908 .39315 L p .56884 .39446 L F P
0 g
s
.499 .416 .693 r
.57266 .4006 m .57959 .39475 L p .56884 .39446 L F P
0 g
s
.499 .416 .693 r
.56884 .39446 m .5702 .39989 L .57266 .4006 L p F P
0 g
s
.918 .975 .769 r
.654 .23146 m .65093 .23564 L .65171 .23157 L closepath p F P
0 g
s
0 0 .202 r
.58998 .34453 m .58482 .35066 L .58705 .34451 L p F P
0 g
s
0 0 .202 r
.58705 .34451 m .59193 .33847 L .58998 .34453 L p F P
0 g
s
.871 .988 .72 r
.79393 .29552 m .79831 .28957 L .79649 .2946 L p F P
0 g
s
.871 .988 .72 r
.79649 .2946 m .79633 .29481 L .79393 .29552 L p F P
0 g
s
.845 .883 .868 r
.7098 .16752 m .70726 .16982 L .70713 .16529 L closepath p F P
0 g
s
.846 .906 .877 r
.70702 .1652 m .70713 .16529 L .70726 .16982 L p F P
0 g
s
.846 .906 .877 r
.69832 .17334 m .70702 .1652 L p .70726 .16982 L F P
0 g
s
.846 .906 .877 r
.69785 .17801 m .69832 .17334 L p .70726 .16982 L F P
0 g
s
.821 .883 .889 r
.71799 .16095 m .7098 .16752 L .70713 .16529 L p F P
0 g
s
.387 .295 .628 r
.5775 .38705 m .5737 .39039 L .56994 .38607 L p F P
0 g
s
.387 .295 .628 r
.56994 .38607 m .57636 .38042 L .5775 .38705 L p F P
0 g
s
.858 .988 .718 r
.79094 .3018 m .79633 .29481 L .79393 .29552 L p F P
0 g
s
0 0 0 r
.60109 .32015 m .59733 .32589 L .60049 .31946 L p F P
0 g
s
0 0 0 r
.60174 .31875 m .60109 .32015 L p .60049 .31946 L F P
0 g
s
0 0 0 r
.60049 .31946 m .60278 .31592 L .60174 .31875 L p F P
0 g
s
.718 .802 .917 r
.75052 .14421 m .74841 .14523 L .74565 .14198 L p F P
0 g
s
.761 .814 .895 r
.73362 .14941 m .74565 .14198 L .74841 .14523 L p F P
0 g
s
.852 .908 .873 r
.69785 .17801 m .69521 .1762 L .69832 .17334 L closepath p F P
0 g
s
0 0 .341 r
.82743 .20685 m .8272 .20803 L .82647 .20291 L p F P
0 g
s
0 0 .341 r
.82647 .20291 m .82678 .20135 L .82743 .20685 L p F P
0 g
s
.555 .729 .956 r
.16209 .41164 m .17316 .40999 L .17689 .41337 L p F P
0 g
s
.555 .728 .955 r
.17316 .40999 m .16209 .41164 L .15835 .40825 L p F P
0 g
s
.722 .732 .212 r
.82323 .23612 m .82262 .23824 L .82361 .23448 L closepath p F P
0 g
s
.867 .929 .863 r
.68344 .18827 m .69027 .18133 L .68991 .18619 L p F P
0 g
s
.867 .929 .863 r
.68991 .18619 m .68624 .1898 L .68344 .18827 L p F P
0 g
s
.776 .96 .927 r
.7067 .37747 m .71384 .37254 L .71112 .37159 L p F P
0 g
s
.776 .96 .927 r
.71112 .37159 m .71066 .37191 L .7067 .37747 L p F P
0 g
s
.775 .951 .932 r
.69915 .37958 m .71066 .37191 L .7067 .37747 L p F P
0 g
s
.886 .952 .843 r
.67515 .20276 m .67452 .20253 L .67536 .20162 L closepath p F P
0 g
s
.226 .08 .464 r
.57608 .37425 m .57583 .3745 L .57574 .36908 L p F P
0 g
s
.226 .08 .464 r
.57574 .36908 m .57602 .3688 L .57608 .37425 L p F P
0 g
s
.895 .93 .833 r
.68243 .19397 m .68624 .1898 L .68344 .18827 L p F P
0 g
s
.913 .718 .625 r
.21298 .38833 m .21703 .39164 L .2189 .38569 L p F P
0 g
s
.913 .718 .625 r
.2189 .38569 m .21483 .38238 L .21298 .38833 L p F P
0 g
s
.722 .886 .956 r
.65854 .40021 m .64837 .40531 L .64547 .4034 L p F P
0 g
s
.705 .882 .963 r
.63347 .40899 m .64547 .4034 L .64837 .40531 L p F P
0 g
s
.852 .94 .571 r
.80897 .27079 m .8074 .27579 L .81107 .26918 L p F P
0 g
s
.852 .94 .571 r
.81107 .26918 m .81272 .26416 L .80897 .27079 L p F P
0 g
s
.622 .801 .373 r
.61392 .29523 m .61758 .28865 L .61479 .29413 L p F P
0 g
s
.622 .801 .373 r
.61215 .29855 m .61392 .29523 L p .61479 .29413 L F P
0 g
s
.622 .801 .373 r
.61479 .29413 m .61325 .29673 L .61215 .29855 L p F P
0 g
s
.829 .87 .875 r
.71799 .16095 m .72167 .15794 L .7189 .1553 L p F P
0 g
s
.829 .87 .875 r
.7189 .1553 m .71778 .15624 L .71799 .16095 L p F P
0 g
s
.821 .883 .889 r
.70715 .1651 m .71778 .15624 L .71799 .16095 L p F P
0 g
s
.821 .883 .889 r
.70713 .16529 m .70715 .1651 L p .71799 .16095 L F P
0 g
s
.729 .803 .91 r
.75052 .14421 m .76054 .13931 L .75778 .13573 L p F P
0 g
s
.729 .803 .91 r
.75778 .13573 m .75088 .1393 L .75052 .14421 L p F P
0 g
s
.718 .802 .917 r
.74565 .14198 m .75088 .1393 L .75052 .14421 L p F P
0 g
s
.484 .437 .729 r
.5702 .39989 m .57266 .4006 L .57086 .40206 L closepath p F P
0 g
s
.209 .069 .46 r
.58249 .36779 m .57608 .37425 L .57602 .3688 L p F P
0 g
s
.209 .069 .46 r
.57602 .3688 m .58241 .36234 L .58249 .36779 L p F P
0 g
s
.565 .53 .775 r
.58226 .40144 m .57266 .4006 L .57086 .40206 L p F P
0 g
s
.565 .53 .775 r
.58402 .40506 m .58226 .40144 L p .57086 .40206 L F P
0 g
s
.565 .53 .775 r
.58023 .40813 m .58402 .40506 L p .57086 .40206 L F P
0 g
s
.92 .976 .76 r
.64705 .23758 m .64578 .24266 L .65093 .23564 L p F P
0 g
s
.92 .976 .76 r
.6512 .23161 m .64705 .23758 L p .65093 .23564 L F P
0 g
s
.92 .976 .76 r
.65093 .23564 m .65171 .23157 L .6512 .23161 L p F P
0 g
s
.75 .918 .948 r
.67647 .3935 m .6752 .39423 L .67236 .3927 L p F P
0 g
s
.735 .916 .955 r
.66037 .39927 m .67236 .3927 L .6752 .39423 L p F P
0 g
s
.794 .86 .898 r
.73102 .15129 m .72167 .15794 L .7189 .1553 L p F P
0 g
s
.895 .93 .833 r
.68344 .18827 m .68266 .18916 L .68243 .19397 L p F P
0 g
s
.895 .93 .833 r
.67605 .19666 m .67536 .20162 L .68243 .19397 L p F P
0 g
s
.895 .93 .833 r
.68243 .19397 m .68266 .18916 L .67605 .19666 L p F P
0 g
s
.75 .927 .948 r
.67647 .3935 m .68717 .3871 L .68437 .38576 L p F P
0 g
s
.75 .927 .948 r
.68437 .38576 m .68091 .3878 L .67647 .3935 L p F P
0 g
s
.75 .918 .948 r
.67236 .3927 m .68091 .3878 L .67647 .3935 L p F P
0 g
s
.934 .702 .562 r
.21092 .37901 m .21483 .38238 L .21583 .37673 L p F P
0 g
s
.934 .702 .562 r
.21583 .37673 m .21192 .37335 L .21092 .37901 L p F P
0 g
s
.867 .963 .631 r
.62758 .27004 m .62556 .27531 L .62988 .26854 L p F P
0 g
s
.867 .963 .631 r
.63079 .26469 m .62758 .27004 L p .62988 .26854 L F P
0 g
s
.867 .963 .631 r
.62988 .26854 m .63131 .26431 L .63079 .26469 L p F P
0 g
s
.666 .821 .388 r
.61325 .29673 m .61101 .30074 L .61215 .29855 L closepath p F P
0 g
s
.864 .994 .758 r
.78701 .30407 m .78502 .30913 L .79094 .3018 L p F P
0 g
s
.864 .994 .758 r
.79094 .3018 m .79304 .29669 L .78701 .30407 L p F P
0 g
s
.858 .988 .718 r
.79393 .29552 m .79304 .29669 L .79094 .3018 L p F P
0 g
s
.788 .963 .921 r
.72065 .36765 m .71384 .37254 L .71112 .37159 L p F P
0 g
s
.854 .744 .741 r
.2178 .40136 m .21876 .40001 L .21518 .3956 L p F P
0 g
s
.846 .908 .501 r
.81522 .26006 m .81418 .26124 L .81588 .25772 L closepath p F P
0 g
s
.221 .368 .8 r
.81228 .15806 m .81496 .16402 L .81775 .16587 L p F P
0 g
s
0 0 .044 r
.82673 .21893 m .82571 .22385 L .82622 .21831 L p F P
0 g
s
0 0 .044 r
.82622 .21831 m .82726 .21338 L .82673 .21893 L p F P
0 g
s
.886 .951 .843 r
.67173 .20151 m .67605 .19666 L .67536 .20162 L p F P
0 g
s
.886 .951 .843 r
.67536 .20162 m .67452 .20253 L .67173 .20151 L p F P
0 g
s
.854 .744 .741 r
.21518 .3956 m .2134 .39818 L .2178 .40136 L p F P
0 g
s
.818 .758 .796 r
.20577 .40604 m .20995 .40928 L .2178 .40136 L p F P
0 g
s
.818 .758 .796 r
.2178 .40136 m .2134 .39818 L .20577 .40604 L p F P
0 g
s
.912 .951 .809 r
.66915 .20899 m .67452 .20253 L .67173 .20151 L p F P
0 g
s
.818 .868 .425 r
.81718 .25278 m .81588 .25772 L .81848 .25147 L p F P
0 g
s
.818 .868 .425 r
.81848 .25147 m .81983 .24651 L .81718 .25278 L p F P
0 g
s
.493 .597 .886 r
.79358 .14514 m .8038 .14577 L .80352 .15061 L p F P
0 g
s
.513 .601 .879 r
.8038 .14577 m .79358 .14514 L .79079 .14053 L p F P
0 g
s
0 0 .438 r
.82783 .19321 m .82723 .19804 L .82585 .19315 L p F P
0 g
s
0 0 .438 r
.82585 .19315 m .82642 .18832 L .82783 .19321 L p F P
0 g
s
.95 .683 .497 r
.20817 .3699 m .21192 .37335 L .21231 .36791 L p F P
0 g
s
.95 .683 .497 r
.21231 .36791 m .20856 .36446 L .20817 .3699 L p F P
0 g
s
.785 .773 .842 r
.20995 .40928 m .2069 .41166 L .20324 .40806 L p F P
0 g
s
.711 .762 .893 r
.19181 .41367 m .20324 .40806 L .2069 .41166 L p F P
0 g
s
.627 .751 .936 r
.17689 .41337 m .18811 .41024 L .19181 .41367 L p F P
0 g
s
.628 .751 .936 r
.18811 .41024 m .17689 .41337 L .17316 .40999 L p F P
0 g
s
0 0 .302 r
.82794 .20317 m .82743 .20685 L .82678 .20135 L p F P
0 g
s
0 0 .302 r
.82678 .20135 m .82723 .19804 L .82794 .20317 L p F P
0 g
s
.694 .855 .96 r
.63347 .40899 m .63243 .40943 L .63316 .40875 L closepath p F P
0 g
s
.694 .833 .95 r
.63052 .40668 m .63316 .40875 L .63243 .40943 L p F P
0 g
s
.694 .833 .95 r
.61851 .41151 m .63052 .40668 L p .63243 .40943 L F P
0 g
s
.794 .86 .898 r
.7189 .1553 m .73059 .14664 L .73102 .15129 L p F P
0 g
s
.801 .846 .884 r
.73102 .15129 m .73362 .14941 L .73085 .14645 L p F P
0 g
s
.801 .846 .884 r
.73085 .14645 m .73059 .14664 L .73102 .15129 L p F P
0 g
s
.029 0 .287 r
.58446 .35106 m .58431 .35257 L .58482 .35066 L closepath p F P
0 g
s
.727 .735 .216 r
.82311 .23549 m .82466 .22958 L .82361 .23448 L p F P
0 g
s
.727 .735 .216 r
.82227 .23945 m .82311 .23549 L p .82361 .23448 L F P
0 g
s
.727 .735 .216 r
.82361 .23448 m .82262 .23824 L .82227 .23945 L p F P
0 g
s
.785 .773 .842 r
.20324 .40806 m .20577 .40604 L .20995 .40928 L p F P
0 g
s
.791 .971 .913 r
.72577 .36386 m .72065 .36765 L .72359 .3632 L closepath p F P
0 g
s
.788 .963 .921 r
.72308 .36301 m .72359 .3632 L .72065 .36765 L p F P
0 g
s
.788 .963 .921 r
.71112 .37159 m .72308 .36301 L p .72065 .36765 L F P
0 g
s
.864 .996 .785 r
.78492 .30938 m .7848 .30939 L .78502 .30913 L closepath p F P
0 g
s
.703 .857 .956 r
.64255 .40137 m .64547 .4034 L .63347 .40899 L p F P
0 g
s
.703 .857 .956 r
.63807 .40337 m .64255 .40137 L p .63347 .40899 L F P
0 g
s
.703 .857 .956 r
.63347 .40899 m .63316 .40875 L .63807 .40337 L p F P
0 g
s
.889 .988 .733 r
.6422 .24452 m .64705 .23758 L .64578 .24266 L p F P
0 g
s
.889 .988 .733 r
.64128 .24765 m .6422 .24452 L p .64578 .24266 L F P
0 g
s
.889 .988 .733 r
.64578 .24266 m .64238 .24729 L .64128 .24765 L p F P
0 g
s
0 0 0 r
.5985 .32642 m .59441 .33224 L .59733 .32589 L p F P
0 g
s
0 0 0 r
.59733 .32589 m .60109 .32015 L .5985 .32642 L p F P
0 g
s
.767 .818 .893 r
.74565 .14198 m .73362 .14941 L .73085 .14645 L p F P
0 g
s
.867 .996 .789 r
.78233 .30954 m .78701 .30407 L .78502 .30913 L p F P
0 g
s
.867 .996 .789 r
.78502 .30913 m .7848 .30939 L .78233 .30954 L p F P
0 g
s
.856 .997 .791 r
.77823 .31674 m .7848 .30939 L .78233 .30954 L p F P
0 g
s
.869 .961 .626 r
.80484 .27756 m .80897 .27079 L .8074 .27579 L p F P
0 g
s
.869 .961 .626 r
.80411 .27991 m .80484 .27756 L p .8074 .27579 L F P
0 g
s
.869 .961 .626 r
.8074 .27579 m .80533 .27915 L .80411 .27991 L p F P
0 g
s
.67 .806 .356 r
.61047 .30156 m .61036 .30178 L .61042 .30167 L closepath p F P
0 g
s
0 0 0 r
.61036 .30178 m .61042 .30167 L .61039 .30173 L p F P
0 g
s
.645 .798 .353 r
.6095 .30357 m .61101 .30074 L p .61036 .30178 L F P
0 g
s
0 0 0 r
.61039 .30173 m .60885 .305 L p .61036 .30178 L F P
0 g
s
.645 .798 .353 r
.61036 .30178 m .60752 .30726 L .6095 .30357 L p F P
0 g
s
.645 .798 .353 r
.61047 .30156 m .61036 .30178 L p .61101 .30074 L F P
0 g
s
.645 .798 .353 r
.61101 .30074 m .61215 .29855 L .61047 .30156 L p F P
0 g
s
.84 .991 .856 r
.76211 .33402 m .76137 .33392 L .76284 .33253 L closepath p F P
0 g
s
.055 0 .301 r
.58855 .35045 m .58998 .34453 L .58482 .35066 L p F P
0 g
s
.055 0 .301 r
.58399 .35579 m .58855 .35045 L p .58482 .35066 L F P
0 g
s
.055 0 .301 r
.58482 .35066 m .58431 .35257 L .58399 .35579 L p F P
0 g
s
.523 .511 .784 r
.57266 .4006 m .57959 .39475 L .58226 .40144 L closepath p F P
0 g
s
.715 .766 .892 r
.20324 .40806 m .19181 .41367 L .18811 .41024 L p F P
0 g
s
.801 .972 .907 r
.73295 .35833 m .72577 .36386 L .72359 .3632 L p F P
0 g
s
.912 .951 .809 r
.67173 .20151 m .66963 .20411 L .66915 .20899 L p F P
0 g
s
.912 .951 .81 r
.66379 .21136 m .66288 .21637 L .66915 .20899 L p F P
0 g
s
.912 .951 .81 r
.66915 .20899 m .66963 .20411 L .66379 .21136 L p F P
0 g
s
.699 .85 .955 r
.63316 .40875 m .63052 .40668 L .63807 .40337 L closepath p F P
0 g
s
.438 .54 .863 r
.80634 .14615 m .8038 .14577 L .80352 .15061 L p F P
0 g
s
.438 .54 .863 r
.80352 .15061 m .80919 .15173 L .80634 .14615 L p F P
0 g
s
.624 .743 .932 r
.58847 .41232 m .60047 .40933 L .60351 .41283 L p F P
0 g
s
.598 .701 .916 r
.60047 .40933 m .58847 .41232 L .58538 .40752 L p F P
0 g
s
.77 .917 .539 r
.62363 .2767 m .62758 .27004 L .62556 .27531 L p F P
0 g
s
.77 .917 .539 r
.62163 .28132 m .62363 .2767 L p .62556 .27531 L F P
0 g
s
.77 .917 .539 r
.62556 .27531 m .62202 .28089 L .62163 .28132 L p F P
0 g
s
0 .021 .563 r
.82695 .18348 m .82642 .18832 L .82425 .1837 L p F P
0 g
s
0 .021 .563 r
.82425 .1837 m .82473 .17888 L .82695 .18348 L p F P
0 g
s
.723 .902 .959 r
.66037 .39927 m .65854 .40021 L .65975 .3989 L closepath p F P
0 g
s
.722 .886 .956 r
.65749 .39747 m .65975 .3989 L .65854 .40021 L p F P
0 g
s
.722 .886 .956 r
.64547 .4034 m .65749 .39747 L p .65854 .40021 L F P
0 g
s
.762 .934 .942 r
.6949 .3823 m .68717 .3871 L .68437 .38576 L p F P
0 g
s
.912 .98 .718 r
.64238 .24729 m .6408 .24964 L .64128 .24765 L closepath p F P
0 g
s
0 0 .08 r
.59354 .3334 m .59301 .3357 L .59441 .33224 L closepath p F P
0 g
s
.856 .997 .791 r
.78233 .30954 m .7805 .3116 L .77823 .31674 L p F P
0 g
s
.855 .997 .813 r
.77325 .31936 m .7805 .3116 L .77823 .31674 L p F P
0 g
s
.855 .997 .813 r
.77203 .32223 m .77325 .31936 L p .77823 .31674 L F P
0 g
s
.855 .997 .813 r
.77823 .31674 m .77313 .32222 L .77203 .32223 L p F P
0 g
s
.805 .979 .898 r
.73767 .35458 m .73295 .35833 L .73557 .35405 L closepath p F P
0 g
s
.801 .972 .907 r
.73502 .35387 m .73557 .35405 L .73295 .35833 L p F P
0 g
s
.801 .972 .907 r
.72417 .3622 m .73502 .35387 L p .73295 .35833 L F P
0 g
s
.801 .972 .907 r
.72359 .3632 m .72417 .3622 L p .73295 .35833 L F P
0 g
s
.895 .742 .684 r
.21157 .39141 m .21298 .38833 L .21703 .39164 L p F P
0 g
s
.895 .742 .684 r
.21703 .39164 m .21518 .3956 L .21157 .39141 L p F P
0 g
s
.675 .83 .958 r
.63052 .40668 m .61851 .41151 L .61552 .40875 L p F P
0 g
s
.659 .806 .953 r
.60351 .41283 m .61552 .40875 L .61851 .41151 L p F P
0 g
s
.856 .963 .631 r
.80533 .27915 m .80314 .28258 L .80411 .27991 L closepath p F P
0 g
s
.674 .744 .903 r
.76054 .13931 m .77281 .13471 L .77557 .13867 L p F P
0 g
s
.684 .752 .903 r
.77281 .13471 m .76054 .13931 L .75778 .13573 L p F P
0 g
s
.047 0 .298 r
.58431 .35257 m .58324 .35661 L .58399 .35579 L closepath p F P
0 g
s
.736 .905 .953 r
.66951 .39108 m .67236 .3927 L .66037 .39927 L p F P
0 g
s
.736 .905 .953 r
.66336 .39439 m .66951 .39108 L p .66037 .39927 L F P
0 g
s
.736 .905 .953 r
.66037 .39927 m .65975 .3989 L .66336 .39439 L p F P
0 g
s
.582 .615 .85 r
.58023 .40813 m .58402 .40506 L .58538 .40752 L closepath p F P
0 g
s
.61 .688 .899 r
.7891 .13779 m .78863 .14086 L p .77557 .13867 L F P
0 g
s
.61 .688 .899 r
.77557 .13867 m .78801 .13606 L .7891 .13779 L p F P
0 g
s
.622 .7 .901 r
.78801 .13606 m .77557 .13867 L .77281 .13471 L p F P
0 g
s
.644 .78 .946 r
.61552 .40875 m .60351 .41283 L .60047 .40933 L p F P
0 g
s
.815 .979 .892 r
.74393 .34942 m .73767 .35458 L .73557 .35405 L p F P
0 g
s
.901 .97 .814 r
.66287 .21642 m .66284 .21642 L .66288 .21637 L closepath p F P
0 g
s
.901 .97 .815 r
.66004 .21597 m .66379 .21136 L .66288 .21637 L p F P
0 g
s
.901 .97 .815 r
.66288 .21637 m .66284 .21642 L .66004 .21597 L p F P
0 g
s
.324 .45 .833 r
.81205 .15758 m .81229 .15769 L .81228 .15806 L closepath p F P
0 g
s
.221 .368 .8 r
.81797 .16109 m .81229 .15769 L .81228 .15806 L p F P
0 g
s
.221 .368 .8 r
.81775 .16587 m .81797 .16109 L p .81228 .15806 L F P
0 g
s
.923 .966 .778 r
.65747 .22348 m .66284 .21642 L .66004 .21597 L p F P
0 g
s
.845 .998 .819 r
.77313 .32222 m .77092 .32451 L .77203 .32223 L closepath p F P
0 g
s
0 0 .188 r
.8276 .21169 m .82726 .21338 L .8272 .20803 L p F P
0 g
s
0 0 .188 r
.8272 .20803 m .82743 .20685 L .8276 .21169 L p F P
0 g
s
.911 .978 .706 r
.63762 .25138 m .63625 .25648 L .6408 .24964 L p F P
0 g
s
.911 .978 .706 r
.63958 .24829 m .63762 .25138 L p .6408 .24964 L F P
0 g
s
.911 .978 .706 r
.6408 .24964 m .64128 .24765 L .63958 .24829 L p F P
0 g
s
.7 .724 .205 r
.82262 .23824 m .82203 .24039 L .82227 .23945 L closepath p F P
0 g
s
.042 .165 .668 r
.82519 .17404 m .82473 .17888 L .82163 .17458 L p F P
0 g
s
.042 .165 .668 r
.82163 .17458 m .822 .16977 L .82519 .17404 L p F P
0 g
s
.293 .176 .544 r
.57755 .37927 m .57636 .38042 L .57583 .3745 L p F P
0 g
s
.293 .176 .544 r
.57583 .3745 m .57608 .37425 L .57755 .37927 L p F P
0 g
s
.842 .993 .847 r
.76524 .32737 m .76284 .33253 L .77092 .32451 L p F P
0 g
s
.842 .993 .847 r
.7706 .32207 m .76524 .32737 L p .77092 .32451 L F P
0 g
s
.842 .993 .847 r
.77092 .32451 m .77203 .32223 L .7706 .32207 L p F P
0 g
s
.341 .47 .844 r
.81229 .15769 m .81205 .15758 L .80919 .15173 L p F P
0 g
s
.818 .986 .881 r
.74954 .34462 m .74393 .34942 L .74693 .3441 L closepath p F P
0 g
s
.815 .979 .892 r
.74693 .3441 m .74693 .3441 L .74393 .34942 L p F P
0 g
s
.815 .979 .892 r
.73615 .35297 m .74693 .3441 L p .74393 .34942 L F P
0 g
s
.815 .979 .892 r
.73557 .35405 m .73615 .35297 L p .74393 .34942 L F P
0 g
s
.849 .91 .504 r
.8141 .2592 m .81718 .25278 L .81588 .25772 L p F P
0 g
s
.849 .91 .504 r
.81332 .26221 m .8141 .2592 L p .81588 .25772 L F P
0 g
s
.849 .91 .504 r
.81588 .25772 m .81418 .26124 L .81332 .26221 L p F P
0 g
s
.341 .47 .844 r
.80919 .15173 m .81229 .15296 L .81229 .15769 L p F P
0 g
s
.269 .403 .814 r
.81818 .15629 m .81797 .16109 L .81229 .15769 L p F P
0 g
s
.269 .403 .814 r
.81229 .15769 m .81229 .15296 L .81818 .15629 L p F P
0 g
s
.272 .156 .533 r
.58378 .37288 m .57755 .37927 L .57608 .37425 L p F P
0 g
s
.272 .156 .533 r
.57608 .37425 m .58249 .36779 L .58378 .37288 L p F P
0 g
s
0 0 0 r
.60278 .31592 m .60174 .31875 L .60418 .31374 L closepath p F P
0 g
s
.828 .986 .875 r
.75383 .34084 m .74954 .34462 L .74693 .3441 L p F P
0 g
s
.872 .982 .695 r
.80008 .28453 m .79831 .28957 L .80314 .28258 L p F P
0 g
s
.872 .982 .695 r
.80299 .28032 m .80008 .28453 L p .80314 .28258 L F P
0 g
s
.872 .982 .695 r
.80314 .28258 m .80411 .27991 L .80299 .28032 L p F P
0 g
s
.842 .989 .858 r
.75879 .33351 m .76524 .32737 L .76284 .33253 L p F P
0 g
s
.842 .989 .858 r
.76284 .33253 m .76137 .33392 L .75879 .33351 L p F P
0 g
s
.164 .293 .751 r
.82235 .16495 m .822 .16977 L .81775 .16587 L p F P
0 g
s
.164 .293 .751 r
.81775 .16587 m .81797 .16109 L .82235 .16495 L p F P
0 g
s
.832 .99 .863 r
.75383 .34084 m .76137 .33392 L .75879 .33351 L p F P
0 g
s
.832 .99 .863 r
.75879 .33351 m .75652 .3356 L .75383 .34084 L p F P
0 g
s
.828 .986 .875 r
.74694 .3441 m .75652 .3356 L .75383 .34084 L p F P
0 g
s
.828 .986 .875 r
.74693 .3441 m .74694 .3441 L p .75383 .34084 L F P
0 g
s
.585 .674 .901 r
.78863 .14086 m .7891 .13779 L .79079 .14053 L closepath p F P
0 g
s
.555 .728 .955 r
.15835 .40825 m .16943 .40658 L .17316 .40999 L p F P
0 g
s
.92 .727 .624 r
.20908 .38495 m .21298 .38833 L .21483 .38238 L p F P
0 g
s
.92 .727 .624 r
.21483 .38238 m .21092 .37901 L .20908 .38495 L p F P
0 g
s
.807 .924 .543 r
.62202 .28089 m .62133 .28205 L .62163 .28132 L closepath p F P
0 g
s
.764 .946 .938 r
.69915 .37958 m .6949 .3823 L .69747 .37886 L closepath p F P
0 g
s
.762 .934 .942 r
.69638 .37833 m .69747 .37886 L .6949 .3823 L p F P
0 g
s
.762 .934 .942 r
.68437 .38576 m .69638 .37833 L p .6949 .3823 L F P
0 g
s
0 0 0 r
.60734 .30817 m .60418 .31374 L .60752 .30726 L p F P
0 g
s
0 0 0 r
.60752 .30726 m .61036 .30178 L .60734 .30817 L p F P
0 g
s
.731 .895 .954 r
.65975 .3989 m .65749 .39747 L .66336 .39439 L closepath p F P
0 g
s
0 0 .101 r
.59621 .33259 m .5985 .32642 L .59441 .33224 L p F P
0 g
s
0 0 .101 r
.59261 .33757 m .59621 .33259 L p .59441 .33224 L F P
0 g
s
0 0 .101 r
.59441 .33224 m .59301 .3357 L .59261 .33757 L p F P
0 g
s
.727 .807 .914 r
.75088 .1393 m .74565 .14198 L .74288 .13875 L p F P
0 g
s
.767 .818 .893 r
.73085 .14645 m .74288 .13875 L .74565 .14198 L p F P
0 g
s
0 0 0 r
.82566 .22468 m .82466 .22958 L .82571 .22385 L p F P
0 g
s
0 0 0 r
.82571 .22385 m .82673 .21893 L .82566 .22468 L p F P
0 g
s
.779 .816 .338 r
.82094 .24229 m .81983 .24651 L .82203 .24039 L p F P
0 g
s
.779 .816 .338 r
.82203 .24039 m .82227 .23945 L .82094 .24229 L p F P
0 g
s
.794 .91 .515 r
.6195 .28388 m .61758 .28865 L .62133 .28205 L p F P
0 g
s
.794 .91 .515 r
.62133 .28205 m .62163 .28132 L .6195 .28388 L p F P
0 g
s
.445 .387 .699 r
.5737 .39039 m .5775 .38705 L .57908 .39315 L closepath p F P
0 g
s
.862 .752 .74 r
.2134 .39818 m .21518 .3956 L .21157 .39141 L p F P
0 g
s
.827 .886 .886 r
.70713 .16529 m .70702 .1652 L .70715 .1651 L closepath p F P
0 g
s
.635 .793 .349 r
.61215 .29855 m .61047 .30156 L .61392 .29523 L closepath p F P
0 g
s
0 0 .151 r
.82804 .20851 m .8276 .21169 L .82743 .20685 L p F P
0 g
s
0 0 .151 r
.82743 .20685 m .82794 .20317 L .82804 .20851 L p F P
0 g
s
.923 .966 .778 r
.66004 .21597 m .65814 .21856 L .65747 .22348 L p F P
0 g
s
.924 .966 .776 r
.653 .22559 m .65195 .23063 L .65747 .22348 L p F P
0 g
s
.924 .966 .776 r
.65747 .22348 m .65814 .21856 L .653 .22559 L p F P
0 g
s
.827 .886 .886 r
.70715 .1651 m .70702 .1652 L .70424 .16292 L p F P
0 g
s
.861 .903 .861 r
.69832 .17334 m .70702 .1652 L .70424 .16292 L p F P
0 g
s
.831 .865 .871 r
.70739 .16023 m .70715 .1651 L .71778 .15624 L p F P
0 g
s
.827 .886 .886 r
.70424 .16292 m .70739 .16023 L .70715 .1651 L p F P
0 g
s
.861 .903 .861 r
.70424 .16292 m .69844 .16853 L .69832 .17334 L p F P
0 g
s
.852 .907 .872 r
.69241 .17426 m .69844 .16853 L .69832 .17334 L p F P
0 g
s
.852 .907 .872 r
.69832 .17334 m .69521 .1762 L .69241 .17426 L p F P
0 g
s
.882 .912 .844 r
.69027 .18133 m .69521 .1762 L .69241 .17426 L p F P
0 g
s
.775 .947 .933 r
.71066 .37191 m .69915 .37958 L .69747 .37886 L p F P
0 g
s
.834 .91 .505 r
.81418 .26124 m .81272 .26416 L .81332 .26221 L closepath p F P
0 g
s
.942 .71 .56 r
.20716 .37556 m .21092 .37901 L .21192 .37335 L p F P
0 g
s
.942 .71 .56 r
.21192 .37335 m .20817 .3699 L .20716 .37556 L p F P
0 g
s
.109 0 .372 r
.58377 .36084 m .58241 .36234 L .58324 .35661 L p F P
0 g
s
.109 0 .372 r
.58324 .35661 m .58399 .35579 L .58377 .36084 L p F P
0 g
s
.513 .601 .879 r
.80409 .14189 m .8038 .14577 L p .79079 .14053 L F P
0 g
s
.513 .601 .879 r
.79079 .14053 m .80351 .14083 L .80409 .14189 L p F P
0 g
s
.498 .629 .91 r
.7891 .13779 m .79079 .14053 L .80351 .14083 L p F P
0 g
s
.906 .983 .773 r
.65171 .23157 m .6512 .23161 L .65195 .23063 L closepath p F P
0 g
s
.9 .972 .668 r
.6334 .25813 m .63168 .26333 L .63625 .25648 L p F P
0 g
s
.9 .972 .668 r
.63625 .25648 m .63762 .25138 L .6334 .25813 L p F P
0 g
s
.862 .752 .74 r
.21157 .39141 m .20922 .39492 L .2134 .39818 L p F P
0 g
s
.823 .765 .797 r
.20174 .40273 m .20577 .40604 L .2134 .39818 L p F P
0 g
s
.823 .765 .797 r
.2134 .39818 m .20922 .39492 L .20174 .40273 L p F P
0 g
s
.714 .883 .959 r
.65749 .39747 m .64547 .4034 L .64255 .40137 L p F P
0 g
s
0 0 .296 r
.82855 .19834 m .82794 .20317 L .82723 .19804 L p F P
0 g
s
0 0 .296 r
.82723 .19804 m .82783 .19321 L .82855 .19834 L p F P
0 g
s
.882 .912 .844 r
.69241 .17426 m .69027 .17656 L .69027 .18133 L p F P
0 g
s
.874 .926 .856 r
.68298 .1843 m .69027 .17656 L .69027 .18133 L p F P
0 g
s
.874 .926 .856 r
.68266 .18783 m .68298 .1843 L p .69027 .18133 L F P
0 g
s
.874 .926 .856 r
.69027 .18133 m .68344 .18827 L .68266 .18783 L p F P
0 g
s
.778 .906 .512 r
.61972 .28336 m .6195 .28388 L .62163 .28132 L p F P
0 g
s
.778 .906 .512 r
.62163 .28132 m .62363 .2767 L .61972 .28336 L p F P
0 g
s
.827 .863 .873 r
.7189 .1553 m .71778 .15624 L .71759 .15405 L closepath p F P
0 g
s
.831 .865 .871 r
.71612 .15266 m .70739 .16023 L p .71778 .15624 L F P
0 g
s
.831 .865 .871 r
.71778 .15624 m .71759 .15405 L .71612 .15266 L p F P
0 g
s
.802 .861 .893 r
.73059 .14664 m .7189 .1553 L .71759 .15405 L p F P
0 g
s
.877 .987 .72 r
.7948 .29167 m .80008 .28453 L .79831 .28957 L p F P
0 g
s
.877 .987 .72 r
.79344 .29567 m .7948 .29167 L p .79831 .28957 L F P
0 g
s
.877 .987 .72 r
.79831 .28957 m .79393 .29552 L .79344 .29567 L p F P
0 g
s
.79 .776 .84 r
.20577 .40604 m .20324 .40806 L .19957 .4045 L p F P
0 g
s
.715 .766 .892 r
.18811 .41024 m .19957 .4045 L .20324 .40806 L p F P
0 g
s
.81 .823 .346 r
.82109 .24155 m .82094 .24229 L .82227 .23945 L p F P
0 g
s
.81 .823 .346 r
.82227 .23945 m .82311 .23549 L .82109 .24155 L p F P
0 g
s
0 0 .089 r
.59301 .3357 m .59193 .33847 L .59261 .33757 L closepath p F P
0 g
s
.737 .803 .904 r
.75088 .1393 m .75778 .13573 L .75501 .13219 L p F P
0 g
s
.737 .803 .904 r
.75501 .13219 m .75061 .13458 L .75088 .1393 L p F P
0 g
s
.727 .807 .914 r
.74288 .13875 m .75061 .13458 L .75088 .1393 L p F P
0 g
s
.628 .751 .936 r
.17316 .40999 m .1844 .40682 L .18811 .41024 L p F P
0 g
s
.629 .752 .936 r
.1844 .40682 m .17316 .40999 L .16943 .40658 L p F P
0 g
s
.897 .983 .715 r
.64128 .24765 m .63958 .24829 L .6422 .24452 L closepath p F P
0 g
s
.598 .701 .916 r
.58538 .40752 m .59742 .40531 L .60047 .40933 L p F P
0 g
s
.604 .626 .846 r
.58402 .40506 m .58538 .40752 L .59742 .40531 L p F P
0 g
s
.851 .964 .634 r
.63131 .26431 m .63079 .26469 L .63168 .26333 L closepath p F P
0 g
s
.894 .921 .832 r
.68344 .18827 m .68266 .18916 L .68266 .18783 L closepath p F P
0 g
s
.79 .776 .84 r
.19957 .4045 m .20174 .40273 L .20577 .40604 L p F P
0 g
s
.748 .913 .948 r
.68091 .3878 m .67236 .3927 L .66951 .39108 L p F P
0 g
s
.897 .923 .828 r
.67635 .19182 m .67605 .19666 L .68266 .18916 L p F P
0 g
s
.897 .923 .828 r
.68064 .18676 m .67635 .19182 L p .68266 .18916 L F P
0 g
s
.897 .923 .828 r
.68266 .18916 m .68266 .18783 L .68064 .18676 L p F P
0 g
s
.866 .949 .592 r
.81049 .2658 m .80897 .27079 L .81272 .26416 L p F P
0 g
s
.866 .949 .592 r
.81193 .26323 m .81049 .2658 L p .81272 .26416 L F P
0 g
s
.866 .949 .592 r
.81272 .26416 m .81332 .26221 L .81193 .26323 L p F P
0 g
s
.078 0 .362 r
.58778 .35617 m .58377 .36084 L .58399 .35579 L p F P
0 g
s
.078 0 .362 r
.58399 .35579 m .58855 .35045 L .58778 .35617 L p F P
0 g
s
.907 .982 .775 r
.64839 .23182 m .653 .22559 L .65195 .23063 L p F P
0 g
s
.907 .982 .775 r
.65195 .23063 m .6512 .23161 L .64839 .23182 L p F P
0 g
s
.856 .992 .837 r
.77203 .32223 m .7706 .32207 L .77325 .31936 L closepath p F P
0 g
s
.928 .972 .739 r
.64705 .23758 m .6512 .23161 L .64839 .23182 L p F P
0 g
s
.717 .769 .893 r
.19957 .4045 m .18811 .41024 L .1844 .40682 L p F P
0 g
s
.361 .488 .852 r
.81229 .15296 m .80919 .15173 L .80634 .14615 L p F P
0 g
s
0 0 0 r
.60451 .31451 m .60734 .30817 L .60418 .31374 L p F P
0 g
s
0 0 0 r
.60145 .31956 m .60451 .31451 L p .60418 .31374 L F P
0 g
s
0 0 0 r
.60418 .31374 m .60174 .31875 L .60145 .31956 L p F P
0 g
s
.362 .277 .625 r
.581 .38369 m .5775 .38705 L .57636 .38042 L p F P
0 g
s
.362 .277 .625 r
.57636 .38042 m .57755 .37927 L .581 .38369 L p F P
0 g
s
.779 .891 .48 r
.61631 .28987 m .61392 .29523 L .61758 .28865 L p F P
0 g
s
.779 .891 .48 r
.61922 .28425 m .61631 .28987 L p .61758 .28865 L F P
0 g
s
.779 .891 .48 r
.61758 .28865 m .6195 .28388 L .61922 .28425 L p F P
0 g
s
.866 .989 .726 r
.79393 .29552 m .79304 .29669 L .79344 .29567 L closepath p F P
0 g
s
.778 .957 .928 r
.71112 .37159 m .71066 .37191 L .71093 .37152 L closepath p F P
0 g
s
.775 .947 .933 r
.70838 .37038 m .71093 .37152 L .71066 .37191 L p F P
0 g
s
.775 .947 .933 r
.69886 .37673 m .70838 .37038 L p .71066 .37191 L F P
0 g
s
.775 .947 .933 r
.69747 .37886 m .69886 .37673 L p .71066 .37191 L F P
0 g
s
.793 .958 .92 r
.72037 .36193 m .72308 .36301 L .71112 .37159 L p F P
0 g
s
.793 .958 .92 r
.71393 .36653 m .72037 .36193 L p .71112 .37159 L F P
0 g
s
.793 .958 .92 r
.71112 .37159 m .71093 .37152 L .71393 .36653 L p F P
0 g
s
0 0 .028 r
.82732 .21593 m .82673 .21893 L .82726 .21338 L p F P
0 g
s
0 0 .028 r
.82726 .21338 m .8276 .21169 L .82732 .21593 L p F P
0 g
s
.802 .861 .893 r
.72807 .14353 m .73053 .14612 L .73059 .14664 L p F P
0 g
s
.802 .861 .893 r
.71769 .15147 m .72807 .14353 L p .73059 .14664 L F P
0 g
s
.802 .861 .893 r
.71759 .15405 m .71769 .15147 L p .73059 .14664 L F P
0 g
s
.801 .842 .882 r
.73085 .14645 m .73059 .14664 L .73053 .14612 L closepath p F P
0 g
s
0 0 .165 r
.59188 .34199 m .58998 .34453 L .59193 .33847 L p F P
0 g
s
0 0 .165 r
.59193 .33847 m .59261 .33757 L .59188 .34199 L p F P
0 g
s
.701 .837 .947 r
.63807 .40337 m .63052 .40668 L .62756 .40416 L p F P
0 g
s
.675 .83 .958 r
.61552 .40875 m .62756 .40416 L .63052 .40668 L p F P
0 g
s
.893 .946 .836 r
.66993 .19927 m .67635 .19182 L .67605 .19666 L p F P
0 g
s
.893 .946 .836 r
.66976 .20075 m .66993 .19927 L p .67605 .19666 L F P
0 g
s
.893 .946 .836 r
.67605 .19666 m .67173 .20151 L .66976 .20075 L p F P
0 g
s
.773 .838 .901 r
.7401 .13552 m .74288 .13875 L .73085 .14645 L p F P
0 g
s
.773 .838 .901 r
.7307 .1418 m .7401 .13552 L p .73085 .14645 L F P
0 g
s
.773 .838 .901 r
.73085 .14645 m .73053 .14612 L .7307 .1418 L p F P
0 g
s
0 0 .439 r
.82838 .18837 m .82783 .19321 L .82642 .18832 L p F P
0 g
s
0 0 .439 r
.82642 .18832 m .82695 .18348 L .82838 .18837 L p F P
0 g
s
.87 .995 .772 r
.78895 .299 m .78701 .30407 L .79304 .29669 L p F P
0 g
s
.87 .995 .772 r
.79149 .29588 m .78895 .299 L p .79304 .29669 L F P
0 g
s
.87 .995 .772 r
.79304 .29669 m .79344 .29567 L .79149 .29588 L p F P
0 g
s
.851 .964 .634 r
.62917 .26488 m .6334 .25813 L .63168 .26333 L p F P
0 g
s
.851 .964 .634 r
.62871 .26623 m .62917 .26488 L p .63168 .26333 L F P
0 g
s
.851 .964 .634 r
.63168 .26333 m .63079 .26469 L .62871 .26623 L p F P
0 g
s
.552 .571 .827 r
.58226 .40144 m .5883 .40127 L .58402 .40506 L closepath p F P
0 g
s
.604 .626 .846 r
.59433 .40064 m .5883 .40127 L .58402 .40506 L p F P
0 g
s
.604 .626 .846 r
.59742 .40531 m .59433 .40064 L p .58402 .40506 L F P
0 g
s
.888 .979 .686 r
.80411 .27991 m .80299 .28032 L .80484 .27756 L closepath p F P
0 g
s
.901 .748 .682 r
.20793 .3875 m .20908 .38495 L .21298 .38833 L p F P
0 g
s
.901 .748 .682 r
.21298 .38833 m .21157 .39141 L .20793 .3875 L p F P
0 g
s
.837 .886 .456 r
.81843 .24784 m .81718 .25278 L .81983 .24651 L p F P
0 g
s
.837 .886 .456 r
.82061 .24272 m .81843 .24784 L p .81983 .24651 L F P
0 g
s
.837 .886 .456 r
.81983 .24651 m .82094 .24229 L .82061 .24272 L p F P
0 g
s
.799 .961 .915 r
.72359 .3632 m .72308 .36301 L .72417 .3622 L closepath p F P
0 g
s
.786 .947 .927 r
.71093 .37152 m .70838 .37038 L .71393 .36653 L closepath p F P
0 g
s
.881 .962 .628 r
.63079 .26469 m .62758 .27004 L .62871 .26623 L closepath p F P
0 g
s
.76 .759 .248 r
.82407 .2306 m .82311 .23549 L .82466 .22958 L p F P
0 g
s
.76 .759 .248 r
.82466 .22958 m .82566 .22468 L .82407 .2306 L p F P
0 g
s
.633 .711 .902 r
.78523 .13171 m .77281 .13471 L .77004 .13081 L p F P
0 g
s
.684 .752 .903 r
.75778 .13573 m .77004 .13081 L .77281 .13471 L p F P
0 g
s
.622 .7 .901 r
.77281 .13471 m .78523 .13171 L .78801 .13606 L p F P
0 g
s
.544 .657 .909 r
.78801 .13606 m .78888 .136 L .7891 .13779 L closepath p F P
0 g
s
.498 .629 .91 r
.80069 .13579 m .78888 .136 L .7891 .13779 L p F P
0 g
s
.498 .629 .91 r
.80351 .14083 m .80069 .13579 L p .7891 .13779 L F P
0 g
s
.88 .928 .849 r
.68266 .18783 m .68064 .18676 L .68298 .1843 L closepath p F P
0 g
s
.776 .84 .9 r
.73053 .14612 m .72807 .14353 L .7307 .1418 L closepath p F P
0 g
s
.912 .938 .812 r
.67173 .20151 m .66963 .20411 L .66976 .20075 L closepath p F P
0 g
s
.644 .78 .946 r
.60047 .40933 m .61251 .40568 L .61552 .40875 L p F P
0 g
s
.625 .749 .936 r
.61251 .40568 m .60047 .40933 L .59742 .40531 L p F P
0 g
s
.693 .759 .902 r
.77004 .13081 m .75778 .13573 L .75501 .13219 L p F P
0 g
s
.664 .811 .954 r
.62756 .40416 m .61552 .40875 L .61251 .40568 L p F P
0 g
s
.75 .927 .948 r
.68437 .38576 m .68091 .3878 L .68304 .38508 L closepath p F P
0 g
s
.748 .913 .948 r
.68155 .38425 m .68304 .38508 L .68091 .3878 L p F P
0 g
s
.748 .913 .948 r
.66951 .39108 m .68155 .38425 L p .68091 .3878 L F P
0 g
s
.928 .972 .739 r
.64839 .23182 m .64784 .23264 L .64705 .23758 L p F P
0 g
s
.929 .972 .731 r
.64333 .23947 m .6422 .24452 L .64705 .23758 L p F P
0 g
s
.929 .972 .731 r
.64705 .23758 m .64784 .23264 L .64333 .23947 L p F P
0 g
s
.455 .561 .873 r
.8038 .14577 m .80409 .14189 L .80634 .14615 L closepath p F P
0 g
s
.806 .864 .891 r
.71759 .15405 m .71612 .15266 L .71769 .15147 L closepath p F P
0 g
s
.915 .94 .806 r
.66427 .20647 m .66379 .21136 L .66963 .20411 L p F P
0 g
s
.915 .94 .806 r
.66891 .20045 m .66427 .20647 L p .66963 .20411 L F P
0 g
s
.915 .94 .806 r
.66963 .20411 m .66976 .20075 L .66891 .20045 L p F P
0 g
s
0 0 .158 r
.59432 .33865 m .59188 .34199 L .59261 .33757 L p F P
0 g
s
0 0 .158 r
.59261 .33757 m .59621 .33259 L .59432 .33865 L p F P
0 g
s
.882 .967 .645 r
.80628 .2726 m .80484 .27756 L .80897 .27079 L p F P
0 g
s
.882 .967 .645 r
.80897 .27079 m .81049 .2658 L .80628 .2726 L p F P
0 g
s
.325 .239 .603 r
.58559 .37889 m .581 .38369 L .57755 .37927 L p F P
0 g
s
.325 .239 .603 r
.58478 .37456 m .58559 .37889 L p .57755 .37927 L F P
0 g
s
.325 .239 .603 r
.57755 .37927 m .58378 .37288 L .58478 .37456 L p F P
0 g
s
.871 .995 .789 r
.78249 .30653 m .78895 .299 L .78701 .30407 L p F P
0 g
s
.871 .995 .789 r
.78136 .30959 m .78249 .30653 L p .78701 .30407 L F P
0 g
s
.871 .995 .789 r
.78701 .30407 m .78233 .30954 L .78136 .30959 L p F P
0 g
s
0 .026 .567 r
.82745 .17864 m .82695 .18348 L .82473 .17888 L p F P
0 g
s
0 .026 .567 r
.82473 .17888 m .82519 .17404 L .82745 .17864 L p F P
0 g
s
.885 .991 .761 r
.79344 .29567 m .79149 .29588 L .7948 .29167 L closepath p F P
0 g
s
.812 .969 .903 r
.73557 .35405 m .73502 .35387 L .73615 .35297 L closepath p F P
0 g
s
.884 .946 .586 r
.81332 .26221 m .81193 .26323 L .8141 .2592 L closepath p F P
0 g
s
.174 .042 .45 r
.58387 .36627 m .58249 .36779 L .58241 .36234 L p F P
0 g
s
.174 .042 .45 r
.58241 .36234 m .58377 .36084 L .58387 .36627 L p F P
0 g
s
0 0 0 r
.60174 .31875 m .60109 .32015 L .60145 .31956 L closepath p F P
0 g
s
.927 .735 .624 r
.20532 .38151 m .20908 .38495 L .21092 .37901 L p F P
0 g
s
.927 .735 .624 r
.21092 .37901 m .20716 .37556 L .20532 .38151 L p F P
0 g
s
.801 .957 .916 r
.72417 .3622 m .72308 .36301 L .72037 .36193 L p F P
0 g
s
.869 .76 .74 r
.20922 .39492 m .21157 .39141 L .20793 .3875 L p F P
0 g
s
.558 .531 .781 r
.57959 .39475 m .58226 .40144 L .5883 .40127 L p F P
0 g
s
.805 .964 .91 r
.72417 .3622 m .73502 .35387 L .73234 .35292 L p F P
0 g
s
.805 .964 .91 r
.73234 .35292 m .72714 .3569 L .72417 .3622 L p F P
0 g
s
.801 .957 .916 r
.72037 .36193 m .72714 .3569 L .72417 .3622 L p F P
0 g
s
.764 .929 .941 r
.69358 .3769 m .69638 .37833 L .68437 .38576 L p F P
0 g
s
.764 .929 .941 r
.68499 .38218 m .69358 .3769 L p .68437 .38576 L F P
0 g
s
.764 .929 .941 r
.68437 .38576 m .68304 .38508 L .68499 .38218 L p F P
0 g
s
.732 .887 .951 r
.66336 .39439 m .65749 .39747 L .65459 .39554 L p F P
0 g
s
.714 .883 .959 r
.64255 .40137 m .65459 .39554 L .65749 .39747 L p F P
0 g
s
.772 .936 .936 r
.69747 .37886 m .69638 .37833 L .69886 .37673 L closepath p F P
0 g
s
.485 .413 .7 r
.58728 .38725 m .581 .38369 L .5775 .38705 L p F P
0 g
s
.485 .413 .7 r
.58071 .39371 m .58728 .38725 L p .5775 .38705 L F P
0 g
s
.485 .413 .7 r
.5775 .38705 m .57908 .39315 L .58071 .39371 L p F P
0 g
s
.622 .784 .339 r
.61307 .29632 m .61631 .28987 L .61392 .29523 L p F P
0 g
s
.622 .784 .339 r
.61042 .30167 m .61307 .29632 L p .61392 .29523 L F P
0 g
s
.622 .784 .339 r
.61392 .29523 m .61047 .30156 L .61042 .30167 L p F P
0 g
s
0 0 0 r
.82759 .21405 m .82732 .21593 L .8276 .21169 L p F P
0 g
s
0 0 0 r
.8276 .21169 m .82804 .20851 L .82759 .21405 L p F P
0 g
s
0 0 0 r
.6003 .32344 m .5985 .32642 L .60109 .32015 L p F P
0 g
s
0 0 0 r
.60109 .32015 m .60145 .31956 L .6003 .32344 L p F P
0 g
s
.861 .997 .795 r
.78233 .30954 m .7805 .3116 L .78136 .30959 L closepath p F P
0 g
s
.876 .954 .607 r
.62537 .27151 m .62363 .2767 L .62758 .27004 L p F P
0 g
s
.876 .954 .607 r
.62799 .26682 m .62537 .27151 L p .62758 .27004 L F P
0 g
s
.876 .954 .607 r
.62758 .27004 m .62871 .26623 L .62799 .26682 L p F P
0 g
s
.557 .668 .911 r
.78888 .136 m .78801 .13606 L .78523 .13171 L p F P
0 g
s
0 0 .139 r
.82865 .20369 m .82804 .20851 L .82794 .20317 L p F P
0 g
s
0 0 .139 r
.82794 .20317 m .82855 .19834 L .82865 .20369 L p F P
0 g
s
.049 .174 .674 r
.82562 .1692 m .82519 .17404 L .822 .16977 L p F P
0 g
s
.049 .174 .674 r
.822 .16977 m .82235 .16495 L .82562 .1692 L p F P
0 g
s
.736 .811 .911 r
.75061 .13458 m .74288 .13875 L .7401 .13552 L p F P
0 g
s
.858 .994 .827 r
.77533 .31427 m .77325 .31936 L .7805 .3116 L p F P
0 g
s
.858 .994 .827 r
.77982 .30947 m .77533 .31427 L p .7805 .3116 L F P
0 g
s
.858 .994 .827 r
.7805 .3116 m .78136 .30959 L .77982 .30947 L p F P
0 g
s
.361 .488 .852 r
.80634 .14615 m .81228 .14822 L .81229 .15296 L p F P
0 g
s
.281 .415 .82 r
.81839 .15148 m .81818 .15629 L .81229 .15296 L p F P
0 g
s
.281 .415 .82 r
.81229 .15296 m .81228 .14822 L .81839 .15148 L p F P
0 g
s
.702 .86 .957 r
.64255 .40137 m .63807 .40337 L .64106 .40025 L closepath p F P
0 g
s
.701 .837 .947 r
.63961 .39911 m .64106 .40025 L .63807 .40337 L p F P
0 g
s
.701 .837 .947 r
.62756 .40416 m .63961 .39911 L p .63807 .40337 L F P
0 g
s
.908 .964 .808 r
.65865 .21367 m .66427 .20647 L .66379 .21136 L p F P
0 g
s
.908 .964 .808 r
.65836 .21567 m .65865 .21367 L p .66379 .21136 L F P
0 g
s
.908 .964 .808 r
.66379 .21136 m .66004 .21597 L .65836 .21567 L p F P
0 g
s
.828 .772 .799 r
.19784 .39936 m .20174 .40273 L .20922 .39492 L p F P
0 g
s
.828 .772 .799 r
.20922 .39492 m .20523 .39157 L .19784 .39936 L p F P
0 g
s
.869 .76 .74 r
.20793 .3875 m .20523 .39157 L .20922 .39492 L p F P
0 g
s
.175 .304 .757 r
.82269 .1602 m .82235 .16495 L .81797 .16109 L p F P
0 g
s
.175 .304 .757 r
.82264 .16005 m .82269 .1602 L p .81797 .16109 L F P
0 g
s
.175 .304 .757 r
.81797 .16109 m .81818 .15629 L .82264 .16005 L p F P
0 g
s
.557 .668 .911 r
.78523 .13171 m .78825 .13141 L .78888 .136 L p F P
0 g
s
.527 .625 .892 r
.79788 .13091 m .78825 .13141 L .78888 .136 L p F P
0 g
s
.527 .625 .892 r
.78888 .136 m .80069 .13579 L .79788 .13091 L p F P
0 g
s
.899 .983 .717 r
.63878 .24633 m .64333 .23947 L .6422 .24452 L p F P
0 g
s
.899 .983 .717 r
.63814 .24882 m .63878 .24633 L p .6422 .24452 L F P
0 g
s
.899 .983 .717 r
.6422 .24452 m .63958 .24829 L .63814 .24882 L p F P
0 g
s
.814 .966 .903 r
.73615 .35297 m .73502 .35387 L .73234 .35292 L p F P
0 g
s
.466 .431 .736 r
.57908 .39315 m .58071 .39371 L .57959 .39475 L closepath p F P
0 g
s
.558 .531 .781 r
.59122 .39493 m .58071 .39371 L .57959 .39475 L p F P
0 g
s
.558 .531 .781 r
.59242 .39729 m .59122 .39493 L p .57959 .39475 L F P
0 g
s
.558 .531 .781 r
.5883 .40127 m .59242 .39729 L p .57959 .39475 L F P
0 g
s
.869 .922 .529 r
.8153 .25428 m .8141 .2592 L .81718 .25278 L p F P
0 g
s
.869 .922 .529 r
.81718 .25278 m .81843 .24784 L .8153 .25428 L p F P
0 g
s
.819 .972 .896 r
.73615 .35297 m .74693 .3441 L .74428 .34327 L p F P
0 g
s
.819 .972 .896 r
.74428 .34327 m .73886 .34773 L .73615 .35297 L p F P
0 g
s
.814 .966 .903 r
.73234 .35292 m .73886 .34773 L .73615 .35297 L p F P
0 g
s
0 0 0 r
.60191 .32078 m .6003 .32344 L .60145 .31956 L p F P
0 g
s
0 0 0 r
.60145 .31956 m .60451 .31451 L .60191 .32078 L p F P
0 g
s
.343 .494 .865 r
.80409 .14189 m .80634 .14615 L .81228 .14822 L p F P
0 g
s
0 0 .24 r
.59137 .34668 m .58855 .35045 L .58998 .34453 L p F P
0 g
s
0 0 .24 r
.58998 .34453 m .59188 .34199 L .59137 .34668 L p F P
0 g
s
.857 .991 .838 r
.76805 .32177 m .77533 .31427 L .77325 .31936 L p F P
0 g
s
.857 .991 .838 r
.77325 .31936 m .7706 .32207 L .76805 .32177 L p F P
0 g
s
.794 .779 .839 r
.20174 .40273 m .19957 .4045 L .19588 .40098 L p F P
0 g
s
.717 .769 .893 r
.1844 .40682 m .19588 .40098 L .19957 .4045 L p F P
0 g
s
.889 .979 .688 r
.8017 .27952 m .80628 .2726 L .80484 .27756 L p F P
0 g
s
.889 .979 .688 r
.80129 .28093 m .8017 .27952 L p .80484 .27756 L F P
0 g
s
.889 .979 .688 r
.80484 .27756 m .80299 .28032 L .80129 .28093 L p F P
0 g
s
.926 .954 .784 r
.66004 .21597 m .65814 .21856 L .65836 .21567 L closepath p F P
0 g
s
.732 .887 .951 r
.66665 .38935 m .66721 .38971 L .66336 .39439 L p F P
0 g
s
.732 .887 .951 r
.65459 .39554 m .66665 .38935 L p .66336 .39439 L F P
0 g
s
.734 .905 .954 r
.66951 .39108 m .66336 .39439 L .66721 .38971 L closepath p F P
0 g
s
.794 .779 .839 r
.19588 .40098 m .19784 .39936 L .20174 .40273 L p F P
0 g
s
.848 .993 .843 r
.76524 .32737 m .7706 .32207 L .76805 .32177 L p F P
0 g
s
0 0 0 r
.82661 .21977 m .82566 .22468 L .82673 .21893 L p F P
0 g
s
0 0 0 r
.82669 .21933 m .82661 .21977 L p .82673 .21893 L F P
0 g
s
0 0 0 r
.82673 .21893 m .82732 .21593 L .82669 .21933 L p F P
0 g
s
.629 .752 .936 r
.16943 .40658 m .18068 .40338 L .1844 .40682 L p F P
0 g
s
.148 .024 .442 r
.58788 .36162 m .58387 .36627 L .58377 .36084 L p F P
0 g
s
.148 .024 .442 r
.58377 .36084 m .58778 .35617 L .58788 .36162 L p F P
0 g
s
.826 .976 .888 r
.74693 .3441 m .74693 .3441 L .74694 .3441 L closepath p F P
0 g
s
.828 .972 .89 r
.74694 .3441 m .74693 .3441 L .74428 .34327 L p F P
0 g
s
.829 .98 .883 r
.74938 .33893 m .74694 .3441 L .75652 .3356 L p F P
0 g
s
.828 .972 .89 r
.74428 .34327 m .74938 .33893 L .74694 .3441 L p F P
0 g
s
.833 .884 .879 r
.70739 .16023 m .70424 .16292 L .70144 .1606 L p F P
0 g
s
.865 .894 .853 r
.69844 .16853 m .70424 .16292 L .70144 .1606 L p F P
0 g
s
.848 .993 .843 r
.76805 .32177 m .76761 .3222 L .76524 .32737 L p F P
0 g
s
.845 .988 .858 r
.75892 .33043 m .76761 .3222 L .76524 .32737 L p F P
0 g
s
.845 .988 .858 r
.75766 .33332 m .75892 .33043 L p .76524 .32737 L F P
0 g
s
.845 .988 .858 r
.76524 .32737 m .75879 .33351 L .75766 .33332 L p F P
0 g
s
.827 .835 .365 r
.82202 .23669 m .82109 .24155 L .82311 .23549 L p F P
0 g
s
.827 .835 .365 r
.82311 .23549 m .82407 .2306 L .82202 .23669 L p F P
0 g
s
.921 .974 .702 r
.63958 .24829 m .63762 .25138 L .63814 .24882 L closepath p F P
0 g
s
.842 .881 .87 r
.70739 .16023 m .71612 .15266 L .71332 .15003 L p F P
0 g
s
.842 .881 .87 r
.71332 .15003 m .70726 .15547 L .70739 .16023 L p F P
0 g
s
.833 .884 .879 r
.70144 .1606 m .70726 .15547 L .70739 .16023 L p F P
0 g
s
.835 .989 .865 r
.75879 .33351 m .75652 .3356 L .75766 .33332 L closepath p F P
0 g
s
.829 .98 .883 r
.75619 .33292 m .74938 .33893 L p .75652 .3356 L F P
0 g
s
.829 .98 .883 r
.75652 .3356 m .75766 .33332 L .75619 .33292 L p F P
0 g
s
.865 .894 .853 r
.70144 .1606 m .69823 .16381 L .69844 .16853 L p F P
0 g
s
.858 .904 .865 r
.69005 .17185 m .69823 .16381 L .69844 .16853 L p F P
0 g
s
.858 .904 .865 r
.69003 .17258 m .69005 .17185 L p .69844 .16853 L F P
0 g
s
.858 .904 .865 r
.69844 .16853 m .69241 .17426 L .69003 .17258 L p F P
0 g
s
.713 .862 .953 r
.65168 .39348 m .65459 .39554 L .64255 .40137 L p F P
0 g
s
.713 .862 .953 r
.64331 .39741 m .65168 .39348 L p .64255 .40137 L F P
0 g
s
.713 .862 .953 r
.64255 .40137 m .64106 .40025 L .64331 .39741 L p F P
0 g
s
.929 .955 .777 r
.6536 .22068 m .653 .22559 L .65814 .21856 L p F P
0 g
s
.929 .955 .777 r
.65722 .2155 m .6536 .22068 L p .65814 .21856 L F P
0 g
s
.929 .955 .777 r
.65814 .21856 m .65836 .21567 L .65722 .2155 L p F P
0 g
s
.879 .981 .694 r
.80299 .28032 m .80008 .28453 L .80129 .28093 L closepath p F P
0 g
s
.879 .9 .841 r
.69241 .17426 m .69027 .17656 L .69003 .17258 L closepath p F P
0 g
s
.806 .863 .891 r
.71769 .15147 m .71612 .15266 L .71332 .15003 L p F P
0 g
s
.773 .931 .936 r
.69886 .37673 m .69638 .37833 L .69358 .3769 L p F P
0 g
s
.883 .902 .838 r
.6831 .17949 m .68298 .1843 L .69027 .17656 L p F P
0 g
s
.883 .902 .838 r
.68961 .17229 m .6831 .17949 L p .69027 .17656 L F P
0 g
s
.883 .902 .838 r
.69027 .17656 m .69003 .17258 L .68961 .17229 L p F P
0 g
s
.719 .773 .895 r
.19588 .40098 m .1844 .40682 L .18068 .40338 L p F P
0 g
s
.816 .864 .883 r
.71769 .15147 m .72807 .14353 L .72528 .1406 L p F P
0 g
s
.816 .864 .883 r
.72528 .1406 m .7176 .14669 L .71769 .15147 L p F P
0 g
s
.806 .863 .891 r
.71332 .15003 m .7176 .14669 L .71769 .15147 L p F P
0 g
s
.508 .516 .799 r
.58806 .38747 m .58728 .38725 L .58071 .39371 L p F P
0 g
s
.508 .516 .799 r
.58071 .39371 m .59122 .39493 L .58806 .38747 L p F P
0 g
s
0 0 .292 r
.82911 .1935 m .82855 .19834 L .82783 .19321 L p F P
0 g
s
0 0 .292 r
.82783 .19321 m .82838 .18837 L .82911 .1935 L p F P
0 g
s
0 0 0 r
.60885 .305 m .60734 .30817 L .61036 .30178 L p F P
0 g
s
.837 .926 .54 r
.62179 .27807 m .61972 .28336 L .62363 .2767 L p F P
0 g
s
.837 .926 .54 r
.62363 .2767 m .62537 .27151 L .62179 .27807 L p F P
0 g
s
0 0 0 r
.60997 .30275 m .60885 .305 L .61042 .30167 L p F P
0 g
s
0 0 0 r
.61042 .30167 m .61307 .29632 L .60997 .30275 L p F P
0 g
s
.745 .803 .899 r
.75061 .13458 m .75501 .13219 L .75223 .12867 L p F P
0 g
s
.745 .803 .899 r
.75223 .12867 m .74992 .12999 L .75061 .13458 L p F P
0 g
s
.736 .811 .911 r
.7401 .13552 m .74992 .12999 L .75061 .13458 L p F P
0 g
s
.757 .918 .944 r
.68304 .38508 m .68155 .38425 L .68499 .38218 L closepath p F P
0 g
s
.776 .94 .934 r
.69886 .37673 m .70838 .37038 L .70561 .36912 L p F P
0 g
s
.776 .94 .934 r
.70561 .36912 m .70234 .37128 L .69886 .37673 L p F P
0 g
s
.773 .931 .936 r
.69358 .3769 m .70234 .37128 L .69886 .37673 L p F P
0 g
s
.921 .972 .688 r
.63457 .25308 m .6334 .25813 L .63762 .25138 L p F P
0 g
s
.921 .972 .688 r
.63677 .2494 m .63457 .25308 L p .63762 .25138 L F P
0 g
s
.921 .972 .688 r
.63762 .25138 m .63814 .24882 L .63677 .2494 L p F P
0 g
s
.907 .754 .681 r
.20426 .38388 m .20532 .38151 L .20908 .38495 L p F P
0 g
s
.907 .754 .681 r
.20908 .38495 m .20793 .3875 L .20426 .38388 L p F P
0 g
s
0 0 0 r
.59928 .3275 m .59621 .33259 L .5985 .32642 L p F P
0 g
s
0 0 0 r
.5985 .32642 m .6003 .32344 L .59928 .3275 L p F P
0 g
s
.747 .907 .948 r
.67871 .38257 m .68155 .38425 L .66951 .39108 L p F P
0 g
s
.747 .907 .948 r
.66798 .38862 m .67871 .38257 L p .66951 .39108 L F P
0 g
s
.747 .907 .948 r
.66951 .39108 m .66721 .38971 L .66798 .38862 L p F P
0 g
s
.625 .749 .936 r
.59742 .40531 m .60948 .40225 L .61251 .40568 L p F P
0 g
s
.598 .711 .923 r
.60948 .40225 m .59742 .40531 L .59433 .40064 L p F P
0 g
s
.88 .925 .849 r
.67783 .18521 m .6831 .17949 L .68298 .1843 L p F P
0 g
s
.88 .925 .849 r
.68298 .1843 m .68064 .18676 L .67783 .18521 L p F P
0 g
s
.885 .99 .745 r
.79641 .28668 m .7948 .29167 L .80008 .28453 L p F P
0 g
s
.885 .99 .745 r
.80061 .28104 m .79641 .28668 L p .80008 .28453 L F P
0 g
s
.885 .99 .745 r
.80008 .28453 m .80129 .28093 L .80061 .28104 L p F P
0 g
s
.872 .991 .817 r
.78136 .30959 m .77982 .30947 L .78249 .30653 L closepath p F P
0 g
s
.907 .925 .817 r
.67635 .19182 m .68064 .18676 L .67783 .18521 L p F P
0 g
s
.633 .711 .902 r
.77004 .13081 m .78245 .12745 L .78523 .13171 L p F P
0 g
s
.644 .72 .904 r
.78245 .12745 m .77004 .13081 L .76726 .12697 L p F P
0 g
s
.693 .759 .902 r
.75501 .13219 m .76726 .12697 L .77004 .13081 L p F P
0 g
s
.9 .948 .827 r
.66976 .20075 m .66891 .20045 L .66993 .19927 L closepath p F P
0 g
s
.683 .835 .956 r
.63961 .39911 m .62756 .40416 L .62457 .40142 L p F P
0 g
s
.664 .811 .954 r
.61251 .40568 m .62457 .40142 L .62756 .40416 L p F P
0 g
s
.574 .62 .86 r
.5883 .40127 m .59242 .39729 L .59433 .40064 L closepath p F P
0 g
s
.887 .947 .589 r
.81176 .26087 m .8153 .25428 L .8141 .2592 L p F P
0 g
s
.887 .947 .589 r
.81105 .26387 m .81176 .26087 L p .8141 .2592 L F P
0 g
s
.887 .947 .589 r
.8141 .2592 m .81193 .26323 L .81105 .26387 L p F P
0 g
s
.776 .84 .9 r
.7307 .1418 m .72807 .14353 L .72528 .1406 L p F P
0 g
s
.245 .14 .531 r
.5844 .3722 m .58378 .37288 L .58249 .36779 L p F P
0 g
s
.245 .14 .531 r
.58249 .36779 m .58387 .36627 L .5844 .3722 L p F P
0 g
s
.916 .977 .769 r
.6487 .22765 m .6536 .22068 L .653 .22559 L p F P
0 g
s
.916 .977 .769 r
.64794 .23185 m .6487 .22765 L p .653 .22559 L F P
0 g
s
.916 .977 .769 r
.653 .22559 m .64839 .23182 L .64794 .23185 L p F P
0 g
s
.86 .886 .456 r
.82094 .24229 m .82061 .24272 L .82109 .24155 L closepath p F P
0 g
s
.702 .765 .902 r
.76726 .12697 m .75501 .13219 L .75223 .12867 L p F P
0 g
s
.343 .494 .865 r
.81226 .14346 m .80403 .14094 L .80409 .14189 L p F P
0 g
s
.343 .494 .865 r
.81228 .14822 m .81226 .14346 L p .80409 .14189 L F P
0 g
s
.42 .549 .879 r
.80351 .14083 m .80403 .14094 L .80409 .14189 L closepath p F P
0 g
s
.65 .788 .948 r
.62457 .40142 m .61251 .40568 L .60948 .40225 L p F P
0 g
s
.759 .886 .476 r
.6195 .28388 m .61922 .28425 L .61972 .28336 L closepath p F P
0 g
s
.786 .839 .893 r
.7307 .1418 m .7401 .13552 L .73732 .1323 L p F P
0 g
s
.786 .839 .893 r
.73732 .1323 m .73048 .13704 L .7307 .1418 L p F P
0 g
s
.776 .84 .9 r
.72528 .1406 m .73048 .13704 L .7307 .1418 L p F P
0 g
s
.875 .769 .742 r
.20523 .39157 m .20793 .3875 L .20426 .38388 L p F P
0 g
s
0 0 .44 r
.8289 .18352 m .82838 .18837 L .82695 .18348 L p F P
0 g
s
0 0 .44 r
.82695 .18348 m .82745 .17864 L .8289 .18352 L p F P
0 g
s
.907 .925 .817 r
.67783 .18521 m .67629 .18707 L .67635 .19182 L p F P
0 g
s
.906 .925 .817 r
.67026 .19441 m .66993 .19927 L .67635 .19182 L p F P
0 g
s
.906 .925 .817 r
.67635 .19182 m .67629 .18707 L .67026 .19441 L p F P
0 g
s
0 0 0 r
.82819 .20923 m .82759 .21405 L .82804 .20851 L p F P
0 g
s
0 0 0 r
.82804 .20851 m .82865 .20369 L .82819 .20923 L p F P
0 g
s
0 0 .326 r
.59113 .3517 m .58778 .35617 L .58855 .35045 L p F P
0 g
s
0 0 .326 r
.58855 .35045 m .59137 .34668 L .59113 .3517 L p F P
0 g
s
.787 .944 .927 r
.71393 .36653 m .70838 .37038 L .70561 .36912 L p F P
0 g
s
0 0 .235 r
.59292 .34456 m .59137 .34668 L .59188 .34199 L p F P
0 g
s
0 0 .235 r
.59188 .34199 m .59432 .33865 L .59292 .34456 L p F P
0 g
s
.435 .564 .886 r
.80403 .14094 m .80351 .14083 L .80069 .13579 L p F P
0 g
s
.418 .381 .711 r
.58779 .38672 m .58728 .38725 L .581 .38369 L p F P
0 g
s
.418 .381 .711 r
.581 .38369 m .58559 .37889 L .58779 .38672 L p F P
0 g
s
.757 .884 .473 r
.61828 .28462 m .62179 .27807 L .61972 .28336 L p F P
0 g
s
.757 .884 .473 r
.61748 .28661 m .61828 .28462 L p .61972 .28336 L F P
0 g
s
.757 .884 .473 r
.61972 .28336 m .61922 .28425 L .61748 .28661 L p F P
0 g
s
.863 .888 .459 r
.81953 .24292 m .82202 .23669 L .82109 .24155 L p F P
0 g
s
.863 .888 .459 r
.81921 .24461 m .81953 .24292 L p .82109 .24155 L F P
0 g
s
.863 .888 .459 r
.82109 .24155 m .82061 .24272 L .81921 .24461 L p F P
0 g
s
.57 .676 .911 r
.78825 .13141 m .78523 .13171 L .78245 .12745 L p F P
0 g
s
.886 .991 .763 r
.7907 .29397 m .79641 .28668 L .7948 .29167 L p F P
0 g
s
.886 .991 .763 r
.79005 .29603 m .7907 .29397 L p .7948 .29167 L F P
0 g
s
.886 .991 .763 r
.7948 .29167 m .79149 .29588 L .79005 .29603 L p F P
0 g
s
.908 .965 .648 r
.63066 .25974 m .62917 .26488 L .6334 .25813 L p F P
0 g
s
.908 .965 .648 r
.6334 .25813 m .63457 .25308 L .63066 .25974 L p F P
0 g
s
.709 .855 .952 r
.64106 .40025 m .63961 .39911 L .64331 .39741 L closepath p F P
0 g
s
.776 .773 .267 r
.82498 .22571 m .82407 .2306 L .82566 .22468 L p F P
0 g
s
.776 .773 .267 r
.82566 .22468 m .82661 .21977 L .82498 .22571 L p F P
0 g
s
.875 .949 .593 r
.81193 .26323 m .81049 .2658 L .81105 .26387 L closepath p F P
0 g
s
.842 .979 .873 r
.75766 .33332 m .75619 .33292 L .75892 .33043 L closepath p F P
0 g
s
.8 .896 .483 r
.61922 .28425 m .61631 .28987 L .61748 .28661 L closepath p F P
0 g
s
0 0 0 r
.60713 .3091 m .60451 .31451 L .60734 .30817 L p F P
0 g
s
0 0 0 r
.60771 .30771 m .60713 .3091 L p .60734 .30817 L F P
0 g
s
0 0 0 r
.60734 .30817 m .60885 .305 L .60771 .30771 L p F P
0 g
s
.381 .519 .871 r
.81226 .13868 m .81226 .14346 L .80403 .14094 L p F P
0 g
s
.381 .519 .871 r
.80403 .14094 m .80364 .13628 L .81226 .13868 L p F P
0 g
s
.435 .564 .886 r
.80069 .13579 m .80364 .13628 L .80403 .14094 L p F P
0 g
s
.934 .966 .748 r
.64839 .23182 m .64784 .23264 L .64794 .23185 L closepath p F P
0 g
s
.849 .888 .46 r
.82061 .24272 m .81843 .24784 L .81921 .24461 L closepath p F P
0 g
s
.858 .955 .61 r
.62871 .26623 m .62799 .26682 L .62917 .26488 L closepath p F P
0 g
s
.79 .953 .924 r
.71393 .36653 m .72037 .36193 L .71764 .36082 L p F P
0 g
s
.79 .953 .924 r
.71764 .36082 m .7172 .36113 L .71393 .36653 L p F P
0 g
s
.787 .944 .927 r
.70561 .36912 m .7172 .36113 L .71393 .36653 L p F P
0 g
s
.9 .945 .827 r
.66609 .1994 m .67026 .19441 L .66993 .19927 L p F P
0 g
s
.9 .945 .827 r
.66993 .19927 m .66891 .20045 L .66609 .1994 L p F P
0 g
s
.832 .779 .802 r
.19407 .39594 m .19784 .39936 L .20523 .39157 L p F P
0 g
s
.832 .779 .802 r
.20523 .39157 m .20144 .38815 L .19407 .39594 L p F P
0 g
s
.875 .769 .742 r
.20426 .38388 m .20144 .38815 L .20523 .39157 L p F P
0 g
s
.731 .689 .147 r
.82732 .21593 m .82669 .21933 L .82759 .21405 L closepath p F P
0 g
s
.936 .966 .738 r
.644 .23456 m .64333 .23947 L .64784 .23264 L p F P
0 g
s
.936 .966 .738 r
.64557 .2321 m .644 .23456 L p .64784 .23264 L F P
0 g
s
.936 .966 .738 r
.64784 .23264 m .64794 .23185 L .64557 .2321 L p F P
0 g
s
.924 .942 .792 r
.66427 .20647 m .66891 .20045 L .66609 .1994 L p F P
0 g
s
0 .048 .584 r
.82765 .17639 m .82745 .17864 L .82519 .17404 L p F P
0 g
s
0 .048 .584 r
.82581 .16955 m .82765 .17639 L p .82519 .17404 L F P
0 g
s
0 .048 .584 r
.82519 .17404 m .82562 .1692 L .82581 .16955 L p F P
0 g
s
.876 .993 .77 r
.79149 .29588 m .78895 .299 L .79005 .29603 L closepath p F P
0 g
s
.223 .125 .526 r
.58914 .36673 m .5844 .3722 L .58387 .36627 L p F P
0 g
s
.223 .125 .526 r
.58387 .36627 m .58788 .36162 L .58914 .36673 L p F P
0 g
s
.724 .884 .955 r
.66665 .38935 m .65459 .39554 L .65168 .39348 L p F P
0 g
s
.744 .815 .907 r
.74992 .12999 m .7401 .13552 L .73732 .1323 L p F P
0 g
s
.915 .964 .796 r
.65836 .21567 m .65722 .2155 L .65865 .21367 L closepath p F P
0 g
s
.892 .972 .664 r
.80767 .26764 m .80628 .2726 L .81049 .2658 L p F P
0 g
s
.892 .972 .664 r
.80961 .26449 m .80767 .26764 L p .81049 .2658 L F P
0 g
s
.892 .972 .664 r
.81049 .2658 m .81105 .26387 L .80961 .26449 L p F P
0 g
s
0 0 .08 r
.59785 .333 m .59432 .33865 L .59621 .33259 L p F P
0 g
s
0 0 .08 r
.59904 .32882 m .59785 .333 L p .59621 .33259 L F P
0 g
s
0 0 .08 r
.59621 .33259 m .59928 .3275 L .59904 .32882 L p F P
0 g
s
.759 .912 .942 r
.68499 .38218 m .68155 .38425 L .67871 .38257 L p F P
0 g
s
.796 .782 .839 r
.19784 .39936 m .19588 .40098 L .19218 .39751 L p F P
0 g
s
.719 .773 .895 r
.18068 .40338 m .19218 .39751 L .19588 .40098 L p F P
0 g
s
.906 .978 .698 r
.63814 .24882 m .63677 .2494 L .63878 .24633 L closepath p F P
0 g
s
.874 .992 .805 r
.78426 .3015 m .78249 .30653 L .78895 .299 L p F P
0 g
s
.874 .992 .805 r
.78902 .29598 m .78426 .3015 L p .78895 .299 L F P
0 g
s
.874 .992 .805 r
.78895 .299 m .79005 .29603 L .78902 .29598 L p F P
0 g
s
.796 .782 .839 r
.19218 .39751 m .19407 .39594 L .19784 .39936 L p F P
0 g
s
.801 .955 .916 r
.72714 .3569 m .72037 .36193 L .71764 .36082 L p F P
0 g
s
.048 .173 .674 r
.82564 .16896 m .82562 .1692 L .82235 .16495 L p F P
0 g
s
.048 .173 .674 r
.82235 .16495 m .82269 .1602 L .82564 .16896 L p F P
0 g
s
.301 .434 .829 r
.81845 .14959 m .81839 .15148 L .81228 .14822 L p F P
0 g
s
.301 .434 .829 r
.81667 .14559 m .81845 .14959 L p .81228 .14822 L F P
0 g
s
.301 .434 .829 r
.81228 .14822 m .81226 .14346 L .81667 .14559 L p F P
0 g
s
.922 .975 .754 r
.64794 .23185 m .64557 .2321 L .6487 .22765 L closepath p F P
0 g
s
0 0 .129 r
.82921 .19886 m .82865 .20369 L .82855 .19834 L p F P
0 g
s
0 0 .129 r
.82855 .19834 m .82911 .1935 L .82921 .19886 L p F P
0 g
s
.57 .676 .911 r
.78245 .12745 m .78769 .12679 L .78825 .13141 L p F P
0 g
s
.541 .64 .897 r
.79508 .12615 m .78769 .12679 L .78825 .13141 L p F P
0 g
s
.541 .64 .897 r
.78825 .13141 m .79788 .13091 L .79508 .12615 L p F P
0 g
s
.759 .921 .943 r
.68499 .38218 m .69358 .3769 L .69077 .37541 L p F P
0 g
s
.759 .921 .943 r
.69077 .37541 m .68871 .37666 L .68499 .38218 L p F P
0 g
s
.759 .912 .942 r
.67871 .38257 m .68871 .37666 L .68499 .38218 L p F P
0 g
s
.181 .305 .756 r
.81962 .15242 m .81839 .15148 L .81818 .15629 L p F P
0 g
s
.181 .305 .756 r
.81818 .15629 m .82264 .16005 L .81962 .15242 L p F P
0 g
s
.924 .942 .792 r
.66609 .1994 m .66438 .20169 L .66427 .20647 L p F P
0 g
s
.925 .942 .792 r
.6591 .20878 m .65865 .21367 L .66427 .20647 L p F P
0 g
s
.925 .942 .792 r
.66427 .20647 m .66438 .20169 L .6591 .20878 L p F P
0 g
s
.598 .711 .923 r
.59433 .40064 m .60643 .39837 L .60948 .40225 L p F P
0 g
s
.605 .635 .854 r
.59242 .39729 m .59433 .40064 L .60643 .39837 L p F P
0 g
s
.86 .956 .612 r
.62677 .26641 m .63066 .25974 L .62917 .26488 L p F P
0 g
s
.86 .956 .612 r
.62619 .26828 m .62677 .26641 L p .62917 .26488 L F P
0 g
s
.86 .956 .612 r
.62917 .26488 m .62799 .26682 L .62619 .26828 L p F P
0 g
s
.805 .964 .91 r
.73234 .35292 m .72714 .3569 L .72987 .35203 L closepath p F P
0 g
s
.801 .955 .916 r
.72964 .35193 m .72987 .35203 L .72714 .3569 L p F P
0 g
s
.801 .955 .916 r
.71764 .36082 m .72964 .35193 L p .72714 .3569 L F P
0 g
s
0 0 0 r
.59961 .32697 m .59928 .3275 L .6003 .32344 L p F P
0 g
s
0 0 0 r
.6003 .32344 m .60191 .32078 L .59961 .32697 L p F P
0 g
s
.784 .877 .449 r
.61507 .29108 m .61307 .29632 L .61631 .28987 L p F P
0 g
s
.784 .877 .449 r
.61643 .2882 m .61507 .29108 L p .61631 .28987 L F P
0 g
s
.784 .877 .449 r
.61631 .28987 m .61748 .28661 L .61643 .2882 L p F P
0 g
s
.873 .99 .817 r
.77737 .30918 m .78426 .3015 L .78249 .30653 L p F P
0 g
s
.873 .99 .817 r
.77734 .30926 m .77737 .30918 L p .78249 .30653 L F P
0 g
s
.873 .99 .817 r
.78249 .30653 m .77982 .30947 L .77734 .30926 L p F P
0 g
s
.864 .906 .86 r
.69003 .17258 m .68961 .17229 L .69005 .17185 L closepath p F P
0 g
s
.936 .968 .716 r
.63976 .24132 m .63878 .24633 L .64333 .23947 L p F P
0 g
s
.936 .968 .716 r
.64333 .23947 m .644 .23456 L .63976 .24132 L p F P
0 g
s
.883 .932 .554 r
.81644 .24936 m .8153 .25428 L .81843 .24784 L p F P
0 g
s
.883 .932 .554 r
.81843 .24527 m .81644 .24936 L p .81843 .24784 L F P
0 g
s
.883 .932 .554 r
.81843 .24784 m .81921 .24461 L .81843 .24527 L p F P
0 g
s
.815 .964 .904 r
.73886 .34773 m .73234 .35292 L .72987 .35203 L p F P
0 g
s
.864 .992 .824 r
.77982 .30947 m .77533 .31427 L .77734 .30926 L closepath p F P
0 g
s
.891 .954 .607 r
.62799 .26682 m .62537 .27151 L .62619 .26828 L closepath p F P
0 g
s
.839 .882 .873 r
.70726 .15547 m .70144 .1606 L .69862 .15824 L p F P
0 g
s
.869 .886 .846 r
.69823 .16381 m .70144 .1606 L .69862 .15824 L p F P
0 g
s
.71 .842 .945 r
.64331 .39741 m .63961 .39911 L .63665 .39661 L p F P
0 g
s
.683 .835 .956 r
.62457 .40142 m .63665 .39661 L .63961 .39911 L p F P
0 g
s
0 0 0 r
.60479 .3153 m .60191 .32078 L .60451 .31451 L p F P
0 g
s
0 0 0 r
.60451 .31451 m .60713 .3091 L .60479 .3153 L p F P
0 g
s
.846 .875 .862 r
.70726 .15547 m .71332 .15003 L .71052 .14737 L p F P
0 g
s
.846 .875 .862 r
.71052 .14737 m .70681 .1508 L .70726 .15547 L p F P
0 g
s
.839 .882 .873 r
.69862 .15824 m .70681 .1508 L .70726 .15547 L p F P
0 g
s
.736 .692 .151 r
.8272 .21496 m .82819 .20923 L .82759 .21405 L p F P
0 g
s
.736 .692 .151 r
.82663 .21961 m .8272 .21496 L p .82759 .21405 L F P
0 g
s
.736 .692 .151 r
.82759 .21405 m .82669 .21933 L .82663 .21961 L p F P
0 g
s
.899 .98 .701 r
.80301 .27459 m .8017 .27952 L .80628 .2726 L p F P
0 g
s
.899 .98 .701 r
.80628 .2726 m .80767 .26764 L .80301 .27459 L p F P
0 g
s
.869 .886 .846 r
.69862 .15824 m .69772 .15917 L .69823 .16381 L p F P
0 g
s
.867 .885 .847 r
.69002 .16706 m .69005 .17185 L .69823 .16381 L p F P
0 g
s
.867 .885 .847 r
.69823 .16381 m .69772 .15917 L .69002 .16706 L p F P
0 g
s
.899 .986 .734 r
.80129 .28093 m .80061 .28104 L .8017 .27952 L closepath p F P
0 g
s
.812 .863 .885 r
.7176 .14669 m .71332 .15003 L .71052 .14737 L p F P
0 g
s
.741 .897 .949 r
.66721 .38971 m .66665 .38935 L .66798 .38862 L closepath p F P
0 g
s
.083 0 .421 r
.59124 .35714 m .58788 .36162 L .58778 .35617 L p F P
0 g
s
.083 0 .421 r
.58778 .35617 m .59113 .3517 L .59124 .35714 L p F P
0 g
s
.311 .234 .606 r
.58378 .37288 m .5844 .3722 L .58478 .37456 L closepath p F P
0 g
s
.841 .846 .384 r
.82289 .23182 m .82202 .23669 L .82407 .2306 L p F P
0 g
s
.841 .846 .384 r
.82407 .2306 m .82498 .22571 L .82289 .23182 L p F P
0 g
s
.861 .989 .839 r
.7773 .30925 m .77734 .30926 L .77533 .31427 L p F P
0 g
s
.861 .989 .839 r
.76954 .31715 m .7773 .30925 L p .77533 .31427 L F P
0 g
s
.861 .989 .839 r
.76782 .32173 m .76954 .31715 L p .77533 .31427 L F P
0 g
s
.861 .989 .839 r
.77533 .31427 m .76805 .32177 L .76782 .32173 L p F P
0 g
s
.819 .972 .897 r
.73886 .34773 m .74428 .34327 L .74163 .34243 L p F P
0 g
s
.819 .972 .897 r
.74163 .34243 m .74156 .34248 L .73886 .34773 L p F P
0 g
s
.815 .964 .904 r
.73008 .35159 m .74156 .34248 L .73886 .34773 L p F P
0 g
s
.815 .964 .904 r
.72987 .35203 m .73008 .35159 L p .73886 .34773 L F P
0 g
s
.644 .72 .904 r
.76726 .12697 m .77967 .12326 L .78245 .12745 L p F P
0 g
s
.654 .729 .904 r
.77967 .12326 m .76726 .12697 L .76449 .12316 L p F P
0 g
s
.702 .765 .902 r
.75223 .12867 m .76449 .12316 L .76726 .12697 L p F P
0 g
s
.863 .905 .86 r
.68679 .17032 m .69002 .16706 L .69005 .17185 L p F P
0 g
s
.863 .905 .86 r
.69005 .17185 m .68961 .17229 L .68679 .17032 L p F P
0 g
s
.752 .803 .894 r
.74992 .12999 m .75223 .12867 L .74945 .12517 L p F P
0 g
s
.752 .803 .894 r
.74945 .12517 m .74892 .12549 L .74992 .12999 L p F P
0 g
s
.744 .815 .907 r
.73732 .1323 m .74892 .12549 L .74992 .12999 L p F P
0 g
s
.893 .911 .83 r
.6831 .17949 m .68961 .17229 L .68679 .17032 L p F P
0 g
s
.916 .961 .797 r
.65439 .21502 m .6591 .20878 L .65865 .21367 L p F P
0 g
s
.916 .961 .797 r
.65865 .21367 m .65722 .2155 L .65439 .21502 L p F P
0 g
s
.907 .967 .654 r
.81105 .26387 m .80961 .26449 L .81176 .26087 L closepath p F P
0 g
s
.82 .859 .876 r
.7176 .14669 m .72528 .1406 L .72248 .13765 L p F P
0 g
s
.82 .859 .876 r
.72248 .13765 m .71717 .142 L .7176 .14669 L p F P
0 g
s
.812 .863 .885 r
.71052 .14737 m .71717 .142 L .7176 .14669 L p F P
0 g
s
.829 .972 .89 r
.74938 .33893 m .74428 .34327 L .74163 .34243 L p F P
0 g
s
.451 .578 .89 r
.80364 .13628 m .80069 .13579 L .79788 .13091 L p F P
0 g
s
0 0 .286 r
.82963 .18866 m .82911 .1935 L .82838 .18837 L p F P
0 g
s
0 0 .286 r
.82838 .18837 m .8289 .18352 L .82963 .18866 L p F P
0 g
s
.772 .928 .936 r
.70234 .37128 m .69358 .3769 L .69077 .37541 L p F P
0 g
s
.852 .99 .846 r
.76805 .32177 m .76761 .3222 L .76782 .32173 L closepath p F P
0 g
s
.845 .982 .867 r
.76106 .32533 m .75892 .33043 L .76761 .3222 L p F P
0 g
s
.845 .982 .867 r
.76546 .32115 m .76106 .32533 L p .76761 .3222 L F P
0 g
s
.845 .982 .867 r
.76761 .3222 m .76782 .32173 L .76546 .32115 L p F P
0 g
s
.937 .952 .762 r
.6536 .22068 m .65722 .2155 L .65439 .21502 L p F P
0 g
s
.834 .978 .881 r
.74938 .33893 m .75619 .33292 L .75357 .33219 L p F P
0 g
s
.834 .978 .881 r
.75357 .33219 m .75179 .33376 L .74938 .33893 L p F P
0 g
s
.829 .972 .89 r
.74163 .34243 m .75179 .33376 L .74938 .33893 L p F P
0 g
s
.65 .788 .948 r
.60948 .40225 m .62157 .39842 L .62457 .40142 L p F P
0 g
s
.63 .761 .941 r
.62157 .39842 m .60948 .40225 L .60643 .39837 L p F P
0 g
s
.672 .818 .953 r
.63665 .39661 m .62457 .40142 L .62157 .39842 L p F P
0 g
s
.843 .977 .874 r
.75892 .33043 m .75619 .33292 L .75357 .33219 L p F P
0 g
s
.843 .977 .874 r
.75357 .33219 m .76106 .32533 L .75892 .33043 L p F P
0 g
s
.703 .85 .953 r
.64331 .39741 m .65168 .39348 L .64875 .39129 L p F P
0 g
s
.703 .85 .953 r
.64875 .39129 m .64826 .3915 L .64331 .39741 L p F P
0 g
s
.71 .842 .945 r
.63665 .39661 m .64826 .3915 L .64331 .39741 L p F P
0 g
s
.709 .771 .9 r
.76449 .12316 m .75223 .12867 L .74945 .12517 L p F P
0 g
s
.377 .28 .616 r
.59197 .37136 m .58914 .36673 L .5844 .3722 L p F P
0 g
s
.377 .28 .616 r
.58695 .37739 m .59197 .37136 L p .5844 .3722 L F P
0 g
s
.377 .28 .616 r
.5844 .3722 m .58478 .37456 L .58695 .37739 L p F P
0 g
s
.55 .581 .838 r
.59122 .39493 m .59492 .39482 L .59242 .39729 L closepath p F P
0 g
s
.605 .635 .854 r
.60335 .39394 m .59492 .39482 L .59242 .39729 L p F P
0 g
s
.605 .635 .854 r
.60643 .39837 m .60335 .39394 L p .59242 .39729 L F P
0 g
s
.783 .841 .896 r
.73048 .13704 m .72528 .1406 L .72248 .13765 L p F P
0 g
s
0 0 .202 r
.59662 .33887 m .59292 .34456 L .59432 .33865 L p F P
0 g
s
0 0 .202 r
.59432 .33865 m .59785 .333 L .59662 .33887 L p F P
0 g
s
.743 .888 .946 r
.66798 .38862 m .66665 .38935 L .66376 .38737 L p F P
0 g
s
.724 .884 .955 r
.65168 .39348 m .66376 .38737 L .66665 .38935 L p F P
0 g
s
.893 .911 .83 r
.68679 .17032 m .68289 .17476 L .6831 .17949 L p F P
0 g
s
.885 .921 .842 r
.67615 .18234 m .68289 .17476 L .6831 .17949 L p F P
0 g
s
.885 .921 .842 r
.67611 .18423 m .67615 .18234 L p .6831 .17949 L F P
0 g
s
.885 .921 .842 r
.6831 .17949 m .67783 .18521 L .67611 .18423 L p F P
0 g
s
.581 .684 .911 r
.78769 .12679 m .78245 .12745 L .77967 .12326 L p F P
0 g
s
0 0 0 r
.60885 .305 m .60771 .30771 L .60997 .30275 L closepath p F P
0 g
s
.885 .945 .584 r
.62324 .27296 m .62179 .27807 L .62537 .27151 L p F P
0 g
s
.885 .945 .584 r
.62517 .26922 m .62324 .27296 L p .62537 .27151 L F P
0 g
s
.885 .945 .584 r
.62537 .27151 m .62619 .26828 L .62517 .26922 L p F P
0 g
s
.858 .98 .857 r
.76782 .32173 m .76546 .32115 L .76954 .31715 L closepath p F P
0 g
s
.909 .978 .702 r
.6355 .2481 m .63976 .24132 L .63878 .24633 L p F P
0 g
s
.909 .978 .702 r
.63505 .25009 m .6355 .2481 L p .63878 .24633 L F P
0 g
s
.909 .978 .702 r
.63878 .24633 m .63677 .2494 L .63505 .25009 L p F P
0 g
s
.743 .888 .946 r
.66376 .38737 m .67174 .38308 L .66798 .38862 L p F P
0 g
s
.742 .895 .948 r
.66798 .38862 m .67871 .38257 L .67585 .38082 L p F P
0 g
s
.742 .895 .948 r
.67585 .38082 m .67174 .38308 L .66798 .38862 L p F P
0 g
s
0 0 .322 r
.59216 .35029 m .59113 .3517 L .59137 .34668 L p F P
0 g
s
0 0 .322 r
.59137 .34668 m .59292 .34456 L .59216 .35029 L p F P
0 g
s
.723 .817 .355 r
.61224 .29742 m .60997 .30275 L .61307 .29632 L p F P
0 g
s
.723 .817 .355 r
.61307 .29632 m .61507 .29108 L .61224 .29742 L p F P
0 g
s
.9 .985 .736 r
.79818 .28141 m .80301 .27459 L .8017 .27952 L p F P
0 g
s
.9 .985 .736 r
.8017 .27952 m .80061 .28104 L .79818 .28141 L p F P
0 g
s
.904 .914 .817 r
.67783 .18521 m .67629 .18707 L .67611 .18423 L closepath p F P
0 g
s
.783 .841 .896 r
.72248 .13765 m .72991 .13239 L .73048 .13704 L p F P
0 g
s
.791 .836 .886 r
.73048 .13704 m .73732 .1323 L .73452 .12908 L p F P
0 g
s
.791 .836 .886 r
.73452 .12908 m .72991 .13239 L .73048 .13704 L p F P
0 g
s
.901 .953 .609 r
.81284 .25597 m .81176 .26087 L .8153 .25428 L p F P
0 g
s
.901 .953 .609 r
.8153 .25428 m .81644 .24936 L .81284 .25597 L p F P
0 g
s
.333 .267 .632 r
.58478 .37456 m .58695 .37739 L .58559 .37889 L closepath p F P
0 g
s
.937 .952 .762 r
.65439 .21502 m .65381 .21588 L .6536 .22068 L p F P
0 g
s
.939 .953 .757 r
.64921 .22276 m .6487 .22765 L .6536 .22068 L p F P
0 g
s
.939 .953 .757 r
.6536 .22068 m .65381 .21588 L .64921 .22276 L p F P
0 g
s
.887 .989 .794 r
.79005 .29603 m .78902 .29598 L .7907 .29397 L closepath p F P
0 g
s
.504 .529 .815 r
.59492 .39482 m .59122 .39493 L .58806 .38747 L p F P
0 g
s
.891 .988 .737 r
.79641 .28668 m .80061 .28104 L .79818 .28141 L p F P
0 g
s
.908 .916 .812 r
.67023 .18964 m .67026 .19441 L .67629 .18707 L p F P
0 g
s
.908 .916 .812 r
.675 .18362 m .67023 .18964 L p .67629 .18707 L F P
0 g
s
.908 .916 .812 r
.67629 .18707 m .67611 .18423 L .675 .18362 L p F P
0 g
s
.776 .939 .934 r
.70561 .36912 m .70234 .37128 L .70416 .36841 L closepath p F P
0 g
s
.772 .928 .936 r
.70283 .3677 m .70416 .36841 L .70234 .37128 L p F P
0 g
s
.772 .928 .936 r
.69077 .37541 m .70283 .3677 L p .70234 .37128 L F P
0 g
s
0 0 .434 r
.82897 .18283 m .8289 .18352 L .82745 .17864 L p F P
0 g
s
0 0 .434 r
.82745 .17864 m .82765 .17639 L .82897 .18283 L p F P
0 g
s
.931 .967 .685 r
.63677 .2494 m .63457 .25308 L .63505 .25009 L closepath p F P
0 g
s
0 0 0 r
.82873 .20441 m .82819 .20923 L .82865 .20369 L p F P
0 g
s
0 0 0 r
.82865 .20369 m .82921 .19886 L .82873 .20441 L p F P
0 g
s
0 0 0 r
.60273 .32142 m .59961 .32697 L .60191 .32078 L p F P
0 g
s
0 0 0 r
.60191 .32078 m .60479 .3153 L .60273 .32142 L p F P
0 g
s
.787 .94 .928 r
.7172 .36113 m .70561 .36912 L .70416 .36841 L p F P
0 g
s
.398 .533 .876 r
.81223 .13615 m .81226 .13868 L .80364 .13628 L p F P
0 g
s
.398 .533 .876 r
.81088 .13346 m .81223 .13615 L p .80364 .13628 L F P
0 g
s
.398 .533 .876 r
.80364 .13628 m .80326 .13162 L .81088 .13346 L p F P
0 g
s
.451 .578 .89 r
.79788 .13091 m .80326 .13162 L .80364 .13628 L p F P
0 g
s
.708 .68 .137 r
.82669 .21933 m .82661 .21977 L .82663 .21961 L closepath p F P
0 g
s
.883 .897 .478 r
.82035 .23808 m .81953 .24292 L .82202 .23669 L p F P
0 g
s
.883 .897 .478 r
.82202 .23669 m .82289 .23182 L .82035 .23808 L p F P
0 g
s
.752 .817 .903 r
.74892 .12549 m .73732 .1323 L .73452 .12908 L p F P
0 g
s
.798 .787 .287 r
.8255 .22269 m .82498 .22571 L .82661 .21977 L p F P
0 g
s
.798 .787 .287 r
.82661 .21977 m .82663 .21961 L .8255 .22269 L p F P
0 g
s
.408 .375 .71 r
.59302 .38102 m .58779 .38672 L .58559 .37889 L p F P
0 g
s
.408 .375 .71 r
.58559 .37889 m .58695 .37739 L .59302 .38102 L p F P
0 g
s
.468 .458 .763 r
.58728 .38725 m .58779 .38672 L .58806 .38747 L closepath p F P
0 g
s
.891 .988 .737 r
.79818 .28141 m .79798 .28168 L .79641 .28668 L p F P
0 g
s
.891 .99 .773 r
.79216 .28902 m .7907 .29397 L .79641 .28668 L p F P
0 g
s
.891 .99 .773 r
.79641 .28668 m .79798 .28168 L .79216 .28902 L p F P
0 g
s
.829 .793 .297 r
.82573 .22086 m .8255 .22269 L .82663 .21961 L p F P
0 g
s
.829 .793 .297 r
.82663 .21961 m .8272 .21496 L .82573 .22086 L p F P
0 g
s
.761 .87 .443 r
.61748 .28661 m .61643 .2882 L .61828 .28462 L closepath p F P
0 g
s
.93 .964 .67 r
.63162 .25475 m .63066 .25974 L .63457 .25308 L p F P
0 g
s
.93 .964 .67 r
.63394 .25062 m .63162 .25475 L p .63457 .25308 L F P
0 g
s
.93 .964 .67 r
.63457 .25308 m .63505 .25009 L .63394 .25062 L p F P
0 g
s
.72 .877 .954 r
.66376 .38737 m .65168 .39348 L .64875 .39129 L p F P
0 g
s
.906 .939 .82 r
.66436 .19693 m .67023 .18964 L .67026 .19441 L p F P
0 g
s
.906 .939 .82 r
.66428 .19868 m .66436 .19693 L p .67026 .19441 L F P
0 g
s
.906 .939 .82 r
.67026 .19441 m .66609 .1994 L .66428 .19868 L p F P
0 g
s
0 .04 .581 r
.82562 .1692 m .82564 .16896 L .82581 .16955 L closepath p F P
0 g
s
.9 .928 .547 r
.81921 .24461 m .81843 .24527 L .81953 .24292 L closepath p F P
0 g
s
.851 .917 .519 r
.62001 .27942 m .61828 .28462 L .62179 .27807 L p F P
0 g
s
.851 .917 .519 r
.62179 .27807 m .62324 .27296 L .62001 .27942 L p F P
0 g
s
.924 .973 .757 r
.64455 .22966 m .64921 .22276 L .6487 .22765 L p F P
0 g
s
.924 .973 .757 r
.64418 .2322 m .64455 .22966 L p .6487 .22765 L F P
0 g
s
.924 .973 .757 r
.6487 .22765 m .64557 .2321 L .64418 .2322 L p F P
0 g
s
0 .108 .639 r
.82565 .16447 m .82564 .16896 L .82269 .1602 L p F P
0 g
s
0 0 .505 r
.82777 .16912 m .82565 .16447 L .82564 .16896 L p F P
0 g
s
0 0 .505 r
.82772 .17385 m .82777 .16912 L p .82564 .16896 L F P
0 g
s
0 0 .505 r
.82564 .16896 m .82581 .16955 L .82772 .17385 L p F P
0 g
s
0 0 .524 r
.82581 .16955 m .82772 .17385 L .82765 .17639 L closepath p F P
0 g
s
.504 .529 .815 r
.58806 .38747 m .60011 .3888 L .59492 .39482 L p F P
0 g
s
.52 .489 .762 r
.58779 .38672 m .58806 .38747 L .60011 .3888 L p F P
0 g
s
.174 .095 .519 r
.59183 .36313 m .58914 .36673 L .58788 .36162 L p F P
0 g
s
.174 .095 .519 r
.58788 .36162 m .59124 .35714 L .59183 .36313 L p F P
0 g
s
.52 .489 .762 r
.59711 .38213 m .59302 .38102 L .58779 .38672 L p F P
0 g
s
.52 .489 .762 r
.6002 .38869 m .59711 .38213 L p .58779 .38672 L F P
0 g
s
.52 .489 .762 r
.60011 .3888 m .6002 .38869 L p .58779 .38672 L F P
0 g
s
.756 .907 .943 r
.68871 .37666 m .67871 .38257 L .67585 .38082 L p F P
0 g
s
.581 .684 .911 r
.77967 .12326 m .78725 .12211 L .78769 .12679 L p F P
0 g
s
.554 .654 .901 r
.79227 .12152 m .78725 .12211 L .78769 .12679 L p F P
0 g
s
.554 .654 .901 r
.78769 .12679 m .79508 .12615 L .79227 .12152 L p F P
0 g
s
.908 .967 .656 r
.80886 .26272 m .81284 .25597 L .81176 .26087 L p F P
0 g
s
.908 .967 .656 r
.80837 .26501 m .80886 .26272 L p .81176 .26087 L F P
0 g
s
.908 .967 .656 r
.81176 .26087 m .80961 .26449 L .80837 .26501 L p F P
0 g
s
0 0 0 r
.6096 .30371 m .61224 .29742 L .60997 .30275 L p F P
0 g
s
0 0 0 r
.60739 .30849 m .6096 .30371 L p .60997 .30275 L F P
0 g
s
0 0 0 r
.60997 .30275 m .60771 .30771 L .60739 .30849 L p F P
0 g
s
.306 .433 .826 r
.81376 .13932 m .81226 .13868 L .81226 .14346 L p F P
0 g
s
.306 .433 .826 r
.81226 .14346 m .81667 .14559 L .81376 .13932 L p F P
0 g
s
.923 .93 .794 r
.66609 .1994 m .66438 .20169 L .66428 .19868 L closepath p F P
0 g
s
.065 .215 .71 r
.82264 .16005 m .82269 .16011 L .82269 .1602 L closepath p F P
0 g
s
0 .108 .639 r
.82269 .1602 m .82269 .16011 L .82565 .16447 L p F P
0 g
s
.082 .239 .727 r
.82269 .16011 m .82264 .16005 L .81962 .15242 L p F P
0 g
s
0 0 .304 r
.59598 .34456 m .59216 .35029 L .59292 .34456 L p F P
0 g
s
0 0 .304 r
.59292 .34456 m .59662 .33887 L .59598 .34456 L p F P
0 g
s
.572 .634 .874 r
.60025 .38879 m .60011 .3888 L .59492 .39482 L p F P
0 g
s
.572 .634 .874 r
.59492 .39482 m .60335 .39394 L .60025 .38879 L p F P
0 g
s
.082 .239 .727 r
.81962 .15242 m .82257 .15541 L .82269 .16011 L p F P
0 g
s
0 .112 .644 r
.8256 .15975 m .82565 .16447 L .82269 .16011 L p F P
0 g
s
0 .112 .644 r
.82269 .16011 m .82257 .15541 L .8256 .15975 L p F P
0 g
s
.466 .59 .893 r
.80326 .13162 m .79788 .13091 L .79508 .12615 L p F P
0 g
s
0 0 .118 r
.82971 .19402 m .82921 .19886 L .82911 .1935 L p F P
0 g
s
0 0 .118 r
.82911 .1935 m .82963 .18866 L .82971 .19402 L p F P
0 g
s
.791 .95 .924 r
.71764 .36082 m .7172 .36113 L .71743 .36073 L closepath p F P
0 g
s
.787 .94 .928 r
.71489 .35946 m .71743 .36073 L .7172 .36113 L p F P
0 g
s
.787 .94 .928 r
.70551 .36591 m .71489 .35946 L p .7172 .36113 L F P
0 g
s
.787 .94 .928 r
.70416 .36841 m .70551 .36591 L p .7172 .36113 L F P
0 g
s
.806 .951 .915 r
.72692 .35068 m .72964 .35193 L .71764 .36082 L p F P
0 g
s
.806 .951 .915 r
.71983 .35591 m .72692 .35068 L p .71764 .36082 L F P
0 g
s
.806 .951 .915 r
.71764 .36082 m .71743 .36073 L .71983 .35591 L p F P
0 g
s
.199 .332 .774 r
.81839 .15148 m .81845 .14959 L .81962 .15242 L closepath p F P
0 g
s
.889 .988 .796 r
.78652 .29584 m .79216 .28902 L .7907 .29397 L p F P
0 g
s
.889 .988 .796 r
.7907 .29397 m .78902 .29598 L .78652 .29584 L p F P
0 g
s
0 0 .083 r
.59928 .3275 m .59904 .32882 L .59961 .32697 L closepath p F P
0 g
s
.927 .931 .788 r
.65918 .204 m .6591 .20878 L .66438 .20169 L p F P
0 g
s
.927 .931 .788 r
.66325 .19831 m .65918 .204 L p .66438 .20169 L F P
0 g
s
.927 .931 .788 r
.66438 .20169 m .66428 .19868 L .66325 .19831 L p F P
0 g
s
.942 .96 .734 r
.64557 .2321 m .644 .23456 L .64418 .2322 L closepath p F P
0 g
s
.654 .729 .904 r
.76449 .12316 m .77688 .11914 L .77967 .12326 L p F P
0 g
s
.663 .737 .904 r
.77688 .11914 m .76449 .12316 L .7617 .11939 L p F P
0 g
s
.709 .771 .9 r
.74945 .12517 m .7617 .11939 L .76449 .12316 L p F P
0 g
s
0 0 .387 r
.82908 .17877 m .82897 .18283 L .82765 .17639 L p F P
0 g
s
0 0 .387 r
.82765 .17639 m .82772 .17385 L .82908 .17877 L p F P
0 g
s
.881 .991 .8 r
.78426 .3015 m .78902 .29598 L .78652 .29584 L p F P
0 g
s
.702 .827 .942 r
.64826 .3915 m .63665 .39661 L .63368 .39392 L p F P
0 g
s
.672 .818 .953 r
.62157 .39842 m .63368 .39392 L .63665 .39661 L p F P
0 g
s
.797 .939 .921 r
.71743 .36073 m .71489 .35946 L .71983 .35591 L closepath p F P
0 g
s
.63 .761 .941 r
.60643 .39837 m .61855 .39511 L .62157 .39842 L p F P
0 g
s
.604 .727 .931 r
.61855 .39511 m .60643 .39837 L .60335 .39394 L p F P
0 g
s
.361 .326 .684 r
.59545 .37794 m .59302 .38102 L .58695 .37739 L p F P
0 g
s
.361 .326 .684 r
.5939 .373 m .59545 .37794 L p .58695 .37739 L F P
0 g
s
.361 .326 .684 r
.58695 .37739 m .59197 .37136 L .5939 .373 L p F P
0 g
s
.899 .971 .662 r
.80961 .26449 m .80767 .26764 L .80837 .26501 L closepath p F P
0 g
s
.865 .946 .586 r
.62619 .26828 m .62517 .26922 L .62677 .26641 L closepath p F P
0 g
s
0 0 .094 r
.60103 .32743 m .60273 .32142 L .59961 .32697 L p F P
0 g
s
0 0 .094 r
.5985 .33184 m .60103 .32743 L p .59961 .32697 L F P
0 g
s
0 0 .094 r
.59961 .32697 m .59904 .32882 L .5985 .33184 L p F P
0 g
s
.844 .88 .867 r
.70681 .1508 m .69862 .15824 L .69743 .15723 L p F P
0 g
s
.867 .879 .844 r
.69862 .15824 m .69772 .15917 L .69743 .15723 L closepath p F P
0 g
s
.818 .861 .88 r
.71717 .142 m .71052 .14737 L .7077 .14467 L p F P
0 g
s
.85 .868 .855 r
.70681 .1508 m .71052 .14737 L .7077 .14467 L p F P
0 g
s
.85 .868 .855 r
.7077 .14467 m .70609 .1462 L .70681 .1508 L p F P
0 g
s
.844 .88 .867 r
.69729 .15448 m .70609 .1462 L .70681 .1508 L p F P
0 g
s
.844 .88 .867 r
.69743 .15723 m .69729 .15448 L p .70681 .1508 L F P
0 g
s
.811 .953 .911 r
.72987 .35203 m .72964 .35193 L .73008 .35159 L closepath p F P
0 g
s
.871 .881 .841 r
.68966 .16236 m .69002 .16706 L .69772 .15917 L p F P
0 g
s
.871 .881 .841 r
.6958 .15586 m .68966 .16236 L p .69772 .15917 L F P
0 g
s
.871 .881 .841 r
.69772 .15917 m .69743 .15723 L .6958 .15586 L p F P
0 g
s
.917 .957 .629 r
.62802 .26133 m .62677 .26641 L .63066 .25974 L p F P
0 g
s
.917 .957 .629 r
.63066 .25974 m .63162 .25475 L .62802 .26133 L p F P
0 g
s
.944 .96 .723 r
.64029 .23644 m .63976 .24132 L .644 .23456 L p F P
0 g
s
.944 .96 .723 r
.64273 .23238 m .64029 .23644 L p .644 .23456 L F P
0 g
s
.944 .96 .723 r
.644 .23456 m .64418 .2322 L .64273 .23238 L p F P
0 g
s
.592 .691 .911 r
.78725 .12211 m .77967 .12326 L .77688 .11914 L p F P
0 g
s
.892 .923 .835 r
.67611 .18423 m .675 .18362 L .67615 .18234 L closepath p F P
0 g
s
.903 .929 .55 r
.8174 .24448 m .82035 .23808 L .81953 .24292 L p F P
0 g
s
.903 .929 .55 r
.81708 .24641 m .8174 .24448 L p .81953 .24292 L F P
0 g
s
.903 .929 .55 r
.81953 .24292 m .81843 .24527 L .81708 .24641 L p F P
0 g
s
.751 .801 .893 r
.74945 .12517 m .74892 .12549 L .74856 .12405 L closepath p F P
0 g
s
.752 .817 .903 r
.74666 .12169 m .74856 .12405 L .74892 .12549 L p F P
0 g
s
.752 .817 .903 r
.73452 .12908 m .74666 .12169 L p .74892 .12549 L F P
0 g
s
.659 .799 .95 r
.63368 .39392 m .62157 .39842 L .61855 .39511 L p F P
0 g
s
.881 .991 .8 r
.78652 .29584 m .78597 .29647 L .78426 .3015 L p F P
0 g
s
.876 .987 .823 r
.77896 .3042 m .77737 .30918 L .78426 .3015 L p F P
0 g
s
.876 .987 .823 r
.78426 .3015 m .78597 .29647 L .77896 .3042 L p F P
0 g
s
.716 .791 .91 r
.75891 .11564 m .7617 .11939 L .74945 .12517 L p F P
0 g
s
.716 .791 .91 r
.74866 .12071 m .75891 .11564 L p .74945 .12517 L F P
0 g
s
.716 .791 .91 r
.74945 .12517 m .74856 .12405 L .74866 .12071 L p F P
0 g
s
.771 .718 .185 r
.82772 .21015 m .8272 .21496 L .82819 .20923 L p F P
0 g
s
.771 .718 .185 r
.82819 .20923 m .82873 .20441 L .82772 .21015 L p F P
0 g
s
.762 .871 .444 r
.61688 .28586 m .62001 .27942 L .61828 .28462 L p F P
0 g
s
.762 .871 .444 r
.61557 .28949 m .61688 .28586 L p .61828 .28462 L F P
0 g
s
.762 .871 .444 r
.61828 .28462 m .61643 .2882 L .61557 .28949 L p F P
0 g
s
.075 0 .418 r
.59226 .35575 m .59124 .35714 L .59113 .3517 L p F P
0 g
s
.075 0 .418 r
.59113 .3517 m .59216 .35029 L .59226 .35575 L p F P
0 g
s
.825 .854 .869 r
.71717 .142 m .72248 .13765 L .71967 .13467 L p F P
0 g
s
.825 .854 .869 r
.71967 .13467 m .71646 .13739 L .71717 .142 L p F P
0 g
s
.818 .861 .88 r
.7077 .14467 m .71646 .13739 L .71717 .142 L p F P
0 g
s
.782 .929 .931 r
.70416 .36841 m .70283 .3677 L .70551 .36591 L closepath p F P
0 g
s
.812 .949 .911 r
.73008 .35159 m .72964 .35193 L .72692 .35068 L p F P
0 g
s
.813 .957 .908 r
.73244 .34644 m .73008 .35159 L .74156 .34248 L p F P
0 g
s
.812 .949 .911 r
.72692 .35068 m .73244 .34644 L .73008 .35159 L p F P
0 g
s
.046 .228 .728 r
.81845 .14959 m .81962 .15242 L .82257 .15541 L p F P
0 g
s
.868 .9 .853 r
.68395 .16829 m .68966 .16236 L .69002 .16706 L p F P
0 g
s
.868 .9 .853 r
.69002 .16706 m .68679 .17032 L .68395 .16829 L p F P
0 g
s
.858 .86 .408 r
.8237 .22695 m .82289 .23182 L .82498 .22571 L p F P
0 g
s
.858 .86 .408 r
.8247 .22401 m .8237 .22695 L p .82498 .22571 L F P
0 g
s
.858 .86 .408 r
.82498 .22571 m .8255 .22269 L .8247 .22401 L p F P
0 g
s
.905 .982 .718 r
.80426 .26966 m .80301 .27459 L .80767 .26764 L p F P
0 g
s
.905 .982 .718 r
.80724 .26522 m .80426 .26966 L p .80767 .26764 L F P
0 g
s
.905 .982 .718 r
.80767 .26764 m .80837 .26501 L .80724 .26522 L p F P
0 g
s
.759 .92 .943 r
.69077 .37541 m .68871 .37666 L .68988 .37491 L closepath p F P
0 g
s
.756 .907 .943 r
.68794 .37373 m .68988 .37491 L .68871 .37666 L p F P
0 g
s
.756 .907 .943 r
.67585 .38082 m .68794 .37373 L p .68871 .37666 L F P
0 g
s
0 0 0 r
.60771 .30771 m .60713 .3091 L .60739 .30849 L closepath p F P
0 g
s
0 0 .067 r
.59904 .32882 m .59785 .333 L .5985 .33184 L closepath p F P
0 g
s
.895 .901 .823 r
.68289 .17476 m .68679 .17032 L .68395 .16829 L p F P
0 g
s
.789 .841 .891 r
.72991 .13239 m .72248 .13765 L .71967 .13467 L p F P
0 g
s
.922 .955 .791 r
.65409 .21104 m .65918 .204 L .6591 .20878 L p F P
0 g
s
.922 .955 .791 r
.65381 .21491 m .65409 .21104 L p .6591 .20878 L F P
0 g
s
.922 .955 .791 r
.6591 .20878 m .65439 .21502 L .65381 .21491 L p F P
0 g
s
0 0 .274 r
.82965 .1884 m .82963 .18866 L .8289 .18352 L p F P
0 g
s
0 0 .274 r
.8289 .18352 m .82897 .18283 L .82965 .1884 L p F P
0 g
s
.892 .932 .555 r
.81843 .24527 m .81644 .24936 L .81708 .24641 L closepath p F P
0 g
s
.871 .983 .838 r
.77734 .30926 m .7773 .30925 L .77737 .30918 L closepath p F P
0 g
s
.774 .922 .935 r
.70003 .36612 m .70283 .3677 L .69077 .37541 L p F P
0 g
s
.774 .922 .935 r
.6919 .37128 m .70003 .36612 L p .69077 .37541 L F P
0 g
s
.774 .922 .935 r
.69077 .37541 m .68988 .37491 L .6919 .37128 L p F P
0 g
s
.873 .981 .84 r
.77473 .30867 m .77896 .3042 L .77737 .30918 L p F P
0 g
s
.873 .981 .84 r
.77737 .30918 m .7773 .30925 L .77473 .30867 L p F P
0 g
s
.865 .983 .846 r
.76954 .31715 m .7773 .30925 L .77473 .30867 L p F P
0 g
s
.739 .88 .945 r
.67174 .38308 m .66376 .38737 L .66086 .3853 L p F P
0 g
s
.72 .877 .954 r
.64875 .39129 m .66086 .3853 L .66376 .38737 L p F P
0 g
s
0 0 0 r
.60612 .31221 m .60479 .3153 L .60713 .3091 L p F P
0 g
s
0 0 0 r
.60713 .3091 m .60739 .30849 L .60612 .31221 L p F P
0 g
s
.895 .901 .823 r
.68395 .16829 m .68239 .17012 L .68289 .17476 L p F P
0 g
s
.895 .901 .824 r
.676 .17759 m .67615 .18234 L .68289 .17476 L p F P
0 g
s
.895 .901 .824 r
.68289 .17476 m .68239 .17012 L .676 .17759 L p F P
0 g
s
.189 .345 .791 r
.81667 .14559 m .81829 .14675 L .81845 .14959 L closepath p F P
0 g
s
.046 .228 .728 r
.8224 .15071 m .81829 .14675 L .81845 .14959 L p F P
0 g
s
.046 .228 .728 r
.82257 .15541 m .8224 .15071 L p .81845 .14959 L F P
0 g
s
.821 .968 .898 r
.74163 .34243 m .74156 .34248 L .74159 .34242 L closepath p F P
0 g
s
.813 .957 .908 r
.73894 .34129 m .73244 .34644 L p .74156 .34248 L F P
0 g
s
.813 .957 .908 r
.74156 .34248 m .74159 .34242 L .73894 .34129 L p F P
0 g
s
.831 .968 .89 r
.75179 .33376 m .74163 .34243 L .74159 .34242 L p F P
0 g
s
.826 .957 .899 r
.74159 .34242 m .73894 .34129 L .7437 .33738 L closepath p F P
0 g
s
.831 .968 .89 r
.74159 .34242 m .7437 .33738 L p .75179 .33376 L F P
0 g
s
.915 .972 .68 r
.63505 .25009 m .63394 .25062 L .6355 .2481 L closepath p F P
0 g
s
.865 .983 .846 r
.77473 .30867 m .77137 .31211 L .76954 .31715 L p F P
0 g
s
.859 .979 .857 r
.76313 .32022 m .77137 .31211 L .76954 .31715 L p F P
0 g
s
.859 .979 .857 r
.76302 .32053 m .76313 .32022 L p .76954 .31715 L F P
0 g
s
.859 .979 .857 r
.76954 .31715 m .76546 .32115 L .76302 .32053 L p F P
0 g
s
.809 .883 .456 r
.61643 .2882 m .61507 .29108 L .61557 .28949 L closepath p F P
0 g
s
0 0 .229 r
.82979 .18391 m .82965 .1884 L .82897 .18283 L p F P
0 g
s
0 0 .229 r
.82897 .18283 m .82908 .17877 L .82979 .18391 L p F P
0 g
s
.718 .792 .91 r
.74856 .12405 m .74666 .12169 L .74866 .12071 L closepath p F P
0 g
s
.85 .981 .864 r
.76546 .32115 m .76106 .32533 L .76302 .32053 L closepath p F P
0 g
s
.796 .833 .88 r
.72991 .13239 m .73452 .12908 L .73172 .12584 L p F P
0 g
s
.796 .833 .88 r
.73172 .12584 m .72906 .12781 L .72991 .13239 L p F P
0 g
s
.789 .841 .891 r
.71967 .13467 m .72906 .12781 L .72991 .13239 L p F P
0 g
s
.836 .975 .882 r
.75357 .33219 m .75179 .33376 L .75262 .3319 L closepath p F P
0 g
s
.831 .968 .89 r
.75092 .33125 m .75262 .3319 L .75179 .33376 L p F P
0 g
s
.831 .968 .89 r
.7437 .33738 m .75092 .33125 L p .75179 .33376 L F P
0 g
s
.845 .974 .875 r
.76106 .32533 m .75357 .33219 L .75262 .3319 L p F P
0 g
s
.845 .974 .875 r
.76286 .32048 m .76302 .32053 L .76106 .32533 L p F P
0 g
s
.845 .974 .875 r
.75386 .32866 m .76286 .32048 L p .76106 .32533 L F P
0 g
s
.845 .974 .875 r
.75262 .3319 m .75386 .32866 L p .76106 .32533 L F P
0 g
s
0 0 0 r
.60717 .30995 m .60612 .31221 L .60739 .30849 L p F P
0 g
s
0 0 0 r
.60739 .30849 m .6096 .30371 L .60717 .30995 L p F P
0 g
s
.942 .963 .7 r
.63631 .24313 m .6355 .2481 L .63976 .24132 L p F P
0 g
s
.942 .963 .7 r
.63976 .24132 m .64029 .23644 L .63631 .24313 L p F P
0 g
s
.938 .943 .766 r
.65439 .21502 m .65381 .21588 L .65381 .21491 L closepath p F P
0 g
s
.87 .948 .591 r
.62446 .2679 m .62802 .26133 L .62677 .26641 L p F P
0 g
s
.87 .948 .591 r
.62377 .27047 m .62446 .2679 L p .62677 .26641 L F P
0 g
s
.87 .948 .591 r
.62677 .26641 m .62517 .26922 L .62377 .27047 L p F P
0 g
s
.029 0 .403 r
.59609 .35003 m .59226 .35575 L .59216 .35029 L p F P
0 g
s
.029 0 .403 r
.59216 .35029 m .59598 .34456 L .59609 .35003 L p F P
0 g
s
.849 .883 .864 r
.69743 .15723 m .6958 .15586 L .69729 .15448 L closepath p F P
0 g
s
.891 .919 .835 r
.67216 .18202 m .676 .17759 L .67615 .18234 L p F P
0 g
s
.891 .919 .835 r
.67615 .18234 m .675 .18362 L .67216 .18202 L p F P
0 g
s
.942 .944 .758 r
.64934 .21797 m .64921 .22276 L .65381 .21588 L p F P
0 g
s
.942 .944 .758 r
.65155 .21455 m .64934 .21797 L p .65381 .21588 L F P
0 g
s
.942 .944 .758 r
.65381 .21588 m .65381 .21491 L .65155 .21455 L p F P
0 g
s
.906 .984 .737 r
.79917 .27678 m .80426 .26966 L .80301 .27459 L p F P
0 g
s
.906 .984 .737 r
.79805 .28142 m .79917 .27678 L p .80301 .27459 L F P
0 g
s
.906 .984 .737 r
.80301 .27459 m .79818 .28141 L .79805 .28142 L p F P
0 g
s
0 0 .383 r
.82916 .17403 m .82908 .17877 L .82772 .17385 L p F P
0 g
s
0 0 .383 r
.82772 .17385 m .82777 .16912 L .82916 .17403 L p F P
0 g
s
.91 .959 .631 r
.81385 .25108 m .81284 .25597 L .81644 .24936 L p F P
0 g
s
.91 .959 .631 r
.81615 .24686 m .81385 .25108 L p .81644 .24936 L F P
0 g
s
.91 .959 .631 r
.81644 .24936 m .81708 .24641 L .81615 .24686 L p F P
0 g
s
.916 .918 .802 r
.67023 .18964 m .675 .18362 L .67216 .18202 L p F P
0 g
s
.761 .806 .889 r
.74666 .12169 m .73452 .12908 L .73172 .12584 L p F P
0 g
s
.267 .218 .616 r
.59307 .36989 m .59197 .37136 L .58914 .36673 L p F P
0 g
s
.267 .218 .616 r
.58914 .36673 m .59183 .36313 L .59307 .36989 L p F P
0 g
s
0 0 0 r
.82921 .19959 m .82873 .20441 L .82921 .19886 L p F P
0 g
s
0 0 0 r
.82921 .19886 m .82971 .19402 L .82921 .19959 L p F P
0 g
s
.466 .59 .893 r
.79508 .12615 m .80287 .12693 L .80326 .13162 L p F P
0 g
s
.406 .528 .868 r
.80802 .12796 m .80287 .12693 L .80326 .13162 L p F P
0 g
s
.406 .528 .868 r
.80326 .13162 m .81088 .13346 L .80802 .12796 L p F P
0 g
s
.79 .861 .417 r
.61378 .29255 m .61224 .29742 L .61507 .29108 L p F P
0 g
s
.79 .861 .417 r
.61507 .29108 m .61557 .28949 L .61378 .29255 L p F P
0 g
s
.48 .602 .896 r
.80287 .12693 m .79508 .12615 L .79227 .12152 L p F P
0 g
s
0 0 .16 r
.59795 .33649 m .59662 .33887 L .59785 .333 L p F P
0 g
s
0 0 .16 r
.59785 .333 m .5985 .33184 L .59795 .33649 L p F P
0 g
s
.912 .94 .811 r
.66428 .19868 m .66325 .19831 L .66436 .19693 L closepath p F P
0 g
s
.766 .911 .938 r
.68988 .37491 m .68794 .37373 L .6919 .37128 L closepath p F P
0 g
s
.208 .367 .803 r
.81829 .14675 m .81667 .14559 L .81376 .13932 L p F P
0 g
s
.931 .97 .741 r
.64418 .2322 m .64273 .23238 L .64455 .22966 L closepath p F P
0 g
s
.901 .944 .586 r
.62517 .26922 m .62324 .27296 L .62377 .27047 L closepath p F P
0 g
s
.703 .85 .953 r
.64875 .39129 m .64826 .3915 L .64857 .39114 L closepath p F P
0 g
s
.702 .827 .942 r
.6458 .38882 m .64857 .39114 L .64826 .3915 L p F P
0 g
s
.702 .827 .942 r
.63368 .39392 m .6458 .38882 L p .64826 .3915 L F P
0 g
s
.741 .898 .949 r
.67585 .38082 m .67174 .38308 L .67412 .3797 L closepath p F P
0 g
s
.739 .88 .945 r
.67298 .37891 m .67412 .3797 L .67174 .38308 L p F P
0 g
s
.739 .88 .945 r
.66086 .3853 m .67298 .37891 L p .67174 .38308 L F P
0 g
s
.783 .924 .93 r
.70551 .36591 m .70283 .3677 L .70003 .36612 L p F P
0 g
s
.717 .853 .946 r
.65794 .3831 m .66086 .3853 L .64875 .39129 L p F P
0 g
s
.717 .853 .946 r
.65181 .38602 m .65794 .3831 L p .64875 .39129 L F P
0 g
s
.717 .853 .946 r
.64875 .39129 m .64857 .39114 L .65181 .38602 L p F P
0 g
s
.894 .904 .495 r
.82111 .23323 m .82035 .23808 L .82289 .23182 L p F P
0 g
s
.894 .904 .495 r
.82289 .23182 m .8237 .22695 L .82111 .23323 L p F P
0 g
s
.604 .727 .931 r
.60335 .39394 m .61551 .39142 L .61855 .39511 L p F P
0 g
s
.569 .685 .918 r
.61551 .39142 m .60335 .39394 L .60025 .38879 L p F P
0 g
s
.844 .804 .314 r
.82622 .21607 m .82573 .22086 L .8272 .21496 L p F P
0 g
s
.844 .804 .314 r
.8272 .21496 m .82772 .21015 L .82622 .21607 L p F P
0 g
s
.928 .955 .779 r
.65381 .21491 m .65155 .21455 L .65409 .21104 L closepath p F P
0 g
s
0 0 .528 r
.82776 .16438 m .82777 .16912 L .82565 .16447 L p F P
0 g
s
0 0 .528 r
.82565 .16447 m .8256 .15975 L .82776 .16438 L p F P
0 g
s
.916 .918 .802 r
.67216 .18202 m .66989 .18496 L .67023 .18964 L p F P
0 g
s
.916 .918 .803 r
.66433 .19216 m .66436 .19693 L .67023 .18964 L p F P
0 g
s
.916 .918 .803 r
.67023 .18964 m .66989 .18496 L .66433 .19216 L p F P
0 g
s
.712 .846 .946 r
.64857 .39114 m .6458 .38882 L .65181 .38602 L closepath p F P
0 g
s
.786 .932 .928 r
.70551 .36591 m .71489 .35946 L .71212 .35803 L p F P
0 g
s
.786 .932 .928 r
.71212 .35803 m .7083 .36063 L .70551 .36591 L p F P
0 g
s
.783 .924 .93 r
.70003 .36612 m .7083 .36063 L .70551 .36591 L p F P
0 g
s
.917 .976 .706 r
.80837 .26501 m .80724 .26522 L .80886 .26272 L closepath p F P
0 g
s
.897 .987 .744 r
.79818 .28141 m .79798 .28168 L .79805 .28142 L closepath p F P
0 g
s
0 0 0 r
.605 .31613 m .60273 .32142 L .60479 .3153 L p F P
0 g
s
0 0 0 r
.60479 .3153 m .60612 .31221 L .605 .31613 L p F P
0 g
s
.672 .743 .904 r
.77409 .11507 m .7617 .11939 L .75891 .11564 L p F P
0 g
s
.663 .737 .904 r
.7617 .11939 m .77409 .11507 L .77688 .11914 L p F P
0 g
s
.919 .972 .686 r
.63232 .24983 m .63631 .24313 L .6355 .2481 L p F P
0 g
s
.919 .972 .686 r
.63202 .25146 m .63232 .24983 L p .6355 .2481 L F P
0 g
s
.919 .972 .686 r
.6355 .2481 m .63394 .25062 L .63202 .25146 L p F P
0 g
s
.894 .987 .784 r
.79356 .28406 m .79216 .28902 L .79798 .28168 L p F P
0 g
s
.894 .987 .784 r
.7957 .28133 m .79356 .28406 L p .79798 .28168 L F P
0 g
s
.894 .987 .784 r
.79798 .28168 m .79805 .28142 L .7957 .28133 L p F P
0 g
s
.592 .691 .911 r
.77688 .11914 m .78698 .11735 L .78725 .12211 L p F P
0 g
s
.568 .666 .905 r
.78947 .11698 m .78698 .11735 L .78725 .12211 L p F P
0 g
s
.568 .666 .905 r
.78725 .12211 m .79227 .12152 L .78947 .11698 L p F P
0 g
s
.17 .092 .519 r
.59351 .36087 m .59183 .36313 L .59124 .35714 L p F P
0 g
s
.17 .092 .519 r
.59124 .35714 m .59226 .35575 L .59351 .36087 L p F P
0 g
s
.756 .9 .941 r
.6851 .37191 m .68794 .37373 L .67585 .38082 L p F P
0 g
s
.756 .9 .941 r
.67533 .37757 m .6851 .37191 L p .67585 .38082 L F P
0 g
s
.756 .9 .941 r
.67585 .38082 m .67412 .3797 L .67533 .37757 L p F P
0 g
s
.944 .951 .746 r
.64496 .22479 m .64455 .22966 L .64921 .22276 L p F P
0 g
s
.944 .951 .746 r
.64921 .22276 m .64934 .21797 L .64496 .22479 L p F P
0 g
s
.84 .964 .885 r
.75262 .3319 m .75092 .33125 L .75386 .32866 L closepath p F P
0 g
s
.88 .86 .409 r
.8255 .22269 m .8247 .22401 L .82573 .22086 L closepath p F P
0 g
s
0 0 .167 r
.59979 .33332 m .59795 .33649 L .5985 .33184 L p F P
0 g
s
0 0 .167 r
.5985 .33184 m .60103 .32743 L .59979 .33332 L p F P
0 g
s
.324 .456 .84 r
.81226 .13868 m .81223 .13615 L .81376 .13932 L closepath p F P
0 g
s
.907 .983 .771 r
.79805 .28142 m .7957 .28133 L .79917 .27678 L closepath p F P
0 g
s
0 .118 .65 r
.82549 .15502 m .8256 .15975 L .82257 .15541 L p F P
0 g
s
0 .118 .65 r
.82257 .15541 m .8224 .15071 L .82549 .15502 L p F P
0 g
s
.894 .935 .56 r
.62116 .2744 m .62001 .27942 L .62324 .27296 L p F P
0 g
s
.894 .935 .56 r
.62235 .27191 m .62116 .2744 L p .62324 .27296 L F P
0 g
s
.894 .935 .56 r
.62324 .27296 m .62377 .27047 L .62235 .27191 L p F P
0 g
s
.603 .692 .905 r
.78698 .11735 m .77688 .11914 L .77409 .11507 L p F P
0 g
s
.683 .827 .952 r
.6458 .38882 m .63368 .39392 L .63069 .391 L p F P
0 g
s
.659 .799 .95 r
.61855 .39511 m .63069 .391 L .63368 .39392 L p F P
0 g
s
.918 .969 .671 r
.80981 .25785 m .80886 .26272 L .81284 .25597 L p F P
0 g
s
.918 .969 .671 r
.81284 .25597 m .81385 .25108 L .80981 .25785 L p F P
0 g
s
.208 .367 .803 r
.81376 .13932 m .81797 .14208 L .81829 .14675 L p F P
0 g
s
.092 .261 .745 r
.82219 .146 m .8224 .15071 L .81829 .14675 L p F P
0 g
s
.092 .261 .745 r
.81829 .14675 m .81797 .14208 L .82219 .146 L p F P
0 g
s
.763 .853 .408 r
.61388 .29228 m .61378 .29255 L .61557 .28949 L p F P
0 g
s
.763 .853 .408 r
.61557 .28949 m .61688 .28586 L .61388 .29228 L p F P
0 g
s
.94 .96 .669 r
.63394 .25062 m .63162 .25475 L .63202 .25146 L closepath p F P
0 g
s
.641 .775 .945 r
.63069 .391 m .61855 .39511 L .61551 .39142 L p F P
0 g
s
0 0 .1 r
.82978 .19319 m .82971 .19402 L .82963 .18866 L p F P
0 g
s
0 0 .1 r
.82963 .18866 m .82965 .1884 L .82978 .19319 L p F P
0 g
s
.912 .937 .812 r
.6604 .19718 m .66433 .19216 L .66436 .19693 L p F P
0 g
s
.912 .937 .812 r
.66436 .19693 m .66325 .19831 L .6604 .19718 L p F P
0 g
s
.718 .793 .911 r
.74866 .12071 m .74666 .12169 L .74386 .11822 L p F P
0 g
s
.761 .806 .889 r
.73172 .12584 m .74386 .11822 L .74666 .12169 L p F P
0 g
s
.798 .937 .921 r
.71983 .35591 m .71489 .35946 L .71212 .35803 L p F P
0 g
s
0 0 .063 r
.82991 .18927 m .82978 .19319 L .82965 .1884 L p F P
0 g
s
0 0 .063 r
.82965 .1884 m .82979 .18391 L .82991 .18927 L p F P
0 g
s
.934 .93 .776 r
.65918 .204 m .66325 .19831 L .6604 .19718 L p F P
0 g
s
.823 .86 .874 r
.71646 .13739 m .7077 .14467 L .7053 .14234 L p F P
0 g
s
.847 .86 .852 r
.7077 .14467 m .70609 .1462 L .7053 .14234 L closepath p F P
0 g
s
.851 .862 .849 r
.69679 .1498 m .69729 .15448 L .70609 .1462 L p F P
0 g
s
.851 .862 .849 r
.70487 .14194 m .69679 .1498 L p .70609 .1462 L F P
0 g
s
.851 .862 .849 r
.70609 .1462 m .7053 .14234 L .70487 .14194 L p F P
0 g
s
.761 .826 .359 r
.61142 .29852 m .6096 .30371 L .61224 .29742 L p F P
0 g
s
.761 .826 .359 r
.61364 .29284 m .61142 .29852 L p .61224 .29742 L F P
0 g
s
.761 .826 .359 r
.61224 .29742 m .61378 .29255 L .61364 .29284 L p F P
0 g
s
.893 .986 .796 r
.78732 .29154 m .79356 .28406 L .79216 .28902 L p F P
0 g
s
.893 .986 .796 r
.78619 .29581 m .78732 .29154 L p .79216 .28902 L F P
0 g
s
.893 .986 .796 r
.79216 .28902 m .78652 .29584 L .78619 .29581 L p F P
0 g
s
.848 .88 .863 r
.69296 .15345 m .69679 .1498 L .69729 .15448 L p F P
0 g
s
.848 .88 .863 r
.69729 .15448 m .6958 .15586 L .69296 .15345 L p F P
0 g
s
.878 .887 .836 r
.68966 .16236 m .6958 .15586 L .69296 .15345 L p F P
0 g
s
.727 .794 .905 r
.74866 .12071 m .75891 .11564 L .75611 .11191 L p F P
0 g
s
.727 .794 .905 r
.75611 .11191 m .74829 .11596 L .74866 .12071 L p F P
0 g
s
.718 .793 .911 r
.74386 .11822 m .74829 .11596 L .74866 .12071 L p F P
0 g
s
.181 .364 .81 r
.81223 .13615 m .81376 .13932 L .81797 .14208 L p F P
0 g
s
.801 .945 .918 r
.71983 .35591 m .72692 .35068 L .72419 .34939 L p F P
0 g
s
.801 .945 .918 r
.72419 .34939 m .72242 .35068 L .71983 .35591 L p F P
0 g
s
.798 .937 .921 r
.71212 .35803 m .72242 .35068 L .71983 .35591 L p F P
0 g
s
.828 .849 .863 r
.71646 .13739 m .71967 .13467 L .71685 .13167 L p F P
0 g
s
.828 .849 .863 r
.71685 .13167 m .71549 .13285 L .71646 .13739 L p F P
0 g
s
.823 .86 .874 r
.70523 .14164 m .71549 .13285 L .71646 .13739 L p F P
0 g
s
.823 .86 .874 r
.7053 .14234 m .70523 .14164 L p .71646 .13739 L F P
0 g
s
.458 .472 .786 r
.59302 .38102 m .59545 .37794 L .59711 .38213 L closepath p F P
0 g
s
.124 .056 .501 r
.59721 .3552 m .59351 .36087 L .59226 .35575 L p F P
0 g
s
.124 .056 .501 r
.59226 .35575 m .59609 .35003 L .59721 .3552 L p F P
0 g
s
.795 .841 .886 r
.72906 .12781 m .71967 .13467 L .71685 .13167 L p F P
0 g
s
.917 .934 .567 r
.81811 .23966 m .8174 .24448 L .82035 .23808 L p F P
0 g
s
.917 .934 .567 r
.82035 .23808 m .82111 .23323 L .81811 .23966 L p F P
0 g
s
.933 .967 .744 r
.64053 .23163 m .64496 .22479 L .64455 .22966 L p F P
0 g
s
.933 .967 .744 r
.64043 .23258 m .64053 .23163 L p .64455 .22966 L F P
0 g
s
.933 .967 .744 r
.64455 .22966 m .64273 .23238 L .64043 .23258 L p F P
0 g
s
0 0 .259 r
.59769 .34149 m .59598 .34456 L .59662 .33887 L p F P
0 g
s
0 0 .259 r
.59662 .33887 m .59795 .33649 L .59769 .34149 L p F P
0 g
s
.788 .731 .203 r
.82817 .20535 m .82772 .21015 L .82873 .20441 L p F P
0 g
s
.788 .731 .203 r
.82873 .20441 m .82921 .19959 L .82817 .20535 L p F P
0 g
s
.924 .953 .621 r
.81708 .24641 m .81615 .24686 L .8174 .24448 L closepath p F P
0 g
s
.878 .887 .836 r
.69296 .15345 m .68902 .15774 L .68966 .16236 L p F P
0 g
s
.872 .896 .847 r
.68175 .16551 m .68902 .15774 L .68966 .16236 L p F P
0 g
s
.872 .896 .847 r
.68184 .16673 m .68175 .16551 L p .68966 .16236 L F P
0 g
s
.872 .896 .847 r
.68966 .16236 m .68395 .16829 L .68184 .16673 L p F P
0 g
s
.94 .956 .651 r
.62877 .2564 m .62802 .26133 L .63162 .25475 L p F P
0 g
s
.94 .956 .651 r
.6311 .25194 m .62877 .2564 L p .63162 .25475 L F P
0 g
s
.94 .956 .651 r
.63162 .25475 m .63202 .25146 L .6311 .25194 L p F P
0 g
s
.884 .989 .804 r
.78652 .29584 m .78597 .29647 L .78619 .29581 L closepath p F P
0 g
s
.884 .861 .413 r
.82426 .22214 m .82622 .21607 L .82573 .22086 L p F P
0 g
s
.884 .861 .413 r
.82395 .22522 m .82426 .22214 L p .82573 .22086 L F P
0 g
s
.884 .861 .413 r
.82573 .22086 m .8247 .22401 L .82395 .22522 L p F P
0 g
s
.877 .983 .831 r
.78048 .29922 m .77896 .3042 L .78597 .29647 L p F P
0 g
s
.877 .983 .831 r
.78398 .29536 m .78048 .29922 L p .78597 .29647 L F P
0 g
s
.877 .983 .831 r
.78597 .29647 m .78619 .29581 L .78398 .29536 L p F P
0 g
s
.934 .93 .776 r
.6604 .19718 m .65892 .19931 L .65918 .204 L p F P
0 g
s
.935 .931 .775 r
.65411 .20626 m .65409 .21104 L .65918 .204 L p F P
0 g
s
.935 .931 .775 r
.65918 .204 m .65892 .19931 L .65411 .20626 L p F P
0 g
s
0 0 .221 r
.82988 .17918 m .82979 .18391 L .82908 .17877 L p F P
0 g
s
0 0 .221 r
.82908 .17877 m .82916 .17403 L .82988 .17918 L p F P
0 g
s
.892 .891 .821 r
.68395 .16829 m .68239 .17012 L .68184 .16673 L closepath p F P
0 g
s
.812 .947 .911 r
.73244 .34644 m .72692 .35068 L .72419 .34939 L p F P
0 g
s
.731 .879 .949 r
.67298 .37891 m .66086 .3853 L .65794 .3831 L p F P
0 g
s
.541 .589 .851 r
.60011 .3888 m .6002 .38869 L .60025 .38879 L closepath p F P
0 g
s
.919 .976 .708 r
.8054 .26475 m .80981 .25785 L .80886 .26272 L p F P
0 g
s
.919 .976 .708 r
.80524 .26557 m .8054 .26475 L p .80886 .26272 L F P
0 g
s
.919 .976 .708 r
.80886 .26272 m .80724 .26522 L .80524 .26557 L p F P
0 g
s
.95 .953 .721 r
.64273 .23238 m .64029 .23644 L .64043 .23258 L closepath p F P
0 g
s
.582 .61 .845 r
.6002 .38869 m .60025 .38879 L .61244 .38728 L p F P
0 g
s
.569 .685 .918 r
.60025 .38879 m .61244 .38728 L .61551 .39142 L p F P
0 g
s
.48 .602 .896 r
.79227 .12152 m .8025 .12221 L .80287 .12693 L p F P
0 g
s
.494 .612 .898 r
.8025 .12221 m .79227 .12152 L .78947 .11698 L p F P
0 g
s
.867 .907 .497 r
.61828 .28077 m .61688 .28586 L .62001 .27942 L p F P
0 g
s
.867 .907 .497 r
.62001 .27942 m .62116 .2744 L .61828 .28077 L p F P
0 g
s
.767 .906 .936 r
.6919 .37128 m .68794 .37373 L .6851 .37191 L p F P
0 g
s
.514 .544 .824 r
.59711 .38213 m .60531 .38274 L .6002 .38869 L closepath p F P
0 g
s
.582 .61 .845 r
.60935 .38258 m .60531 .38274 L .6002 .38869 L p F P
0 g
s
.582 .61 .845 r
.61244 .38728 m .60935 .38258 L p .6002 .38869 L F P
0 g
s
.897 .893 .817 r
.67555 .17292 m .676 .17759 L .68239 .17012 L p F P
0 g
s
.897 .893 .817 r
.6811 .16619 m .67555 .17292 L p .68239 .17012 L F P
0 g
s
.897 .893 .817 r
.68239 .17012 m .68184 .16673 L .6811 .16619 L p F P
0 g
s
0 0 0 r
.60348 .32208 m .60103 .32743 L .60273 .32142 L p F P
0 g
s
0 0 0 r
.60499 .31619 m .60348 .32208 L p .60273 .32142 L F P
0 g
s
0 0 0 r
.60273 .32142 m .605 .31613 L .60499 .31619 L p F P
0 g
s
.817 .954 .906 r
.73244 .34644 m .73894 .34129 L .73624 .34013 L p F P
0 g
s
.817 .954 .906 r
.73624 .34013 m .73479 .34127 L .73244 .34644 L p F P
0 g
s
.812 .947 .911 r
.72419 .34939 m .73479 .34127 L .73244 .34644 L p F P
0 g
s
.801 .831 .874 r
.72906 .12781 m .73172 .12584 L .72891 .12259 L p F P
0 g
s
.801 .831 .874 r
.72891 .12259 m .72797 .1233 L .72906 .12781 L p F P
0 g
s
.795 .841 .886 r
.71685 .13167 m .72797 .1233 L .72906 .12781 L p F P
0 g
s
.293 .45 .846 r
.81088 .13346 m .81199 .13397 L .81223 .13615 L closepath p F P
0 g
s
.181 .364 .81 r
.8176 .1374 m .81199 .13397 L .81223 .13615 L p F P
0 g
s
.181 .364 .81 r
.81797 .14208 m .8176 .1374 L p .81223 .13615 L F P
0 g
s
.267 .219 .617 r
.59638 .3655 m .59307 .36989 L .59183 .36313 L p F P
0 g
s
.267 .219 .617 r
.59183 .36313 m .59351 .36087 L .59638 .3655 L p F P
0 g
s
.889 .979 .82 r
.78619 .29581 m .78398 .29536 L .78732 .29154 L closepath p F P
0 g
s
.911 .98 .716 r
.80724 .26522 m .80426 .26966 L .80524 .26557 L closepath p F P
0 g
s
.874 .98 .84 r
.77307 .30709 m .78048 .29922 L .77896 .3042 L p F P
0 g
s
.874 .98 .84 r
.77274 .30821 m .77307 .30709 L p .77896 .3042 L F P
0 g
s
.874 .98 .84 r
.77896 .3042 m .77473 .30867 L .77274 .30821 L p F P
0 g
s
.872 .936 .562 r
.62377 .27047 m .62235 .27191 L .62446 .2679 L closepath p F P
0 g
s
.766 .807 .886 r
.74386 .11822 m .73172 .12584 L .72891 .12259 L p F P
0 g
s
.346 .325 .693 r
.59197 .37136 m .59307 .36989 L .5939 .373 L closepath p F P
0 g
s
.749 .89 .943 r
.67412 .3797 m .67298 .37891 L .67533 .37757 L closepath p F P
0 g
s
.768 .914 .937 r
.6919 .37128 m .70003 .36612 L .69722 .36448 L p F P
0 g
s
.768 .914 .937 r
.69722 .36448 m .69489 .36594 L .6919 .37128 L p F P
0 g
s
.767 .906 .936 r
.6851 .37191 m .69489 .36594 L .6919 .37128 L p F P
0 g
s
.827 .955 .899 r
.7437 .33738 m .73894 .34129 L .73624 .34013 L p F P
0 g
s
.866 .981 .847 r
.77473 .30867 m .77137 .31211 L .77274 .30821 L closepath p F P
0 g
s
0 0 0 r
.60501 .31611 m .605 .31613 L .60612 .31221 L p F P
0 g
s
0 0 0 r
.60612 .31221 m .60717 .30995 L .60501 .31611 L p F P
0 g
s
.832 .962 .893 r
.7437 .33738 m .75092 .33125 L .74825 .33019 L p F P
0 g
s
.832 .962 .893 r
.74825 .33019 m .74579 .33228 L .7437 .33738 L p F P
0 g
s
.827 .955 .899 r
.73624 .34013 m .74579 .33228 L .7437 .33738 L p F P
0 g
s
.87 .862 .413 r
.8247 .22401 m .8237 .22695 L .82395 .22522 L closepath p F P
0 g
s
.895 .913 .828 r
.6693 .18031 m .67555 .17292 L .676 .17759 L p F P
0 g
s
.895 .913 .828 r
.676 .17759 m .67216 .18202 L .6693 .18031 L p F P
0 g
s
.854 .97 .871 r
.76302 .32053 m .76286 .32048 L .76313 .32022 L closepath p F P
0 g
s
.673 .743 .244 r
.60922 .30469 m .60717 .30995 L .6096 .30371 L p F P
0 g
s
.673 .743 .244 r
.6096 .30371 m .61142 .29852 L .60922 .30469 L p F P
0 g
s
.952 .952 .708 r
.63668 .23829 m .63631 .24313 L .64029 .23644 L p F P
0 g
s
.952 .952 .708 r
.63987 .23266 m .63668 .23829 L p .64029 .23644 L F P
0 g
s
.952 .952 .708 r
.64029 .23644 m .64043 .23258 L .63987 .23266 L p F P
0 g
s
.857 .972 .866 r
.76475 .31524 m .76313 .32022 L .77137 .31211 L p F P
0 g
s
.857 .972 .866 r
.77215 .30802 m .76475 .31524 L p .77137 .31211 L F P
0 g
s
.857 .972 .866 r
.77137 .31211 m .77274 .30821 L .77215 .30802 L p F P
0 g
s
0 0 .382 r
.82917 .16929 m .82916 .17403 L .82777 .16912 L p F P
0 g
s
0 0 .382 r
.82777 .16912 m .82776 .16438 L .82917 .16929 L p F P
0 g
s
.929 .95 .781 r
.64921 .21326 m .65411 .20626 L .65409 .21104 L p F P
0 g
s
.929 .95 .781 r
.64918 .21409 m .64921 .21326 L p .65409 .21104 L F P
0 g
s
.929 .95 .781 r
.65409 .21104 m .65155 .21455 L .64918 .21409 L p F P
0 g
s
.422 .547 .877 r
.80517 .12264 m .8025 .12221 L .80287 .12693 L p F P
0 g
s
.422 .547 .877 r
.80287 .12693 m .80802 .12796 L .80517 .12264 L p F P
0 g
s
.841 .962 .886 r
.75386 .32866 m .75092 .33125 L .74825 .33019 L p F P
0 g
s
.847 .967 .878 r
.75386 .32866 m .76286 .32048 L .76023 .31951 L p F P
0 g
s
.847 .967 .878 r
.76023 .31951 m .75571 .32362 L .75386 .32866 L p F P
0 g
s
.841 .962 .886 r
.74825 .33019 m .75571 .32362 L .75386 .32866 L p F P
0 g
s
.855 .966 .871 r
.76023 .31951 m .76475 .31524 L .76313 .32022 L p F P
0 g
s
.855 .966 .871 r
.76313 .32022 m .76286 .32048 L .76023 .31951 L p F P
0 g
s
.926 .948 .61 r
.62546 .2629 m .62446 .2679 L .62802 .26133 L p F P
0 g
s
.926 .948 .61 r
.62802 .26133 m .62877 .2564 L .62546 .2629 L p F P
0 g
s
.711 .632 .07 r
.8294 .19728 m .82921 .19959 L .82971 .19402 L p F P
0 g
s
.711 .632 .07 r
.82971 .19402 m .82978 .19319 L .8294 .19728 L p F P
0 g
s
.926 .953 .623 r
.81472 .24622 m .81811 .23966 L .8174 .24448 L p F P
0 g
s
.926 .953 .623 r
.81451 .24765 m .81472 .24622 L p .8174 .24448 L F P
0 g
s
.926 .953 .623 r
.8174 .24448 m .81615 .24686 L .81451 .24765 L p F P
0 g
s
.909 .983 .759 r
.80027 .27188 m .79917 .27678 L .80426 .26966 L p F P
0 g
s
.909 .983 .759 r
.80482 .26557 m .80027 .27188 L p .80426 .26966 L F P
0 g
s
.909 .983 .759 r
.80426 .26966 m .80524 .26557 L .80482 .26557 L p F P
0 g
s
.713 .835 .94 r
.65181 .38602 m .6458 .38882 L .64284 .38618 L p F P
0 g
s
.683 .827 .952 r
.63069 .391 m .64284 .38618 L .6458 .38882 L p F P
0 g
s
.918 .907 .796 r
.66989 .18496 m .67216 .18202 L .6693 .18031 L p F P
0 g
s
.672 .743 .904 r
.75891 .11564 m .7713 .11104 L .77409 .11507 L p F P
0 g
s
.68 .749 .904 r
.7713 .11104 m .75891 .11564 L .75611 .11191 L p F P
0 g
s
.31 .467 .855 r
.81199 .13397 m .81088 .13346 L .80802 .12796 L p F P
0 g
s
.614 .701 .906 r
.78667 .11254 m .77409 .11507 L .7713 .11104 L p F P
0 g
s
.603 .692 .905 r
.78696 .11299 m .78698 .11735 L p .77409 .11507 L F P
0 g
s
.603 .692 .905 r
.77409 .11507 m .78667 .11254 L .78696 .11299 L p F P
0 g
s
.945 .937 .755 r
.65155 .21455 m .64934 .21797 L .64918 .21409 L closepath p F P
0 g
s
0 0 .268 r
.59913 .33902 m .59769 .34149 L .59795 .33649 L p F P
0 g
s
0 0 .268 r
.59795 .33649 m .59979 .33332 L .59913 .33902 L p F P
0 g
s
.782 .921 .93 r
.7083 .36063 m .70003 .36612 L .69722 .36448 L p F P
0 g
s
.525 .512 .784 r
.59545 .37794 m .59711 .38213 L .60531 .38274 L p F P
0 g
s
.641 .775 .945 r
.61551 .39142 m .62767 .38783 L .63069 .391 L p F P
0 g
s
.617 .747 .939 r
.62767 .38783 m .61551 .39142 L .61244 .38728 L p F P
0 g
s
0 0 .53 r
.8277 .15965 m .82776 .16438 L .8256 .15975 L p F P
0 g
s
0 0 .53 r
.8256 .15975 m .82549 .15502 L .8277 .15965 L p F P
0 g
s
.918 .907 .796 r
.6693 .18031 m .66926 .18036 L .66989 .18496 L p F P
0 g
s
.919 .908 .794 r
.66397 .18747 m .66433 .19216 L .66989 .18496 L p F P
0 g
s
.919 .908 .794 r
.66989 .18496 m .66926 .18036 L .66397 .18747 L p F P
0 g
s
.917 .957 .63 r
.81615 .24686 m .81385 .25108 L .81451 .24765 L closepath p F P
0 g
s
.859 .815 .332 r
.82664 .21128 m .82622 .21607 L .82772 .21015 L p F P
0 g
s
.859 .815 .332 r
.82772 .21015 m .82817 .20535 L .82664 .21128 L p F P
0 g
s
.82 .874 .436 r
.61553 .2871 m .61388 .29228 L .61688 .28586 L p F P
0 g
s
.82 .874 .436 r
.61688 .28586 m .61828 .28077 L .61553 .2871 L p F P
0 g
s
.907 .912 .514 r
.82181 .22839 m .82111 .23323 L .8237 .22695 L p F P
0 g
s
.907 .912 .514 r
.82253 .22663 m .82181 .22839 L p .8237 .22695 L F P
0 g
s
.907 .912 .514 r
.8237 .22695 m .82395 .22522 L .82253 .22663 L p F P
0 g
s
.431 .38 .701 r
.60155 .36942 m .59638 .3655 L .59307 .36989 L p F P
0 g
s
.431 .38 .701 r
.59773 .37509 m .60155 .36942 L p .59307 .36989 L F P
0 g
s
.431 .38 .701 r
.59307 .36989 m .5939 .373 L .59773 .37509 L p F P
0 g
s
.756 .652 .095 r
.82949 .19482 m .8294 .19728 L .82978 .19319 L p F P
0 g
s
.756 .652 .095 r
.82978 .19319 m .82991 .18927 L .82949 .19482 L p F P
0 g
s
.671 .811 .95 r
.64284 .38618 m .63069 .391 L .62767 .38783 L p F P
0 g
s
0 0 .37 r
.59782 .34694 m .59609 .35003 L .59598 .34456 L p F P
0 g
s
0 0 .37 r
.59598 .34456 m .59769 .34149 L .59782 .34694 L p F P
0 g
s
.58 .678 .907 r
.78698 .11735 m .78696 .11299 L .78947 .11698 L closepath p F P
0 g
s
.401 .39 .732 r
.5939 .373 m .59773 .37509 L .59545 .37794 L closepath p F P
0 g
s
.75 .882 .94 r
.67533 .37757 m .67298 .37891 L .67008 .3768 L p F P
0 g
s
.731 .879 .949 r
.65794 .3831 m .67008 .3768 L .67298 .37891 L p F P
0 g
s
.31 .467 .855 r
.80802 .12796 m .81141 .12934 L .81199 .13397 L p F P
0 g
s
.223 .393 .822 r
.81719 .13272 m .8176 .1374 L .81199 .13397 L p F P
0 g
s
.223 .393 .822 r
.81199 .13397 m .81141 .12934 L .81719 .13272 L p F P
0 g
s
.826 .862 .873 r
.7053 .14234 m .70487 .14194 L .70523 .14164 L closepath p F P
0 g
s
.525 .512 .784 r
.60623 .377 m .59773 .37509 L .59545 .37794 L p F P
0 g
s
.525 .512 .784 r
.6075 .3794 m .60623 .377 L p .59545 .37794 L F P
0 g
s
.525 .512 .784 r
.60531 .38274 m .6075 .3794 L p .59545 .37794 L F P
0 g
s
0 0 .108 r
.60237 .32793 m .59979 .33332 L .60103 .32743 L p F P
0 g
s
0 0 .108 r
.60103 .32743 m .60348 .32208 L .60237 .32793 L p F P
0 g
s
0 .125 .655 r
.82535 .15029 m .82549 .15502 L .8224 .15071 L p F P
0 g
s
0 .125 .655 r
.8224 .15071 m .82219 .146 L .82535 .15029 L p F P
0 g
s
.725 .796 .908 r
.74829 .11596 m .74386 .11822 L .74105 .11475 L p F P
0 g
s
.766 .807 .886 r
.72891 .12259 m .74105 .11475 L .74386 .11822 L p F P
0 g
s
.948 .938 .746 r
.64498 .22003 m .64496 .22479 L .64934 .21797 L p F P
0 g
s
.948 .938 .746 r
.64869 .21401 m .64498 .22003 L p .64934 .21797 L F P
0 g
s
.948 .938 .746 r
.64934 .21797 m .64918 .21409 L .64869 .21401 L p F P
0 g
s
.949 .957 .685 r
.63295 .24491 m .63232 .24983 L .63631 .24313 L p F P
0 g
s
.949 .957 .685 r
.63631 .24313 m .63668 .23829 L .63295 .24491 L p F P
0 g
s
.907 .982 .773 r
.79476 .27914 m .80027 .27188 L .79917 .27678 L p F P
0 g
s
.907 .982 .773 r
.7943 .28127 m .79476 .27914 L p .79917 .27678 L F P
0 g
s
.907 .982 .773 r
.79917 .27678 m .7957 .28133 L .7943 .28127 L p F P
0 g
s
.099 .271 .752 r
.82193 .14129 m .82219 .146 L .81797 .14208 L p F P
0 g
s
.099 .271 .752 r
.81797 .14208 m .8176 .1374 L .82193 .14129 L p F P
0 g
s
.213 .176 .598 r
.59968 .35995 m .59638 .3655 L .59351 .36087 L p F P
0 g
s
.213 .176 .598 r
.59351 .36087 m .59721 .3552 L .59968 .35995 L p F P
0 g
s
.923 .965 .663 r
.63202 .25146 m .6311 .25194 L .63232 .24983 L closepath p F P
0 g
s
.715 .858 .95 r
.65794 .3831 m .65181 .38602 L .6554 .38109 L closepath p F P
0 g
s
.713 .835 .94 r
.65501 .38076 m .6554 .38109 L .65181 .38602 L p F P
0 g
s
.713 .835 .94 r
.64284 .38618 m .65501 .38076 L p .65181 .38602 L F P
0 g
s
.75 .882 .94 r
.67008 .3768 m .67835 .37222 L .67533 .37757 L p F P
0 g
s
.749 .889 .942 r
.67533 .37757 m .6851 .37191 L .68223 .37002 L p F P
0 g
s
.749 .889 .942 r
.68223 .37002 m .67835 .37222 L .67533 .37757 L p F P
0 g
s
0 0 .05 r
.82999 .18454 m .82991 .18927 L .82979 .18391 L p F P
0 g
s
0 0 .05 r
.82979 .18391 m .82988 .17918 L .82999 .18454 L p F P
0 g
s
.786 .932 .928 r
.71212 .35803 m .7083 .36063 L .71021 .35701 L closepath p F P
0 g
s
.782 .921 .93 r
.70933 .35649 m .71021 .35701 L .7083 .36063 L p F P
0 g
s
.782 .921 .93 r
.69722 .36448 m .70933 .35649 L p .7083 .36063 L F P
0 g
s
.923 .971 .69 r
.81069 .253 m .80981 .25785 L .81385 .25108 L p F P
0 g
s
.923 .971 .69 r
.81381 .2478 m .81069 .253 L p .81385 .25108 L F P
0 g
s
.923 .971 .69 r
.81385 .25108 m .81451 .24765 L .81381 .2478 L p F P
0 g
s
.916 .929 .805 r
.65855 .19463 m .66397 .18747 L .66433 .19216 L p F P
0 g
s
.916 .929 .805 r
.65861 .19641 m .65855 .19463 L p .66433 .19216 L F P
0 g
s
.916 .929 .805 r
.66433 .19216 m .6604 .19718 L .65861 .19641 L p F P
0 g
s
.826 .86 .872 r
.70523 .14164 m .70487 .14194 L .70203 .13919 L p F P
0 g
s
.859 .872 .848 r
.69679 .1498 m .70487 .14194 L .70203 .13919 L p F P
0 g
s
.88 .94 .57 r
.62222 .26938 m .62546 .2629 L .62446 .2679 L p F P
0 g
s
.88 .94 .57 r
.62143 .2728 m .62222 .26938 L p .62446 .2679 L F P
0 g
s
.88 .94 .57 r
.62446 .2679 m .62235 .27191 L .62143 .2728 L p F P
0 g
s
.83 .845 .858 r
.70458 .13698 m .70523 .14164 L .71549 .13285 L p F P
0 g
s
.826 .86 .872 r
.70203 .13919 m .70458 .13698 L .70523 .14164 L p F P
0 g
s
0 0 0 r
.60728 .31079 m .60501 .31611 L .60717 .30995 L p F P
0 g
s
0 0 0 r
.60717 .30995 m .60922 .30469 L .60728 .31079 L p F P
0 g
s
.877 .898 .842 r
.68184 .16673 m .6811 .16619 L .68175 .16551 L closepath p F P
0 g
s
.494 .612 .898 r
.78947 .11698 m .80215 .11748 L .8025 .12221 L p F P
0 g
s
.483 .628 .916 r
.78696 .11299 m .78947 .11698 L .80215 .11748 L p F P
0 g
s
.859 .872 .848 r
.70203 .13919 m .69602 .1452 L .69679 .1498 L p F P
0 g
s
.852 .876 .857 r
.69011 .15098 m .69602 .1452 L .69679 .1498 L p F P
0 g
s
.852 .876 .857 r
.69679 .1498 m .69296 .15345 L .69011 .15098 L p F P
0 g
s
.899 .985 .781 r
.7957 .28133 m .79356 .28406 L .7943 .28127 L closepath p F P
0 g
s
.88 .879 .829 r
.68902 .15774 m .69296 .15345 L .69011 .15098 L p F P
0 g
s
.797 .933 .922 r
.72242 .35068 m .71212 .35803 L .71021 .35701 L p F P
0 g
s
.827 .843 .86 r
.71685 .13167 m .71549 .13285 L .71455 .1292 L closepath p F P
0 g
s
.83 .845 .858 r
.71402 .12864 m .70458 .13698 L p .71549 .13285 L F P
0 g
s
.83 .845 .858 r
.71549 .13285 m .71455 .1292 L .71402 .12864 L p F P
0 g
s
.8 .84 .881 r
.72797 .1233 m .71685 .13167 L .71455 .1292 L p F P
0 g
s
.733 .794 .901 r
.74829 .11596 m .75611 .11191 L .75331 .10819 L p F P
0 g
s
.733 .794 .901 r
.75331 .10819 m .74746 .11134 L .74829 .11596 L p F P
0 g
s
.725 .796 .908 r
.74105 .11475 m .74746 .11134 L .74829 .11596 L p F P
0 g
s
.922 .906 .508 r
.82395 .22522 m .82253 .22663 L .82426 .22214 L closepath p F P
0 g
s
.727 .813 .346 r
.61378 .29255 m .61364 .29284 L .61388 .29228 L closepath p F P
0 g
s
.892 .981 .811 r
.78855 .28663 m .78732 .29154 L .79356 .28406 L p F P
0 g
s
.892 .981 .811 r
.7932 .28107 m .78855 .28663 L p .79356 .28406 L F P
0 g
s
.892 .981 .811 r
.79356 .28406 m .7943 .28127 L .7932 .28107 L p F P
0 g
s
.88 .879 .829 r
.69011 .15098 m .68813 .15318 L .68902 .15774 L p F P
0 g
s
.879 .878 .83 r
.6812 .16084 m .68175 .16551 L .68902 .15774 L p F P
0 g
s
.879 .878 .83 r
.68902 .15774 m .68813 .15318 L .6812 .16084 L p F P
0 g
s
.932 .919 .778 r
.6604 .19718 m .65892 .19931 L .65861 .19641 L closepath p F P
0 g
s
.734 .818 .353 r
.61294 .2934 m .61553 .2871 L .61388 .29228 L p F P
0 g
s
.734 .818 .353 r
.61215 .29582 m .61294 .2934 L p .61388 .29228 L F P
0 g
s
.734 .818 .353 r
.61388 .29228 m .61364 .29284 L .61215 .29582 L p F P
0 g
s
.806 .743 .22 r
.82855 .20072 m .82817 .20535 L .82921 .19959 L p F P
0 g
s
.806 .743 .22 r
.82921 .19959 m .8294 .19728 L .82855 .20072 L p F P
0 g
s
.925 .938 .581 r
.81876 .23484 m .81811 .23966 L .82111 .23323 L p F P
0 g
s
.925 .938 .581 r
.82111 .23323 m .82181 .22839 L .81876 .23484 L p F P
0 g
s
.95 .947 .734 r
.64081 .22679 m .64053 .23163 L .64496 .22479 L p F P
0 g
s
.95 .947 .734 r
.64496 .22479 m .64498 .22003 L .64081 .22679 L p F P
0 g
s
.792 .838 .373 r
.61364 .29284 m .61142 .29852 L .61215 .29582 L closepath p F P
0 g
s
.911 .935 .566 r
.62235 .27191 m .62116 .2744 L .62143 .2728 L closepath p F P
0 g
s
.73 .862 .943 r
.66718 .3746 m .67008 .3768 L .65794 .3831 L p F P
0 g
s
.73 .862 .943 r
.65579 .38037 m .66718 .3746 L p .65794 .3831 L F P
0 g
s
.73 .862 .943 r
.65794 .3831 m .6554 .38109 L .65579 .38037 L p F P
0 g
s
.327 .484 .862 r
.81141 .12934 m .80802 .12796 L .80517 .12264 L p F P
0 g
s
.936 .92 .771 r
.6538 .20158 m .65411 .20626 L .65892 .19931 L p F P
0 g
s
.936 .92 .771 r
.65753 .19598 m .6538 .20158 L p .65892 .19931 L F P
0 g
s
.936 .92 .771 r
.65892 .19931 m .65861 .19641 L .65753 .19598 L p F P
0 g
s
.929 .965 .67 r
.62924 .25154 m .63295 .24491 L .63232 .24983 L p F P
0 g
s
.929 .965 .67 r
.62904 .25292 m .62924 .25154 L p .63232 .24983 L F P
0 g
s
.929 .965 .67 r
.63232 .24983 m .6311 .25194 L .62904 .25292 L p F P
0 g
s
0 0 .213 r
.82989 .17444 m .82988 .17918 L .82916 .17403 L p F P
0 g
s
0 0 .213 r
.82916 .17403 m .82917 .16929 L .82989 .17444 L p F P
0 g
s
.904 .872 .436 r
.82466 .21737 m .82426 .22214 L .82622 .21607 L p F P
0 g
s
.904 .872 .436 r
.82622 .21607 m .82664 .21128 L .82466 .21737 L p F P
0 g
s
.876 .894 .841 r
.67824 .16407 m .6812 .16084 L .68175 .16551 L p F P
0 g
s
.876 .894 .841 r
.68175 .16551 m .6811 .16619 L .67824 .16407 L p F P
0 g
s
.903 .897 .811 r
.67555 .17292 m .6811 .16619 L .67824 .16407 L p F P
0 g
s
.8 .84 .881 r
.72608 .11932 m .72721 .12063 L .72797 .1233 L p F P
0 g
s
.8 .84 .881 r
.71442 .12833 m .72608 .11932 L p .72797 .1233 L F P
0 g
s
.8 .84 .881 r
.71455 .1292 m .71442 .12833 L p .72797 .1233 L F P
0 g
s
.8 .826 .872 r
.72891 .12259 m .72797 .1233 L .72721 .12063 L closepath p F P
0 g
s
.802 .942 .918 r
.72419 .34939 m .72242 .35068 L .72327 .34893 L closepath p F P
0 g
s
.797 .933 .922 r
.72143 .34791 m .72327 .34893 L .72242 .35068 L p F P
0 g
s
.797 .933 .922 r
.71092 .35539 m .72143 .34791 L p .72242 .35068 L F P
0 g
s
.797 .933 .922 r
.71021 .35701 m .71092 .35539 L p .72242 .35068 L F P
0 g
s
.768 .82 .893 r
.73823 .11126 m .74105 .11475 L .72891 .12259 L p F P
0 g
s
.768 .82 .893 r
.72696 .11875 m .73823 .11126 L p .72891 .12259 L F P
0 g
s
.768 .82 .893 r
.72891 .12259 m .72721 .12063 L .72696 .11875 L p F P
0 g
s
.765 .9 .936 r
.69489 .36594 m .6851 .37191 L .68223 .37002 L p F P
0 g
s
.812 .943 .911 r
.73479 .34127 m .72419 .34939 L .72327 .34893 L p F P
0 g
s
.925 .974 .717 r
.80621 .25992 m .8054 .26475 L .80981 .25785 L p F P
0 g
s
.925 .974 .717 r
.80981 .25785 m .81069 .253 L .80621 .25992 L p F P
0 g
s
.939 .965 .727 r
.64043 .23258 m .63987 .23266 L .64053 .23163 L closepath p F P
0 g
s
.89 .979 .82 r
.78191 .29426 m .78855 .28663 L .78732 .29154 L p F P
0 g
s
.89 .979 .82 r
.78176 .29489 m .78191 .29426 L p .78732 .29154 L F P
0 g
s
.89 .979 .82 r
.78732 .29154 m .78398 .29536 L .78176 .29489 L p F P
0 g
s
.949 .951 .652 r
.6311 .25194 m .62877 .2564 L .62904 .25292 L closepath p F P
0 g
s
.869 .97 .855 r
.77274 .30821 m .77215 .30802 L .77307 .30709 L closepath p F P
0 g
s
.903 .923 .537 r
.61914 .27582 m .61828 .28077 L .62116 .2744 L p F P
0 g
s
.903 .923 .537 r
.61952 .27495 m .61914 .27582 L p .62116 .2744 L F P
0 g
s
.903 .923 .537 r
.62116 .2744 m .62143 .2728 L .61952 .27495 L p F P
0 g
s
0 0 .229 r
.6018 .33362 m .59913 .33902 L .59979 .33332 L p F P
0 g
s
0 0 .229 r
.59979 .33332 m .60237 .32793 L .6018 .33362 L p F P
0 g
s
.882 .981 .828 r
.78398 .29536 m .78048 .29922 L .78176 .29489 L closepath p F P
0 g
s
.617 .747 .939 r
.61244 .38728 m .62464 .38435 L .62767 .38783 L p F P
0 g
s
.586 .712 .93 r
.62464 .38435 m .61244 .38728 L .60935 .38258 L p F P
0 g
s
.056 .014 .487 r
.59844 .35298 m .59721 .3552 L .59609 .35003 L p F P
0 g
s
.056 .014 .487 r
.59609 .35003 m .59782 .34694 L .59844 .35298 L p F P
0 g
s
.614 .701 .906 r
.7713 .11104 m .78386 .10819 L .78667 .11254 L p F P
0 g
s
.623 .709 .907 r
.78386 .10819 m .7713 .11104 L .7685 .10705 L p F P
0 g
s
.68 .749 .904 r
.75611 .11191 m .7685 .10705 L .7713 .11104 L p F P
0 g
s
.687 .754 .903 r
.7685 .10705 m .75611 .11191 L .75331 .10819 L p F P
0 g
s
0 0 .38 r
.59925 .3445 m .59782 .34694 L .59769 .34149 L p F P
0 g
s
0 0 .38 r
.59769 .34149 m .59913 .33902 L .59925 .3445 L p F P
0 g
s
.898 .907 .822 r
.66882 .17568 m .67482 .16832 L .67555 .17292 L p F P
0 g
s
.898 .907 .822 r
.66924 .18028 m .66882 .17568 L p .67555 .17292 L F P
0 g
s
.898 .907 .822 r
.67555 .17292 m .6693 .18031 L .66924 .18028 L p F P
0 g
s
.903 .897 .811 r
.67824 .16407 m .67482 .16832 L .67555 .17292 L p F P
0 g
s
0 0 0 r
.605 .31613 m .60499 .31619 L .60501 .31611 L closepath p F P
0 g
s
.92 .977 .747 r
.80524 .26557 m .80482 .26557 L .8054 .26475 L closepath p F P
0 g
s
0 0 0 r
.60568 .31679 m .60728 .31079 L .60501 .31611 L p F P
0 g
s
0 0 0 r
.60413 .32038 m .60568 .31679 L p .60501 .31611 L F P
0 g
s
0 0 0 r
.60501 .31611 m .60499 .31619 L .60413 .32038 L p F P
0 g
s
.456 .503 .818 r
.60307 .37003 m .60155 .36942 L .59773 .37509 L p F P
0 g
s
.456 .503 .818 r
.59773 .37509 m .60623 .377 L .60307 .37003 L p F P
0 g
s
0 0 0 r
.60499 .31619 m .60348 .32208 L .60413 .32038 L closepath p F P
0 g
s
.872 .973 .849 r
.7744 .30217 m .77307 .30709 L .78048 .29922 L p F P
0 g
s
.872 .973 .849 r
.78143 .29478 m .7744 .30217 L p .78048 .29922 L F P
0 g
s
.872 .973 .849 r
.78048 .29922 m .78176 .29489 L .78143 .29478 L p F P
0 g
s
0 0 .379 r
.82912 .16456 m .82917 .16929 L .82776 .16438 L p F P
0 g
s
0 0 .379 r
.82776 .16438 m .8277 .15965 L .82912 .16456 L p F P
0 g
s
.695 .835 .95 r
.65501 .38076 m .64284 .38618 L .63986 .38336 L p F P
0 g
s
.671 .811 .95 r
.62767 .38783 m .63986 .38336 L .64284 .38618 L p F P
0 g
s
.437 .565 .885 r
.80233 .1175 m .80215 .11748 L .8025 .12221 L p F P
0 g
s
.437 .565 .885 r
.8025 .12221 m .80517 .12264 L .80233 .1175 L p F P
0 g
s
.817 .952 .906 r
.73624 .34013 m .73479 .34127 L .73545 .33977 L closepath p F P
0 g
s
.812 .943 .911 r
.73351 .33876 m .73545 .33977 L .73479 .34127 L p F P
0 g
s
.812 .943 .911 r
.7246 .34556 m .73351 .33876 L p .73479 .34127 L F P
0 g
s
.812 .943 .911 r
.72327 .34893 m .7246 .34556 L p .73479 .34127 L F P
0 g
s
.941 .962 .731 r
.63701 .23295 m .64081 .22679 L .64053 .23163 L p F P
0 g
s
.941 .962 .731 r
.64053 .23163 m .63987 .23266 L .63701 .23295 L p F P
0 g
s
.827 .951 .899 r
.74579 .33228 m .73624 .34013 L .73545 .33977 L p F P
0 g
s
.939 .93 .767 r
.64916 .20849 m .64921 .21326 L .65411 .20626 L p F P
0 g
s
.939 .93 .767 r
.65411 .20626 m .6538 .20158 L .64916 .20849 L p F P
0 g
s
.774 .665 .112 r
.82956 .1901 m .82949 .19482 L .82991 .18927 L p F P
0 g
s
.774 .665 .112 r
.82991 .18927 m .82999 .18454 L .82956 .1901 L p F P
0 g
s
.959 .945 .696 r
.63668 .23829 m .63987 .23266 L .63701 .23295 L p F P
0 g
s
.655 .792 .947 r
.63986 .38336 m .62767 .38783 L .62464 .38435 L p F P
0 g
s
.87 .967 .856 r
.76954 .3071 m .7744 .30217 L .77307 .30709 L p F P
0 g
s
.87 .967 .856 r
.77307 .30709 m .77215 .30802 L .76954 .3071 L p F P
0 g
s
.935 .954 .635 r
.81531 .24142 m .81472 .24622 L .81811 .23966 L p F P
0 g
s
.935 .954 .635 r
.81811 .23966 m .81876 .23484 L .81531 .24142 L p F P
0 g
s
.862 .969 .862 r
.76475 .31524 m .77215 .30802 L .76954 .3071 L p F P
0 g
s
.833 .959 .893 r
.74825 .33019 m .74579 .33228 L .74685 .32961 L closepath p F P
0 g
s
.827 .951 .899 r
.74557 .32898 m .74685 .32961 L .74579 .33228 L p F P
0 g
s
.827 .951 .899 r
.73673 .3362 m .74557 .32898 L p .74579 .33228 L F P
0 g
s
.827 .951 .899 r
.73545 .33977 m .73673 .3362 L p .74579 .33228 L F P
0 g
s
.948 .947 .632 r
.62599 .25803 m .62546 .2629 L .62877 .2564 L p F P
0 g
s
.948 .947 .632 r
.62824 .25338 m .62599 .25803 L p .62877 .2564 L F P
0 g
s
.948 .947 .632 r
.62877 .2564 m .62904 .25292 L .62824 .25338 L p F P
0 g
s
.765 .806 .323 r
.6106 .29962 m .60922 .30469 L .61142 .29852 L p F P
0 g
s
.765 .806 .323 r
.61086 .29887 m .6106 .29962 L p .61142 .29852 L F P
0 g
s
.765 .806 .323 r
.61142 .29852 m .61215 .29582 L .61086 .29887 L p F P
0 g
s
.769 .914 .937 r
.69722 .36448 m .69489 .36594 L .69608 .36379 L closepath p F P
0 g
s
.765 .9 .936 r
.69438 .36267 m .69608 .36379 L .69489 .36594 L p F P
0 g
s
.765 .9 .936 r
.68223 .37002 m .69438 .36267 L p .69489 .36594 L F P
0 g
s
.842 .959 .886 r
.75571 .32362 m .74825 .33019 L .74685 .32961 L p F P
0 g
s
.922 .976 .749 r
.80236 .26551 m .80621 .25992 L .8054 .26475 L p F P
0 g
s
.922 .976 .749 r
.8054 .26475 m .80482 .26557 L .80236 .26551 L p F P
0 g
s
.545 .613 .872 r
.60531 .38274 m .6075 .3794 L .60935 .38258 L closepath p F P
0 g
s
.531 .656 .915 r
.78667 .11254 m .78684 .11253 L .78696 .11299 L closepath p F P
0 g
s
.483 .628 .916 r
.7995 .11258 m .78684 .11253 L .78696 .11299 L p F P
0 g
s
.483 .628 .916 r
.80212 .11712 m .7995 .11258 L p .78696 .11299 L F P
0 g
s
.483 .628 .916 r
.80215 .11748 m .80212 .11712 L p .78696 .11299 L F P
0 g
s
.837 .751 .234 r
.82856 .20055 m .82855 .20072 L .8294 .19728 L p F P
0 g
s
.837 .751 .234 r
.8294 .19728 m .82949 .19482 L .82856 .20055 L p F P
0 g
s
.862 .969 .862 r
.76954 .3071 m .76631 .31026 L .76475 .31524 L p F P
0 g
s
.856 .965 .871 r
.75758 .31851 m .76631 .31026 L .76475 .31524 L p F P
0 g
s
.856 .965 .871 r
.76475 .31524 m .76023 .31951 L .75758 .31851 L p F P
0 g
s
.916 .9 .796 r
.6693 .18031 m .66926 .18036 L .66924 .18028 L closepath p F P
0 g
s
.935 .95 .769 r
.64918 .21409 m .64869 .21401 L .64921 .21326 L closepath p F P
0 g
s
.92 .901 .79 r
.66333 .18286 m .66397 .18747 L .66926 .18036 L p F P
0 g
s
.92 .901 .79 r
.66643 .17859 m .66333 .18286 L p .66926 .18036 L F P
0 g
s
.92 .901 .79 r
.66926 .18036 m .66924 .18028 L .66643 .17859 L p F P
0 g
s
.807 .932 .915 r
.72327 .34893 m .72143 .34791 L .7246 .34556 L closepath p F P
0 g
s
.847 .966 .878 r
.75571 .32362 m .76023 .31951 L .75758 .31851 L p F P
0 g
s
.847 .966 .878 r
.75758 .31851 m .75752 .31857 L .75571 .32362 L p F P
0 g
s
.842 .959 .886 r
.74763 .32723 m .75752 .31857 L .75571 .32362 L p F P
0 g
s
.842 .959 .886 r
.74685 .32961 m .74763 .32723 L p .75571 .32362 L F P
0 g
s
0 0 .533 r
.82759 .15491 m .8277 .15965 L .82549 .15502 L p F P
0 g
s
0 0 .533 r
.82549 .15502 m .82535 .15029 L .82759 .15491 L p F P
0 g
s
.915 .98 .752 r
.80027 .27188 m .80482 .26557 L .80236 .26551 L p F P
0 g
s
.904 .909 .816 r
.66924 .18028 m .66643 .17859 L .66882 .17568 L closepath p F P
0 g
s
.732 .798 .905 r
.74746 .11134 m .74105 .11475 L .73823 .11126 L p F P
0 g
s
.934 .964 .678 r
.81451 .24765 m .81381 .2478 L .81472 .24622 L closepath p F P
0 g
s
.784 .915 .928 r
.70652 .35476 m .70933 .35649 L .69722 .36448 L p F P
0 g
s
.784 .915 .928 r
.69744 .36071 m .70652 .35476 L p .69722 .36448 L F P
0 g
s
.784 .915 .928 r
.69722 .36448 m .69608 .36379 L .69744 .36071 L p F P
0 g
s
.904 .977 .799 r
.7943 .28127 m .7932 .28107 L .79476 .27914 L closepath p F P
0 g
s
.88 .926 .538 r
.62143 .2728 m .61952 .27495 L .62222 .26938 L closepath p F P
0 g
s
.542 .666 .917 r
.78684 .11253 m .78667 .11254 L .78386 .10819 L p F P
0 g
s
.878 .832 .363 r
.827 .20649 m .82664 .21128 L .82817 .20535 L p F P
0 g
s
.878 .832 .363 r
.82848 .20087 m .827 .20649 L p .82817 .20535 L F P
0 g
s
.878 .832 .363 r
.82817 .20535 m .82855 .20072 L .82848 .20087 L p F P
0 g
s
.278 .276 .677 r
.60232 .36812 m .60155 .36942 L .59638 .3655 L p F P
0 g
s
.278 .276 .677 r
.59983 .36011 m .60232 .36812 L p .59638 .3655 L F P
0 g
s
.278 .276 .677 r
.59638 .3655 m .59968 .35995 L .59983 .36011 L p F P
0 g
s
.925 .907 .511 r
.82224 .22361 m .82466 .21737 L .82426 .22214 L p F P
0 g
s
.925 .907 .511 r
.82196 .22716 m .82224 .22361 L p .82426 .22214 L F P
0 g
s
.925 .907 .511 r
.82426 .22214 m .82253 .22663 L .82196 .22716 L p F P
0 g
s
.542 .666 .917 r
.78386 .10819 m .78561 .10806 L .78684 .11253 L p F P
0 g
s
.51 .625 .901 r
.79667 .10779 m .78561 .10806 L .78684 .11253 L p F P
0 g
s
.51 .625 .901 r
.78684 .11253 m .7995 .11258 L .79667 .10779 L p F P
0 g
s
.792 .922 .924 r
.71021 .35701 m .70933 .35649 L .71092 .35539 L closepath p F P
0 g
s
.327 .484 .862 r
.80517 .12264 m .81079 .12471 L .81141 .12934 L p F P
0 g
s
.232 .403 .828 r
.81674 .12803 m .81719 .13272 L .81141 .12934 L p F P
0 g
s
.232 .403 .828 r
.81141 .12934 m .81079 .12471 L .81674 .12803 L p F P
0 g
s
.746 .875 .939 r
.67835 .37222 m .67008 .3768 L .66718 .3746 L p F P
0 g
s
.802 .842 .881 r
.71455 .1292 m .71402 .12864 L .71442 .12833 L closepath p F P
0 g
s
0 .135 .663 r
.82517 .14623 m .82535 .15029 L .82219 .146 L p F P
0 g
s
0 .135 .663 r
.82473 .14497 m .82517 .14623 L p .82219 .146 L F P
0 g
s
0 .135 .663 r
.82219 .146 m .82193 .14129 L .82473 .14497 L p F P
0 g
s
.771 .822 .892 r
.72721 .12063 m .72608 .11932 L .72696 .11875 L closepath p F P
0 g
s
.882 .895 .475 r
.6166 .2821 m .61553 .2871 L .61828 .28077 L p F P
0 g
s
.882 .895 .475 r
.61828 .28077 m .61914 .27582 L .6166 .2821 L p F P
0 g
s
.106 .28 .758 r
.82162 .13657 m .82193 .14129 L .8176 .1374 L p F P
0 g
s
.106 .28 .758 r
.8176 .1374 m .81719 .13272 L .82162 .13657 L p F P
0 g
s
.821 .94 .905 r
.73545 .33977 m .73351 .33876 L .73673 .3362 L closepath p F P
0 g
s
.922 .93 .796 r
.65861 .19641 m .65753 .19598 L .65855 .19463 L closepath p F P
0 g
s
.343 .499 .869 r
.81079 .12471 m .80517 .12264 L .80233 .1175 L p F P
0 g
s
.935 .946 .77 r
.64581 .21346 m .64916 .20849 L .64921 .21326 L p F P
0 g
s
.935 .946 .77 r
.64921 .21326 m .64869 .21401 L .64581 .21346 L p F P
0 g
s
.954 .934 .734 r
.64498 .22003 m .64869 .21401 L .64581 .21346 L p F P
0 g
s
.959 .945 .696 r
.63701 .23295 m .63667 .23355 L .63668 .23829 L p F P
0 g
s
.961 .944 .684 r
.63317 .24011 m .63295 .24491 L .63668 .23829 L p F P
0 g
s
.961 .944 .684 r
.63668 .23829 m .63667 .23355 L .63317 .24011 L p F P
0 g
s
.83 .857 .866 r
.70458 .13698 m .70203 .13919 L .69918 .13638 L p F P
0 g
s
.861 .866 .841 r
.69602 .1452 m .70203 .13919 L .69918 .13638 L p F P
0 g
s
0 0 .037 r
.83001 .17981 m .82999 .18454 L .82988 .17918 L p F P
0 g
s
0 0 .037 r
.82988 .17918 m .82989 .17444 L .83001 .17981 L p F P
0 g
s
.837 .856 .859 r
.70458 .13698 m .71402 .12864 L .71117 .12558 L p F P
0 g
s
.837 .856 .859 r
.71117 .12558 m .70366 .1324 L .70458 .13698 L p F P
0 g
s
.83 .857 .866 r
.69918 .13638 m .70366 .1324 L .70458 .13698 L p F P
0 g
s
.91 .979 .781 r
.7957 .27429 m .79476 .27914 L .80027 .27188 L p F P
0 g
s
.91 .979 .781 r
.80027 .27188 m .8013 .26699 L .7957 .27429 L p F P
0 g
s
.915 .98 .752 r
.80236 .26551 m .8013 .26699 L .80027 .27188 L p F P
0 g
s
.923 .909 .789 r
.65817 .18995 m .65855 .19463 L .66397 .18747 L p F P
0 g
s
.923 .909 .789 r
.66397 .18747 m .66333 .18286 L .65817 .18995 L p F P
0 g
s
.802 .84 .88 r
.71442 .12833 m .71402 .12864 L .71117 .12558 L p F P
0 g
s
.861 .866 .841 r
.69918 .13638 m .695 .14065 L .69602 .1452 L p F P
0 g
s
.855 .872 .851 r
.68724 .14842 m .695 .14065 L .69602 .1452 L p F P
0 g
s
.855 .872 .851 r
.69602 .1452 m .69011 .15098 L .68724 .14842 L p F P
0 g
s
.81 .843 .874 r
.71442 .12833 m .72608 .11932 L .72324 .11604 L p F P
0 g
s
.81 .843 .874 r
.72324 .11604 m .71359 .1237 L .71442 .12833 L p F P
0 g
s
.802 .84 .88 r
.71117 .12558 m .71359 .1237 L .71442 .12833 L p F P
0 g
s
.739 .793 .896 r
.74746 .11134 m .75331 .10819 L .75049 .10447 L p F P
0 g
s
.739 .793 .896 r
.75049 .10447 m .74629 .10682 L .74746 .11134 L p F P
0 g
s
.732 .798 .905 r
.73823 .11126 m .74629 .10682 L .74746 .11134 L p F P
0 g
s
0 0 .35 r
.60193 .3391 m .59925 .3445 L .59913 .33902 L p F P
0 g
s
0 0 .35 r
.59913 .33902 m .6018 .33362 L .60193 .3391 L p F P
0 g
s
.936 .964 .68 r
.81149 .24814 m .81531 .24142 L .81472 .24622 L p F P
0 g
s
.936 .964 .68 r
.81148 .24827 m .81149 .24814 L p .81472 .24622 L F P
0 g
s
.936 .964 .68 r
.81472 .24622 m .81381 .2478 L .81148 .24827 L p F P
0 g
s
.882 .872 .823 r
.68813 .15318 m .69011 .15098 L .68724 .14842 L p F P
0 g
s
0 0 .047 r
.60351 .32494 m .60237 .32793 L .60348 .32208 L p F P
0 g
s
0 0 .047 r
.60348 .32208 m .60413 .32038 L .60351 .32494 L p F P
0 g
s
.724 .854 .943 r
.6554 .38109 m .65501 .38076 L .65579 .38037 L closepath p F P
0 g
s
.936 .939 .591 r
.62298 .26445 m .62222 .26938 L .62546 .2629 L p F P
0 g
s
.936 .939 .591 r
.62546 .2629 m .62599 .25803 L .62298 .26445 L p F P
0 g
s
.882 .872 .823 r
.68724 .14842 m .68701 .14868 L .68813 .15318 L p F P
0 g
s
.882 .872 .822 r
.68038 .15625 m .6812 .16084 L .68813 .15318 L p F P
0 g
s
.882 .872 .822 r
.68813 .15318 m .68701 .14868 L .68038 .15625 L p F P
0 g
s
.586 .712 .93 r
.60935 .38258 m .62159 .38052 L .62464 .38435 L p F P
0 g
s
.597 .639 .863 r
.6075 .3794 m .60935 .38258 L .62159 .38052 L p F P
0 g
s
.792 .917 .923 r
.71092 .35539 m .70933 .35649 L .70652 .35476 L p F P
0 g
s
.915 .911 .516 r
.82253 .22663 m .82181 .22839 L .82196 .22716 L closepath p F P
0 g
s
.929 .969 .687 r
.81381 .2478 m .81069 .253 L .81148 .24827 L closepath p F P
0 g
s
.796 .923 .921 r
.71092 .35539 m .72143 .34791 L .71866 .34631 L p F P
0 g
s
.796 .923 .921 r
.71866 .34631 m .71304 .35028 L .71092 .35539 L p F P
0 g
s
.792 .917 .923 r
.70652 .35476 m .71304 .35028 L .71092 .35539 L p F P
0 g
s
.081 .032 .496 r
.60041 .34966 m .59844 .35298 L .59782 .34694 L p F P
0 g
s
.081 .032 .496 r
.59782 .34694 m .59925 .3445 L .60041 .34966 L p F P
0 g
s
.775 .905 .931 r
.69608 .36379 m .69438 .36267 L .69744 .36071 L closepath p F P
0 g
s
.749 .892 .943 r
.68223 .37002 m .67835 .37222 L .68039 .36874 L closepath p F P
0 g
s
.746 .875 .939 r
.67935 .36799 m .68039 .36874 L .67835 .37222 L p F P
0 g
s
.746 .875 .939 r
.66718 .3746 m .67935 .36799 L p .67835 .37222 L F P
0 g
s
.702 .732 .217 r
.60884 .30567 m .60728 .31079 L .60922 .30469 L p F P
0 g
s
.702 .732 .217 r
.60922 .30469 m .6106 .29962 L .60884 .30567 L p F P
0 g
s
.725 .843 .937 r
.65579 .38037 m .65501 .38076 L .65205 .37817 L p F P
0 g
s
.695 .835 .95 r
.63986 .38336 m .65205 .37817 L .65501 .38076 L p F P
0 g
s
.174 .158 .599 r
.59975 .35983 m .59968 .35995 L .59721 .3552 L p F P
0 g
s
.174 .158 .599 r
.59721 .3552 m .59844 .35298 L .59975 .35983 L p F P
0 g
s
.771 .821 .892 r
.72696 .11875 m .72608 .11932 L .72324 .11604 L p F P
0 g
s
.855 .763 .254 r
.82862 .19583 m .82856 .20055 L .82949 .19482 L p F P
0 g
s
.855 .763 .254 r
.82949 .19482 m .82956 .1901 L .82862 .19583 L p F P
0 g
s
.905 .975 .8 r
.79067 .28057 m .7957 .27429 L .79476 .27914 L p F P
0 g
s
.905 .975 .8 r
.79476 .27914 m .7932 .28107 L .79067 .28057 L p F P
0 g
s
.72 .846 .941 r
.65579 .38037 m .66718 .3746 L .66425 .37229 L p F P
0 g
s
.72 .846 .941 r
.66425 .37229 m .65844 .37511 L .65579 .38037 L p F P
0 g
s
.725 .843 .937 r
.65205 .37817 m .65844 .37511 L .65579 .38037 L p F P
0 g
s
.956 .934 .728 r
.64072 .22206 m .64081 .22679 L .64498 .22003 L p F P
0 g
s
.956 .934 .728 r
.64498 .22003 m .64467 .21536 L .64072 .22206 L p F P
0 g
s
.954 .934 .734 r
.64581 .21346 m .64467 .21536 L .64498 .22003 L p F P
0 g
s
.779 .823 .887 r
.72696 .11875 m .73823 .11126 L .73541 .10776 L p F P
0 g
s
.779 .823 .887 r
.73541 .10776 m .7261 .11412 L .72696 .11875 L p F P
0 g
s
.771 .821 .892 r
.72324 .11604 m .7261 .11412 L .72696 .11875 L p F P
0 g
s
.921 .925 .797 r
.65465 .19473 m .65817 .18995 L .65855 .19463 L p F P
0 g
s
.921 .925 .797 r
.65855 .19463 m .65753 .19598 L .65465 .19473 L p F P
0 g
s
.933 .942 .598 r
.81933 .23002 m .81876 .23484 L .82181 .22839 L p F P
0 g
s
.933 .942 .598 r
.82024 .22808 m .81933 .23002 L p .82181 .22839 L F P
0 g
s
.933 .942 .598 r
.82181 .22839 m .82196 .22716 L .82024 .22808 L p F P
0 g
s
0 0 .204 r
.82985 .16971 m .82989 .17444 L .82917 .16929 L p F P
0 g
s
0 0 .204 r
.82917 .16929 m .82912 .16456 L .82985 .16971 L p F P
0 g
s
.879 .888 .835 r
.67537 .16186 m .68038 .15625 L .6812 .16084 L p F P
0 g
s
.879 .888 .835 r
.6812 .16084 m .67824 .16407 L .67537 .16186 L p F P
0 g
s
.623 .709 .907 r
.7685 .10705 m .78106 .1039 L .78386 .10819 L p F P
0 g
s
.632 .716 .908 r
.78106 .1039 m .7685 .10705 L .76569 .10308 L p F P
0 g
s
.687 .754 .903 r
.75331 .10819 m .76569 .10308 L .7685 .10705 L p F P
0 g
s
.836 .948 .893 r
.74685 .32961 m .74557 .32898 L .74763 .32723 L closepath p F P
0 g
s
.726 .791 .307 r
.61215 .29582 m .61086 .29887 L .61294 .2934 L closepath p F P
0 g
s
.898 .979 .806 r
.78855 .28663 m .7932 .28107 L .79067 .28057 L p F P
0 g
s
.693 .759 .902 r
.76569 .10308 m .75331 .10819 L .75049 .10447 L p F P
0 g
s
.914 .879 .453 r
.82498 .2126 m .82466 .21737 L .82664 .21128 L p F P
0 g
s
.914 .879 .453 r
.82664 .21128 m .827 .20649 L .82498 .2126 L p F P
0 g
s
.941 .917 .762 r
.6538 .20158 m .65753 .19598 L .65465 .19473 L p F P
0 g
s
.904 .887 .805 r
.67482 .16832 m .67824 .16407 L .67537 .16186 L p F P
0 g
s
.765 .894 .934 r
.69153 .36072 m .69438 .36267 L .68223 .37002 L p F P
0 g
s
.765 .894 .934 r
.68122 .36689 m .69153 .36072 L p .68223 .37002 L F P
0 g
s
.765 .894 .934 r
.68223 .37002 m .68039 .36874 L .68122 .36689 L p F P
0 g
s
.955 .95 .669 r
.62969 .24667 m .62924 .25154 L .63295 .24491 L p F P
0 g
s
.955 .95 .669 r
.63295 .24491 m .63317 .24011 L .62969 .24667 L p F P
0 g
s
.839 .862 .411 r
.61422 .28833 m .61294 .2934 L .61553 .2871 L p F P
0 g
s
.839 .862 .411 r
.61553 .2871 m .6166 .2821 L .61422 .28833 L p F P
0 g
s
.926 .974 .735 r
.80695 .2551 m .80621 .25992 L .81069 .253 L p F P
0 g
s
.926 .974 .735 r
.81141 .24827 m .80695 .2551 L p .81069 .253 L F P
0 g
s
.926 .974 .735 r
.81069 .253 m .81148 .24827 L .81141 .24827 L p F P
0 g
s
.685 .822 .949 r
.65205 .37817 m .63986 .38336 L .63686 .38032 L p F P
0 g
s
.655 .792 .947 r
.62464 .38435 m .63686 .38032 L .63986 .38336 L p F P
0 g
s
.807 .928 .914 r
.7246 .34556 m .72143 .34791 L .71866 .34631 L p F P
0 g
s
.932 .958 .645 r
.62904 .25292 m .62824 .25338 L .62924 .25154 L closepath p F P
0 g
s
.635 .769 .944 r
.63686 .38032 m .62464 .38435 L .62159 .38052 L p F P
0 g
s
.898 .979 .806 r
.79067 .28057 m .78971 .28172 L .78855 .28663 L p F P
0 g
s
.891 .974 .825 r
.78296 .28939 m .78191 .29426 L .78855 .28663 L p F P
0 g
s
.891 .974 .825 r
.78855 .28663 m .78971 .28172 L .78296 .28939 L p F P
0 g
s
0 0 .072 r
.6045 .32266 m .60351 .32494 L .60413 .32038 L p F P
0 g
s
0 0 .072 r
.60413 .32038 m .60568 .31679 L .6045 .32266 L p F P
0 g
s
.531 .581 .85 r
.60623 .377 m .60932 .37703 L .6075 .3794 L closepath p F P
0 g
s
.597 .639 .863 r
.61852 .37626 m .60932 .37703 L .6075 .3794 L p F P
0 g
s
.597 .639 .863 r
.62159 .38052 m .61852 .37626 L p .6075 .3794 L F P
0 g
s
.904 .887 .805 r
.6681 .17107 m .66882 .17568 L .67482 .16832 L p F P
0 g
s
.904 .887 .805 r
.67482 .16832 m .67384 .16379 L .6681 .17107 L p F P
0 g
s
.904 .887 .805 r
.67537 .16186 m .67384 .16379 L .67482 .16832 L p F P
0 g
s
.811 .935 .912 r
.7246 .34556 m .73351 .33876 L .73077 .33728 L p F P
0 g
s
.811 .935 .912 r
.73077 .33728 m .72655 .34048 L .7246 .34556 L p F P
0 g
s
.807 .928 .914 r
.71866 .34631 m .72655 .34048 L .7246 .34556 L p F P
0 g
s
.884 .97 .838 r
.78176 .29489 m .78143 .29478 L .78191 .29426 L closepath p F P
0 g
s
.452 .58 .891 r
.80215 .11748 m .80212 .11712 L .80233 .1175 L closepath p F P
0 g
s
0 0 .383 r
.82904 .16094 m .82912 .16456 L .8277 .15965 L p F P
0 g
s
0 0 .383 r
.82811 .15665 m .82904 .16094 L p .8277 .15965 L F P
0 g
s
0 0 .383 r
.8277 .15965 m .82759 .15491 L .82811 .15665 L p F P
0 g
s
.89 .93 .549 r
.62005 .27084 m .62298 .26445 L .62222 .26938 L p F P
0 g
s
.89 .93 .549 r
.61921 .27529 m .62005 .27084 L p .62222 .26938 L F P
0 g
s
.89 .93 .549 r
.62222 .26938 m .61952 .27495 L .61921 .27529 L p F P
0 g
s
.945 .934 .587 r
.82196 .22716 m .82024 .22808 L .82224 .22361 L closepath p F P
0 g
s
.552 .673 .918 r
.78561 .10806 m .78386 .10819 L .78106 .1039 L p F P
0 g
s
.343 .499 .869 r
.80233 .1175 m .81012 .12008 L .81079 .12471 L p F P
0 g
s
.324 .505 .881 r
.80212 .11712 m .80233 .1175 L .81012 .12008 L p F P
0 g
s
.941 .917 .762 r
.65465 .19473 m .65319 .19697 L .6538 .20158 L p F P
0 g
s
.943 .917 .759 r
.64877 .20382 m .64916 .20849 L .6538 .20158 L p F P
0 g
s
.943 .917 .759 r
.6538 .20158 m .65319 .19697 L .64877 .20382 L p F P
0 g
s
.404 .559 .894 r
.7995 .11258 m .80121 .11292 L .80212 .11712 L closepath p F P
0 g
s
.324 .505 .881 r
.80941 .11544 m .80121 .11292 L .80212 .11712 L p F P
0 g
s
.324 .505 .881 r
.81012 .12008 m .80941 .11544 L p .80212 .11712 L F P
0 g
s
.738 .799 .901 r
.74629 .10682 m .73823 .11126 L .73541 .10776 L p F P
0 g
s
.947 .954 .729 r
.63676 .22877 m .64072 .22206 L .64081 .22679 L p F P
0 g
s
.947 .954 .729 r
.63665 .23297 m .63676 .22877 L p .64081 .22679 L F P
0 g
s
.947 .954 .729 r
.64081 .22679 m .63701 .23295 L .63665 .23297 L p F P
0 g
s
.791 .677 .128 r
.82956 .18538 m .82956 .1901 L .82999 .18454 L p F P
0 g
s
.791 .677 .128 r
.82999 .18454 m .83001 .17981 L .82956 .18538 L p F P
0 g
s
.885 .967 .839 r
.77884 .2939 m .78296 .28939 L .78191 .29426 L p F P
0 g
s
.885 .967 .839 r
.78191 .29426 m .78143 .29478 L .77884 .2939 L p F P
0 g
s
.878 .97 .845 r
.7744 .30217 m .78143 .29478 L .77884 .2939 L p F P
0 g
s
.822 .937 .904 r
.73673 .3362 m .73351 .33876 L .73077 .33728 L p F P
0 g
s
0 0 .163 r
.60322 .32989 m .6018 .33362 L .60237 .32793 L p F P
0 g
s
0 0 .163 r
.60237 .32793 m .60351 .32494 L .60322 .32989 L p F P
0 g
s
.479 .531 .833 r
.60932 .37703 m .60623 .377 L .60307 .37003 L p F P
0 g
s
.827 .944 .9 r
.73673 .3362 m .74557 .32898 L .74286 .32761 L p F P
0 g
s
.827 .944 .9 r
.74286 .32761 m .73848 .33118 L .73673 .3362 L p F P
0 g
s
.822 .937 .904 r
.73077 .33728 m .73848 .33118 L .73673 .3362 L p F P
0 g
s
.94 .955 .647 r
.81583 .23663 m .81531 .24142 L .81876 .23484 L p F P
0 g
s
.94 .955 .647 r
.81876 .23484 m .81933 .23002 L .81583 .23663 L p F P
0 g
s
.902 .903 .815 r
.66354 .17676 m .6681 .17107 L .66882 .17568 L p F P
0 g
s
.902 .903 .815 r
.66882 .17568 m .66643 .17859 L .66354 .17676 L p F P
0 g
s
0 0 0 r
.60739 .31163 m .60568 .31679 L .60728 .31079 L p F P
0 g
s
0 0 0 r
.60728 .31079 m .60884 .30567 L .60739 .31163 L p F P
0 g
s
0 0 .529 r
.82756 .15423 m .82759 .15491 L .82535 .15029 L p F P
0 g
s
0 0 .529 r
.82535 .15029 m .82517 .14623 L .82756 .15423 L p F P
0 g
s
.552 .673 .918 r
.78106 .1039 m .78437 .10357 L .78561 .10806 L p F P
0 g
s
.522 .637 .905 r
.79385 .10309 m .78437 .10357 L .78561 .10806 L p F P
0 g
s
.522 .637 .905 r
.78561 .10806 m .79667 .10779 L .79385 .10309 L p F P
0 g
s
.2 .178 .607 r
.60304 .35437 m .59975 .35983 L .59844 .35298 L p F P
0 g
s
.2 .178 .607 r
.59844 .35298 m .60041 .34966 L .60304 .35437 L p F P
0 g
s
.008 0 .469 r
.60298 .3443 m .60041 .34966 L .59925 .3445 L p F P
0 g
s
.008 0 .469 r
.59925 .3445 m .60193 .3391 L .60298 .3443 L p F P
0 g
s
.938 .957 .653 r
.62624 .25323 m .62969 .24667 L .62924 .25154 L p F P
0 g
s
.938 .957 .653 r
.62611 .25448 m .62624 .25323 L p .62924 .25154 L F P
0 g
s
.938 .957 .653 r
.62924 .25154 m .62824 .25338 L .62611 .25448 L p F P
0 g
s
.878 .97 .845 r
.77884 .2939 m .77566 .29724 L .7744 .30217 L p F P
0 g
s
.871 .966 .855 r
.76773 .3053 m .77566 .29724 L .7744 .30217 L p F P
0 g
s
.871 .966 .855 r
.76748 .30635 m .76773 .3053 L p .7744 .30217 L F P
0 g
s
.871 .966 .855 r
.7744 .30217 m .76954 .3071 L .76748 .30635 L p F P
0 g
s
.925 .974 .748 r
.80206 .26217 m .80695 .2551 L .80621 .25992 L p F P
0 g
s
.925 .974 .748 r
.80159 .26548 m .80206 .26217 L p .80621 .25992 L F P
0 g
s
.925 .974 .748 r
.80621 .25992 m .80236 .26551 L .80159 .26548 L p F P
0 g
s
.244 .416 .834 r
.81634 .1244 m .81674 .12803 L .81079 .12471 L p F P
0 g
s
.244 .416 .834 r
.81568 .12301 m .81634 .1244 L p .81079 .12471 L F P
0 g
s
.244 .416 .834 r
.81079 .12471 m .81012 .12008 L .81568 .12301 L p F P
0 g
s
.897 .831 .365 r
.82855 .20072 m .82848 .20087 L .82856 .20055 L closepath p F P
0 g
s
.776 .899 .929 r
.69744 .36071 m .69438 .36267 L .69153 .36072 L p F P
0 g
s
.924 .898 .783 r
.66333 .18286 m .66643 .17859 L .66354 .17676 L p F P
0 g
s
.836 .944 .893 r
.74763 .32723 m .74557 .32898 L .74286 .32761 L p F P
0 g
s
.738 .874 .944 r
.67935 .36799 m .66718 .3746 L .66425 .37229 L p F P
0 g
s
.901 .833 .369 r
.8272 .20174 m .82862 .19583 L .82856 .20055 L p F P
0 g
s
.901 .833 .369 r
.82718 .20346 m .8272 .20174 L p .82856 .20055 L F P
0 g
s
.901 .833 .369 r
.82856 .20055 m .82848 .20087 L .82718 .20346 L p F P
0 g
s
.863 .967 .863 r
.76954 .3071 m .76631 .31026 L .76748 .30635 L closepath p F P
0 g
s
.838 .951 .891 r
.74916 .32226 m .74763 .32723 L .75752 .31857 L p F P
0 g
s
.836 .944 .893 r
.74286 .32761 m .74916 .32226 L .74763 .32723 L p F P
0 g
s
.938 .913 .533 r
.82252 .21886 m .82224 .22361 L .82466 .21737 L p F P
0 g
s
.938 .913 .533 r
.82466 .21737 m .82498 .2126 L .82252 .21886 L p F P
0 g
s
.738 .799 .318 r
.61205 .29451 m .61422 .28833 L .61294 .2934 L p F P
0 g
s
.738 .799 .318 r
.61068 .29929 m .61205 .29451 L p .61294 .2934 L F P
0 g
s
.738 .799 .318 r
.61294 .2934 m .61086 .29887 L .61068 .29929 L p F P
0 g
s
.406 .44 .783 r
.60155 .36942 m .60232 .36812 L .60307 .37003 L closepath p F P
0 g
s
.858 .961 .871 r
.76691 .30609 m .76748 .30635 L .76631 .31026 L p F P
0 g
s
.858 .961 .871 r
.75885 .31365 m .76691 .30609 L p .76631 .31026 L F P
0 g
s
.858 .961 .871 r
.75754 .3185 m .75885 .31365 L p .76631 .31026 L F P
0 g
s
.858 .961 .871 r
.76631 .31026 m .75758 .31851 L .75754 .3185 L p F P
0 g
s
0 .132 .662 r
.82162 .13658 m .82162 .13657 L .82193 .14129 L p F P
0 g
s
0 .132 .662 r
.82193 .14129 m .82473 .14497 L .82162 .13658 L p F P
0 g
s
.89 .834 .368 r
.82848 .20087 m .827 .20649 L .82718 .20346 L closepath p F P
0 g
s
.958 .942 .635 r
.62824 .25338 m .62599 .25803 L .62611 .25448 L closepath p F P
0 g
s
.132 .306 .774 r
.82162 .13656 m .82162 .13657 L .81719 .13272 L p F P
0 g
s
.132 .306 .774 r
.81864 .12955 m .82162 .13656 L p .81719 .13272 L F P
0 g
s
.132 .306 .774 r
.81719 .13272 m .81674 .12803 L .81864 .12955 L p F P
0 g
s
.849 .962 .879 r
.75758 .31851 m .75752 .31857 L .75754 .3185 L closepath p F P
0 g
s
.838 .951 .891 r
.75491 .31723 m .74916 .32226 L p .75752 .31857 L F P
0 g
s
.838 .951 .891 r
.75752 .31857 m .75754 .3185 L .75491 .31723 L p F P
0 g
s
.851 .95 .88 r
.75754 .3185 m .75491 .31723 L .75885 .31365 L closepath p F P
0 g
s
.778 .906 .93 r
.69744 .36071 m .70652 .35476 L .7037 .35296 L p F P
0 g
s
.778 .906 .93 r
.7037 .35296 m .69969 .35556 L .69744 .36071 L p F P
0 g
s
.776 .899 .929 r
.69153 .36072 m .69969 .35556 L .69744 .36071 L p F P
0 g
s
.921 .924 .545 r
.61952 .27495 m .61914 .27582 L .61921 .27529 L closepath p F P
0 g
s
.833 .854 .861 r
.70366 .1324 m .69918 .13638 L .69631 .13351 L p F P
0 g
s
.863 .859 .835 r
.695 .14065 m .69918 .13638 L .69631 .13351 L p F P
0 g
s
.939 .937 .766 r
.64429 .2107 m .64877 .20382 L .64916 .20849 L p F P
0 g
s
.939 .937 .766 r
.6444 .21312 m .64429 .2107 L p .64916 .20849 L F P
0 g
s
.939 .937 .766 r
.64916 .20849 m .64581 .21346 L .6444 .21312 L p F P
0 g
s
.84 .851 .853 r
.70366 .1324 m .71117 .12558 L .70832 .12248 L p F P
0 g
s
.84 .851 .853 r
.70832 .12248 m .7025 .12787 L .70366 .1324 L p F P
0 g
s
.833 .854 .861 r
.69631 .13351 m .7025 .12787 L .70366 .1324 L p F P
0 g
s
.806 .838 .875 r
.71359 .1237 m .71117 .12558 L .70832 .12248 L p F P
0 g
s
.962 .938 .704 r
.63701 .23295 m .63667 .23355 L .63665 .23297 L closepath p F P
0 g
s
.863 .859 .835 r
.69631 .13351 m .69376 .13617 L .695 .14065 L p F P
0 g
s
.858 .868 .846 r
.68605 .14411 m .69376 .13617 L .695 .14065 L p F P
0 g
s
.858 .868 .846 r
.68683 .14805 m .68605 .14411 L p .695 .14065 L F P
0 g
s
.858 .868 .846 r
.695 .14065 m .68724 .14842 L .68683 .14805 L p F P
0 g
s
0 0 .022 r
.82995 .17509 m .83001 .17981 L .82989 .17444 L p F P
0 g
s
0 0 .022 r
.82989 .17444 m .82985 .16971 L .82995 .17509 L p F P
0 g
s
.744 .793 .892 r
.74629 .10682 m .75049 .10447 L .74767 .10075 L p F P
0 g
s
.744 .793 .892 r
.74767 .10075 m .74486 .10237 L .74629 .10682 L p F P
0 g
s
.738 .799 .901 r
.73541 .10776 m .74486 .10237 L .74629 .10682 L p F P
0 g
s
.911 .909 .509 r
.6171 .27795 m .6166 .2821 L .61914 .27582 L p F P
0 g
s
.911 .909 .509 r
.61914 .27582 m .61921 .27529 L .6171 .27795 L p F P
0 g
s
.924 .898 .783 r
.66354 .17676 m .66243 .17833 L .66333 .18286 L p F P
0 g
s
.925 .898 .781 r
.65749 .18534 m .65817 .18995 L .66333 .18286 L p F P
0 g
s
.925 .898 .781 r
.66333 .18286 m .66243 .17833 L .65749 .18534 L p F P
0 g
s
.813 .838 .869 r
.71359 .1237 m .72324 .11604 L .7204 .11272 L p F P
0 g
s
.813 .838 .869 r
.7204 .11272 m .71249 .11915 L .71359 .1237 L p F P
0 g
s
.806 .838 .875 r
.70832 .12248 m .71249 .11915 L .71359 .1237 L p F P
0 g
s
.965 .937 .691 r
.63301 .23542 m .63317 .24011 L .63667 .23355 L p F P
0 g
s
.965 .937 .691 r
.63412 .23326 m .63301 .23542 L p .63667 .23355 L F P
0 g
s
.965 .937 .691 r
.63667 .23355 m .63665 .23297 L .63412 .23326 L p F P
0 g
s
.757 .885 .936 r
.68039 .36874 m .67935 .36799 L .68122 .36689 L closepath p F P
0 g
s
.918 .977 .757 r
.80236 .26551 m .8013 .26699 L .80159 .26548 L closepath p F P
0 g
s
.479 .531 .833 r
.60307 .37003 m .61274 .37148 L .60932 .37703 L p F P
0 g
s
.557 .648 .895 r
.61542 .3715 m .61274 .37148 L .60932 .37703 L p F P
0 g
s
.557 .648 .895 r
.60932 .37703 m .61852 .37626 L .61542 .3715 L p F P
0 g
s
.88 .865 .821 r
.68724 .14842 m .68701 .14868 L .68683 .14805 L closepath p F P
0 g
s
.884 .867 .817 r
.67932 .15172 m .68038 .15625 L .68701 .14868 L p F P
0 g
s
.884 .867 .817 r
.68436 .14583 m .67932 .15172 L p .68701 .14868 L F P
0 g
s
.884 .867 .817 r
.68701 .14868 m .68683 .14805 L .68436 .14583 L p F P
0 g
s
.91 .975 .791 r
.79657 .26944 m .7957 .27429 L .8013 .26699 L p F P
0 g
s
.91 .975 .791 r
.79986 .26515 m .79657 .26944 L p .8013 .26699 L F P
0 g
s
.91 .975 .791 r
.8013 .26699 m .80159 .26548 L .79986 .26515 L p F P
0 g
s
.266 .273 .681 r
.59968 .35995 m .59975 .35983 L .59983 .36011 L closepath p F P
0 g
s
.5 .496 .784 r
.60232 .36812 m .60307 .37003 L .61274 .37148 L p F P
0 g
s
.632 .716 .908 r
.76569 .10308 m .77825 .09966 L .78106 .1039 L p F P
0 g
s
.64 .723 .908 r
.77825 .09966 m .76569 .10308 L .76288 .09914 L p F P
0 g
s
.693 .759 .902 r
.75049 .10447 m .76288 .09914 L .76569 .10308 L p F P
0 g
s
.389 .354 .699 r
.60774 .35845 m .60304 .35437 L .59975 .35983 L p F P
0 g
s
.389 .354 .699 r
.60515 .36379 m .60774 .35845 L p .59975 .35983 L F P
0 g
s
.389 .354 .699 r
.59975 .35983 m .59983 .36011 L .60515 .36379 L p F P
0 g
s
.886 .912 .509 r
.61725 .27721 m .6171 .27795 L .61921 .27529 L p F P
0 g
s
.886 .912 .509 r
.61921 .27529 m .62005 .27084 L .61725 .27721 L p F P
0 g
s
.352 .357 .725 r
.59983 .36011 m .60515 .36379 L .60232 .36812 L closepath p F P
0 g
s
.942 .961 .686 r
.81196 .24337 m .81149 .24814 L .81531 .24142 L p F P
0 g
s
.942 .961 .686 r
.81531 .24142 m .81583 .23663 L .81196 .24337 L p F P
0 g
s
.953 .951 .712 r
.63665 .23297 m .63412 .23326 L .63676 .22877 L closepath p F P
0 g
s
.776 .82 .888 r
.7261 .11412 m .72324 .11604 L .7204 .11272 L p F P
0 g
s
.5 .496 .784 r
.61229 .3659 m .60515 .36379 L .60232 .36812 L p F P
0 g
s
.5 .496 .784 r
.61392 .36895 m .61229 .3659 L p .60232 .36812 L F P
0 g
s
.5 .496 .784 r
.61274 .37148 m .61392 .36895 L p .60232 .36812 L F P
0 g
s
.717 .831 .935 r
.65844 .37511 m .65205 .37817 L .64908 .37543 L p F P
0 g
s
.685 .822 .949 r
.63686 .38032 m .64908 .37543 L .65205 .37817 L p F P
0 g
s
.953 .923 .738 r
.64581 .21346 m .64467 .21536 L .6444 .21312 L closepath p F P
0 g
s
.699 .762 .901 r
.76288 .09914 m .75049 .10447 L .74767 .10075 L p F P
0 g
s
.791 .913 .923 r
.71304 .35028 m .70652 .35476 L .7037 .35296 L p F P
0 g
s
.957 .936 .613 r
.62327 .25964 m .62298 .26445 L .62599 .25803 L p F P
0 g
s
.957 .936 .613 r
.62538 .25494 m .62327 .25964 L p .62599 .25803 L F P
0 g
s
.957 .936 .613 r
.62599 .25803 m .62611 .25448 L .62538 .25494 L p F P
0 g
s
.862 .87 .843 r
.68683 .14805 m .68436 .14583 L .68605 .14411 L closepath p F P
0 g
s
.776 .82 .888 r
.7204 .11272 m .72496 .10957 L .7261 .11412 L p F P
0 g
s
.783 .82 .882 r
.7261 .11412 m .73541 .10776 L .73257 .10423 L p F P
0 g
s
.783 .82 .882 r
.73257 .10423 m .72496 .10957 L .7261 .11412 L p F P
0 g
s
.635 .769 .944 r
.62159 .38052 m .63384 .37705 L .63686 .38032 L p F P
0 g
s
.609 .742 .939 r
.63384 .37705 m .62159 .38052 L .61852 .37626 L p F P
0 g
s
.417 .571 .899 r
.80121 .11292 m .7995 .11258 L .79667 .10779 L p F P
0 g
s
.87 .772 .27 r
.8286 .19113 m .82862 .19583 L .82956 .1901 L p F P
0 g
s
.87 .772 .27 r
.82956 .1901 m .82956 .18538 L .8286 .19113 L p F P
0 g
s
.882 .882 .829 r
.67268 .15931 m .67932 .15172 L .68038 .15625 L p F P
0 g
s
.882 .882 .829 r
.67277 .15977 m .67268 .15931 L p .68038 .15625 L F P
0 g
s
.882 .882 .829 r
.68038 .15625 m .67537 .16186 L .67277 .15977 L p F P
0 g
s
.957 .923 .728 r
.6403 .21741 m .64072 .22206 L .64467 .21536 L p F P
0 g
s
.957 .923 .728 r
.64292 .21282 m .6403 .21741 L p .64467 .21536 L F P
0 g
s
.957 .923 .728 r
.64467 .21536 m .6444 .21312 L .64292 .21282 L p F P
0 g
s
.799 .82 .342 r
.61086 .29887 m .6106 .29962 L .61068 .29929 L closepath p F P
0 g
s
0 0 .017 r
.60634 .31747 m .6045 .32266 L .60568 .31679 L p F P
0 g
s
0 0 .017 r
.60568 .31679 m .60739 .31163 L .60634 .31747 L p F P
0 g
s
.923 .916 .791 r
.65244 .1924 m .65749 .18534 L .65817 .18995 L p F P
0 g
s
.923 .916 .791 r
.65259 .19374 m .65244 .1924 L p .65817 .18995 L F P
0 g
s
.923 .916 .791 r
.65817 .18995 m .65465 .19473 L .65259 .19374 L p F P
0 g
s
0 0 .191 r
.82977 .16659 m .82985 .16971 L .82912 .16456 L p F P
0 g
s
0 0 .191 r
.82912 .16456 m .82904 .16094 L .82977 .16659 L p F P
0 g
s
0 0 .297 r
.60335 .33535 m .60193 .3391 L .6018 .33362 L p F P
0 g
s
0 0 .297 r
.6018 .33362 m .60322 .32989 L .60335 .33535 L p F P
0 g
s
.672 .807 .948 r
.64908 .37543 m .63686 .38032 L .63384 .37705 L p F P
0 g
s
.947 .934 .59 r
.81966 .22526 m .82252 .21886 L .82224 .22361 L p F P
0 g
s
.947 .934 .59 r
.81949 .22846 m .81966 .22526 L p .82224 .22361 L F P
0 g
s
.947 .934 .59 r
.82224 .22361 m .82024 .22808 L .81949 .22846 L p F P
0 g
s
.562 .68 .918 r
.78437 .10357 m .78106 .1039 L .77825 .09966 L p F P
0 g
s
.907 .973 .8 r
.79058 .27688 m .79657 .26944 L .7957 .27429 L p F P
0 g
s
.907 .973 .8 r
.79 .28042 m .79058 .27688 L p .7957 .27429 L F P
0 g
s
.907 .973 .8 r
.7957 .27429 m .79067 .28057 L .79 .28042 L p F P
0 g
s
.757 .769 .264 r
.60942 .30305 m .60884 .30567 L .6106 .29962 L p F P
0 g
s
.757 .769 .264 r
.6106 .29962 m .61068 .29929 L .60942 .30305 L p F P
0 g
s
0 0 .191 r
.60388 .32837 m .60322 .32989 L .60351 .32494 L p F P
0 g
s
0 0 .191 r
.60351 .32494 m .6045 .32266 L .60388 .32837 L p F P
0 g
s
.757 .877 .933 r
.68122 .36689 m .67935 .36799 L .67646 .36576 L p F P
0 g
s
.738 .874 .944 r
.66425 .37229 m .67646 .36576 L .67935 .36799 L p F P
0 g
s
.794 .922 .923 r
.71304 .35028 m .71866 .34631 L .71587 .34466 L p F P
0 g
s
.794 .922 .923 r
.71587 .34466 m .71519 .34514 L .71304 .35028 L p F P
0 g
s
.791 .913 .923 r
.7037 .35296 m .71519 .34514 L .71304 .35028 L p F P
0 g
s
.927 .889 .476 r
.82523 .20784 m .82498 .2126 L .827 .20649 L p F P
0 g
s
.927 .889 .476 r
.82638 .20435 m .82523 .20784 L p .827 .20649 L F P
0 g
s
.927 .889 .476 r
.827 .20649 m .82718 .20346 L .82638 .20435 L p F P
0 g
s
.901 .877 .803 r
.67537 .16186 m .67384 .16379 L .67277 .15977 L closepath p F P
0 g
s
.967 .937 .67 r
.62973 .24192 m .62969 .24667 L .63317 .24011 L p F P
0 g
s
.967 .937 .67 r
.63317 .24011 m .63301 .23542 L .62973 .24192 L p F P
0 g
s
.921 .969 .777 r
.80159 .26548 m .79986 .26515 L .80206 .26217 L closepath p F P
0 g
s
.708 .748 .24 r
.61012 .30062 m .60942 .30305 L .61068 .29929 L p F P
0 g
s
.708 .748 .24 r
.61068 .29929 m .61205 .29451 L .61012 .30062 L p F P
0 g
s
.757 .883 .935 r
.68122 .36689 m .69153 .36072 L .68866 .35869 L p F P
0 g
s
.757 .883 .935 r
.68866 .35869 m .68346 .36174 L .68122 .36689 L p F P
0 g
s
.757 .877 .933 r
.67646 .36576 m .68346 .36174 L .68122 .36689 L p F P
0 g
s
.905 .879 .798 r
.66712 .16653 m .6681 .17107 L .67384 .16379 L p F P
0 g
s
.905 .879 .798 r
.67247 .15954 m .66712 .16653 L p .67384 .16379 L F P
0 g
s
.905 .879 .798 r
.67384 .16379 m .67277 .15977 L .67247 .15954 L p F P
0 g
s
.937 .967 .721 r
.81148 .24827 m .81141 .24827 L .81149 .24814 L closepath p F P
0 g
s
.899 .889 .466 r
.61495 .28343 m .61422 .28833 L .6166 .2821 L p F P
0 g
s
.899 .889 .466 r
.61669 .2786 m .61495 .28343 L p .6166 .2821 L F P
0 g
s
.899 .889 .466 r
.6166 .2821 m .6171 .27795 L .61669 .2786 L p F P
0 g
s
.354 .522 .884 r
.80866 .1108 m .80941 .11544 L .80121 .11292 L p F P
0 g
s
.354 .522 .884 r
.80121 .11292 m .80017 .10838 L .80866 .1108 L p F P
0 g
s
.417 .571 .899 r
.79667 .10779 m .80017 .10838 L .80121 .11292 L p F P
0 g
s
.939 .905 .763 r
.65465 .19473 m .65319 .19697 L .65259 .19374 L closepath p F P
0 g
s
.72 .854 .946 r
.66425 .37229 m .65844 .37511 L .66154 .37004 L closepath p F P
0 g
s
.717 .831 .935 r
.66131 .36984 m .66154 .37004 L .65844 .37511 L p F P
0 g
s
.717 .831 .935 r
.64908 .37543 m .66131 .36984 L p .65844 .37511 L F P
0 g
s
.743 .8 .898 r
.74486 .10237 m .73541 .10776 L .73257 .10423 L p F P
0 g
s
.806 .925 .915 r
.72655 .34048 m .71866 .34631 L .71587 .34466 L p F P
0 g
s
.122 .122 .585 r
.60528 .34912 m .60304 .35437 L .60041 .34966 L p F P
0 g
s
.122 .122 .585 r
.60041 .34966 m .60298 .3443 L .60528 .34912 L p F P
0 g
s
.938 .965 .725 r
.80896 .2482 m .81196 .24337 L .81149 .24814 L p F P
0 g
s
.938 .965 .725 r
.81149 .24814 m .81141 .24827 L .80896 .2482 L p F P
0 g
s
.932 .97 .728 r
.80695 .2551 m .81141 .24827 L .80896 .2482 L p F P
0 g
s
.9 .976 .808 r
.79067 .28057 m .78971 .28172 L .79 .28042 L closepath p F P
0 g
s
0 0 .372 r
.82759 .15491 m .82756 .15423 L .82811 .15665 L closepath p F P
0 g
s
.889 .968 .832 r
.78394 .28453 m .78296 .28939 L .78971 .28172 L p F P
0 g
s
.889 .968 .832 r
.78811 .27979 m .78394 .28453 L p .78971 .28172 L F P
0 g
s
.889 .968 .832 r
.78971 .28172 m .79 .28042 L .78811 .27979 L p F P
0 g
s
0 .03 .593 r
.82473 .14497 m .8251 .14558 L .82517 .14623 L closepath p F P
0 g
s
0 0 .472 r
.82715 .15027 m .82756 .15423 L .82517 .14623 L p F P
0 g
s
0 0 .472 r
.82517 .14623 m .8251 .14558 L .82715 .15027 L p F P
0 g
s
.943 .906 .755 r
.64809 .19923 m .64877 .20382 L .65319 .19697 L p F P
0 g
s
.943 .906 .755 r
.65175 .19337 m .64809 .19923 L p .65319 .19697 L F P
0 g
s
.943 .906 .755 r
.65319 .19697 m .65259 .19374 L .65175 .19337 L p F P
0 g
s
0 .052 .61 r
.8251 .14558 m .82473 .14497 L .82162 .13658 L p F P
0 g
s
.94 .939 .597 r
.82024 .22808 m .81933 .23002 L .81949 .22846 L closepath p F P
0 g
s
.945 .927 .571 r
.62055 .26598 m .62005 .27084 L .62298 .26445 L p F P
0 g
s
.945 .927 .571 r
.62298 .26445 m .62327 .25964 L .62055 .26598 L p F P
0 g
s
.808 .689 .146 r
.82949 .18066 m .82956 .18538 L .83001 .17981 L p F P
0 g
s
.808 .689 .146 r
.83001 .17981 m .82995 .17509 L .82949 .18066 L p F P
0 g
s
.96 .929 .718 r
.63654 .22406 m .63676 .22877 L .64072 .22206 L p F P
0 g
s
.96 .929 .718 r
.64072 .22206 m .6403 .21741 L .63654 .22406 L p F P
0 g
s
.562 .68 .918 r
.77825 .09966 m .7831 .09908 L .78437 .10357 L p F P
0 g
s
.533 .648 .908 r
.79102 .09847 m .7831 .09908 L .78437 .10357 L p F P
0 g
s
.533 .648 .908 r
.78437 .10357 m .79385 .10309 L .79102 .09847 L p F P
0 g
s
.812 .934 .912 r
.73077 .33728 m .72655 .34048 L .72829 .33591 L closepath p F P
0 g
s
.806 .925 .915 r
.72801 .33574 m .72829 .33591 L .72655 .34048 L p F P
0 g
s
.806 .925 .915 r
.71587 .34466 m .72801 .33574 L p .72655 .34048 L F P
0 g
s
0 0 .278 r
.8285 .1552 m .82715 .15027 L .82756 .15423 L p F P
0 g
s
0 0 .278 r
.82895 .15984 m .8285 .1552 L p .82756 .15423 L F P
0 g
s
0 0 .278 r
.82756 .15423 m .82811 .15665 L .82895 .15984 L p F P
0 g
s
.904 .896 .81 r
.66144 .1738 m .66712 .16653 L .6681 .17107 L p F P
0 g
s
.904 .896 .81 r
.66174 .17555 m .66144 .1738 L p .6681 .17107 L F P
0 g
s
.904 .896 .81 r
.6681 .17107 m .66354 .17676 L .66174 .17555 L p F P
0 g
s
0 .052 .61 r
.82162 .13658 m .82451 .14096 L .8251 .14558 L p F P
0 g
s
0 0 .47 r
.8266 .14564 m .82715 .15027 L .8251 .14558 L p F P
0 g
s
0 0 .47 r
.8251 .14558 m .82451 .14096 L .8266 .14564 L p F P
0 g
s
.864 .955 .866 r
.76748 .30635 m .76691 .30609 L .76773 .3053 L closepath p F P
0 g
s
.886 .965 .838 r
.77681 .29234 m .78394 .28453 L .78296 .28939 L p F P
0 g
s
.886 .965 .838 r
.77666 .29313 m .77681 .29234 L p .78296 .28939 L F P
0 g
s
.886 .965 .838 r
.78296 .28939 m .77884 .2939 L .77666 .29313 L p F P
0 g
s
.821 .935 .904 r
.73848 .33118 m .73077 .33728 L .72829 .33591 L p F P
0 g
s
.252 .415 .831 r
.81278 .11706 m .80941 .11544 L .81012 .12008 L p F P
0 g
s
.252 .415 .831 r
.81012 .12008 m .81568 .12301 L .81278 .11706 L p F P
0 g
s
.945 .937 .754 r
.6444 .21312 m .64292 .21282 L .64429 .2107 L closepath p F P
0 g
s
.945 .956 .662 r
.81627 .23185 m .81583 .23663 L .81933 .23002 L p F P
0 g
s
.945 .956 .662 r
.81788 .2288 m .81627 .23185 L p .81933 .23002 L F P
0 g
s
.945 .956 .662 r
.81933 .23002 m .81949 .22846 L .81788 .2288 L p F P
0 g
s
.738 .858 .937 r
.67354 .36345 m .67646 .36576 L .66425 .37229 L p F P
0 g
s
.738 .858 .937 r
.6617 .36964 m .67354 .36345 L p .66425 .37229 L F P
0 g
s
.738 .858 .937 r
.66425 .37229 m .66154 .37004 L .6617 .36964 L p F P
0 g
s
0 0 .314 r
.82811 .15665 m .82895 .15984 L .82904 .16094 L closepath p F P
0 g
s
.773 .894 .929 r
.69969 .35556 m .69153 .36072 L .68866 .35869 L p F P
0 g
s
.879 .967 .846 r
.77884 .2939 m .77566 .29724 L .77666 .29313 L closepath p F P
0 g
s
.962 .942 .654 r
.62649 .24841 m .62624 .25323 L .62969 .24667 L p F P
0 g
s
.962 .942 .654 r
.62969 .24667 m .62973 .24192 L .62649 .24841 L p F P
0 g
s
.932 .97 .728 r
.80896 .2482 m .80762 .25027 L .80695 .2551 L p F P
0 g
s
.927 .97 .758 r
.80265 .25738 m .80206 .26217 L .80695 .2551 L p F P
0 g
s
.927 .97 .758 r
.80695 .2551 m .80762 .25027 L .80265 .25738 L p F P
0 g
s
.919 .838 .386 r
.82716 .19704 m .8272 .20174 L .82862 .19583 L p F P
0 g
s
.919 .838 .386 r
.82862 .19583 m .8286 .19113 L .82716 .19704 L p F P
0 g
s
0 .159 .683 r
.82162 .13657 m .82162 .13656 L .82162 .13658 L closepath p F P
0 g
s
0 .03 .598 r
.82162 .13656 m .82162 .13658 L .82451 .14096 L p F P
0 g
s
0 .195 .712 r
.81864 .12955 m .82091 .13197 L .82162 .13656 L closepath p F P
0 g
s
0 .03 .598 r
.82386 .13634 m .82091 .13197 L .82162 .13656 L p F P
0 g
s
0 .03 .598 r
.82451 .14096 m .82386 .13634 L p .82162 .13656 L F P
0 g
s
.9 .965 .82 r
.79 .28042 m .78811 .27979 L .79058 .27688 L closepath p F P
0 g
s
.126 .305 .774 r
.81674 .12803 m .81634 .1244 L .81864 .12955 L closepath p F P
0 g
s
.827 .943 .9 r
.74286 .32761 m .73848 .33118 L .74017 .32621 L closepath p F P
0 g
s
.821 .935 .904 r
.74013 .32619 m .74017 .32621 L .73848 .33118 L p F P
0 g
s
.821 .935 .904 r
.72845 .33541 m .74013 .32619 L p .73848 .33118 L F P
0 g
s
.821 .935 .904 r
.72829 .33591 m .72845 .33541 L p .73848 .33118 L F P
0 g
s
0 0 .153 r
.60581 .32316 m .60388 .32837 L .6045 .32266 L p F P
0 g
s
0 0 .153 r
.6045 .32266 m .60634 .31747 L .60581 .32316 L p F P
0 g
s
.945 .917 .546 r
.82273 .21412 m .82252 .21886 L .82498 .2126 L p F P
0 g
s
.945 .917 .546 r
.82498 .2126 m .82523 .20784 L .82273 .21412 L p F P
0 g
s
.867 .958 .863 r
.76879 .30043 m .76773 .3053 L .77566 .29724 L p F P
0 g
s
.867 .958 .863 r
.77623 .29294 m .76879 .30043 L p .77566 .29724 L F P
0 g
s
.867 .958 .863 r
.77566 .29724 m .77666 .29313 L .77623 .29294 L p F P
0 g
s
.809 .836 .871 r
.71249 .11915 m .70832 .12248 L .70545 .11932 L p F P
0 g
s
.842 .845 .847 r
.7025 .12787 m .70832 .12248 L .70545 .11932 L p F P
0 g
s
.836 .85 .856 r
.7025 .12787 m .69631 .13351 L .69343 .13056 L p F P
0 g
s
.864 .853 .83 r
.69376 .13617 m .69631 .13351 L .69343 .13056 L p F P
0 g
s
.713 .716 .19 r
.60839 .30709 m .60739 .31163 L .60884 .30567 L p F P
0 g
s
.713 .716 .19 r
.60884 .30567 m .60942 .30305 L .60839 .30709 L p F P
0 g
s
.842 .845 .847 r
.70545 .11932 m .70113 .12341 L .7025 .12787 L p F P
0 g
s
.836 .85 .856 r
.69343 .13056 m .70113 .12341 L .7025 .12787 L p F P
0 g
s
.921 .888 .782 r
.66354 .17676 m .66243 .17833 L .66174 .17555 L closepath p F P
0 g
s
.749 .793 .889 r
.74486 .10237 m .74767 .10075 L .74484 .09702 L p F P
0 g
s
.749 .793 .889 r
.74484 .09702 m .74323 .09797 L .74486 .10237 L p F P
0 g
s
.743 .8 .898 r
.73257 .10423 m .74323 .09797 L .74486 .10237 L p F P
0 g
s
.836 .942 .893 r
.74916 .32226 m .74286 .32761 L .74017 .32621 L p F P
0 g
s
.864 .853 .83 r
.69343 .13056 m .69232 .13174 L .69376 .13617 L p F P
0 g
s
.863 .852 .831 r
.6849 .13959 m .68605 .14411 L .69376 .13617 L p F P
0 g
s
.863 .852 .831 r
.69376 .13617 m .69232 .13174 L .6849 .13959 L p F P
0 g
s
.647 .729 .908 r
.77543 .09546 m .76288 .09914 L .76006 .0952 L p F P
0 g
s
.699 .762 .901 r
.74767 .10075 m .76006 .0952 L .76288 .09914 L p F P
0 g
s
.64 .723 .908 r
.76288 .09914 m .77543 .09546 L .77825 .09966 L p F P
0 g
s
.946 .915 .752 r
.64382 .20604 m .64429 .2107 L .64877 .20382 L p F P
0 g
s
.946 .915 .752 r
.64877 .20382 m .64809 .19923 L .64382 .20604 L p F P
0 g
s
.816 .834 .863 r
.71249 .11915 m .7204 .11272 L .71754 .10936 L p F P
0 g
s
.816 .834 .863 r
.71754 .10936 m .71116 .11466 L .71249 .11915 L p F P
0 g
s
.809 .836 .871 r
.70545 .11932 m .71116 .11466 L .71249 .11915 L p F P
0 g
s
.43 .582 .902 r
.80017 .10838 m .79667 .10779 L .79385 .10309 L p F P
0 g
s
.609 .742 .939 r
.61852 .37626 m .6308 .37351 L .63384 .37705 L p F P
0 g
s
.575 .708 .933 r
.6308 .37351 m .61852 .37626 L .61542 .3715 L p F P
0 g
s
.926 .889 .776 r
.65654 .1808 m .65749 .18534 L .66243 .17833 L p F P
0 g
s
.926 .889 .776 r
.66063 .17483 m .65654 .1808 L p .66243 .17833 L F P
0 g
s
.926 .889 .776 r
.66243 .17833 m .66174 .17555 L .66063 .17483 L p F P
0 g
s
.842 .948 .888 r
.74916 .32226 m .75491 .31723 L .75222 .31591 L p F P
0 g
s
.842 .948 .888 r
.75222 .31591 m .75064 .31728 L .74916 .32226 L p F P
0 g
s
.836 .942 .893 r
.74019 .32614 m .75064 .31728 L .74916 .32226 L p F P
0 g
s
.836 .942 .893 r
.74017 .32621 m .74019 .32614 L p .74916 .32226 L F P
0 g
s
.865 .952 .867 r
.76425 .30484 m .76879 .30043 L .76773 .3053 L p F P
0 g
s
.865 .952 .867 r
.76773 .3053 m .76691 .30609 L .76425 .30484 L p F P
0 g
s
.941 .949 .626 r
.62611 .25448 m .62538 .25494 L .62624 .25323 L closepath p F P
0 g
s
.857 .953 .874 r
.75885 .31365 m .76691 .30609 L .76425 .30484 L p F P
0 g
s
.856 .847 .384 r
.61295 .28955 m .61205 .29451 L .61422 .28833 L p F P
0 g
s
.856 .847 .384 r
.61422 .28833 m .61495 .28343 L .61295 .28955 L p F P
0 g
s
0 0 .442 r
.60404 .34148 m .60298 .3443 L .60193 .3391 L p F P
0 g
s
0 0 .442 r
.60193 .3391 m .60335 .33535 L .60404 .34148 L p F P
0 g
s
.851 .948 .88 r
.75885 .31365 m .75491 .31723 L .75222 .31591 L p F P
0 g
s
.715 .572 0 r
.82985 .17132 m .82995 .17509 L .82985 .16971 L p F P
0 g
s
.715 .572 0 r
.82985 .16971 m .82977 .16659 L .82985 .17132 L p F P
0 g
s
.857 .953 .874 r
.76425 .30484 m .76011 .30873 L .75885 .31365 L p F P
0 g
s
.851 .948 .88 r
.75222 .31591 m .76011 .30873 L .75885 .31365 L p F P
0 g
s
.94 .881 .47 r
.82718 .20346 m .82638 .20435 L .8272 .20174 L closepath p F P
0 g
s
.705 .766 .899 r
.76006 .0952 m .74767 .10075 L .74484 .09702 L p F P
0 g
s
.861 .865 .842 r
.68147 .14316 m .6849 .13959 L .68605 .14411 L p F P
0 g
s
.861 .865 .842 r
.68605 .14411 m .68436 .14583 L .68147 .14316 L p F P
0 g
s
.955 .946 .717 r
.63278 .23072 m .63654 .22406 L .63676 .22877 L p F P
0 g
s
.955 .946 .717 r
.63282 .23333 m .63278 .23072 L p .63676 .22877 L F P
0 g
s
.955 .946 .717 r
.63676 .22877 m .63412 .23326 L .63282 .23333 L p F P
0 g
s
.78 .819 .884 r
.72496 .10957 m .7204 .11272 L .71754 .10936 L p F P
0 g
s
.888 .868 .813 r
.67932 .15172 m .68436 .14583 L .68147 .14316 L p F P
0 g
s
0 0 .143 r
.82965 .16501 m .82977 .16659 L .82904 .16094 L p F P
0 g
s
0 0 .143 r
.82904 .16094 m .82895 .15984 L .82965 .16501 L p F P
0 g
s
.7 .833 .946 r
.66131 .36984 m .64908 .37543 L .64609 .37252 L p F P
0 g
s
.672 .807 .948 r
.63384 .37705 m .64609 .37252 L .64908 .37543 L p F P
0 g
s
.777 .908 .93 r
.7037 .35296 m .69969 .35556 L .70149 .35151 L closepath p F P
0 g
s
.773 .894 .929 r
.70086 .35107 m .70149 .35151 L .69969 .35556 L p F P
0 g
s
.773 .894 .929 r
.68866 .35869 m .70086 .35107 L p .69969 .35556 L F P
0 g
s
.925 .916 .53 r
.61795 .27229 m .61725 .27721 L .62005 .27084 L p F P
0 g
s
.925 .916 .53 r
.62005 .27084 m .62055 .26598 L .61795 .27229 L p F P
0 g
s
.954 .947 .648 r
.81949 .22846 m .81788 .2288 L .81966 .22526 L closepath p F P
0 g
s
.571 .686 .918 r
.7831 .09908 m .77825 .09966 L .77543 .09546 L p F P
0 g
s
.921 .968 .778 r
.79737 .26459 m .80265 .25738 L .80206 .26217 L p F P
0 g
s
.921 .968 .778 r
.79737 .26464 m .79737 .26459 L p .80206 .26217 L F P
0 g
s
.921 .968 .778 r
.80206 .26217 m .79986 .26515 L .79737 .26464 L p F P
0 g
s
.417 .488 .825 r
.60913 .35911 m .60774 .35845 L .60515 .36379 L p F P
0 g
s
.417 .488 .825 r
.60515 .36379 m .61229 .3659 L .60913 .35911 L p F P
0 g
s
0 0 .326 r
.60401 .33386 m .60335 .33535 L .60322 .32989 L p F P
0 g
s
0 0 .326 r
.60322 .32989 m .60388 .32837 L .60401 .33386 L p F P
0 g
s
.656 .79 .946 r
.64609 .37252 m .63384 .37705 L .6308 .37351 L p F P
0 g
s
.945 .96 .695 r
.81234 .23861 m .81196 .24337 L .81583 .23663 L p F P
0 g
s
.945 .96 .695 r
.81583 .23663 m .81627 .23185 L .81234 .23861 L p F P
0 g
s
.78 .819 .884 r
.71754 .10936 m .72359 .10508 L .72496 .10957 L p F P
0 g
s
.786 .817 .877 r
.72496 .10957 m .73257 .10423 L .72972 .10067 L p F P
0 g
s
.786 .817 .877 r
.72972 .10067 m .72359 .10508 L .72496 .10957 L p F P
0 g
s
.888 .868 .813 r
.68147 .14316 m .67803 .14726 L .67932 .15172 L p F P
0 g
s
.885 .867 .816 r
.67164 .15476 m .67268 .15931 L .67932 .15172 L p F P
0 g
s
.885 .867 .816 r
.67932 .15172 m .67803 .14726 L .67164 .15476 L p F P
0 g
s
.789 .909 .923 r
.71519 .34514 m .7037 .35296 L .70149 .35151 L p F P
0 g
s
.948 .948 .636 r
.62331 .2549 m .62649 .24841 L .62624 .25323 L p F P
0 g
s
.948 .948 .636 r
.62323 .25613 m .62331 .2549 L p .62624 .25323 L F P
0 g
s
.948 .948 .636 r
.62624 .25323 m .62538 .25494 L .62323 .25613 L p F P
0 g
s
0 .183 .709 r
.81634 .1244 m .81864 .12955 L .82091 .13197 L p F P
0 g
s
.915 .972 .787 r
.79986 .26515 m .79657 .26944 L .79737 .26464 L closepath p F P
0 g
s
.884 .782 .288 r
.82851 .18642 m .8286 .19113 L .82956 .18538 L p F P
0 g
s
.884 .782 .288 r
.82956 .18538 m .82949 .18066 L .82851 .18642 L p F P
0 g
s
.928 .898 .777 r
.65171 .1878 m .65244 .1924 L .65749 .18534 L p F P
0 g
s
.928 .898 .777 r
.65749 .18534 m .65654 .1808 L .65171 .1878 L p F P
0 g
s
.945 .93 .756 r
.64 .21208 m .64382 .20604 L .64429 .2107 L p F P
0 g
s
.945 .93 .756 r
.64429 .2107 m .64292 .21282 L .64 .21208 L p F P
0 g
s
.929 .918 .783 r
.65259 .19374 m .65175 .19337 L .65244 .1924 L closepath p F P
0 g
s
0 0 .128 r
.82921 .16037 m .82965 .16501 L .82895 .15984 L p F P
0 g
s
0 0 .128 r
.82895 .15984 m .8285 .1552 L .82921 .16037 L p F P
0 g
s
.968 .929 .691 r
.63412 .23326 m .63301 .23542 L .63282 .23333 L closepath p F P
0 g
s
.886 .884 .825 r
.67277 .15977 m .67247 .15954 L .67268 .15931 L closepath p F P
0 g
s
.522 .604 .877 r
.61274 .37148 m .61392 .36895 L .61542 .3715 L closepath p F P
0 g
s
.753 .87 .933 r
.68346 .36174 m .67646 .36576 L .67354 .36345 L p F P
0 g
s
.955 .935 .606 r
.81983 .22054 m .81966 .22526 L .82252 .21886 L p F P
0 g
s
.955 .935 .606 r
.82252 .21886 m .82273 .21412 L .81983 .22054 L p F P
0 g
s
.966 .931 .617 r
.62538 .25494 m .62327 .25964 L .62323 .25613 L closepath p F P
0 g
s
.208 .242 .677 r
.6083 .3571 m .60774 .35845 L .60304 .35437 L p F P
0 g
s
.208 .242 .677 r
.60589 .34984 m .6083 .3571 L p .60304 .35437 L F P
0 g
s
.208 .242 .677 r
.60304 .35437 m .60528 .34912 L .60589 .34984 L p F P
0 g
s
.748 .801 .895 r
.74323 .09797 m .73257 .10423 L .72972 .10067 L p F P
0 g
s
.943 .882 .474 r
.82528 .20312 m .82716 .19704 L .8272 .20174 L p F P
0 g
s
.943 .882 .474 r
.82531 .20551 m .82528 .20312 L p .8272 .20174 L F P
0 g
s
.943 .882 .474 r
.8272 .20174 m .82638 .20435 L .82531 .20551 L p F P
0 g
s
.961 .916 .72 r
.6403 .21741 m .64292 .21282 L .64 .21208 L p F P
0 g
s
.868 .889 .461 r
.6171 .27795 m .61669 .2786 L .61725 .27721 L closepath p F P
0 g
s
.885 .879 .824 r
.66957 .15718 m .67164 .15476 L .67268 .15931 L p F P
0 g
s
.885 .879 .824 r
.67268 .15931 m .67247 .15954 L .66957 .15718 L p F P
0 g
s
.909 .88 .793 r
.66712 .16653 m .67247 .15954 L .66957 .15718 L p F P
0 g
s
.904 .966 .813 r
.79128 .27207 m .79058 .27688 L .79657 .26944 L p F P
0 g
s
.904 .966 .813 r
.79734 .26464 m .79128 .27207 L p .79657 .26944 L F P
0 g
s
.904 .966 .813 r
.79657 .26944 m .79737 .26464 L .79734 .26464 L p F P
0 g
s
.366 .533 .888 r
.80816 .10804 m .80866 .1108 L .80017 .10838 L p F P
0 g
s
.366 .533 .888 r
.80701 .10589 m .80816 .10804 L p .80017 .10838 L F P
0 g
s
.366 .533 .888 r
.80017 .10838 m .79908 .10384 L .80701 .10589 L p F P
0 g
s
.43 .582 .902 r
.79385 .10309 m .79908 .10384 L .80017 .10838 L p F P
0 g
s
.971 .927 .676 r
.6294 .23726 m .62973 .24192 L .63301 .23542 L p F P
0 g
s
.971 .927 .676 r
.63123 .23353 m .6294 .23726 L p .63301 .23542 L F P
0 g
s
.971 .927 .676 r
.63301 .23542 m .63282 .23333 L .63123 .23353 L p F P
0 g
s
0 0 0 r
.6075 .31247 m .60634 .31747 L .60739 .31163 L p F P
0 g
s
0 0 0 r
.60816 .30852 m .6075 .31247 L p .60739 .31163 L F P
0 g
s
0 0 0 r
.60739 .31163 m .60839 .30709 L .60816 .30852 L p F P
0 g
s
0 0 0 r
.60869 .30745 m .60922 .30449 L p .60852 .30663 L F P
0 g
s
0 0 0 r
.60844 .30687 m .60942 .30305 L p .60852 .30663 L F P
0 g
s
0 0 0 r
.60942 .30305 m .61012 .30062 L .60852 .30663 L p F P
0 g
s
.721 .72 .194 r
.60974 .30159 m .60852 .30663 L .61012 .30062 L p F P
0 g
s
0 0 0 r
.60922 .30449 m .60974 .30159 L .60852 .30663 L p F P
0 g
s
0 0 0 r
.60852 .30663 m .60839 .30709 L .60844 .30687 L p F P
0 g
s
.799 .795 .299 r
.61119 .29562 m .61012 .30062 L .61205 .29451 L p F P
0 g
s
.799 .795 .299 r
.61205 .29451 m .61295 .28955 L .61119 .29562 L p F P
0 g
s
0 0 .296 r
.60595 .32865 m .60401 .33386 L .60388 .32837 L p F P
0 g
s
0 0 .296 r
.60388 .32837 m .60581 .32316 L .60595 .32865 L p F P
0 g
s
0 0 .301 r
.82797 .15057 m .8285 .1552 L .82715 .15027 L p F P
0 g
s
0 0 .301 r
.82715 .15027 m .8266 .14564 L .82797 .15057 L p F P
0 g
s
.794 .919 .922 r
.71587 .34466 m .71519 .34514 L .71548 .34442 L closepath p F P
0 g
s
.789 .909 .923 r
.71305 .3428 m .71548 .34442 L .71519 .34514 L p F P
0 g
s
.789 .909 .923 r
.70187 .35041 m .71305 .3428 L p .71519 .34514 L F P
0 g
s
.789 .909 .923 r
.70149 .35151 m .70187 .35041 L p .71519 .34514 L F P
0 g
s
.941 .963 .723 r
.80806 .2455 m .81234 .23861 L .81196 .24337 L p F P
0 g
s
.941 .963 .723 r
.80787 .24815 m .80806 .2455 L p .81196 .24337 L F P
0 g
s
.941 .963 .723 r
.81196 .24337 m .80896 .2482 L .80787 .24815 L p F P
0 g
s
.909 .898 .804 r
.66174 .17555 m .66063 .17483 L .66144 .1738 L closepath p F P
0 g
s
.809 .92 .911 r
.72523 .33397 m .72801 .33574 L .71587 .34466 L p F P
0 g
s
.809 .92 .911 r
.71677 .34015 m .72523 .33397 L p .71587 .34466 L F P
0 g
s
.809 .92 .911 r
.71587 .34466 m .71548 .34442 L .71677 .34015 L p F P
0 g
s
.884 .896 .477 r
.61549 .27856 m .61795 .27229 L .61725 .27721 L p F P
0 g
s
.884 .896 .477 r
.61515 .28082 m .61549 .27856 L p .61725 .27721 L F P
0 g
s
.884 .896 .477 r
.61725 .27721 m .61669 .2786 L .61515 .28082 L p F P
0 g
s
.928 .911 .783 r
.64883 .19193 m .65171 .1878 L .65244 .1924 L p F P
0 g
s
.928 .911 .783 r
.65244 .1924 m .65175 .19337 L .64883 .19193 L p F P
0 g
s
.571 .686 .918 r
.77543 .09546 m .78184 .09457 L .7831 .09908 L p F P
0 g
s
.544 .659 .911 r
.78819 .09393 m .78184 .09457 L .7831 .09908 L p F P
0 g
s
.544 .659 .911 r
.7831 .09908 m .79102 .09847 L .78819 .09393 L p F P
0 g
s
.112 .313 .786 r
.81568 .12301 m .81615 .12337 L .81634 .1244 L closepath p F P
0 g
s
0 .183 .709 r
.82013 .12738 m .81615 .12337 L .81634 .1244 L p F P
0 g
s
0 .183 .709 r
.82091 .13197 m .82013 .12738 L p .81634 .1244 L F P
0 g
s
.935 .887 .478 r
.82638 .20435 m .82523 .20784 L .82531 .20551 L closepath p F P
0 g
s
.947 .902 .748 r
.64809 .19923 m .65175 .19337 L .64883 .19193 L p F P
0 g
s
.753 .87 .933 r
.68578 .35658 m .68586 .35664 L .68346 .36174 L p F P
0 g
s
.753 .87 .933 r
.67354 .36345 m .68578 .35658 L p .68346 .36174 L F P
0 g
s
.757 .887 .937 r
.68866 .35869 m .68346 .36174 L .68586 .35664 L closepath p F P
0 g
s
.575 .708 .933 r
.61542 .3715 m .62774 .36965 L .6308 .37351 L p F P
0 g
s
.589 .638 .867 r
.61392 .36895 m .61542 .3715 L .62774 .36965 L p F P
0 g
s
.901 .963 .82 r
.78553 .2789 m .79128 .27207 L .79058 .27688 L p F P
0 g
s
.901 .963 .82 r
.79058 .27688 m .78811 .27979 L .78553 .2789 L p F P
0 g
s
.827 .702 .167 r
.82935 .17595 m .82949 .18066 L .82995 .17509 L p F P
0 g
s
.827 .702 .167 r
.82955 .17346 m .82935 .17595 L p .82995 .17509 L F P
0 g
s
.827 .702 .167 r
.82995 .17509 m .82985 .17132 L .82955 .17346 L p F P
0 g
s
.762 .598 .028 r
.82978 .17038 m .82985 .17132 L .82977 .16659 L p F P
0 g
s
.762 .598 .028 r
.82977 .16659 m .82965 .16501 L .82978 .17038 L p F P
0 g
s
.731 .85 .937 r
.66154 .37004 m .66131 .36984 L .6617 .36964 L closepath p F P
0 g
s
.961 .916 .72 r
.64 .21208 m .63958 .21285 L .6403 .21741 L p F P
0 g
s
.964 .916 .713 r
.636 .21945 m .63654 .22406 L .6403 .21741 L p F P
0 g
s
.964 .916 .713 r
.6403 .21741 m .63958 .21285 L .636 .21945 L p F P
0 g
s
.909 .88 .793 r
.66957 .15718 m .66591 .16205 L .66712 .16653 L p F P
0 g
s
.907 .879 .796 r
.66044 .16925 m .66144 .1738 L .66712 .16653 L p F P
0 g
s
.907 .879 .796 r
.66712 .16653 m .66591 .16205 L .66044 .16925 L p F P
0 g
s
.92 .893 .48 r
.61669 .2786 m .61495 .28343 L .61515 .28082 L closepath p F P
0 g
s
.442 .592 .905 r
.79908 .10384 m .79385 .10309 L .79102 .09847 L p F P
0 g
s
0 0 .469 r
.82598 .14101 m .8266 .14564 L .82451 .14096 L p F P
0 g
s
0 0 .469 r
.82451 .14096 m .82386 .13634 L .82598 .14101 L p F P
0 g
s
.965 .924 .592 r
.62061 .26124 m .62055 .26598 L .62327 .25964 L p F P
0 g
s
.965 .924 .592 r
.6225 .25664 m .62061 .26124 L p .62327 .25964 L F P
0 g
s
.965 .924 .592 r
.62327 .25964 m .62323 .25613 L .6225 .25664 L p F P
0 g
s
.799 .909 .916 r
.71548 .34442 m .71305 .3428 L .71677 .34015 L closepath p F P
0 g
s
.266 .436 .844 r
.80988 .11134 m .80866 .1108 L .80941 .11544 L p F P
0 g
s
.266 .436 .844 r
.80941 .11544 m .81278 .11706 L .80988 .11134 L p F P
0 g
s
.815 .924 .908 r
.72829 .33591 m .72801 .33574 L .72845 .33541 L closepath p F P
0 g
s
.894 .966 .827 r
.78394 .28453 m .78811 .27979 L .78553 .2789 L p F P
0 g
s
.127 .331 .798 r
.81615 .12337 m .81568 .12301 L .81278 .11706 L p F P
0 g
s
.065 .094 .581 r
.6055 .34852 m .60528 .34912 L .60298 .3443 L p F P
0 g
s
.065 .094 .581 r
.60298 .3443 m .60404 .34148 L .6055 .34852 L p F P
0 g
s
.731 .84 .932 r
.6617 .36964 m .66131 .36984 L .65835 .36717 L p F P
0 g
s
.7 .833 .946 r
.64609 .37252 m .65835 .36717 L .66131 .36984 L p F P
0 g
s
.647 .729 .908 r
.76006 .0952 m .77261 .09129 L .77543 .09546 L p F P
0 g
s
.654 .734 .908 r
.77261 .09129 m .76006 .0952 L .75723 .09127 L p F P
0 g
s
.705 .766 .899 r
.74484 .09702 m .75723 .09127 L .76006 .0952 L p F P
0 g
s
.727 .843 .936 r
.6617 .36964 m .67354 .36345 L .67061 .36103 L p F P
0 g
s
.727 .843 .936 r
.67061 .36103 m .66352 .3646 L .6617 .36964 L p F P
0 g
s
.731 .84 .932 r
.65835 .36717 m .66352 .3646 L .6617 .36964 L p F P
0 g
s
.935 .967 .732 r
.80896 .2482 m .80762 .25027 L .80787 .24815 L closepath p F P
0 g
s
.879 .956 .851 r
.77666 .29313 m .77623 .29294 L .77681 .29234 L closepath p F P
0 g
s
0 .055 .616 r
.82313 .13174 m .82386 .13634 L .82091 .13197 L p F P
0 g
s
0 .055 .616 r
.82091 .13197 m .82013 .12738 L .82313 .13174 L p F P
0 g
s
.956 .947 .651 r
.81654 .2271 m .81983 .22054 L .81966 .22526 L p F P
0 g
s
.956 .947 .651 r
.81648 .22906 m .81654 .2271 L p .81966 .22526 L F P
0 g
s
.956 .947 .651 r
.81966 .22526 m .81788 .2288 L .81648 .22906 L p F P
0 g
s
.812 .833 .866 r
.71116 .11466 m .70545 .11932 L .70256 .1161 L p F P
0 g
s
.843 .84 .842 r
.70113 .12341 m .70545 .11932 L .70256 .1161 L p F P
0 g
s
.753 .793 .885 r
.74323 .09797 m .74484 .09702 L .74199 .09327 L p F P
0 g
s
.753 .793 .885 r
.74199 .09327 m .74144 .09361 L .74323 .09797 L p F P
0 g
s
.748 .801 .895 r
.72972 .10067 m .74144 .09361 L .74323 .09797 L p F P
0 g
s
.843 .84 .842 r
.70256 .1161 m .69957 .11899 L .70113 .12341 L p F P
0 g
s
.838 .846 .851 r
.69075 .12733 m .69957 .11899 L .70113 .12341 L p F P
0 g
s
.838 .846 .851 r
.69093 .12795 m .69075 .12733 L p .70113 .12341 L F P
0 g
s
.838 .846 .851 r
.70113 .12341 m .69343 .13056 L .69093 .12795 L p F P
0 g
s
.815 .919 .907 r
.72845 .33541 m .72801 .33574 L .72523 .33397 L p F P
0 g
s
.894 .966 .827 r
.78553 .2789 m .78485 .27967 L .78394 .28453 L p F P
0 g
s
.886 .96 .841 r
.7776 .28752 m .77681 .29234 L .78394 .28453 L p F P
0 g
s
.886 .96 .841 r
.78394 .28453 m .78485 .27967 L .7776 .28752 L p F P
0 g
s
.127 .331 .798 r
.81278 .11706 m .81522 .11881 L .81615 .12337 L p F P
0 g
s
0 .218 .731 r
.81928 .12279 m .82013 .12738 L .81615 .12337 L p F P
0 g
s
0 .218 .731 r
.81615 .12337 m .81522 .11881 L .81928 .12279 L p F P
0 g
s
.774 .89 .927 r
.69801 .34898 m .70086 .35107 L .68866 .35869 L p F P
0 g
s
.774 .89 .927 r
.68591 .3565 m .69801 .34898 L p .68866 .35869 L F P
0 g
s
.774 .89 .927 r
.68866 .35869 m .68586 .35664 L .68591 .3565 L p F P
0 g
s
.82 .924 .904 r
.72845 .33541 m .74013 .32619 L .73738 .32452 L p F P
0 g
s
.82 .924 .904 r
.73738 .32452 m .72979 .33048 L .72845 .33541 L p F P
0 g
s
.815 .919 .907 r
.72523 .33397 m .72979 .33048 L .72845 .33541 L p F P
0 g
s
.862 .846 .827 r
.69343 .13056 m .69232 .13174 L .69093 .12795 L closepath p F P
0 g
s
0 0 .468 r
.60513 .33905 m .60404 .34148 L .60335 .33535 L p F P
0 g
s
0 0 .468 r
.60335 .33535 m .60401 .33386 L .60513 .33905 L p F P
0 g
s
.93 .845 .402 r
.82705 .19236 m .82716 .19704 L .8286 .19113 L p F P
0 g
s
.93 .845 .402 r
.8286 .19113 m .82851 .18642 L .82705 .19236 L p F P
0 g
s
.866 .848 .824 r
.68353 .13512 m .6849 .13959 L .69232 .13174 L p F P
0 g
s
.866 .848 .824 r
.69053 .12754 m .68353 .13512 L p .69232 .13174 L F P
0 g
s
.866 .848 .824 r
.69232 .13174 m .69093 .12795 L .69053 .12754 L p F P
0 g
s
.972 .929 .655 r
.62635 .2437 m .62649 .24841 L .62973 .24192 L p F P
0 g
s
.972 .929 .655 r
.62973 .24192 m .6294 .23726 L .62635 .2437 L p F P
0 g
s
.818 .83 .859 r
.71116 .11466 m .71754 .10936 L .71467 .10595 L p F P
0 g
s
.818 .83 .859 r
.71467 .10595 m .70963 .11022 L .71116 .11466 L p F P
0 g
s
.812 .833 .866 r
.70256 .1161 m .70963 .11022 L .71116 .11466 L p F P
0 g
s
.71 .768 .898 r
.75723 .09127 m .74484 .09702 L .74199 .09327 L p F P
0 g
s
.96 .944 .699 r
.63282 .23333 m .63123 .23353 L .63278 .23072 L closepath p F P
0 g
s
.926 .966 .769 r
.80317 .2526 m .80265 .25738 L .80762 .25027 L p F P
0 g
s
.926 .966 .769 r
.80647 .24786 m .80317 .2526 L p .80762 .25027 L F P
0 g
s
.926 .966 .769 r
.80762 .25027 m .80787 .24815 L .80647 .24786 L p F P
0 g
s
.579 .691 .918 r
.78184 .09457 m .77543 .09546 L .77261 .09129 L p F P
0 g
s
.953 .921 .566 r
.82286 .20938 m .82273 .21412 L .82523 .20784 L p F P
0 g
s
.953 .921 .566 r
.82413 .20617 m .82286 .20938 L p .82523 .20784 L F P
0 g
s
.953 .921 .566 r
.82523 .20784 m .82531 .20551 L .82413 .20617 L p F P
0 g
s
.517 .577 .855 r
.61229 .3659 m .6158 .36602 L .61392 .36895 L closepath p F P
0 g
s
.589 .638 .867 r
.62467 .36543 m .6158 .36602 L .61392 .36895 L p F P
0 g
s
.589 .638 .867 r
.62774 .36965 m .62467 .36543 L p .61392 .36895 L F P
0 g
s
.907 .892 .803 r
.65771 .17282 m .66044 .16925 L .66144 .1738 L p F P
0 g
s
.907 .892 .803 r
.66144 .1738 m .66063 .17483 L .65771 .17282 L p F P
0 g
s
.947 .902 .748 r
.64883 .19193 m .64714 .19471 L .64809 .19923 L p F P
0 g
s
.948 .903 .745 r
.64304 .20147 m .64382 .20604 L .64809 .19923 L p F P
0 g
s
.948 .903 .745 r
.64809 .19923 m .64714 .19471 L .64304 .20147 L p F P
0 g
s
.784 .818 .88 r
.72359 .10508 m .71754 .10936 L .71467 .10595 L p F P
0 g
s
.929 .887 .77 r
.65654 .1808 m .66063 .17483 L .65771 .17282 L p F P
0 g
s
.69 .821 .946 r
.65835 .36717 m .64609 .37252 L .64308 .36942 L p F P
0 g
s
.656 .79 .946 r
.6308 .37351 m .64308 .36942 L .64609 .37252 L p F P
0 g
s
.879 .952 .852 r
.77359 .29172 m .7776 .28752 L .77681 .29234 L p F P
0 g
s
.879 .952 .852 r
.77681 .29234 m .77623 .29294 L .77359 .29172 L p F P
0 g
s
.636 .769 .944 r
.64308 .36942 m .6308 .37351 L .62774 .36965 L p F P
0 g
s
.862 .86 .836 r
.67856 .14039 m .68353 .13512 L .6849 .13959 L p F P
0 g
s
.862 .86 .836 r
.6849 .13959 m .68147 .14316 L .67856 .14039 L p F P
0 g
s
.872 .954 .859 r
.76879 .30043 m .77623 .29294 L .77359 .29172 L p F P
0 g
s
.783 .61 .046 r
.82934 .16575 m .82978 .17038 L .82965 .16501 L p F P
0 g
s
.783 .61 .046 r
.82965 .16501 m .82921 .16037 L .82934 .16575 L p F P
0 g
s
.829 .932 .898 r
.74017 .32621 m .74013 .32619 L .74019 .32614 L closepath p F P
0 g
s
.83 .927 .897 r
.74019 .32614 m .74013 .32619 L .73738 .32452 L p F P
0 g
s
.831 .935 .897 r
.74137 .32126 m .74019 .32614 L .75064 .31728 L p F P
0 g
s
.83 .927 .897 r
.73738 .32452 m .74137 .32126 L .74019 .32614 L p F P
0 g
s
.721 .72 .194 r
.61012 .30062 m .61119 .29562 L .60974 .30159 L p F P
0 g
s
.784 .899 .924 r
.70149 .35151 m .70086 .35107 L .70187 .35041 L closepath p F P
0 g
s
.95 .952 .659 r
.81788 .2288 m .81627 .23185 L .81648 .22906 L closepath p F P
0 g
s
.888 .861 .808 r
.67803 .14726 m .68147 .14316 L .67856 .14039 L p F P
0 g
s
0 0 .069 r
.60702 .31816 m .60581 .32316 L .60634 .31747 L p F P
0 g
s
0 0 .069 r
.60634 .31747 m .6075 .31247 L .60702 .31816 L p F P
0 g
s
.965 .924 .707 r
.63242 .22605 m .63278 .23072 L .63654 .22406 L p F P
0 g
s
.965 .924 .707 r
.63654 .22406 m .636 .21945 L .63242 .22605 L p F P
0 g
s
.872 .954 .859 r
.77359 .29172 m .76977 .29557 L .76879 .30043 L p F P
0 g
s
.865 .95 .866 r
.76158 .30356 m .76977 .29557 L .76879 .30043 L p F P
0 g
s
.865 .95 .866 r
.76879 .30043 m .76425 .30484 L .76158 .30356 L p F P
0 g
s
.906 .871 .435 r
.61334 .28474 m .61295 .28955 L .61495 .28343 L p F P
0 g
s
.906 .871 .435 r
.61386 .28311 m .61334 .28474 L p .61495 .28343 L F P
0 g
s
.906 .871 .435 r
.61495 .28343 m .61515 .28082 L .61386 .28311 L p F P
0 g
s
.831 .935 .897 r
.7495 .31441 m .74137 .32126 L p .75064 .31728 L F P
0 g
s
.831 .935 .897 r
.75064 .31728 m .75118 .31538 L .7495 .31441 L p F P
0 g
s
.842 .945 .888 r
.75222 .31591 m .75064 .31728 L .75118 .31538 L closepath p F P
0 g
s
.857 .951 .874 r
.76011 .30873 m .76425 .30484 L .76158 .30356 L p F P
0 g
s
.851 .944 .88 r
.76011 .30873 m .75222 .31591 L .75118 .31538 L p F P
0 g
s
.784 .818 .88 r
.71467 .10595 m .72201 .10064 L .72359 .10508 L p F P
0 g
s
.789 .815 .873 r
.72359 .10508 m .72972 .10067 L .72685 .09708 L p F P
0 g
s
.789 .815 .873 r
.72685 .09708 m .72201 .10064 L .72359 .10508 L p F P
0 g
s
.857 .951 .874 r
.76158 .30356 m .76131 .30381 L .76011 .30873 L p F P
0 g
s
.851 .944 .88 r
.75181 .31239 m .76131 .30381 L .76011 .30873 L p F P
0 g
s
.851 .944 .88 r
.75118 .31538 m .75181 .31239 L p .76011 .30873 L F P
0 g
s
.888 .861 .808 r
.67856 .14039 m .67654 .14284 L .67803 .14726 L p F P
0 g
s
.887 .86 .809 r
.67036 .15028 m .67164 .15476 L .67803 .14726 L p F P
0 g
s
.887 .86 .809 r
.67803 .14726 m .67654 .14284 L .67036 .15028 L p F P
0 g
s
.954 .914 .549 r
.61818 .2675 m .61795 .27229 L .62055 .26598 L p F P
0 g
s
.954 .914 .549 r
.62055 .26598 m .62061 .26124 L .61818 .2675 L p F P
0 g
s
0 0 .439 r
.60699 .33387 m .60513 .33905 L .60401 .33386 L p F P
0 g
s
0 0 .439 r
.60401 .33386 m .60595 .32865 L .60699 .33387 L p F P
0 g
s
.46 .531 .843 r
.6158 .36602 m .61229 .3659 L .60913 .35911 L p F P
0 g
s
.923 .963 .782 r
.79781 .25984 m .79737 .26459 L .80265 .25738 L p F P
0 g
s
.923 .963 .782 r
.80265 .25738 m .80317 .2526 L .79781 .25984 L p F P
0 g
s
.946 .959 .71 r
.81265 .23386 m .81234 .23861 L .81627 .23185 L p F P
0 g
s
.946 .959 .71 r
.81547 .22903 m .81265 .23386 L p .81627 .23185 L F P
0 g
s
.946 .959 .71 r
.81627 .23185 m .81648 .22906 L .81547 .22903 L p F P
0 g
s
.929 .887 .77 r
.65771 .17282 m .65536 .17633 L .65654 .1808 L p F P
0 g
s
.929 .887 .77 r
.6507 .18327 m .65171 .1878 L .65654 .1808 L p F P
0 g
s
.929 .887 .77 r
.65654 .1808 m .65536 .17633 L .6507 .18327 L p F P
0 g
s
.784 .893 .922 r
.70187 .35041 m .70086 .35107 L .69801 .34898 L p F P
0 g
s
.752 .801 .891 r
.74144 .09361 m .72972 .10067 L .72685 .09708 L p F P
0 g
s
0 0 .117 r
.82868 .15574 m .82921 .16037 L .8285 .1552 L p F P
0 g
s
0 0 .117 r
.8285 .1552 m .82797 .15057 L .82868 .15574 L p F P
0 g
s
.897 .791 .306 r
.82834 .18173 m .82851 .18642 L .82949 .18066 L p F P
0 g
s
.897 .791 .306 r
.82949 .18066 m .82935 .17595 L .82834 .18173 L p F P
0 g
s
.786 .898 .922 r
.70187 .35041 m .71305 .3428 L .71023 .34085 L p F P
0 g
s
.786 .898 .922 r
.71023 .34085 m .70342 .34543 L .70187 .35041 L p F P
0 g
s
.784 .893 .922 r
.69801 .34898 m .70342 .34543 L .70187 .35041 L p F P
0 g
s
.143 .349 .808 r
.81522 .11881 m .81278 .11706 L .80988 .11134 L p F P
0 g
s
.947 .921 .752 r
.63891 .20825 m .64304 .20147 L .64382 .20604 L p F P
0 g
s
.947 .921 .752 r
.63938 .21189 m .63891 .20825 L p .64382 .20604 L F P
0 g
s
.947 .921 .752 r
.64382 .20604 m .64 .21208 L .63938 .21189 L p F P
0 g
s
.969 .932 .638 r
.62336 .25013 m .62331 .2549 L .62649 .24841 L p F P
0 g
s
.969 .932 .638 r
.62649 .24841 m .62635 .2437 L .62336 .25013 L p F P
0 g
s
.745 .869 .937 r
.68578 .35658 m .67354 .36345 L .67061 .36103 L p F P
0 g
s
.442 .592 .905 r
.79102 .09847 m .79794 .09929 L .79908 .10384 L p F P
0 g
s
.374 .529 .882 r
.80414 .10071 m .79794 .09929 L .79908 .10384 L p F P
0 g
s
.374 .529 .882 r
.79908 .10384 m .80701 .10589 L .80414 .10071 L p F P
0 g
s
.886 .872 .819 r
.66664 .1547 m .67036 .15028 L .67164 .15476 L p F P
0 g
s
.886 .872 .819 r
.67164 .15476 m .66957 .15718 L .66664 .1547 L p F P
0 g
s
.936 .96 .755 r
.80787 .24815 m .80647 .24786 L .80806 .2455 L closepath p F P
0 g
s
.959 .936 .617 r
.81991 .21583 m .81983 .22054 L .82273 .21412 L p F P
0 g
s
.959 .936 .617 r
.82273 .21412 m .82286 .20938 L .81991 .21583 L p F P
0 g
s
.128 .14 .602 r
.60767 .3438 m .6055 .34852 L .60404 .34148 L p F P
0 g
s
.128 .14 .602 r
.60404 .34148 m .60513 .33905 L .60767 .3438 L p F P
0 g
s
.36 .423 .792 r
.60774 .35845 m .6083 .3571 L .60913 .35911 L closepath p F P
0 g
s
.955 .885 .49 r
.82514 .19845 m .82528 .20312 L .82716 .19704 L p F P
0 g
s
.955 .885 .49 r
.82716 .19704 m .82705 .19236 L .82514 .19845 L p F P
0 g
s
.962 .911 .554 r
.82531 .20551 m .82413 .20617 L .82528 .20312 L closepath p F P
0 g
s
.452 .601 .908 r
.79794 .09929 m .79102 .09847 L .78819 .09393 L p F P
0 g
s
.909 .87 .788 r
.66591 .16205 m .66957 .15718 L .66664 .1547 L p F P
0 g
s
.856 .711 .185 r
.82985 .17132 m .82955 .17346 L .82978 .17038 L closepath p F P
0 g
s
.962 .938 .705 r
.62886 .23266 m .63242 .22605 L .63278 .23072 L p F P
0 g
s
.962 .938 .705 r
.62892 .23364 m .62886 .23266 L p .63278 .23072 L F P
0 g
s
.962 .938 .705 r
.63278 .23072 m .63123 .23353 L .62892 .23364 L p F P
0 g
s
.914 .962 .801 r
.79737 .26464 m .79734 .26464 L .79737 .26459 L closepath p F P
0 g
s
0 0 0 r
.60839 .30709 m .60816 .30852 L .60852 .30663 L closepath p F P
0 g
s
.949 .938 .606 r
.62323 .25613 m .6225 .25664 L .62331 .2549 L closepath p F P
0 g
s
.915 .958 .802 r
.79478 .26373 m .79781 .25984 L .79737 .26459 L p F P
0 g
s
.915 .958 .802 r
.79737 .26459 m .79734 .26464 L .79478 .26373 L p F P
0 g
s
.909 .962 .808 r
.79128 .27207 m .79734 .26464 L .79478 .26373 L p F P
0 g
s
0 0 .294 r
.82736 .14595 m .82797 .15057 L .8266 .14564 L p F P
0 g
s
0 0 .294 r
.8266 .14564 m .82598 .14101 L .82736 .14595 L p F P
0 g
s
.579 .691 .918 r
.77261 .09129 m .78057 .09004 L .78184 .09457 L p F P
0 g
s
.554 .668 .913 r
.78536 .08945 m .78057 .09004 L .78184 .09457 L p F P
0 g
s
.554 .668 .913 r
.78184 .09457 m .78819 .09393 L .78536 .08945 L p F P
0 g
s
.844 .934 .886 r
.75118 .31538 m .7495 .31441 L .75181 .31239 L closepath p F P
0 g
s
.928 .902 .778 r
.64595 .19025 m .6507 .18327 L .65171 .1878 L p F P
0 g
s
.928 .902 .778 r
.64597 .19037 m .64595 .19025 L p .65171 .1878 L F P
0 g
s
.928 .902 .778 r
.65171 .1878 m .64883 .19193 L .64597 .19037 L p F P
0 g
s
.188 .236 .681 r
.60528 .34912 m .6055 .34852 L .60589 .34984 L closepath p F P
0 g
s
0 0 0 r
.60766 .31152 m .60869 .30745 L p .60852 .30663 L F P
0 g
s
0 0 0 r
.60852 .30663 m .60816 .30852 L .60766 .31152 L p F P
0 g
s
.654 .734 .908 r
.75723 .09127 m .76978 .08714 L .77261 .09129 L p F P
0 g
s
.66 .738 .908 r
.76978 .08714 m .75723 .09127 L .7544 .08735 L p F P
0 g
s
.71 .768 .898 r
.74199 .09327 m .7544 .08735 L .75723 .09127 L p F P
0 g
s
.943 .959 .731 r
.80831 .24078 m .80806 .2455 L .81234 .23861 L p F P
0 g
s
.943 .959 .731 r
.81234 .23861 m .81265 .23386 L .80831 .24078 L p F P
0 g
s
.799 .905 .915 r
.71677 .34015 m .71305 .3428 L .71023 .34085 L p F P
0 g
s
.46 .531 .843 r
.60913 .35911 m .61827 .36073 L .6158 .36602 L p F P
0 g
s
.545 .651 .904 r
.62157 .3608 m .61827 .36073 L .6158 .36602 L p F P
0 g
s
.545 .651 .904 r
.6158 .36602 m .62467 .36543 L .62157 .3608 L p F P
0 g
s
.871 .827 .353 r
.61172 .29077 m .61119 .29562 L .61295 .28955 L p F P
0 g
s
.871 .827 .353 r
.61295 .28955 m .61334 .28474 L .61172 .29077 L p F P
0 g
s
.959 .906 .724 r
.64 .21208 m .63958 .21285 L .63938 .21189 L closepath p F P
0 g
s
.484 .498 .796 r
.6083 .3571 m .60913 .35911 L .61827 .36073 L p F P
0 g
s
.909 .87 .788 r
.66664 .1547 m .66448 .15763 L .66591 .16205 L p F P
0 g
s
.908 .87 .789 r
.6592 .16477 m .66044 .16925 L .66591 .16205 L p F P
0 g
s
.908 .87 .789 r
.66591 .16205 m .66448 .15763 L .6592 .16477 L p F P
0 g
s
.974 .919 .678 r
.63123 .23353 m .6294 .23726 L .62892 .23364 L closepath p F P
0 g
s
.841 .848 .85 r
.69093 .12795 m .69053 .12754 L .69075 .12733 L closepath p F P
0 g
s
.861 .714 .19 r
.82894 .17131 m .82934 .16575 L .82978 .17038 L p F P
0 g
s
.861 .714 .19 r
.82931 .17518 m .82894 .17131 L p .82978 .17038 L F P
0 g
s
.861 .714 .19 r
.82978 .17038 m .82955 .17346 L .82931 .17518 L p F P
0 g
s
.873 .871 .428 r
.61515 .28082 m .61386 .28311 L .61549 .27856 L closepath p F P
0 g
s
.964 .906 .713 r
.63516 .21491 m .636 .21945 L .63958 .21285 L p F P
0 g
s
.964 .906 .713 r
.63708 .21129 m .63516 .21491 L p .63958 .21285 L F P
0 g
s
.964 .906 .713 r
.63958 .21285 m .63938 .21189 L .63708 .21129 L p F P
0 g
s
.936 .901 .506 r
.6159 .27372 m .61549 .27856 L .61795 .27229 L p F P
0 g
s
.936 .901 .506 r
.61795 .27229 m .61818 .2675 L .6159 .27372 L p F P
0 g
s
0 0 .468 r
.82528 .1364 m .82598 .14101 L .82386 .13634 L p F P
0 g
s
0 0 .468 r
.82386 .13634 m .82313 .13174 L .82528 .1364 L p F P
0 g
s
.724 .83 .931 r
.66352 .3646 m .65835 .36717 L .65537 .36435 L p F P
0 g
s
.69 .821 .946 r
.64308 .36942 m .65537 .36435 L .65835 .36717 L p F P
0 g
s
.282 .455 .855 r
.80866 .1108 m .80816 .10804 L .80988 .11134 L closepath p F P
0 g
s
.803 .912 .914 r
.71677 .34015 m .72523 .33397 L .72243 .33214 L p F P
0 g
s
.803 .912 .914 r
.72243 .33214 m .71824 .33518 L .71677 .34015 L p F P
0 g
s
.799 .905 .915 r
.71023 .34085 m .71824 .33518 L .71677 .34015 L p F P
0 g
s
0 0 .22 r
.60715 .32365 m .60595 .32865 L .60581 .32316 L p F P
0 g
s
0 0 .22 r
.60581 .32316 m .60702 .31816 L .60715 .32365 L p F P
0 g
s
.318 .348 .735 r
.60589 .34984 m .61037 .35308 L .6083 .3571 L closepath p F P
0 g
s
.484 .498 .796 r
.61844 .35558 m .61037 .35308 L .6083 .3571 L p F P
0 g
s
.484 .498 .796 r
.61931 .35711 m .61844 .35558 L p .6083 .3571 L F P
0 g
s
.484 .498 .796 r
.61827 .36073 m .61931 .35711 L p .6083 .3571 L F P
0 g
s
.586 .696 .918 r
.78057 .09004 m .77261 .09129 L .76978 .08714 L p F P
0 g
s
.909 .962 .808 r
.79478 .26373 m .79191 .26727 L .79128 .27207 L p F P
0 g
s
.903 .959 .82 r
.78544 .27489 m .79191 .26727 L .79128 .27207 L p F P
0 g
s
.903 .959 .82 r
.78501 .27871 m .78544 .27489 L p .79128 .27207 L F P
0 g
s
.903 .959 .82 r
.79128 .27207 m .78553 .2789 L .78501 .27871 L p F P
0 g
s
.357 .348 .712 r
.61224 .34793 m .60767 .3438 L .6055 .34852 L p F P
0 g
s
.357 .348 .712 r
.61037 .35308 m .61224 .34793 L p .6055 .34852 L F P
0 g
s
.357 .348 .712 r
.6055 .34852 m .60589 .34984 L .61037 .35308 L p F P
0 g
s
.753 .791 .884 r
.74199 .09327 m .74144 .09361 L .74029 .09103 L closepath p F P
0 g
s
.752 .801 .891 r
.73914 .08951 m .74029 .09103 L .74144 .09361 L p F P
0 g
s
.752 .801 .891 r
.72685 .09708 m .73914 .08951 L p .74144 .09361 L F P
0 g
s
.815 .83 .862 r
.70963 .11022 m .70256 .1161 L .69967 .11281 L p F P
0 g
s
.844 .836 .838 r
.69957 .11899 m .70256 .1161 L .69967 .11281 L p F P
0 g
s
.712 .779 .904 r
.75155 .08342 m .7544 .08735 L .74199 .09327 L p F P
0 g
s
.712 .779 .904 r
.73988 .08915 m .75155 .08342 L p .74199 .09327 L F P
0 g
s
.712 .779 .904 r
.74199 .09327 m .74029 .09103 L .73988 .08915 L p F P
0 g
s
.844 .836 .838 r
.69967 .11281 m .69782 .11461 L .69957 .11899 L p F P
0 g
s
.841 .835 .839 r
.6893 .12286 m .69075 .12733 L .69957 .11899 L p F P
0 g
s
.841 .835 .839 r
.69957 .11899 m .69782 .11461 L .6893 .12286 L p F P
0 g
s
.943 .89 .749 r
.64883 .19193 m .64714 .19471 L .64597 .19037 L closepath p F P
0 g
s
.957 .938 .618 r
.62045 .25655 m .62336 .25013 L .62331 .2549 L p F P
0 g
s
.957 .938 .618 r
.62042 .2579 m .62045 .25655 L p .62331 .2549 L F P
0 g
s
.957 .938 .618 r
.62331 .2549 m .6225 .25664 L .62042 .2579 L p F P
0 g
s
0 .059 .62 r
.82233 .12713 m .82313 .13174 L .82013 .12738 L p F P
0 g
s
0 .059 .62 r
.82013 .12738 m .81928 .12279 L .82233 .12713 L p F P
0 g
s
.636 .769 .944 r
.62774 .36965 m .64006 .36612 L .64308 .36942 L p F P
0 g
s
.61 .745 .941 r
.64006 .36612 m .62774 .36965 L .62467 .36543 L p F P
0 g
s
0 0 0 r
.60816 .30852 m .6075 .31247 L .60766 .31152 L closepath p F P
0 g
s
.839 .844 .848 r
.68762 .12446 m .6893 .12286 L .69075 .12733 L p F P
0 g
s
.839 .844 .848 r
.69075 .12733 m .69053 .12754 L .68762 .12446 L p F P
0 g
s
.869 .851 .823 r
.68353 .13512 m .69053 .12754 L .68762 .12446 L p F P
0 g
s
.143 .349 .808 r
.80988 .11134 m .81422 .11425 L .81522 .11881 L p F P
0 g
s
0 .225 .736 r
.81835 .11821 m .81928 .12279 L .81522 .11881 L p F P
0 g
s
0 .225 .736 r
.81522 .11881 m .81422 .11425 L .81835 .11821 L p F P
0 g
s
.82 .826 .854 r
.70963 .11022 m .71467 .10595 L .71178 .10248 L p F P
0 g
s
.82 .826 .854 r
.71178 .10248 m .70791 .10582 L .70963 .11022 L p F P
0 g
s
.815 .83 .862 r
.69967 .11281 m .70791 .10582 L .70963 .11022 L p F P
0 g
s
.765 .88 .929 r
.68586 .35664 m .68578 .35658 L .68591 .3565 L closepath p F P
0 g
s
.955 .951 .696 r
.81648 .22906 m .81547 .22903 L .81654 .2271 L closepath p F P
0 g
s
.765 .873 .926 r
.68591 .3565 m .68578 .35658 L .68287 .35424 L p F P
0 g
s
.745 .869 .937 r
.67061 .36103 m .68287 .35424 L .68578 .35658 L p F P
0 g
s
.96 .944 .66 r
.81659 .2224 m .81654 .2271 L .81983 .22054 L p F P
0 g
s
.96 .944 .66 r
.81983 .22054 m .81991 .21583 L .81659 .2224 L p F P
0 g
s
.765 .873 .926 r
.68287 .35424 m .6874 .35154 L .68591 .3565 L p F P
0 g
s
.766 .877 .928 r
.68591 .3565 m .69801 .34898 L .69513 .34682 L p F P
0 g
s
.766 .877 .928 r
.69513 .34682 m .6874 .35154 L .68591 .3565 L p F P
0 g
s
.787 .816 .876 r
.72201 .10064 m .71467 .10595 L .71178 .10248 L p F P
0 g
s
.678 .808 .945 r
.65537 .36435 m .64308 .36942 L .64006 .36612 L p F P
0 g
s
.94 .851 .417 r
.82685 .18767 m .82705 .19236 L .82851 .18642 L p F P
0 g
s
.94 .851 .417 r
.82851 .18642 m .82834 .18173 L .82685 .18767 L p F P
0 g
s
.952 .921 .74 r
.63938 .21189 m .63708 .21129 L .63891 .20825 L closepath p F P
0 g
s
.814 .916 .907 r
.72979 .33048 m .72523 .33397 L .72243 .33214 L p F P
0 g
s
.973 .919 .599 r
.6225 .25664 m .62061 .26124 L .62042 .2579 L closepath p F P
0 g
s
.116 .346 .812 r
.80816 .10804 m .80988 .11134 L .81422 .11425 L p F P
0 g
s
.977 .917 .66 r
.62586 .23909 m .62635 .2437 L .6294 .23726 L p F P
0 g
s
.977 .917 .66 r
.62831 .23372 m .62586 .23909 L p .6294 .23726 L F P
0 g
s
.977 .917 .66 r
.6294 .23726 m .62892 .23364 L .62831 .23372 L p F P
0 g
s
.908 .883 .798 r
.65477 .17066 m .6592 .16477 L .66044 .16925 L p F P
0 g
s
.908 .883 .798 r
.66044 .16925 m .65771 .17282 L .65477 .17066 L p F P
0 g
s
.895 .962 .828 r
.78553 .2789 m .78485 .27967 L .78501 .27871 L closepath p F P
0 g
s
.948 .891 .74 r
.642 .19697 m .64304 .20147 L .64714 .19471 L p F P
0 g
s
.948 .891 .74 r
.6459 .19033 m .642 .19697 L p .64714 .19471 L F P
0 g
s
.948 .891 .74 r
.64714 .19471 m .64597 .19037 L .6459 .19033 L p F P
0 g
s
.883 .953 .847 r
.77831 .28272 m .7776 .28752 L .78485 .27967 L p F P
0 g
s
.883 .953 .847 r
.78291 .27773 m .77831 .28272 L p .78485 .27967 L F P
0 g
s
.883 .953 .847 r
.78485 .27967 m .78501 .27871 L .78291 .27773 L p F P
0 g
s
.869 .851 .823 r
.68762 .12446 m .68195 .13071 L .68353 .13512 L p F P
0 g
s
.863 .854 .831 r
.67563 .13751 m .68195 .13071 L .68353 .13512 L p F P
0 g
s
.863 .854 .831 r
.68353 .13512 m .67856 .14039 L .67563 .13751 L p F P
0 g
s
.964 .912 .557 r
.82281 .20468 m .82514 .19845 L .82528 .20312 L p F P
0 g
s
.964 .912 .557 r
.82288 .20683 m .82281 .20468 L p .82528 .20312 L F P
0 g
s
.964 .912 .557 r
.82528 .20312 m .82413 .20617 L .82288 .20683 L p F P
0 g
s
.718 .839 .939 r
.66352 .3646 m .67061 .36103 L .66767 .3585 L p F P
0 g
s
.718 .839 .939 r
.66767 .3585 m .66585 .35938 L .66352 .3646 L p F P
0 g
s
.724 .83 .931 r
.65537 .36435 m .66585 .35938 L .66352 .3646 L p F P
0 g
s
.05 .083 .575 r
.60925 .33872 m .60767 .3438 L .60513 .33905 L p F P
0 g
s
.05 .083 .575 r
.60513 .33905 m .60699 .33387 L .60925 .33872 L p F P
0 g
s
.936 .959 .756 r
.80396 .24731 m .80831 .24078 L .80806 .2455 L p F P
0 g
s
.936 .959 .756 r
.80806 .2455 m .80647 .24786 L .80396 .24731 L p F P
0 g
s
.819 .922 .905 r
.72979 .33048 m .73738 .32452 L .73462 .3228 L p F P
0 g
s
.819 .922 .905 r
.73462 .3228 m .7311 .32555 L .72979 .33048 L p F P
0 g
s
.814 .916 .907 r
.72243 .33214 m .7311 .32555 L .72979 .33048 L p F P
0 g
s
.799 .62 .061 r
.82881 .16112 m .82934 .16575 L .82921 .16037 L p F P
0 g
s
.799 .62 .061 r
.82921 .16037 m .82868 .15574 L .82881 .16112 L p F P
0 g
s
.844 .71 .179 r
.82955 .17346 m .82935 .17595 L .82931 .17518 L closepath p F P
0 g
s
.887 .853 .803 r
.67654 .14284 m .67856 .14039 L .67563 .13751 L p F P
0 g
s
.792 .813 .869 r
.72201 .10064 m .72685 .09708 L .72398 .09345 L p F P
0 g
s
.792 .813 .869 r
.72398 .09345 m .72024 .09625 L .72201 .10064 L p F P
0 g
s
.787 .816 .876 r
.71178 .10248 m .72024 .09625 L .72201 .10064 L p F P
0 g
s
.928 .877 .766 r
.65536 .17633 m .65771 .17282 L .65477 .17066 L p F P
0 g
s
.932 .963 .762 r
.80317 .2526 m .80647 .24786 L .80396 .24731 L p F P
0 g
s
.88 .95 .851 r
.77094 .29045 m .77831 .28272 L .7776 .28752 L p F P
0 g
s
.88 .95 .851 r
.7776 .28752 m .77359 .29172 L .77094 .29045 L p F P
0 g
s
.967 .91 .703 r
.63175 .22146 m .63242 .22605 L .636 .21945 L p F P
0 g
s
.967 .91 .703 r
.636 .21945 m .63516 .21491 L .63175 .22146 L p F P
0 g
s
.829 .924 .897 r
.74137 .32126 m .73738 .32452 L .73462 .3228 L p F P
0 g
s
.887 .853 .803 r
.67563 .13751 m .67486 .13847 L .67654 .14284 L p F P
0 g
s
.888 .853 .803 r
.66887 .14585 m .67036 .15028 L .67654 .14284 L p F P
0 g
s
.888 .853 .803 r
.67654 .14284 m .67486 .13847 L .66887 .14585 L p F P
0 g
s
.873 .952 .859 r
.76977 .29557 m .77359 .29172 L .77094 .29045 L p F P
0 g
s
.835 .93 .893 r
.74137 .32126 m .7495 .31441 L .74677 .31277 L p F P
0 g
s
.835 .93 .893 r
.74677 .31277 m .74249 .31637 L .74137 .32126 L p F P
0 g
s
.829 .924 .897 r
.73462 .3228 m .74249 .31637 L .74137 .32126 L p F P
0 g
s
.894 .95 .835 r
.78501 .27871 m .78291 .27773 L .78544 .27489 L closepath p F P
0 g
s
.757 .793 .882 r
.73914 .08951 m .72685 .09708 L .72398 .09345 L p F P
0 g
s
.814 .77 .26 r
.61039 .29671 m .60974 .30159 L .61119 .29562 L p F P
0 g
s
.814 .77 .26 r
.61119 .29562 m .61172 .29077 L .61039 .29671 L p F P
0 g
s
.873 .952 .859 r
.77094 .29045 m .77069 .29071 L .76977 .29557 L p F P
0 g
s
.866 .945 .866 r
.7621 .299 m .77069 .29071 L .76977 .29557 L p F P
0 g
s
.866 .945 .866 r
.76139 .30346 m .7621 .299 L p .76977 .29557 L F P
0 g
s
.866 .945 .866 r
.76977 .29557 m .76158 .30356 L .76139 .30346 L p F P
0 g
s
.891 .88 .448 r
.61381 .27989 m .6159 .27372 L .61549 .27856 L p F P
0 g
s
.891 .88 .448 r
.61337 .28392 m .61381 .27989 L p .61549 .27856 L F P
0 g
s
.891 .88 .448 r
.61549 .27856 m .61386 .28311 L .61337 .28392 L p F P
0 g
s
.959 .918 .565 r
.82413 .20617 m .82286 .20938 L .82288 .20683 L closepath p F P
0 g
s
.452 .601 .908 r
.78819 .09393 m .79674 .09475 L .79794 .09929 L p F P
0 g
s
.462 .61 .911 r
.79674 .09475 m .78819 .09393 L .78536 .08945 L p F P
0 g
s
0 0 .018 r
.60731 .31642 m .60702 .31816 L .6075 .31247 L p F P
0 g
s
0 0 .018 r
.6075 .31247 m .60766 .31152 L .60731 .31642 L p F P
0 g
s
.844 .93 .886 r
.75181 .31239 m .7495 .31441 L .74677 .31277 L p F P
0 g
s
.928 .877 .766 r
.65477 .17066 m .65395 .17192 L .65536 .17633 L p F P
0 g
s
.929 .877 .763 r
.64945 .17881 m .6507 .18327 L .65536 .17633 L p F P
0 g
s
.929 .877 .763 r
.65536 .17633 m .65395 .17192 L .64945 .17881 L p F P
0 g
s
.846 .936 .885 r
.75275 .30754 m .75181 .31239 L .76131 .30381 L p F P
0 g
s
.844 .93 .886 r
.74677 .31277 m .75275 .30754 L .75181 .31239 L p F P
0 g
s
.858 .947 .874 r
.76158 .30356 m .76131 .30381 L .76139 .30346 L closepath p F P
0 g
s
.846 .936 .885 r
.75888 .30202 m .75275 .30754 L p .76131 .30381 L F P
0 g
s
.846 .936 .885 r
.76131 .30381 m .76139 .30346 L .75888 .30202 L p F P
0 g
s
.972 .911 .57 r
.61801 .26282 m .61818 .2675 L .62061 .26124 L p F P
0 g
s
.972 .911 .57 r
.61961 .25853 m .61801 .26282 L p .62061 .26124 L F P
0 g
s
.972 .911 .57 r
.62061 .26124 m .62042 .2579 L .61961 .25853 L p F P
0 g
s
0 0 .104 r
.82808 .15112 m .82868 .15574 L .82797 .15057 L p F P
0 g
s
0 0 .104 r
.82797 .15057 m .82736 .14595 L .82808 .15112 L p F P
0 g
s
.714 .78 .904 r
.74029 .09103 m .73914 .08951 L .73988 .08915 L closepath p F P
0 g
s
.24 .438 .854 r
.80701 .10589 m .80769 .10622 L .80816 .10804 L closepath p F P
0 g
s
.116 .346 .812 r
.81314 .1097 m .80769 .10622 L .80816 .10804 L p F P
0 g
s
.116 .346 .812 r
.81422 .11425 m .81314 .1097 L p .80816 .10804 L F P
0 g
s
.955 .95 .697 r
.81301 .22889 m .81659 .2224 L .81654 .2271 L p F P
0 g
s
.955 .95 .697 r
.81654 .2271 m .81547 .22903 L .81301 .22889 L p F P
0 g
s
.922 .96 .787 r
.79817 .2551 m .79781 .25984 L .80317 .2526 L p F P
0 g
s
.922 .96 .787 r
.80317 .2526 m .80361 .24782 L .79817 .2551 L p F P
0 g
s
.932 .963 .762 r
.80396 .24731 m .80361 .24782 L .80317 .2526 L p F P
0 g
s
.781 .888 .922 r
.70342 .34543 m .69801 .34898 L .69513 .34682 L p F P
0 g
s
.742 .863 .937 r
.68287 .35424 m .67061 .36103 L .66767 .3585 L p F P
0 g
s
.912 .799 .323 r
.82815 .17819 m .82834 .18173 L .82935 .17595 L p F P
0 g
s
.912 .799 .323 r
.82935 .17595 m .82931 .17518 L .82815 .17819 L p F P
0 g
s
.951 .899 .739 r
.63804 .2037 m .63891 .20825 L .64304 .20147 L p F P
0 g
s
.951 .899 .739 r
.64304 .20147 m .642 .19697 L .63804 .2037 L p F P
0 g
s
.858 .935 .874 r
.76139 .30346 m .75888 .30202 L .7621 .299 L closepath p F P
0 g
s
.386 .544 .89 r
.80128 .09565 m .79674 .09475 L .79794 .09929 L p F P
0 g
s
.386 .544 .89 r
.79794 .09929 m .80414 .10071 L .80128 .09565 L p F P
0 g
s
.886 .865 .813 r
.6637 .15208 m .66887 .14585 L .67036 .15028 L p F P
0 g
s
.886 .865 .813 r
.67036 .15028 m .66664 .1547 L .6637 .15208 L p F P
0 g
s
.978 .919 .64 r
.62303 .24547 m .62336 .25013 L .62635 .2437 L p F P
0 g
s
.978 .919 .64 r
.62635 .2437 m .62586 .23909 L .62303 .24547 L p F P
0 g
s
.951 .955 .702 r
.81265 .23386 m .81547 .22903 L .81301 .22889 L p F P
0 g
s
0 0 .378 r
.60808 .32891 m .60699 .33387 L .60595 .32865 L p F P
0 g
s
0 0 .378 r
.60595 .32865 m .60715 .32365 L .60808 .32891 L p F P
0 g
s
0 0 .072 r
.60815 .31315 m .60731 .31642 L .60766 .31152 L p F P
0 g
s
0 0 .072 r
.60766 .31152 m .60869 .30745 L .60815 .31315 L p F P
0 g
s
.963 .937 .634 r
.81992 .21112 m .81991 .21583 L .82286 .20938 L p F P
0 g
s
.963 .937 .634 r
.82179 .20703 m .81992 .21112 L p .82286 .20938 L F P
0 g
s
.963 .937 .634 r
.82286 .20938 m .82288 .20683 L .82179 .20703 L p F P
0 g
s
.962 .888 .503 r
.82491 .19378 m .82514 .19845 L .82705 .19236 L p F P
0 g
s
.962 .888 .503 r
.82705 .19236 m .82685 .18767 L .82491 .19378 L p F P
0 g
s
.66 .738 .908 r
.7544 .08735 m .76695 .08301 L .76978 .08714 L p F P
0 g
s
.666 .742 .907 r
.76695 .08301 m .7544 .08735 L .75155 .08342 L p F P
0 g
s
.783 .896 .923 r
.70342 .34543 m .71023 .34085 L .70738 .33884 L p F P
0 g
s
.783 .896 .923 r
.70738 .33884 m .705 .34042 L .70342 .34543 L p F P
0 g
s
.781 .888 .922 r
.69513 .34682 m .705 .34042 L .70342 .34543 L p F P
0 g
s
.908 .862 .783 r
.66448 .15763 m .66664 .1547 L .6637 .15208 L p F P
0 g
s
.927 .795 .326 r
.82804 .17706 m .82815 .17819 L .82931 .17518 L p F P
0 g
s
.927 .795 .326 r
.82931 .17518 m .82894 .17131 L .82804 .17706 L p F P
0 g
s
.586 .696 .918 r
.76978 .08714 m .77932 .08549 L .78057 .09004 L p F P
0 g
s
.563 .677 .915 r
.78253 .08503 m .77932 .08549 L .78057 .09004 L p F P
0 g
s
.563 .677 .915 r
.78057 .09004 m .78536 .08945 L .78253 .08503 L p F P
0 g
s
0 0 .287 r
.82668 .14133 m .82736 .14595 L .82598 .14101 L p F P
0 g
s
0 0 .287 r
.82598 .14101 m .82528 .1364 L .82668 .14133 L p F P
0 g
s
.969 .918 .697 r
.62835 .22802 m .62886 .23266 L .63242 .22605 L p F P
0 g
s
.969 .918 .697 r
.63242 .22605 m .63175 .22146 L .62835 .22802 L p F P
0 g
s
.593 .7 .918 r
.77932 .08549 m .76978 .08714 L .76695 .08301 L p F P
0 g
s
.61 .745 .941 r
.62467 .36543 m .63702 .36259 L .64006 .36612 L p F P
0 g
s
.578 .716 .937 r
.63702 .36259 m .62467 .36543 L .62157 .3608 L p F P
0 g
s
.252 .452 .862 r
.80769 .10622 m .80701 .10589 L .80414 .10071 L p F P
0 g
s
.93 .885 .767 r
.64487 .18574 m .64595 .19025 L .6507 .18327 L p F P
0 g
s
.93 .885 .767 r
.6507 .18327 m .64945 .17881 L .64487 .18574 L p F P
0 g
s
.927 .876 .453 r
.61386 .28311 m .61334 .28474 L .61337 .28392 L closepath p F P
0 g
s
.916 .956 .801 r
.79244 .26248 m .79817 .2551 L .79781 .25984 L p F P
0 g
s
.916 .956 .801 r
.79241 .26287 m .79244 .26248 L p .79781 .25984 L F P
0 g
s
.916 .956 .801 r
.79781 .25984 m .79478 .26373 L .79241 .26287 L p F P
0 g
s
.908 .862 .783 r
.6637 .15208 m .66286 .15325 L .66448 .15763 L p F P
0 g
s
.909 .862 .783 r
.65773 .16035 m .6592 .16477 L .66448 .15763 L p F P
0 g
s
.909 .862 .783 r
.66448 .15763 m .66286 .15325 L .65773 .16035 L p F P
0 g
s
.716 .819 .929 r
.66585 .35938 m .65537 .36435 L .65238 .3614 L p F P
0 g
s
.678 .808 .945 r
.64006 .36612 m .65238 .3614 L .65537 .36435 L p F P
0 g
s
.714 .779 .903 r
.73988 .08915 m .73914 .08951 L .73628 .08574 L p F P
0 g
s
.757 .793 .882 r
.72398 .09345 m .73628 .08574 L .73914 .08951 L p F P
0 g
s
.389 .495 .846 r
.61528 .34938 m .61224 .34793 L .61037 .35308 L p F P
0 g
s
.389 .495 .846 r
.61037 .35308 m .61844 .35558 L .61528 .34938 L p F P
0 g
s
.797 .902 .915 r
.71824 .33518 m .71023 .34085 L .70738 .33884 L p F P
0 g
s
.252 .452 .862 r
.80414 .10071 m .80642 .10172 L .80769 .10622 L p F P
0 g
s
.15 .37 .824 r
.81199 .10516 m .81314 .1097 L .80769 .10622 L p F P
0 g
s
.15 .37 .824 r
.80769 .10622 m .80642 .10172 L .81199 .10516 L p F P
0 g
s
0 0 .467 r
.82451 .13179 m .82528 .1364 L .82313 .13174 L p F P
0 g
s
0 0 .467 r
.82313 .13174 m .82233 .12713 L .82451 .13179 L p F P
0 g
s
.72 .781 .901 r
.73988 .08915 m .75155 .08342 L .7487 .07948 L p F P
0 g
s
.72 .781 .901 r
.7487 .07948 m .73858 .08459 L .73988 .08915 L p F P
0 g
s
.714 .779 .903 r
.73628 .08574 m .73858 .08459 L .73988 .08915 L p F P
0 g
s
.951 .955 .702 r
.81301 .22889 m .81288 .22911 L .81265 .23386 L p F P
0 g
s
.944 .956 .738 r
.80848 .23606 m .80831 .24078 L .81265 .23386 L p F P
0 g
s
.944 .956 .738 r
.81265 .23386 m .81288 .22911 L .80848 .23606 L p F P
0 g
s
.817 .827 .857 r
.70791 .10582 m .69967 .11281 L .69675 .10944 L p F P
0 g
s
.845 .831 .833 r
.69782 .11461 m .69967 .11281 L .69675 .10944 L p F P
0 g
s
.885 .727 .215 r
.8284 .1667 m .82894 .17131 L .82934 .16575 L p F P
0 g
s
.885 .727 .215 r
.82934 .16575 m .82881 .16112 L .8284 .1667 L p F P
0 g
s
.845 .831 .833 r
.69675 .10944 m .69592 .11028 L .69782 .11461 L p F P
0 g
s
.843 .83 .835 r
.68763 .11845 m .6893 .12286 L .69782 .11461 L p F P
0 g
s
.843 .83 .835 r
.69782 .11461 m .69592 .11028 L .68763 .11845 L p F P
0 g
s
.951 .913 .743 r
.63413 .2103 m .63804 .2037 L .63891 .20825 L p F P
0 g
s
.951 .913 .743 r
.63891 .20825 m .63708 .21129 L .63413 .2103 L p F P
0 g
s
.91 .959 .809 r
.79478 .26373 m .79191 .26727 L .79241 .26287 L closepath p F P
0 g
s
.908 .847 .394 r
.61181 .28732 m .61172 .29077 L .61334 .28474 L p F P
0 g
s
.908 .847 .394 r
.61334 .28474 m .61337 .28392 L .61181 .28732 L p F P
0 g
s
.967 .935 .685 r
.62892 .23364 m .62831 .23372 L .62886 .23266 L closepath p F P
0 g
s
.663 .793 .944 r
.65238 .3614 m .64006 .36612 L .63702 .36259 L p F P
0 g
s
.841 .839 .844 r
.6847 .1213 m .68763 .11845 L .6893 .12286 L p F P
0 g
s
.841 .839 .844 r
.6893 .12286 m .68762 .12446 L .6847 .1213 L p F P
0 g
s
.821 .823 .85 r
.70791 .10582 m .71178 .10248 L .70889 .09896 L p F P
0 g
s
.821 .823 .85 r
.70889 .09896 m .70603 .10147 L .70791 .10582 L p F P
0 g
s
.817 .827 .857 r
.69675 .10944 m .70603 .10147 L .70791 .10582 L p F P
0 g
s
.869 .844 .818 r
.68195 .13071 m .68762 .12446 L .6847 .1213 L p F P
0 g
s
.734 .687 .143 r
.60944 .30254 m .60869 .30745 L .60974 .30159 L p F P
0 g
s
.734 .687 .143 r
.60974 .30159 m .61039 .29671 L .60944 .30254 L p F P
0 g
s
0 .061 .622 r
.82145 .12254 m .82233 .12713 L .81928 .12279 L p F P
0 g
s
0 .061 .622 r
.81928 .12279 m .81835 .11821 L .82145 .12254 L p F P
0 g
s
0 .231 .742 r
.81735 .11364 m .81835 .11821 L .81422 .11425 L p F P
0 g
s
0 .231 .742 r
.81422 .11425 m .81314 .1097 L .81735 .11364 L p F P
0 g
s
.963 .899 .526 r
.61587 .269 m .6159 .27372 L .61818 .2675 L p F P
0 g
s
.963 .899 .526 r
.61818 .2675 m .61801 .26282 L .61587 .269 L p F P
0 g
s
.789 .814 .872 r
.72024 .09625 m .71178 .10248 L .70889 .09896 L p F P
0 g
s
.897 .952 .83 r
.78589 .27013 m .78544 .27489 L .79191 .26727 L p F P
0 g
s
.897 .952 .83 r
.7922 .26278 m .78589 .27013 L p .79191 .26727 L F P
0 g
s
.897 .952 .83 r
.79191 .26727 m .79241 .26287 L .7922 .26278 L p F P
0 g
s
.174 .24 .692 r
.61305 .34447 m .61224 .34793 L .60767 .3438 L p F P
0 g
s
.174 .24 .692 r
.61208 .3419 m .61305 .34447 L p .60767 .3438 L F P
0 g
s
.174 .24 .692 r
.60767 .3438 m .60925 .33872 L .61208 .3419 L p F P
0 g
s
.975 .922 .62 r
.62029 .25184 m .62045 .25655 L .62336 .25013 L p F P
0 g
s
.975 .922 .62 r
.62336 .25013 m .62303 .24547 L .62029 .25184 L p F P
0 g
s
.761 .867 .926 r
.6874 .35154 m .68287 .35424 L .67995 .35182 L p F P
0 g
s
.742 .863 .937 r
.66767 .3585 m .67995 .35182 L .68287 .35424 L p F P
0 g
s
.965 .897 .707 r
.63516 .21491 m .63708 .21129 L .63413 .2103 L p F P
0 g
s
0 0 .169 r
.60744 .32189 m .60715 .32365 L .60702 .31816 L p F P
0 g
s
0 0 .169 r
.60702 .31816 m .60731 .31642 L .60744 .32189 L p F P
0 g
s
.803 .912 .914 r
.72243 .33214 m .71824 .33518 L .71968 .3303 L closepath p F P
0 g
s
.797 .902 .915 r
.71962 .33026 m .71968 .3303 L .71824 .33518 L p F P
0 g
s
.797 .902 .915 r
.70738 .33884 m .71962 .33026 L p .71824 .33518 L F P
0 g
s
.509 .61 .889 r
.61827 .36073 m .61931 .35711 L .62157 .3608 L closepath p F P
0 g
s
.934 .903 .77 r
.64597 .19037 m .6459 .19033 L .64595 .19025 L closepath p F P
0 g
s
.908 .875 .793 r
.65246 .16751 m .65773 .16035 L .6592 .16477 L p F P
0 g
s
.908 .875 .793 r
.65298 .16927 m .65246 .16751 L p .6592 .16477 L F P
0 g
s
.908 .875 .793 r
.6592 .16477 m .65477 .17066 L .65298 .16927 L p F P
0 g
s
.869 .844 .818 r
.6847 .1213 m .68019 .12634 L .68195 .13071 L p F P
0 g
s
.864 .849 .826 r
.67308 .13411 m .68019 .12634 L .68195 .13071 L p F P
0 g
s
.864 .849 .826 r
.67354 .13539 m .67308 .13411 L p .68195 .13071 L F P
0 g
s
.864 .849 .826 r
.68195 .13071 m .67563 .13751 L .67354 .13539 L p F P
0 g
s
.962 .943 .669 r
.81655 .21772 m .81659 .2224 L .81991 .21583 L p F P
0 g
s
.962 .943 .669 r
.81991 .21583 m .81992 .21112 L .81655 .21772 L p F P
0 g
s
.932 .896 .77 r
.64295 .18866 m .64487 .18574 L .64595 .19025 L p F P
0 g
s
.932 .896 .77 r
.64595 .19025 m .6459 .19033 L .64295 .18866 L p F P
0 g
s
.871 .844 .38 r
.61196 .28599 m .61181 .28732 L .61337 .28392 L p F P
0 g
s
.871 .844 .38 r
.61337 .28392 m .61381 .27989 L .61196 .28599 L p F P
0 g
s
.951 .86 .441 r
.82657 .183 m .82685 .18767 L .82834 .18173 L p F P
0 g
s
.951 .86 .441 r
.82762 .17884 m .82657 .183 L p .82834 .18173 L F P
0 g
s
.951 .86 .441 r
.82834 .18173 m .82815 .17819 L .82762 .17884 L p F P
0 g
s
.949 .887 .735 r
.642 .19697 m .6459 .19033 L .64295 .18866 L p F P
0 g
s
.968 .929 .691 r
.62537 .23386 m .62835 .22802 L .62886 .23266 L p F P
0 g
s
.968 .929 .691 r
.62886 .23266 m .62831 .23372 L .62537 .23386 L p F P
0 g
s
.813 .912 .907 r
.7311 .32555 m .72243 .33214 L .71968 .3303 L p F P
0 g
s
.789 .814 .872 r
.70889 .09896 m .71832 .0919 L .72024 .09625 L p F P
0 g
s
.794 .81 .865 r
.72024 .09625 m .72398 .09345 L .7211 .08978 L p F P
0 g
s
.794 .81 .865 r
.7211 .08978 m .71832 .0919 L .72024 .09625 L p F P
0 g
s
.462 .61 .911 r
.78536 .08945 m .79549 .09021 L .79674 .09475 L p F P
0 g
s
.472 .618 .913 r
.79549 .09021 m .78536 .08945 L .78253 .08503 L p F P
0 g
s
.972 .911 .569 r
.82256 .20003 m .82281 .20468 L .82514 .19845 L p F P
0 g
s
.972 .911 .569 r
.82514 .19845 m .82491 .19378 L .82256 .20003 L p F P
0 g
s
.815 .63 .076 r
.82821 .1565 m .82881 .16112 L .82868 .15574 L p F P
0 g
s
.815 .63 .076 r
.82868 .15574 m .82808 .15112 L .82821 .1565 L p F P
0 g
s
.971 .927 .619 r
.82288 .20683 m .82179 .20703 L .82281 .20468 L closepath p F P
0 g
s
.957 .927 .584 r
.62042 .2579 m .61961 .25853 L .62045 .25655 L closepath p F P
0 g
s
.98 .908 .657 r
.62586 .23909 m .62831 .23372 L .62537 .23386 L p F P
0 g
s
.885 .846 .801 r
.67563 .13751 m .67486 .13847 L .67354 .13539 L closepath p F P
0 g
s
.894 .948 .835 r
.78028 .27647 m .78589 .27013 L .78544 .27489 L p F P
0 g
s
.894 .948 .835 r
.78544 .27489 m .78291 .27773 L .78028 .27647 L p F P
0 g
s
.761 .867 .926 r
.67995 .35182 m .689 .34652 L .6874 .35154 L p F P
0 g
s
.761 .874 .929 r
.6874 .35154 m .69513 .34682 L .69224 .34458 L p F P
0 g
s
.761 .874 .929 r
.69224 .34458 m .689 .34652 L .6874 .35154 L p F P
0 g
s
.939 .955 .756 r
.80374 .24312 m .80848 .23606 L .80831 .24078 L p F P
0 g
s
.939 .955 .756 r
.80365 .24723 m .80374 .24312 L p .80831 .24078 L F P
0 g
s
.939 .955 .756 r
.80831 .24078 m .80396 .24731 L .80365 .24723 L p F P
0 g
s
.889 .848 .797 r
.66717 .14148 m .66887 .14585 L .67486 .13847 L p F P
0 g
s
.889 .848 .797 r
.67269 .13454 m .66717 .14148 L p .67486 .13847 L F P
0 g
s
.889 .848 .797 r
.67486 .13847 m .67354 .13539 L .67269 .13454 L p F P
0 g
s
.76 .792 .88 r
.73628 .08574 m .72398 .09345 L .7211 .08978 L p F P
0 g
s
.887 .951 .842 r
.77831 .28272 m .78291 .27773 L .78028 .27647 L p F P
0 g
s
.965 .897 .707 r
.63413 .2103 m .63405 .21044 L .63516 .21491 L p F P
0 g
s
.968 .897 .698 r
.63078 .21696 m .63175 .22146 L .63516 .21491 L p F P
0 g
s
.968 .897 .698 r
.63516 .21491 m .63405 .21044 L .63078 .21696 L p F P
0 g
s
.924 .867 .765 r
.65477 .17066 m .65395 .17192 L .65298 .16927 L closepath p F P
0 g
s
.819 .921 .904 r
.73462 .3228 m .7311 .32555 L .73221 .32126 L closepath p F P
0 g
s
.813 .912 .907 r
.73184 .321 m .73221 .32126 L .7311 .32555 L p F P
0 g
s
.813 .912 .907 r
.71971 .3302 m .73184 .321 L p .7311 .32555 L F P
0 g
s
.813 .912 .907 r
.71968 .3303 m .71971 .3302 L p .7311 .32555 L F P
0 g
s
0 0 .52 r
.60991 .33545 m .60925 .33872 L .60699 .33387 L p F P
0 g
s
0 0 .52 r
.60877 .33071 m .60991 .33545 L p .60699 .33387 L F P
0 g
s
0 0 .52 r
.60699 .33387 m .60808 .32891 L .60877 .33071 L p F P
0 g
s
.887 .951 .842 r
.78028 .27647 m .77895 .27791 L .77831 .28272 L p F P
0 g
s
.881 .946 .85 r
.77122 .28595 m .77895 .27791 L .77831 .28272 L p F P
0 g
s
.881 .946 .85 r
.77075 .29036 m .77122 .28595 L p .77831 .28272 L F P
0 g
s
.881 .946 .85 r
.77831 .28272 m .77094 .29045 L .77075 .29036 L p F P
0 g
s
.829 .921 .897 r
.74249 .31637 m .73462 .3228 L .73221 .32126 L p F P
0 g
s
.718 .841 .94 r
.66767 .3585 m .66585 .35938 L .66669 .35763 L closepath p F P
0 g
s
.716 .819 .929 r
.6647 .35579 m .66669 .35763 L .66585 .35938 L p F P
0 g
s
.716 .819 .929 r
.65238 .3614 m .6647 .35579 L p .66585 .35938 L F P
0 g
s
.929 .868 .758 r
.64797 .17441 m .64945 .17881 L .65395 .17192 L p F P
0 g
s
.929 .868 .758 r
.65182 .16838 m .64797 .17441 L p .65395 .17192 L F P
0 g
s
.929 .868 .758 r
.65395 .17192 m .65298 .16927 L .65182 .16838 L p F P
0 g
s
.265 .465 .869 r
.80642 .10172 m .80414 .10071 L .80128 .09565 L p F P
0 g
s
.591 .65 .877 r
.61931 .35711 m .62157 .3608 L .63396 .35881 L p F P
0 g
s
.578 .716 .937 r
.62157 .3608 m .63396 .35881 L .63702 .36259 L p F P
0 g
s
0 0 .231 r
.60829 .31866 m .60744 .32189 L .60731 .31642 L p F P
0 g
s
0 0 .231 r
.60731 .31642 m .60815 .31315 L .60829 .31866 L p F P
0 g
s
.709 .497 0 r
.8274 .1465 m .82808 .15112 L .82736 .14595 L p F P
0 g
s
.709 .497 0 r
.82736 .14595 m .82668 .14133 L .8274 .1465 L p F P
0 g
s
.834 .928 .894 r
.74249 .31637 m .74677 .31277 L .74402 .31109 L p F P
0 g
s
.834 .928 .894 r
.74402 .31109 m .74357 .31147 L .74249 .31637 L p F P
0 g
s
.829 .921 .897 r
.73232 .32062 m .74357 .31147 L .74249 .31637 L p F P
0 g
s
.829 .921 .897 r
.73221 .32126 m .73232 .32062 L p .74249 .31637 L F P
0 g
s
.74 .846 .929 r
.67702 .34931 m .67995 .35182 L .66767 .3585 L p F P
0 g
s
.74 .846 .929 r
.66745 .35436 m .67702 .34931 L p .66767 .3585 L F P
0 g
s
.74 .846 .929 r
.66767 .3585 m .66669 .35763 L .66745 .35436 L p F P
0 g
s
.881 .807 .324 r
.61054 .29197 m .61039 .29671 L .61172 .29077 L p F P
0 g
s
.881 .807 .324 r
.61106 .28956 m .61054 .29197 L p .61172 .29077 L F P
0 g
s
.881 .807 .324 r
.61172 .29077 m .61181 .28732 L .61106 .28956 L p F P
0 g
s
.398 .558 .896 r
.79843 .09071 m .79549 .09021 L .79674 .09475 L p F P
0 g
s
.398 .558 .896 r
.79674 .09475 m .80128 .09565 L .79843 .09071 L p F P
0 g
s
.945 .883 .477 r
.61392 .27513 m .61381 .27989 L .6159 .27372 L p F P
0 g
s
.945 .883 .477 r
.6159 .27372 m .61587 .269 L .61392 .27513 L p F P
0 g
s
.886 .858 .808 r
.66112 .1489 m .66717 .14148 L .66887 .14585 L p F P
0 g
s
.886 .858 .808 r
.66153 .15007 m .66112 .1489 L p .66887 .14585 L F P
0 g
s
.886 .858 .808 r
.66887 .14585 m .6637 .15208 L .66153 .15007 L p F P
0 g
s
.873 .947 .859 r
.77094 .29045 m .77069 .29071 L .77075 .29036 L closepath p F P
0 g
s
.951 .887 .733 r
.63689 .19922 m .63804 .2037 L .642 .19697 L p F P
0 g
s
.951 .887 .733 r
.642 .19697 m .64071 .19253 L .63689 .19922 L p F P
0 g
s
.949 .887 .735 r
.64295 .18866 m .64071 .19253 L .642 .19697 L p F P
0 g
s
.86 .937 .872 r
.76278 .29421 m .7621 .299 L .77069 .29071 L p F P
0 g
s
.86 .937 .872 r
.76826 .28892 m .76278 .29421 L p .77069 .29071 L F P
0 g
s
.86 .937 .872 r
.77069 .29071 m .77075 .29036 L .76826 .28892 L p F P
0 g
s
.666 .742 .907 r
.75155 .08342 m .7641 .0789 L .76695 .08301 L p F P
0 g
s
.67 .745 .907 r
.7641 .0789 m .75155 .08342 L .7487 .07948 L p F P
0 g
s
.778 .884 .922 r
.705 .34042 m .69513 .34682 L .69224 .34458 L p F P
0 g
s
.965 .926 .598 r
.61765 .25818 m .62029 .25184 L .62045 .25655 L p F P
0 g
s
.965 .926 .598 r
.61769 .25979 m .61765 .25818 L p .62045 .25655 L F P
0 g
s
.965 .926 .598 r
.62045 .25655 m .61961 .25853 L .61769 .25979 L p F P
0 g
s
.938 .801 .341 r
.8275 .17245 m .82804 .17706 L .82894 .17131 L p F P
0 g
s
.938 .801 .341 r
.82894 .17131 m .8284 .1667 L .8275 .17245 L p F P
0 g
s
.844 .928 .886 r
.75275 .30754 m .74677 .31277 L .74402 .31109 L p F P
0 g
s
.958 .946 .697 r
.81281 .22445 m .81655 .21772 L .81659 .2224 L p F P
0 g
s
.958 .946 .697 r
.81289 .22888 m .81281 .22445 L p .81659 .2224 L F P
0 g
s
.958 .946 .697 r
.81659 .2224 m .81301 .22889 L .81289 .22888 L p F P
0 g
s
.933 .959 .765 r
.80396 .24731 m .80361 .24782 L .80365 .24723 L closepath p F P
0 g
s
.85 .933 .881 r
.75275 .30754 m .75888 .30202 L .75617 .30041 L p F P
0 g
s
.85 .933 .881 r
.75617 .30041 m .75362 .3027 L .75275 .30754 L p F P
0 g
s
.844 .928 .886 r
.74402 .31109 m .75362 .3027 L .75275 .30754 L p F P
0 g
s
.858 .933 .873 r
.75617 .30041 m .76278 .29421 L .7621 .299 L p F P
0 g
s
.858 .933 .873 r
.7621 .299 m .75888 .30202 L .75617 .30041 L p F P
0 g
s
.92 .954 .794 r
.79844 .25036 m .79817 .2551 L .80361 .24782 L p F P
0 g
s
.92 .954 .794 r
.8014 .24638 m .79844 .25036 L p .80361 .24782 L F P
0 g
s
.92 .954 .794 r
.80361 .24782 m .80365 .24723 L .8014 .24638 L p F P
0 g
s
.593 .7 .918 r
.76695 .08301 m .77808 .08091 L .77932 .08549 L p F P
0 g
s
.599 .702 .915 r
.77808 .08091 m .76695 .08301 L .7641 .0789 L p F P
0 g
s
0 0 .002 r
.60896 .30823 m .60815 .31315 L .60869 .30745 L p F P
0 g
s
0 0 .002 r
.60869 .30745 m .60944 .30254 L .60896 .30823 L p F P
0 g
s
.872 .936 .86 r
.77075 .29036 m .76826 .28892 L .77122 .28595 L closepath p F P
0 g
s
.98 .908 .657 r
.62537 .23386 m .62506 .23456 L .62586 .23909 L p F P
0 g
s
.983 .906 .641 r
.62236 .2409 m .62303 .24547 L .62586 .23909 L p F P
0 g
s
.983 .906 .641 r
.62586 .23909 m .62506 .23456 L .62236 .2409 L p F P
0 g
s
.572 .684 .917 r
.77969 .08065 m .77808 .08091 L .77932 .08549 L p F P
0 g
s
.572 .684 .917 r
.77932 .08549 m .78253 .08503 L .77969 .08065 L p F P
0 g
s
.968 .891 .517 r
.8246 .18912 m .82491 .19378 L .82685 .18767 L p F P
0 g
s
.968 .891 .517 r
.82685 .18767 m .82657 .183 L .8246 .18912 L p F P
0 g
s
.98 .906 .579 r
.61961 .25853 m .61801 .26282 L .61769 .25979 L closepath p F P
0 g
s
.972 .926 .622 r
.81981 .20643 m .82256 .20003 L .82281 .20468 L p F P
0 g
s
.972 .926 .622 r
.81986 .20734 m .81981 .20643 L p .82281 .20468 L F P
0 g
s
.972 .926 .622 r
.82281 .20468 m .82179 .20703 L .81986 .20734 L p F P
0 g
s
.904 .854 .782 r
.6637 .15208 m .66286 .15325 L .66153 .15007 L closepath p F P
0 g
s
0 0 .278 r
.82591 .13672 m .82668 .14133 L .82528 .1364 L p F P
0 g
s
0 0 .278 r
.82528 .1364 m .82451 .13179 L .82591 .13672 L p F P
0 g
s
.93 .949 .78 r
.80365 .24723 m .8014 .24638 L .80374 .24312 L closepath p F P
0 g
s
.718 .78 .901 r
.73858 .08459 m .73628 .08574 L .73341 .08194 L p F P
0 g
s
.76 .792 .88 r
.7211 .08978 m .73341 .08194 L .73628 .08574 L p F P
0 g
s
.909 .855 .776 r
.65605 .15599 m .65773 .16035 L .66286 .15325 L p F P
0 g
s
.909 .855 .776 r
.66075 .14935 m .65605 .15599 L p .66286 .15325 L F P
0 g
s
.909 .855 .776 r
.66286 .15325 m .66153 .15007 L .66075 .14935 L p F P
0 g
s
.971 .904 .693 r
.62753 .22347 m .62835 .22802 L .63175 .22146 L p F P
0 g
s
.971 .904 .693 r
.63175 .22146 m .63078 .21696 L .62753 .22347 L p F P
0 g
s
.698 .823 .942 r
.6647 .35579 m .65238 .3614 L .64937 .35828 L p F P
0 g
s
.663 .793 .944 r
.63702 .36259 m .64937 .35828 L .65238 .3614 L p F P
0 g
s
.93 .874 .76 r
.64354 .18129 m .64487 .18574 L .64945 .17881 L p F P
0 g
s
.93 .874 .76 r
.64945 .17881 m .64797 .17441 L .64354 .18129 L p F P
0 g
s
0 0 .345 r
.60821 .32812 m .60808 .32891 L .60715 .32365 L p F P
0 g
s
0 0 .345 r
.60715 .32365 m .60744 .32189 L .60821 .32812 L p F P
0 g
s
.645 .776 .944 r
.64937 .35828 m .63702 .36259 L .63396 .35881 L p F P
0 g
s
.733 .839 .93 r
.66669 .35763 m .6647 .35579 L .66745 .35436 L closepath p F P
0 g
s
.818 .823 .854 r
.70603 .10147 m .69675 .10944 L .69394 .10613 L p F P
0 g
s
.843 .826 .831 r
.69675 .10944 m .69592 .11028 L .69394 .10613 L closepath p F P
0 g
s
.847 .827 .828 r
.68578 .11409 m .68763 .11845 L .69592 .11028 L p F P
0 g
s
.847 .827 .828 r
.69383 .10601 m .68578 .11409 L p .69592 .11028 L F P
0 g
s
.847 .827 .828 r
.69592 .11028 m .69394 .10613 L .69383 .10601 L p F P
0 g
s
.265 .465 .869 r
.80128 .09565 m .80507 .09722 L .80642 .10172 L p F P
0 g
s
.154 .378 .829 r
.81076 .10063 m .81199 .10516 L .80642 .10172 L p F P
0 g
s
.154 .378 .829 r
.80642 .10172 m .80507 .09722 L .81076 .10063 L p F P
0 g
s
.723 .78 .898 r
.73858 .08459 m .7487 .07948 L .74583 .07553 L p F P
0 g
s
.723 .78 .898 r
.74583 .07553 m .73697 .08011 L .73858 .08459 L p F P
0 g
s
.718 .78 .901 r
.73341 .08194 m .73697 .08011 L .73858 .08459 L p F P
0 g
s
.783 .895 .923 r
.70738 .33884 m .705 .34042 L .70585 .33772 L closepath p F P
0 g
s
.778 .884 .922 r
.70452 .33669 m .70585 .33772 L .705 .34042 L p F P
0 g
s
.778 .884 .922 r
.69224 .34458 m .70452 .33669 L p .705 .34042 L F P
0 g
s
.916 .951 .803 r
.79263 .25778 m .79244 .26248 L .79817 .2551 L p F P
0 g
s
.916 .951 .803 r
.79817 .2551 m .79844 .25036 L .79263 .25778 L p F P
0 g
s
.967 .933 .631 r
.82179 .20703 m .81992 .21112 L .81986 .20734 L closepath p F P
0 g
s
0 0 .464 r
.82365 .12719 m .82451 .13179 L .82233 .12713 L p F P
0 g
s
0 0 .464 r
.82233 .12713 m .82145 .12254 L .82365 .12719 L p F P
0 g
s
.822 .819 .846 r
.70603 .10147 m .70889 .09896 L .70598 .09538 L p F P
0 g
s
.822 .819 .846 r
.70598 .09538 m .70399 .09715 L .70603 .10147 L p F P
0 g
s
.818 .823 .854 r
.69387 .10597 m .70399 .09715 L .70603 .10147 L p F P
0 g
s
.818 .823 .854 r
.69394 .10613 m .69387 .10597 L p .70603 .10147 L F P
0 g
s
.96 .851 .435 r
.82815 .17819 m .82762 .17884 L .82804 .17706 L closepath p F P
0 g
s
.898 .735 .232 r
.82779 .16209 m .8284 .1667 L .82881 .16112 L p F P
0 g
s
.898 .735 .232 r
.82881 .16112 m .82821 .1565 L .82779 .16209 L p F P
0 g
s
.791 .812 .869 r
.71832 .0919 m .70889 .09896 L .70598 .09538 L p F P
0 g
s
.842 .835 .839 r
.68176 .11804 m .68578 .11409 L .68763 .11845 L p F P
0 g
s
.842 .835 .839 r
.68763 .11845 m .6847 .1213 L .68176 .11804 L p F P
0 g
s
.951 .903 .74 r
.63305 .20592 m .63689 .19922 L .63804 .2037 L p F P
0 g
s
.951 .903 .74 r
.634 .21024 m .63305 .20592 L p .63804 .2037 L F P
0 g
s
.951 .903 .74 r
.63804 .2037 m .63413 .2103 L .634 .21024 L p F P
0 g
s
.868 .838 .814 r
.68019 .12634 m .6847 .1213 L .68176 .11804 L p F P
0 g
s
.8 .897 .912 r
.71679 .32815 m .71962 .33026 L .70738 .33884 L p F P
0 g
s
.8 .897 .912 r
.7063 .33548 m .71679 .32815 L p .70738 .33884 L F P
0 g
s
.8 .897 .912 r
.70738 .33884 m .70585 .33772 L .7063 .33548 L p F P
0 g
s
.867 .85 .825 r
.67354 .13539 m .67269 .13454 L .67308 .13411 L closepath p F P
0 g
s
.953 .951 .707 r
.81301 .22889 m .81288 .22911 L .81289 .22888 L closepath p F P
0 g
s
.518 .593 .869 r
.61844 .35558 m .6201 .35561 L .61931 .35711 L closepath p F P
0 g
s
.591 .65 .877 r
.63089 .35475 m .6201 .35561 L .61931 .35711 L p F P
0 g
s
.591 .65 .877 r
.63396 .35881 m .63089 .35475 L p .61931 .35711 L F P
0 g
s
0 .237 .747 r
.81627 .10907 m .81735 .11364 L .81314 .1097 L p F P
0 g
s
0 .237 .747 r
.81314 .1097 m .81199 .10516 L .81627 .10907 L p F P
0 g
s
.943 .952 .747 r
.80856 .23135 m .80848 .23606 L .81288 .22911 L p F P
0 g
s
.943 .952 .747 r
.8105 .22826 m .80856 .23135 L p .81288 .22911 L F P
0 g
s
.943 .952 .747 r
.81288 .22911 m .81289 .22888 L .8105 .22826 L p F P
0 g
s
0 .064 .625 r
.8205 .11795 m .82145 .12254 L .81835 .11821 L p F P
0 g
s
0 .064 .625 r
.81835 .11821 m .81735 .11364 L .8205 .11795 L p F P
0 g
s
.472 .618 .913 r
.78253 .08503 m .79418 .08567 L .79549 .09021 L p F P
0 g
s
.483 .622 .911 r
.79418 .08567 m .78253 .08503 L .77969 .08065 L p F P
0 g
s
.912 .877 .788 r
.65298 .16927 m .65182 .16838 L .65246 .16751 L closepath p F P
0 g
s
.952 .945 .731 r
.81289 .22888 m .8105 .22826 L .81281 .22445 L closepath p F P
0 g
s
.907 .948 .818 r
.79241 .26287 m .7922 .26278 L .79244 .26248 L closepath p F P
0 g
s
.868 .838 .814 r
.68176 .11804 m .67824 .12202 L .68019 .12634 L p F P
0 g
s
.865 .837 .817 r
.67131 .12973 m .67308 .13411 L .68019 .12634 L p F P
0 g
s
.865 .837 .817 r
.68019 .12634 m .67824 .12202 L .67131 .12973 L p F P
0 g
s
.917 .856 .413 r
.61221 .2812 m .61196 .28599 L .61381 .27989 L p F P
0 g
s
.917 .856 .413 r
.61381 .27989 m .61392 .27513 L .61221 .2812 L p F P
0 g
s
.978 .896 .547 r
.61546 .26439 m .61587 .269 L .61801 .26282 L p F P
0 g
s
.978 .896 .547 r
.6167 .26065 m .61546 .26439 L p .61801 .26282 L F P
0 g
s
.978 .896 .547 r
.61801 .26282 m .61769 .25979 L .6167 .26065 L p F P
0 g
s
.757 .861 .926 r
.689 .34652 m .67995 .35182 L .67702 .34931 L p F P
0 g
s
.908 .86 .782 r
.65093 .1631 m .65246 .16751 L .65773 .16035 L p F P
0 g
s
.908 .86 .782 r
.65773 .16035 m .65605 .15599 L .65093 .1631 L p F P
0 g
s
.33 .429 .812 r
.61224 .34793 m .61305 .34447 L .61528 .34938 L closepath p F P
0 g
s
.824 .737 .212 r
.60966 .29779 m .60944 .30254 L .61039 .29671 L p F P
0 g
s
.824 .737 .212 r
.61039 .29671 m .61054 .29197 L .60966 .29779 L p F P
0 g
s
.467 .548 .855 r
.6201 .35561 m .61844 .35558 L .61528 .34938 L p F P
0 g
s
.791 .812 .869 r
.70598 .09538 m .71624 .08759 L .71832 .0919 L p F P
0 g
s
.795 .808 .862 r
.71832 .0919 m .7211 .08978 L .7182 .08607 L p F P
0 g
s
.795 .808 .862 r
.7182 .08607 m .71624 .08759 L .71832 .0919 L p F P
0 g
s
.983 .909 .624 r
.61976 .24723 m .62029 .25184 L .62303 .24547 L p F P
0 g
s
.983 .909 .624 r
.62303 .24547 m .62236 .2409 L .61976 .24723 L p F P
0 g
s
.931 .886 .766 r
.63998 .18679 m .64354 .18129 L .64487 .18574 L p F P
0 g
s
.931 .886 .766 r
.64487 .18574 m .64295 .18866 L .63998 .18679 L p F P
0 g
s
.907 .944 .818 r
.78958 .26149 m .79263 .25778 L .79244 .26248 L p F P
0 g
s
.907 .944 .818 r
.79244 .26248 m .7922 .26278 L .78958 .26149 L p F P
0 g
s
.901 .948 .825 r
.78589 .27013 m .7922 .26278 L .78958 .26149 L p F P
0 g
s
.963 .852 .439 r
.82613 .17836 m .8275 .17245 L .82804 .17706 L p F P
0 g
s
.963 .852 .439 r
.82636 .18033 m .82613 .17836 L p .82804 .17706 L F P
0 g
s
.963 .852 .439 r
.82804 .17706 m .82762 .17884 L .82636 .18033 L p F P
0 g
s
.276 .478 .875 r
.80507 .09722 m .80128 .09565 L .79843 .09071 L p F P
0 g
s
.963 .942 .685 r
.81642 .21304 m .81655 .21772 L .81992 .21112 L p F P
0 g
s
.963 .942 .685 r
.81938 .20729 m .81642 .21304 L p .81992 .21112 L F P
0 g
s
.963 .942 .685 r
.81992 .21112 m .81986 .20734 L .81938 .20729 L p F P
0 g
s
.762 .792 .878 r
.73341 .08194 m .7211 .08978 L .7182 .08607 L p F P
0 g
s
.97 .919 .693 r
.62432 .22999 m .62753 .22347 L .62835 .22802 L p F P
0 g
s
.97 .919 .693 r
.6249 .23384 m .62432 .22999 L p .62835 .22802 L F P
0 g
s
.97 .919 .693 r
.62835 .22802 m .62537 .23386 L .6249 .23384 L p F P
0 g
s
0 0 .407 r
.60935 .32388 m .60821 .32812 L .60744 .32189 L p F P
0 g
s
0 0 .407 r
.60744 .32189 m .60829 .31866 L .60935 .32388 L p F P
0 g
s
.865 .845 .823 r
.66974 .13147 m .67131 .12973 L .67308 .13411 L p F P
0 g
s
.865 .845 .823 r
.67308 .13411 m .67269 .13454 L .66974 .13147 L p F P
0 g
s
.89 .847 .795 r
.66717 .14148 m .67269 .13454 L .66974 .13147 L p F P
0 g
s
.832 .64 .093 r
.82752 .1519 m .82821 .1565 L .82808 .15112 L p F P
0 g
s
.832 .64 .093 r
.82808 .15112 m .8274 .1465 L .82752 .1519 L p F P
0 g
s
.976 .911 .58 r
.82222 .19539 m .82256 .20003 L .82491 .19378 L p F P
0 g
s
.976 .911 .58 r
.82491 .19378 m .8246 .18912 L .82222 .19539 L p F P
0 g
s
.807 .903 .909 r
.71968 .3303 m .71962 .33026 L .71971 .3302 L closepath p F P
0 g
s
0 0 .171 r
.60911 .31374 m .60829 .31866 L .60815 .31315 L p F P
0 g
s
0 0 .171 r
.60815 .31315 m .60896 .30823 L .60911 .31374 L p F P
0 g
s
.806 .897 .907 r
.71971 .3302 m .71962 .33026 L .71679 .32815 L p F P
0 g
s
.811 .902 .905 r
.71971 .3302 m .73184 .321 L .72903 .31899 L p F P
0 g
s
.811 .902 .905 r
.72903 .31899 m .72055 .32538 L .71971 .3302 L p F P
0 g
s
.806 .897 .907 r
.71679 .32815 m .72055 .32538 L .71971 .3302 L p F P
0 g
s
.129 .226 .698 r
.60925 .33872 m .60991 .33545 L .61208 .3419 L closepath p F P
0 g
s
.947 .875 .732 r
.64071 .19253 m .64295 .18866 L .63998 .18679 L p F P
0 g
s
.467 .548 .855 r
.61528 .34938 m .62222 .35038 L .6201 .35561 L p F P
0 g
s
.546 .667 .917 r
.62779 .35037 m .62222 .35038 L .6201 .35561 L p F P
0 g
s
.546 .667 .917 r
.6201 .35561 m .63089 .35475 L .62779 .35037 L p F P
0 g
s
.833 .795 .299 r
.61181 .28732 m .61106 .28956 L .61196 .28599 L closepath p F P
0 g
s
.962 .888 .71 r
.63413 .2103 m .63405 .21044 L .634 .21024 L closepath p F P
0 g
s
.938 .95 .763 r
.80376 .23843 m .80374 .24312 L .80848 .23606 L p F P
0 g
s
.938 .95 .763 r
.80848 .23606 m .80856 .23135 L .80376 .23843 L p F P
0 g
s
.967 .887 .698 r
.62955 .21252 m .63078 .21696 L .63405 .21044 L p F P
0 g
s
.967 .887 .698 r
.63117 .20925 m .62955 .21252 L p .63405 .21044 L F P
0 g
s
.967 .887 .698 r
.63405 .21044 m .634 .21024 L .63117 .20925 L p F P
0 g
s
.958 .857 .444 r
.82762 .17884 m .82657 .183 L .82636 .18033 L closepath p F P
0 g
s
.901 .948 .825 r
.78958 .26149 m .78626 .26539 L .78589 .27013 L p F P
0 g
s
.895 .944 .834 r
.77934 .27317 m .78626 .26539 L .78589 .27013 L p F P
0 g
s
.895 .944 .834 r
.77917 .27592 m .77934 .27317 L p .78589 .27013 L F P
0 g
s
.895 .944 .834 r
.78589 .27013 m .78028 .27647 L .77917 .27592 L p F P
0 g
s
.822 .911 .9 r
.73221 .32126 m .73184 .321 L .73232 .32062 L closepath p F P
0 g
s
.957 .903 .728 r
.634 .21024 m .63117 .20925 L .63305 .20592 L closepath p F P
0 g
s
.91 .869 .786 r
.64885 .16598 m .65093 .1631 L .65246 .16751 L p F P
0 g
s
.91 .869 .786 r
.65246 .16751 m .65182 .16838 L .64885 .16598 L p F P
0 g
s
.67 .745 .907 r
.7487 .07948 m .76126 .0748 L .7641 .0789 L p F P
0 g
s
.675 .748 .906 r
.76126 .0748 m .7487 .07948 L .74583 .07553 L p F P
0 g
s
.929 .864 .755 r
.64797 .17441 m .65182 .16838 L .64885 .16598 L p F P
0 g
s
.599 .702 .915 r
.77685 .07631 m .77808 .08091 L p .7641 .0789 L F P
0 g
s
.599 .702 .915 r
.7641 .0789 m .77685 .07631 L .77685 .07631 L p F P
0 g
s
.606 .707 .916 r
.77685 .07631 m .7641 .0789 L .76126 .0748 L p F P
0 g
s
.757 .861 .926 r
.68934 .34223 m .69019 .34294 L .689 .34652 L p F P
0 g
s
.757 .861 .926 r
.67702 .34931 m .68934 .34223 L p .689 .34652 L F P
0 g
s
.761 .876 .93 r
.69224 .34458 m .689 .34652 L .69019 .34294 L closepath p F P
0 g
s
.89 .86 .805 r
.66153 .15007 m .66075 .14935 L .66112 .1489 L closepath p F P
0 g
s
.887 .846 .799 r
.65937 .14453 m .66112 .1489 L .66717 .14148 L p F P
0 g
s
.887 .846 .799 r
.66717 .14148 m .66528 .13715 L .65937 .14453 L p F P
0 g
s
.89 .847 .795 r
.66974 .13147 m .66528 .13715 L .66717 .14148 L p F P
0 g
s
.732 .831 .926 r
.66745 .35436 m .6647 .35579 L .66172 .35293 L p F P
0 g
s
.698 .823 .942 r
.64937 .35828 m .66172 .35293 L .6647 .35579 L p F P
0 g
s
.409 .571 .902 r
.79557 .08587 m .79418 .08567 L .79549 .09021 L p F P
0 g
s
.409 .571 .902 r
.79549 .09021 m .79843 .09071 L .79557 .08587 L p F P
0 g
s
.888 .947 .843 r
.78028 .27647 m .77895 .27791 L .77917 .27592 L closepath p F P
0 g
s
.821 .906 .899 r
.73232 .32062 m .73184 .321 L .72903 .31899 L p F P
0 g
s
.727 .508 0 r
.82664 .1419 m .8274 .1465 L .82668 .14133 L p F P
0 g
s
.727 .508 0 r
.82668 .14133 m .82591 .13672 L .82664 .1419 L p F P
0 g
s
.79 .888 .916 r
.70585 .33772 m .70452 .33669 L .7063 .33548 L closepath p F P
0 g
s
.822 .913 .9 r
.73305 .31583 m .73232 .32062 L .74357 .31147 L p F P
0 g
s
.821 .906 .899 r
.72903 .31899 m .73305 .31583 L .73232 .32062 L p F P
0 g
s
.947 .875 .732 r
.63998 .18679 m .6392 .18815 L .64071 .19253 L p F P
0 g
s
.95 .875 .728 r
.6355 .19481 m .63689 .19922 L .64071 .19253 L p F P
0 g
s
.95 .875 .728 r
.64071 .19253 m .6392 .18815 L .6355 .19481 L p F P
0 g
s
.874 .937 .858 r
.77165 .2812 m .77122 .28595 L .77895 .27791 L p F P
0 g
s
.874 .937 .858 r
.77762 .27501 m .77165 .2812 L p .77895 .27791 L F P
0 g
s
.874 .937 .858 r
.77895 .27791 m .77917 .27592 L .77762 .27501 L p F P
0 g
s
.947 .806 .356 r
.82687 .16785 m .8275 .17245 L .8284 .1667 L p F P
0 g
s
.947 .806 .356 r
.8284 .1667 m .82779 .16209 L .82687 .16785 L p F P
0 g
s
0 0 .508 r
.60808 .32891 m .60821 .32812 L .60877 .33071 L closepath p F P
0 g
s
.78 .878 .919 r
.70164 .33439 m .70452 .33669 L .69224 .34458 L p F P
0 g
s
.78 .878 .919 r
.69046 .34153 m .70164 .33439 L p .69224 .34458 L F P
0 g
s
.78 .878 .919 r
.69224 .34458 m .69019 .34294 L .69046 .34153 L p F P
0 g
s
.97 .881 .499 r
.61362 .27049 m .61392 .27513 L .61587 .269 L p F P
0 g
s
.97 .881 .499 r
.61587 .269 m .61546 .26439 L .61362 .27049 L p F P
0 g
s
.959 .942 .707 r
.81263 .21979 m .81281 .22445 L .81655 .21772 L p F P
0 g
s
.959 .942 .707 r
.81655 .21772 m .81642 .21304 L .81263 .21979 L p F P
0 g
s
.979 .899 .664 r
.62537 .23386 m .62506 .23456 L .6249 .23384 L closepath p F P
0 g
s
.728 .836 .931 r
.66745 .35436 m .67702 .34931 L .67407 .3467 L p F P
0 g
s
.728 .836 .931 r
.67407 .3467 m .66868 .34944 L .66745 .35436 L p F P
0 g
s
.732 .831 .926 r
.66172 .35293 m .66868 .34944 L .66745 .35436 L p F P
0 g
s
.981 .91 .602 r
.61728 .25353 m .61765 .25818 L .62029 .25184 L p F P
0 g
s
.981 .91 .602 r
.62029 .25184 m .61976 .24723 L .61728 .25353 L p F P
0 g
s
.861 .812 .327 r
.61079 .28718 m .61221 .2812 L .61196 .28599 L p F P
0 g
s
.861 .812 .327 r
.61052 .29106 m .61079 .28718 L p .61196 .28599 L F P
0 g
s
.861 .812 .327 r
.61196 .28599 m .61106 .28956 L .61052 .29106 L p F P
0 g
s
.722 .78 .899 r
.73697 .08011 m .73341 .08194 L .73052 .0781 L p F P
0 g
s
.762 .792 .878 r
.7182 .08607 m .73052 .0781 L .73341 .08194 L p F P
0 g
s
.872 .933 .86 r
.76556 .28732 m .77165 .2812 L .77122 .28595 L p F P
0 g
s
.872 .933 .86 r
.77122 .28595 m .76826 .28892 L .76556 .28732 L p F P
0 g
s
.485 .521 .819 r
.61305 .34447 m .61528 .34938 L .62222 .35038 L p F P
0 g
s
.58 .691 .918 r
.77808 .08091 m .77685 .07631 L .77969 .08065 L closepath p F P
0 g
s
.622 .757 .943 r
.64635 .355 m .63396 .35881 L .63089 .35475 L p F P
0 g
s
.645 .776 .944 r
.63396 .35881 m .64635 .355 L .64937 .35828 L p F P
0 g
s
.834 .924 .893 r
.74402 .31109 m .74357 .31147 L .74369 .31088 L closepath p F P
0 g
s
.822 .913 .9 r
.74125 .30919 m .73305 .31583 L p .74357 .31147 L F P
0 g
s
.822 .913 .9 r
.74357 .31147 m .74369 .31088 L .74125 .30919 L p F P
0 g
s
.843 .923 .885 r
.75362 .3027 m .74402 .31109 L .74369 .31088 L p F P
0 g
s
.93 .947 .781 r
.79883 .24537 m .80376 .23843 L .80374 .24312 L p F P
0 g
s
.93 .947 .781 r
.80374 .24312 m .8014 .24638 L .79883 .24537 L p F P
0 g
s
.864 .934 .867 r
.76278 .29421 m .76826 .28892 L .76556 .28732 L p F P
0 g
s
.984 .897 .646 r
.6214 .23642 m .62236 .2409 L .62506 .23456 L p F P
0 g
s
.984 .897 .646 r
.62242 .23396 m .6214 .23642 L p .62506 .23456 L F P
0 g
s
.984 .897 .646 r
.62506 .23456 m .6249 .23384 L .62242 .23396 L p F P
0 g
s
.688 .812 .941 r
.66172 .35293 m .64937 .35828 L .64635 .355 L p F P
0 g
s
.864 .934 .867 r
.76556 .28732 m .76339 .28942 L .76278 .29421 L p F P
0 g
s
.858 .929 .873 r
.75433 .29789 m .76339 .28942 L .76278 .29421 L p F P
0 g
s
.858 .929 .873 r
.75419 .2992 m .75433 .29789 L p .76278 .29421 L F P
0 g
s
.858 .929 .873 r
.76278 .29421 m .75617 .30041 L .75419 .2992 L p F P
0 g
s
.849 .93 .881 r
.75617 .30041 m .75362 .3027 L .75419 .2992 L closepath p F P
0 g
s
.843 .923 .885 r
.75343 .29869 m .75419 .2992 L .75362 .3027 L p F P
0 g
s
.843 .923 .885 r
.74421 .30669 m .75343 .29869 L p .75362 .3027 L F P
0 g
s
.843 .923 .885 r
.74369 .31088 m .74421 .30669 L p .75362 .3027 L F P
0 g
s
.887 .854 .804 r
.65777 .14652 m .65937 .14453 L .66112 .1489 L p F P
0 g
s
.887 .854 .804 r
.66112 .1489 m .66075 .14935 L .65777 .14652 L p F P
0 g
s
0 0 .274 r
.82524 .13306 m .82591 .13672 L .82451 .13179 L p F P
0 g
s
0 0 .274 r
.82449 .13005 m .82524 .13306 L p .82451 .13179 L F P
0 g
s
0 0 .274 r
.82451 .13179 m .82365 .12719 L .82449 .13005 L p F P
0 g
s
.819 .825 .854 r
.69394 .10613 m .69383 .10601 L .69387 .10597 L closepath p F P
0 g
s
.975 .894 .536 r
.82421 .18447 m .8246 .18912 L .82657 .183 L p F P
0 g
s
.975 .894 .536 r
.82538 .18084 m .82421 .18447 L p .82657 .183 L F P
0 g
s
.975 .894 .536 r
.82657 .183 m .82636 .18033 L .82538 .18084 L p F P
0 g
s
.909 .852 .774 r
.65605 .15599 m .66075 .14935 L .65777 .14652 L p F P
0 g
s
.929 .864 .755 r
.64885 .16598 m .64628 .17005 L .64797 .17441 L p F P
0 g
s
.929 .864 .754 r
.64197 .17691 m .64354 .18129 L .64797 .17441 L p F P
0 g
s
.929 .864 .754 r
.64797 .17441 m .64628 .17005 L .64197 .17691 L p F P
0 g
s
.976 .922 .629 r
.81943 .20181 m .81981 .20643 L .82256 .20003 L p F P
0 g
s
.976 .922 .629 r
.82256 .20003 m .82222 .19539 L .81943 .20181 L p F P
0 g
s
.713 .568 0 r
.60923 .30347 m .60913 .30001 L .60919 .30273 L p F P
0 g
s
.737 .64 .079 r
.60923 .30347 m .60896 .30823 L .60928 .30445 L p F P
0 g
s
0 0 .085 r
.60896 .30823 m .60923 .30347 L .60937 .30898 L p F P
0 g
s
.713 .568 0 r
.60919 .30273 m .60925 .30549 L p .60923 .30347 L F P
0 g
s
.737 .64 .079 r
.60928 .30445 m .60944 .30254 L p .60923 .30347 L F P
0 g
s
.737 .64 .079 r
.60944 .30254 m .60966 .29779 L .60923 .30347 L p F P
0 g
s
.964 .913 .561 r
.61769 .25979 m .6167 .26065 L .61765 .25818 L closepath p F P
0 g
s
.14 .151 .609 r
.61169 .32871 m .60935 .32388 L .60821 .32812 L p F P
0 g
s
.14 .151 .609 r
.61047 .33373 m .61169 .32871 L p .60821 .32812 L F P
0 g
s
.14 .151 .609 r
.60821 .32812 m .60877 .33071 L .61047 .33373 L p F P
0 g
s
.817 .821 .852 r
.69387 .10597 m .69383 .10601 L .69089 .10251 L p F P
0 g
s
.847 .829 .829 r
.68578 .11409 m .69383 .10601 L .69089 .10251 L p F P
0 g
s
.82 .815 .845 r
.69192 .10161 m .69387 .10597 L .70399 .09715 L p F P
0 g
s
.817 .821 .852 r
.69089 .10251 m .69192 .10161 L .69387 .10597 L p F P
0 g
s
.971 .89 .689 r
.62643 .219 m .62753 .22347 L .63078 .21696 L p F P
0 g
s
.971 .89 .689 r
.63078 .21696 m .62955 .21252 L .62643 .219 L p F P
0 g
s
.835 .913 .889 r
.74369 .31088 m .74125 .30919 L .74421 .30669 L closepath p F P
0 g
s
.925 .951 .788 r
.79844 .25036 m .8014 .24638 L .79883 .24537 L p F P
0 g
s
.483 .622 .911 r
.79287 .08138 m .79418 .08567 L p .77969 .08065 L F P
0 g
s
.483 .622 .911 r
.77969 .08065 m .79272 .08112 L .79287 .08138 L p F P
0 g
s
.472 .636 .926 r
.77685 .07631 m .77969 .08065 L .79272 .08112 L p F P
0 g
s
.276 .478 .875 r
.79843 .09071 m .80365 .09274 L .80507 .09722 L p F P
0 g
s
.158 .386 .834 r
.80945 .0961 m .81076 .10063 L .80507 .09722 L p F P
0 g
s
.158 .386 .834 r
.80507 .09722 m .80365 .09274 L .80945 .0961 L p F P
0 g
s
.726 .78 .895 r
.73697 .08011 m .74583 .07553 L .74296 .07156 L p F P
0 g
s
.726 .78 .895 r
.74296 .07156 m .73512 .0757 L .73697 .08011 L p F P
0 g
s
.722 .78 .899 r
.73052 .0781 m .73512 .0757 L .73697 .08011 L p F P
0 g
s
.823 .816 .843 r
.70399 .09715 m .70598 .09538 L .70305 .09174 L p F P
0 g
s
.823 .816 .843 r
.70305 .09174 m .7018 .09287 L .70399 .09715 L p F P
0 g
s
.82 .815 .845 r
.70399 .09715 m .7018 .09287 L .69192 .10161 L p F P
0 g
s
.975 .916 .673 r
.6249 .23384 m .62242 .23396 L .62432 .22999 L closepath p F P
0 g
s
.793 .809 .865 r
.71624 .08759 m .70598 .09538 L .70305 .09174 L p F P
0 g
s
.847 .829 .829 r
.69089 .10251 m .68374 .10977 L .68578 .11409 L p F P
0 g
s
.842 .83 .835 r
.6788 .11467 m .68374 .10977 L .68578 .11409 L p F P
0 g
s
.842 .83 .835 r
.68578 .11409 m .68176 .11804 L .6788 .11467 L p F P
0 g
s
0 0 .477 r
.82335 .12573 m .82365 .12719 L .82145 .12254 L p F P
0 g
s
0 0 .477 r
.82116 .11927 m .82335 .12573 L p .82145 .12254 L F P
0 g
s
0 0 .477 r
.82145 .12254 m .8205 .11795 L .82116 .11927 L p F P
0 g
s
.072 .121 .608 r
.60877 .33071 m .61047 .33373 L .60991 .33545 L closepath p F P
0 g
s
.868 .832 .81 r
.67824 .12202 m .68176 .11804 L .6788 .11467 L p F P
0 g
s
.287 .489 .881 r
.80365 .09274 m .79843 .09071 L .79557 .08587 L p F P
0 g
s
.911 .743 .248 r
.82708 .15749 m .82779 .16209 L .82821 .1565 L p F P
0 g
s
.911 .743 .248 r
.82821 .1565 m .82752 .1519 L .82708 .15749 L p F P
0 g
s
.952 .882 .727 r
.63179 .20147 m .63305 .20592 L .63689 .19922 L p F P
0 g
s
.952 .882 .727 r
.63689 .19922 m .6355 .19481 L .63179 .20147 L p F P
0 g
s
.311 .372 .765 r
.61208 .3419 m .61366 .3429 L .61305 .34447 L closepath p F P
0 g
s
.485 .521 .819 r
.62311 .34551 m .61366 .3429 L .61305 .34447 L p F P
0 g
s
.485 .521 .819 r
.62222 .35038 m .62311 .34551 L p .61305 .34447 L F P
0 g
s
.001 .244 .751 r
.81515 .10466 m .81627 .10907 L .81199 .10516 L p F P
0 g
s
.001 .244 .751 r
.81506 .10445 m .81515 .10466 L p .81199 .10516 L F P
0 g
s
.001 .244 .751 r
.81199 .10516 m .81076 .10063 L .81506 .10445 L p F P
0 g
s
0 .079 .638 r
.82017 .11652 m .8205 .11795 L .81735 .11364 L p F P
0 g
s
0 .079 .638 r
.81807 .11142 m .82017 .11652 L p .81735 .11364 L F P
0 g
s
0 .079 .638 r
.81735 .11364 m .81627 .10907 L .81807 .11142 L p F P
0 g
s
.925 .951 .788 r
.79883 .24537 m .79864 .24563 L .79844 .25036 L p F P
0 g
s
.915 .946 .807 r
.79274 .25309 m .79263 .25778 L .79844 .25036 L p F P
0 g
s
.915 .946 .807 r
.79844 .25036 m .79864 .24563 L .79274 .25309 L p F P
0 g
s
.909 .819 .351 r
.61106 .28956 m .61054 .29197 L .61052 .29106 L closepath p F P
0 g
s
0 0 .354 r
.6101 .31899 m .60935 .32388 L .60829 .31866 L p F P
0 g
s
0 0 .354 r
.60829 .31866 m .60911 .31374 L .6101 .31899 L p F P
0 g
s
.885 .935 .845 r
.77917 .27592 m .77762 .27501 L .77934 .27317 L closepath p F P
0 g
s
.789 .882 .914 r
.7063 .33548 m .70452 .33669 L .70164 .33439 L p F P
0 g
s
.868 .832 .81 r
.6788 .11467 m .67613 .11773 L .67824 .12202 L p F P
0 g
s
.865 .832 .812 r
.66935 .12541 m .67131 .12973 L .67824 .12202 L p F P
0 g
s
.865 .832 .812 r
.67824 .12202 m .67613 .11773 L .66935 .12541 L p F P
0 g
s
.347 .37 .742 r
.60991 .33545 m .61208 .3419 L .61366 .3429 L p F P
0 g
s
.952 .943 .733 r
.80851 .22666 m .81263 .21979 L .81281 .22445 L p F P
0 g
s
.952 .943 .733 r
.80855 .22772 m .80851 .22666 L p .81281 .22445 L F P
0 g
s
.952 .943 .733 r
.81281 .22445 m .8105 .22826 L .80855 .22772 L p F P
0 g
s
.969 .932 .67 r
.81986 .20734 m .81938 .20729 L .81981 .20643 L closepath p F P
0 g
s
.909 .852 .774 r
.65777 .14652 m .65417 .15167 L .65605 .15599 L p F P
0 g
s
.908 .852 .776 r
.64918 .15874 m .65093 .1631 L .65605 .15599 L p F P
0 g
s
.908 .852 .776 r
.65605 .15599 m .65417 .15167 L .64918 .15874 L p F P
0 g
s
.792 .887 .914 r
.7063 .33548 m .71679 .32815 L .71394 .32597 L p F P
0 g
s
.792 .887 .914 r
.71394 .32597 m .70718 .33065 L .7063 .33548 L p F P
0 g
s
.789 .882 .914 r
.70164 .33439 m .70718 .33065 L .7063 .33548 L p F P
0 g
s
.797 .805 .859 r
.71624 .08759 m .7182 .08607 L .71529 .08231 L p F P
0 g
s
.797 .805 .859 r
.71529 .08231 m .71402 .0833 L .71624 .08759 L p F P
0 g
s
.793 .809 .865 r
.70305 .09174 m .71402 .0833 L .71624 .08759 L p F P
0 g
s
.347 .37 .742 r
.61519 .33782 m .61047 .33373 L .60991 .33545 L p F P
0 g
s
.347 .37 .742 r
.61366 .3429 m .61519 .33782 L p .60991 .33545 L F P
0 g
s
.75 .86 .93 r
.68934 .34223 m .67702 .34931 L .67407 .3467 L p F P
0 g
s
.763 .791 .876 r
.73052 .0781 m .7182 .08607 L .71529 .08231 L p F P
0 g
s
.93 .876 .762 r
.63759 .18379 m .64197 .17691 L .64354 .18129 L p F P
0 g
s
.93 .876 .762 r
.63817 .18554 m .63759 .18379 L p .64354 .18129 L F P
0 g
s
.93 .876 .762 r
.64354 .18129 m .63998 .18679 L .63817 .18554 L p F P
0 g
s
.973 .912 .576 r
.61493 .25979 m .61728 .25353 L .61765 .25818 L p F P
0 g
s
.973 .912 .576 r
.61507 .26184 m .61493 .25979 L p .61765 .25818 L F P
0 g
s
.973 .912 .576 r
.61765 .25818 m .6167 .26065 L .61507 .26184 L p F P
0 g
s
.952 .861 .444 r
.61202 .27652 m .61221 .2812 L .61392 .27513 L p F P
0 g
s
.952 .861 .444 r
.61392 .27513 m .61362 .27049 L .61202 .27652 L p F P
0 g
s
.987 .895 .626 r
.61891 .24271 m .61976 .24723 L .62236 .2409 L p F P
0 g
s
.987 .895 .626 r
.62236 .2409 m .6214 .23642 L .61891 .24271 L p F P
0 g
s
.864 .839 .818 r
.66677 .12829 m .66935 .12541 L .67131 .12973 L p F P
0 g
s
.864 .839 .818 r
.67131 .12973 m .66974 .13147 L .66677 .12829 L p F P
0 g
s
.973 .852 .453 r
.82548 .17377 m .82613 .17836 L .8275 .17245 L p F P
0 g
s
.973 .852 .453 r
.8275 .17245 m .82687 .16785 L .82548 .17377 L p F P
0 g
s
.888 .839 .791 r
.66528 .13715 m .66974 .13147 L .66677 .12829 L p F P
0 g
s
.908 .942 .817 r
.78695 .26016 m .79274 .25309 L .79263 .25778 L p F P
0 g
s
.908 .942 .817 r
.79263 .25778 m .78958 .26149 L .78695 .26016 L p F P
0 g
s
.87 .764 .259 r
.6096 .29525 m .60966 .29779 L .61054 .29197 L p F P
0 g
s
.87 .764 .259 r
.61054 .29197 m .61052 .29106 L .6096 .29525 L p F P
0 g
s
.97 .93 .672 r
.81691 .20699 m .81943 .20181 L .81981 .20643 L p F P
0 g
s
.97 .93 .672 r
.81981 .20643 m .81938 .20729 L .81691 .20699 L p F P
0 g
s
.947 .948 .742 r
.8105 .22826 m .80856 .23135 L .80855 .22772 L closepath p F P
0 g
s
.974 .896 .683 r
.62335 .22548 m .62432 .22999 L .62753 .22347 L p F P
0 g
s
.974 .896 .683 r
.62753 .22347 m .62643 .219 L .62335 .22548 L p F P
0 g
s
.847 .65 .11 r
.82674 .1473 m .82752 .1519 L .8274 .1465 L p F P
0 g
s
.847 .65 .11 r
.8274 .1465 m .82664 .1419 L .82674 .1473 L p F P
0 g
s
.979 .911 .59 r
.82179 .19076 m .82222 .19539 L .8246 .18912 L p F P
0 g
s
.979 .911 .59 r
.8246 .18912 m .82421 .18447 L .82179 .19076 L p F P
0 g
s
.675 .748 .906 r
.74583 .07553 m .7584 .0707 L .76126 .0748 L p F P
0 g
s
.678 .75 .905 r
.7584 .0707 m .74583 .07553 L .74296 .07156 L p F P
0 g
s
.967 .936 .677 r
.81642 .21304 m .81938 .20729 L .81691 .20699 L p F P
0 g
s
.606 .707 .916 r
.76126 .0748 m .774 .07202 L .77685 .07631 L p F P
0 g
s
.611 .712 .917 r
.774 .07202 m .76126 .0748 L .7584 .0707 L p F P
0 g
s
.77 .87 .921 r
.69019 .34294 m .68934 .34223 L .69046 .34153 L closepath p F P
0 g
s
.365 .453 .818 r
.6233 .34344 m .62311 .34551 L .61366 .3429 L p F P
0 g
s
.365 .453 .818 r
.62153 .34036 m .6233 .34344 L p .61366 .3429 L F P
0 g
s
.365 .453 .818 r
.61366 .3429 m .61519 .33782 L .62153 .34036 L p F P
0 g
s
.805 .894 .907 r
.72055 .32538 m .71679 .32815 L .71394 .32597 L p F P
0 g
s
.98 .883 .523 r
.82636 .18033 m .82538 .18084 L .82613 .17836 L closepath p F P
0 g
s
.902 .945 .825 r
.78626 .26539 m .78958 .26149 L .78695 .26016 L p F P
0 g
s
.986 .891 .558 r
.6167 .26065 m .61546 .26439 L .61507 .26184 L closepath p F P
0 g
s
.954 .893 .73 r
.62818 .20794 m .63179 .20147 L .63305 .20592 L p F P
0 g
s
.954 .893 .73 r
.63305 .20592 m .63117 .20925 L .62818 .20794 L p F P
0 g
s
.908 .861 .782 r
.64586 .1634 m .64918 .15874 L .65093 .1631 L p F P
0 g
s
.908 .861 .782 r
.65093 .1631 m .64885 .16598 L .64586 .1634 L p F P
0 g
s
.934 .945 .774 r
.80369 .23376 m .80376 .23843 L .80856 .23135 L p F P
0 g
s
.934 .945 .774 r
.80797 .22748 m .80369 .23376 L p .80856 .23135 L F P
0 g
s
.934 .945 .774 r
.80856 .23135 m .80855 .22772 L .80797 .22748 L p F P
0 g
s
.943 .865 .733 r
.63998 .18679 m .6392 .18815 L .63817 .18554 L closepath p F P
0 g
s
.809 .899 .906 r
.72055 .32538 m .72903 .31899 L .72621 .31693 L p F P
0 g
s
.809 .899 .906 r
.72621 .31693 m .72135 .32056 L .72055 .32538 L p F P
0 g
s
.805 .894 .907 r
.71394 .32597 m .72135 .32056 L .72055 .32538 L p F P
0 g
s
0 0 .085 r
.60937 .30898 m .60911 .31374 L .60896 .30823 L p F P
0 g
s
.888 .839 .791 r
.66677 .12829 m .66321 .13287 L .66528 .13715 L p F P
0 g
s
.886 .839 .794 r
.65743 .14021 m .65937 .14453 L .66528 .13715 L p F P
0 g
s
.886 .839 .794 r
.66528 .13715 m .66321 .13287 L .65743 .14021 L p F P
0 g
s
.725 .822 .925 r
.66868 .34944 m .66172 .35293 L .65873 .34995 L p F P
0 g
s
.688 .812 .941 r
.64635 .355 m .65873 .34995 L .66172 .35293 L p F P
0 g
s
.811 .743 .22 r
.60976 .29305 m .6096 .29525 L .61052 .29106 L p F P
0 g
s
.811 .743 .22 r
.61052 .29106 m .61079 .28718 L .60976 .29305 L p F P
0 g
s
.902 .945 .825 r
.78695 .26016 m .78654 .26065 L .78626 .26539 L p F P
0 g
s
.892 .939 .837 r
.77951 .26847 m .77934 .27317 L .78626 .26539 L p F P
0 g
s
.892 .939 .837 r
.78626 .26539 m .78654 .26065 L .77951 .26847 L p F P
0 g
s
.622 .757 .943 r
.63089 .35475 m .64331 .35154 L .64635 .355 L p F P
0 g
s
.595 .734 .941 r
.64331 .35154 m .63089 .35475 L .62779 .35037 L p F P
0 g
s
.42 .582 .907 r
.79418 .08567 m .79287 .08138 L .79557 .08587 L closepath p F P
0 g
s
.17 .257 .712 r
.61587 .33298 m .61519 .33782 L .61047 .33373 L p F P
0 g
s
.17 .257 .712 r
.61047 .33373 m .61169 .32871 L .61587 .33298 L p F P
0 g
s
.927 .855 .751 r
.64628 .17005 m .64885 .16598 L .64586 .1634 L p F P
0 g
s
.948 .865 .723 r
.63388 .19045 m .6355 .19481 L .6392 .18815 L p F P
0 g
s
.948 .865 .723 r
.63699 .18475 m .63388 .19045 L p .6392 .18815 L F P
0 g
s
.948 .865 .723 r
.6392 .18815 m .63817 .18554 L .63699 .18475 L p F P
0 g
s
.746 .52 0 r
.82607 .13888 m .82664 .1419 L .82591 .13672 L p F P
0 g
s
.746 .52 0 r
.82591 .13672 m .82524 .13306 L .82607 .13888 L p F P
0 g
s
.725 .779 .896 r
.73512 .0757 m .73052 .0781 L .72763 .07423 L p F P
0 g
s
.763 .791 .876 r
.71529 .08231 m .72763 .07423 L .73052 .0781 L p F P
0 g
s
.849 .92 .879 r
.75419 .2992 m .75343 .29869 L .75433 .29789 L closepath p F P
0 g
s
.966 .878 .695 r
.62955 .21252 m .63117 .20925 L .62818 .20794 L p F P
0 g
s
.511 .632 .906 r
.62467 .34565 m .62311 .34551 L .62222 .35038 L p F P
0 g
s
.511 .632 .906 r
.62222 .35038 m .62779 .35037 L .62467 .34565 L p F P
0 g
s
.956 .811 .371 r
.82615 .16326 m .82687 .16785 L .82779 .16209 L p F P
0 g
s
.956 .811 .371 r
.82779 .16209 m .82708 .15749 L .82615 .16326 L p F P
0 g
s
.82 .903 .898 r
.73305 .31583 m .72903 .31899 L .72621 .31693 L p F P
0 g
s
.676 .8 .942 r
.65873 .34995 m .64635 .355 L .64331 .35154 L p F P
0 g
s
.77 .864 .919 r
.69046 .34153 m .68934 .34223 L .68641 .3397 L p F P
0 g
s
.75 .86 .93 r
.67407 .3467 m .68641 .3397 L .68934 .34223 L p F P
0 g
s
.885 .932 .845 r
.77494 .27341 m .77951 .26847 L .77934 .27317 L p F P
0 g
s
.885 .932 .845 r
.77934 .27317 m .77762 .27501 L .77494 .27341 L p F P
0 g
s
.519 .662 .926 r
.77685 .07631 m .77685 .07631 L .77685 .07631 L closepath p F P
0 g
s
.472 .636 .926 r
.78987 .07651 m .77685 .07631 L .77685 .07631 L p F P
0 g
s
.472 .636 .926 r
.79272 .08112 m .78987 .07651 L p .77685 .07631 L F P
0 g
s
.525 .667 .927 r
.77685 .07631 m .77685 .07631 L .774 .07202 L p F P
0 g
s
.525 .667 .927 r
.774 .07202 m .77482 .07197 L .77685 .07631 L p F P
0 g
s
.49 .634 .918 r
.78701 .07195 m .77482 .07197 L .77685 .07631 L p F P
0 g
s
.49 .634 .918 r
.77685 .07631 m .78987 .07651 L .78701 .07195 L p F P
0 g
s
.771 .868 .92 r
.69046 .34153 m .70164 .33439 L .69875 .33203 L p F P
0 g
s
.771 .868 .92 r
.69875 .33203 m .69127 .33672 L .69046 .34153 L p F P
0 g
s
.77 .864 .919 r
.68641 .3397 m .69127 .33672 L .69046 .34153 L p F P
0 g
s
.825 .908 .896 r
.73305 .31583 m .74125 .30919 L .73846 .30721 L p F P
0 g
s
.825 .908 .896 r
.73846 .30721 m .73371 .31104 L .73305 .31583 L p F P
0 g
s
.82 .903 .898 r
.72621 .31693 m .73371 .31104 L .73305 .31583 L p F P
0 g
s
.287 .489 .881 r
.79557 .08587 m .80215 .08826 L .80365 .09274 L p F P
0 g
s
.271 .492 .887 r
.79287 .08138 m .79557 .08587 L .80215 .08826 L p F P
0 g
s
.878 .934 .853 r
.77165 .2812 m .77762 .27501 L .77494 .27341 L p F P
0 g
s
.967 .936 .677 r
.81691 .20699 m .81621 .20837 L .81642 .21304 L p F P
0 g
s
.959 .939 .714 r
.81237 .21515 m .81263 .21979 L .81642 .21304 L p F P
0 g
s
.959 .939 .714 r
.81642 .21304 m .81621 .20837 L .81237 .21515 L p F P
0 g
s
.983 .878 .521 r
.61297 .26594 m .61362 .27049 L .61546 .26439 L p F P
0 g
s
.983 .878 .521 r
.61379 .26312 m .61297 .26594 L p .61546 .26439 L F P
0 g
s
.983 .878 .521 r
.61546 .26439 m .61507 .26184 L .61379 .26312 L p F P
0 g
s
.988 .897 .606 r
.61655 .24897 m .61728 .25353 L .61976 .24723 L p F P
0 g
s
.988 .897 .606 r
.61976 .24723 m .61891 .24271 L .61655 .24897 L p F P
0 g
s
.886 .846 .799 r
.65479 .14353 m .65743 .14021 L .65937 .14453 L p F P
0 g
s
.886 .846 .799 r
.65937 .14453 m .65777 .14652 L .65479 .14353 L p F P
0 g
s
.818 .817 .848 r
.69192 .10161 m .69089 .10251 L .68794 .09893 L p F P
0 g
s
.847 .823 .825 r
.68374 .10977 m .69089 .10251 L .68794 .09893 L p F P
0 g
s
.821 .811 .842 r
.68978 .0973 m .69192 .10161 L .7018 .09287 L p F P
0 g
s
.818 .817 .848 r
.68794 .09893 m .68978 .0973 L .69192 .10161 L p F P
0 g
s
.975 .908 .679 r
.62033 .23195 m .62335 .22548 L .62432 .22999 L p F P
0 g
s
.975 .908 .679 r
.6207 .23386 m .62033 .23195 L p .62432 .22999 L F P
0 g
s
.975 .908 .679 r
.62432 .22999 m .62242 .23396 L .6207 .23386 L p F P
0 g
s
.927 .855 .751 r
.64586 .1634 m .64439 .16575 L .64628 .17005 L p F P
0 g
s
.928 .855 .749 r
.64019 .17257 m .64197 .17691 L .64628 .17005 L p F P
0 g
s
.928 .855 .749 r
.64628 .17005 m .64439 .16575 L .64019 .17257 L p F P
0 g
s
0 0 .259 r
.82365 .12719 m .82335 .12573 L .82449 .13005 L closepath p F P
0 g
s
.931 .943 .78 r
.79852 .24098 m .80369 .23376 L .80376 .23843 L p F P
0 g
s
.931 .943 .78 r
.79864 .24529 m .79852 .24098 L p .80376 .23843 L F P
0 g
s
.931 .943 .78 r
.80376 .23843 m .79883 .24537 L .79864 .24529 L p F P
0 g
s
.878 .934 .853 r
.77494 .27341 m .77199 .27646 L .77165 .2812 L p F P
0 g
s
.872 .93 .859 r
.76381 .28466 m .77199 .27646 L .77165 .2812 L p F P
0 g
s
.872 .93 .859 r
.76373 .2862 m .76381 .28466 L p .77165 .2812 L F P
0 g
s
.872 .93 .859 r
.77165 .2812 m .76556 .28732 L .76373 .2862 L p F P
0 g
s
.923 .827 .37 r
.61071 .28248 m .61079 .28718 L .61221 .2812 L p F P
0 g
s
.923 .827 .37 r
.61221 .2812 m .61202 .27652 L .61071 .28248 L p F P
0 g
s
.823 .812 .84 r
.7018 .09287 m .70305 .09174 L .70012 .08803 L p F P
0 g
s
.823 .812 .84 r
.70012 .08803 m .69948 .08861 L .7018 .09287 L p F P
0 g
s
.821 .811 .842 r
.7018 .09287 m .69948 .08861 L .68978 .0973 L p F P
0 g
s
.907 .844 .771 r
.65417 .15167 m .65777 .14652 L .65479 .14353 L p F P
0 g
s
.794 .806 .862 r
.71402 .0833 m .70305 .09174 L .70012 .08803 L p F P
0 g
s
.835 .91 .888 r
.74421 .30669 m .74125 .30919 L .73846 .30721 L p F P
0 g
s
.729 .779 .893 r
.73512 .0757 m .74296 .07156 L .74007 .06757 L p F P
0 g
s
.729 .779 .893 r
.74007 .06757 m .73307 .07134 L .73512 .0757 L p F P
0 g
s
.725 .779 .896 r
.72763 .07423 m .73307 .07134 L .73512 .0757 L p F P
0 g
s
0 0 .533 r
.61222 .3239 m .61169 .32871 L .60935 .32388 L p F P
0 g
s
0 0 .533 r
.60935 .32388 m .6101 .31899 L .61222 .3239 L p F P
0 g
s
.982 .883 .527 r
.82366 .17986 m .82548 .17377 L .82613 .17836 L p F P
0 g
s
.982 .883 .527 r
.82391 .18154 m .82366 .17986 L p .82613 .17836 L F P
0 g
s
.982 .883 .527 r
.82613 .17836 m .82538 .18084 L .82391 .18154 L p F P
0 g
s
.162 .393 .839 r
.80805 .09159 m .80945 .0961 L .80365 .09274 L p F P
0 g
s
.162 .393 .839 r
.80365 .09274 m .80215 .08826 L .80805 .09159 L p F P
0 g
s
.841 .915 .885 r
.74421 .30669 m .75343 .29869 L .75068 .29678 L p F P
0 g
s
.841 .915 .885 r
.75068 .29678 m .74472 .30194 L .74421 .30669 L p F P
0 g
s
.835 .91 .888 r
.73846 .30721 m .74472 .30194 L .74421 .30669 L p F P
0 g
s
.966 .878 .695 r
.62818 .20794 m .62808 .20815 L .62955 .21252 L p F P
0 g
s
.97 .877 .686 r
.62506 .2146 m .62643 .219 L .62955 .21252 L p F P
0 g
s
.97 .877 .686 r
.62955 .21252 m .62808 .20815 L .62506 .2146 L p F P
0 g
s
.977 .92 .637 r
.81897 .19719 m .81943 .20181 L .82222 .19539 L p F P
0 g
s
.977 .92 .637 r
.82222 .19539 m .82179 .19076 L .81897 .19719 L p F P
0 g
s
.847 .823 .825 r
.68794 .09893 m .68154 .10549 L .68374 .10977 L p F P
0 g
s
.842 .825 .831 r
.67583 .11121 m .68154 .10549 L .68374 .10977 L p F P
0 g
s
.842 .825 .831 r
.68374 .10977 m .6788 .11467 L .67583 .11121 L p F P
0 g
s
.72 .832 .935 r
.66868 .34944 m .67407 .3467 L .67111 .344 L p F P
0 g
s
.72 .832 .935 r
.67111 .344 m .67036 .34436 L .66868 .34944 L p F P
0 g
s
.725 .822 .925 r
.65873 .34995 m .67036 .34436 L .66868 .34944 L p F P
0 g
s
.864 .931 .867 r
.76556 .28732 m .76339 .28942 L .76373 .2862 L closepath p F P
0 g
s
.851 .921 .878 r
.75468 .29317 m .75433 .29789 L .76339 .28942 L p F P
0 g
s
.851 .921 .878 r
.76284 .2856 m .75468 .29317 L p .76339 .28942 L F P
0 g
s
.851 .921 .878 r
.76339 .28942 m .76373 .2862 L .76284 .2856 L p F P
0 g
s
.849 .915 .878 r
.75433 .29789 m .75343 .29869 L .75068 .29678 L p F P
0 g
s
.849 .915 .878 r
.75068 .29678 m .75468 .29317 L .75433 .29789 L p F P
0 g
s
.867 .827 .806 r
.67613 .11773 m .6788 .11467 L .67583 .11121 L p F P
0 g
s
.812 .688 .145 r
.60913 .30001 m .60923 .30347 L .60966 .29779 L p F P
0 g
s
.812 .688 .145 r
.60966 .29779 m .6096 .29525 L .60913 .30001 L p F P
0 g
s
0 0 .467 r
.8205 .11795 m .82017 .11652 L .82116 .11927 L closepath p F P
0 g
s
.004 .244 .752 r
.81211 .09834 m .80945 .0961 L .81076 .10063 L p F P
0 g
s
.004 .244 .752 r
.81076 .10063 m .81506 .10445 L .81211 .09834 L p F P
0 g
s
.951 .87 .722 r
.63028 .19709 m .63179 .20147 L .6355 .19481 L p F P
0 g
s
.951 .87 .722 r
.6355 .19481 m .63388 .19045 L .63028 .19709 L p F P
0 g
s
.867 .827 .806 r
.67583 .11121 m .67387 .11348 L .67613 .11773 L p F P
0 g
s
.865 .826 .808 r
.6672 .12113 m .66935 .12541 L .67613 .11773 L p F P
0 g
s
.865 .826 .808 r
.67613 .11773 m .67387 .11348 L .6672 .12113 L p F P
0 g
s
.923 .75 .265 r
.8263 .1529 m .82708 .15749 L .82752 .1519 L p F P
0 g
s
.923 .75 .265 r
.82752 .1519 m .82674 .1473 L .8263 .1529 L p F P
0 g
s
0 .074 .634 r
.81627 .10907 m .81515 .10466 L .81807 .11142 L closepath p F P
0 g
s
.794 .806 .862 r
.70012 .08803 m .71167 .07904 L .71402 .0833 L p F P
0 g
s
.798 .803 .856 r
.71402 .0833 m .71529 .08231 L .71237 .07849 L p F P
0 g
s
.798 .803 .856 r
.71237 .07849 m .71167 .07904 L .71402 .0833 L p F P
0 g
s
.765 .79 .874 r
.72763 .07423 m .71529 .08231 L .71237 .07849 L p F P
0 g
s
.907 .844 .771 r
.65479 .14353 m .65212 .14739 L .65417 .15167 L p F P
0 g
s
.907 .844 .771 r
.64722 .15444 m .64918 .15874 L .65417 .15167 L p F P
0 g
s
.907 .844 .771 r
.65417 .15167 m .65212 .14739 L .64722 .15444 L p F P
0 g
s
.979 .89 .535 r
.82538 .18084 m .82421 .18447 L .82391 .18154 L closepath p F P
0 g
s
.983 .887 .65 r
.62242 .23396 m .6214 .23642 L .6207 .23386 L closepath p F P
0 g
s
.787 .878 .913 r
.70718 .33065 m .70164 .33439 L .69875 .33203 L p F P
0 g
s
.925 .946 .789 r
.79883 .24537 m .79864 .24563 L .79864 .24529 L closepath p F P
0 g
s
.911 .94 .812 r
.79276 .24841 m .79274 .25309 L .79864 .24563 L p F P
0 g
s
.911 .94 .812 r
.79622 .24402 m .79276 .24841 L p .79864 .24563 L F P
0 g
s
.911 .94 .812 r
.79864 .24563 m .79864 .24529 L .79622 .24402 L p F P
0 g
s
0 0 .378 r
.82116 .11927 m .82257 .12264 L .82335 .12573 L closepath p F P
0 g
s
.702 .425 0 r
.82389 .12761 m .82257 .12264 L .82335 .12573 L p F P
0 g
s
.702 .425 0 r
.82335 .12573 m .82449 .13005 L .82503 .13213 L p F P
0 g
s
.702 .425 0 r
.82503 .13213 m .82389 .12761 L p .82335 .12573 L F P
0 g
s
.746 .855 .93 r
.68641 .3397 m .67407 .3467 L .67111 .344 L p F P
0 g
s
.935 .877 .754 r
.63817 .18554 m .63699 .18475 L .63759 .18379 L closepath p F P
0 g
s
.952 .937 .736 r
.8082 .22204 m .80851 .22666 L .81263 .21979 L p F P
0 g
s
.952 .937 .736 r
.81263 .21979 m .81237 .21515 L .8082 .22204 L p F P
0 g
s
.929 .86 .752 r
.63592 .17942 m .63759 .18379 L .64197 .17691 L p F P
0 g
s
.929 .86 .752 r
.64197 .17691 m .64019 .17257 L .63592 .17942 L p F P
0 g
s
.864 .832 .814 r
.66378 .12498 m .6672 .12113 L .66935 .12541 L p F P
0 g
s
.864 .832 .814 r
.66935 .12541 m .66677 .12829 L .66378 .12498 L p F P
0 g
s
0 0 .35 r
.82017 .11652 m .82116 .11927 L .82257 .12264 L p F P
0 g
s
.921 .935 .798 r
.79864 .24529 m .79622 .24402 L .79852 .24098 L closepath p F P
0 g
s
0 0 .275 r
.61027 .31427 m .6101 .31899 L .60911 .31374 L p F P
0 g
s
0 0 .275 r
.60911 .31374 m .60937 .30898 L .61027 .31427 L p F P
0 g
s
.678 .75 .905 r
.74296 .07156 m .75553 .0666 L .7584 .0707 L p F P
0 g
s
.611 .712 .917 r
.7584 .0707 m .77115 .06775 L .774 .07202 L p F P
0 g
s
.616 .716 .917 r
.77115 .06775 m .7584 .0707 L .75553 .0666 L p F P
0 g
s
.681 .752 .905 r
.75553 .0666 m .74296 .07156 L .74007 .06757 L p F P
0 g
s
.886 .833 .788 r
.66321 .13287 m .66677 .12829 L .66378 .12498 L p F P
0 g
s
0 0 .538 r
.81807 .11142 m .8193 .11342 L .82017 .11652 L closepath p F P
0 g
s
0 0 .35 r
.82133 .11814 m .8193 .11342 L .82017 .11652 L p F P
0 g
s
0 0 .35 r
.82257 .12264 m .82133 .11814 L p .82017 .11652 L F P
0 g
s
0 0 .198 r
.82449 .13005 m .82503 .13213 L .82524 .13306 L closepath p F P
0 g
s
.789 .885 .915 r
.70718 .33065 m .71394 .32597 L .71107 .32374 L p F P
0 g
s
.789 .885 .915 r
.71107 .32374 m .70805 .3258 L .70718 .33065 L p F P
0 g
s
.787 .878 .913 r
.69875 .33203 m .70805 .3258 L .70718 .33065 L p F P
0 g
s
.988 .884 .629 r
.61778 .23827 m .61891 .24271 L .6214 .23642 L p F P
0 g
s
.988 .884 .629 r
.61945 .23391 m .61778 .23827 L p .6214 .23642 L F P
0 g
s
.988 .884 .629 r
.6214 .23642 m .6207 .23386 L .61945 .23391 L p F P
0 g
s
.987 .896 .581 r
.61433 .2552 m .61493 .25979 L .61728 .25353 L p F P
0 g
s
.987 .896 .581 r
.61728 .25353 m .61655 .24897 L .61433 .2552 L p F P
0 g
s
.979 .854 .465 r
.82475 .1692 m .82548 .17377 L .82687 .16785 L p F P
0 g
s
.979 .854 .465 r
.82687 .16785 m .82615 .16326 L .82475 .1692 L p F P
0 g
s
.595 .734 .941 r
.62779 .35037 m .64025 .34789 L .64331 .35154 L p F P
0 g
s
.561 .707 .939 r
.64025 .34789 m .62779 .35037 L .62467 .34565 L p F P
0 g
s
.942 .939 .759 r
.80855 .22772 m .80797 .22748 L .80851 .22666 L closepath p F P
0 g
s
.975 .859 .468 r
.61146 .27195 m .61202 .27652 L .61362 .27049 L p F P
0 g
s
.975 .859 .468 r
.61362 .27049 m .61297 .26594 L .61146 .27195 L p F P
0 g
s
.97 .897 .534 r
.61507 .26184 m .61379 .26312 L .61493 .25979 L closepath p F P
0 g
s
.864 .66 .128 r
.82602 .14343 m .82674 .1473 L .82664 .1419 L p F P
0 g
s
.864 .66 .128 r
.82664 .1419 m .82607 .13888 L .82602 .14343 L p F P
0 g
s
.973 .882 .68 r
.6221 .22104 m .62335 .22548 L .62643 .219 L p F P
0 g
s
.973 .882 .68 r
.62643 .219 m .62506 .2146 L .6221 .22104 L p F P
0 g
s
.972 .926 .671 r
.81578 .20375 m .81897 .19719 L .81943 .20181 L p F P
0 g
s
.972 .926 .671 r
.81611 .20687 m .81578 .20375 L p .81943 .20181 L F P
0 g
s
.972 .926 .671 r
.81943 .20181 m .81691 .20699 L .81611 .20687 L p F P
0 g
s
.908 .937 .816 r
.78652 .25599 m .79276 .24841 L .79274 .25309 L p F P
0 g
s
.908 .937 .816 r
.78656 .25996 m .78652 .25599 L p .79274 .25309 L F P
0 g
s
.908 .937 .816 r
.79274 .25309 m .78695 .26016 L .78656 .25996 L p F P
0 g
s
.981 .911 .607 r
.82127 .18614 m .82179 .19076 L .82421 .18447 L p F P
0 g
s
.981 .911 .607 r
.82302 .18162 m .82127 .18614 L p .82421 .18447 L F P
0 g
s
.981 .911 .607 r
.82421 .18447 m .82391 .18154 L .82302 .18162 L p F P
0 g
s
.791 .55 0 r
.82572 .13732 m .82607 .13888 L .82524 .13306 L p F P
0 g
s
.791 .55 0 r
.82524 .13306 m .82503 .13213 L .82572 .13732 L p F P
0 g
s
.906 .852 .778 r
.64285 .16065 m .64722 .15444 L .64918 .15874 L p F P
0 g
s
.906 .852 .778 r
.64918 .15874 m .64586 .1634 L .64285 .16065 L p F P
0 g
s
.873 .771 .269 r
.60976 .28833 m .60976 .29305 L .61079 .28718 L p F P
0 g
s
.873 .771 .269 r
.61079 .28718 m .61071 .28248 L .60976 .28833 L p F P
0 g
s
.952 .883 .728 r
.62667 .20373 m .63028 .19709 L .63179 .20147 L p F P
0 g
s
.952 .883 .728 r
.62796 .20783 m .62667 .20373 L p .63179 .20147 L F P
0 g
s
.952 .883 .728 r
.63179 .20147 m .62818 .20794 L .62796 .20783 L p F P
0 g
s
.885 .832 .789 r
.65529 .13594 m .65743 .14021 L .66321 .13287 L p F P
0 g
s
.885 .832 .789 r
.66321 .13287 m .66097 .12862 L .65529 .13594 L p F P
0 g
s
.886 .833 .788 r
.66378 .12498 m .66097 .12862 L .66321 .13287 L p F P
0 g
s
.271 .492 .887 r
.80056 .0838 m .79278 .08114 L .79287 .08138 L p F P
0 g
s
.271 .492 .887 r
.80215 .08826 m .80056 .0838 L p .79287 .08138 L F P
0 g
s
.358 .55 .905 r
.79272 .08112 m .79278 .08114 L .79287 .08138 L closepath p F P
0 g
s
.717 .813 .924 r
.67036 .34436 m .65873 .34995 L .65572 .34684 L p F P
0 g
s
.676 .8 .942 r
.64331 .35154 m .65572 .34684 L .65873 .34995 L p F P
0 g
s
.803 .89 .906 r
.72135 .32056 m .71394 .32597 L .71107 .32374 L p F P
0 g
s
.727 .779 .894 r
.73307 .07134 m .72763 .07423 L .72472 .07032 L p F P
0 g
s
.765 .79 .874 r
.71237 .07849 m .72472 .07032 L .72763 .07423 L p F P
0 g
s
.365 .559 .909 r
.79278 .08114 m .79272 .08112 L .78987 .07651 L p F P
0 g
s
.365 .559 .909 r
.78987 .07651 m .79095 .07674 L .79278 .08114 L p F P
0 g
s
.293 .508 .893 r
.79888 .07934 m .80056 .0838 L .79278 .08114 L p F P
0 g
s
.293 .508 .893 r
.79278 .08114 m .79095 .07674 L .79888 .07934 L p F P
0 g
s
0 0 .52 r
.81515 .10466 m .81807 .11142 L .8193 .11342 L p F P
0 g
s
.791 .678 .13 r
.60929 .29403 m .60922 .29877 L .60976 .29305 L p F P
0 g
s
0 0 .054 r
.60922 .29877 m .60929 .29403 L .60935 .29643 L p F P
0 g
s
.728 .644 .085 r
.60918 .29943 m .6096 .29525 L p .60922 .29877 L F P
0 g
s
0 0 .054 r
.60935 .29643 m .60944 .29956 L p .60922 .29877 L F P
0 g
s
.728 .644 .085 r
.60922 .29877 m .60913 .30001 L .60918 .29943 L p F P
0 g
s
.728 .644 .085 r
.6096 .29525 m .60976 .29305 L .60922 .29877 L p F P
0 g
s
.53 .672 .928 r
.77482 .07197 m .774 .07202 L .77115 .06775 L p F P
0 g
s
.942 .935 .76 r
.80539 .22635 m .8082 .22204 L .80851 .22666 L p F P
0 g
s
.942 .935 .76 r
.80851 .22666 m .80797 .22748 L .80539 .22635 L p F P
0 g
s
.931 .868 .754 r
.63398 .18256 m .63592 .17942 L .63759 .18379 L p F P
0 g
s
.931 .868 .754 r
.63759 .18379 m .63699 .18475 L .63398 .18256 L p F P
0 g
s
.661 .787 .942 r
.65572 .34684 m .64331 .35154 L .64025 .34789 L p F P
0 g
s
.938 .94 .767 r
.80369 .23376 m .80797 .22748 L .80539 .22635 L p F P
0 g
s
.809 .559 0 r
.82459 .1328 m .82572 .13732 L .82503 .13213 L p F P
0 g
s
.809 .559 0 r
.82503 .13213 m .82389 .12761 L .82459 .1328 L p F P
0 g
s
.902 .94 .825 r
.78695 .26016 m .78654 .26065 L .78656 .25996 L closepath p F P
0 g
s
.947 .859 .721 r
.63388 .19045 m .63699 .18475 L .63398 .18256 L p F P
0 g
s
.322 .466 .849 r
.61836 .33437 m .61587 .33298 L .61519 .33782 L p F P
0 g
s
.322 .466 .849 r
.61519 .33782 m .62153 .34036 L .61836 .33437 L p F P
0 g
s
.888 .932 .842 r
.7796 .26379 m .77951 .26847 L .78654 .26065 L p F P
0 g
s
.888 .932 .842 r
.78429 .25856 m .7796 .26379 L p .78654 .26065 L F P
0 g
s
.888 .932 .842 r
.78654 .26065 m .78656 .25996 L .78429 .25856 L p F P
0 g
s
.924 .846 .748 r
.64439 .16575 m .64586 .1634 L .64285 .16065 L p F P
0 g
s
.713 .568 0 r
.60925 .30549 m .60937 .30898 L .60923 .30347 L p F P
0 g
s
.53 .672 .928 r
.77115 .06775 m .77272 .06764 L .77482 .07197 L p F P
0 g
s
.497 .642 .92 r
.78415 .06745 m .77272 .06764 L .77482 .07197 L p F P
0 g
s
.497 .642 .92 r
.77482 .07197 m .78701 .07195 L .78415 .06745 L p F P
0 g
s
.807 .897 .906 r
.72135 .32056 m .72621 .31693 L .72338 .3148 L p F P
0 g
s
.807 .897 .906 r
.72338 .3148 m .72213 .31573 L .72135 .32056 L p F P
0 g
s
.803 .89 .906 r
.71107 .32374 m .72213 .31573 L .72135 .32056 L p F P
0 g
s
.863 .92 .866 r
.76373 .2862 m .76284 .2856 L .76381 .28466 L closepath p F P
0 g
s
.964 .815 .385 r
.82534 .15868 m .82615 .16326 L .82708 .15749 L p F P
0 g
s
.964 .815 .385 r
.82708 .15749 m .8263 .1529 L .82534 .15868 L p F P
0 g
s
.766 .858 .918 r
.69127 .33672 m .68641 .3397 L .68348 .3371 L p F P
0 g
s
.746 .855 .93 r
.67111 .344 m .68348 .3371 L .68641 .3397 L p F P
0 g
s
.818 .813 .845 r
.68978 .0973 m .68794 .09893 L .68498 .09526 L p F P
0 g
s
.846 .818 .822 r
.68154 .10549 m .68794 .09893 L .68498 .09526 L p F P
0 g
s
.885 .839 .795 r
.65178 .1404 m .65529 .13594 L .65743 .14021 L p F P
0 g
s
.885 .839 .795 r
.65743 .14021 m .65479 .14353 L .65178 .1404 L p F P
0 g
s
.968 .932 .681 r
.81691 .20699 m .81621 .20837 L .81611 .20687 L closepath p F P
0 g
s
.821 .808 .839 r
.68748 .09304 m .68978 .0973 L .69948 .08861 L p F P
0 g
s
.818 .813 .845 r
.68498 .09526 m .68748 .09304 L .68978 .0973 L p F P
0 g
s
.058 .185 .683 r
.61599 .3295 m .61587 .33298 L .61169 .32871 L p F P
0 g
s
.058 .185 .683 r
.61516 .32748 m .61599 .3295 L p .61169 .32871 L F P
0 g
s
.058 .185 .683 r
.61169 .32871 m .61222 .3239 L .61516 .32748 L p F P
0 g
s
.819 .899 .898 r
.73371 .31104 m .72621 .31693 L .72338 .3148 L p F P
0 g
s
.823 .809 .837 r
.69948 .08861 m .70012 .08803 L .69717 .08425 L p F P
0 g
s
.823 .809 .837 r
.69717 .08425 m .69702 .08439 L .69948 .08861 L p F P
0 g
s
.821 .808 .839 r
.69948 .08861 m .69702 .08439 L .68748 .09304 L p F P
0 g
s
.795 .804 .859 r
.71167 .07904 m .70012 .08803 L .69717 .08425 L p F P
0 g
s
.924 .846 .748 r
.64285 .16065 m .64232 .1615 L .64439 .16575 L p F P
0 g
s
.926 .846 .745 r
.6382 .16829 m .64019 .17257 L .64439 .16575 L p F P
0 g
s
.926 .846 .745 r
.64439 .16575 m .64232 .1615 L .6382 .16829 L p F P
0 g
s
.731 .778 .89 r
.73307 .07134 m .74007 .06757 L .73718 .06356 L p F P
0 g
s
.731 .778 .89 r
.73718 .06356 m .73084 .06702 L .73307 .07134 L p F P
0 g
s
.727 .779 .894 r
.72472 .07032 m .73084 .06702 L .73307 .07134 L p F P
0 g
s
.898 .929 .829 r
.78656 .25996 m .78429 .25856 L .78652 .25599 L closepath p F P
0 g
s
.885 .929 .844 r
.77225 .27173 m .7796 .26379 L .77951 .26847 L p F P
0 g
s
.885 .929 .844 r
.77225 .27175 m .77225 .27173 L p .77951 .26847 L F P
0 g
s
.885 .929 .844 r
.77951 .26847 m .77494 .27341 L .77225 .27175 L p F P
0 g
s
.991 .883 .609 r
.61551 .2445 m .61655 .24897 L .61891 .24271 L p F P
0 g
s
.991 .883 .609 r
.61891 .24271 m .61778 .23827 L .61551 .2445 L p F P
0 g
s
.69 .412 0 r
.82266 .1231 m .82389 .12761 L .82257 .12264 L p F P
0 g
s
.69 .412 0 r
.82257 .12264 m .82133 .11814 L .82266 .1231 L p F P
0 g
s
.846 .818 .822 r
.68498 .09526 m .67917 .10125 L .68154 .10549 L p F P
0 g
s
.841 .82 .828 r
.67285 .10764 m .67917 .10125 L .68154 .10549 L p F P
0 g
s
.841 .82 .828 r
.68154 .10549 m .67583 .11121 L .67285 .10764 L p F P
0 g
s
.957 .935 .724 r
.81202 .21051 m .81237 .21515 L .81621 .20837 L p F P
0 g
s
.957 .935 .724 r
.8144 .2063 m .81202 .21051 L p .81621 .20837 L F P
0 g
s
.957 .935 .724 r
.81621 .20837 m .81611 .20687 L .8144 .2063 L p F P
0 g
s
.98 .896 .551 r
.61228 .26138 m .61433 .2552 L .61493 .25979 L p F P
0 g
s
.98 .896 .551 r
.6126 .26411 m .61228 .26138 L p .61493 .25979 L F P
0 g
s
.98 .896 .551 r
.61493 .25979 m .61379 .26312 L .6126 .26411 L p F P
0 g
s
.977 .888 .672 r
.61919 .22748 m .62033 .23195 L .62335 .22548 L p F P
0 g
s
.977 .888 .672 r
.62335 .22548 m .6221 .22104 L .61919 .22748 L p F P
0 g
s
.166 .401 .844 r
.80687 .08804 m .80805 .09159 L .80215 .08826 L p F P
0 g
s
.166 .401 .844 r
.80626 .0869 m .80687 .08804 L p .80215 .08826 L F P
0 g
s
.166 .401 .844 r
.80215 .08826 m .80056 .0838 L .80626 .0869 L p F P
0 g
s
.469 .594 .895 r
.62311 .34551 m .6233 .34344 L .62467 .34565 L closepath p F P
0 g
s
.905 .836 .767 r
.65212 .14739 m .65479 .14353 L .65178 .1404 L p F P
0 g
s
.963 .868 .697 r
.62818 .20794 m .62808 .20815 L .62796 .20783 L closepath p F P
0 g
s
.968 .867 .684 r
.62346 .21025 m .62506 .2146 L .62808 .20815 L p F P
0 g
s
.968 .867 .684 r
.62518 .20654 m .62346 .21025 L p .62808 .20815 L F P
0 g
s
.968 .867 .684 r
.62808 .20815 m .62796 .20783 L .62518 .20654 L p F P
0 g
s
.98 .905 .658 r
.6207 .23386 m .61945 .23391 L .62033 .23195 L closepath p F P
0 g
s
.824 .905 .896 r
.73371 .31104 m .73846 .30721 L .73566 .30517 L p F P
0 g
s
.824 .905 .896 r
.73566 .30517 m .73433 .30624 L .73371 .31104 L p F P
0 g
s
.819 .899 .898 r
.72338 .3148 m .73433 .30624 L .73371 .31104 L p F P
0 g
s
.865 .821 .803 r
.67387 .11348 m .67583 .11121 L .67285 .10764 L p F P
0 g
s
.987 .88 .537 r
.82291 .17529 m .82366 .17986 L .82548 .17377 L p F P
0 g
s
.987 .88 .537 r
.82548 .17377 m .82475 .1692 L .82291 .17529 L p F P
0 g
s
.766 .865 .921 r
.69127 .33672 m .69875 .33203 L .69584 .32958 L p F P
0 g
s
.766 .865 .921 r
.69584 .32958 m .69212 .33187 L .69127 .33672 L p F P
0 g
s
.766 .858 .918 r
.68348 .3371 m .69212 .33187 L .69127 .33672 L p F P
0 g
s
.878 .93 .852 r
.77494 .27341 m .77199 .27646 L .77225 .27175 L closepath p F P
0 g
s
.929 .937 .785 r
.7983 .23635 m .79852 .24098 L .80369 .23376 L p F P
0 g
s
.929 .937 .785 r
.80369 .23376 m .80353 .2291 L .7983 .23635 L p F P
0 g
s
.938 .94 .767 r
.80539 .22635 m .80353 .2291 L .80369 .23376 L p F P
0 g
s
.978 .918 .644 r
.81842 .19259 m .81897 .19719 L .82179 .19076 L p F P
0 g
s
.978 .918 .644 r
.82179 .19076 m .82127 .18614 L .81842 .19259 L p F P
0 g
s
.957 .834 .404 r
.61022 .27789 m .61071 .28248 L .61202 .27652 L p F P
0 g
s
.957 .834 .404 r
.61202 .27652 m .61146 .27195 L .61022 .27789 L p F P
0 g
s
.864 .922 .865 r
.76394 .27999 m .76381 .28466 L .77199 .27646 L p F P
0 g
s
.864 .922 .865 r
.77224 .27174 m .76394 .27999 L p .77199 .27646 L F P
0 g
s
.864 .922 .865 r
.77199 .27646 m .77225 .27175 L .77224 .27174 L p F P
0 g
s
.834 .907 .888 r
.74472 .30194 m .73846 .30721 L .73566 .30517 L p F P
0 g
s
.865 .821 .803 r
.67285 .10764 m .67145 .10927 L .67387 .11348 L p F P
0 g
s
.864 .821 .804 r
.66487 .11689 m .6672 .12113 L .67387 .11348 L p F P
0 g
s
.864 .821 .804 r
.67387 .11348 m .67145 .10927 L .66487 .11689 L p F P
0 g
s
.958 .883 .716 r
.62796 .20783 m .62518 .20654 L .62667 .20373 L closepath p F P
0 g
s
0 0 .52 r
.8193 .11342 m .81795 .10893 L p .81515 .10466 L F P
0 g
s
0 0 .368 r
.82 .11364 m .82133 .11814 L .8193 .11342 L p F P
0 g
s
0 0 .368 r
.8193 .11342 m .81795 .10893 L .82 .11364 L p F P
0 g
s
.795 .804 .859 r
.69717 .08425 m .7092 .07481 L .71167 .07904 L p F P
0 g
s
.798 .801 .854 r
.71167 .07904 m .71237 .07849 L .70944 .07462 L p F P
0 g
s
.798 .801 .854 r
.70944 .07462 m .7092 .07481 L .71167 .07904 L p F P
0 g
s
.766 .789 .872 r
.72472 .07032 m .71237 .07849 L .70944 .07462 L p F P
0 g
s
.011 .261 .764 r
.80918 .09249 m .80805 .09159 L .80945 .0961 L p F P
0 g
s
.011 .261 .764 r
.80945 .0961 m .81211 .09834 L .80918 .09249 L p F P
0 g
s
.947 .859 .721 r
.63398 .18256 m .63205 .18615 L .63388 .19045 L p F P
0 g
s
.949 .859 .718 r
.62854 .19276 m .63028 .19709 L .63388 .19045 L p F P
0 g
s
.949 .859 .718 r
.63388 .19045 m .63205 .18615 L .62854 .19276 L p F P
0 g
s
0 .114 .665 r
.81506 .10445 m .81511 .10451 L .81515 .10466 L closepath p F P
0 g
s
0 0 .52 r
.81795 .10893 m .81511 .10451 L .81515 .10466 L p F P
0 g
s
.84 .912 .885 r
.74472 .30194 m .75068 .29678 L .7479 .29482 L p F P
0 g
s
.84 .912 .885 r
.7479 .29482 m .74516 .29719 L .74472 .30194 L p F P
0 g
s
.834 .907 .888 r
.73566 .30517 m .74516 .29719 L .74472 .30194 L p F P
0 g
s
0 .127 .676 r
.81511 .10451 m .81506 .10445 L .81211 .09834 L p F P
0 g
s
.887 .669 .15 r
.82586 .14272 m .82602 .14343 L .82607 .13888 L p F P
0 g
s
.887 .669 .15 r
.82607 .13888 m .82572 .13732 L .82586 .14272 L p F P
0 g
s
0 0 .469 r
.61222 .31969 m .61222 .3239 L .6101 .31899 L p F P
0 g
s
0 0 .469 r
.61189 .31853 m .61222 .31969 L p .6101 .31899 L F P
0 g
s
0 0 .469 r
.6101 .31899 m .61027 .31427 L .61189 .31853 L p F P
0 g
s
.862 .916 .865 r
.7601 .28369 m .76394 .27999 L .76381 .28466 L p F P
0 g
s
.862 .916 .865 r
.76381 .28466 m .76284 .2856 L .7601 .28369 L p F P
0 g
s
0 .127 .676 r
.81211 .09834 m .81363 .10005 L .81511 .10451 L p F P
0 g
s
0 0 .546 r
.8165 .10446 m .81795 .10893 L .81511 .10451 L p F P
0 g
s
0 0 .546 r
.81511 .10451 m .81363 .10005 L .8165 .10446 L p F P
0 g
s
.905 .836 .767 r
.65178 .1404 m .64988 .14316 L .65212 .14739 L p F P
0 g
s
.905 .836 .767 r
.64507 .15019 m .64722 .15444 L .65212 .14739 L p F P
0 g
s
.905 .836 .767 r
.65212 .14739 m .64988 .14316 L .64507 .15019 L p F P
0 g
s
.855 .916 .873 r
.75468 .29317 m .76284 .2856 L .7601 .28369 L p F P
0 g
s
.561 .707 .939 r
.62467 .34565 m .63717 .34404 L .64025 .34789 L p F P
0 g
s
.576 .648 .884 r
.6233 .34344 m .62467 .34565 L .63717 .34404 L p F P
0 g
s
.849 .912 .877 r
.75468 .29317 m .75068 .29678 L .7479 .29482 L p F P
0 g
s
.855 .916 .873 r
.7601 .28369 m .75496 .28846 L .75468 .29317 L p F P
0 g
s
.849 .912 .877 r
.7479 .29482 m .75496 .28846 L .75468 .29317 L p F P
0 g
s
.936 .76 .287 r
.82542 .14832 m .8263 .1529 L .82674 .1473 L p F P
0 g
s
.936 .76 .287 r
.82573 .1445 m .82542 .14832 L p .82674 .1473 L F P
0 g
s
.936 .76 .287 r
.82674 .1473 m .82602 .14343 L .82573 .1445 L p F P
0 g
s
.986 .9 .592 r
.82391 .18154 m .82302 .18162 L .82366 .17986 L closepath p F P
0 g
s
.791 .678 .13 r
.60976 .29305 m .60976 .28833 L .60929 .29403 L p F P
0 g
s
.72 .833 .935 r
.67111 .344 m .67036 .34436 L .67064 .34355 L closepath p F P
0 g
s
.717 .813 .924 r
.66812 .34111 m .67064 .34355 L .67036 .34436 L p F P
0 g
s
.717 .813 .924 r
.65572 .34684 m .66812 .34111 L p .67036 .34436 L F P
0 g
s
.616 .716 .917 r
.75553 .0666 m .76829 .0635 L .77115 .06775 L p F P
0 g
s
.62 .719 .917 r
.76829 .0635 m .75553 .0666 L .75266 .06249 L p F P
0 g
s
.681 .752 .905 r
.74007 .06757 m .75266 .06249 L .75553 .0666 L p F P
0 g
s
.99 .874 .535 r
.61379 .26312 m .61297 .26594 L .6126 .26411 L closepath p F P
0 g
s
.684 .754 .904 r
.75266 .06249 m .74007 .06757 L .73718 .06356 L p F P
0 g
s
.863 .826 .81 r
.66078 .12154 m .66487 .11689 L .6672 .12113 L p F P
0 g
s
.863 .826 .81 r
.6672 .12113 m .66378 .12498 L .66078 .12154 L p F P
0 g
s
.745 .839 .922 r
.68052 .33441 m .68348 .3371 L .67111 .344 L p F P
0 g
s
.745 .839 .922 r
.67095 .3396 m .68052 .33441 L p .67111 .344 L F P
0 g
s
.745 .839 .922 r
.67111 .344 m .67064 .34355 L .67095 .3396 L p F P
0 g
s
.927 .851 .747 r
.63403 .17512 m .63592 .17942 L .64019 .17257 L p F P
0 g
s
.927 .851 .747 r
.64019 .17257 m .6382 .16829 L .63403 .17512 L p F P
0 g
s
.784 .873 .913 r
.70805 .3258 m .69875 .33203 L .69584 .32958 L p F P
0 g
s
.964 .927 .708 r
.81611 .20687 m .8144 .2063 L .81578 .20375 L closepath p F P
0 g
s
.92 .933 .799 r
.79359 .24259 m .7983 .23635 L .79852 .24098 L p F P
0 g
s
.92 .933 .799 r
.79852 .24098 m .79622 .24402 L .79359 .24259 L p F P
0 g
s
.951 .933 .741 r
.80779 .21743 m .8082 .22204 L .81237 .21515 L p F P
0 g
s
.951 .933 .741 r
.81237 .21515 m .81202 .21051 L .80779 .21743 L p F P
0 g
s
.885 .826 .785 r
.66097 .12862 m .66378 .12498 L .66078 .12154 L p F P
0 g
s
.372 .566 .912 r
.79095 .07674 m .78987 .07651 L .78701 .07195 L p F P
0 g
s
.737 .832 .923 r
.67064 .34355 m .66812 .34111 L .67095 .3396 L closepath p F P
0 g
s
.979 .895 .665 r
.61646 .23368 m .61919 .22748 L .62033 .23195 L p F P
0 g
s
.979 .895 .665 r
.62033 .23195 m .61945 .23391 L .61646 .23368 L p F P
0 g
s
.984 .855 .477 r
.82392 .16463 m .82475 .1692 L .82615 .16326 L p F P
0 g
s
.984 .855 .477 r
.82615 .16326 m .82534 .15868 L .82392 .16463 L p F P
0 g
s
.916 .936 .806 r
.79276 .24841 m .79622 .24402 L .79359 .24259 L p F P
0 g
s
.496 .587 .876 r
.62153 .34036 m .62435 .34052 L .6233 .34344 L closepath p F P
0 g
s
.576 .648 .884 r
.63408 .33997 m .62435 .34052 L .6233 .34344 L p F P
0 g
s
.576 .648 .884 r
.63717 .34404 m .63408 .33997 L p .6233 .34344 L F P
0 g
s
.992 .883 .587 r
.61339 .2507 m .61433 .2552 L .61655 .24897 L p F P
0 g
s
.992 .883 .587 r
.61655 .24897 m .61551 .2445 L .61339 .2507 L p F P
0 g
s
.972 .869 .677 r
.62059 .21667 m .6221 .22104 L .62506 .2146 L p F P
0 g
s
.972 .869 .677 r
.62506 .2146 m .62346 .21025 L .62059 .21667 L p F P
0 g
s
.9 .676 .166 r
.82472 .1382 m .82586 .14272 L .82572 .13732 L p F P
0 g
s
.9 .676 .166 r
.82572 .13732 m .82459 .1328 L .82472 .1382 L p F P
0 g
s
0 0 .216 r
.61018 .31193 m .61027 .31427 L .60937 .30898 L p F P
0 g
s
0 0 .216 r
.60937 .30898 m .60925 .30549 L .61018 .31193 L p F P
0 g
s
.904 .843 .774 r
.64014 .15726 m .64507 .15019 L .64722 .15444 L p F P
0 g
s
.904 .843 .774 r
.64083 .15869 m .64014 .15726 L p .64722 .15444 L F P
0 g
s
.904 .843 .774 r
.64722 .15444 m .64285 .16065 L .64083 .15869 L p F P
0 g
s
.884 .826 .785 r
.65297 .13171 m .65529 .13594 L .66097 .12862 L p F P
0 g
s
.884 .826 .785 r
.66097 .12862 m .65858 .12442 L .65297 .13171 L p F P
0 g
s
.885 .826 .785 r
.66078 .12154 m .65858 .12442 L .66097 .12862 L p F P
0 g
s
.987 .858 .492 r
.61055 .26747 m .61146 .27195 L .61297 .26594 L p F P
0 g
s
.987 .858 .492 r
.61088 .26617 m .61055 .26747 L p .61297 .26594 L F P
0 g
s
.987 .858 .492 r
.61297 .26594 m .6126 .26411 L .61088 .26617 L p F P
0 g
s
.729 .778 .892 r
.73084 .06702 m .72472 .07032 L .7218 .06638 L p F P
0 g
s
.766 .789 .872 r
.70944 .07462 m .7218 .06638 L .72472 .07032 L p F P
0 g
s
.535 .676 .929 r
.77272 .06764 m .77115 .06775 L .76829 .0635 L p F P
0 g
s
.973 .921 .679 r
.81519 .19917 m .81578 .20375 L .81897 .19719 L p F P
0 g
s
.973 .921 .679 r
.81897 .19719 m .81842 .19259 L .81519 .19917 L p F P
0 g
s
.702 .817 .937 r
.66812 .34111 m .65572 .34684 L .65269 .3436 L p F P
0 g
s
.661 .787 .942 r
.64025 .34789 m .65269 .3436 L .65572 .34684 L p F P
0 g
s
.951 .865 .717 r
.62503 .19938 m .62667 .20373 L .63028 .19709 L p F P
0 g
s
.951 .865 .717 r
.63028 .19709 m .62854 .19276 L .62503 .19938 L p F P
0 g
s
.643 .773 .942 r
.65269 .3436 m .64025 .34789 L .63717 .34404 L p F P
0 g
s
.987 .899 .595 r
.82066 .18154 m .82291 .17529 L .82366 .17986 L p F P
0 g
s
.987 .899 .595 r
.82069 .18172 m .82066 .18154 L p .82366 .17986 L F P
0 g
s
.987 .899 .595 r
.82366 .17986 m .82302 .18162 L .82069 .18172 L p F P
0 g
s
.789 .884 .915 r
.71107 .32374 m .70805 .3258 L .70875 .32188 L closepath p F P
0 g
s
.784 .873 .913 r
.70819 .32141 m .70875 .32188 L .70805 .3258 L p F P
0 g
s
.784 .873 .913 r
.69584 .32958 m .70819 .32141 L p .70805 .3258 L F P
0 g
s
0 0 .099 r
.60935 .3043 m .60925 .30549 L .60913 .30001 L p F P
0 g
s
0 0 .099 r
.60913 .30001 m .60922 .29877 L .60935 .3043 L p F P
0 g
s
.372 .566 .912 r
.78701 .07195 m .78902 .07236 L .79095 .07674 L p F P
0 g
s
.297 .514 .897 r
.7971 .0749 m .79888 .07934 L .79095 .07674 L p F P
0 g
s
.297 .514 .897 r
.79095 .07674 m .78902 .07236 L .7971 .0749 L p F P
0 g
s
.987 .874 .632 r
.61778 .23827 m .61945 .23391 L .61646 .23368 L p F P
0 g
s
.916 .936 .806 r
.79359 .24259 m .79269 .24373 L .79276 .24841 L p F P
0 g
s
.905 .931 .82 r
.78636 .25135 m .78652 .25599 L .79276 .24841 L p F P
0 g
s
.905 .931 .82 r
.79276 .24841 m .79269 .24373 L .78636 .25135 L p F P
0 g
s
.801 .885 .906 r
.72213 .31573 m .71107 .32374 L .70875 .32188 L p F P
0 g
s
.923 .79 .316 r
.60934 .28372 m .60976 .28833 L .61071 .28248 L p F P
0 g
s
.923 .79 .316 r
.61071 .28248 m .61022 .27789 L .60934 .28372 L p F P
0 g
s
.929 .858 .751 r
.63095 .18014 m .63403 .17512 L .63592 .17942 L p F P
0 g
s
.929 .858 .751 r
.63592 .17942 m .63398 .18256 L .63095 .18014 L p F P
0 g
s
.535 .676 .929 r
.76829 .0635 m .77053 .06332 L .77272 .06764 L p F P
0 g
s
.503 .649 .923 r
.78129 .063 m .77053 .06332 L .77272 .06764 L p F P
0 g
s
.503 .649 .923 r
.77272 .06764 m .78415 .06745 L .78129 .063 L p F P
0 g
s
.984 .906 .604 r
.82302 .18162 m .82127 .18614 L .82069 .18172 L closepath p F P
0 g
s
0 .141 .686 r
.81363 .10005 m .81211 .09834 L .80918 .09249 L p F P
0 g
s
.824 .567 .014 r
.82337 .1283 m .82459 .1328 L .82389 .12761 L p F P
0 g
s
.824 .567 .014 r
.82389 .12761 m .82266 .1231 L .82337 .1283 L p F P
0 g
s
.943 .932 .759 r
.80324 .22446 m .80779 .21743 L .8082 .22204 L p F P
0 g
s
.943 .932 .759 r
.80333 .22539 m .80324 .22446 L p .8082 .22204 L F P
0 g
s
.943 .932 .759 r
.8082 .22204 m .80539 .22635 L .80333 .22539 L p F P
0 g
s
.818 .808 .842 r
.68748 .09304 m .68498 .09526 L .682 .09149 L p F P
0 g
s
.845 .813 .819 r
.67917 .10125 m .68498 .09526 L .682 .09149 L p F P
0 g
s
.826 .806 .832 r
.685 .08881 m .68748 .09304 L .69702 .08439 L p F P
0 g
s
.818 .808 .842 r
.682 .09149 m .685 .08881 L .68748 .09304 L p F P
0 g
s
.92 .837 .747 r
.64285 .16065 m .64232 .1615 L .64083 .15869 L closepath p F P
0 g
s
.883 .831 .791 r
.64876 .1371 m .65297 .13171 L .65529 .13594 L p F P
0 g
s
.883 .831 .791 r
.65529 .13594 m .65178 .1404 L .64876 .1371 L p F P
0 g
s
.822 .805 .836 r
.69717 .08425 m .69702 .08439 L .69603 .08277 L closepath p F P
0 g
s
.826 .806 .832 r
.6942 .08041 m .685 .08881 L p .69702 .08439 L F P
0 g
s
.826 .806 .832 r
.69702 .08439 m .69603 .08277 L .6942 .08041 L p F P
0 g
s
.795 .8 .856 r
.7092 .07481 m .69717 .08425 L .69603 .08277 L p F P
0 g
s
.439 .549 .871 r
.62435 .34052 m .62153 .34036 L .61836 .33437 L p F P
0 g
s
.733 .777 .889 r
.73084 .06702 m .73718 .06356 L .73427 .05953 L p F P
0 g
s
.733 .777 .889 r
.73427 .05953 m .72846 .06274 L .73084 .06702 L p F P
0 g
s
.729 .778 .892 r
.7218 .06638 m .72846 .06274 L .73084 .06702 L p F P
0 g
s
.897 .926 .829 r
.78161 .25687 m .78636 .25135 L .78652 .25599 L p F P
0 g
s
.897 .926 .829 r
.78652 .25599 m .78429 .25856 L .78161 .25687 L p F P
0 g
s
.925 .837 .739 r
.63602 .16406 m .6382 .16829 L .64232 .1615 L p F P
0 g
s
.925 .837 .739 r
.63982 .15772 m .63602 .16406 L p .64232 .1615 L F P
0 g
s
.925 .837 .739 r
.64232 .1615 m .64083 .15869 L .63982 .15772 L p F P
0 g
s
.762 .853 .918 r
.69212 .33187 m .68348 .3371 L .68052 .33441 L p F P
0 g
s
.972 .818 .4 r
.82444 .15411 m .82534 .15868 L .8263 .1529 L p F P
0 g
s
.972 .818 .4 r
.8263 .1529 m .82542 .14832 L .82444 .15411 L p F P
0 g
s
.944 .849 .719 r
.63205 .18615 m .63398 .18256 L .63095 .18014 L p F P
0 g
s
.845 .813 .819 r
.682 .09149 m .67665 .09705 L .67917 .10125 L p F P
0 g
s
.841 .814 .824 r
.66985 .10396 m .67665 .09705 L .67917 .10125 L p F P
0 g
s
.841 .814 .824 r
.67917 .10125 m .67285 .10764 L .66985 .10396 L p F P
0 g
s
0 0 .054 r
.60944 .29956 m .60935 .3043 L .60922 .29877 L p F P
0 g
s
.892 .928 .836 r
.7796 .26379 m .78429 .25856 L .78161 .25687 L p F P
0 g
s
.253 .4 .817 r
.61587 .33298 m .61599 .3295 L .61836 .33437 L closepath p F P
0 g
s
.171 .401 .844 r
.80337 .08166 m .79888 .07934 L .80056 .0838 L p F P
0 g
s
.171 .401 .844 r
.80056 .0838 m .80626 .0869 L .80337 .08166 L p F P
0 g
s
.706 .42 0 r
.82134 .1186 m .82266 .1231 L .82133 .11814 L p F P
0 g
s
.706 .42 0 r
.82133 .11814 m .82 .11364 L .82134 .1186 L p F P
0 g
s
.807 .894 .905 r
.72338 .3148 m .72213 .31573 L .72237 .31402 L closepath p F P
0 g
s
.801 .885 .906 r
.72053 .31251 m .72237 .31402 L .72213 .31573 L p F P
0 g
s
.801 .885 .906 r
.70882 .32097 m .72053 .31251 L p .72213 .31573 L F P
0 g
s
.801 .885 .906 r
.70875 .32188 m .70882 .32097 L p .72213 .31573 L F P
0 g
s
.864 .816 .8 r
.67145 .10927 m .67285 .10764 L .66985 .10396 L p F P
0 g
s
.975 .878 .502 r
.6126 .26411 m .61088 .26617 L .61228 .26138 L closepath p F P
0 g
s
.818 .895 .897 r
.73433 .30624 m .72338 .3148 L .72237 .31402 L p F P
0 g
s
.902 .829 .764 r
.64988 .14316 m .65178 .1404 L .64876 .1371 L p F P
0 g
s
.987 .874 .632 r
.61646 .23368 m .61637 .23389 L .61778 .23827 L p F P
0 g
s
.991 .87 .611 r
.61419 .24011 m .61551 .2445 L .61778 .23827 L p F P
0 g
s
.991 .87 .611 r
.61778 .23827 m .61637 .23389 L .61419 .24011 L p F P
0 g
s
.938 .936 .768 r
.80539 .22635 m .80353 .2291 L .80333 .22539 L closepath p F P
0 g
s
.975 .874 .67 r
.61778 .22308 m .61919 .22748 L .6221 .22104 L p F P
0 g
s
.975 .874 .67 r
.6221 .22104 m .62059 .21667 L .61778 .22308 L p F P
0 g
s
.864 .816 .8 r
.66985 .10396 m .66889 .10509 L .67145 .10927 L p F P
0 g
s
.863 .816 .801 r
.66237 .11269 m .66487 .11689 L .67145 .10927 L p F P
0 g
s
.863 .816 .801 r
.67145 .10927 m .66889 .10509 L .66237 .11269 L p F P
0 g
s
.964 .925 .709 r
.81186 .20539 m .81519 .19917 L .81578 .20375 L p F P
0 g
s
.964 .925 .709 r
.81578 .20375 m .8144 .2063 L .81186 .20539 L p F P
0 g
s
.954 .873 .718 r
.62215 .20485 m .62503 .19938 L .62667 .20373 L p F P
0 g
s
.954 .873 .718 r
.62667 .20373 m .62518 .20654 L .62215 .20485 L p F P
0 g
s
.797 .798 .852 r
.70944 .07462 m .7092 .07481 L .7075 .07205 L closepath p F P
0 g
s
.795 .8 .856 r
.70649 .0707 m .7075 .07205 L .7092 .07481 L p F P
0 g
s
.795 .8 .856 r
.69453 .08015 m .70649 .0707 L p .7092 .07481 L F P
0 g
s
.795 .8 .856 r
.69603 .08277 m .69453 .08015 L p .7092 .07481 L F P
0 g
s
.761 .789 .876 r
.71887 .06239 m .7218 .06638 L .70944 .07462 L p F P
0 g
s
.761 .789 .876 r
.70668 .07058 m .71887 .06239 L p .70944 .07462 L F P
0 g
s
.761 .789 .876 r
.70944 .07462 m .7075 .07205 L .70668 .07058 L p F P
0 g
s
.991 .88 .557 r
.61146 .25685 m .61228 .26138 L .61433 .2552 L p F P
0 g
s
.991 .88 .557 r
.61433 .2552 m .61339 .2507 L .61146 .25685 L p F P
0 g
s
.892 .928 .836 r
.78161 .25687 m .7796 .25911 L .7796 .26379 L p F P
0 g
s
.883 .923 .845 r
.77215 .2671 m .77225 .27173 L .7796 .26379 L p F P
0 g
s
.883 .923 .845 r
.7796 .26379 m .7796 .25911 L .77215 .2671 L p F P
0 g
s
0 .164 .681 r
.61222 .3239 m .61222 .31969 L .61516 .32748 L closepath p F P
0 g
s
.947 .756 .292 r
.82602 .14343 m .82573 .1445 L .82586 .14272 L closepath p F P
0 g
s
.99 .879 .546 r
.82206 .17074 m .82291 .17529 L .82475 .1692 L p F P
0 g
s
.99 .879 .546 r
.82475 .1692 m .82392 .16463 L .82206 .17074 L p F P
0 g
s
0 0 .36 r
.81858 .10916 m .82 .11364 L .81795 .10893 L p F P
0 g
s
0 0 .36 r
.81795 .10893 m .8165 .10446 L .81858 .10916 L p F P
0 g
s
.944 .849 .719 r
.63095 .18014 m .63002 .1819 L .63205 .18615 L p F P
0 g
s
.946 .849 .714 r
.62658 .18849 m .62854 .19276 L .63205 .18615 L p F P
0 g
s
.946 .849 .714 r
.63205 .18615 m .63002 .1819 L .62658 .18849 L p F P
0 g
s
.977 .917 .661 r
.81777 .188 m .81842 .19259 L .82127 .18614 L p F P
0 g
s
.977 .917 .661 r
.82059 .1817 m .81777 .188 L p .82127 .18614 L F P
0 g
s
.977 .917 .661 r
.82127 .18614 m .82069 .18172 L .82059 .1817 L p F P
0 g
s
.924 .931 .794 r
.79798 .23173 m .7983 .23635 L .80353 .2291 L p F P
0 g
s
.924 .931 .794 r
.8028 .22509 m .79798 .23173 L p .80353 .2291 L F P
0 g
s
.924 .931 .794 r
.80353 .2291 m .80333 .22539 L .8028 .22509 L p F P
0 g
s
.902 .829 .764 r
.64876 .1371 m .64749 .13897 L .64988 .14316 L p F P
0 g
s
.903 .829 .763 r
.64274 .14598 m .64507 .15019 L .64988 .14316 L p F P
0 g
s
.903 .829 .763 r
.64988 .14316 m .64749 .13897 L .64274 .14598 L p F P
0 g
s
.019 .277 .775 r
.80805 .09159 m .80687 .08804 L .80918 .09249 L closepath p F P
0 g
s
.62 .719 .917 r
.75266 .06249 m .76542 .05927 L .76829 .0635 L p F P
0 g
s
.623 .722 .918 r
.76542 .05927 m .75266 .06249 L .74977 .05839 L p F P
0 g
s
.684 .754 .904 r
.73718 .06356 m .74977 .05839 L .75266 .06249 L p F P
0 g
s
.978 .833 .431 r
.60938 .27339 m .61022 .27789 L .61146 .27195 L p F P
0 g
s
.978 .833 .431 r
.61146 .27195 m .61055 .26747 L .60938 .27339 L p F P
0 g
s
0 .141 .686 r
.80918 .09249 m .81206 .09559 L .81363 .10005 L p F P
0 g
s
0 0 .544 r
.81497 .09999 m .8165 .10446 L .81363 .10005 L p F P
0 g
s
0 0 .544 r
.81363 .10005 m .81206 .09559 L .81497 .09999 L p F P
0 g
s
.824 .902 .895 r
.73566 .30517 m .73433 .30624 L .73453 .30433 L closepath p F P
0 g
s
.818 .895 .897 r
.73284 .30298 m .73453 .30433 L .73433 .30624 L p F P
0 g
s
.818 .895 .897 r
.72253 .31099 m .73284 .30298 L p .73433 .30624 L F P
0 g
s
.818 .895 .897 r
.72237 .31402 m .72253 .31099 L p .73433 .30624 L F P
0 g
s
.793 .8 .858 r
.69603 .08277 m .6942 .08041 L .69453 .08015 L closepath p F P
0 g
s
.686 .755 .904 r
.74977 .05839 m .73718 .06356 L .73427 .05953 L p F P
0 g
s
.961 .93 .716 r
.81202 .21051 m .8144 .2063 L .81186 .20539 L p F P
0 g
s
.833 .902 .887 r
.74516 .29719 m .73566 .30517 L .73453 .30433 L p F P
0 g
s
.439 .549 .871 r
.61836 .33437 m .62534 .33558 L .62435 .34052 L p F P
0 g
s
.529 .667 .924 r
.63097 .33567 m .62534 .33558 L .62435 .34052 L p F P
0 g
s
.529 .667 .924 r
.62435 .34052 m .63408 .33997 L .63097 .33567 L p F P
0 g
s
.875 .92 .853 r
.77225 .27175 m .77224 .27174 L .77225 .27173 L closepath p F P
0 g
s
.875 .915 .852 r
.76952 .26981 m .77215 .2671 L .77225 .27173 L p F P
0 g
s
.875 .915 .852 r
.77225 .27173 m .77224 .27174 L .76952 .26981 L p F P
0 g
s
.868 .916 .859 r
.76394 .27999 m .77224 .27174 L .76952 .26981 L p F P
0 g
s
.767 .866 .922 r
.69584 .32958 m .69212 .33187 L .69303 .32716 L closepath p F P
0 g
s
.762 .853 .918 r
.69292 .32707 m .69303 .32716 L .69212 .33187 L p F P
0 g
s
.762 .853 .918 r
.68052 .33441 m .69292 .32707 L p .69212 .33187 L F P
0 g
s
.965 .858 .684 r
.62346 .21025 m .62518 .20654 L .62215 .20485 L p F P
0 g
s
.951 .757 .298 r
.82434 .14379 m .82472 .1382 L .82586 .14272 L p F P
0 g
s
.951 .757 .298 r
.82508 .14674 m .82434 .14379 L p .82586 .14272 L F P
0 g
s
.951 .757 .298 r
.82586 .14272 m .82573 .1445 L .82508 .14674 L p F P
0 g
s
.861 .82 .807 r
.65776 .11797 m .66237 .11269 L .66487 .11689 L p F P
0 g
s
.861 .82 .807 r
.66487 .11689 m .66078 .12154 L .65776 .11797 L p F P
0 g
s
.925 .841 .743 r
.63193 .17087 m .63403 .17512 L .6382 .16829 L p F P
0 g
s
.925 .841 .743 r
.6382 .16829 m .63602 .16406 L .63193 .17087 L p F P
0 g
s
.379 .574 .915 r
.78902 .07236 m .78701 .07195 L .78415 .06745 L p F P
0 g
s
.839 .909 .884 r
.7479 .29482 m .74516 .29719 L .74548 .29305 L closepath p F P
0 g
s
.833 .902 .887 r
.74512 .29277 m .74548 .29305 L .74516 .29719 L p F P
0 g
s
.833 .902 .887 r
.73462 .30153 m .74512 .29277 L p .74516 .29719 L F P
0 g
s
.833 .902 .887 r
.73453 .30433 m .73462 .30153 L p .74516 .29719 L F P
0 g
s
.737 .826 .92 r
.67095 .3396 m .66812 .34111 L .66513 .33811 L p F P
0 g
s
.702 .817 .937 r
.65269 .3436 m .66513 .33811 L .66812 .34111 L p F P
0 g
s
.868 .916 .859 r
.76952 .26981 m .76397 .27532 L .76394 .27999 L p F P
0 g
s
.862 .913 .864 r
.75734 .28172 m .76397 .27532 L .76394 .27999 L p F P
0 g
s
.862 .913 .864 r
.76394 .27999 m .7601 .28369 L .75734 .28172 L p F P
0 g
s
.848 .909 .876 r
.75496 .28846 m .7479 .29482 L .74548 .29305 L p F P
0 g
s
.854 .913 .872 r
.75496 .28846 m .7601 .28369 L .75734 .28172 L p F P
0 g
s
0 0 .441 r
.61027 .31427 m .61018 .31193 L .61189 .31853 L closepath p F P
0 g
s
.854 .913 .872 r
.75734 .28172 m .75515 .28375 L .75496 .28846 L p F P
0 g
s
.848 .909 .876 r
.74548 .29245 m .75515 .28375 L .75496 .28846 L p F P
0 g
s
.848 .909 .876 r
.74548 .29305 m .74548 .29245 L p .75496 .28846 L F P
0 g
s
.864 .716 .193 r
.60891 .28942 m .60929 .29403 L .60976 .28833 L p F P
0 g
s
.864 .716 .193 r
.60976 .28833 m .60934 .28372 L .60891 .28942 L p F P
0 g
s
.786 .869 .91 r
.70529 .3189 m .70819 .32141 L .69584 .32958 L p F P
0 g
s
.786 .869 .91 r
.69304 .32699 m .70529 .3189 L p .69584 .32958 L F P
0 g
s
.786 .869 .91 r
.69584 .32958 m .69303 .32716 L .69304 .32699 L p F P
0 g
s
0 0 .323 r
.6104 .30954 m .61018 .31193 L .60925 .30549 L p F P
0 g
s
0 0 .323 r
.60925 .30549 m .60935 .3043 L .6104 .30954 L p F P
0 g
s
.882 .82 .782 r
.65858 .12442 m .66078 .12154 L .65776 .11797 L p F P
0 g
s
.811 .886 .899 r
.72237 .31402 m .72053 .31251 L .72253 .31099 L closepath p F P
0 g
s
0 .128 .677 r
.80687 .08804 m .80918 .09249 L .81206 .09559 L p F P
0 g
s
.539 .68 .929 r
.77053 .06332 m .76829 .0635 L .76542 .05927 L p F P
0 g
s
.461 .525 .837 r
.61599 .3295 m .61836 .33437 L .62534 .33558 L p F P
0 g
s
.733 .83 .925 r
.67095 .3396 m .68052 .33441 L .67755 .33163 L p F P
0 g
s
.733 .83 .925 r
.67755 .33163 m .67139 .33486 L .67095 .3396 L p F P
0 g
s
.737 .826 .92 r
.66513 .33811 m .67139 .33486 L .67095 .3396 L p F P
0 g
s
.921 .929 .798 r
.79239 .23911 m .79798 .23173 L .7983 .23635 L p F P
0 g
s
.921 .929 .798 r
.79263 .24204 m .79239 .23911 L p .7983 .23635 L F P
0 g
s
.921 .929 .798 r
.7983 .23635 m .79359 .24259 L .79263 .24204 L p F P
0 g
s
.945 .76 .296 r
.82573 .1445 m .82542 .14832 L .82508 .14674 L closepath p F P
0 g
s
.643 .773 .942 r
.63717 .34404 m .64965 .34023 L .65269 .3436 L p F P
0 g
s
.622 .756 .942 r
.64965 .34023 m .63717 .34404 L .63408 .33997 L p F P
0 g
s
.961 .93 .716 r
.81186 .20539 m .81158 .20589 L .81202 .21051 L p F P
0 g
s
.95 .929 .745 r
.8073 .21283 m .80779 .21743 L .81202 .21051 L p F P
0 g
s
.95 .929 .745 r
.81202 .21051 m .81158 .20589 L .8073 .21283 L p F P
0 g
s
.731 .777 .89 r
.72846 .06274 m .7218 .06638 L .71887 .06239 L p F P
0 g
s
.882 .82 .782 r
.65047 .12753 m .65297 .13171 L .65858 .12442 L p F P
0 g
s
.882 .82 .782 r
.65858 .12442 m .65602 .12025 L .65047 .12753 L p F P
0 g
s
.882 .82 .782 r
.65776 .11797 m .65602 .12025 L .65858 .12442 L p F P
0 g
s
.902 .832 .767 r
.63787 .15303 m .64014 .15726 L .64507 .15019 L p F P
0 g
s
.902 .832 .767 r
.64507 .15019 m .64274 .14598 L .63787 .15303 L p F P
0 g
s
.908 .845 .77 r
.64083 .15869 m .63982 .15772 L .64014 .15726 L closepath p F P
0 g
s
.988 .855 .489 r
.823 .16008 m .82392 .16463 L .82534 .15868 L p F P
0 g
s
.988 .855 .489 r
.82534 .15868 m .82444 .15411 L .823 .16008 L p F P
0 g
s
.978 .884 .667 r
.61505 .22947 m .61778 .22308 L .61919 .22748 L p F P
0 g
s
.978 .884 .667 r
.61628 .23364 m .61505 .22947 L p .61919 .22748 L F P
0 g
s
.978 .884 .667 r
.61919 .22748 m .61646 .23368 L .61628 .23364 L p F P
0 g
s
.692 .808 .937 r
.66513 .33811 m .65269 .3436 L .64965 .34023 L p F P
0 g
s
.965 .858 .684 r
.62215 .20485 m .62164 .20597 L .62346 .21025 L p F P
0 g
s
.969 .857 .674 r
.61884 .21237 m .62059 .21667 L .62346 .21025 L p F P
0 g
s
.969 .857 .674 r
.62346 .21025 m .62164 .20597 L .61884 .21237 L p F P
0 g
s
.912 .682 .181 r
.8235 .1337 m .82472 .1382 L .82459 .1328 L p F P
0 g
s
.912 .682 .181 r
.82459 .1328 m .82337 .1283 L .8235 .1337 L p F P
0 g
s
.994 .87 .591 r
.61216 .24628 m .61339 .2507 L .61551 .2445 L p F P
0 g
s
.994 .87 .591 r
.61551 .2445 m .61419 .24011 L .61216 .24628 L p F P
0 g
s
.795 .877 .907 r
.70875 .32188 m .70819 .32141 L .70882 .32097 L closepath p F P
0 g
s
.379 .574 .915 r
.78415 .06745 m .78701 .06799 L .78902 .07236 L p F P
0 g
s
.301 .52 .9 r
.79523 .07048 m .7971 .0749 L .78902 .07236 L p F P
0 g
s
.301 .52 .9 r
.78902 .07236 m .78701 .06799 L .79523 .07048 L p F P
0 g
s
.949 .853 .713 r
.62315 .19508 m .62503 .19938 L .62854 .19276 L p F P
0 g
s
.949 .853 .713 r
.62854 .19276 m .62658 .18849 L .62315 .19508 L p F P
0 g
s
.972 .918 .684 r
.8145 .1946 m .81519 .19917 L .81842 .19259 L p F P
0 g
s
.972 .918 .684 r
.81842 .19259 m .81777 .188 L .8145 .1946 L p F P
0 g
s
.985 .877 .522 r
.60974 .26295 m .61146 .25685 L .61228 .26138 L p F P
0 g
s
.985 .877 .522 r
.61035 .26668 m .60974 .26295 L p .61228 .26138 L F P
0 g
s
.985 .877 .522 r
.61228 .26138 m .61088 .26617 L .61035 .26668 L p F P
0 g
s
.826 .894 .89 r
.73453 .30433 m .73284 .30298 L .73462 .30153 L closepath p F P
0 g
s
.989 .893 .599 r
.81979 .17699 m .82066 .18154 L .82291 .17529 L p F P
0 g
s
.989 .893 .599 r
.82291 .17529 m .82206 .17074 L .81979 .17699 L p F P
0 g
s
.764 .79 .874 r
.7075 .07205 m .70649 .0707 L .70668 .07058 L closepath p F P
0 g
s
0 0 .275 r
.61043 .30482 m .6104 .30954 L .60935 .3043 L p F P
0 g
s
0 0 .275 r
.60935 .3043 m .60944 .29956 L .61043 .30482 L p F P
0 g
s
.539 .68 .929 r
.76542 .05927 m .76826 .05901 L .77053 .06332 L p F P
0 g
s
.508 .655 .925 r
.77842 .05859 m .76826 .05901 L .77053 .06332 L p F P
0 g
s
.508 .655 .925 r
.77053 .06332 m .78129 .063 L .77842 .05859 L p F P
0 g
s
.926 .848 .747 r
.6279 .17749 m .63193 .17087 L .63403 .17512 L p F P
0 g
s
.926 .848 .747 r
.63403 .17512 m .63095 .18014 L .6279 .17749 L p F P
0 g
s
.915 .932 .807 r
.79359 .24259 m .79269 .24373 L .79263 .24204 L closepath p F P
0 g
s
.9 .924 .825 r
.78611 .24672 m .78636 .25135 L .79269 .24373 L p F P
0 g
s
.9 .924 .825 r
.79093 .24093 m .78611 .24672 L p .79269 .24373 L F P
0 g
s
.9 .924 .825 r
.79269 .24373 m .79263 .24204 L .79093 .24093 L p F P
0 g
s
.817 .804 .839 r
.685 .08881 m .682 .09149 L .679 .08764 L p F P
0 g
s
.843 .809 .816 r
.67665 .09705 m .682 .09149 L .679 .08764 L p F P
0 g
s
.822 .804 .835 r
.685 .08881 m .6942 .08041 L .69123 .07649 L p F P
0 g
s
.822 .804 .835 r
.69123 .07649 m .68237 .08462 L .685 .08881 L p F P
0 g
s
.817 .804 .839 r
.679 .08764 m .68237 .08462 L .685 .08881 L p F P
0 g
s
.792 .797 .856 r
.69453 .08015 m .6942 .08041 L .69123 .07649 L p F P
0 g
s
.796 .798 .853 r
.69453 .08015 m .70649 .0707 L .70353 .06673 L p F P
0 g
s
.796 .798 .853 r
.70353 .06673 m .69193 .07594 L .69453 .08015 L p F P
0 g
s
.792 .797 .856 r
.69123 .07649 m .69193 .07594 L .69453 .08015 L p F P
0 g
s
.795 .872 .905 r
.70882 .32097 m .70819 .32141 L .70529 .3189 L p F P
0 g
s
.88 .824 .788 r
.64572 .13365 m .65047 .12753 L .65297 .13171 L p F P
0 g
s
.88 .824 .788 r
.65297 .13171 m .64876 .1371 L .64572 .13365 L p F P
0 g
s
.838 .575 .029 r
.82205 .1238 m .82337 .1283 L .82266 .1231 L p F P
0 g
s
.838 .575 .029 r
.82266 .1231 m .82134 .1186 L .82205 .1238 L p F P
0 g
s
.798 .876 .904 r
.70882 .32097 m .72053 .31251 L .71766 .31011 L p F P
0 g
s
.798 .876 .904 r
.71766 .31011 m .70902 .31629 L .70882 .32097 L p F P
0 g
s
.795 .872 .905 r
.70529 .3189 m .70902 .31629 L .70882 .32097 L p F P
0 g
s
.956 .799 .355 r
.60855 .27921 m .60934 .28372 L .61022 .27789 L p F P
0 g
s
.956 .799 .355 r
.61022 .27789 m .60938 .27339 L .60855 .27921 L p F P
0 g
s
.262 .363 .779 r
.61516 .32748 m .61627 .32821 L .61599 .3295 L closepath p F P
0 g
s
.461 .525 .837 r
.62544 .33091 m .61627 .32821 L .61599 .3295 L p F P
0 g
s
.461 .525 .837 r
.62534 .33558 m .62544 .33091 L p .61599 .3295 L F P
0 g
s
.734 .776 .887 r
.72846 .06274 m .73427 .05953 L .73136 .05547 L p F P
0 g
s
.734 .776 .887 r
.73136 .05547 m .72594 .0585 L .72846 .06274 L p F P
0 g
s
.731 .777 .89 r
.71887 .06239 m .72594 .0585 L .72846 .06274 L p F P
0 g
s
.843 .809 .816 r
.679 .08764 m .67398 .09288 L .67665 .09705 L p F P
0 g
s
.839 .809 .821 r
.66683 .10017 m .67398 .09288 L .67665 .09705 L p F P
0 g
s
.839 .809 .821 r
.67665 .09705 m .66985 .10396 L .66683 .10017 L p F P
0 g
s
.904 .836 .768 r
.63678 .15464 m .63787 .15303 L .64014 .15726 L p F P
0 g
s
.904 .836 .768 r
.64014 .15726 m .63982 .15772 L .63678 .15464 L p F P
0 g
s
.942 .926 .761 r
.8027 .21988 m .80324 .22446 L .80779 .21743 L p F P
0 g
s
.942 .926 .761 r
.80779 .21743 m .8073 .21283 L .8027 .21988 L p F P
0 g
s
.922 .832 .739 r
.63602 .16406 m .63982 .15772 L .63678 .15464 L p F P
0 g
s
.033 .107 .61 r
.61273 .31439 m .6104 .30954 L .61018 .31193 L p F P
0 g
s
.033 .107 .61 r
.61229 .31921 m .61273 .31439 L p .61018 .31193 L F P
0 g
s
.033 .107 .61 r
.61018 .31193 m .61189 .31853 L .61229 .31921 L p F P
0 g
s
.296 .363 .762 r
.61222 .31969 m .61516 .32748 L .61627 .32821 L p F P
0 g
s
.756 .852 .922 r
.69292 .32707 m .68052 .33441 L .67755 .33163 L p F P
0 g
s
.979 .821 .415 r
.82346 .14956 m .82444 .15411 L .82542 .14832 L p F P
0 g
s
.979 .821 .415 r
.82364 .14844 m .82346 .14956 L p .82542 .14832 L F P
0 g
s
.979 .821 .415 r
.82542 .14832 m .82508 .14674 L .82364 .14844 L p F P
0 g
s
0 .274 .776 r
.80626 .0869 m .80651 .08711 L .80687 .08804 L closepath p F P
0 g
s
0 .128 .677 r
.8104 .09115 m .80651 .08711 L .80687 .08804 L p F P
0 g
s
0 .128 .677 r
.81206 .09559 m .8104 .09115 L p .80687 .08804 L F P
0 g
s
.862 .811 .798 r
.66889 .10509 m .66985 .10396 L .66683 .10017 L p F P
0 g
s
.178 .414 .852 r
.80048 .07656 m .7971 .0749 L .79888 .07934 L p F P
0 g
s
.178 .414 .852 r
.79888 .07934 m .80337 .08166 L .80048 .07656 L p F P
0 g
s
.862 .811 .798 r
.66683 .10017 m .66618 .10094 L .66889 .10509 L p F P
0 g
s
.862 .811 .798 r
.65971 .10854 m .66237 .11269 L .66889 .10509 L p F P
0 g
s
.862 .811 .798 r
.66889 .10509 m .66618 .10094 L .65971 .10854 L p F P
0 g
s
.764 .787 .873 r
.70668 .07058 m .70649 .0707 L .70353 .06673 L p F P
0 g
s
.722 .428 0 r
.81993 .11412 m .82134 .1186 L .82 .11364 L p F P
0 g
s
.722 .428 0 r
.82 .11364 m .81858 .10916 L .81993 .11412 L p F P
0 g
s
.898 .922 .828 r
.77946 .25446 m .78611 .24672 L .78636 .25135 L p F P
0 g
s
.898 .922 .828 r
.77953 .2555 m .77946 .25446 L p .78636 .25135 L F P
0 g
s
.898 .922 .828 r
.78636 .25135 m .78161 .25687 L .77953 .2555 L p F P
0 g
s
.764 .787 .873 r
.70353 .06673 m .7041 .06635 L .70668 .07058 L p F P
0 g
s
.768 .789 .87 r
.70668 .07058 m .71887 .06239 L .71593 .05835 L p F P
0 g
s
.768 .789 .87 r
.71593 .05835 m .7041 .06635 L .70668 .07058 L p F P
0 g
s
.9 .821 .761 r
.64749 .13897 m .64876 .1371 L .64572 .13365 L p F P
0 g
s
.94 .839 .717 r
.63002 .1819 m .63095 .18014 L .6279 .17749 L p F P
0 g
s
.932 .926 .779 r
.80333 .22539 m .8028 .22509 L .80324 .22446 L closepath p F P
0 g
s
.984 .865 .638 r
.61646 .23368 m .61637 .23389 L .61628 .23364 L closepath p F P
0 g
s
.989 .86 .615 r
.61262 .23577 m .61419 .24011 L .61637 .23389 L p F P
0 g
s
.989 .86 .615 r
.61345 .23341 m .61262 .23577 L p .61637 .23389 L F P
0 g
s
.989 .86 .615 r
.61637 .23389 m .61628 .23364 L .61345 .23341 L p F P
0 g
s
.973 .861 .668 r
.61611 .21875 m .61778 .22308 L .62059 .21667 L p F P
0 g
s
.973 .861 .668 r
.62059 .21667 m .61884 .21237 L .61611 .21875 L p F P
0 g
s
.951 .861 .716 r
.61973 .20169 m .62315 .19508 L .62503 .19938 L p F P
0 g
s
.951 .861 .716 r
.62064 .20387 m .61973 .20169 L p .62503 .19938 L F P
0 g
s
.951 .861 .716 r
.62503 .19938 m .62215 .20485 L .62064 .20387 L p F P
0 g
s
.623 .722 .918 r
.74977 .05839 m .76254 .05505 L .76542 .05927 L p F P
0 g
s
.626 .725 .918 r
.76254 .05505 m .74977 .05839 L .74688 .05427 L p F P
0 g
s
.686 .755 .904 r
.73427 .05953 m .74688 .05427 L .74977 .05839 L p F P
0 g
s
.762 .594 .024 r
.60906 .29494 m .60944 .29956 L .60929 .29403 L p F P
0 g
s
.762 .594 .024 r
.60929 .29403 m .60891 .28942 L .60906 .29494 L p F P
0 g
s
.003 .285 .783 r
.80651 .08711 m .80626 .0869 L .80337 .08166 L p F P
0 g
s
0 .08 .604 r
.61189 .31853 m .61229 .31921 L .61222 .31969 L closepath p F P
0 g
s
.81 .882 .897 r
.72253 .31099 m .72053 .31251 L .71766 .31011 L p F P
0 g
s
.9 .821 .761 r
.64572 .13365 m .64493 .13481 L .64749 .13897 L p F P
0 g
s
.901 .822 .76 r
.64022 .14181 m .64274 .14598 L .64749 .13897 L p F P
0 g
s
.901 .822 .76 r
.64749 .13897 m .64493 .13481 L .64022 .14181 L p F P
0 g
s
.984 .882 .646 r
.61628 .23364 m .61345 .23341 L .61505 .22947 L closepath p F P
0 g
s
.688 .755 .903 r
.74688 .05427 m .73427 .05953 L .73136 .05547 L p F P
0 g
s
.965 .92 .708 r
.81088 .20133 m .8145 .1946 L .81519 .19917 L p F P
0 g
s
.965 .92 .708 r
.8115 .20525 m .81088 .20133 L p .81519 .19917 L F P
0 g
s
.965 .92 .708 r
.81519 .19917 m .81186 .20539 L .8115 .20525 L p F P
0 g
s
.296 .363 .762 r
.61693 .32333 m .61229 .31921 L .61222 .31969 L p F P
0 g
s
.296 .363 .762 r
.61627 .32821 m .61693 .32333 L p .61222 .31969 L F P
0 g
s
.994 .854 .508 r
.61088 .26617 m .61055 .26747 L .61035 .26668 L closepath p F P
0 g
s
0 0 .352 r
.81706 .10469 m .81858 .10916 L .8165 .10446 L p F P
0 g
s
0 0 .352 r
.8165 .10446 m .81497 .09999 L .81706 .10469 L p F P
0 g
s
.94 .839 .717 r
.6279 .17749 m .6278 .17769 L .63002 .1819 L p F P
0 g
s
.943 .839 .711 r
.62442 .18427 m .62658 .18849 L .63002 .1819 L p F P
0 g
s
.943 .839 .711 r
.63002 .1819 m .6278 .17769 L .62442 .18427 L p F P
0 g
s
.814 .886 .896 r
.72253 .31099 m .73284 .30298 L .73 .30066 L p F P
0 g
s
.814 .886 .896 r
.73 .30066 m .72267 .30632 L .72253 .31099 L p F P
0 g
s
.81 .882 .897 r
.71766 .31011 m .72267 .30632 L .72253 .31099 L p F P
0 g
s
.992 .878 .555 r
.82111 .1662 m .82206 .17074 L .82392 .16463 L p F P
0 g
s
.992 .878 .555 r
.82392 .16463 m .823 .16008 L .82111 .1662 L p F P
0 g
s
.344 .464 .839 r
.62502 .32685 m .62544 .33091 L .61627 .32821 L p F P
0 g
s
.344 .464 .839 r
.6247 .32634 m .62502 .32685 L p .61627 .32821 L F P
0 g
s
.344 .464 .839 r
.61627 .32821 m .61693 .32333 L .6247 .32634 L p F P
0 g
s
.384 .58 .918 r
.78701 .06799 m .78415 .06745 L .78129 .063 L p F P
0 g
s
.891 .924 .836 r
.78161 .25687 m .7796 .25911 L .77953 .2555 L closepath p F P
0 g
s
.996 .867 .564 r
.61031 .25241 m .61146 .25685 L .61339 .2507 L p F P
0 g
s
.996 .867 .564 r
.61339 .2507 m .61216 .24628 L .61031 .25241 L p F P
0 g
s
.003 .285 .783 r
.80337 .08166 m .80472 .08269 L .80651 .08711 L p F P
0 g
s
0 .15 .694 r
.80865 .08672 m .8104 .09115 L .80651 .08711 L p F P
0 g
s
0 .15 .694 r
.80651 .08711 m .80472 .08269 L .80865 .08672 L p F P
0 g
s
.91 .921 .812 r
.79263 .24204 m .79093 .24093 L .79239 .23911 L closepath p F P
0 g
s
.982 .907 .645 r
.82069 .18172 m .82059 .1817 L .82066 .18154 L closepath p F P
0 g
s
0 0 .541 r
.81334 .09554 m .81497 .09999 L .81206 .09559 L p F P
0 g
s
0 0 .541 r
.81206 .09559 m .8104 .09115 L .81334 .09554 L p F P
0 g
s
.877 .916 .85 r
.77194 .26248 m .77215 .2671 L .7796 .25911 L p F P
0 g
s
.877 .916 .85 r
.77891 .25506 m .77194 .26248 L p .7796 .25911 L F P
0 g
s
.877 .916 .85 r
.7796 .25911 m .77953 .2555 L .77891 .25506 L p F P
0 g
s
.859 .814 .804 r
.65472 .11426 m .65971 .10854 L .66237 .11269 L p F P
0 g
s
.859 .814 .804 r
.66237 .11269 m .65776 .11797 L .65472 .11426 L p F P
0 g
s
.982 .904 .648 r
.81808 .18104 m .81979 .17699 L .82066 .18154 L p F P
0 g
s
.982 .904 .648 r
.82066 .18154 m .82059 .1817 L .81808 .18104 L p F P
0 g
s
.98 .91 .652 r
.81777 .188 m .82059 .1817 L .81808 .18104 L p F P
0 g
s
.107 .24 .72 r
.61694 .31865 m .61693 .32333 L .61229 .31921 L p F P
0 g
s
.107 .24 .72 r
.61229 .31921 m .61273 .31439 L .61694 .31865 L p F P
0 g
s
.931 .922 .78 r
.80017 .22352 m .8027 .21988 L .80324 .22446 L p F P
0 g
s
.931 .922 .78 r
.80324 .22446 m .8028 .22509 L .80017 .22352 L p F P
0 g
s
.989 .834 .455 r
.60843 .26966 m .60938 .27339 L .61055 .26747 L p F P
0 g
s
.989 .834 .455 r
.61055 .26747 m .61035 .26668 L .60843 .26966 L p F P
0 g
s
.922 .832 .739 r
.63678 .15464 m .63366 .15988 L .63602 .16406 L p F P
0 g
s
.922 .832 .739 r
.62962 .16667 m .63193 .17087 L .63602 .16406 L p F P
0 g
s
.922 .832 .739 r
.63602 .16406 m .63366 .15988 L .62962 .16667 L p F P
0 g
s
.927 .926 .787 r
.79798 .23173 m .8028 .22509 L .80017 .22352 L p F P
0 g
s
.962 .76 .315 r
.82311 .13929 m .82434 .14379 L .82472 .1382 L p F P
0 g
s
.962 .76 .315 r
.82472 .1382 m .8235 .1337 L .82311 .13929 L p F P
0 g
s
.982 .81 .408 r
.82508 .14674 m .82364 .14844 L .82434 .14379 L closepath p F P
0 g
s
.73 .819 .92 r
.67139 .33486 m .66513 .33811 L .66211 .33501 L p F P
0 g
s
.692 .808 .937 r
.64965 .34023 m .66211 .33501 L .66513 .33811 L p F P
0 g
s
.84 .9 .88 r
.74548 .29305 m .74512 .29277 L .74548 .29245 L closepath p F P
0 g
s
.622 .756 .942 r
.63408 .33997 m .64659 .33671 L .64965 .34023 L p F P
0 g
s
.598 .738 .942 r
.64659 .33671 m .63408 .33997 L .63097 .33567 L p F P
0 g
s
.825 .889 .889 r
.73462 .30153 m .73284 .30298 L .73 .30066 L p F P
0 g
s
.543 .683 .93 r
.76826 .05901 m .76542 .05927 L .76254 .05505 L p F P
0 g
s
.875 .912 .851 r
.76678 .26782 m .77194 .26248 L .77215 .2671 L p F P
0 g
s
.875 .912 .851 r
.77215 .2671 m .76952 .26981 L .76678 .26782 L p F P
0 g
s
.88 .814 .779 r
.65602 .12025 m .65776 .11797 L .65472 .11426 L p F P
0 g
s
.83 .893 .886 r
.73462 .30153 m .74512 .29277 L .7423 .29052 L p F P
0 g
s
.83 .893 .886 r
.7423 .29052 m .73466 .29688 L .73462 .30153 L p F P
0 g
s
.825 .889 .889 r
.73 .30066 m .73466 .29688 L .73462 .30153 L p F P
0 g
s
.868 .913 .859 r
.76397 .27532 m .76952 .26981 L .76678 .26782 L p F P
0 g
s
.776 .861 .913 r
.69303 .32716 m .69292 .32707 L .69304 .32699 L closepath p F P
0 g
s
.732 .776 .888 r
.72594 .0585 m .71887 .06239 L .71593 .05835 L p F P
0 g
s
.776 .856 .91 r
.69304 .32699 m .69292 .32707 L .68997 .32436 L p F P
0 g
s
.756 .852 .922 r
.67755 .33163 m .68997 .32436 L .69292 .32707 L p F P
0 g
s
.868 .913 .859 r
.76678 .26782 m .76391 .27066 L .76397 .27532 L p F P
0 g
s
.862 .909 .864 r
.75519 .27907 m .76391 .27066 L .76397 .27532 L p F P
0 g
s
.862 .909 .864 r
.75523 .28016 m .75519 .27907 L p .76397 .27532 L F P
0 g
s
.862 .909 .864 r
.76397 .27532 m .75734 .28172 L .75523 .28016 L p F P
0 g
s
.776 .856 .91 r
.68997 .32436 m .69313 .32234 L .69304 .32699 L p F P
0 g
s
.777 .858 .911 r
.69304 .32699 m .70529 .3189 L .70238 .31633 L p F P
0 g
s
.777 .858 .911 r
.70238 .31633 m .69313 .32234 L .69304 .32699 L p F P
0 g
s
.88 .814 .779 r
.6478 .12339 m .65047 .12753 L .65602 .12025 L p F P
0 g
s
.88 .814 .779 r
.65602 .12025 m .65332 .11611 L .6478 .12339 L p F P
0 g
s
.88 .814 .779 r
.65472 .11426 m .65332 .11611 L .65602 .12025 L p F P
0 g
s
.977 .853 .46 r
.60831 .26895 m .60843 .26966 L .61035 .26668 L p F P
0 g
s
.977 .853 .46 r
.61035 .26668 m .60974 .26295 L .60831 .26895 L p F P
0 g
s
.494 .637 .918 r
.62785 .33114 m .62544 .33091 L .62534 .33558 L p F P
0 g
s
.494 .637 .918 r
.62534 .33558 m .63097 .33567 L .62785 .33114 L p F P
0 g
s
.961 .848 .686 r
.62215 .20485 m .62164 .20597 L .62064 .20387 L closepath p F P
0 g
s
.839 .895 .879 r
.74548 .29245 m .74512 .29277 L .7423 .29052 L p F P
0 g
s
.84 .901 .88 r
.74541 .28782 m .74548 .29245 L .75515 .28375 L p F P
0 g
s
.839 .895 .879 r
.7423 .29052 m .74541 .28782 L .74548 .29245 L p F P
0 g
s
.9 .824 .763 r
.63541 .14886 m .63787 .15303 L .64274 .14598 L p F P
0 g
s
.9 .824 .763 r
.64274 .14598 m .64022 .14181 L .63541 .14886 L p F P
0 g
s
.681 .799 .937 r
.66211 .33501 m .64965 .34023 L .64659 .33671 L p F P
0 g
s
.853 .91 .872 r
.75734 .28172 m .75515 .28375 L .75523 .28016 L closepath p F P
0 g
s
.84 .901 .88 r
.75457 .27965 m .74541 .28782 L p .75515 .28375 L F P
0 g
s
.84 .901 .88 r
.75515 .28375 m .75523 .28016 L .75457 .27965 L p F P
0 g
s
.915 .74 .247 r
.60815 .28491 m .60891 .28942 L .60934 .28372 L p F P
0 g
s
.915 .74 .247 r
.60934 .28372 m .60855 .27921 L .60815 .28491 L p F P
0 g
s
0 0 .503 r
.6126 .30972 m .61273 .31439 L .6104 .30954 L p F P
0 g
s
0 0 .503 r
.6104 .30954 m .61043 .30482 L .6126 .30972 L p F P
0 g
s
.961 .925 .718 r
.81186 .20539 m .81158 .20589 L .8115 .20525 L closepath p F P
0 g
s
.967 .846 .671 r
.61688 .20811 m .61884 .21237 L .62164 .20597 L p F P
0 g
s
.967 .846 .671 r
.6191 .20294 m .61688 .20811 L p .62164 .20597 L F P
0 g
s
.967 .846 .671 r
.62164 .20597 m .62064 .20387 L .6191 .20294 L p F P
0 g
s
.947 .924 .753 r
.80671 .20824 m .8073 .21283 L .81158 .20589 L p F P
0 g
s
.947 .924 .753 r
.80927 .20407 m .80671 .20824 L p .81158 .20589 L F P
0 g
s
.947 .924 .753 r
.81158 .20589 m .8115 .20525 L .80927 .20407 L p F P
0 g
s
.927 .926 .787 r
.80017 .22352 m .79757 .22712 L .79798 .23173 L p F P
0 g
s
.918 .922 .8 r
.79191 .23453 m .79239 .23911 L .79798 .23173 L p F P
0 g
s
.918 .922 .8 r
.79798 .23173 m .79757 .22712 L .79191 .23453 L p F P
0 g
s
.384 .58 .918 r
.78129 .063 m .78491 .06363 L .78701 .06799 L p F P
0 g
s
.303 .525 .903 r
.79325 .06608 m .79523 .07048 L .78701 .06799 L p F P
0 g
s
.303 .525 .903 r
.78701 .06799 m .78491 .06363 L .79325 .06608 L p F P
0 g
s
.977 .865 .66 r
.61347 .22512 m .61505 .22947 L .61778 .22308 L p F P
0 g
s
.977 .865 .66 r
.61778 .22308 m .61611 .21875 L .61347 .22512 L p F P
0 g
s
.922 .687 .196 r
.82218 .12921 m .8235 .1337 L .82337 .1283 L p F P
0 g
s
.922 .687 .196 r
.82337 .1283 m .82205 .1238 L .82218 .12921 L p F P
0 g
s
.991 .856 .5 r
.82198 .15553 m .823 .16008 L .82444 .15411 L p F P
0 g
s
.991 .856 .5 r
.82444 .15411 m .82346 .14956 L .82198 .15553 L p F P
0 g
s
.945 .842 .71 r
.62106 .19085 m .62315 .19508 L .62658 .18849 L p F P
0 g
s
.945 .842 .71 r
.62658 .18849 m .62442 .18427 L .62106 .19085 L p F P
0 g
s
.993 .857 .594 r
.61066 .24193 m .61216 .24628 L .61419 .24011 L p F P
0 g
s
.993 .857 .594 r
.61419 .24011 m .61262 .23577 L .61066 .24193 L p F P
0 g
s
.726 .827 .927 r
.67139 .33486 m .67755 .33163 L .67457 .32877 L p F P
0 g
s
.726 .827 .927 r
.67457 .32877 m .67207 .33004 L .67139 .33486 L p F P
0 g
s
.73 .819 .92 r
.66211 .33501 m .67207 .33004 L .67139 .33486 L p F P
0 g
s
.543 .683 .93 r
.76254 .05505 m .76591 .05471 L .76826 .05901 L p F P
0 g
s
.513 .661 .927 r
.77555 .05422 m .76591 .05471 L .76826 .05901 L p F P
0 g
s
.513 .661 .927 r
.76826 .05901 m .77842 .05859 L .77555 .05422 L p F P
0 g
s
.922 .838 .744 r
.62553 .17348 m .62962 .16667 L .63193 .17087 L p F P
0 g
s
.922 .838 .744 r
.62743 .17705 m .62553 .17348 L p .63193 .17087 L F P
0 g
s
.922 .838 .744 r
.63193 .17087 m .6279 .17749 L .62743 .17705 L p F P
0 g
s
.816 .8 .836 r
.68237 .08462 m .679 .08764 L .67599 .08369 L p F P
0 g
s
.842 .804 .814 r
.67398 .09288 m .679 .08764 L .67599 .08369 L p F P
0 g
s
.792 .793 .854 r
.69193 .07594 m .69123 .07649 L .68824 .0725 L p F P
0 g
s
.82 .8 .833 r
.68237 .08462 m .69123 .07649 L .68824 .0725 L p F P
0 g
s
.82 .8 .833 r
.68824 .0725 m .67957 .08047 L .68237 .08462 L p F P
0 g
s
.816 .8 .836 r
.67599 .08369 m .67957 .08047 L .68237 .08462 L p F P
0 g
s
.954 .917 .737 r
.8115 .20525 m .80927 .20407 L .81088 .20133 L closepath p F P
0 g
s
.98 .91 .652 r
.81808 .18104 m .81703 .18342 L .81777 .188 L p F P
0 g
s
.971 .914 .69 r
.81373 .19004 m .8145 .1946 L .81777 .188 L p F P
0 g
s
.971 .914 .69 r
.81777 .188 m .81703 .18342 L .81373 .19004 L p F P
0 g
s
.796 .794 .851 r
.69193 .07594 m .70353 .06673 L .70056 .06269 L p F P
0 g
s
.796 .794 .851 r
.70056 .06269 m .68917 .07177 L .69193 .07594 L p F P
0 g
s
.792 .793 .854 r
.68824 .0725 m .68917 .07177 L .69193 .07594 L p F P
0 g
s
.99 .89 .606 r
.81882 .17247 m .81979 .17699 L .82206 .17074 L p F P
0 g
s
.99 .89 .606 r
.82206 .17074 m .82111 .1662 L .81882 .17247 L p F P
0 g
s
.995 .86 .528 r
.60868 .25848 m .60974 .26295 L .61146 .25685 L p F P
0 g
s
.995 .86 .528 r
.61146 .25685 m .61031 .25241 L .60868 .25848 L p F P
0 g
s
.878 .817 .784 r
.64266 .13003 m .6478 .12339 L .65047 .12753 L p F P
0 g
s
.878 .817 .784 r
.65047 .12753 m .64572 .13365 L .64266 .13003 L p F P
0 g
s
.735 .775 .886 r
.72594 .0585 m .73136 .05547 L .72843 .05138 L p F P
0 g
s
.735 .775 .886 r
.72843 .05138 m .72328 .05428 L .72594 .0585 L p F P
0 g
s
.732 .776 .888 r
.71593 .05835 m .72328 .05428 L .72594 .0585 L p F P
0 g
s
.842 .804 .814 r
.67599 .08369 m .67116 .08875 L .67398 .09288 L p F P
0 g
s
.838 .804 .818 r
.66381 .09627 m .67116 .08875 L .67398 .09288 L p F P
0 g
s
.838 .804 .818 r
.67398 .09288 m .66683 .10017 L .66381 .09627 L p F P
0 g
s
.852 .582 .044 r
.82064 .11932 m .82205 .1238 L .82134 .1186 L p F P
0 g
s
.852 .582 .044 r
.82134 .1186 m .81993 .11412 L .82064 .11932 L p F P
0 g
s
.901 .828 .765 r
.63371 .15135 m .63541 .14886 L .63787 .15303 L p F P
0 g
s
.901 .828 .765 r
.63787 .15303 m .63678 .15464 L .63371 .15135 L p F P
0 g
s
.008 .295 .79 r
.80472 .08269 m .80337 .08166 L .80048 .07656 L p F P
0 g
s
0 0 .194 r
.61 .30023 m .61043 .30482 L .60944 .29956 L p F P
0 g
s
0 0 .194 r
.60944 .29956 m .60906 .29494 L .61 .30023 L p F P
0 g
s
.793 .868 .904 r
.70902 .31629 m .70529 .3189 L .70238 .31633 L p F P
0 g
s
.909 .917 .812 r
.78825 .23912 m .79191 .23453 L .79239 .23911 L p F P
0 g
s
.909 .917 .812 r
.79239 .23911 m .79093 .24093 L .78825 .23912 L p F P
0 g
s
.86 .806 .796 r
.66618 .10094 m .66683 .10017 L .66381 .09627 L p F P
0 g
s
.977 .802 .387 r
.60744 .27479 m .60855 .27921 L .60938 .27339 L p F P
0 g
s
.977 .802 .387 r
.60799 .27085 m .60744 .27479 L p .60938 .27339 L F P
0 g
s
.977 .802 .387 r
.60938 .27339 m .60843 .26966 L .60799 .27085 L p F P
0 g
s
.918 .824 .737 r
.63366 .15988 m .63678 .15464 L .63371 .15135 L p F P
0 g
s
.86 .806 .796 r
.66381 .09627 m .66334 .09682 L .66618 .10094 L p F P
0 g
s
.86 .806 .796 r
.65688 .10442 m .65971 .10854 L .66618 .10094 L p F P
0 g
s
.86 .806 .796 r
.66618 .10094 m .66334 .09682 L .65688 .10442 L p F P
0 g
s
.764 .785 .87 r
.7041 .06635 m .70353 .06673 L .70056 .06269 L p F P
0 g
s
.904 .92 .819 r
.78611 .24672 m .79093 .24093 L .78825 .23912 L p F P
0 g
s
.764 .785 .87 r
.70056 .06269 m .70136 .06216 L .7041 .06635 L p F P
0 g
s
.767 .786 .868 r
.7041 .06635 m .71593 .05835 L .71298 .05428 L p F P
0 g
s
.767 .786 .868 r
.71298 .05428 m .70136 .06216 L .7041 .06635 L p F P
0 g
s
.753 .847 .922 r
.68997 .32436 m .67755 .33163 L .67457 .32877 L p F P
0 g
s
.184 .426 .859 r
.79759 .07159 m .79523 .07048 L .7971 .0749 L p F P
0 g
s
.184 .426 .859 r
.7971 .0749 m .80048 .07656 L .79759 .07159 L p F P
0 g
s
.941 .921 .764 r
.80206 .21532 m .8027 .21988 L .8073 .21283 L p F P
0 g
s
.941 .921 .764 r
.8073 .21283 m .80671 .20824 L .80206 .21532 L p F P
0 g
s
.795 .873 .905 r
.70902 .31629 m .71766 .31011 L .71477 .30765 L p F P
0 g
s
.795 .873 .905 r
.71477 .30765 m .70917 .31161 L .70902 .31629 L p F P
0 g
s
.793 .868 .904 r
.70238 .31633 m .70917 .31161 L .70902 .31629 L p F P
0 g
s
.985 .811 .413 r
.82224 .14506 m .82311 .13929 L .82434 .14379 L p F P
0 g
s
.985 .811 .413 r
.82328 .14883 m .82224 .14506 L p .82434 .14379 L F P
0 g
s
.985 .811 .413 r
.82434 .14379 m .82364 .14844 L .82328 .14883 L p F P
0 g
s
.626 .725 .918 r
.74688 .05427 m .75966 .05084 L .76254 .05505 L p F P
0 g
s
.628 .727 .919 r
.75966 .05084 m .74688 .05427 L .74398 .05014 L p F P
0 g
s
.688 .755 .903 r
.73136 .05547 m .74398 .05014 L .74688 .05427 L p F P
0 g
s
.897 .815 .759 r
.64493 .13481 m .64572 .13365 L .64266 .13003 L p F P
0 g
s
.388 .586 .921 r
.78491 .06363 m .78129 .063 L .77842 .05859 L p F P
0 g
s
.738 .437 0 r
.81842 .10965 m .81993 .11412 L .81858 .10916 L p F P
0 g
s
.738 .437 0 r
.81858 .10916 m .81706 .10469 L .81842 .10965 L p F P
0 g
s
.689 .756 .903 r
.74398 .05014 m .73136 .05547 L .72843 .05138 L p F P
0 g
s
.957 .862 .704 r
.62064 .20387 m .6191 .20294 L .61973 .20169 L closepath p F P
0 g
s
.897 .815 .759 r
.64266 .13003 m .64221 .13069 L .64493 .13481 L p F P
0 g
s
.898 .815 .757 r
.63754 .13769 m .64022 .14181 L .64493 .13481 L p F P
0 g
s
.898 .815 .757 r
.64493 .13481 m .64221 .13069 L .63754 .13769 L p F P
0 g
s
.887 .914 .838 r
.77953 .2555 m .77891 .25506 L .77946 .25446 L closepath p F P
0 g
s
.97 .849 .666 r
.61421 .21448 m .61611 .21875 L .61884 .21237 L p F P
0 g
s
.97 .849 .666 r
.61884 .21237 m .61688 .20811 L .61421 .21448 L p F P
0 g
s
.948 .846 .709 r
.61771 .19743 m .61973 .20169 L .62315 .19508 L p F P
0 g
s
.948 .846 .709 r
.62315 .19508 m .62106 .19085 L .61771 .19743 L p F P
0 g
s
.936 .83 .716 r
.6279 .17749 m .6278 .17769 L .62743 .17705 L closepath p F P
0 g
s
.981 .871 .652 r
.61092 .23147 m .61347 .22512 L .61505 .22947 L p F P
0 g
s
.981 .871 .652 r
.61144 .23295 m .61092 .23147 L p .61505 .22947 L F P
0 g
s
.981 .871 .652 r
.61505 .22947 m .61345 .23341 L .61144 .23295 L p F P
0 g
s
.904 .92 .819 r
.78825 .23912 m .78577 .24211 L .78611 .24672 L p F P
0 g
s
.896 .916 .829 r
.77903 .24988 m .77946 .25446 L .78611 .24672 L p F P
0 g
s
.896 .916 .829 r
.78611 .24672 m .78577 .24211 L .77903 .24988 L p F P
0 g
s
.941 .83 .706 r
.62207 .18009 m .62442 .18427 L .6278 .17769 L p F P
0 g
s
.941 .83 .706 r
.62484 .17466 m .62207 .18009 L p .6278 .17769 L F P
0 g
s
.941 .83 .706 r
.6278 .17769 m .62743 .17705 L .62484 .17466 L p F P
0 g
s
0 0 .343 r
.81545 .10023 m .81706 .10469 L .81497 .09999 L p F P
0 g
s
0 0 .343 r
.81497 .09999 m .81334 .09554 L .81545 .10023 L p F P
0 g
s
.008 .295 .79 r
.80048 .07656 m .80282 .07829 L .80472 .08269 L p F P
0 g
s
0 .151 .694 r
.8068 .08231 m .80865 .08672 L .80472 .08269 L p F P
0 g
s
0 .151 .694 r
.80472 .08269 m .80282 .07829 L .8068 .08231 L p F P
0 g
s
.598 .738 .942 r
.63097 .33567 m .64352 .33306 L .64659 .33671 L p F P
0 g
s
.568 .717 .942 r
.64352 .33306 m .63097 .33567 L .62785 .33114 L p F P
0 g
s
.857 .807 .801 r
.65167 .11041 m .65688 .10442 L .65971 .10854 L p F P
0 g
s
.857 .807 .801 r
.65971 .10854 m .65472 .11426 L .65167 .11041 L p F P
0 g
s
0 0 .537 r
.81161 .0911 m .81334 .09554 L .8104 .09115 L p F P
0 g
s
0 0 .537 r
.8104 .09115 m .80865 .08672 L .81161 .0911 L p F P
0 g
s
.809 .878 .897 r
.72267 .30632 m .71766 .31011 L .71477 .30765 L p F P
0 g
s
.963 .914 .714 r
.81007 .19679 m .81088 .20133 L .8145 .1946 L p F P
0 g
s
.963 .914 .714 r
.8145 .1946 m .81373 .19004 L .81007 .19679 L p F P
0 g
s
.993 .876 .564 r
.82008 .16167 m .82111 .1662 L .823 .16008 L p F P
0 g
s
.993 .876 .564 r
.823 .16008 m .82198 .15553 L .82008 .16167 L p F P
0 g
s
.838 .64 .095 r
.6083 .29044 m .60906 .29494 L .60891 .28942 L p F P
0 g
s
.838 .64 .095 r
.60891 .28942 m .60815 .28491 L .6083 .29044 L p F P
0 g
s
.997 .854 .57 r
.60888 .24805 m .61031 .25241 L .61216 .24628 L p F P
0 g
s
.997 .854 .57 r
.61216 .24628 m .61066 .24193 L .60888 .24805 L p F P
0 g
s
.546 .686 .931 r
.76591 .05471 m .76254 .05505 L .75966 .05084 L p F P
0 g
s
.918 .824 .737 r
.63371 .15135 m .63112 .15573 L .63366 .15988 L p F P
0 g
s
.919 .824 .736 r
.62713 .16251 m .62962 .16667 L .63366 .15988 L p F P
0 g
s
.919 .824 .736 r
.63366 .15988 m .63112 .15573 L .62713 .16251 L p F P
0 g
s
.927 .839 .738 r
.62743 .17705 m .62484 .17466 L .62553 .17348 L closepath p F P
0 g
s
.983 .9 .646 r
.81614 .17888 m .81882 .17247 L .81979 .17699 L p F P
0 g
s
.983 .9 .646 r
.81651 .18058 m .81614 .17888 L p .81979 .17699 L F P
0 g
s
.983 .9 .646 r
.81979 .17699 m .81808 .18104 L .81651 .18058 L p F P
0 g
s
.723 .811 .92 r
.67207 .33004 m .66211 .33501 L .65909 .3318 L p F P
0 g
s
.681 .799 .937 r
.64659 .33671 m .65909 .3318 L .66211 .33501 L p F P
0 g
s
.813 .883 .896 r
.72267 .30632 m .73 .30066 L .72714 .29828 L p F P
0 g
s
.813 .883 .896 r
.72714 .29828 m .72275 .30165 L .72267 .30632 L p F P
0 g
s
.809 .878 .897 r
.71477 .30765 m .72275 .30165 L .72267 .30632 L p F P
0 g
s
.878 .808 .777 r
.65332 .11611 m .65472 .11426 L .65167 .11041 L p F P
0 g
s
.969 .762 .328 r
.82179 .1348 m .82311 .13929 L .8235 .1337 L p F P
0 g
s
.969 .762 .328 r
.8235 .1337 m .82218 .12921 L .82179 .1348 L p F P
0 g
s
.886 .909 .837 r
.77618 .25303 m .77903 .24988 L .77946 .25446 L p F P
0 g
s
.886 .909 .837 r
.77946 .25446 m .77891 .25506 L .77618 .25303 L p F P
0 g
s
.88 .911 .844 r
.77194 .26248 m .77891 .25506 L .77618 .25303 L p F P
0 g
s
.932 .918 .779 r
.79752 .22188 m .80206 .21532 L .8027 .21988 L p F P
0 g
s
.932 .918 .779 r
.8027 .21988 m .80017 .22352 L .79752 .22188 L p F P
0 g
s
.732 .774 .886 r
.72328 .05428 m .71593 .05835 L .71298 .05428 L p F P
0 g
s
.99 .846 .477 r
.60733 .26447 m .60831 .26895 L .60974 .26295 L p F P
0 g
s
.99 .846 .477 r
.60974 .26295 m .60868 .25848 L .60733 .26447 L p F P
0 g
s
.287 .478 .872 r
.62154 .32102 m .61694 .31865 L .61693 .32333 L p F P
0 g
s
.287 .478 .872 r
.61693 .32333 m .6247 .32634 L .62154 .32102 L p F P
0 g
s
.853 .901 .869 r
.75523 .28016 m .75457 .27965 L .75519 .27907 L closepath p F P
0 g
s
.878 .808 .777 r
.65167 .11041 m .65047 .11201 L .65332 .11611 L p F P
0 g
s
.878 .808 .777 r
.64496 .11929 m .6478 .12339 L .65332 .11611 L p F P
0 g
s
.878 .808 .777 r
.65332 .11611 m .65047 .11201 L .64496 .11929 L p F P
0 g
s
.669 .789 .938 r
.65909 .3318 m .64659 .33671 L .64352 .33306 L p F P
0 g
s
.897 .816 .76 r
.63276 .14473 m .63541 .14886 L .64022 .14181 L p F P
0 g
s
.897 .816 .76 r
.64022 .14181 m .63754 .13769 L .63276 .14473 L p F P
0 g
s
.824 .886 .888 r
.73466 .29688 m .73 .30066 L .72714 .29828 L p F P
0 g
s
.003 .179 .694 r
.61643 .31411 m .61694 .31865 L .61273 .31439 L p F P
0 g
s
.003 .179 .694 r
.61273 .31439 m .6126 .30972 L .61643 .31411 L p F P
0 g
s
.986 .851 .622 r
.61345 .23341 m .61262 .23577 L .61144 .23295 L closepath p F P
0 g
s
.88 .911 .844 r
.77618 .25303 m .77165 .25787 L .77194 .26248 L p F P
0 g
s
.874 .908 .85 r
.76402 .26577 m .77165 .25787 L .77194 .26248 L p F P
0 g
s
.874 .908 .85 r
.77194 .26248 m .76678 .26782 L .76402 .26577 L p F P
0 g
s
.772 .851 .91 r
.69313 .32234 m .68997 .32436 L .68702 .32158 L p F P
0 g
s
.753 .847 .922 r
.67457 .32877 m .68702 .32158 L .68997 .32436 L p F P
0 g
s
.829 .89 .886 r
.73466 .29688 m .7423 .29052 L .73948 .28821 L p F P
0 g
s
.829 .89 .886 r
.73948 .28821 m .73462 .29223 L .73466 .29688 L p F P
0 g
s
.824 .886 .888 r
.72714 .29828 m .73462 .29223 L .73466 .29688 L p F P
0 g
s
.927 .922 .786 r
.79757 .22712 m .80017 .22352 L .79752 .22188 L p F P
0 g
s
.983 .817 .418 r
.82364 .14844 m .82346 .14956 L .82328 .14883 L closepath p F P
0 g
s
.388 .586 .921 r
.77842 .05859 m .78271 .05929 L .78491 .06363 L p F P
0 g
s
.304 .53 .906 r
.79117 .06169 m .79325 .06608 L .78491 .06363 L p F P
0 g
s
.304 .53 .906 r
.78491 .06363 m .78271 .05929 L .79117 .06169 L p F P
0 g
s
.867 .909 .858 r
.76391 .27066 m .76678 .26782 L .76402 .26577 L p F P
0 g
s
.952 .851 .705 r
.61604 .20079 m .61771 .19743 L .61973 .20169 L p F P
0 g
s
.952 .851 .705 r
.61973 .20169 m .6191 .20294 L .61604 .20079 L p F P
0 g
s
.867 .909 .858 r
.76402 .26577 m .76377 .26601 L .76391 .27066 L p F P
0 g
s
.859 .904 .865 r
.7549 .27448 m .75519 .27907 L .76391 .27066 L p F P
0 g
s
.859 .904 .865 r
.76391 .27066 m .76377 .26601 L .7549 .27448 L p F P
0 g
s
.838 .892 .878 r
.74541 .28782 m .7423 .29052 L .73948 .28821 L p F P
0 g
s
.942 .832 .707 r
.61876 .18666 m .62106 .19085 L .62442 .18427 L p F P
0 g
s
.942 .832 .707 r
.62442 .18427 m .62207 .18009 L .61876 .18666 L p F P
0 g
s
.949 .753 .291 r
.60705 .28049 m .60815 .28491 L .60855 .27921 L p F P
0 g
s
.949 .753 .291 r
.60855 .27921 m .60744 .27479 L .60705 .28049 L p F P
0 g
s
.012 .304 .796 r
.80282 .07829 m .80048 .07656 L .79759 .07159 L p F P
0 g
s
.844 .896 .875 r
.74541 .28782 m .75457 .27965 L .75177 .27738 L p F P
0 g
s
.844 .896 .875 r
.75177 .27738 m .74524 .2832 L .74541 .28782 L p F P
0 g
s
.838 .892 .878 r
.73948 .28821 m .74524 .2832 L .74541 .28782 L p F P
0 g
s
.932 .692 .211 r
.82077 .12473 m .82218 .12921 L .82205 .1238 L p F P
0 g
s
.932 .692 .211 r
.82205 .1238 m .82064 .11932 L .82077 .12473 L p F P
0 g
s
.772 .851 .91 r
.68702 .32158 m .6932 .31769 L .69313 .32234 L p F P
0 g
s
.773 .855 .912 r
.69313 .32234 m .70238 .31633 L .69945 .31368 L p F P
0 g
s
.773 .855 .912 r
.69945 .31368 m .6932 .31769 L .69313 .32234 L p F P
0 g
s
.974 .852 .658 r
.61164 .22083 m .61347 .22512 L .61611 .21875 L p F P
0 g
s
.974 .852 .658 r
.61611 .21875 m .61421 .21448 L .61164 .22083 L p F P
0 g
s
.98 .906 .656 r
.81808 .18104 m .81703 .18342 L .81651 .18058 L closepath p F P
0 g
s
.546 .686 .931 r
.75966 .05084 m .76346 .05043 L .76591 .05471 L p F P
0 g
s
.517 .666 .929 r
.77267 .04989 m .76346 .05043 L .76591 .05471 L p F P
0 g
s
.517 .666 .929 r
.76591 .05471 m .77555 .05422 L .77267 .04989 L p F P
0 g
s
.454 .603 .909 r
.62544 .33091 m .62502 .32685 L .62785 .33114 L closepath p F P
0 g
s
.852 .896 .868 r
.75177 .27738 m .7549 .27448 L .75519 .27907 L p F P
0 g
s
.852 .896 .868 r
.75519 .27907 m .75457 .27965 L .75177 .27738 L p F P
0 g
s
.815 .795 .834 r
.67957 .08047 m .67599 .08369 L .67297 .07965 L p F P
0 g
s
.84 .799 .812 r
.67116 .08875 m .67599 .08369 L .67297 .07965 L p F P
0 g
s
.994 .855 .513 r
.82088 .151 m .82198 .15553 L .82346 .14956 L p F P
0 g
s
.994 .855 .513 r
.82127 .14935 m .82088 .151 L p .82346 .14956 L F P
0 g
s
.994 .855 .513 r
.82346 .14956 m .82328 .14883 L .82127 .14935 L p F P
0 g
s
.791 .79 .851 r
.68917 .07177 m .68824 .0725 L .68524 .06843 L p F P
0 g
s
.819 .796 .83 r
.67957 .08047 m .68824 .0725 L .68524 .06843 L p F P
0 g
s
.819 .796 .83 r
.68524 .06843 m .67663 .07635 L .67957 .08047 L p F P
0 g
s
.815 .795 .834 r
.67297 .07965 m .67663 .07635 L .67957 .08047 L p F P
0 g
s
.953 .914 .737 r
.80666 .20262 m .81007 .19679 L .81088 .20133 L p F P
0 g
s
.953 .914 .737 r
.81088 .20133 m .80927 .20407 L .80666 .20262 L p F P
0 g
s
.963 .838 .673 r
.61688 .20811 m .6191 .20294 L .61604 .20079 L p F P
0 g
s
.794 .791 .849 r
.68917 .07177 m .70056 .06269 L .69758 .0586 L p F P
0 g
s
.794 .791 .849 r
.69758 .0586 m .68624 .06764 L .68917 .07177 L p F P
0 g
s
.791 .79 .851 r
.68524 .06843 m .68624 .06764 L .68917 .07177 L p F P
0 g
s
.992 .845 .596 r
.60891 .23765 m .61066 .24193 L .61262 .23577 L p F P
0 g
s
.992 .845 .596 r
.61041 .23285 m .60891 .23765 L p .61262 .23577 L F P
0 g
s
.992 .845 .596 r
.61262 .23577 m .61144 .23295 L .61041 .23285 L p F P
0 g
s
.927 .922 .786 r
.79752 .22188 m .79706 .22252 L .79757 .22712 L p F P
0 g
s
.916 .918 .802 r
.79134 .22996 m .79191 .23453 L .79757 .22712 L p F P
0 g
s
.916 .918 .802 r
.79757 .22712 m .79706 .22252 L .79134 .22996 L p F P
0 g
s
0 0 .437 r
.61201 .30519 m .6126 .30972 L .61043 .30482 L p F P
0 g
s
0 0 .437 r
.61043 .30482 m .61 .30023 L .61201 .30519 L p F P
0 g
s
.919 .826 .738 r
.62308 .16932 m .62553 .17348 L .62962 .16667 L p F P
0 g
s
.919 .826 .738 r
.62962 .16667 m .62713 .16251 L .62308 .16932 L p F P
0 g
s
.875 .809 .781 r
.63959 .12625 m .64496 .11929 L .6478 .12339 L p F P
0 g
s
.875 .809 .781 r
.6478 .12339 m .64266 .13003 L .63959 .12625 L p F P
0 g
s
.735 .774 .884 r
.72328 .05428 m .72843 .05138 L .72549 .04727 L p F P
0 g
s
.735 .774 .884 r
.72549 .04727 m .72051 .05008 L .72328 .05428 L p F P
0 g
s
.732 .774 .886 r
.71298 .05428 m .72051 .05008 L .72328 .05428 L p F P
0 g
s
.84 .799 .812 r
.67297 .07965 m .6682 .08465 L .67116 .08875 L p F P
0 g
s
.836 .799 .816 r
.66076 .09226 m .6682 .08465 L .67116 .08875 L p F P
0 g
s
.836 .799 .816 r
.67116 .08875 m .66381 .09627 L .66076 .09226 L p F P
0 g
s
.99 .887 .613 r
.81776 .16795 m .81882 .17247 L .82111 .1662 L p F P
0 g
s
.99 .887 .613 r
.82111 .1662 m .82008 .16167 L .81776 .16795 L p F P
0 g
s
.968 .91 .701 r
.81285 .1855 m .81373 .19004 L .81703 .18342 L p F P
0 g
s
.968 .91 .701 r
.81554 .18012 m .81285 .1855 L p .81703 .18342 L F P
0 g
s
.968 .91 .701 r
.81703 .18342 m .81651 .18058 L .81554 .18012 L p F P
0 g
s
.897 .819 .762 r
.63063 .14786 m .63276 .14473 L .63541 .14886 L p F P
0 g
s
.897 .819 .762 r
.63541 .14886 m .63371 .15135 L .63063 .14786 L p F P
0 g
s
.996 .843 .499 r
.82328 .14883 m .82127 .14935 L .82224 .14506 L closepath p F P
0 g
s
.95 .918 .745 r
.80671 .20824 m .80927 .20407 L .80666 .20262 L p F P
0 g
s
.998 .849 .538 r
.60731 .2541 m .60868 .25848 L .61031 .25241 L p F P
0 g
s
.998 .849 .538 r
.61031 .25241 m .60888 .24805 L .60731 .2541 L p F P
0 g
s
.957 .814 .376 r
.60843 .26966 m .60799 .27085 L .60831 .26895 L closepath p F P
0 g
s
.858 .801 .794 r
.66334 .09682 m .66381 .09627 L .66076 .09226 L p F P
0 g
s
.726 .829 .929 r
.67457 .32877 m .67207 .33004 L .67264 .32687 L closepath p F P
0 g
s
.723 .811 .92 r
.67157 .32579 m .67264 .32687 L .67207 .33004 L p F P
0 g
s
.723 .811 .92 r
.65909 .3318 m .67157 .32579 L p .67207 .33004 L F P
0 g
s
.866 .589 .06 r
.81913 .11485 m .82064 .11932 L .81993 .11412 L p F P
0 g
s
.866 .589 .06 r
.81993 .11412 m .81842 .10965 L .81913 .11485 L p F P
0 g
s
.764 .782 .868 r
.70136 .06216 m .70056 .06269 L .69758 .0586 L p F P
0 g
s
.858 .801 .794 r
.66076 .09226 m .66036 .09274 L .66334 .09682 L p F P
0 g
s
.858 .801 .794 r
.6539 .10034 m .65688 .10442 L .66334 .09682 L p F P
0 g
s
.858 .801 .794 r
.66334 .09682 m .66036 .09274 L .6539 .10034 L p F P
0 g
s
.764 .782 .868 r
.69758 .0586 m .69845 .05801 L .70136 .06216 L p F P
0 g
s
.767 .783 .867 r
.70136 .06216 m .71298 .05428 L .71001 .05016 L p F P
0 g
s
.767 .783 .867 r
.71001 .05016 m .69845 .05801 L .70136 .06216 L p F P
0 g
s
.391 .591 .924 r
.78271 .05929 m .77842 .05859 L .77555 .05422 L p F P
0 g
s
.628 .727 .919 r
.74398 .05014 m .75677 .04663 L .75966 .05084 L p F P
0 g
s
.629 .729 .919 r
.75677 .04663 m .74398 .05014 L .74107 .046 L p F P
0 g
s
.689 .756 .903 r
.72843 .05138 m .74107 .046 L .74398 .05014 L p F P
0 g
s
.79 .864 .904 r
.70917 .31161 m .70238 .31633 L .69945 .31368 L p F P
0 g
s
.915 .815 .735 r
.63112 .15573 m .63371 .15135 L .63063 .14786 L p F P
0 g
s
.19 .437 .866 r
.79471 .06673 m .79325 .06608 L .79523 .07048 L p F P
0 g
s
.19 .437 .866 r
.79523 .07048 m .79759 .07159 L .79471 .06673 L p F P
0 g
s
.568 .717 .942 r
.62785 .33114 m .64043 .32926 L .64352 .33306 L p F P
0 g
s
.581 .667 .898 r
.62502 .32685 m .62785 .33114 L .64043 .32926 L p F P
0 g
s
.909 .914 .811 r
.78556 .23723 m .79134 .22996 L .79191 .23453 L p F P
0 g
s
.909 .914 .811 r
.79191 .23453 m .78825 .23912 L .78556 .23723 L p F P
0 g
s
.69 .756 .902 r
.74107 .046 m .72843 .05138 L .72549 .04727 L p F P
0 g
s
.893 .808 .757 r
.64221 .13069 m .64266 .13003 L .63959 .12625 L p F P
0 g
s
.702 .478 0 r
.60918 .29575 m .61 .30023 L .60906 .29494 L p F P
0 g
s
.702 .478 0 r
.60906 .29494 m .6083 .29044 L .60918 .29575 L p F P
0 g
s
.754 .836 .914 r
.68404 .31873 m .68702 .32158 L .67457 .32877 L p F P
0 g
s
.754 .836 .914 r
.67254 .32525 m .68404 .31873 L p .67457 .32877 L F P
0 g
s
.754 .836 .914 r
.67457 .32877 m .67264 .32687 L .67254 .32525 L p F P
0 g
s
.975 .819 .407 r
.60634 .27035 m .60733 .26447 L .60831 .26895 L p F P
0 g
s
.975 .819 .407 r
.60695 .27321 m .60634 .27035 L p .60831 .26895 L F P
0 g
s
.975 .819 .407 r
.60831 .26895 m .60799 .27085 L .60695 .27321 L p F P
0 g
s
.893 .808 .757 r
.63959 .12625 m .63934 .12661 L .64221 .13069 L p F P
0 g
s
.895 .808 .755 r
.63468 .13361 m .63754 .13769 L .64221 .13069 L p F P
0 g
s
.895 .808 .755 r
.64221 .13069 m .63934 .12661 L .63468 .13361 L p F P
0 g
s
.991 .81 .428 r
.82091 .14058 m .82224 .14506 L .82311 .13929 L p F P
0 g
s
.991 .81 .428 r
.82311 .13929 m .82179 .1348 L .82091 .14058 L p F P
0 g
s
.755 .445 0 r
.81682 .1052 m .81842 .10965 L .81706 .10469 L p F P
0 g
s
.755 .445 0 r
.81706 .10469 m .81545 .10023 L .81682 .1052 L p F P
0 g
s
.95 .918 .745 r
.80666 .20262 m .80602 .20367 L .80671 .20824 L p F P
0 g
s
.939 .916 .766 r
.80132 .21077 m .80206 .21532 L .80671 .20824 L p F P
0 g
s
.939 .916 .766 r
.80671 .20824 m .80602 .20367 L .80132 .21077 L p F P
0 g
s
.944 .835 .706 r
.61546 .19324 m .61771 .19743 L .62106 .19085 L p F P
0 g
s
.944 .835 .706 r
.62106 .19085 m .61876 .18666 L .61546 .19324 L p F P
0 g
s
.963 .838 .673 r
.61604 .20079 m .6147 .20391 L .61688 .20811 L p F P
0 g
s
.966 .837 .664 r
.61209 .21027 m .61421 .21448 L .61688 .20811 L p F P
0 g
s
.966 .837 .664 r
.61688 .20811 m .6147 .20391 L .61209 .21027 L p F P
0 g
s
.855 .801 .798 r
.64861 .10643 m .6539 .10034 L .65688 .10442 L p F P
0 g
s
.855 .801 .798 r
.65688 .10442 m .65167 .11041 L .64861 .10643 L p F P
0 g
s
.922 .829 .737 r
.62175 .17159 m .62308 .16932 L .62553 .17348 L p F P
0 g
s
.922 .829 .737 r
.62553 .17348 m .62484 .17466 L .62175 .17159 L p F P
0 g
s
.904 .916 .819 r
.78577 .24211 m .78825 .23912 L .78556 .23723 L p F P
0 g
s
.793 .87 .905 r
.70917 .31161 m .71477 .30765 L .71187 .30511 L p F P
0 g
s
.793 .87 .905 r
.71187 .30511 m .70928 .30693 L .70917 .31161 L p F P
0 g
s
.79 .864 .904 r
.69945 .31368 m .70928 .30693 L .70917 .31161 L p F P
0 g
s
.012 .304 .796 r
.79759 .07159 m .80083 .07391 L .80282 .07829 L p F P
0 g
s
0 .152 .694 r
.80485 .07791 m .8068 .08231 L .80282 .07829 L p F P
0 g
s
0 .152 .694 r
.80282 .07829 m .80083 .07391 L .80485 .07791 L p F P
0 g
s
.548 .688 .932 r
.76346 .05043 m .75966 .05084 L .75677 .04663 L p F P
0 g
s
0 0 .332 r
.81374 .09579 m .81545 .10023 L .81334 .09554 L p F P
0 g
s
0 0 .332 r
.81334 .09554 m .81161 .0911 L .81374 .09579 L p F P
0 g
s
.978 .854 .648 r
.60916 .22716 m .61092 .23147 L .61347 .22512 L p F P
0 g
s
.978 .854 .648 r
.61347 .22512 m .61164 .22083 L .60916 .22716 L p F P
0 g
s
.936 .823 .707 r
.62207 .18009 m .62484 .17466 L .62175 .17159 L p F P
0 g
s
0 0 .532 r
.80979 .08668 m .81161 .0911 L .80865 .08672 L p F P
0 g
s
0 0 .532 r
.80865 .08672 m .8068 .08231 L .80979 .08668 L p F P
0 g
s
.915 .815 .735 r
.63063 .14786 m .62841 .15163 L .63112 .15573 L p F P
0 g
s
.915 .815 .734 r
.62444 .15841 m .62713 .16251 L .63112 .15573 L p F P
0 g
s
.915 .815 .734 r
.63112 .15573 m .62841 .15163 L .62444 .15841 L p F P
0 g
s
.987 .803 .41 r
.60799 .27085 m .60744 .27479 L .60695 .27321 L closepath p F P
0 g
s
.904 .916 .819 r
.78556 .23723 m .78533 .2375 L .78577 .24211 L p F P
0 g
s
.893 .911 .83 r
.7785 .24532 m .77903 .24988 L .78577 .24211 L p F P
0 g
s
.893 .911 .83 r
.78577 .24211 m .78533 .2375 L .7785 .24532 L p F P
0 g
s
.994 .874 .573 r
.81894 .15715 m .82008 .16167 L .82198 .15553 L p F P
0 g
s
.994 .874 .573 r
.82198 .15553 m .82088 .151 L .81894 .15715 L p F P
0 g
s
.875 .802 .775 r
.65047 .11201 m .65167 .11041 L .64861 .10643 L p F P
0 g
s
.995 .842 .575 r
.60718 .24375 m .60888 .24805 L .61066 .24193 L p F P
0 g
s
.995 .842 .575 r
.61066 .24193 m .60891 .23765 L .60718 .24375 L p F P
0 g
s
.732 .772 .885 r
.72051 .05008 m .71298 .05428 L .71001 .05016 L p F P
0 g
s
.962 .909 .718 r
.80916 .19226 m .81007 .19679 L .81373 .19004 L p F P
0 g
s
.962 .909 .718 r
.81373 .19004 m .81285 .1855 L .80916 .19226 L p F P
0 g
s
.71 .815 .93 r
.67157 .32579 m .65909 .3318 L .65604 .3285 L p F P
0 g
s
.669 .789 .938 r
.64352 .33306 m .65604 .3285 L .65909 .3318 L p F P
0 g
s
.807 .874 .896 r
.72275 .30165 m .71477 .30765 L .71187 .30511 L p F P
0 g
s
.892 .671 .155 r
.60719 .28603 m .6083 .29044 L .60815 .28491 L p F P
0 g
s
.892 .671 .155 r
.60815 .28491 m .60705 .28049 L .60719 .28603 L p F P
0 g
s
.875 .802 .775 r
.64196 .11523 m .64496 .11929 L .65047 .11201 L p F P
0 g
s
.875 .802 .775 r
.65047 .11201 m .64746 .10795 L .64196 .11523 L p F P
0 g
s
.875 .802 .775 r
.64861 .10643 m .64746 .10795 L .65047 .11201 L p F P
0 g
s
.655 .778 .939 r
.65604 .3285 m .64352 .33306 L .64043 .32926 L p F P
0 g
s
.983 .893 .651 r
.81505 .17438 m .81614 .17888 L .81882 .17247 L p F P
0 g
s
.983 .893 .651 r
.81882 .17247 m .81776 .16795 L .81505 .17438 L p F P
0 g
s
.987 .867 .627 r
.61144 .23295 m .61041 .23285 L .61092 .23147 L closepath p F P
0 g
s
.975 .764 .341 r
.82037 .13033 m .82179 .1348 L .82218 .12921 L p F P
0 g
s
.975 .764 .341 r
.82218 .12921 m .82077 .12473 L .82037 .13033 L p F P
0 g
s
.893 .809 .758 r
.62992 .14065 m .63276 .14473 L .63754 .13769 L p F P
0 g
s
.893 .809 .758 r
.63754 .13769 m .63468 .13361 L .62992 .14065 L p F P
0 g
s
.014 .311 .802 r
.80083 .07391 m .79759 .07159 L .79471 .06673 L p F P
0 g
s
.932 .914 .778 r
.79631 .21798 m .80132 .21077 L .80206 .21532 L p F P
0 g
s
.932 .914 .778 r
.79692 .22148 m .79631 .21798 L p .80206 .21532 L F P
0 g
s
.932 .914 .778 r
.80206 .21532 m .79752 .22188 L .79692 .22148 L p F P
0 g
s
.886 .906 .836 r
.77344 .25093 m .7785 .24532 L .77903 .24988 L p F P
0 g
s
.886 .906 .836 r
.77903 .24988 m .77618 .25303 L .77344 .25093 L p F P
0 g
s
.997 .836 .492 r
.60603 .26007 m .60733 .26447 L .60868 .25848 L p F P
0 g
s
.997 .836 .492 r
.60868 .25848 m .60731 .2541 L .60603 .26007 L p F P
0 g
s
.811 .88 .896 r
.72275 .30165 m .72714 .29828 L .72427 .29583 L p F P
0 g
s
.811 .88 .896 r
.72427 .29583 m .72276 .29698 L .72275 .30165 L p F P
0 g
s
.807 .874 .896 r
.71187 .30511 m .72276 .29698 L .72275 .30165 L p F P
0 g
s
.974 .902 .685 r
.81651 .18058 m .81554 .18012 L .81614 .17888 L closepath p F P
0 g
s
.88 .907 .844 r
.77165 .25787 m .77618 .25303 L .77344 .25093 L p F P
0 g
s
.305 .534 .909 r
.78905 .0575 m .79117 .06169 L .78271 .05929 L p F P
0 g
s
.305 .534 .909 r
.78894 .05732 m .78905 .0575 L p .78271 .05929 L F P
0 g
s
.305 .534 .909 r
.78271 .05929 m .78041 .05496 L .78894 .05732 L p F P
0 g
s
.391 .591 .924 r
.77555 .05422 m .78041 .05496 L .78271 .05929 L p F P
0 g
s
.216 .419 .846 r
.61835 .31537 m .61643 .31411 L .61694 .31865 L p F P
0 g
s
.216 .419 .846 r
.61694 .31865 m .62154 .32102 L .61835 .31537 L p F P
0 g
s
.769 .846 .91 r
.6932 .31769 m .68702 .32158 L .68404 .31873 L p F P
0 g
s
.823 .882 .887 r
.73462 .29223 m .72714 .29828 L .72427 .29583 L p F P
0 g
s
.548 .688 .932 r
.75677 .04663 m .76091 .04617 L .76346 .05043 L p F P
0 g
s
.52 .67 .931 r
.76979 .04559 m .76091 .04617 L .76346 .05043 L p F P
0 g
s
.52 .67 .931 r
.76346 .05043 m .77267 .04989 L .76979 .04559 L p F P
0 g
s
.947 .839 .704 r
.61295 .19832 m .61546 .19324 L .61771 .19743 L p F P
0 g
s
.947 .839 .704 r
.61771 .19743 m .61604 .20079 L .61295 .19832 L p F P
0 g
s
.936 .823 .707 r
.62175 .17159 m .61953 .17596 L .62207 .18009 L p F P
0 g
s
.938 .822 .704 r
.61625 .18253 m .61876 .18666 L .62207 .18009 L p F P
0 g
s
.938 .822 .704 r
.62207 .18009 m .61953 .17596 L .61625 .18253 L p F P
0 g
s
.88 .907 .844 r
.77344 .25093 m .77125 .25327 L .77165 .25787 L p F P
0 g
s
.874 .904 .849 r
.76329 .26145 m .77125 .25327 L .77165 .25787 L p F P
0 g
s
.874 .904 .849 r
.76374 .26555 m .76329 .26145 L p .77165 .25787 L F P
0 g
s
.874 .904 .849 r
.77165 .25787 m .76402 .26577 L .76374 .26555 L p F P
0 g
s
0 .104 .651 r
.6157 .31043 m .61643 .31411 L .6126 .30972 L p F P
0 g
s
0 .104 .651 r
.61515 .30926 m .6157 .31043 L p .6126 .30972 L F P
0 g
s
0 .104 .651 r
.6126 .30972 m .61201 .30519 L .61515 .30926 L p F P
0 g
s
.97 .839 .657 r
.60957 .21661 m .61164 .22083 L .61421 .21448 L p F P
0 g
s
.97 .839 .657 r
.61421 .21448 m .61209 .21027 L .60957 .21661 L p F P
0 g
s
.941 .696 .226 r
.81926 .12027 m .82077 .12473 L .82064 .11932 L p F P
0 g
s
.941 .696 .226 r
.82064 .11932 m .81913 .11485 L .81926 .12027 L p F P
0 g
s
.745 .829 .916 r
.67264 .32687 m .67157 .32579 L .67254 .32525 L closepath p F P
0 g
s
.872 .802 .779 r
.6365 .1223 m .64196 .11523 L .64496 .11929 L p F P
0 g
s
.872 .802 .779 r
.64496 .11929 m .63959 .12625 L .6365 .1223 L p F P
0 g
s
.504 .614 .894 r
.6247 .32634 m .62513 .32635 L .62502 .32685 L closepath p F P
0 g
s
.581 .667 .898 r
.63733 .32532 m .62513 .32635 L .62502 .32685 L p F P
0 g
s
.581 .667 .898 r
.64043 .32926 m .63733 .32532 L p .62502 .32685 L F P
0 g
s
.735 .773 .883 r
.72051 .05008 m .72549 .04727 L .72255 .04312 L p F P
0 g
s
.735 .773 .883 r
.72255 .04312 m .71761 .04591 L .72051 .05008 L p F P
0 g
s
.732 .772 .885 r
.71001 .05016 m .71761 .04591 L .72051 .05008 L p F P
0 g
s
.915 .817 .735 r
.62043 .16521 m .62308 .16932 L .62713 .16251 L p F P
0 g
s
.915 .817 .735 r
.62713 .16251 m .62444 .15841 L .62043 .16521 L p F P
0 g
s
.827 .887 .886 r
.73462 .29223 m .73948 .28821 L .73664 .28583 L p F P
0 g
s
.827 .887 .886 r
.73664 .28583 m .7345 .28759 L .73462 .29223 L p F P
0 g
s
.823 .882 .887 r
.72427 .29583 m .7345 .28759 L .73462 .29223 L p F P
0 g
s
.997 .842 .503 r
.81958 .14652 m .82091 .14058 L .82224 .14506 L p F P
0 g
s
.997 .842 .503 r
.82047 .14951 m .81958 .14652 L p .82224 .14506 L F P
0 g
s
.997 .842 .503 r
.82224 .14506 m .82127 .14935 L .82047 .14951 L p F P
0 g
s
.968 .76 .324 r
.60614 .27758 m .60705 .28049 L .60744 .27479 L p F P
0 g
s
.968 .76 .324 r
.60744 .27479 m .60695 .27321 L .60614 .27758 L p F P
0 g
s
.984 .856 .634 r
.60736 .23206 m .60916 .22716 L .61092 .23147 L p F P
0 g
s
.984 .856 .634 r
.61092 .23147 m .61041 .23285 L .60736 .23206 L p F P
0 g
s
.837 .888 .877 r
.74524 .2832 m .73948 .28821 L .73664 .28583 L p F P
0 g
s
.866 .905 .857 r
.76402 .26577 m .76377 .26601 L .76374 .26555 L closepath p F P
0 g
s
.852 .897 .867 r
.75451 .2699 m .7549 .27448 L .76377 .26601 L p F P
0 g
s
.852 .897 .867 r
.76124 .26349 m .75451 .2699 L p .76377 .26601 L F P
0 g
s
.852 .897 .867 r
.76377 .26601 m .76374 .26555 L .76124 .26349 L p F P
0 g
s
.46 .58 .888 r
.62513 .32635 m .6247 .32634 L .62154 .32102 L p F P
0 g
s
.953 .909 .736 r
.80513 .19914 m .80916 .19226 L .81007 .19679 L p F P
0 g
s
.953 .909 .736 r
.80574 .20207 m .80513 .19914 L p .81007 .19679 L F P
0 g
s
.953 .909 .736 r
.81007 .19679 m .80666 .20262 L .80574 .20207 L p F P
0 g
s
.843 .892 .874 r
.74524 .2832 m .75177 .27738 L .74896 .27506 L p F P
0 g
s
.843 .892 .874 r
.74896 .27506 m .74498 .2786 L .74524 .2832 L p F P
0 g
s
.837 .888 .877 r
.73664 .28583 m .74498 .2786 L .74524 .2832 L p F P
0 g
s
.926 .917 .787 r
.79752 .22188 m .79706 .22252 L .79692 .22148 L closepath p F P
0 g
s
.894 .811 .759 r
.62754 .14417 m .62992 .14065 L .63276 .14473 L p F P
0 g
s
.894 .811 .759 r
.63276 .14473 m .63063 .14786 L .62754 .14417 L p F P
0 g
s
.851 .893 .867 r
.74896 .27506 m .75451 .2699 L .7549 .27448 L p F P
0 g
s
.851 .893 .867 r
.7549 .27448 m .75177 .27738 L .74896 .27506 L p F P
0 g
s
.394 .595 .926 r
.78041 .05496 m .77555 .05422 L .77267 .04989 L p F P
0 g
s
.46 .58 .888 r
.62154 .32102 m .62573 .32147 L .62513 .32635 L p F P
0 g
s
.537 .687 .935 r
.63421 .32124 m .62573 .32147 L .62513 .32635 L p F P
0 g
s
.537 .687 .935 r
.62513 .32635 m .63733 .32532 L .63421 .32124 L p F P
0 g
s
.77 .852 .913 r
.6932 .31769 m .69945 .31368 L .69651 .31097 L p F P
0 g
s
.77 .852 .913 r
.69651 .31097 m .69326 .31301 L .6932 .31769 L p F P
0 g
s
.769 .846 .91 r
.68404 .31873 m .69326 .31301 L .6932 .31769 L p F P
0 g
s
.911 .911 .807 r
.79066 .22541 m .79134 .22996 L .79706 .22252 L p F P
0 g
s
.911 .911 .807 r
.79485 .21996 m .79066 .22541 L p .79706 .22252 L F P
0 g
s
.911 .911 .807 r
.79706 .22252 m .79692 .22148 L .79485 .21996 L p F P
0 g
s
0 0 .361 r
.61104 .30076 m .61201 .30519 L .61 .30023 L p F P
0 g
s
0 0 .361 r
.61 .30023 m .60918 .29575 L .61104 .30076 L p F P
0 g
s
.958 .828 .673 r
.6147 .20391 m .61604 .20079 L .61295 .19832 L p F P
0 g
s
.988 .837 .603 r
.60891 .23765 m .61041 .23285 L .60736 .23206 L p F P
0 g
s
.864 .896 .855 r
.76374 .26555 m .76124 .26349 L .76329 .26145 L closepath p F P
0 g
s
.629 .729 .919 r
.74107 .046 m .75387 .04243 L .75677 .04663 L p F P
0 g
s
.63 .73 .92 r
.75387 .04243 m .74107 .046 L .73814 .04184 L p F P
0 g
s
.69 .756 .902 r
.72549 .04727 m .73814 .04184 L .74107 .046 L p F P
0 g
s
.989 .884 .619 r
.8166 .16345 m .81776 .16795 L .82008 .16167 L p F P
0 g
s
.989 .884 .619 r
.82008 .16167 m .81894 .15715 L .8166 .16345 L p F P
0 g
s
.973 .898 .686 r
.81296 .17879 m .81505 .17438 L .81614 .17888 L p F P
0 g
s
.973 .898 .686 r
.81614 .17888 m .81554 .18012 L .81296 .17879 L p F P
0 g
s
.878 .596 .076 r
.81753 .1104 m .81913 .11485 L .81842 .10965 L p F P
0 g
s
.878 .596 .076 r
.81842 .10965 m .81682 .1052 L .81753 .1104 L p F P
0 g
s
.999 .837 .545 r
.60567 .24978 m .60731 .2541 L .60888 .24805 L p F P
0 g
s
.999 .837 .545 r
.60888 .24805 m .60718 .24375 L .60567 .24978 L p F P
0 g
s
.69 .756 .902 r
.73814 .04184 m .72549 .04727 L .72255 .04312 L p F P
0 g
s
.911 .808 .733 r
.62841 .15163 m .63063 .14786 L .62754 .14417 L p F P
0 g
s
.89 .802 .755 r
.63934 .12661 m .63959 .12625 L .6365 .1223 L p F P
0 g
s
.194 .447 .872 r
.79182 .06198 m .79117 .06169 L .79325 .06608 L p F P
0 g
s
.194 .447 .872 r
.79325 .06608 m .79471 .06673 L .79182 .06198 L p F P
0 g
s
.89 .802 .755 r
.6365 .1223 m .63632 .12257 L .63934 .12661 L p F P
0 g
s
.892 .801 .753 r
.63166 .12957 m .63468 .13361 L .63934 .12661 L p F P
0 g
s
.892 .801 .753 r
.63934 .12661 m .63632 .12257 L .63166 .12957 L p F P
0 g
s
.971 .904 .693 r
.81285 .1855 m .81554 .18012 L .81296 .17879 L p F P
0 g
s
.744 .824 .913 r
.67254 .32525 m .67157 .32579 L .66856 .32268 L p F P
0 g
s
.71 .815 .93 r
.65604 .3285 m .66856 .32268 L .67157 .32579 L p F P
0 g
s
.788 .86 .903 r
.70928 .30693 m .69945 .31368 L .69651 .31097 L p F P
0 g
s
.92 .907 .793 r
.79692 .22148 m .79485 .21996 L .79631 .21798 L closepath p F P
0 g
s
.771 .454 0 r
.81511 .10076 m .81682 .1052 L .81545 .10023 L p F P
0 g
s
.771 .454 0 r
.81545 .10023 m .81374 .09579 L .81511 .10076 L p F P
0 g
s
.742 .826 .916 r
.67254 .32525 m .68404 .31873 L .68106 .3158 L p F P
0 g
s
.742 .826 .916 r
.68106 .3158 m .67214 .32072 L .67254 .32525 L p F P
0 g
s
.744 .824 .913 r
.66856 .32268 m .67214 .32072 L .67254 .32525 L p F P
0 g
s
.994 .81 .439 r
.81948 .13612 m .82091 .14058 L .82179 .1348 L p F P
0 g
s
.994 .81 .439 r
.82179 .1348 m .82037 .13033 L .81948 .13612 L p F P
0 g
s
.549 .69 .932 r
.76091 .04617 m .75677 .04663 L .75387 .04243 L p F P
0 g
s
.909 .909 .809 r
.78461 .23297 m .79066 .22541 L .79134 .22996 L p F P
0 g
s
.909 .909 .809 r
.78527 .23703 m .78461 .23297 L p .79134 .22996 L F P
0 g
s
.909 .909 .809 r
.79134 .22996 m .78556 .23723 L .78527 .23703 L p F P
0 g
s
.94 .825 .703 r
.613 .18909 m .61546 .19324 L .61876 .18666 L p F P
0 g
s
.94 .825 .703 r
.61876 .18666 m .61625 .18253 L .613 .18909 L p F P
0 g
s
.942 .763 .296 r
.60583 .27609 m .60614 .27758 L .60695 .27321 L p F P
0 g
s
.942 .763 .296 r
.60695 .27321 m .60634 .27035 L .60583 .27609 L p F P
0 g
s
.917 .82 .735 r
.61865 .16826 m .62043 .16521 L .62308 .16932 L p F P
0 g
s
.917 .82 .735 r
.62308 .16932 m .62175 .17159 L .61865 .16826 L p F P
0 g
s
.949 .913 .746 r
.80666 .20262 m .80602 .20367 L .80574 .20207 L closepath p F P
0 g
s
.958 .828 .673 r
.61295 .19832 m .61233 .19976 L .6147 .20391 L p F P
0 g
s
.962 .826 .663 r
.60976 .20611 m .61209 .21027 L .6147 .20391 L p F P
0 g
s
.962 .826 .663 r
.6147 .20391 m .61233 .19976 L .60976 .20611 L p F P
0 g
s
.833 .561 .014 r
.60758 .29003 m .60801 .29136 L .60719 .28603 L p F P
0 g
s
0 0 .223 r
.60801 .29136 m .60758 .29003 L .60779 .29065 L p F P
0 g
s
.785 .533 0 r
.60892 .29422 m .6083 .29044 L p .60801 .29136 L F P
0 g
s
0 0 .223 r
.60779 .29065 m .60861 .2932 L .60801 .29136 L p F P
0 g
s
.785 .533 0 r
.60801 .29136 m .60918 .29575 L .60892 .29422 L p F P
0 g
s
.785 .533 0 r
.6083 .29044 m .60719 .28603 L .60801 .29136 L p F P
0 g
s
.989 .813 .426 r
.60509 .26594 m .60634 .27035 L .60733 .26447 L p F P
0 g
s
.989 .813 .426 r
.60733 .26447 m .60603 .26007 L .60509 .26594 L p F P
0 g
s
.014 .311 .802 r
.79471 .06673 m .79875 .06954 L .80083 .07391 L p F P
0 g
s
0 .151 .694 r
.80279 .07353 m .80485 .07791 L .80083 .07391 L p F P
0 g
s
0 .151 .694 r
.80083 .07391 m .79875 .06954 L .80279 .07353 L p F P
0 g
s
.996 .849 .512 r
.82127 .14935 m .82088 .151 L .82047 .14951 L closepath p F P
0 g
s
.933 .91 .773 r
.80047 .20624 m .80132 .21077 L .80602 .20367 L p F P
0 g
s
.933 .91 .773 r
.80402 .20088 m .80047 .20624 L p .80602 .20367 L F P
0 g
s
.933 .91 .773 r
.80602 .20367 m .80574 .20207 L .80402 .20088 L p F P
0 g
s
0 0 .321 r
.81192 .09137 m .81374 .09579 L .81161 .0911 L p F P
0 g
s
0 0 .321 r
.81161 .0911 m .80979 .08668 L .81192 .09137 L p F P
0 g
s
.911 .808 .733 r
.62754 .14417 m .62554 .14757 L .62841 .15163 L p F P
0 g
s
.911 .807 .732 r
.62158 .15434 m .62444 .15841 L .62841 .15163 L p F P
0 g
s
.911 .807 .732 r
.62841 .15163 m .62554 .14757 L .62158 .15434 L p F P
0 g
s
.975 .841 .648 r
.60716 .22292 m .60916 .22716 L .61164 .22083 L p F P
0 g
s
.975 .841 .648 r
.61164 .22083 m .60957 .21661 L .60716 .22292 L p F P
0 g
s
0 0 .527 r
.80786 .08228 m .80979 .08668 L .8068 .08231 L p F P
0 g
s
0 0 .527 r
.8068 .08231 m .80485 .07791 L .80786 .08228 L p F P
0 g
s
.014 .318 .806 r
.79875 .06954 m .79471 .06673 L .79182 .06198 L p F P
0 g
s
.932 .814 .706 r
.61953 .17596 m .62175 .17159 L .61865 .16826 L p F P
0 g
s
.655 .778 .939 r
.64043 .32926 m .65299 .32509 L .65604 .3285 L p F P
0 g
s
.639 .766 .94 r
.65299 .32509 m .64043 .32926 L .63733 .32532 L p F P
0 g
s
.703 .808 .931 r
.66856 .32268 m .65604 .3285 L .65299 .32509 L p F P
0 g
s
.793 .869 .905 r
.71187 .30511 m .70928 .30693 L .70933 .30284 L closepath p F P
0 g
s
.788 .86 .903 r
.70896 .30249 m .70933 .30284 L .70928 .30693 L p F P
0 g
s
.788 .86 .903 r
.69651 .31097 m .70896 .30249 L p .70928 .30693 L F P
0 g
s
.988 .837 .603 r
.60736 .23206 m .60693 .23342 L .60891 .23765 L p F P
0 g
s
.993 .83 .578 r
.60525 .23951 m .60718 .24375 L .60891 .23765 L p F P
0 g
s
.993 .83 .578 r
.60891 .23765 m .60693 .23342 L .60525 .23951 L p F P
0 g
s
.994 .872 .586 r
.81771 .15265 m .81894 .15715 L .82088 .151 L p F P
0 g
s
.994 .872 .586 r
.8188 .14914 m .81771 .15265 L p .82088 .151 L F P
0 g
s
.994 .872 .586 r
.82088 .151 m .82047 .14951 L .8188 .14914 L p F P
0 g
s
.902 .911 .818 r
.78556 .23723 m .78533 .2375 L .78527 .23703 L closepath p F P
0 g
s
.89 .802 .756 r
.62689 .13662 m .62992 .14065 L .63468 .13361 L p F P
0 g
s
.89 .802 .756 r
.63468 .13361 m .63166 .12957 L .62689 .13662 L p F P
0 g
s
.887 .904 .834 r
.77787 .24077 m .7785 .24532 L .78533 .2375 L p F P
0 g
s
.887 .904 .834 r
.78283 .23509 m .77787 .24077 L p .78533 .2375 L F P
0 g
s
.887 .904 .834 r
.78533 .2375 m .78527 .23703 L .78283 .23509 L p F P
0 g
s
.971 .904 .693 r
.81296 .17879 m .81188 .18096 L .81285 .1855 L p F P
0 g
s
.96 .905 .721 r
.80814 .18775 m .80916 .19226 L .81285 .1855 L p F P
0 g
s
.96 .905 .721 r
.81285 .1855 m .81188 .18096 L .80814 .18775 L p F P
0 g
s
.805 .87 .895 r
.72276 .29698 m .71187 .30511 L .70933 .30284 L p F P
0 g
s
.98 .766 .353 r
.81885 .12588 m .82037 .13033 L .82077 .12473 L p F P
0 g
s
.98 .766 .353 r
.82077 .12473 m .81926 .12027 L .81885 .12588 L p F P
0 g
s
.982 .889 .655 r
.81386 .16989 m .81505 .17438 L .81776 .16795 L p F P
0 g
s
.982 .889 .655 r
.81776 .16795 m .8166 .16345 L .81386 .16989 L p F P
0 g
s
.926 .689 .201 r
.60625 .28307 m .60719 .28603 L .60705 .28049 L p F P
0 g
s
.926 .689 .201 r
.60705 .28049 m .60614 .27758 L .60625 .28307 L p F P
0 g
s
.399 .55 .889 r
.62573 .32147 m .62154 .32102 L .61835 .31537 L p F P
0 g
s
.897 .902 .821 r
.78527 .23703 m .78283 .23509 L .78461 .23297 L closepath p F P
0 g
s
.394 .595 .926 r
.77267 .04989 m .77801 .05066 L .78041 .05496 L p F P
0 g
s
.306 .534 .908 r
.78606 .0528 m .77801 .05066 L .78041 .05496 L p F P
0 g
s
.306 .534 .908 r
.78041 .05496 m .78894 .05732 L .78606 .0528 L p F P
0 g
s
1 .826 .504 r
.60443 .25575 m .60603 .26007 L .60731 .2541 L p F P
0 g
s
1 .826 .504 r
.60731 .2541 m .60567 .24978 L .60443 .25575 L p F P
0 g
s
.929 .907 .78 r
.79542 .21347 m .79631 .21798 L .80132 .21077 L p F P
0 g
s
.929 .907 .78 r
.80132 .21077 m .80047 .20624 L .79542 .21347 L p F P
0 g
s
.549 .69 .932 r
.75387 .04243 m .75826 .04192 L .76091 .04617 L p F P
0 g
s
.522 .674 .933 r
.7669 .04131 m .75826 .04192 L .76091 .04617 L p F P
0 g
s
.522 .674 .933 r
.76091 .04617 m .76979 .04559 L .7669 .04131 L p F P
0 g
s
.941 .905 .758 r
.80574 .20207 m .80402 .20088 L .80513 .19914 L closepath p F P
0 g
s
.886 .902 .835 r
.77075 .24869 m .77787 .24077 L .7785 .24532 L p F P
0 g
s
.886 .902 .835 r
.77077 .24883 m .77075 .24869 L p .7785 .24532 L F P
0 g
s
.886 .902 .835 r
.7785 .24532 m .77344 .25093 L .77077 .24883 L p F P
0 g
s
.932 .814 .706 r
.61865 .16826 m .61681 .17188 L .61953 .17596 L p F P
0 g
s
.934 .813 .703 r
.61356 .17844 m .61625 .18253 L .61953 .17596 L p F P
0 g
s
.934 .813 .703 r
.61953 .17596 m .61681 .17188 L .61356 .17844 L p F P
0 g
s
.942 .828 .703 r
.60984 .19551 m .613 .18909 L .61546 .19324 L p F P
0 g
s
.942 .828 .703 r
.61546 .19324 m .61295 .19832 L .60984 .19551 L p F P
0 g
s
.765 .841 .909 r
.69326 .31301 m .68404 .31873 L .68106 .3158 L p F P
0 g
s
.911 .809 .733 r
.61758 .16115 m .62043 .16521 L .62444 .15841 L p F P
0 g
s
.911 .809 .733 r
.62444 .15841 m .62158 .15434 L .61758 .16115 L p F P
0 g
s
.81 .877 .895 r
.72427 .29583 m .72276 .29698 L .72272 .29448 L closepath p F P
0 g
s
.805 .87 .895 r
.72138 .29326 m .72272 .29448 L .72276 .29698 L p F P
0 g
s
.805 .87 .895 r
.70928 .30226 m .72138 .29326 L p .72276 .29698 L F P
0 g
s
.805 .87 .895 r
.70933 .30284 m .70928 .30226 L p .72276 .29698 L F P
0 g
s
.966 .827 .656 r
.60728 .21244 m .60957 .21661 L .61209 .21027 L p F P
0 g
s
.966 .827 .656 r
.61209 .21027 m .60976 .20611 L .60728 .21244 L p F P
0 g
s
.821 .878 .886 r
.7345 .28759 m .72427 .29583 L .72272 .29448 L p F P
0 g
s
.95 .7 .241 r
.81765 .11582 m .81926 .12027 L .81913 .11485 L p F P
0 g
s
.95 .7 .241 r
.81913 .11485 m .81753 .1104 L .81765 .11582 L p F P
0 g
s
.996 .86 .569 r
.82047 .14951 m .8188 .14914 L .81958 .14652 L closepath p F P
0 g
s
.395 .599 .928 r
.77801 .05066 m .77267 .04989 L .76979 .04559 L p F P
0 g
s
.137 .354 .814 r
.61643 .31411 m .6157 .31043 L .61835 .31537 L closepath p F P
0 g
s
.879 .903 .843 r
.77344 .25093 m .77125 .25327 L .77077 .24883 L closepath p F P
0 g
s
.89 .802 .756 r
.62442 .14026 m .62689 .13662 L .62992 .14065 L p F P
0 g
s
.89 .802 .756 r
.62992 .14065 m .62754 .14417 L .62442 .14026 L p F P
0 g
s
.865 .896 .855 r
.76269 .25691 m .76329 .26145 L .77125 .25327 L p F P
0 g
s
.865 .896 .855 r
.77068 .24876 m .76269 .25691 L p .77125 .25327 L F P
0 g
s
.865 .896 .855 r
.77125 .25327 m .77077 .24883 L .77068 .24876 L p F P
0 g
s
.999 .838 .513 r
.81813 .14207 m .81958 .14652 L .82091 .14058 L p F P
0 g
s
.999 .838 .513 r
.82091 .14058 m .81948 .13612 L .81813 .14207 L p F P
0 g
s
0 .069 .631 r
.61191 .30209 m .61104 .30076 L .61201 .30519 L p F P
0 g
s
0 .069 .631 r
.61201 .30519 m .61515 .30926 L .61191 .30209 L p F P
0 g
s
.979 .844 .638 r
.60487 .2292 m .60716 .22292 L .60916 .22716 L p F P
0 g
s
.979 .844 .638 r
.60592 .23147 m .60487 .2292 L p .60916 .22716 L F P
0 g
s
.979 .844 .638 r
.60916 .22716 m .60736 .23206 L .60592 .23147 L p F P
0 g
s
.63 .73 .92 r
.73814 .04184 m .75096 .03824 L .75387 .04243 L p F P
0 g
s
.63 .731 .92 r
.75096 .03824 m .73814 .04184 L .73521 .03767 L p F P
0 g
s
.69 .756 .902 r
.72255 .04312 m .73521 .03767 L .73814 .04184 L p F P
0 g
s
.965 .767 .326 r
.60462 .27167 m .60583 .27609 L .60634 .27035 L p F P
0 g
s
.965 .767 .326 r
.60634 .27035 m .60509 .26594 L .60462 .27167 L p F P
0 g
s
.951 .903 .739 r
.80408 .19465 m .80513 .19914 L .80916 .19226 L p F P
0 g
s
.951 .903 .739 r
.80916 .19226 m .80814 .18775 L .80408 .19465 L p F P
0 g
s
.827 .884 .885 r
.73664 .28583 m .7345 .28759 L .73432 .28384 L closepath p F P
0 g
s
.821 .878 .886 r
.73378 .28335 m .73432 .28384 L .7345 .28759 L p F P
0 g
s
.821 .878 .886 r
.72251 .29238 m .73378 .28335 L p .7345 .28759 L F P
0 g
s
.821 .878 .886 r
.72272 .29448 m .72251 .29238 L p .7345 .28759 L F P
0 g
s
.836 .884 .876 r
.74498 .2786 m .73664 .28583 L .73432 .28384 L p F P
0 g
s
.863 .892 .854 r
.75844 .26113 m .76269 .25691 L .76329 .26145 L p F P
0 g
s
.863 .892 .854 r
.76329 .26145 m .76124 .26349 L .75844 .26113 L p F P
0 g
s
.856 .892 .862 r
.75451 .2699 m .76124 .26349 L .75844 .26113 L p F P
0 g
s
.919 .903 .793 r
.79215 .21792 m .79542 .21347 L .79631 .21798 L p F P
0 g
s
.919 .903 .793 r
.79631 .21798 m .79485 .21996 L .79215 .21792 L p F P
0 g
s
.841 .889 .874 r
.74498 .2786 m .74896 .27506 L .74613 .27266 L p F P
0 g
s
.841 .889 .874 r
.74613 .27266 m .74462 .274 L .74498 .2786 L p F P
0 g
s
.836 .884 .876 r
.73423 .28298 m .74462 .274 L .74498 .2786 L p F P
0 g
s
.836 .884 .876 r
.73432 .28384 m .73423 .28298 L p .74498 .2786 L F P
0 g
s
.85 .889 .866 r
.74613 .27266 m .75402 .26534 L .75451 .2699 L p F P
0 g
s
.85 .889 .866 r
.75451 .2699 m .74896 .27506 L .74613 .27266 L p F P
0 g
s
.856 .892 .862 r
.75844 .26113 m .75402 .26534 L .75451 .2699 L p F P
0 g
s
.891 .603 .093 r
.81582 .10596 m .81753 .1104 L .81682 .1052 L p F P
0 g
s
.891 .603 .093 r
.81682 .1052 m .81511 .10076 L .81582 .10596 L p F P
0 g
s
.906 .8 .731 r
.62554 .14757 m .62754 .14417 L .62442 .14026 L p F P
0 g
s
.988 .88 .625 r
.81533 .15897 m .8166 .16345 L .81894 .15715 L p F P
0 g
s
.988 .88 .625 r
.81894 .15715 m .81771 .15265 L .81533 .15897 L p F P
0 g
s
.997 .825 .551 r
.60378 .24554 m .60567 .24978 L .60718 .24375 L p F P
0 g
s
.997 .825 .551 r
.60718 .24375 m .60525 .23951 L .60378 .24554 L p F P
0 g
s
.198 .455 .878 r
.79117 .06169 m .78905 .0575 L .79182 .06198 L closepath p F P
0 g
s
0 0 .26 r
.61052 .2989 m .61104 .30076 L .60918 .29575 L p F P
0 g
s
0 0 .26 r
.60861 .2932 m .61052 .2989 L p .60918 .29575 L F P
0 g
s
0 0 .26 r
.60918 .29575 m .60801 .29136 L .60861 .2932 L p F P
0 g
s
.973 .894 .685 r
.81076 .17646 m .81386 .16989 L .81505 .17438 L p F P
0 g
s
.973 .894 .685 r
.81112 .17778 m .81076 .17646 L p .81505 .17438 L F P
0 g
s
.973 .894 .685 r
.81505 .17438 m .81296 .17879 L .81112 .17778 L p F P
0 g
s
.765 .841 .909 r
.68106 .3158 m .69334 .30832 L .69326 .31301 L p F P
0 g
s
.766 .85 .914 r
.69326 .31301 m .69651 .31097 L .69355 .30818 L p F P
0 g
s
.766 .85 .914 r
.69355 .30818 m .69334 .30832 L .69326 .31301 L p F P
0 g
s
.914 .906 .801 r
.79066 .22541 m .79485 .21996 L .79215 .21792 L p F P
0 g
s
.953 .818 .673 r
.61233 .19976 m .61295 .19832 L .60984 .19551 L p F P
0 g
s
.55 .692 .933 r
.75826 .04192 m .75387 .04243 L .75096 .03824 L p F P
0 g
s
.399 .55 .889 r
.61835 .31537 m .62549 .31685 L .62573 .32147 L p F P
0 g
s
.507 .665 .933 r
.63109 .31703 m .62549 .31685 L .62573 .32147 L p F P
0 g
s
.507 .665 .933 r
.62573 .32147 m .63421 .32124 L .63109 .31703 L p F P
0 g
s
.739 .818 .913 r
.67214 .32072 m .66856 .32268 L .66553 .31949 L p F P
0 g
s
.703 .808 .931 r
.65299 .32509 m .66553 .31949 L .66856 .32268 L p F P
0 g
s
.913 .81 .732 r
.61552 .16467 m .61758 .16115 L .62043 .16521 L p F P
0 g
s
.913 .81 .732 r
.62043 .16521 m .61865 .16826 L .61552 .16467 L p F P
0 g
s
.014 .318 .806 r
.79182 .06198 m .79656 .06519 L .79875 .06954 L p F P
0 g
s
0 .313 .804 r
.78905 .0575 m .79182 .06198 L .79656 .06519 L p F P
0 g
s
.935 .815 .701 r
.61033 .185 m .613 .18909 L .61625 .18253 L p F P
0 g
s
.935 .815 .701 r
.61625 .18253 m .61356 .17844 L .61033 .185 L p F P
0 g
s
.787 .462 0 r
.8133 .09633 m .81511 .10076 L .81374 .09579 L p F P
0 g
s
.787 .462 0 r
.81374 .09579 m .81192 .09137 L .8133 .09633 L p F P
0 g
s
.785 .857 .904 r
.70896 .30249 m .69651 .31097 L .69355 .30818 L p F P
0 g
s
.424 .531 .862 r
.6157 .31043 m .61835 .31537 L .62549 .31685 L p F P
0 g
s
.953 .818 .673 r
.60984 .19551 m .60977 .19566 L .61233 .19976 L p F P
0 g
s
.957 .816 .662 r
.60723 .202 m .60976 .20611 L .61233 .19976 L p F P
0 g
s
.957 .816 .662 r
.61233 .19976 m .60977 .19566 L .60723 .202 L p F P
0 g
s
.996 .809 .449 r
.81795 .13167 m .81948 .13612 L .82037 .13033 L p F P
0 g
s
.996 .809 .449 r
.82037 .13033 m .81885 .12588 L .81795 .13167 L p F P
0 g
s
0 .15 .692 r
.80063 .06917 m .80279 .07353 L .79875 .06954 L p F P
0 g
s
0 .15 .692 r
.79875 .06954 m .79656 .06519 L .80063 .06917 L p F P
0 g
s
.906 .8 .731 r
.62442 .14026 m .62249 .14354 L .62554 .14757 L p F P
0 g
s
.907 .8 .73 r
.61853 .15033 m .62158 .15434 L .62554 .14757 L p F P
0 g
s
.907 .8 .73 r
.62554 .14757 m .62249 .14354 L .61853 .15033 L p F P
0 g
s
.87 .66 .13 r
.60596 .28164 m .60625 .28307 L .60614 .27758 L p F P
0 g
s
.87 .66 .13 r
.60614 .27758 m .60583 .27609 L .60596 .28164 L p F P
0 g
s
.639 .766 .94 r
.63733 .32532 m .64992 .32158 L .65299 .32509 L p F P
0 g
s
.621 .754 .941 r
.64992 .32158 m .63733 .32532 L .63421 .32124 L p F P
0 g
s
0 0 .308 r
.81001 .08696 m .81192 .09137 L .80979 .08668 L p F P
0 g
s
0 0 .308 r
.80979 .08668 m .80786 .08228 L .81001 .08696 L p F P
0 g
s
.914 .906 .801 r
.79215 .21792 m .78988 .22087 L .79066 .22541 L p F P
0 g
s
.905 .903 .811 r
.78377 .22846 m .78461 .23297 L .79066 .22541 L p F P
0 g
s
.905 .903 .811 r
.79066 .22541 m .78988 .22087 L .78377 .22846 L p F P
0 g
s
.996 .806 .445 r
.60354 .26161 m .60509 .26594 L .60603 .26007 L p F P
0 g
s
.996 .806 .445 r
.60603 .26007 m .60443 .25575 L .60354 .26161 L p F P
0 g
s
0 0 .52 r
.80583 .07789 m .80786 .08228 L .80485 .07791 L p F P
0 g
s
0 0 .52 r
.80485 .07791 m .80279 .07353 L .80583 .07789 L p F P
0 g
s
.737 .822 .917 r
.67214 .32072 m .68106 .3158 L .67806 .31279 L p F P
0 g
s
.737 .822 .917 r
.67806 .31279 m .67177 .31617 L .67214 .32072 L p F P
0 g
s
.739 .818 .913 r
.66553 .31949 m .67177 .31617 L .67214 .32072 L p F P
0 g
s
.833 .561 .014 r
.60719 .28603 m .60625 .28307 L .60758 .29003 L p F P
0 g
s
.984 .826 .608 r
.60736 .23206 m .60693 .23342 L .60592 .23147 L closepath p F P
0 g
s
.97 .829 .647 r
.60491 .21874 m .60716 .22292 L .60957 .21661 L p F P
0 g
s
.97 .829 .647 r
.60957 .21661 m .60728 .21244 L .60491 .21874 L p F P
0 g
s
.695 .802 .931 r
.66553 .31949 m .65299 .32509 L .64992 .32158 L p F P
0 g
s
.94 .901 .759 r
.80135 .19896 m .80408 .19465 L .80513 .19914 L p F P
0 g
s
.94 .901 .759 r
.80513 .19914 m .80402 .20088 L .80135 .19896 L p F P
0 g
s
.814 .871 .888 r
.72272 .29448 m .72138 .29326 L .72251 .29238 L closepath p F P
0 g
s
.927 .805 .705 r
.61681 .17188 m .61865 .16826 L .61552 .16467 L p F P
0 g
s
.97 .899 .695 r
.81296 .17879 m .81188 .18096 L .81112 .17778 L closepath p F P
0 g
s
.799 .863 .896 r
.70933 .30284 m .70896 .30249 L .70928 .30226 L closepath p F P
0 g
s
.937 .905 .766 r
.80047 .20624 m .80402 .20088 L .80135 .19896 L p F P
0 g
s
.989 .819 .58 r
.60309 .23533 m .60525 .23951 L .60693 .23342 L p F P
0 g
s
.989 .819 .58 r
.60428 .23101 m .60309 .23533 L p .60693 .23342 L F P
0 g
s
.989 .819 .58 r
.60693 .23342 m .60592 .23147 L .60428 .23101 L p F P
0 g
s
.996 .858 .572 r
.81636 .14817 m .81813 .14207 L .81958 .14652 L p F P
0 g
s
.996 .858 .572 r
.81647 .14852 m .81636 .14817 L p .81958 .14652 L F P
0 g
s
.996 .858 .572 r
.81958 .14652 m .8188 .14914 L .81647 .14852 L p F P
0 g
s
.985 .766 .365 r
.81723 .12144 m .81885 .12588 L .81926 .12027 L p F P
0 g
s
.985 .766 .365 r
.81926 .12027 m .81765 .11582 L .81723 .12144 L p F P
0 g
s
.955 .899 .731 r
.80703 .18325 m .80814 .18775 L .81188 .18096 L p F P
0 g
s
.955 .899 .731 r
.81034 .17725 m .80703 .18325 L p .81188 .18096 L F P
0 g
s
.955 .899 .731 r
.81188 .18096 m .81112 .17778 L .81034 .17725 L p F P
0 g
s
.896 .898 .82 r
.78008 .23286 m .78377 .22846 L .78461 .23297 L p F P
0 g
s
.896 .898 .82 r
.78461 .23297 m .78283 .23509 L .78008 .23286 L p F P
0 g
s
.307 .54 .912 r
.78318 .04835 m .7755 .04637 L .77801 .05066 L p F P
0 g
s
.307 .54 .912 r
.77801 .05066 m .78606 .0528 L .78318 .04835 L p F P
0 g
s
.395 .599 .928 r
.76979 .04559 m .7755 .04637 L .77801 .05066 L p F P
0 g
s
.798 .859 .894 r
.70928 .30226 m .70896 .30249 L .70602 .29971 L p F P
0 g
s
.785 .857 .904 r
.69355 .30818 m .70602 .29971 L .70896 .30249 L p F P
0 g
s
.98 .885 .66 r
.81258 .16542 m .81386 .16989 L .8166 .16345 L p F P
0 g
s
.98 .885 .66 r
.8166 .16345 m .81533 .15897 L .81258 .16542 L p F P
0 g
s
.801 .861 .894 r
.70928 .30226 m .72138 .29326 L .71847 .29056 L p F P
0 g
s
.801 .861 .894 r
.71847 .29056 m .70876 .29773 L .70928 .30226 L p F P
0 g
s
.798 .859 .894 r
.70602 .29971 m .70876 .29773 L .70928 .30226 L p F P
0 g
s
.55 .692 .933 r
.75096 .03824 m .7555 .03769 L .75826 .04192 L p F P
0 g
s
.523 .677 .935 r
.764 .03707 m .7555 .03769 L .75826 .04192 L p F P
0 g
s
.523 .677 .935 r
.75826 .04192 m .7669 .04131 L .764 .03707 L p F P
0 g
s
.891 .9 .828 r
.77787 .24077 m .78283 .23509 L .78008 .23286 L p F P
0 g
s
.905 .677 .171 r
.60477 .27722 m .60596 .28164 L .60583 .27609 L p F P
0 g
s
.905 .677 .171 r
.60583 .27609 m .60462 .27167 L .60477 .27722 L p F P
0 g
s
.927 .805 .705 r
.61552 .16467 m .61392 .16784 L .61681 .17188 L p F P
0 g
s
.929 .804 .701 r
.61068 .1744 m .61356 .17844 L .61681 .17188 L p F P
0 g
s
.929 .804 .701 r
.61681 .17188 m .61392 .16784 L .61068 .1744 L p F P
0 g
s
.937 .817 .702 r
.60712 .19157 m .61033 .185 L .613 .18909 L p F P
0 g
s
.937 .817 .702 r
.60935 .19502 m .60712 .19157 L p .613 .18909 L F P
0 g
s
.937 .817 .702 r
.613 .18909 m .60984 .19551 L .60935 .19502 L p F P
0 g
s
.907 .8 .731 r
.61453 .15714 m .61758 .16115 L .62158 .15434 L p F P
0 g
s
.907 .8 .731 r
.62158 .15434 m .61853 .15033 L .61453 .15714 L p F P
0 g
s
1 .815 .514 r
.60258 .25149 m .60443 .25575 L .60567 .24978 L p F P
0 g
s
1 .815 .514 r
.60567 .24978 m .60378 .24554 L .60258 .25149 L p F P
0 g
s
.395 .602 .93 r
.7755 .04637 m .76979 .04559 L .7669 .04131 L p F P
0 g
s
.191 .352 .797 r
.61515 .30926 m .61569 .30963 L .6157 .31043 L closepath p F P
0 g
s
.424 .531 .862 r
.62468 .31239 m .61569 .30963 L .6157 .31043 L p F P
0 g
s
.424 .531 .862 r
.62549 .31685 m .62468 .31239 L p .6157 .31043 L F P
0 g
s
.937 .905 .766 r
.80135 .19896 m .79953 .20172 L .80047 .20624 L p F P
0 g
s
.926 .902 .781 r
.79443 .20897 m .79542 .21347 L .80047 .20624 L p F P
0 g
s
.926 .902 .781 r
.80047 .20624 m .79953 .20172 L .79443 .20897 L p F P
0 g
s
.995 .865 .582 r
.8188 .14914 m .81771 .15265 L .81647 .14852 L closepath p F P
0 g
s
.761 .836 .909 r
.69334 .30832 m .68106 .3158 L .67806 .31279 L p F P
0 g
s
.961 .816 .655 r
.60478 .20832 m .60728 .21244 L .60976 .20611 L p F P
0 g
s
.961 .816 .655 r
.60976 .20611 m .60723 .202 L .60478 .20832 L p F P
0 g
s
.884 .896 .835 r
.76994 .24418 m .77075 .24869 L .77787 .24077 L p F P
0 g
s
.884 .896 .835 r
.77787 .24077 m .77714 .23623 L .76994 .24418 L p F P
0 g
s
.891 .9 .828 r
.78008 .23286 m .77714 .23623 L .77787 .24077 L p F P
0 g
s
.089 .277 .76 r
.61569 .30963 m .61515 .30926 L .61191 .30209 L p F P
0 g
s
.957 .703 .255 r
.81594 .11139 m .81765 .11582 L .81753 .1104 L p F P
0 g
s
.957 .703 .255 r
.81753 .1104 m .81582 .10596 L .81594 .11139 L p F P
0 g
s
.63 .731 .92 r
.73521 .03767 m .74804 .03404 L .75096 .03824 L p F P
0 g
s
.829 .877 .879 r
.73432 .28384 m .73378 .28335 L .73423 .28298 L closepath p F P
0 g
s
.814 .866 .887 r
.72251 .29238 m .72138 .29326 L .71847 .29056 L p F P
0 g
s
.999 .835 .521 r
.81659 .13763 m .81813 .14207 L .81948 .13612 L p F P
0 g
s
.999 .835 .521 r
.81948 .13612 m .81795 .13167 L .81659 .13763 L p F P
0 g
s
.817 .869 .885 r
.72251 .29238 m .73378 .28335 L .7309 .28071 L p F P
0 g
s
.817 .869 .885 r
.7309 .28071 m .72194 .28786 L .72251 .29238 L p F P
0 g
s
.814 .866 .887 r
.71847 .29056 m .72194 .28786 L .72251 .29238 L p F P
0 g
s
.975 .829 .636 r
.60267 .22501 m .60487 .2292 L .60716 .22292 L p F P
0 g
s
.975 .829 .636 r
.60716 .22292 m .60491 .21874 L .60267 .22501 L p F P
0 g
s
.311 .477 .863 r
.62346 .30804 m .62468 .31239 L .61569 .30963 L p F P
0 g
s
.311 .477 .863 r
.61569 .30963 m .61534 .305 L .62346 .30804 L p F P
0 g
s
.089 .277 .76 r
.61191 .30209 m .61534 .305 L .61569 .30963 L p F P
0 g
s
.876 .895 .843 r
.77077 .24883 m .77068 .24876 L .77075 .24869 L closepath p F P
0 g
s
.986 .84 .612 r
.60592 .23147 m .60428 .23101 L .60487 .2292 L closepath p F P
0 g
s
.874 .89 .842 r
.7679 .24635 m .76994 .24418 L .77075 .24869 L p F P
0 g
s
.874 .89 .842 r
.77075 .24869 m .77068 .24876 L .7679 .24635 L p F P
0 g
s
.868 .891 .849 r
.76269 .25691 m .77068 .24876 L .7679 .24635 L p F P
0 g
s
0 0 .554 r
.61104 .30076 m .61052 .2989 L .61191 .30209 L closepath p F P
0 g
s
.981 .767 .356 r
.6031 .26733 m .60462 .27167 L .60509 .26594 L p F P
0 g
s
.981 .767 .356 r
.60509 .26594 m .60354 .26161 L .6031 .26733 L p F P
0 g
s
.135 .416 .861 r
.78894 .05732 m .78896 .05733 L .78905 .0575 L closepath p F P
0 g
s
0 .313 .804 r
.79427 .06086 m .78896 .05733 L .78905 .0575 L p F P
0 g
s
0 .313 .804 r
.79656 .06519 m .79427 .06086 L p .78905 .0575 L F P
0 g
s
.949 .898 .741 r
.80293 .19017 m .80408 .19465 L .80814 .18775 L p F P
0 g
s
.949 .898 .741 r
.80814 .18775 m .80703 .18325 L .80293 .19017 L p F P
0 g
s
.133 .421 .864 r
.78896 .05733 m .78894 .05732 L .78606 .0528 L p F P
0 g
s
.55 .693 .934 r
.7555 .03769 m .75096 .03824 L .74804 .03404 L p F P
0 g
s
.902 .609 .11 r
.81401 .10154 m .81582 .10596 L .81511 .10076 L p F P
0 g
s
.902 .609 .11 r
.81511 .10076 m .8133 .09633 L .81401 .10154 L p F P
0 g
s
.133 .421 .864 r
.78606 .0528 m .78653 .05303 L .78896 .05733 L p F P
0 g
s
.002 .323 .81 r
.79187 .05655 m .79427 .06086 L .78896 .05733 L p F P
0 g
s
.002 .323 .81 r
.78896 .05733 m .78653 .05303 L .79187 .05655 L p F P
0 g
s
.77 .507 0 r
.60574 .28251 m .60696 .28692 L .60666 .28531 L p F P
0 g
s
.77 .507 0 r
.60666 .28531 m .60596 .28164 L p .60574 .28251 L F P
0 g
s
.832 .545 0 r
.6042 .27818 m .60574 .28251 L .60477 .27722 L p F P
0 g
s
0 0 .306 r
.60574 .28251 m .6042 .27818 L .60482 .27969 L p F P
0 g
s
.77 .507 0 r
.60596 .28164 m .60477 .27722 L .60574 .28251 L p F P
0 g
s
0 0 .306 r
.60482 .27969 m .60625 .28314 L p .60574 .28251 L F P
0 g
s
0 0 .376 r
.60696 .28692 m .60574 .28251 L .60635 .2839 L p F P
0 g
s
.708 .467 0 r
.60735 .2888 m .60625 .28307 L p .60696 .28692 L F P
0 g
s
0 0 .376 r
.60635 .2839 m .60789 .28743 L p .60696 .28692 L F P
0 g
s
.708 .467 0 r
.60696 .28692 m .60758 .29003 L .60735 .2888 L p F P
0 g
s
.708 .467 0 r
.60625 .28307 m .60596 .28164 L .60696 .28692 L p F P
0 g
s
.828 .873 .878 r
.73423 .28298 m .73378 .28335 L .7309 .28071 L p F P
0 g
s
.828 .877 .88 r
.73358 .27847 m .73423 .28298 L .74462 .274 L p F P
0 g
s
.828 .873 .878 r
.7309 .28071 m .73358 .27847 L .73423 .28298 L p F P
0 g
s
.868 .891 .849 r
.7679 .24635 m .76198 .25239 L .76269 .25691 L p F P
0 g
s
.862 .888 .853 r
.75563 .2587 m .76198 .25239 L .76269 .25691 L p F P
0 g
s
.862 .888 .853 r
.76269 .25691 m .75844 .26113 L .75563 .2587 L p F P
0 g
s
.918 .899 .792 r
.78943 .21579 m .79443 .20897 L .79542 .21347 L p F P
0 g
s
.918 .899 .792 r
.79542 .21347 m .79215 .21792 L .78943 .21579 L p F P
0 g
s
.993 .813 .556 r
.60166 .24135 m .60378 .24554 L .60525 .23951 L p F P
0 g
s
.993 .813 .556 r
.60525 .23951 m .60309 .23533 L .60166 .24135 L p F P
0 g
s
.985 .878 .64 r
.81397 .1545 m .81533 .15897 L .81771 .15265 L p F P
0 g
s
.985 .878 .64 r
.81627 .14842 m .81397 .1545 L p .81771 .15265 L F P
0 g
s
.985 .878 .64 r
.81771 .15265 m .81647 .14852 L .81627 .14842 L p F P
0 g
s
.971 .887 .687 r
.80945 .172 m .81076 .17646 L .81386 .16989 L p F P
0 g
s
.971 .887 .687 r
.81386 .16989 m .81258 .16542 L .80945 .172 L p F P
0 g
s
.855 .888 .861 r
.75402 .26534 m .75844 .26113 L .75563 .2587 L p F P
0 g
s
.908 .801 .73 r
.61238 .16081 m .61453 .15714 L .61758 .16115 L p F P
0 g
s
.908 .801 .73 r
.61758 .16115 m .61552 .16467 L .61238 .16081 L p F P
0 g
s
.855 .888 .861 r
.75563 .2587 m .75343 .26079 L .75402 .26534 L p F P
0 g
s
.849 .885 .864 r
.74407 .26945 m .75343 .26079 L .75402 .26534 L p F P
0 g
s
.849 .885 .864 r
.74433 .27109 m .74407 .26945 L p .75402 .26534 L F P
0 g
s
.849 .885 .864 r
.75402 .26534 m .74613 .27266 L .74433 .27109 L p F P
0 g
s
.734 .813 .913 r
.67177 .31617 m .66553 .31949 L .66249 .31621 L p F P
0 g
s
.695 .802 .931 r
.64992 .32158 m .66249 .31621 L .66553 .31949 L p F P
0 g
s
.6 .74 .943 r
.64684 .31798 m .63421 .32124 L .63109 .31703 L p F P
0 g
s
.621 .754 .941 r
.63421 .32124 m .64684 .31798 L .64992 .32158 L p F P
0 g
s
.841 .885 .873 r
.74613 .27266 m .74462 .274 L .74433 .27109 L closepath p F P
0 g
s
.828 .877 .88 r
.74329 .27015 m .73358 .27847 L p .74462 .274 L F P
0 g
s
.828 .877 .88 r
.74462 .274 m .74433 .27109 L .74329 .27015 L p F P
0 g
s
.93 .805 .7 r
.60745 .18096 m .61033 .185 L .61356 .17844 L p F P
0 g
s
.93 .805 .7 r
.61356 .17844 m .61068 .1744 L .60745 .18096 L p F P
0 g
s
.948 .809 .673 r
.60984 .19551 m .60977 .19566 L .60935 .19502 L closepath p F P
0 g
s
.954 .805 .658 r
.60451 .19794 m .60723 .202 L .60977 .19566 L p F P
0 g
s
.954 .805 .658 r
.60671 .19244 m .60451 .19794 L p .60977 .19566 L F P
0 g
s
.954 .805 .658 r
.60977 .19566 m .60935 .19502 L .60671 .19244 L p F P
0 g
s
.803 .471 0 r
.81139 .09193 m .8133 .09633 L .81192 .09137 L p F P
0 g
s
.803 .471 0 r
.81192 .09137 m .81001 .08696 L .81139 .09193 L p F P
0 g
s
0 .148 .69 r
.79837 .06483 m .80063 .06917 L .79656 .06519 L p F P
0 g
s
0 .148 .69 r
.79656 .06519 m .79427 .06086 L .79837 .06483 L p F P
0 g
s
.765 .847 .913 r
.69355 .30818 m .69334 .30832 L .69333 .30797 L closepath p F P
0 g
s
.761 .836 .909 r
.69057 .30524 m .69333 .30797 L .69334 .30832 L p F P
0 g
s
.761 .836 .909 r
.67806 .31279 m .69057 .30524 L p .69334 .30832 L F P
0 g
s
.998 .807 .458 r
.81631 .12724 m .81795 .13167 L .81885 .12588 L p F P
0 g
s
.998 .807 .458 r
.81885 .12588 m .81723 .12144 L .81631 .12724 L p F P
0 g
s
.121 .284 .757 r
.61052 .2989 m .61191 .30209 L .61534 .305 L p F P
0 g
s
.788 .851 .898 r
.70307 .29686 m .70602 .29971 L .69355 .30818 L p F P
0 g
s
.788 .851 .898 r
.69273 .30382 m .70307 .29686 L p .69355 .30818 L F P
0 g
s
.788 .851 .898 r
.69355 .30818 m .69333 .30797 L .69273 .30382 L p F P
0 g
s
.913 .902 .8 r
.78988 .22087 m .79215 .21792 L .78943 .21579 L p F P
0 g
s
.644 .284 0 r
.80799 .08258 m .81001 .08696 L .80786 .08228 L p F P
0 g
s
.644 .284 0 r
.80786 .08228 m .80583 .07789 L .80799 .08258 L p F P
0 g
s
.473 .641 .93 r
.62794 .31269 m .62468 .31239 L .62549 .31685 L p F P
0 g
s
.473 .641 .93 r
.62549 .31685 m .63109 .31703 L .62794 .31269 L p F P
0 g
s
0 0 .512 r
.80369 .07353 m .80583 .07789 L .80279 .07353 L p F P
0 g
s
0 0 .512 r
.80279 .07353 m .80063 .06917 L .80369 .07353 L p F P
0 g
s
.961 .893 .715 r
.81112 .17778 m .81034 .17725 L .81076 .17646 L closepath p F P
0 g
s
.686 .794 .932 r
.66249 .31621 m .64992 .32158 L .64684 .31798 L p F P
0 g
s
.965 .817 .647 r
.60244 .21462 m .60491 .21874 L .60728 .21244 L p F P
0 g
s
.965 .817 .647 r
.60728 .21244 m .60478 .20832 L .60244 .21462 L p F P
0 g
s
.942 .817 .691 r
.60935 .19502 m .60671 .19244 L .60712 .19157 L closepath p F P
0 g
s
.778 .844 .902 r
.69333 .30797 m .69057 .30524 L .69273 .30382 L closepath p F P
0 g
s
.922 .796 .704 r
.61392 .16784 m .61552 .16467 L .61238 .16081 L p F P
0 g
s
.999 .797 .461 r
.60172 .25735 m .60354 .26161 L .60443 .25575 L p F P
0 g
s
.999 .797 .461 r
.60443 .25575 m .60258 .25149 L .60172 .25735 L p F P
0 g
s
.913 .902 .8 r
.78943 .21579 m .789 .21635 L .78988 .22087 L p F P
0 g
s
.903 .898 .812 r
.78282 .22397 m .78377 .22846 L .78988 .22087 L p F P
0 g
s
.903 .898 .812 r
.78988 .22087 m .789 .21635 L .78282 .22397 L p F P
0 g
s
.94 .897 .757 r
.79866 .19694 m .80293 .19017 L .80408 .19465 L p F P
0 g
s
.94 .897 .757 r
.80408 .19465 m .80135 .19896 L .79866 .19694 L p F P
0 g
s
0 0 .502 r
.60861 .2932 m .61017 .29628 L .61052 .2989 L closepath p F P
0 g
s
.121 .284 .757 r
.6145 .30051 m .61017 .29628 L .61052 .2989 L p F P
0 g
s
.121 .284 .757 r
.61534 .305 m .6145 .30051 L p .61052 .2989 L F P
0 g
s
.731 .819 .919 r
.67177 .31617 m .67806 .31279 L .67504 .30971 L p F P
0 g
s
.731 .819 .919 r
.67504 .30971 m .67148 .31157 L .67177 .31617 L p F P
0 g
s
.734 .813 .913 r
.66249 .31621 m .67148 .31157 L .67177 .31617 L p F P
0 g
s
0 0 .513 r
.60758 .29003 m .60861 .2932 L .61017 .29628 L p F P
0 g
s
.981 .828 .618 r
.60118 .22957 m .60267 .22501 L .60487 .2292 L p F P
0 g
s
.981 .828 .618 r
.60487 .2292 m .60428 .23101 L .60118 .22957 L p F P
0 g
s
0 0 .513 r
.60921 .29181 m .60696 .28692 L .60758 .29003 L p F P
0 g
s
0 0 .513 r
.61017 .29628 m .60921 .29181 L p .60758 .29003 L F P
0 g
s
.996 .852 .575 r
.8148 .14374 m .81636 .14817 L .81813 .14207 L p F P
0 g
s
.996 .852 .575 r
.81813 .14207 m .81659 .13763 L .8148 .14374 L p F P
0 g
s
.55 .693 .934 r
.74804 .03404 m .75264 .03349 L .7555 .03769 L p F P
0 g
s
.524 .68 .936 r
.7611 .03285 m .75264 .03349 L .7555 .03769 L p F P
0 g
s
.524 .68 .936 r
.7555 .03769 m .764 .03707 L .7611 .03285 L p F P
0 g
s
.395 .602 .93 r
.7669 .04131 m .77288 .04211 L .7755 .04637 L p F P
0 g
s
.307 .545 .916 r
.78029 .04397 m .77288 .04211 L .7755 .04637 L p F P
0 g
s
.307 .545 .916 r
.7755 .04637 m .78318 .04835 L .78029 .04397 L p F P
0 g
s
.988 .767 .377 r
.81551 .11701 m .81723 .12144 L .81765 .11582 L p F P
0 g
s
.988 .767 .377 r
.81765 .11582 m .81594 .11139 L .81551 .11701 L p F P
0 g
s
.922 .796 .704 r
.61238 .16081 m .61085 .16384 L .61392 .16784 L p F P
0 g
s
.924 .796 .7 r
.60761 .17041 m .61068 .1744 L .61392 .16784 L p F P
0 g
s
.924 .796 .7 r
.61392 .16784 m .61085 .16384 L .60761 .17041 L p F P
0 g
s
.96 .889 .716 r
.80769 .17535 m .80945 .172 L .81076 .17646 L p F P
0 g
s
.96 .889 .716 r
.81076 .17646 m .81034 .17725 L .80769 .17535 L p F P
0 g
s
.394 .605 .933 r
.77288 .04211 m .7669 .04131 L .764 .03707 L p F P
0 g
s
.979 .88 .664 r
.81119 .16096 m .81258 .16542 L .81533 .15897 L p F P
0 g
s
.979 .88 .664 r
.81533 .15897 m .81397 .1545 L .81119 .16096 L p F P
0 g
s
.984 .811 .589 r
.60309 .23533 m .60428 .23101 L .60118 .22957 L p F P
0 g
s
.932 .806 .698 r
.60426 .18753 m .60712 .19157 L .61033 .185 L p F P
0 g
s
.932 .806 .698 r
.61033 .185 m .60745 .18096 L .60426 .18753 L p F P
0 g
s
.796 .855 .894 r
.70876 .29773 m .70602 .29971 L .70307 .29686 L p F P
0 g
s
.896 .894 .819 r
.77732 .23054 m .78282 .22397 L .78377 .22846 L p F P
0 g
s
.896 .894 .819 r
.78377 .22846 m .78008 .23286 L .77732 .23054 L p F P
0 g
s
.936 .9 .765 r
.79953 .20172 m .80135 .19896 L .79866 .19694 L p F P
0 g
s
.957 .893 .723 r
.80703 .18325 m .81034 .17725 L .80769 .17535 L p F P
0 g
s
.938 .692 .217 r
.60325 .27288 m .60477 .27722 L .60462 .27167 L p F P
0 g
s
.938 .692 .217 r
.60462 .27167 m .6031 .26733 L .60325 .27288 L p F P
0 g
s
.799 .858 .893 r
.70876 .29773 m .71847 .29056 L .71555 .28779 L p F P
0 g
s
.799 .858 .893 r
.71555 .28779 m .70814 .29322 L .70876 .29773 L p F P
0 g
s
.796 .855 .894 r
.70307 .29686 m .70814 .29322 L .70876 .29773 L p F P
0 g
s
.997 .804 .522 r
.60049 .2473 m .60258 .25149 L .60378 .24554 L p F P
0 g
s
.997 .804 .522 r
.60378 .24554 m .60166 .24135 L .60049 .2473 L p F P
0 g
s
.956 .806 .655 r
.60208 .20426 m .60478 .20832 L .60723 .202 L p F P
0 g
s
.956 .806 .655 r
.60723 .202 m .60451 .19794 L .60208 .20426 L p F P
0 g
s
.757 .837 .912 r
.69057 .30524 m .67806 .31279 L .67504 .30971 L p F P
0 g
s
.89 .895 .827 r
.77714 .23623 m .78008 .23286 L .77732 .23054 L p F P
0 g
s
.936 .9 .765 r
.79866 .19694 m .79849 .19721 L .79953 .20172 L p F P
0 g
s
.924 .897 .783 r
.79333 .20449 m .79443 .20897 L .79953 .20172 L p F P
0 g
s
.924 .897 .783 r
.79953 .20172 m .79849 .19721 L .79333 .20449 L p F P
0 g
s
.964 .706 .27 r
.81412 .10698 m .81594 .11139 L .81582 .10596 L p F P
0 g
s
.964 .706 .27 r
.81582 .10596 m .81401 .10154 L .81412 .10698 L p F P
0 g
s
.841 .878 .869 r
.74433 .27109 m .74329 .27015 L .74407 .26945 L closepath p F P
0 g
s
.89 .895 .827 r
.77732 .23054 m .77631 .23171 L .77714 .23623 L p F P
0 g
s
.881 .892 .835 r
.76902 .2397 m .76994 .24418 L .77714 .23623 L p F P
0 g
s
.881 .892 .835 r
.77714 .23623 m .77631 .23171 L .76902 .2397 L p F P
0 g
s
.969 .817 .636 r
.60024 .22089 m .60267 .22501 L .60491 .21874 L p F P
0 g
s
.969 .817 .636 r
.60491 .21874 m .60244 .21462 L .60024 .22089 L p F P
0 g
s
.131 .424 .867 r
.78653 .05303 m .78606 .0528 L .78318 .04835 L p F P
0 g
s
.999 .832 .528 r
.81494 .1332 m .81659 .13763 L .81795 .13167 L p F P
0 g
s
.999 .832 .528 r
.81795 .13167 m .81631 .12724 L .81494 .1332 L p F P
0 g
s
.812 .863 .886 r
.72194 .28786 m .71847 .29056 L .71555 .28779 L p F P
0 g
s
.131 .424 .867 r
.78318 .04835 m .784 .04875 L .78653 .05303 L p F P
0 g
s
0 .323 .81 r
.78937 .05226 m .79187 .05655 L .78653 .05303 L p F P
0 g
s
0 .323 .81 r
.78653 .05303 m .784 .04875 L .78937 .05226 L p F P
0 g
s
.6 .74 .943 r
.63109 .31703 m .64374 .31428 L .64684 .31798 L p F P
0 g
s
.578 .726 .944 r
.64374 .31428 m .63109 .31703 L .62794 .31269 L p F P
0 g
s
.816 .866 .884 r
.72194 .28786 m .7309 .28071 L .72801 .278 L p F P
0 g
s
.816 .866 .884 r
.72801 .278 m .72127 .28335 L .72194 .28786 L p F P
0 g
s
.812 .863 .886 r
.71555 .28779 m .72127 .28335 L .72194 .28786 L p F P
0 g
s
.913 .615 .126 r
.8121 .09714 m .81401 .10154 L .8133 .09633 L p F P
0 g
s
.913 .615 .126 r
.8133 .09633 m .81139 .09193 L .8121 .09714 L p F P
0 g
s
.989 .868 .622 r
.81647 .14852 m .81627 .14842 L .81636 .14817 L closepath p F P
0 g
s
.99 .764 .381 r
.6013 .26307 m .6031 .26733 L .60354 .26161 L p F P
0 g
s
.99 .764 .381 r
.60354 .26161 m .60172 .25735 L .6013 .26307 L p F P
0 g
s
.874 .886 .84 r
.7651 .24387 m .76902 .2397 L .76994 .24418 L p F P
0 g
s
.874 .886 .84 r
.76994 .24418 m .7679 .24635 L .7651 .24387 L p F P
0 g
s
.957 .893 .723 r
.80769 .17535 m .80581 .17877 L .80703 .18325 L p F P
0 g
s
.947 .892 .743 r
.80167 .18571 m .80293 .19017 L .80703 .18325 L p F P
0 g
s
.947 .892 .743 r
.80703 .18325 m .80581 .17877 L .80167 .18571 L p F P
0 g
s
.252 .449 .859 r
.62223 .3046 m .62346 .30804 L .61534 .305 L p F P
0 g
s
.252 .449 .859 r
.62162 .30368 m .62223 .3046 L p .61534 .305 L F P
0 g
s
.252 .449 .859 r
.61534 .305 m .6145 .30051 L .62162 .30368 L p F P
0 g
s
0 .168 .701 r
.61327 .29613 m .6145 .30051 L .61017 .29628 L p F P
0 g
s
0 .168 .701 r
.61017 .29628 m .60921 .29181 L .61327 .29613 L p F P
0 g
s
.984 .811 .589 r
.60118 .22957 m .60073 .2312 L .60309 .23533 L p F P
0 g
s
.989 .802 .561 r
.59932 .23722 m .60166 .24135 L .60309 .23533 L p F P
0 g
s
.989 .802 .561 r
.60309 .23533 m .60073 .2312 L .59932 .23722 L p F P
0 g
s
.867 .887 .848 r
.76198 .25239 m .7679 .24635 L .7651 .24387 L p F P
0 g
s
.925 .796 .699 r
.60438 .17698 m .60745 .18096 L .61068 .1744 L p F P
0 g
s
.925 .796 .699 r
.61068 .1744 m .60761 .17041 L .60438 .17698 L p F P
0 g
s
.988 .864 .625 r
.81367 .14693 m .8148 .14374 L .81636 .14817 L p F P
0 g
s
.988 .864 .625 r
.81636 .14817 m .81627 .14842 L .81367 .14693 L p F P
0 g
s
.728 .807 .914 r
.67148 .31157 m .66249 .31621 L .65943 .31286 L p F P
0 g
s
.686 .794 .932 r
.64684 .31798 m .65943 .31286 L .66249 .31621 L p F P
0 g
s
.987 .87 .631 r
.81397 .1545 m .81627 .14842 L .81367 .14693 L p F P
0 g
s
.917 .894 .791 r
.7879 .21188 m .79333 .20449 L .79443 .20897 L p F P
0 g
s
.917 .894 .791 r
.78876 .21524 m .7879 .21188 L p .79443 .20897 L F P
0 g
s
.917 .894 .791 r
.79443 .20897 m .78943 .21579 L .78876 .21524 L p F P
0 g
s
.936 .806 .691 r
.60355 .18903 m .60426 .18753 L .60712 .19157 L p F P
0 g
s
.936 .806 .691 r
.60712 .19157 m .60671 .19244 L .60355 .18903 L p F P
0 g
s
.826 .869 .877 r
.73358 .27847 m .7309 .28071 L .72801 .278 L p F P
0 g
s
.969 .882 .69 r
.80804 .16756 m .80945 .172 L .81258 .16542 L p F P
0 g
s
.969 .882 .69 r
.81258 .16542 m .81119 .16096 L .80804 .16756 L p F P
0 g
s
.867 .887 .848 r
.7651 .24387 m .76116 .24788 L .76198 .25239 L p F P
0 g
s
.862 .884 .852 r
.7528 .2562 m .76116 .24788 L .76198 .25239 L p F P
0 g
s
.862 .884 .852 r
.76198 .25239 m .75563 .2587 L .7528 .2562 L p F P
0 g
s
.831 .872 .874 r
.73358 .27847 m .74329 .27015 L .74042 .26748 L p F P
0 g
s
.831 .872 .874 r
.74042 .26748 m .73283 .27397 L .73358 .27847 L p F P
0 g
s
.826 .869 .877 r
.72801 .278 m .73283 .27397 L .73358 .27847 L p F P
0 g
s
0 .145 .686 r
.79599 .06051 m .79837 .06483 L .79427 .06086 L p F P
0 g
s
0 .145 .686 r
.79427 .06086 m .79187 .05655 L .79599 .06051 L p F P
0 g
s
.818 .479 0 r
.80937 .08754 m .81139 .09193 L .81001 .08696 L p F P
0 g
s
.818 .479 0 r
.81001 .08696 m .80799 .08258 L .80937 .08754 L p F P
0 g
s
.947 .798 .662 r
.60451 .19794 m .60671 .19244 L .60355 .18903 L p F P
0 g
s
.853 .885 .86 r
.75343 .26079 m .75563 .2587 L .7528 .2562 L p F P
0 g
s
0 0 .376 r
.60789 .28743 m .60921 .29181 L .60696 .28692 L p F P
0 g
s
.846 .881 .865 r
.74324 .26496 m .74407 .26945 L .75343 .26079 L p F P
0 g
s
.846 .881 .865 r
.75343 .26079 m .75274 .25625 L .74324 .26496 L p F P
0 g
s
.853 .885 .86 r
.7528 .2562 m .75274 .25625 L .75343 .26079 L p F P
0 g
s
.677 .787 .933 r
.65943 .31286 m .64684 .31798 L .64374 .31428 L p F P
0 g
s
.84 .873 .867 r
.74407 .26945 m .74329 .27015 L .74042 .26748 L p F P
0 g
s
.84 .873 .867 r
.74042 .26748 m .74324 .26496 L .74407 .26945 L p F P
0 g
s
.999 .805 .468 r
.81458 .12282 m .81631 .12724 L .81723 .12144 L p F P
0 g
s
.999 .805 .468 r
.81723 .12144 m .81551 .11701 L .81458 .12282 L p F P
0 g
s
.663 .293 0 r
.80585 .07821 m .80799 .08258 L .80583 .07789 L p F P
0 g
s
.663 .293 0 r
.80583 .07789 m .80369 .07353 L .80585 .07821 L p F P
0 g
s
0 0 .502 r
.80144 .06918 m .80369 .07353 L .80063 .06917 L p F P
0 g
s
0 0 .502 r
.80063 .06917 m .79837 .06483 L .80144 .06918 L p F P
0 g
s
.777 .84 .9 r
.69273 .30382 m .69057 .30524 L .68758 .30222 L p F P
0 g
s
.757 .837 .912 r
.67504 .30971 m .68758 .30222 L .69057 .30524 L p F P
0 g
s
.959 .806 .647 r
.59976 .21055 m .60244 .21462 L .60478 .20832 L p F P
0 g
s
.959 .806 .647 r
.60478 .20832 m .60208 .20426 L .59976 .21055 L p F P
0 g
s
.778 .843 .901 r
.69273 .30382 m .70307 .29686 L .70011 .29394 L p F P
0 g
s
.778 .843 .901 r
.70011 .29394 m .69199 .29934 L .69273 .30382 L p F P
0 g
s
.777 .84 .9 r
.68758 .30222 m .69199 .29934 L .69273 .30382 L p F P
0 g
s
.999 .788 .473 r
.59965 .25315 m .60172 .25735 L .60258 .25149 L p F P
0 g
s
.999 .788 .473 r
.60258 .25149 m .60049 .2473 L .59965 .25315 L p F P
0 g
s
.436 .616 .926 r
.62479 .30825 m .62346 .30804 L .62468 .31239 L p F P
0 g
s
.436 .616 .926 r
.62468 .31239 m .62794 .31269 L .62479 .30825 L p F P
0 g
s
.912 .896 .799 r
.78943 .21579 m .789 .21635 L .78876 .21524 L closepath p F P
0 g
s
.896 .891 .817 r
.78177 .21949 m .78282 .22397 L .789 .21635 L p F P
0 g
s
.896 .891 .817 r
.78668 .21343 m .78177 .21949 L p .789 .21635 L F P
0 g
s
.896 .891 .817 r
.789 .21635 m .78876 .21524 L .78668 .21343 L p F P
0 g
s
.975 .816 .622 r
.5982 .22711 m .60024 .22089 L .60267 .22501 L p F P
0 g
s
.975 .816 .622 r
.59871 .22798 m .5982 .22711 L p .60267 .22501 L F P
0 g
s
.975 .816 .622 r
.60267 .22501 m .60118 .22957 L .59871 .22798 L p F P
0 g
s
.939 .891 .756 r
.79721 .19276 m .80167 .18571 L .80293 .19017 L p F P
0 g
s
.939 .891 .756 r
.79835 .1967 m .79721 .19276 L p .80293 .19017 L F P
0 g
s
.939 .891 .756 r
.80293 .19017 m .79866 .19694 L .79835 .1967 L p F P
0 g
s
.832 .545 0 r
.60477 .27722 m .60325 .27288 L .6042 .27818 L p F P
0 g
s
.394 .605 .933 r
.764 .03707 m .77015 .03786 L .77288 .04211 L p F P
0 g
s
.305 .549 .919 r
.7774 .03966 m .77015 .03786 L .77288 .04211 L p F P
0 g
s
.305 .549 .919 r
.77288 .04211 m .78029 .04397 L .7774 .03966 L p F P
0 g
s
.392 .607 .934 r
.77015 .03786 m .764 .03707 L .7611 .03285 L p F P
0 g
s
.995 .848 .581 r
.81314 .13933 m .8148 .14374 L .81659 .13763 L p F P
0 g
s
.995 .848 .581 r
.81659 .13763 m .81494 .1332 L .81314 .13933 L p F P
0 g
s
.991 .766 .389 r
.81368 .11261 m .81551 .11701 L .81594 .11139 L p F P
0 g
s
.991 .766 .389 r
.81594 .11139 m .81412 .10698 L .81368 .11261 L p F P
0 g
s
.926 .796 .697 r
.60118 .18354 m .60426 .18753 L .60745 .18096 L p F P
0 g
s
.926 .796 .697 r
.60745 .18096 m .60438 .17698 L .60118 .18354 L p F P
0 g
s
.725 .816 .922 r
.67148 .31157 m .67504 .30971 L .67202 .30655 L p F P
0 g
s
.725 .816 .922 r
.67202 .30655 m .67132 .30691 L .67148 .31157 L p F P
0 g
s
.728 .807 .914 r
.65943 .31286 m .67132 .30691 L .67148 .31157 L p F P
0 g
s
.959 .884 .715 r
.80501 .17334 m .80804 .16756 L .80945 .172 L p F P
0 g
s
.959 .884 .715 r
.80945 .172 m .80769 .17535 L .80501 .17334 L p F P
0 g
s
.987 .87 .631 r
.81367 .14693 m .8125 .15004 L .81397 .1545 L p F P
0 g
s
.976 .876 .668 r
.80969 .15652 m .81119 .16096 L .81397 .1545 L p F P
0 g
s
.976 .876 .668 r
.81397 .1545 m .8125 .15004 L .80969 .15652 L p F P
0 g
s
.794 .851 .893 r
.70814 .29322 m .70307 .29686 L .70011 .29394 L p F P
0 g
s
.95 .796 .655 r
.59918 .20024 m .60208 .20426 L .60451 .19794 L p F P
0 g
s
.95 .796 .655 r
.60451 .19794 m .6016 .19392 L .59918 .20024 L p F P
0 g
s
.947 .798 .662 r
.60355 .18903 m .6016 .19392 L .60451 .19794 L p F P
0 g
s
.895 .889 .818 r
.77529 .22723 m .78177 .21949 L .78282 .22397 L p F P
0 g
s
.895 .889 .818 r
.77578 .2292 m .77529 .22723 L p .78282 .22397 L F P
0 g
s
.895 .889 .818 r
.78282 .22397 m .77732 .23054 L .77578 .2292 L p F P
0 g
s
.906 .888 .803 r
.78876 .21524 m .78668 .21343 L .7879 .21188 L closepath p F P
0 g
s
.994 .793 .529 r
.59817 .24316 m .60049 .2473 L .60166 .24135 L p F P
0 g
s
.994 .793 .529 r
.60166 .24135 m .59932 .23722 L .59817 .24316 L p F P
0 g
s
.959 .699 .256 r
.60145 .26862 m .60325 .27288 L .6031 .26733 L p F P
0 g
s
.959 .699 .256 r
.6031 .26733 m .6013 .26307 L .60145 .26862 L p F P
0 g
s
.127 .427 .869 r
.784 .04875 m .78318 .04835 L .78029 .04397 L p F P
0 g
s
.755 .832 .911 r
.68758 .30222 m .67504 .30971 L .67202 .30655 L p F P
0 g
s
.797 .855 .893 r
.70814 .29322 m .71555 .28779 L .71262 .28495 L p F P
0 g
s
.797 .855 .893 r
.71262 .28495 m .70743 .28872 L .70814 .29322 L p F P
0 g
s
.794 .851 .893 r
.70011 .29394 m .70743 .28872 L .70814 .29322 L p F P
0 g
s
.97 .708 .284 r
.8122 .10258 m .81412 .10698 L .81401 .10154 L p F P
0 g
s
.97 .708 .284 r
.81401 .10154 m .8121 .09714 L .8122 .10258 L p F P
0 g
s
.578 .726 .944 r
.62794 .31269 m .64063 .3105 L .64374 .31428 L p F P
0 g
s
.553 .711 .945 r
.64063 .3105 m .62794 .31269 L .62479 .30825 L p F P
0 g
s
.934 .894 .766 r
.79866 .19694 m .79849 .19721 L .79835 .1967 L closepath p F P
0 g
s
.918 .89 .788 r
.79213 .20003 m .79333 .20449 L .79849 .19721 L p F P
0 g
s
.918 .89 .788 r
.79594 .19463 m .79213 .20003 L p .79849 .19721 L F P
0 g
s
.918 .89 .788 r
.79849 .19721 m .79835 .1967 L .79594 .19463 L p F P
0 g
s
.964 .805 .637 r
.59757 .21682 m .60024 .22089 L .60244 .21462 L p F P
0 g
s
.964 .805 .637 r
.60244 .21462 m .59976 .21055 L .59757 .21682 L p F P
0 g
s
.956 .888 .723 r
.80581 .17877 m .80769 .17535 L .80501 .17334 L p F P
0 g
s
.979 .801 .593 r
.60118 .22957 m .60073 .2312 L .59871 .22798 L closepath p F P
0 g
s
.889 .891 .826 r
.77732 .23054 m .77631 .23171 L .77578 .2292 L closepath p F P
0 g
s
.999 .829 .535 r
.8132 .1288 m .81494 .1332 L .81631 .12724 L p F P
0 g
s
.999 .829 .535 r
.81631 .12724 m .81458 .12282 L .8132 .1288 L p F P
0 g
s
.127 .427 .869 r
.78029 .04397 m .78136 .04449 L .784 .04875 L p F P
0 g
s
0 .322 .81 r
.78675 .04798 m .78937 .05226 L .784 .04875 L p F P
0 g
s
0 .322 .81 r
.784 .04875 m .78136 .04449 L .78675 .04798 L p F P
0 g
s
.874 .884 .839 r
.76799 .23523 m .76902 .2397 L .77631 .23171 L p F P
0 g
s
.874 .884 .839 r
.77454 .22807 m .76799 .23523 L p .77631 .23171 L F P
0 g
s
.874 .884 .839 r
.77631 .23171 m .77578 .2292 L .77454 .22807 L p F P
0 g
s
.926 .887 .774 r
.79835 .1967 m .79594 .19463 L .79721 .19276 L closepath p F P
0 g
s
.81 .859 .885 r
.72127 .28335 m .71555 .28779 L .71262 .28495 L p F P
0 g
s
.922 .619 .143 r
.81008 .09277 m .8121 .09714 L .81139 .09193 L p F P
0 g
s
.922 .619 .143 r
.81007 .09271 m .81008 .09277 L p .81139 .09193 L F P
0 g
s
.922 .619 .143 r
.81139 .09193 m .80937 .08754 L .81007 .09271 L p F P
0 g
s
.985 .791 .561 r
.59677 .23313 m .59932 .23722 L .60073 .2312 L p F P
0 g
s
.985 .791 .561 r
.59805 .22764 m .59677 .23313 L p .60073 .2312 L F P
0 g
s
.985 .791 .561 r
.60073 .2312 m .59871 .22798 L .59805 .22764 L p F P
0 g
s
.994 .758 .401 r
.59924 .25887 m .6013 .26307 L .60172 .25735 L p F P
0 g
s
.994 .758 .401 r
.60172 .25735 m .59965 .25315 L .59924 .25887 L p F P
0 g
s
.93 .795 .69 r
.60038 .18526 m .60118 .18354 L .60426 .18753 L p F P
0 g
s
.93 .795 .69 r
.60426 .18753 m .60355 .18903 L .60038 .18526 L p F P
0 g
s
.722 .801 .914 r
.67132 .30691 m .65943 .31286 L .65636 .30943 L p F P
0 g
s
.677 .787 .933 r
.64374 .31428 m .65636 .30943 L .65943 .31286 L p F P
0 g
s
.956 .888 .723 r
.80501 .17334 m .80449 .1743 L .80581 .17877 L p F P
0 g
s
.944 .887 .745 r
.80031 .18126 m .80167 .18571 L .80581 .17877 L p F P
0 g
s
.944 .887 .745 r
.80581 .17877 m .80449 .1743 L .80031 .18126 L p F P
0 g
s
.814 .862 .884 r
.72127 .28335 m .72801 .278 L .7251 .27522 L p F P
0 g
s
.814 .862 .884 r
.7251 .27522 m .7205 .27885 L .72127 .28335 L p F P
0 g
s
.81 .859 .885 r
.71262 .28495 m .7205 .27885 L .72127 .28335 L p F P
0 g
s
.873 .882 .839 r
.76228 .2413 m .76799 .23523 L .76902 .2397 L p F P
0 g
s
.873 .882 .839 r
.76902 .2397 m .7651 .24387 L .76228 .2413 L p F P
0 g
s
.987 .859 .624 r
.81104 .14531 m .81314 .13933 L .8148 .14374 L p F P
0 g
s
.987 .859 .624 r
.8148 .14374 m .81367 .14693 L .81104 .14531 L p F P
0 g
s
0 .141 .682 r
.79351 .05621 m .79599 .06051 L .79187 .05655 L p F P
0 g
s
0 .141 .682 r
.79187 .05655 m .78937 .05226 L .79351 .05621 L p F P
0 g
s
.667 .78 .934 r
.65636 .30943 m .64374 .31428 L .64063 .3105 L p F P
0 g
s
.828 .481 0 r
.80858 .08591 m .80937 .08754 L .80799 .08258 L p F P
0 g
s
.828 .481 0 r
.80659 .08081 m .80858 .08591 L p .80799 .08258 L F P
0 g
s
.828 .481 0 r
.80799 .08258 m .80585 .07821 L .80659 .08081 L p F P
0 g
s
0 .111 .664 r
.61171 .29183 m .61327 .29613 L .60921 .29181 L p F P
0 g
s
0 .111 .664 r
.60921 .29181 m .60789 .28743 L .61171 .29183 L p F P
0 g
s
.192 .451 .876 r
.61843 .29888 m .61327 .29613 L .6145 .30051 L p F P
0 g
s
.192 .451 .876 r
.6145 .30051 m .62162 .30368 L .61843 .29888 L p F P
0 g
s
.967 .877 .693 r
.80652 .16314 m .80804 .16756 L .81119 .16096 L p F P
0 g
s
.967 .877 .693 r
.81119 .16096 m .80969 .15652 L .80652 .16314 L p F P
0 g
s
.866 .883 .847 r
.76116 .24788 m .7651 .24387 L .76228 .2413 L p F P
0 g
s
.914 .888 .792 r
.78665 .20743 m .7879 .21188 L .79333 .20449 L p F P
0 g
s
.914 .888 .792 r
.79333 .20449 m .79213 .20003 L .78665 .20743 L p F P
0 g
s
.942 .788 .662 r
.6016 .19392 m .60355 .18903 L .60038 .18526 L p F P
0 g
s
.825 .865 .876 r
.73283 .27397 m .72801 .278 L .7251 .27522 L p F P
0 g
s
0 0 .492 r
.79907 .06486 m .80144 .06918 L .79837 .06483 L p F P
0 g
s
0 0 .492 r
.79837 .06483 m .79599 .06051 L .79907 .06486 L p F P
0 g
s
.68 .301 0 r
.80392 .07447 m .80585 .07821 L .80369 .07353 L p F P
0 g
s
.68 .301 0 r
.8035 .07362 m .80392 .07447 L p .80369 .07353 L F P
0 g
s
.68 .301 0 r
.80369 .07353 m .80144 .06918 L .8035 .07362 L p F P
0 g
s
.866 .883 .847 r
.76228 .2413 m .76024 .24339 L .76116 .24788 L p F P
0 g
s
.86 .88 .851 r
.75172 .2518 m .76024 .24339 L .76116 .24788 L p F P
0 g
s
.86 .88 .851 r
.75272 .25613 m .75172 .2518 L p .76116 .24788 L F P
0 g
s
.86 .88 .851 r
.76116 .24788 m .7528 .2562 L .75272 .25613 L p F P
0 g
s
.954 .795 .647 r
.59687 .20654 m .59976 .21055 L .60208 .20426 L p F P
0 g
s
.954 .795 .647 r
.60208 .20426 m .59918 .20024 L .59687 .20654 L p F P
0 g
s
.83 .868 .874 r
.73283 .27397 m .74042 .26748 L .73754 .26475 L p F P
0 g
s
.83 .868 .874 r
.73754 .26475 m .73197 .26949 L .73283 .27397 L p F P
0 g
s
.825 .865 .876 r
.7251 .27522 m .73197 .26949 L .73283 .27397 L p F P
0 g
s
1 .803 .476 r
.81274 .11842 m .81458 .12282 L .81551 .11701 L p F P
0 g
s
1 .803 .476 r
.81551 .11701 m .81368 .11261 L .81274 .11842 L p F P
0 g
s
.774 .836 .9 r
.69199 .29934 m .68758 .30222 L .68458 .29913 L p F P
0 g
s
.755 .832 .911 r
.67202 .30655 m .68458 .29913 L .68758 .30222 L p F P
0 g
s
0 0 .306 r
.60625 .28314 m .60789 .28743 L .60574 .28251 L p F P
0 g
s
.839 .87 .866 r
.74324 .26496 m .74042 .26748 L .73754 .26475 L p F P
0 g
s
.852 .88 .859 r
.7528 .2562 m .75274 .25625 L .75272 .25613 L closepath p F P
0 g
s
.839 .873 .868 r
.74229 .2605 m .74324 .26496 L .75274 .25625 L p F P
0 g
s
.839 .873 .868 r
.74994 .25349 m .74229 .2605 L p .75274 .25625 L F P
0 g
s
.839 .873 .868 r
.75274 .25625 m .75272 .25613 L .74994 .25349 L p F P
0 g
s
.839 .87 .866 r
.73754 .26475 m .74229 .2605 L .74324 .26496 L p F P
0 g
s
.851 .873 .856 r
.75272 .25613 m .74994 .25349 L .75172 .2518 L closepath p F P
0 g
s
.996 .778 .484 r
.59735 .24901 m .59965 .25315 L .60049 .2473 L p F P
0 g
s
.996 .778 .484 r
.60049 .2473 m .59817 .24316 L .59735 .24901 L p F P
0 g
s
.302 .552 .922 r
.77451 .03541 m .7673 .03364 L .77015 .03786 L p F P
0 g
s
.302 .552 .922 r
.77015 .03786 m .7774 .03966 L .77451 .03541 L p F P
0 g
s
.392 .607 .934 r
.7611 .03285 m .7673 .03364 L .77015 .03786 L p F P
0 g
s
.986 .864 .632 r
.8125 .15004 m .81367 .14693 L .81104 .14531 L p F P
0 g
s
.969 .803 .623 r
.59556 .22303 m .5982 .22711 L .60024 .22089 L p F P
0 g
s
.969 .803 .623 r
.60024 .22089 m .59757 .21682 L .59556 .22303 L p F P
0 g
s
.775 .84 .901 r
.69199 .29934 m .70011 .29394 L .69713 .29096 L p F P
0 g
s
.775 .84 .901 r
.69713 .29096 m .69117 .29487 L .69199 .29934 L p F P
0 g
s
.774 .836 .9 r
.68458 .29913 m .69117 .29487 L .69199 .29934 L p F P
0 g
s
.396 .589 .921 r
.62346 .30804 m .62223 .3046 L .62479 .30825 L closepath p F P
0 g
s
.936 .885 .758 r
.79582 .18833 m .79721 .19276 L .80167 .18571 L p F P
0 g
s
.936 .885 .758 r
.80167 .18571 m .80031 .18126 L .79582 .18833 L p F P
0 g
s
.904 .884 .803 r
.78392 .21094 m .78665 .20743 L .7879 .21188 L p F P
0 g
s
.904 .884 .803 r
.7879 .21188 m .78668 .21343 L .78392 .21094 L p F P
0 g
s
.877 .573 .057 r
.60237 .27394 m .6042 .27818 L .60325 .27288 L p F P
0 g
s
.877 .573 .057 r
.60325 .27288 m .60145 .26862 L .60237 .27394 L p F P
0 g
s
.884 .883 .827 r
.77578 .2292 m .77454 .22807 L .77529 .22723 L closepath p F P
0 g
s
.994 .844 .586 r
.81138 .13493 m .81314 .13933 L .81494 .1332 L p F P
0 g
s
.994 .844 .586 r
.81494 .1332 m .8132 .1288 L .81138 .13493 L p F P
0 g
s
.993 .765 .4 r
.81175 .10822 m .81368 .11261 L .81412 .10698 L p F P
0 g
s
.993 .765 .4 r
.81412 .10698 m .8122 .10258 L .81175 .10822 L p F P
0 g
s
.9 .886 .81 r
.78177 .21949 m .78668 .21343 L .78392 .21094 L p F P
0 g
s
.944 .787 .655 r
.59608 .19628 m .59918 .20024 L .6016 .19392 L p F P
0 g
s
.944 .787 .655 r
.6016 .19392 m .59851 .18995 L .59608 .19628 L p F P
0 g
s
.942 .788 .662 r
.60038 .18526 m .59851 .18995 L .6016 .19392 L p F P
0 g
s
.553 .711 .945 r
.62479 .30825 m .6375 .30664 L .64063 .3105 L p F P
0 g
s
.565 .677 .914 r
.62223 .3046 m .62479 .30825 L .6375 .30664 L p F P
0 g
s
.121 .428 .87 r
.78136 .04449 m .78029 .04397 L .7774 .03966 L p F P
0 g
s
.958 .879 .714 r
.80299 .16988 m .80652 .16314 L .80804 .16756 L p F P
0 g
s
.958 .879 .714 r
.80389 .17245 m .80299 .16988 L p .80804 .16756 L F P
0 g
s
.958 .879 .714 r
.80804 .16756 m .80501 .17334 L .80389 .17245 L p F P
0 g
s
.986 .864 .632 r
.81104 .14531 m .81093 .1456 L .8125 .15004 L p F P
0 g
s
.974 .871 .671 r
.80809 .1521 m .80969 .15652 L .8125 .15004 L p F P
0 g
s
.974 .871 .671 r
.8125 .15004 m .81093 .1456 L .80809 .1521 L p F P
0 g
s
.989 .783 .535 r
.59563 .23908 m .59817 .24316 L .59932 .23722 L p F P
0 g
s
.989 .783 .535 r
.59932 .23722 m .59677 .23313 L .59563 .23908 L p F P
0 g
s
.792 .847 .892 r
.70743 .28872 m .70011 .29394 L .69713 .29096 L p F P
0 g
s
.725 .815 .921 r
.67202 .30655 m .67132 .30691 L .67127 .30576 L closepath p F P
0 g
s
.722 .801 .914 r
.66897 .30328 m .67127 .30576 L .67132 .30691 L p F P
0 g
s
.722 .801 .914 r
.65636 .30943 m .66897 .30328 L p .67132 .30691 L F P
0 g
s
.9 .886 .81 r
.78392 .21094 m .78061 .21503 L .78177 .21949 L p F P
0 g
s
.892 .883 .818 r
.77407 .22279 m .77529 .22723 L .78177 .21949 L p F P
0 g
s
.892 .883 .818 r
.78177 .21949 m .78061 .21503 L .77407 .22279 L p F P
0 g
s
.757 .823 .904 r
.68156 .29598 m .68458 .29913 L .67202 .30655 L p F P
0 g
s
.757 .823 .904 r
.67038 .30247 m .68156 .29598 L p .67202 .30655 L F P
0 g
s
.757 .823 .904 r
.67202 .30655 m .67127 .30576 L .67038 .30247 L p F P
0 g
s
.972 .702 .288 r
.59939 .26443 m .60145 .26862 L .6013 .26307 L p F P
0 g
s
.972 .702 .288 r
.6013 .26307 m .59924 .25887 L .59939 .26443 L p F P
0 g
s
.975 .711 .301 r
.81017 .0982 m .8122 .10258 L .8121 .09714 L p F P
0 g
s
.975 .711 .301 r
.81008 .0928 m .81017 .0982 L p .8121 .09714 L F P
0 g
s
.975 .711 .301 r
.8121 .09714 m .81008 .09277 L .81008 .0928 L p F P
0 g
s
.957 .794 .637 r
.59469 .2128 m .59757 .21682 L .59976 .21055 L p F P
0 g
s
.957 .794 .637 r
.59976 .21055 m .59687 .20654 L .59469 .2128 L p F P
0 g
s
.983 .81 .593 r
.59871 .22798 m .59805 .22764 L .5982 .22711 L closepath p F P
0 g
s
.121 .428 .87 r
.7774 .03966 m .77862 .04024 L .78136 .04449 L p F P
0 g
s
0 .321 .808 r
.78403 .04373 m .78675 .04798 L .78136 .04449 L p F P
0 g
s
0 .321 .808 r
.78136 .04449 m .77862 .04024 L .78403 .04373 L p F P
0 g
s
.925 .882 .773 r
.7932 .1922 m .79582 .18833 L .79721 .19276 L p F P
0 g
s
.925 .882 .773 r
.79721 .19276 m .79594 .19463 L .7932 .1922 L p F P
0 g
s
.795 .851 .893 r
.70743 .28872 m .71262 .28495 L .70967 .28204 L p F P
0 g
s
.795 .851 .893 r
.70967 .28204 m .70663 .28423 L .70743 .28872 L p F P
0 g
s
.792 .847 .892 r
.69713 .29096 m .70663 .28423 L .70743 .28872 L p F P
0 g
s
.998 .825 .541 r
.81134 .12441 m .8132 .1288 L .81458 .12282 L p F P
0 g
s
.998 .825 .541 r
.81458 .12282 m .81274 .11842 L .81134 .12441 L p F P
0 g
s
.921 .885 .781 r
.79213 .20003 m .79594 .19463 L .7932 .1922 L p F P
0 g
s
.931 .623 .159 r
.80937 .08754 m .80858 .08591 L .81007 .09271 L closepath p F P
0 g
s
.883 .879 .826 r
.77174 .22544 m .77407 .22279 L .77529 .22723 L p F P
0 g
s
.883 .879 .826 r
.77529 .22723 m .77454 .22807 L .77174 .22544 L p F P
0 g
s
.748 .818 .907 r
.67127 .30576 m .66897 .30328 L .67038 .30247 L closepath p F P
0 g
s
.877 .88 .833 r
.76799 .23523 m .77454 .22807 L .77174 .22544 L p F P
0 g
s
.976 .798 .598 r
.5949 .22537 m .59556 .22303 L .5982 .22711 L p F P
0 g
s
.976 .798 .598 r
.5982 .22711 m .59805 .22764 L .5949 .22537 L p F P
0 g
s
.809 .855 .884 r
.7205 .27885 m .71262 .28495 L .70967 .28204 L p F P
0 g
s
.713 .805 .922 r
.66897 .30328 m .65636 .30943 L .65328 .30593 L p F P
0 g
s
.667 .78 .934 r
.64063 .3105 m .65328 .30593 L .65636 .30943 L p F P
0 g
s
.954 .882 .723 r
.80501 .17334 m .80449 .1743 L .80389 .17245 L closepath p F P
0 g
s
.994 .752 .418 r
.59694 .25474 m .59924 .25887 L .59965 .25315 L p F P
0 g
s
.994 .752 .418 r
.59965 .25315 m .59735 .24901 L .59694 .25474 L p F P
0 g
s
.656 .773 .935 r
.65328 .30593 m .64063 .3105 L .6375 .30664 L p F P
0 g
s
0 .136 .676 r
.79091 .05193 m .79351 .05621 L .78937 .05226 L p F P
0 g
s
0 .136 .676 r
.78937 .05226 m .78675 .04798 L .79091 .05193 L p F P
0 g
s
.979 .784 .571 r
.59677 .23313 m .59805 .22764 L .5949 .22537 L p F P
0 g
s
.938 .881 .752 r
.79884 .17683 m .80031 .18126 L .80449 .1743 L p F P
0 g
s
.938 .881 .752 r
.80231 .17106 m .79884 .17683 L p .80449 .1743 L F P
0 g
s
.938 .881 .752 r
.80449 .1743 m .80389 .17245 L .80231 .17106 L p F P
0 g
s
.842 .49 0 r
.80585 .07821 m .80392 .07447 L .80659 .08081 L closepath p F P
0 g
s
.986 .854 .624 r
.80917 .14121 m .81138 .13493 L .81314 .13933 L p F P
0 g
s
.986 .854 .624 r
.81074 .1451 m .80917 .14121 L p .81314 .13933 L F P
0 g
s
.986 .854 .624 r
.81314 .13933 m .81104 .14531 L .81074 .1451 L p F P
0 g
s
.877 .88 .833 r
.77174 .22544 m .76685 .23078 L .76799 .23523 L p F P
0 g
s
.872 .878 .838 r
.75945 .23866 m .76685 .23078 L .76799 .23523 L p F P
0 g
s
.872 .878 .838 r
.76799 .23523 m .76228 .2413 L .75945 .23866 L p F P
0 g
s
0 0 .48 r
.7966 .06055 m .79907 .06486 L .79599 .06051 L p F P
0 g
s
0 0 .48 r
.79599 .06051 m .79351 .05621 L .7966 .06055 L p F P
0 g
s
.947 .785 .648 r
.59377 .20258 m .59687 .20654 L .59918 .20024 L p F P
0 g
s
.947 .785 .648 r
.59918 .20024 m .59608 .19628 L .59377 .20258 L p F P
0 g
s
.812 .859 .883 r
.7205 .27885 m .7251 .27522 L .72217 .27237 L p F P
0 g
s
.812 .859 .883 r
.72217 .27237 m .71963 .27437 L .7205 .27885 L p F P
0 g
s
.809 .855 .884 r
.70967 .28204 m .71963 .27437 L .7205 .27885 L p F P
0 g
s
.695 .31 0 r
.80053 .06793 m .79907 .06486 L .80144 .06918 L p F P
0 g
s
.695 .31 0 r
.80144 .06918 m .8035 .07362 L .80053 .06793 L p F P
0 g
s
.965 .872 .696 r
.80489 .15873 m .80652 .16314 L .80969 .15652 L p F P
0 g
s
.965 .872 .696 r
.80969 .15652 m .80809 .1521 L .80489 .15873 L p F P
0 g
s
0 .054 .62 r
.60988 .28761 m .61171 .29183 L .60789 .28743 L p F P
0 g
s
0 .054 .62 r
.60789 .28743 m .60625 .28314 L .60988 .28761 L p F P
0 g
s
.122 .403 .853 r
.61524 .29401 m .61171 .29183 L .61327 .29613 L p F P
0 g
s
.122 .403 .853 r
.61327 .29613 m .61843 .29888 L .61524 .29401 L p F P
0 g
s
.921 .885 .781 r
.7932 .1922 m .79081 .19558 L .79213 .20003 L p F P
0 g
s
.912 .883 .792 r
.78529 .20301 m .78665 .20743 L .79213 .20003 L p F P
0 g
s
.912 .883 .792 r
.79213 .20003 m .79081 .19558 L .78529 .20301 L p F P
0 g
s
1 .8 .485 r
.8108 .11404 m .81274 .11842 L .81368 .11261 L p F P
0 g
s
1 .8 .485 r
.81368 .11261 m .81175 .10822 L .8108 .11404 L p F P
0 g
s
.824 .861 .874 r
.73197 .26949 m .7251 .27522 L .72217 .27237 L p F P
0 g
s
.865 .879 .846 r
.76024 .24339 m .76228 .2413 L .75945 .23866 L p F P
0 g
s
.485 .626 .913 r
.62162 .30368 m .62217 .30369 L .62223 .3046 L closepath p F P
0 g
s
.565 .677 .914 r
.63437 .30271 m .62217 .30369 L .62223 .3046 L p F P
0 g
s
.565 .677 .914 r
.6375 .30664 m .63437 .30271 L p .62223 .3046 L F P
0 g
s
.771 .832 .899 r
.69117 .29487 m .68458 .29913 L .68156 .29598 L p F P
0 g
s
.865 .879 .846 r
.75945 .23866 m .75921 .23891 L .76024 .24339 L p F P
0 g
s
.857 .875 .852 r
.75058 .24736 m .75172 .2518 L .76024 .24339 L p F P
0 g
s
.857 .875 .852 r
.76024 .24339 m .75921 .23891 L .75058 .24736 L p F P
0 g
s
.828 .864 .873 r
.73197 .26949 m .73754 .26475 L .73465 .26194 L p F P
0 g
s
.828 .864 .873 r
.73465 .26194 m .73101 .26503 L .73197 .26949 L p F P
0 g
s
.824 .861 .874 r
.72217 .27237 m .73101 .26503 L .73197 .26949 L p F P
0 g
s
.745 .382 0 r
.60219 .27477 m .60434 .27892 L .60237 .27394 L p F P
0 g
s
0 0 .519 r
.60434 .27892 m .60219 .27477 L .60281 .27562 L p F P
0 g
s
.684 .339 0 r
.60587 .28221 m .6042 .27818 L p .60434 .27892 L F P
0 g
s
.684 .339 0 r
.6042 .27818 m .60237 .27394 L .60434 .27892 L p F P
0 g
s
0 0 .519 r
.60281 .27562 m .60552 .27933 L p .60434 .27892 L F P
0 g
s
.684 .339 0 r
.60434 .27892 m .60625 .28314 L .60587 .28221 L p F P
0 g
s
.942 .633 .185 r
.80787 .08842 m .80719 .08319 L .80858 .08591 L p F P
0 g
s
.942 .633 .185 r
.81007 .09276 m .80787 .08842 L p .80858 .08591 L F P
0 g
s
.942 .633 .185 r
.80858 .08591 m .81007 .09271 L .81007 .09276 L p F P
0 g
s
.865 .521 .012 r
.80659 .08081 m .80719 .08319 L .80858 .08591 L closepath p F P
0 g
s
.993 .769 .494 r
.59482 .24493 m .59735 .24901 L .59817 .24316 L p F P
0 g
s
.993 .769 .494 r
.59817 .24316 m .59563 .23908 L .59482 .24493 L p F P
0 g
s
.838 .866 .865 r
.74229 .2605 m .73754 .26475 L .73465 .26194 L p F P
0 g
s
.85 .869 .854 r
.74708 .25072 m .75058 .24736 L .75172 .2518 L p F P
0 g
s
.85 .869 .854 r
.75172 .2518 m .74994 .25349 L .74708 .25072 L p F P
0 g
s
.962 .791 .624 r
.59268 .21902 m .59556 .22303 L .59757 .21682 L p F P
0 g
s
.962 .791 .624 r
.59757 .21682 m .59469 .2128 L .59268 .21902 L p F P
0 g
s
.842 .868 .862 r
.74229 .2605 m .74994 .25349 L .74708 .25072 L p F P
0 g
s
.842 .868 .862 r
.74708 .25072 m .74123 .25605 L .74229 .2605 L p F P
0 g
s
.838 .866 .865 r
.73465 .26194 m .74123 .25605 L .74229 .2605 L p F P
0 g
s
.449 .606 .913 r
.62217 .30369 m .62162 .30368 L .61843 .29888 L p F P
0 g
s
.449 .606 .913 r
.61843 .29888 m .62145 .29914 L .62217 .30369 L p F P
0 g
s
.528 .693 .944 r
.63122 .29872 m .62145 .29914 L .62217 .30369 L p F P
0 g
s
.528 .693 .944 r
.62217 .30369 m .63437 .30271 L .63122 .29872 L p F P
0 g
s
.933 .88 .759 r
.79431 .18392 m .79582 .18833 L .80031 .18126 L p F P
0 g
s
.933 .88 .759 r
.80031 .18126 m .79884 .17683 L .79431 .18392 L p F P
0 g
s
.772 .837 .901 r
.69117 .29487 m .69713 .29096 L .69414 .2879 L p F P
0 g
s
.772 .837 .901 r
.69414 .2879 m .69028 .2904 L .69117 .29487 L p F P
0 g
s
.771 .832 .899 r
.68156 .29598 m .69028 .2904 L .69117 .29487 L p F P
0 g
s
.995 .764 .41 r
.80971 .10385 m .81175 .10822 L .8122 .10258 L p F P
0 g
s
.995 .764 .41 r
.8122 .10258 m .81017 .0982 L .80971 .10385 L p F P
0 g
s
.992 .839 .591 r
.80952 .13055 m .81138 .13493 L .8132 .1288 L p F P
0 g
s
.992 .839 .591 r
.8132 .1288 m .81134 .12441 L .80952 .13055 L p F P
0 g
s
.908 .592 .106 r
.60028 .26976 m .60237 .27394 L .60145 .26862 L p F P
0 g
s
.908 .592 .106 r
.60145 .26862 m .59939 .26443 L .60028 .26976 L p F P
0 g
s
.903 .88 .801 r
.78114 .20835 m .78529 .20301 L .78665 .20743 L p F P
0 g
s
.903 .88 .801 r
.78665 .20743 m .78392 .21094 L .78114 .20835 L p F P
0 g
s
.945 .877 .737 r
.80389 .17245 m .80231 .17106 L .80299 .16988 L closepath p F P
0 g
s
.114 .427 .87 r
.77862 .04024 m .7774 .03966 L .77451 .03541 L p F P
0 g
s
.878 .529 .034 r
.80392 .07447 m .80659 .08081 L .80719 .08319 L p F P
0 g
s
.984 .859 .635 r
.81104 .14531 m .81093 .1456 L .81074 .1451 L closepath p F P
0 g
s
.979 .784 .571 r
.5949 .22537 m .59402 .2291 L .59677 .23313 L p F P
0 g
s
.984 .773 .541 r
.5929 .23505 m .59563 .23908 L .59677 .23313 L p F P
0 g
s
.984 .773 .541 r
.59677 .23313 m .59402 .2291 L .5929 .23505 L p F P
0 g
s
.898 .881 .809 r
.78061 .21503 m .78392 .21094 L .78114 .20835 L p F P
0 g
s
.955 .872 .715 r
.80134 .16548 m .80299 .16988 L .80652 .16314 L p F P
0 g
s
.955 .872 .715 r
.80652 .16314 m .80489 .15873 L .80134 .16548 L p F P
0 g
s
.969 .866 .68 r
.80639 .14769 m .80809 .1521 L .81093 .1456 L p F P
0 g
s
.969 .866 .68 r
.80836 .14316 m .80639 .14769 L p .81093 .1456 L F P
0 g
s
.969 .866 .68 r
.81093 .1456 m .81074 .1451 L .80836 .14316 L p F P
0 g
s
.79 .843 .892 r
.70663 .28423 m .69713 .29096 L .69414 .2879 L p F P
0 g
s
.747 .814 .905 r
.67038 .30247 m .66897 .30328 L .66591 .29993 L p F P
0 g
s
.713 .805 .922 r
.65328 .30593 m .66591 .29993 L .66897 .30328 L p F P
0 g
s
.951 .783 .638 r
.59159 .20885 m .59469 .2128 L .59687 .20654 L p F P
0 g
s
.951 .783 .638 r
.59687 .20654 m .59377 .20258 L .59159 .20885 L p F P
0 g
s
.933 .629 .166 r
.81007 .09271 m .81007 .09276 L .81008 .09277 L closepath p F P
0 g
s
.976 .707 .302 r
.81008 .09277 m .81008 .0928 L .81007 .09276 L closepath p F P
0 g
s
.978 .707 .311 r
.80799 .09386 m .80787 .08842 L .81007 .09276 L p F P
0 g
s
.978 .707 .311 r
.8091 .09604 m .80799 .09386 L p .81007 .09276 L F P
0 g
s
.978 .707 .311 r
.81007 .09276 m .81008 .0928 L .8091 .09604 L p F P
0 g
s
.978 .709 .31 r
.81008 .0928 m .81017 .0982 L .8091 .09604 L closepath p F P
0 g
s
.979 .702 .315 r
.59709 .2603 m .59939 .26443 L .59924 .25887 L p F P
0 g
s
.979 .702 .315 r
.59924 .25887 m .59694 .25474 L .59709 .2603 L p F P
0 g
s
.114 .427 .87 r
.77451 .03541 m .77578 .03601 L .77862 .04024 L p F P
0 g
s
0 .318 .806 r
.78119 .0395 m .78403 .04373 L .77862 .04024 L p F P
0 g
s
0 .318 .806 r
.77862 .04024 m .77578 .03601 L .78119 .0395 L p F P
0 g
s
.974 .858 .663 r
.81074 .1451 m .80836 .14316 L .80917 .14121 L closepath p F P
0 g
s
.898 .881 .809 r
.78114 .20835 m .77933 .21059 L .78061 .21503 L p F P
0 g
s
.89 .878 .818 r
.77273 .21838 m .77407 .22279 L .78061 .21503 L p F P
0 g
s
.89 .878 .818 r
.78061 .21503 m .77933 .21059 L .77273 .21838 L p F P
0 g
s
.746 .816 .907 r
.67038 .30247 m .68156 .29598 L .67853 .29275 L p F P
0 g
s
.746 .816 .907 r
.67853 .29275 m .6691 .29813 L .67038 .30247 L p F P
0 g
s
.747 .814 .905 r
.66591 .29993 m .6691 .29813 L .67038 .30247 L p F P
0 g
s
.997 .821 .547 r
.80939 .12004 m .81134 .12441 L .81274 .11842 L p F P
0 g
s
.997 .821 .547 r
.81274 .11842 m .8108 .11404 L .80939 .12004 L p F P
0 g
s
.924 .878 .772 r
.79044 .18966 m .79431 .18392 L .79582 .18833 L p F P
0 g
s
.924 .878 .772 r
.79582 .18833 m .7932 .1922 L .79044 .18966 L p F P
0 g
s
.759 .384 0 r
.8035 .07362 m .8036 .07387 L .80392 .07447 L closepath p F P
0 g
s
.878 .529 .034 r
.80488 .07887 m .8036 .07387 L .80392 .07447 L p F P
0 g
s
.878 .529 .034 r
.80719 .08319 m .80488 .07887 L p .80392 .07447 L F P
0 g
s
.945 .632 .191 r
.80555 .0841 m .80787 .08842 L .80719 .08319 L p F P
0 g
s
.945 .632 .191 r
.80719 .08319 m .80488 .07887 L .80555 .0841 L p F P
0 g
s
.656 .773 .935 r
.6375 .30664 m .65018 .30236 L .65328 .30593 L p F P
0 g
s
.645 .765 .936 r
.65018 .30236 m .6375 .30664 L .63437 .30271 L p F P
0 g
s
.969 .786 .603 r
.59172 .22243 m .59268 .21902 L .59556 .22303 L p F P
0 g
s
.969 .786 .603 r
.59556 .22303 m .5949 .22537 L .59172 .22243 L p F P
0 g
s
.707 .8 .923 r
.66591 .29993 m .65328 .30593 L .65018 .30236 L p F P
0 g
s
.793 .848 .893 r
.70663 .28423 m .70967 .28204 L .7067 .27906 L p F P
0 g
s
.793 .848 .893 r
.7067 .27906 m .70574 .27975 L .70663 .28423 L p F P
0 g
s
.79 .843 .892 r
.69414 .2879 m .70574 .27975 L .70663 .28423 L p F P
0 g
s
0 .129 .669 r
.78819 .04768 m .79091 .05193 L .78675 .04798 L p F P
0 g
s
0 .129 .669 r
.78675 .04798 m .78403 .04373 L .78819 .04768 L p F P
0 g
s
.882 .874 .824 r
.76892 .22272 m .77273 .21838 L .77407 .22279 L p F P
0 g
s
.882 .874 .824 r
.77407 .22279 m .77174 .22544 L .76892 .22272 L p F P
0 g
s
.769 .386 0 r
.8036 .07387 m .8035 .07362 L .80053 .06793 L p F P
0 g
s
.993 .744 .432 r
.59442 .25066 m .59694 .25474 L .59735 .24901 L p F P
0 g
s
.993 .744 .432 r
.59735 .24901 m .59482 .24493 L .59442 .25066 L p F P
0 g
s
.807 .851 .883 r
.71963 .27437 m .70967 .28204 L .7067 .27906 L p F P
0 g
s
.769 .386 0 r
.80053 .06793 m .80118 .06956 L .8036 .07387 L p F P
0 g
s
.881 .527 .037 r
.80246 .07457 m .80488 .07887 L .8036 .07387 L p F P
0 g
s
.881 .527 .037 r
.8036 .07387 m .80118 .06956 L .80246 .07457 L p F P
0 g
s
.876 .875 .831 r
.76685 .23078 m .77174 .22544 L .76892 .22272 L p F P
0 g
s
.919 .88 .78 r
.79081 .19558 m .7932 .1922 L .79044 .18966 L p F P
0 g
s
0 0 .466 r
.794 .05627 m .7966 .06055 L .79351 .05621 L p F P
0 g
s
0 0 .466 r
.79351 .05621 m .79091 .05193 L .794 .05627 L p F P
0 g
s
.983 .847 .629 r
.80729 .13684 m .80917 .14121 L .81138 .13493 L p F P
0 g
s
.983 .847 .629 r
.81138 .13493 m .80952 .13055 L .80729 .13684 L p F P
0 g
s
.943 .872 .737 r
.79957 .16856 m .80134 .16548 L .80299 .16988 L p F P
0 g
s
.943 .872 .737 r
.80299 .16988 m .80231 .17106 L .79957 .16856 L p F P
0 g
s
.707 .313 0 r
.79758 .0626 m .7966 .06055 L .79907 .06486 L p F P
0 g
s
.707 .313 0 r
.79907 .06486 m .80053 .06793 L .79758 .0626 L p F P
0 g
s
.962 .867 .698 r
.80316 .15434 m .80489 .15873 L .80809 .1521 L p F P
0 g
s
.962 .867 .698 r
.80809 .1521 m .80639 .14769 L .80316 .15434 L p F P
0 g
s
.94 .875 .745 r
.79884 .17683 m .80231 .17106 L .79957 .16856 L p F P
0 g
s
.406 .588 .916 r
.62145 .29914 m .61843 .29888 L .61524 .29401 L p F P
0 g
s
.973 .774 .575 r
.59402 .2291 m .5949 .22537 L .59172 .22243 L p F P
0 g
s
.876 .875 .831 r
.76892 .22272 m .7656 .22635 L .76685 .23078 L p F P
0 g
s
.871 .873 .836 r
.75791 .2345 m .7656 .22635 L .76685 .23078 L p F P
0 g
s
.871 .873 .836 r
.75904 .23827 m .75791 .2345 L p .76685 .23078 L F P
0 g
s
.871 .873 .836 r
.76685 .23078 m .75945 .23866 L .75904 .23827 L p F P
0 g
s
.999 .797 .492 r
.80874 .10968 m .8108 .11404 L .81175 .10822 L p F P
0 g
s
.999 .797 .492 r
.81175 .10822 m .80971 .10385 L .80874 .10968 L p F P
0 g
s
0 0 .57 r
.60781 .28344 m .60988 .28761 L .60625 .28314 L p F P
0 g
s
0 0 .57 r
.60625 .28314 m .60434 .27892 L .60781 .28344 L p F P
0 g
s
.81 .855 .883 r
.71963 .27437 m .72217 .27237 L .71924 .26945 L p F P
0 g
s
.81 .855 .883 r
.71924 .26945 m .71866 .2699 L .71963 .27437 L p F P
0 g
s
.807 .851 .883 r
.7067 .27906 m .71866 .2699 L .71963 .27437 L p F P
0 g
s
.919 .88 .78 r
.79044 .18966 m .78939 .19115 L .79081 .19558 L p F P
0 g
s
.909 .878 .792 r
.78382 .1986 m .78529 .20301 L .79081 .19558 L p F P
0 g
s
.909 .878 .792 r
.79081 .19558 m .78939 .19115 L .78382 .1986 L p F P
0 g
s
.049 .352 .827 r
.61203 .28911 m .60988 .28761 L .61171 .29183 L p F P
0 g
s
.049 .352 .827 r
.61171 .29183 m .61524 .29401 L .61203 .28911 L p F P
0 g
s
.768 .828 .899 r
.69028 .2904 m .68156 .29598 L .67853 .29275 L p F P
0 g
s
.822 .857 .873 r
.73101 .26503 m .72217 .27237 L .71924 .26945 L p F P
0 g
s
.988 .76 .502 r
.59209 .2409 m .59482 .24493 L .59563 .23908 L p F P
0 g
s
.988 .76 .502 r
.59563 .23908 m .5929 .23505 L .59209 .2409 L p F P
0 g
s
.955 .78 .626 r
.58958 .21507 m .59268 .21902 L .59469 .2128 L p F P
0 g
s
.955 .78 .626 r
.59469 .2128 m .59159 .20885 L .58958 .21507 L p F P
0 g
s
.863 .874 .844 r
.75945 .23866 m .75921 .23891 L .75904 .23827 L closepath p F P
0 g
s
.745 .382 0 r
.60237 .27394 m .60028 .26976 L .60219 .27477 L p F P
0 g
s
.85 .868 .854 r
.74933 .24295 m .75058 .24736 L .75921 .23891 L p F P
0 g
s
.85 .868 .854 r
.75659 .23584 m .74933 .24295 L p .75921 .23891 L F P
0 g
s
.85 .868 .854 r
.75921 .23891 m .75904 .23827 L .75659 .23584 L p F P
0 g
s
.826 .861 .872 r
.73101 .26503 m .73465 .26194 L .73174 .25905 L p F P
0 g
s
.826 .861 .872 r
.73174 .25905 m .72993 .26058 L .73101 .26503 L p F P
0 g
s
.822 .857 .873 r
.71924 .26945 m .72993 .26058 L .73101 .26503 L p F P
0 g
s
.836 .862 .863 r
.74123 .25605 m .73465 .26194 L .73174 .25905 L p F P
0 g
s
.849 .865 .853 r
.74419 .24786 m .74933 .24295 L .75058 .24736 L p F P
0 g
s
.849 .865 .853 r
.75058 .24736 m .74708 .25072 L .74419 .24786 L p F P
0 g
s
.841 .865 .861 r
.74123 .25605 m .74708 .25072 L .74419 .24786 L p F P
0 g
s
.841 .865 .861 r
.74419 .24786 m .74006 .25162 L .74123 .25605 L p F P
0 g
s
.836 .862 .863 r
.73174 .25905 m .74006 .25162 L .74123 .25605 L p F P
0 g
s
.996 .764 .424 r
.80756 .0995 m .80971 .10385 L .81017 .0982 L p F P
0 g
s
.996 .764 .424 r
.80784 .09598 m .80756 .0995 L p .81017 .0982 L F P
0 g
s
.996 .764 .424 r
.81017 .0982 m .8091 .09604 L .80784 .09598 L p F P
0 g
s
.861 .867 .842 r
.75904 .23827 m .75659 .23584 L .75791 .2345 L closepath p F P
0 g
s
.99 .834 .595 r
.80754 .12619 m .80952 .13055 L .81134 .12441 L p F P
0 g
s
.99 .834 .595 r
.81134 .12441 m .80939 .12004 L .80754 .12619 L p F P
0 g
s
.929 .605 .148 r
.59796 .26563 m .60028 .26976 L .59939 .26443 L p F P
0 g
s
.929 .605 .148 r
.59939 .26443 m .59709 .2603 L .59796 .26563 L p F P
0 g
s
.94 .875 .745 r
.79957 .16856 m .79726 .17242 L .79884 .17683 L p F P
0 g
s
.93 .874 .76 r
.7927 .17953 m .79431 .18392 L .79884 .17683 L p F P
0 g
s
.93 .874 .76 r
.79884 .17683 m .79726 .17242 L .7927 .17953 L p F P
0 g
s
.902 .875 .8 r
.77834 .20568 m .78382 .1986 L .78529 .20301 L p F P
0 g
s
.902 .875 .8 r
.78529 .20301 m .78114 .20835 L .77834 .20568 L p F P
0 g
s
.973 .774 .575 r
.59172 .22243 m .59108 .22511 L .59402 .2291 L p F P
0 g
s
.978 .764 .546 r
.58996 .23106 m .5929 .23505 L .59402 .2291 L p F P
0 g
s
.978 .764 .546 r
.59402 .2291 m .59108 .22511 L .58996 .23106 L p F P
0 g
s
.769 .834 .901 r
.69028 .2904 m .69414 .2879 L .69114 .28478 L p F P
0 g
s
.769 .834 .901 r
.69114 .28478 m .68931 .28594 L .69028 .2904 L p F P
0 g
s
.768 .828 .899 r
.67853 .29275 m .68931 .28594 L .69028 .2904 L p F P
0 g
s
.406 .588 .916 r
.61524 .29401 m .6202 .29475 L .62145 .29914 L p F P
0 g
s
.505 .68 .944 r
.62806 .29469 m .6202 .29475 L .62145 .29914 L p F P
0 g
s
.505 .68 .944 r
.62145 .29914 m .63122 .29872 L .62806 .29469 L p F P
0 g
s
.972 .854 .664 r
.80565 .14081 m .80729 .13684 L .80917 .14121 L p F P
0 g
s
.972 .854 .664 r
.80917 .14121 m .80836 .14316 L .80565 .14081 L p F P
0 g
s
.952 .867 .717 r
.79959 .1611 m .80134 .16548 L .80489 .15873 L p F P
0 g
s
.952 .867 .717 r
.80489 .15873 m .80316 .15434 L .79959 .1611 L p F P
0 g
s
.743 .81 .905 r
.6691 .29813 m .66591 .29993 L .66284 .29651 L p F P
0 g
s
.707 .8 .923 r
.65018 .30236 m .66284 .29651 L .66591 .29993 L p F P
0 g
s
.779 .39 0 r
.80118 .06956 m .80053 .06793 L .79758 .0626 L p F P
0 g
s
.981 .704 .321 r
.80568 .08954 m .80799 .09386 L .80787 .08842 L p F P
0 g
s
.981 .704 .321 r
.80787 .08842 m .80555 .0841 L .80568 .08954 L p F P
0 g
s
.788 .839 .891 r
.70574 .27975 m .69414 .2879 L .69114 .28478 L p F P
0 g
s
.982 .699 .338 r
.59456 .25622 m .59709 .2603 L .59694 .25474 L p F P
0 g
s
.982 .699 .338 r
.59694 .25474 m .59442 .25066 L .59456 .25622 L p F P
0 g
s
.897 .877 .808 r
.77933 .21059 m .78114 .20835 L .77834 .20568 L p F P
0 g
s
.971 .858 .672 r
.80639 .14769 m .80836 .14316 L .80565 .14081 L p F P
0 g
s
.897 .877 .808 r
.77834 .20568 m .77795 .20616 L .77933 .21059 L p F P
0 g
s
.887 .873 .817 r
.77129 .21398 m .77273 .21838 L .77933 .21059 L p F P
0 g
s
.887 .873 .817 r
.77933 .21059 m .77795 .20616 L .77129 .21398 L p F P
0 g
s
.645 .765 .936 r
.63437 .30271 m .64708 .29873 L .65018 .30236 L p F P
0 g
s
.634 .758 .938 r
.64708 .29873 m .63437 .30271 L .63122 .29872 L p F P
0 g
s
.742 .813 .908 r
.6691 .29813 m .67853 .29275 L .67549 .28946 L p F P
0 g
s
.742 .813 .908 r
.67549 .28946 m .66775 .29379 L .6691 .29813 L p F P
0 g
s
.743 .81 .905 r
.66284 .29651 m .66775 .29379 L .6691 .29813 L p F P
0 g
s
.995 .817 .553 r
.80732 .11568 m .80939 .12004 L .8108 .11404 L p F P
0 g
s
.995 .817 .553 r
.8108 .11404 m .80874 .10968 L .80732 .11568 L p F P
0 g
s
.95 .633 .204 r
.80314 .0798 m .80555 .0841 L .80488 .07887 L p F P
0 g
s
.95 .633 .204 r
.80488 .07887 m .80246 .07457 L .80314 .0798 L p F P
0 g
s
.961 .774 .606 r
.58851 .21883 m .58958 .21507 L .59268 .21902 L p F P
0 g
s
.961 .774 .606 r
.59268 .21902 m .59172 .22243 L .58851 .21883 L p F P
0 g
s
.702 .796 .923 r
.66284 .29651 m .65018 .30236 L .64708 .29873 L p F P
0 g
s
0 .122 .661 r
.78536 .04344 m .78819 .04768 L .78403 .04373 L p F P
0 g
s
0 .122 .661 r
.78403 .04373 m .78119 .0395 L .78536 .04344 L p F P
0 g
s
.923 .873 .771 r
.78784 .18675 m .7927 .17953 L .79431 .18392 L p F P
0 g
s
.923 .873 .771 r
.78809 .18743 m .78784 .18675 L p .79431 .18392 L F P
0 g
s
.923 .873 .771 r
.79431 .18392 m .79044 .18966 L .78809 .18743 L p F P
0 g
s
.36 .567 .916 r
.6202 .29475 m .61524 .29401 L .61203 .28911 L p F P
0 g
s
.995 .755 .414 r
.8091 .09604 m .80784 .09598 L .80799 .09386 L closepath p F P
0 g
s
.99 .737 .445 r
.59169 .24663 m .59442 .25066 L .59482 .24493 L p F P
0 g
s
.99 .737 .445 r
.59482 .24493 m .59209 .2409 L .59169 .24663 L p F P
0 g
s
.779 .39 0 r
.79758 .0626 m .79866 .06527 L .80118 .06956 L p F P
0 g
s
.89 .531 .052 r
.79994 .07028 m .80246 .07457 L .80118 .06956 L p F P
0 g
s
.89 .531 .052 r
.80118 .06956 m .79866 .06527 L .79994 .07028 L p F P
0 g
s
0 0 .452 r
.79129 .05201 m .794 .05627 L .79091 .05193 L p F P
0 g
s
0 0 .452 r
.79091 .05193 m .78819 .04768 L .79129 .05201 L p F P
0 g
s
.792 .845 .891 r
.7067 .27906 m .70574 .27975 L .70525 .27756 L closepath p F P
0 g
s
.788 .839 .891 r
.70372 .27597 m .70525 .27756 L .70574 .27975 L p F P
0 g
s
.788 .839 .891 r
.69114 .28478 m .70372 .27597 L p .70574 .27975 L F P
0 g
s
.881 .87 .823 r
.76608 .21992 m .77129 .21398 L .77273 .21838 L p F P
0 g
s
.881 .87 .823 r
.77273 .21838 m .76892 .22272 L .76608 .21992 L p F P
0 g
s
.72 .317 0 r
.79465 .05761 m .794 .05627 L .7966 .06055 L p F P
0 g
s
.72 .317 0 r
.7966 .06055 m .79758 .0626 L .79465 .05761 L p F P
0 g
s
.805 .847 .882 r
.71866 .2699 m .7067 .27906 L .70525 .27756 L p F P
0 g
s
.981 .842 .632 r
.8053 .13249 m .80729 .13684 L .80952 .13055 L p F P
0 g
s
.981 .842 .632 r
.80952 .13055 m .80754 .12619 L .8053 .13249 L p F P
0 g
s
.942 .867 .736 r
.79682 .16594 m .79959 .1611 L .80134 .16548 L p F P
0 g
s
.942 .867 .736 r
.80134 .16548 m .79957 .16856 L .79682 .16594 L p F P
0 g
s
.875 .871 .83 r
.7656 .22635 m .76892 .22272 L .76608 .21992 L p F P
0 g
s
.971 .858 .672 r
.80565 .14081 m .80457 .14331 L .80639 .14769 L p F P
0 g
s
.959 .861 .7 r
.80132 .14996 m .80316 .15434 L .80639 .14769 L p F P
0 g
s
.959 .861 .7 r
.80639 .14769 m .80457 .14331 L .80132 .14996 L p F P
0 g
s
.998 .793 .5 r
.80658 .10534 m .80874 .10968 L .80971 .10385 L p F P
0 g
s
.998 .793 .5 r
.80971 .10385 m .80756 .0995 L .80658 .10534 L p F P
0 g
s
.918 .875 .779 r
.79044 .18966 m .78939 .19115 L .78809 .18743 L closepath p F P
0 g
s
.875 .871 .83 r
.76608 .21992 m .76424 .22193 L .7656 .22635 L p F P
0 g
s
.867 .868 .836 r
.75647 .23012 m .75791 .2345 L .7656 .22635 L p F P
0 g
s
.867 .868 .836 r
.7656 .22635 m .76424 .22193 L .75647 .23012 L p F P
0 g
s
.967 .764 .579 r
.59108 .22511 m .59172 .22243 L .58851 .21883 L p F P
0 g
s
0 0 .519 r
.60552 .27933 m .60781 .28344 L .60434 .27892 L p F P
0 g
s
.983 .75 .509 r
.58915 .23692 m .59209 .2409 L .5929 .23505 L p F P
0 g
s
.983 .75 .509 r
.5929 .23505 m .58996 .23106 L .58915 .23692 L p F P
0 g
s
0 .3 .795 r
.60882 .28423 m .60781 .28344 L .60988 .28761 L p F P
0 g
s
0 .3 .795 r
.60988 .28761 m .61203 .28911 L .60882 .28423 L p F P
0 g
s
.902 .871 .798 r
.78224 .19422 m .78382 .1986 L .78939 .19115 L p F P
0 g
s
.902 .871 .798 r
.78766 .187 m .78224 .19422 L p .78939 .19115 L F P
0 g
s
.902 .871 .798 r
.78939 .19115 m .78809 .18743 L .78766 .187 L p F P
0 g
s
.765 .824 .898 r
.68931 .28594 m .67853 .29275 L .67549 .28946 L p F P
0 g
s
.81 .852 .881 r
.71924 .26945 m .71866 .2699 L .71831 .2685 L closepath p F P
0 g
s
.805 .847 .882 r
.71628 .26639 m .71831 .2685 L .71866 .2699 L p F P
0 g
s
.805 .847 .882 r
.70456 .27534 m .71628 .26639 L p .71866 .2699 L F P
0 g
s
.805 .847 .882 r
.70525 .27756 m .70456 .27534 L p .71866 .2699 L F P
0 g
s
.938 .87 .744 r
.79726 .17242 m .79957 .16856 L .79682 .16594 L p F P
0 g
s
.821 .853 .872 r
.72993 .26058 m .71924 .26945 L .71831 .2685 L p F P
0 g
s
.792 .415 0 r
.59981 .27067 m .60219 .27477 L .60028 .26976 L p F P
0 g
s
.792 .415 0 r
.60028 .26976 m .59796 .26563 L .59981 .27067 L p F P
0 g
s
.86 .863 .841 r
.75372 .23292 m .75647 .23012 L .75791 .2345 L p F P
0 g
s
.86 .863 .841 r
.75791 .2345 m .75659 .23584 L .75372 .23292 L p F P
0 g
s
.853 .863 .848 r
.74933 .24295 m .75659 .23584 L .75372 .23292 L p F P
0 g
s
.825 .857 .871 r
.72993 .26058 m .73174 .25905 L .72881 .25609 L p F P
0 g
s
.825 .857 .871 r
.72881 .25609 m .72875 .25615 L .72993 .26058 L p F P
0 g
s
.821 .853 .872 r
.71737 .26551 m .72875 .25615 L .72993 .26058 L p F P
0 g
s
.821 .853 .872 r
.71831 .2685 m .71737 .26551 L p .72993 .26058 L F P
0 g
s
.995 .753 .42 r
.80529 .09517 m .80568 .08954 L .80799 .09386 L p F P
0 g
s
.995 .753 .42 r
.80542 .09541 m .80529 .09517 L p .80799 .09386 L F P
0 g
s
.995 .753 .42 r
.80799 .09386 m .80784 .09598 L .80542 .09541 L p F P
0 g
s
.835 .858 .862 r
.74006 .25162 m .73174 .25905 L .72881 .25609 L p F P
0 g
s
.853 .863 .848 r
.75372 .23292 m .74796 .23856 L .74933 .24295 L p F P
0 g
s
.848 .861 .852 r
.74129 .24492 m .74796 .23856 L .74933 .24295 L p F P
0 g
s
.848 .861 .852 r
.74933 .24295 m .74419 .24786 L .74129 .24492 L p F P
0 g
s
.79 .394 0 r
.79866 .06527 m .79758 .0626 L .79465 .05761 L p F P
0 g
s
.84 .861 .86 r
.74006 .25162 m .74419 .24786 L .74129 .24492 L p F P
0 g
s
.84 .861 .86 r
.74129 .24492 m .73878 .24721 L .74006 .25162 L p F P
0 g
s
.835 .858 .862 r
.72881 .25609 m .73878 .24721 L .74006 .25162 L p F P
0 g
s
.987 .83 .599 r
.80546 .12184 m .80754 .12619 L .80939 .12004 L p F P
0 g
s
.987 .83 .599 r
.80939 .12004 m .80732 .11568 L .80546 .12184 L p F P
0 g
s
.943 .613 .183 r
.59541 .26157 m .59796 .26563 L .59709 .2603 L p F P
0 g
s
.943 .613 .183 r
.59709 .2603 m .59456 .25622 L .59541 .26157 L p F P
0 g
s
.967 .764 .579 r
.58851 .21883 m .58796 .22117 L .59108 .22511 L p F P
0 g
s
.972 .754 .55 r
.58683 .22713 m .58996 .23106 L .59108 .22511 L p F P
0 g
s
.972 .754 .55 r
.59108 .22511 m .58796 .22117 L .58683 .22713 L p F P
0 g
s
.938 .87 .744 r
.79682 .16594 m .79557 .16803 L .79726 .17242 L p F P
0 g
s
.928 .869 .76 r
.79098 .17516 m .7927 .17953 L .79726 .17242 L p F P
0 g
s
.928 .869 .76 r
.79726 .17242 m .79557 .16803 L .79098 .17516 L p F P
0 g
s
.901 .87 .798 r
.77636 .20178 m .78224 .19422 L .78382 .1986 L p F P
0 g
s
.901 .87 .798 r
.7775 .20485 m .77636 .20178 L p .78382 .1986 L F P
0 g
s
.901 .87 .798 r
.78382 .1986 m .77834 .20568 L .7775 .20485 L p F P
0 g
s
.8 .842 .883 r
.70525 .27756 m .70372 .27597 L .70456 .27534 L closepath p F P
0 g
s
.814 .848 .874 r
.71831 .2685 m .71628 .26639 L .71737 .26551 L closepath p F P
0 g
s
.971 .849 .664 r
.80292 .1383 m .8053 .13249 L .80729 .13684 L p F P
0 g
s
.971 .849 .664 r
.80729 .13684 m .80565 .14081 L .80292 .1383 L p F P
0 g
s
.739 .806 .905 r
.66775 .29379 m .66284 .29651 L .65976 .29304 L p F P
0 g
s
.702 .796 .923 r
.64708 .29873 m .65976 .29304 L .66284 .29651 L p F P
0 g
s
.36 .567 .916 r
.61203 .28911 m .61856 .29046 L .6202 .29475 L p F P
0 g
s
.482 .667 .944 r
.62489 .29063 m .61856 .29046 L .6202 .29475 L p F P
0 g
s
.482 .667 .944 r
.6202 .29475 m .62806 .29469 L .62489 .29063 L p F P
0 g
s
.95 .861 .718 r
.79773 .15675 m .79959 .1611 L .80316 .15434 L p F P
0 g
s
.95 .861 .718 r
.80316 .15434 m .80132 .14996 L .79773 .15675 L p F P
0 g
s
.769 .832 .901 r
.69114 .28478 m .68931 .28594 L .68833 .2818 L closepath p F P
0 g
s
.765 .824 .898 r
.68812 .28158 m .68833 .2818 L .68931 .28594 L p F P
0 g
s
.765 .824 .898 r
.67549 .28946 m .68812 .28158 L p .68931 .28594 L F P
0 g
s
.982 .703 .331 r
.80326 .08524 m .80568 .08954 L .80555 .0841 L p F P
0 g
s
.982 .703 .331 r
.80555 .0841 m .80314 .0798 L .80326 .08524 L p F P
0 g
s
.983 .695 .357 r
.59183 .2522 m .59456 .25622 L .59442 .25066 L p F P
0 g
s
.983 .695 .357 r
.59442 .25066 m .59169 .24663 L .59183 .2522 L p F P
0 g
s
.995 .758 .426 r
.80784 .09598 m .80756 .0995 L .80542 .09541 L closepath p F P
0 g
s
.634 .758 .938 r
.63122 .29872 m .64396 .29505 L .64708 .29873 L p F P
0 g
s
.622 .752 .939 r
.64396 .29505 m .63122 .29872 L .62806 .29469 L p F P
0 g
s
.312 .545 .914 r
.61856 .29046 m .61203 .28911 L .60882 .28423 L p F P
0 g
s
.793 .836 .885 r
.70072 .27277 m .70372 .27597 L .69114 .28478 L p F P
0 g
s
.793 .836 .885 r
.68823 .2815 m .70072 .27277 L p .69114 .28478 L F P
0 g
s
.793 .836 .885 r
.69114 .28478 m .68833 .2818 L .68823 .2815 L p F P
0 g
s
.993 .813 .558 r
.80514 .11135 m .80732 .11568 L .80874 .10968 L p F P
0 g
s
.993 .813 .558 r
.80874 .10968 m .80658 .10534 L .80514 .11135 L p F P
0 g
s
.954 .634 .216 r
.80061 .07552 m .80314 .0798 L .80246 .07457 L p F P
0 g
s
.954 .634 .216 r
.80246 .07457 m .79994 .07028 L .80061 .07552 L p F P
0 g
s
.895 .871 .807 r
.77834 .20568 m .77795 .20616 L .7775 .20485 L closepath p F P
0 g
s
.697 .791 .923 r
.65976 .29304 m .64708 .29873 L .64396 .29505 L p F P
0 g
s
.88 .867 .821 r
.76972 .2096 m .77129 .21398 L .77795 .20616 L p F P
0 g
s
.88 .867 .821 r
.77551 .20281 m .76972 .2096 L p .77795 .20616 L F P
0 g
s
.88 .867 .821 r
.77795 .20616 m .7775 .20485 L .77551 .20281 L p F P
0 g
s
.738 .81 .908 r
.66775 .29379 m .67549 .28946 L .67243 .28611 L p F P
0 g
s
.738 .81 .908 r
.67243 .28611 m .66632 .28946 L .66775 .29379 L p F P
0 g
s
.739 .806 .905 r
.65976 .29304 m .66632 .28946 L .66775 .29379 L p F P
0 g
s
.92 .867 .77 r
.78609 .18239 m .78784 .18675 L .7927 .17953 L p F P
0 g
s
.92 .867 .77 r
.7927 .17953 m .79098 .17516 L .78609 .18239 L p F P
0 g
s
.985 .729 .456 r
.58876 .24265 m .59169 .24663 L .59209 .2409 L p F P
0 g
s
.985 .729 .456 r
.59209 .2409 m .58915 .23692 L .58876 .24265 L p F P
0 g
s
.79 .394 0 r
.79465 .05761 m .79603 .061 L .79866 .06527 L p F P
0 g
s
.897 .535 .067 r
.79732 .06601 m .79994 .07028 L .79866 .06527 L p F P
0 g
s
.897 .535 .067 r
.79866 .06527 m .79603 .061 L .79732 .06601 L p F P
0 g
s
0 0 .436 r
.78846 .04778 m .79129 .05201 L .78819 .04768 L p F P
0 g
s
0 0 .436 r
.78819 .04768 m .78536 .04344 L .78846 .04778 L p F P
0 g
s
.969 .852 .672 r
.80457 .14331 m .80565 .14081 L .80292 .1383 L p F P
0 g
s
.734 .323 0 r
.79174 .05293 m .79129 .05201 L .794 .05627 L p F P
0 g
s
.734 .323 0 r
.794 .05627 m .79465 .05761 L .79174 .05293 L p F P
0 g
s
.978 .837 .635 r
.8032 .12815 m .8053 .13249 L .80754 .12619 L p F P
0 g
s
.978 .837 .635 r
.80754 .12619 m .80546 .12184 L .8032 .12815 L p F P
0 g
s
.88 .866 .821 r
.76322 .21702 m .76972 .2096 L .77129 .21398 L p F P
0 g
s
.88 .866 .821 r
.77129 .21398 m .76608 .21992 L .76322 .21702 L p F P
0 g
s
.799 .838 .881 r
.70456 .27534 m .70372 .27597 L .70072 .27277 L p F P
0 g
s
.802 .84 .88 r
.70456 .27534 m .71628 .26639 L .71331 .26324 L p F P
0 g
s
.802 .84 .88 r
.71331 .26324 m .70309 .27101 L .70456 .27534 L p F P
0 g
s
.799 .838 .881 r
.70072 .27277 m .70309 .27101 L .70456 .27534 L p F P
0 g
s
.94 .862 .735 r
.79404 .1632 m .79773 .15675 L .79959 .1611 L p F P
0 g
s
.94 .862 .735 r
.79959 .1611 m .79682 .16594 L .79404 .1632 L p F P
0 g
s
.911 .869 .785 r
.78809 .18743 m .78766 .187 L .78784 .18675 L closepath p F P
0 g
s
.996 .792 .514 r
.80431 .10101 m .80658 .10534 L .80756 .0995 L p F P
0 g
s
.996 .792 .514 r
.80527 .0953 m .80431 .10101 L p .80756 .0995 L F P
0 g
s
.996 .792 .514 r
.80756 .0995 m .80542 .09541 L .80527 .0953 L p F P
0 g
s
.89 .866 .809 r
.7775 .20485 m .77551 .20281 L .77636 .20178 L closepath p F P
0 g
s
.969 .852 .672 r
.80292 .1383 m .80264 .13894 L .80457 .14331 L p F P
0 g
s
.956 .856 .701 r
.79937 .14561 m .80132 .14996 L .80457 .14331 L p F P
0 g
s
.956 .856 .701 r
.80457 .14331 m .80264 .13894 L .79937 .14561 L p F P
0 g
s
.977 .741 .516 r
.58602 .23299 m .58915 .23692 L .58996 .23106 L p F P
0 g
s
.977 .741 .516 r
.58996 .23106 m .58683 .22713 L .58602 .23299 L p F P
0 g
s
.873 .866 .829 r
.76424 .22193 m .76608 .21992 L .76322 .21702 L p F P
0 g
s
0 0 .454 r
.60528 .27893 m .60552 .27933 L .60219 .27477 L p F P
0 g
s
0 0 .454 r
.60236 .27439 m .60528 .27893 L p .60219 .27477 L F P
0 g
s
0 0 .454 r
.60219 .27477 m .59981 .27067 L .60236 .27439 L p F P
0 g
s
.762 .823 .9 r
.68812 .28158 m .67549 .28946 L .67243 .28611 L p F P
0 g
s
.8 .399 0 r
.79603 .061 m .79465 .05761 L .79174 .05293 L p F P
0 g
s
0 .247 .76 r
.6056 .2794 m .60552 .27933 L .60781 .28344 L p F P
0 g
s
0 .247 .76 r
.60781 .28344 m .60882 .28423 L .6056 .2794 L p F P
0 g
s
.873 .866 .829 r
.76322 .21702 m .76275 .21754 L .76424 .22193 L p F P
0 g
s
.865 .863 .836 r
.75491 .22576 m .75647 .23012 L .76424 .22193 L p F P
0 g
s
.865 .863 .836 r
.76424 .22193 m .76275 .21754 L .75491 .22576 L p F P
0 g
s
.909 .864 .784 r
.78485 .1841 m .78609 .18239 L .78784 .18675 L p F P
0 g
s
.909 .864 .784 r
.78784 .18675 m .78766 .187 L .78485 .1841 L p F P
0 g
s
.904 .866 .791 r
.78224 .19422 m .78766 .187 L .78485 .1841 L p F P
0 g
s
.827 .441 0 r
.59722 .26662 m .59981 .27067 L .59796 .26563 L p F P
0 g
s
.827 .441 0 r
.59796 .26563 m .59541 .26157 L .59722 .26662 L p F P
0 g
s
.813 .844 .873 r
.71737 .26551 m .71628 .26639 L .71331 .26324 L p F P
0 g
s
.812 .847 .876 r
.71588 .26117 m .71737 .26551 L .72875 .25615 L p F P
0 g
s
.813 .844 .873 r
.71331 .26324 m .71588 .26117 L .71737 .26551 L p F P
0 g
s
.994 .748 .426 r
.80287 .09087 m .80529 .09517 L .80568 .08954 L p F P
0 g
s
.994 .748 .426 r
.80568 .08954 m .80326 .08524 L .80287 .09087 L p F P
0 g
s
.859 .859 .84 r
.75083 .22992 m .75491 .22576 L .75647 .23012 L p F P
0 g
s
.859 .859 .84 r
.75647 .23012 m .75372 .23292 L .75083 .22992 L p F P
0 g
s
.937 .864 .743 r
.79557 .16803 m .79682 .16594 L .79404 .1632 L p F P
0 g
s
.851 .859 .847 r
.74796 .23856 m .75372 .23292 L .75083 .22992 L p F P
0 g
s
.985 .825 .603 r
.80328 .11752 m .80546 .12184 L .80732 .11568 L p F P
0 g
s
.985 .825 .603 r
.80732 .11568 m .80514 .11135 L .80328 .11752 L p F P
0 g
s
.952 .617 .213 r
.59266 .25755 m .59541 .26157 L .59456 .25622 L p F P
0 g
s
.952 .617 .213 r
.59456 .25622 m .59183 .2522 L .59266 .25755 L p F P
0 g
s
.824 .853 .869 r
.72881 .25609 m .72875 .25615 L .72869 .25597 L closepath p F P
0 g
s
.812 .847 .876 r
.72586 .25298 m .71588 .26117 L p .72875 .25615 L F P
0 g
s
.812 .847 .876 r
.72875 .25615 m .72869 .25597 L .72586 .25298 L p F P
0 g
s
.834 .853 .861 r
.73878 .24721 m .72881 .25609 L .72869 .25597 L p F P
0 g
s
.312 .545 .914 r
.60882 .28423 m .61661 .28625 L .61856 .29046 L p F P
0 g
s
.265 .522 .91 r
.61661 .28625 m .60882 .28423 L .6056 .2794 L p F P
0 g
s
.851 .859 .847 r
.75083 .22992 m .74647 .23419 L .74796 .23856 L p F P
0 g
s
.847 .857 .85 r
.73838 .24191 m .74647 .23419 L .74796 .23856 L p F P
0 g
s
.847 .857 .85 r
.74796 .23856 m .74129 .24492 L .73838 .24191 L p F P
0 g
s
.838 .857 .858 r
.73878 .24721 m .74129 .24492 L .73838 .24191 L p F P
0 g
s
.838 .857 .858 r
.73838 .24191 m .73737 .24283 L .73878 .24721 L p F P
0 g
s
.834 .853 .861 r
.72722 .25181 m .73737 .24283 L .73878 .24721 L p F P
0 g
s
.834 .853 .861 r
.72869 .25597 m .72722 .25181 L p .73878 .24721 L F P
0 g
s
.826 .849 .864 r
.72869 .25597 m .72586 .25298 L .72722 .25181 L closepath p F P
0 g
s
.937 .864 .743 r
.79404 .1632 m .79377 .16366 L .79557 .16803 L p F P
0 g
s
.925 .863 .761 r
.78914 .1708 m .79098 .17516 L .79557 .16803 L p F P
0 g
s
.925 .863 .761 r
.79557 .16803 m .79377 .16366 L .78914 .1708 L p F P
0 g
s
.904 .866 .791 r
.78485 .1841 m .78054 .18985 L .78224 .19422 L p F P
0 g
s
.898 .864 .798 r
.77462 .19743 m .77636 .20178 L .78224 .19422 L p F P
0 g
s
.898 .864 .798 r
.78224 .19422 m .78054 .18985 L .77462 .19743 L p F P
0 g
s
.622 .752 .939 r
.62806 .29469 m .64082 .29131 L .64396 .29505 L p F P
0 g
s
.611 .745 .941 r
.64082 .29131 m .62806 .29469 L .62489 .29063 L p F P
0 g
s
.736 .803 .905 r
.66632 .28946 m .65976 .29304 L .65666 .2895 L p F P
0 g
s
.697 .791 .923 r
.64396 .29505 m .65666 .2895 L .65976 .29304 L p F P
0 g
s
.983 .702 .34 r
.80073 .08096 m .80326 .08524 L .80314 .0798 L p F P
0 g
s
.983 .702 .34 r
.80314 .0798 m .80061 .07552 L .80073 .08096 L p F P
0 g
s
.969 .843 .663 r
.80056 .13461 m .8032 .12815 L .8053 .13249 L p F P
0 g
s
.969 .843 .663 r
.80186 .13726 m .80056 .13461 L p .8053 .13249 L F P
0 g
s
.969 .843 .663 r
.8053 .13249 m .80292 .1383 L .80186 .13726 L p F P
0 g
s
.947 .856 .719 r
.79575 .1524 m .79773 .15675 L .80132 .14996 L p F P
0 g
s
.947 .856 .719 r
.80132 .14996 m .79937 .14561 L .79575 .1524 L p F P
0 g
s
.782 .831 .89 r
.68833 .2818 m .68812 .28158 L .68823 .2815 L closepath p F P
0 g
s
.981 .69 .373 r
.58889 .24823 m .59183 .2522 L .59169 .24663 L p F P
0 g
s
.981 .69 .373 r
.59169 .24663 m .58876 .24265 L .58889 .24823 L p F P
0 g
s
.459 .655 .945 r
.62171 .28655 m .61661 .28625 L .61856 .29046 L p F P
0 g
s
.459 .655 .945 r
.61856 .29046 m .62489 .29063 L .62171 .28655 L p F P
0 g
s
.781 .827 .888 r
.68823 .2815 m .68812 .28158 L .68508 .27825 L p F P
0 g
s
.762 .823 .9 r
.67243 .28611 m .68508 .27825 L .68812 .28158 L p F P
0 g
s
.783 .828 .888 r
.68823 .2815 m .70072 .27277 L .69771 .26951 L p F P
0 g
s
.783 .828 .888 r
.69771 .26951 m .6866 .27721 L .68823 .2815 L p F P
0 g
s
.781 .827 .888 r
.68508 .27825 m .6866 .27721 L .68823 .2815 L p F P
0 g
s
.692 .787 .924 r
.65666 .2895 m .64396 .29505 L .64082 .29131 L p F P
0 g
s
.957 .635 .228 r
.79799 .07125 m .80061 .07552 L .79994 .07028 L p F P
0 g
s
.957 .635 .228 r
.79994 .07028 m .79732 .06601 L .79799 .07125 L p F P
0 g
s
.991 .808 .563 r
.80286 .10703 m .80514 .11135 L .80658 .10534 L p F P
0 g
s
.991 .808 .563 r
.80658 .10534 m .80431 .10101 L .80286 .10703 L p F P
0 g
s
.888 .861 .808 r
.77267 .19982 m .77462 .19743 L .77636 .20178 L p F P
0 g
s
.888 .861 .808 r
.77636 .20178 m .77551 .20281 L .77267 .19982 L p F P
0 g
s
.98 .721 .465 r
.58562 .23872 m .58876 .24265 L .58915 .23692 L p F P
0 g
s
.98 .721 .465 r
.58915 .23692 m .58602 .23299 L .58562 .23872 L p F P
0 g
s
.8 .399 0 r
.79174 .05293 m .7933 .05675 L .79603 .061 L p F P
0 g
s
.904 .539 .082 r
.79458 .06177 m .79732 .06601 L .79603 .061 L p F P
0 g
s
.904 .539 .082 r
.79603 .061 m .7933 .05675 L .79458 .06177 L p F P
0 g
s
.883 .862 .815 r
.76972 .2096 m .77551 .20281 L .77267 .19982 L p F P
0 g
s
.917 .861 .77 r
.78422 .17805 m .78609 .18239 L .79098 .17516 L p F P
0 g
s
.917 .861 .77 r
.79098 .17516 m .78914 .1708 L .78422 .17805 L p F P
0 g
s
.747 .33 0 r
.78884 .04855 m .78846 .04778 L .79129 .05201 L p F P
0 g
s
.747 .33 0 r
.79129 .05201 m .79174 .05293 L .78884 .04855 L p F P
0 g
s
.734 .807 .909 r
.66632 .28946 m .67243 .28611 L .66936 .28269 L p F P
0 g
s
.734 .807 .909 r
.66936 .28269 m .66483 .28513 L .66632 .28946 L p F P
0 g
s
.736 .803 .905 r
.65666 .2895 m .66483 .28513 L .66632 .28946 L p F P
0 g
s
.975 .832 .637 r
.801 .12384 m .8032 .12815 L .80546 .12184 L p F P
0 g
s
.975 .832 .637 r
.80546 .12184 m .80328 .11752 L .801 .12384 L p F P
0 g
s
.996 .783 .499 r
.80542 .09541 m .80527 .0953 L .80529 .09517 L closepath p F P
0 g
s
.797 .835 .88 r
.70309 .27101 m .70072 .27277 L .69771 .26951 L p F P
0 g
s
.883 .862 .815 r
.77267 .19982 m .76805 .20524 L .76972 .2096 L p F P
0 g
s
.878 .861 .82 r
.76107 .21319 m .76805 .20524 L .76972 .2096 L p F P
0 g
s
.878 .861 .82 r
.76216 .21591 m .76107 .21319 L p .76972 .2096 L F P
0 g
s
.878 .861 .82 r
.76972 .2096 m .76322 .21702 L .76216 .21591 L p F P
0 g
s
.812 .406 0 r
.7933 .05675 m .79174 .05293 L .78884 .04855 L p F P
0 g
s
.966 .847 .673 r
.80292 .1383 m .80264 .13894 L .80186 .13726 L closepath p F P
0 g
s
.994 .779 .503 r
.80255 .09293 m .80287 .09087 L .80529 .09517 L p F P
0 g
s
.994 .779 .503 r
.80529 .09517 m .80527 .0953 L .80255 .09293 L p F P
0 g
s
.938 .856 .734 r
.7918 .15932 m .79575 .1524 L .79773 .15675 L p F P
0 g
s
.938 .856 .734 r
.79318 .16231 m .7918 .15932 L p .79773 .15675 L F P
0 g
s
.938 .856 .734 r
.79773 .15675 m .79404 .1632 L .79318 .16231 L p F P
0 g
s
.994 .784 .51 r
.80431 .10101 m .80527 .0953 L .80255 .09293 L p F P
0 g
s
.8 .837 .879 r
.70309 .27101 m .71331 .26324 L .71032 .26002 L p F P
0 g
s
.8 .837 .879 r
.71032 .26002 m .7015 .2667 L .70309 .27101 L p F P
0 g
s
.797 .835 .88 r
.69771 .26951 m .7015 .2667 L .70309 .27101 L p F P
0 g
s
.95 .85 .709 r
.79731 .14127 m .79937 .14561 L .80264 .13894 L p F P
0 g
s
.95 .85 .709 r
.80015 .13548 m .79731 .14127 L p .80264 .13894 L F P
0 g
s
.95 .85 .709 r
.80264 .13894 m .80186 .13726 L .80015 .13548 L p F P
0 g
s
0 0 .411 r
.59912 .26954 m .59722 .26662 L .59981 .27067 L p F P
0 g
s
0 0 .411 r
.59981 .27067 m .60236 .27439 L .59912 .26954 L p F P
0 g
s
.76 .82 .899 r
.68508 .27825 m .67243 .28611 L .66936 .28269 L p F P
0 g
s
0 .195 .721 r
.60552 .27933 m .60528 .27893 L .6056 .2794 L closepath p F P
0 g
s
.265 .522 .91 r
.6056 .2794 m .61439 .28212 L .61661 .28625 L p F P
0 g
s
.285 .518 .903 r
.60528 .27893 m .6056 .2794 L .61439 .28212 L p F P
0 g
s
.907 .859 .782 r
.78203 .18109 m .78422 .17805 L .78609 .18239 L p F P
0 g
s
.907 .859 .782 r
.78609 .18239 m .78485 .1841 L .78203 .18109 L p F P
0 g
s
.871 .861 .827 r
.76322 .21702 m .76275 .21754 L .76216 .21591 L closepath p F P
0 g
s
.853 .459 0 r
.59444 .26261 m .59722 .26662 L .59541 .26157 L p F P
0 g
s
.853 .459 0 r
.59541 .26157 m .59266 .25755 L .59444 .26261 L p F P
0 g
s
.858 .857 .839 r
.75323 .22142 m .75491 .22576 L .76275 .21754 L p F P
0 g
s
.858 .857 .839 r
.76035 .21397 m .75323 .22142 L p .76275 .21754 L F P
0 g
s
.858 .857 .839 r
.76275 .21754 m .76216 .21591 L .76035 .21397 L p F P
0 g
s
.812 .84 .871 r
.71588 .26117 m .71331 .26324 L .71032 .26002 L p F P
0 g
s
.285 .518 .903 r
.61195 .27803 m .60339 .27515 L .60528 .27893 L p F P
0 g
s
.285 .518 .903 r
.61439 .28212 m .61195 .27803 L p .60528 .27893 L F P
0 g
s
0 .28 .783 r
.60236 .27439 m .60339 .27515 L .60528 .27893 L closepath p F P
0 g
s
.993 .745 .433 r
.80034 .0866 m .80287 .09087 L .80326 .08524 L p F P
0 g
s
.993 .745 .433 r
.80326 .08524 m .80073 .08096 L .80034 .0866 L p F P
0 g
s
.903 .861 .79 r
.78054 .18985 m .78485 .1841 L .78203 .18109 L p F P
0 g
s
.816 .842 .87 r
.71588 .26117 m .72586 .25298 L .7229 .24978 L p F P
0 g
s
.816 .842 .87 r
.7229 .24978 m .71426 .25686 L .71588 .26117 L p F P
0 g
s
.812 .84 .871 r
.71032 .26002 m .71426 .25686 L .71588 .26117 L p F P
0 g
s
.982 .819 .606 r
.80098 .11321 m .80328 .11752 L .80514 .11135 L p F P
0 g
s
.982 .819 .606 r
.80514 .11135 m .80286 .10703 L .80098 .11321 L p F P
0 g
s
.956 .618 .238 r
.58971 .25359 m .59266 .25755 L .59183 .2522 L p F P
0 g
s
.956 .618 .238 r
.59183 .2522 m .58889 .24823 L .58971 .25359 L p F P
0 g
s
.857 .855 .838 r
.74793 .22683 m .75323 .22142 L .75491 .22576 L p F P
0 g
s
.857 .855 .838 r
.75491 .22576 m .75083 .22992 L .74793 .22683 L p F P
0 g
s
.611 .745 .941 r
.62489 .29063 m .63768 .28754 L .64082 .29131 L p F P
0 g
s
.6 .739 .942 r
.63768 .28754 m .62489 .29063 L .62171 .28655 L p F P
0 g
s
.85 .855 .846 r
.74647 .23419 m .75083 .22992 L .74793 .22683 L p F P
0 g
s
.825 .845 .862 r
.72722 .25181 m .72586 .25298 L .7229 .24978 L p F P
0 g
s
.934 .859 .743 r
.79404 .1632 m .79377 .16366 L .79318 .16231 L closepath p F P
0 g
s
.824 .847 .865 r
.72556 .24749 m .72722 .25181 L .73737 .24283 L p F P
0 g
s
.825 .845 .862 r
.7229 .24978 m .72556 .24749 L .72722 .25181 L p F P
0 g
s
.845 .853 .849 r
.73579 .23847 m .74486 .22983 L .74647 .23419 L p F P
0 g
s
.845 .853 .849 r
.73626 .23967 m .73579 .23847 L p .74647 .23419 L F P
0 g
s
.845 .853 .849 r
.74647 .23419 m .73838 .24191 L .73626 .23967 L p F P
0 g
s
.85 .855 .846 r
.74793 .22683 m .74486 .22983 L .74647 .23419 L p F P
0 g
s
.956 .846 .693 r
.80186 .13726 m .80015 .13548 L .80056 .13461 L closepath p F P
0 g
s
.918 .857 .766 r
.78719 .16646 m .78914 .1708 L .79377 .16366 L p F P
0 g
s
.918 .857 .766 r
.79124 .16022 m .78719 .16646 L p .79377 .16366 L F P
0 g
s
.918 .857 .766 r
.79377 .16366 m .79318 .16231 L .79124 .16022 L p F P
0 g
s
.983 .7 .35 r
.7981 .0767 m .80073 .08096 L .80061 .07552 L p F P
0 g
s
.983 .7 .35 r
.80061 .07552 m .79799 .07125 L .7981 .0767 L p F P
0 g
s
.837 .852 .857 r
.73838 .24191 m .73737 .24283 L .73626 .23967 L closepath p F P
0 g
s
.824 .847 .865 r
.73545 .23879 m .72556 .24749 L p .73737 .24283 L F P
0 g
s
.824 .847 .865 r
.73737 .24283 m .73626 .23967 L .73545 .23879 L p F P
0 g
s
.732 .799 .905 r
.66483 .28513 m .65666 .2895 L .65355 .28591 L p F P
0 g
s
.692 .787 .924 r
.64082 .29131 m .65355 .28591 L .65666 .2895 L p F P
0 g
s
.903 .861 .79 r
.78203 .18109 m .77873 .1855 L .78054 .18985 L p F P
0 g
s
.895 .859 .798 r
.77277 .19311 m .77462 .19743 L .78054 .18985 L p F P
0 g
s
.895 .859 .798 r
.78054 .18985 m .77873 .1855 L .77277 .19311 L p F P
0 g
s
.978 .684 .387 r
.58574 .2443 m .58889 .24823 L .58876 .24265 L p F P
0 g
s
.978 .684 .387 r
.58876 .24265 m .58562 .23872 L .58574 .2443 L p F P
0 g
s
.966 .837 .665 r
.79835 .1303 m .80056 .13461 L .8032 .12815 L p F P
0 g
s
.966 .837 .665 r
.8032 .12815 m .801 .12384 L .79835 .1303 L p F P
0 g
s
.944 .85 .72 r
.79367 .14808 m .79575 .1524 L .79937 .14561 L p F P
0 g
s
.944 .85 .72 r
.79937 .14561 m .79731 .14127 L .79367 .14808 L p F P
0 g
s
.869 .856 .827 r
.76216 .21591 m .76035 .21397 L .76107 .21319 L closepath p F P
0 g
s
.687 .783 .924 r
.65355 .28591 m .64082 .29131 L .63768 .28754 L p F P
0 g
s
.436 .644 .945 r
.61852 .28247 m .61439 .28212 L .61661 .28625 L p F P
0 g
s
.436 .644 .945 r
.61661 .28625 m .62171 .28655 L .61852 .28247 L p F P
0 g
s
.959 .635 .24 r
.79525 .06701 m .79799 .07125 L .79732 .06601 L p F P
0 g
s
.959 .635 .24 r
.79732 .06601 m .79458 .06177 L .79525 .06701 L p F P
0 g
s
.779 .824 .887 r
.6866 .27721 m .68508 .27825 L .68203 .27487 L p F P
0 g
s
.76 .82 .899 r
.66936 .28269 m .68203 .27487 L .68508 .27825 L p F P
0 g
s
.781 .825 .887 r
.6866 .27721 m .69771 .26951 L .69469 .26617 L p F P
0 g
s
.781 .825 .887 r
.69469 .26617 m .68486 .27295 L .6866 .27721 L p F P
0 g
s
.779 .824 .887 r
.68203 .27487 m .68486 .27295 L .6866 .27721 L p F P
0 g
s
.994 .784 .51 r
.80255 .09293 m .80192 .09671 L .80431 .10101 L p F P
0 g
s
.988 .803 .567 r
.80046 .10274 m .80286 .10703 L .80431 .10101 L p F P
0 g
s
.988 .803 .567 r
.80431 .10101 m .80192 .09671 L .80046 .10274 L p F P
0 g
s
.812 .406 0 r
.78884 .04855 m .79046 .05252 L .7933 .05675 L p F P
0 g
s
.91 .542 .097 r
.79174 .05754 m .79458 .06177 L .7933 .05675 L p F P
0 g
s
.91 .542 .097 r
.7933 .05675 m .79046 .05252 L .79174 .05754 L p F P
0 g
s
.926 .855 .752 r
.79318 .16231 m .79124 .16022 L .7918 .15932 L closepath p F P
0 g
s
.887 .857 .806 r
.76981 .19673 m .77277 .19311 L .77462 .19743 L p F P
0 g
s
.887 .857 .806 r
.77462 .19743 m .77267 .19982 L .76981 .19673 L p F P
0 g
s
.915 .856 .77 r
.78224 .17373 m .78422 .17805 L .78914 .1708 L p F P
0 g
s
.915 .856 .77 r
.78914 .1708 m .78719 .16646 L .78224 .17373 L p F P
0 g
s
.881 .857 .813 r
.76805 .20524 m .77267 .19982 L .76981 .19673 L p F P
0 g
s
.731 .804 .909 r
.66483 .28513 m .66936 .28269 L .66627 .27921 L p F P
0 g
s
.731 .804 .909 r
.66627 .27921 m .66325 .28081 L .66483 .28513 L p F P
0 g
s
.732 .799 .905 r
.65355 .28591 m .66325 .28081 L .66483 .28513 L p F P
0 g
s
.972 .827 .639 r
.79869 .11954 m .801 .12384 L .80328 .11752 L p F P
0 g
s
.972 .827 .639 r
.80328 .11752 m .80098 .11321 L .79869 .11954 L p F P
0 g
s
0 .235 .752 r
.60339 .27515 m .60236 .27439 L .59912 .26954 L p F P
0 g
s
.992 .774 .506 r
.79979 .09018 m .80034 .0866 L .80287 .09087 L p F P
0 g
s
.992 .774 .506 r
.80287 .09087 m .80255 .09293 L .79979 .09018 L p F P
0 g
s
.795 .831 .879 r
.7015 .2667 m .69771 .26951 L .69469 .26617 L p F P
0 g
s
.935 .85 .734 r
.7897 .15501 m .7918 .15932 L .79575 .1524 L p F P
0 g
s
.935 .85 .734 r
.79575 .1524 m .79367 .14808 L .7897 .15501 L p F P
0 g
s
.881 .857 .813 r
.76981 .19673 m .76625 .20091 L .76805 .20524 L p F P
0 g
s
.875 .856 .819 r
.75923 .20888 m .76107 .21319 L .76805 .20524 L p F P
0 g
s
.875 .856 .819 r
.76805 .20524 m .76625 .20091 L .75923 .20888 L p F P
0 g
s
.954 .84 .693 r
.79736 .13241 m .79835 .1303 L .80056 .13461 L p F P
0 g
s
.954 .84 .693 r
.80056 .13461 m .80015 .13548 L .79736 .13241 L p F P
0 g
s
.798 .833 .878 r
.7015 .2667 m .71032 .26002 L .70732 .25672 L p F P
0 g
s
.798 .833 .878 r
.70732 .25672 m .69978 .26241 L .7015 .2667 L p F P
0 g
s
.795 .831 .879 r
.69469 .26617 m .69978 .26241 L .7015 .2667 L p F P
0 g
s
.627 .189 0 r
.59588 .26491 m .59444 .26261 L .59722 .26662 L p F P
0 g
s
.627 .189 0 r
.59722 .26662 m .59912 .26954 L .59588 .26491 L p F P
0 g
s
.758 .816 .898 r
.68203 .27487 m .66936 .28269 L .66627 .27921 L p F P
0 g
s
.951 .843 .701 r
.79731 .14127 m .80015 .13548 L .79736 .13241 L p F P
0 g
s
.872 .472 .012 r
.59147 .25865 m .59444 .26261 L .59266 .25755 L p F P
0 g
s
.872 .472 .012 r
.59266 .25755 m .58971 .25359 L .59147 .25865 L p F P
0 g
s
.219 .496 .901 r
.60932 .274 m .61195 .27803 L .60339 .27515 L p F P
0 g
s
.219 .496 .901 r
.60339 .27515 m .60102 .27103 L .60932 .274 L p F P
0 g
s
0 .235 .752 r
.59912 .26954 m .60102 .27103 L .60339 .27515 L p F P
0 g
s
.906 .855 .781 r
.77918 .17798 m .78224 .17373 L .78422 .17805 L p F P
0 g
s
.906 .855 .781 r
.78422 .17805 m .78203 .18109 L .77918 .17798 L p F P
0 g
s
.992 .778 .513 r
.80192 .09671 m .80255 .09293 L .79979 .09018 L p F P
0 g
s
.991 .741 .439 r
.7977 .08234 m .80034 .0866 L .80073 .08096 L p F P
0 g
s
.991 .741 .439 r
.80073 .08096 m .7981 .0767 L .7977 .08234 L p F P
0 g
s
.838 .848 .853 r
.73626 .23967 m .73545 .23879 L .73579 .23847 L closepath p F P
0 g
s
.867 .852 .826 r
.75746 .2108 m .75923 .20888 L .76107 .21319 L p F P
0 g
s
.867 .852 .826 r
.76107 .21319 m .76035 .21397 L .75746 .2108 L p F P
0 g
s
.861 .852 .833 r
.75323 .22142 m .76035 .21397 L .75746 .2108 L p F P
0 g
s
.81 .837 .87 r
.71426 .25686 m .71032 .26002 L .70732 .25672 L p F P
0 g
s
.6 .739 .942 r
.62171 .28655 m .63452 .28372 L .63768 .28754 L p F P
0 g
s
.59 .734 .943 r
.63452 .28372 m .62171 .28655 L .61852 .28247 L p F P
0 g
s
.958 .617 .26 r
.58656 .24967 m .58971 .25359 L .58889 .24823 L p F P
0 g
s
.958 .617 .26 r
.58889 .24823 m .58574 .2443 L .58656 .24967 L p F P
0 g
s
.979 .814 .609 r
.79857 .10892 m .80098 .11321 L .80286 .10703 L p F P
0 g
s
.979 .814 .609 r
.80286 .10703 m .80046 .10274 L .79857 .10892 L p F P
0 g
s
.814 .839 .868 r
.71426 .25686 m .7229 .24978 L .71993 .24652 L p F P
0 g
s
.814 .839 .868 r
.71993 .24652 m .71252 .25256 L .71426 .25686 L p F P
0 g
s
.81 .837 .87 r
.70732 .25672 m .71252 .25256 L .71426 .25686 L p F P
0 g
s
.901 .856 .788 r
.77873 .1855 m .78203 .18109 L .77918 .17798 L p F P
0 g
s
.861 .852 .833 r
.75746 .2108 m .75144 .2171 L .75323 .22142 L p F P
0 g
s
.856 .851 .837 r
.74501 .22366 m .75144 .2171 L .75323 .22142 L p F P
0 g
s
.856 .851 .837 r
.75323 .22142 m .74793 .22683 L .74501 .22366 L p F P
0 g
s
.983 .698 .358 r
.79536 .07246 m .7981 .0767 L .79799 .07125 L p F P
0 g
s
.983 .698 .358 r
.79799 .07125 m .79525 .06701 L .79536 .07246 L p F P
0 g
s
.728 .796 .906 r
.66325 .28081 m .65355 .28591 L .65043 .28227 L p F P
0 g
s
.687 .783 .924 r
.63768 .28754 m .65043 .28227 L .65355 .28591 L p F P
0 g
s
.848 .851 .844 r
.74486 .22983 m .74793 .22683 L .74501 .22366 L p F P
0 g
s
.824 .841 .861 r
.72556 .24749 m .7229 .24978 L .71993 .24652 L p F P
0 g
s
.924 .85 .751 r
.78841 .15707 m .7897 .15501 L .7918 .15932 L p F P
0 g
s
.924 .85 .751 r
.7918 .15932 m .79124 .16022 L .78841 .15707 L p F P
0 g
s
.828 .843 .858 r
.72556 .24749 m .73545 .23879 L .7325 .23554 L p F P
0 g
s
.828 .843 .858 r
.7325 .23554 m .72378 .2432 L .72556 .24749 L p F P
0 g
s
.824 .841 .861 r
.71993 .24652 m .72378 .2432 L .72556 .24749 L p F P
0 g
s
.848 .851 .844 r
.74501 .22366 m .74312 .2255 L .74486 .22983 L p F P
0 g
s
.843 .849 .848 r
.73397 .23418 m .73579 .23847 L .74486 .22983 L p F P
0 g
s
.843 .849 .848 r
.74486 .22983 m .74312 .2255 L .73397 .23418 L p F P
0 g
s
.963 .831 .666 r
.79602 .12601 m .79835 .1303 L .801 .12384 L p F P
0 g
s
.963 .831 .666 r
.801 .12384 m .79869 .11954 L .79602 .12601 L p F P
0 g
s
.92 .852 .759 r
.78719 .16646 m .79124 .16022 L .78841 .15707 L p F P
0 g
s
.836 .844 .852 r
.7325 .23554 m .73397 .23418 L .73579 .23847 L p F P
0 g
s
.836 .844 .852 r
.73579 .23847 m .73545 .23879 L .7325 .23554 L p F P
0 g
s
.901 .856 .788 r
.77918 .17798 m .7768 .18117 L .77873 .1855 L p F P
0 g
s
.893 .854 .797 r
.77081 .1888 m .77277 .19311 L .77873 .1855 L p F P
0 g
s
.893 .854 .797 r
.77873 .1855 m .7768 .18117 L .77081 .1888 L p F P
0 g
s
.682 .779 .924 r
.65043 .28227 m .63768 .28754 L .63452 .28372 L p F P
0 g
s
.951 .843 .701 r
.79736 .13241 m .79513 .13696 L .79731 .14127 L p F P
0 g
s
.941 .845 .72 r
.79147 .14378 m .79367 .14808 L .79731 .14127 L p F P
0 g
s
.941 .845 .72 r
.79731 .14127 m .79513 .13696 L .79147 .14378 L p F P
0 g
s
.961 .635 .251 r
.79241 .06278 m .79525 .06701 L .79458 .06177 L p F P
0 g
s
.961 .635 .251 r
.79458 .06177 m .79174 .05754 L .79241 .06278 L p F P
0 g
s
.777 .82 .887 r
.68486 .27295 m .68203 .27487 L .67897 .27142 L p F P
0 g
s
.758 .816 .898 r
.66627 .27921 m .67897 .27142 L .68203 .27487 L p F P
0 g
s
.414 .633 .945 r
.61532 .2784 m .61195 .27803 L .61439 .28212 L p F P
0 g
s
.414 .633 .945 r
.61439 .28212 m .61852 .28247 L .61532 .2784 L p F P
0 g
s
.992 .778 .513 r
.79979 .09018 m .79942 .09243 L .80192 .09671 L p F P
0 g
s
.985 .798 .571 r
.79795 .09846 m .80046 .10274 L .80192 .09671 L p F P
0 g
s
.985 .798 .571 r
.80192 .09671 m .79942 .09243 L .79795 .09846 L p F P
0 g
s
.779 .822 .886 r
.68486 .27295 m .69469 .26617 L .69165 .26277 L p F P
0 g
s
.779 .822 .886 r
.69165 .26277 m .68299 .26871 L .68486 .27295 L p F P
0 g
s
.777 .82 .887 r
.67897 .27142 m .68299 .26871 L .68486 .27295 L p F P
0 g
s
0 .196 .719 r
.60102 .27103 m .59912 .26954 L .59588 .26491 L p F P
0 g
s
.885 .852 .805 r
.76693 .19354 m .77081 .1888 L .77277 .19311 L p F P
0 g
s
.885 .852 .805 r
.77277 .19311 m .76981 .19673 L .76693 .19354 L p F P
0 g
s
.92 .852 .759 r
.78841 .15707 m .78513 .16215 L .78719 .16646 L p F P
0 g
s
.912 .851 .77 r
.78015 .16943 m .78224 .17373 L .78719 .16646 L p F P
0 g
s
.912 .851 .77 r
.78719 .16646 m .78513 .16215 L .78015 .16943 L p F P
0 g
s
.969 .821 .641 r
.79627 .11526 m .79869 .11954 L .80098 .11321 L p F P
0 g
s
.969 .821 .641 r
.80098 .11321 m .79857 .10892 L .79627 .11526 L p F P
0 g
s
.88 .853 .812 r
.76625 .20091 m .76981 .19673 L .76693 .19354 L p F P
0 g
s
.99 .769 .509 r
.79699 .08704 m .7977 .08234 L .80034 .0866 L p F P
0 g
s
.99 .769 .509 r
.80034 .0866 m .79979 .09018 L .79699 .08704 L p F P
0 g
s
.727 .801 .91 r
.66325 .28081 m .66627 .27921 L .66317 .27567 L p F P
0 g
s
.727 .801 .91 r
.66317 .27567 m .66158 .2765 L .66325 .28081 L p F P
0 g
s
.728 .796 .906 r
.65043 .28227 m .66158 .2765 L .66325 .28081 L p F P
0 g
s
.794 .827 .878 r
.69978 .26241 m .69469 .26617 L .69165 .26277 L p F P
0 g
s
.932 .845 .734 r
.78748 .15072 m .7897 .15501 L .79367 .14808 L p F P
0 g
s
.932 .845 .734 r
.79367 .14808 m .79147 .14378 L .78748 .15072 L p F P
0 g
s
.951 .835 .693 r
.79454 .12919 m .79602 .12601 L .79835 .1303 L p F P
0 g
s
.951 .835 .693 r
.79835 .1303 m .79736 .13241 L .79454 .12919 L p F P
0 g
s
.873 .851 .818 r
.75726 .20458 m .75923 .20888 L .76625 .20091 L p F P
0 g
s
.873 .851 .818 r
.76625 .20091 m .76433 .19659 L .75726 .20458 L p F P
0 g
s
.88 .853 .812 r
.76693 .19354 m .76433 .19659 L .76625 .20091 L p F P
0 g
s
.672 .225 0 r
.59264 .26056 m .59147 .25865 L .59444 .26261 L p F P
0 g
s
.672 .225 0 r
.59444 .26261 m .59588 .26491 L .59264 .26056 L p F P
0 g
s
.757 .813 .897 r
.67897 .27142 m .66627 .27921 L .66317 .27567 L p F P
0 g
s
.884 .481 .043 r
.58831 .25474 m .59147 .25865 L .58971 .25359 L p F P
0 g
s
.884 .481 .043 r
.58971 .25359 m .58656 .24967 L .58831 .25474 L p F P
0 g
s
.797 .83 .877 r
.69978 .26241 m .70732 .25672 L .70431 .25336 L p F P
0 g
s
.797 .83 .877 r
.70431 .25336 m .69793 .25814 L .69978 .26241 L p F P
0 g
s
.794 .827 .878 r
.69165 .26277 m .69793 .25814 L .69978 .26241 L p F P
0 g
s
.99 .738 .446 r
.79496 .0781 m .7977 .08234 L .7981 .0767 L p F P
0 g
s
.99 .738 .446 r
.7981 .0767 m .79536 .07246 L .79496 .0781 L p F P
0 g
s
0 .196 .719 r
.59588 .26491 m .59837 .26698 L .60102 .27103 L p F P
0 g
s
.189 .487 .9 r
.6065 .27 m .60932 .274 L .60102 .27103 L p F P
0 g
s
.189 .487 .9 r
.60102 .27103 m .59837 .26698 L .6065 .27 L p F P
0 g
s
.59 .734 .943 r
.61852 .28247 m .63135 .27988 L .63452 .28372 L p F P
0 g
s
.581 .729 .945 r
.63135 .27988 m .61852 .28247 L .61532 .2784 L p F P
0 g
s
.948 .838 .701 r
.79513 .13696 m .79736 .13241 L .79454 .12919 L p F P
0 g
s
.904 .85 .78 r
.77632 .17476 m .78015 .16943 L .78224 .17373 L p F P
0 g
s
.904 .85 .78 r
.78224 .17373 m .77918 .17798 L .77632 .17476 L p F P
0 g
s
.865 .848 .824 r
.75455 .20754 m .75726 .20458 L .75923 .20888 L p F P
0 g
s
.865 .848 .824 r
.75923 .20888 m .75746 .2108 L .75455 .20754 L p F P
0 g
s
.976 .808 .611 r
.79605 .10466 m .79857 .10892 L .80046 .10274 L p F P
0 g
s
.976 .808 .611 r
.80046 .10274 m .79795 .09846 L .79605 .10466 L p F P
0 g
s
.809 .833 .869 r
.71252 .25256 m .70732 .25672 L .70431 .25336 L p F P
0 g
s
.859 .848 .831 r
.75144 .2171 m .75746 .2108 L .75455 .20754 L p F P
0 g
s
.99 .773 .517 r
.79942 .09243 m .79979 .09018 L .79699 .08704 L p F P
0 g
s
.983 .695 .366 r
.79252 .06824 m .79536 .07246 L .79525 .06701 L p F P
0 g
s
.983 .695 .366 r
.79525 .06701 m .79241 .06278 L .79252 .06824 L p F P
0 g
s
.812 .835 .867 r
.71252 .25256 m .71993 .24652 L .71694 .24317 L p F P
0 g
s
.812 .835 .867 r
.71694 .24317 m .71065 .24829 L .71252 .25256 L p F P
0 g
s
.809 .833 .869 r
.70431 .25336 m .71065 .24829 L .71252 .25256 L p F P
0 g
s
.859 .848 .831 r
.75455 .20754 m .74952 .21281 L .75144 .2171 L p F P
0 g
s
.855 .847 .835 r
.74207 .2204 m .74952 .21281 L .75144 .2171 L p F P
0 g
s
.855 .847 .835 r
.75144 .2171 m .74501 .22366 L .74207 .2204 L p F P
0 g
s
.899 .851 .787 r
.7768 .18117 m .77918 .17798 L .77632 .17476 L p F P
0 g
s
.725 .793 .906 r
.66158 .2765 m .65043 .28227 L .6473 .27859 L p F P
0 g
s
.682 .779 .924 r
.63452 .28372 m .6473 .27859 L .65043 .28227 L p F P
0 g
s
.922 .845 .75 r
.78557 .1538 m .78748 .15072 L .7897 .15501 L p F P
0 g
s
.922 .845 .75 r
.7897 .15501 m .78841 .15707 L .78557 .1538 L p F P
0 g
s
.823 .837 .859 r
.72378 .2432 m .71993 .24652 L .71694 .24317 L p F P
0 g
s
.96 .826 .667 r
.79359 .12174 m .79602 .12601 L .79869 .11954 L p F P
0 g
s
.96 .826 .667 r
.79869 .11954 m .79627 .11526 L .79359 .12174 L p F P
0 g
s
.678 .776 .924 r
.6473 .27859 m .63452 .28372 L .63135 .27988 L p F P
0 g
s
.847 .846 .843 r
.74312 .2255 m .74501 .22366 L .74207 .2204 L p F P
0 g
s
.827 .839 .857 r
.72378 .2432 m .7325 .23554 L .72953 .23221 L p F P
0 g
s
.827 .839 .857 r
.72953 .23221 m .72188 .23893 L .72378 .2432 L p F P
0 g
s
.823 .837 .859 r
.71694 .24317 m .72188 .23893 L .72378 .2432 L p F P
0 g
s
.847 .846 .843 r
.74207 .2204 m .74126 .2212 L .74312 .2255 L p F P
0 g
s
.841 .844 .847 r
.73203 .22991 m .73397 .23418 L .74312 .2255 L p F P
0 g
s
.841 .844 .847 r
.74312 .2255 m .74126 .2212 L .73203 .22991 L p F P
0 g
s
.899 .851 .787 r
.77632 .17476 m .77475 .17686 L .7768 .18117 L p F P
0 g
s
.89 .849 .797 r
.76872 .18451 m .77081 .1888 L .7768 .18117 L p F P
0 g
s
.89 .849 .797 r
.7768 .18117 m .77475 .17686 L .76872 .18451 L p F P
0 g
s
.948 .838 .701 r
.79454 .12919 m .79284 .13267 L .79513 .13696 L p F P
0 g
s
.938 .839 .72 r
.78916 .1395 m .79147 .14378 L .79513 .13696 L p F P
0 g
s
.938 .839 .72 r
.79513 .13696 m .79284 .13267 L .78916 .1395 L p F P
0 g
s
.835 .84 .85 r
.72953 .23221 m .73203 .22991 L .73397 .23418 L p F P
0 g
s
.835 .84 .85 r
.73397 .23418 m .7325 .23554 L .72953 .23221 L p F P
0 g
s
0 .164 .689 r
.59837 .26698 m .59588 .26491 L .59264 .26056 L p F P
0 g
s
.918 .846 .758 r
.78513 .16215 m .78841 .15707 L .78557 .1538 L p F P
0 g
s
.775 .817 .886 r
.68299 .26871 m .67897 .27142 L .67589 .26791 L p F P
0 g
s
.757 .813 .897 r
.66317 .27567 m .67589 .26791 L .67897 .27142 L p F P
0 g
s
.99 .773 .517 r
.79699 .08704 m .7968 .08817 L .79942 .09243 L p F P
0 g
s
.982 .792 .574 r
.79532 .09421 m .79795 .09846 L .79942 .09243 L p F P
0 g
s
.982 .792 .574 r
.79942 .09243 m .7968 .08817 L .79532 .09421 L p F P
0 g
s
.394 .624 .945 r
.61211 .27436 m .60932 .274 L .61195 .27803 L p F P
0 g
s
.394 .624 .945 r
.61195 .27803 m .61532 .2784 L .61211 .27436 L p F P
0 g
s
.775 .817 .886 r
.67589 .26791 m .68099 .26449 L .68299 .26871 L p F P
0 g
s
.777 .819 .886 r
.68299 .26871 m .69165 .26277 L .6886 .2593 L p F P
0 g
s
.777 .819 .886 r
.6886 .2593 m .68099 .26449 L .68299 .26871 L p F P
0 g
s
.884 .847 .803 r
.76403 .19025 m .76872 .18451 L .77081 .1888 L p F P
0 g
s
.884 .847 .803 r
.77081 .1888 m .76693 .19354 L .76403 .19025 L p F P
0 g
s
.918 .846 .758 r
.78557 .1538 m .78295 .15785 L .78513 .16215 L p F P
0 g
s
.909 .846 .769 r
.77795 .16515 m .78015 .16943 L .78513 .16215 L p F P
0 g
s
.909 .846 .769 r
.78513 .16215 m .78295 .15785 L .77795 .16515 L p F P
0 g
s
.966 .816 .643 r
.79374 .111 m .79627 .11526 L .79857 .10892 L p F P
0 g
s
.966 .816 .643 r
.79857 .10892 m .79605 .10466 L .79374 .111 L p F P
0 g
s
.988 .764 .512 r
.79414 .08348 m .79496 .0781 L .7977 .08234 L p F P
0 g
s
.988 .764 .512 r
.7977 .08234 m .79699 .08704 L .79414 .08348 L p F P
0 g
s
.878 .848 .81 r
.76433 .19659 m .76693 .19354 L .76403 .19025 L p F P
0 g
s
.724 .798 .91 r
.66158 .2765 m .66317 .27567 L .66006 .27208 L p F P
0 g
s
.724 .798 .91 r
.66006 .27208 m .6598 .27221 L .66158 .2765 L p F P
0 g
s
.725 .793 .906 r
.6473 .27859 m .6598 .27221 L .66158 .2765 L p F P
0 g
s
.929 .839 .734 r
.78515 .14645 m .78748 .15072 L .79147 .14378 L p F P
0 g
s
.929 .839 .734 r
.79147 .14378 m .78916 .1395 L .78515 .14645 L p F P
0 g
s
.792 .824 .877 r
.69793 .25814 m .69165 .26277 L .6886 .2593 L p F P
0 g
s
.949 .83 .692 r
.79169 .1258 m .79359 .12174 L .79602 .12601 L p F P
0 g
s
.949 .83 .692 r
.79602 .12601 m .79454 .12919 L .79169 .1258 L p F P
0 g
s
.706 .251 0 r
.58939 .25651 m .58831 .25474 L .59147 .25865 L p F P
0 g
s
.706 .251 0 r
.59147 .25865 m .59264 .26056 L .58939 .25651 L p F P
0 g
s
.878 .848 .81 r
.76403 .19025 m .76229 .1923 L .76433 .19659 L p F P
0 g
s
.871 .846 .817 r
.75518 .20031 m .75726 .20458 L .76433 .19659 L p F P
0 g
s
.871 .846 .817 r
.76433 .19659 m .76229 .1923 L .75518 .20031 L p F P
0 g
s
.755 .81 .896 r
.67589 .26791 m .66317 .27567 L .66006 .27208 L p F P
0 g
s
.581 .729 .945 r
.61532 .2784 m .62818 .27602 L .63135 .27988 L p F P
0 g
s
.573 .726 .946 r
.62818 .27602 m .61532 .2784 L .61211 .27436 L p F P
0 g
s
.988 .734 .452 r
.79211 .07389 m .79496 .0781 L .79536 .07246 L p F P
0 g
s
.988 .734 .452 r
.79536 .07246 m .79252 .06824 L .79211 .07389 L p F P
0 g
s
.795 .826 .876 r
.69793 .25814 m .70431 .25336 L .70128 .24992 L p F P
0 g
s
.795 .826 .876 r
.70128 .24992 m .69595 .2539 L .69793 .25814 L p F P
0 g
s
.792 .824 .877 r
.6886 .2593 m .69595 .2539 L .69793 .25814 L p F P
0 g
s
0 .164 .689 r
.59264 .26056 m .59548 .263 L .59837 .26698 L p F P
0 g
s
.164 .482 .898 r
.6035 .26605 m .6065 .27 L .59837 .26698 L p F P
0 g
s
.164 .482 .898 r
.59837 .26698 m .59548 .263 L .6035 .26605 L p F P
0 g
s
.902 .845 .778 r
.77344 .17143 m .77795 .16515 L .78015 .16943 L p F P
0 g
s
.902 .845 .778 r
.78015 .16943 m .77632 .17476 L .77344 .17143 L p F P
0 g
s
.972 .803 .613 r
.79341 .10041 m .79605 .10466 L .79795 .09846 L p F P
0 g
s
.972 .803 .613 r
.79795 .09846 m .79532 .09421 L .79341 .10041 L p F P
0 g
s
.946 .832 .7 r
.79284 .13267 m .79454 .12919 L .79169 .1258 L p F P
0 g
s
.864 .843 .823 r
.75162 .20419 m .75518 .20031 L .75726 .20458 L p F P
0 g
s
.864 .843 .823 r
.75726 .20458 m .75455 .20754 L .75162 .20419 L p F P
0 g
s
.807 .829 .867 r
.71065 .24829 m .70431 .25336 L .70128 .24992 L p F P
0 g
s
.858 .843 .83 r
.74952 .21281 m .75455 .20754 L .75162 .20419 L p F P
0 g
s
.722 .79 .906 r
.6598 .27221 m .6473 .27859 L .64415 .27486 L p F P
0 g
s
.678 .776 .924 r
.63135 .27988 m .64415 .27486 L .6473 .27859 L p F P
0 g
s
.811 .831 .866 r
.71065 .24829 m .71694 .24317 L .71393 .23975 L p F P
0 g
s
.811 .831 .866 r
.71393 .23975 m .70864 .24405 L .71065 .24829 L p F P
0 g
s
.807 .829 .867 r
.70128 .24992 m .70864 .24405 L .71065 .24829 L p F P
0 g
s
.858 .843 .83 r
.75162 .20419 m .74747 .20853 L .74952 .21281 L p F P
0 g
s
.853 .842 .833 r
.73925 .21692 m .74747 .20853 L .74952 .21281 L p F P
0 g
s
.853 .842 .833 r
.73956 .21755 m .73925 .21692 L p .74952 .21281 L F P
0 g
s
.853 .842 .833 r
.74952 .21281 m .74207 .2204 L .73956 .21755 L p F P
0 g
s
.675 .773 .925 r
.64415 .27486 m .63135 .27988 L .62818 .27602 L p F P
0 g
s
0 .142 .664 r
.59548 .263 m .59264 .26056 L .58939 .25651 L p F P
0 g
s
.987 .768 .52 r
.7968 .08817 m .79699 .08704 L .79414 .08348 L p F P
0 g
s
.92 .84 .749 r
.7827 .1504 m .78515 .14645 L .78748 .15072 L p F P
0 g
s
.92 .84 .749 r
.78748 .15072 m .78557 .1538 L .7827 .1504 L p F P
0 g
s
.897 .846 .785 r
.77475 .17686 m .77632 .17476 L .77344 .17143 L p F P
0 g
s
.956 .82 .668 r
.79105 .11749 m .79359 .12174 L .79627 .11526 L p F P
0 g
s
.956 .82 .668 r
.79627 .11526 m .79374 .111 L .79105 .11749 L p F P
0 g
s
.821 .833 .858 r
.72188 .23893 m .71694 .24317 L .71393 .23975 L p F P
0 g
s
.845 .842 .841 r
.74207 .2204 m .74126 .2212 L .73956 .21755 L closepath p F P
0 g
s
.825 .835 .856 r
.72188 .23893 m .72953 .23221 L .72655 .2288 L p F P
0 g
s
.825 .835 .856 r
.72655 .2288 m .71984 .23468 L .72188 .23893 L p F P
0 g
s
.821 .833 .858 r
.71393 .23975 m .71984 .23468 L .72188 .23893 L p F P
0 g
s
.946 .832 .7 r
.79169 .1258 m .79043 .12839 L .79284 .13267 L p F P
0 g
s
.935 .834 .721 r
.78673 .13524 m .78916 .1395 L .79284 .13267 L p F P
0 g
s
.935 .834 .721 r
.79284 .13267 m .79043 .12839 L .78673 .13524 L p F P
0 g
s
.833 .838 .85 r
.72996 .22567 m .73203 .22991 L .74126 .2212 L p F P
0 g
s
.833 .838 .85 r
.73912 .21705 m .72996 .22567 L p .74126 .2212 L F P
0 g
s
.833 .838 .85 r
.74126 .2212 m .73956 .21755 L .73912 .21705 L p F P
0 g
s
.897 .846 .785 r
.77344 .17143 m .77258 .17258 L .77475 .17686 L p F P
0 g
s
.888 .844 .796 r
.76652 .18024 m .76872 .18451 L .77475 .17686 L p F P
0 g
s
.888 .844 .796 r
.77475 .17686 m .77258 .17258 L .76652 .18024 L p F P
0 g
s
.834 .836 .848 r
.72655 .2288 m .72996 .22567 L .73203 .22991 L p F P
0 g
s
.834 .836 .848 r
.73203 .22991 m .72953 .23221 L .72655 .2288 L p F P
0 g
s
.987 .768 .52 r
.79414 .08348 m .79407 .08393 L .7968 .08817 L p F P
0 g
s
.978 .787 .577 r
.79258 .08998 m .79532 .09421 L .7968 .08817 L p F P
0 g
s
.978 .787 .577 r
.7968 .08817 m .79407 .08393 L .79258 .08998 L p F P
0 g
s
.773 .814 .885 r
.68099 .26449 m .67589 .26791 L .6728 .26433 L p F P
0 g
s
.755 .81 .896 r
.66006 .27208 m .6728 .26433 L .67589 .26791 L p F P
0 g
s
.376 .617 .946 r
.6089 .27034 m .6065 .27 L .60932 .274 L p F P
0 g
s
.376 .617 .946 r
.60932 .274 m .61211 .27436 L .6089 .27034 L p F P
0 g
s
.915 .841 .756 r
.78295 .15785 m .78557 .1538 L .7827 .1504 L p F P
0 g
s
.775 .816 .885 r
.68099 .26449 m .6886 .2593 L .68553 .25577 L p F P
0 g
s
.775 .816 .885 r
.68553 .25577 m .67885 .26029 L .68099 .26449 L p F P
0 g
s
.773 .814 .885 r
.6728 .26433 m .67885 .26029 L .68099 .26449 L p F P
0 g
s
.882 .843 .801 r
.76112 .18685 m .76652 .18024 L .76872 .18451 L p F P
0 g
s
.882 .843 .801 r
.76872 .18451 m .76403 .19025 L .76112 .18685 L p F P
0 g
s
.906 .84 .769 r
.77562 .16089 m .77795 .16515 L .78295 .15785 L p F P
0 g
s
.906 .84 .769 r
.78295 .15785 m .78065 .15358 L .77562 .16089 L p F P
0 g
s
.915 .841 .756 r
.7827 .1504 m .78065 .15358 L .78295 .15785 L p F P
0 g
s
.985 .759 .516 r
.79125 .0795 m .79211 .07389 L .79496 .0781 L p F P
0 g
s
.985 .759 .516 r
.79496 .0781 m .79414 .08348 L .79125 .0795 L p F P
0 g
s
.963 .81 .644 r
.79109 .10676 m .79374 .111 L .79605 .10466 L p F P
0 g
s
.963 .81 .644 r
.79605 .10466 m .79341 .10041 L .79109 .10676 L p F P
0 g
s
.927 .834 .734 r
.78271 .1422 m .78515 .14645 L .78916 .1395 L p F P
0 g
s
.927 .834 .734 r
.78916 .1395 m .78673 .13524 L .78271 .1422 L p F P
0 g
s
.946 .824 .692 r
.78883 .12224 m .79105 .11749 L .79359 .12174 L p F P
0 g
s
.946 .824 .692 r
.79359 .12174 m .79169 .1258 L .78883 .12224 L p F P
0 g
s
.573 .726 .946 r
.61211 .27436 m .62499 .27213 L .62818 .27602 L p F P
0 g
s
.567 .723 .947 r
.62499 .27213 m .61211 .27436 L .6089 .27034 L p F P
0 g
s
.791 .82 .876 r
.69595 .2539 m .6886 .2593 L .68553 .25577 L p F P
0 g
s
.876 .843 .809 r
.76229 .1923 m .76403 .19025 L .76112 .18685 L p F P
0 g
s
.724 .796 .909 r
.66006 .27208 m .6598 .27221 L .65936 .27125 L closepath p F P
0 g
s
.722 .79 .906 r
.65694 .26841 m .65936 .27125 L .6598 .27221 L p F P
0 g
s
.722 .79 .906 r
.64415 .27486 m .65694 .26841 L p .6598 .27221 L F P
0 g
s
.761 .806 .889 r
.6697 .2607 m .6728 .26433 L .66006 .27208 L p F P
0 g
s
.761 .806 .889 r
.65749 .26807 m .6697 .2607 L p .66006 .27208 L F P
0 g
s
.761 .806 .889 r
.66006 .27208 m .65936 .27125 L .65749 .26807 L p F P
0 g
s
.876 .843 .809 r
.76112 .18685 m .76013 .18803 L .76229 .1923 L p F P
0 g
s
.868 .841 .816 r
.75297 .19607 m .75518 .20031 L .76229 .1923 L p F P
0 g
s
.868 .841 .816 r
.76229 .1923 m .76013 .18803 L .75297 .19607 L p F P
0 g
s
0 .142 .664 r
.58939 .25651 m .59235 .25907 L .59548 .263 L p F P
0 g
s
.144 .479 .898 r
.60034 .26213 m .6035 .26605 L .59548 .263 L p F P
0 g
s
.144 .479 .898 r
.59548 .263 m .59235 .25907 L .60034 .26213 L p F P
0 g
s
.793 .823 .875 r
.69595 .2539 m .70128 .24992 L .69824 .24641 L p F P
0 g
s
.793 .823 .875 r
.69824 .24641 m .69383 .24969 L .69595 .2539 L p F P
0 g
s
.791 .82 .876 r
.68553 .25577 m .69383 .24969 L .69595 .2539 L p F P
0 g
s
.9 .84 .777 r
.77054 .16798 m .77562 .16089 L .77795 .16515 L p F P
0 g
s
.9 .84 .777 r
.77795 .16515 m .77344 .17143 L .77054 .16798 L p F P
0 g
s
.969 .797 .615 r
.79066 .09619 m .79341 .10041 L .79532 .09421 L p F P
0 g
s
.969 .797 .615 r
.79532 .09421 m .79258 .08998 L .79066 .09619 L p F P
0 g
s
.862 .839 .821 r
.74868 .20074 m .75297 .19607 L .75518 .20031 L p F P
0 g
s
.862 .839 .821 r
.75518 .20031 m .75162 .20419 L .74868 .20074 L p F P
0 g
s
.751 .802 .894 r
.65936 .27125 m .65694 .26841 L .65749 .26807 L closepath p F P
0 g
s
.806 .826 .866 r
.70864 .24405 m .70128 .24992 L .69824 .24641 L p F P
0 g
s
.943 .826 .7 r
.79043 .12839 m .79169 .1258 L .78883 .12224 L p F P
0 g
s
.719 .791 .909 r
.65694 .26841 m .64415 .27486 L .641 .27109 L p F P
0 g
s
.675 .773 .925 r
.62818 .27602 m .641 .27109 L .64415 .27486 L p F P
0 g
s
.672 .771 .925 r
.641 .27109 m .62818 .27602 L .62499 .27213 L p F P
0 g
s
.856 .839 .828 r
.74747 .20853 m .75162 .20419 L .74868 .20074 L p F P
0 g
s
.845 .839 .839 r
.73956 .21755 m .73912 .21705 L .73925 .21692 L closepath p F P
0 g
s
.809 .827 .865 r
.70864 .24405 m .71393 .23975 L .71091 .23625 L p F P
0 g
s
.809 .827 .865 r
.71091 .23625 m .7065 .23983 L .70864 .24405 L p F P
0 g
s
.806 .826 .866 r
.69824 .24641 m .7065 .23983 L .70864 .24405 L p F P
0 g
s
.953 .815 .669 r
.78839 .11326 m .79105 .11749 L .79374 .111 L p F P
0 g
s
.953 .815 .669 r
.79374 .111 m .79109 .10676 L .78839 .11326 L p F P
0 g
s
.917 .834 .748 r
.77982 .14687 m .78271 .1422 L .78515 .14645 L p F P
0 g
s
.917 .834 .748 r
.78515 .14645 m .7827 .1504 L .77982 .14687 L p F P
0 g
s
.856 .839 .828 r
.74868 .20074 m .7453 .20428 L .74747 .20853 L p F P
0 g
s
.851 .838 .832 r
.73702 .2127 m .73925 .21692 L .74747 .20853 L p F P
0 g
s
.851 .838 .832 r
.74747 .20853 m .7453 .20428 L .73702 .2127 L p F P
0 g
s
.984 .763 .524 r
.79407 .08393 m .79414 .08348 L .79125 .0795 L p F P
0 g
s
.895 .841 .784 r
.77258 .17258 m .77344 .17143 L .77054 .16798 L p F P
0 g
s
.82 .829 .857 r
.71984 .23468 m .71393 .23975 L .71091 .23625 L p F P
0 g
s
.943 .826 .7 r
.78883 .12224 m .7879 .12414 L .79043 .12839 L p F P
0 g
s
.932 .828 .72 r
.78419 .131 m .78673 .13524 L .79043 .12839 L p F P
0 g
s
.932 .828 .72 r
.79043 .12839 m .7879 .12414 L .78419 .131 L p F P
0 g
s
.984 .763 .524 r
.79125 .0795 m .79122 .07972 L .79407 .08393 L p F P
0 g
s
.975 .781 .58 r
.78972 .08577 m .79258 .08998 L .79407 .08393 L p F P
0 g
s
.975 .781 .58 r
.79407 .08393 m .79122 .07972 L .78972 .08577 L p F P
0 g
s
.824 .831 .854 r
.71984 .23468 m .72655 .2288 L .72356 .22531 L p F P
0 g
s
.824 .831 .854 r
.72356 .22531 m .71767 .23046 L .71984 .23468 L p F P
0 g
s
.82 .829 .857 r
.71091 .23625 m .71767 .23046 L .71984 .23468 L p F P
0 g
s
.895 .841 .784 r
.77054 .16798 m .77029 .16832 L .77258 .17258 L p F P
0 g
s
.885 .839 .795 r
.7642 .176 m .76652 .18024 L .77258 .17258 L p F P
0 g
s
.885 .839 .795 r
.77258 .17258 m .77029 .16832 L .7642 .176 L p F P
0 g
s
.844 .835 .837 r
.73615 .21355 m .73702 .2127 L .73925 .21692 L p F P
0 g
s
.844 .835 .837 r
.73925 .21692 m .73912 .21705 L .73615 .21355 L p F P
0 g
s
.836 .834 .844 r
.72996 .22567 m .73912 .21705 L .73615 .21355 L p F P
0 g
s
.836 .834 .844 r
.73615 .21355 m .72776 .22144 L .72996 .22567 L p F P
0 g
s
.832 .832 .847 r
.72356 .22531 m .72776 .22144 L .72996 .22567 L p F P
0 g
s
.832 .832 .847 r
.72996 .22567 m .72655 .2288 L .72356 .22531 L p F P
0 g
s
.36 .612 .946 r
.60567 .26637 m .6035 .26605 L .6065 .27 L p F P
0 g
s
.36 .612 .946 r
.6065 .27 m .6089 .27034 L .60567 .26637 L p F P
0 g
s
.772 .811 .884 r
.67885 .26029 m .6728 .26433 L .6697 .2607 L p F P
0 g
s
.913 .836 .755 r
.78065 .15358 m .7827 .1504 L .77982 .14687 L p F P
0 g
s
.774 .813 .884 r
.67885 .26029 m .68553 .25577 L .68245 .25216 L p F P
0 g
s
.774 .813 .884 r
.68245 .25216 m .67657 .25613 L .67885 .26029 L p F P
0 g
s
.772 .811 .884 r
.6697 .2607 m .67657 .25613 L .67885 .26029 L p F P
0 g
s
.959 .804 .645 r
.78833 .10255 m .79109 .10676 L .79341 .10041 L p F P
0 g
s
.959 .804 .645 r
.79341 .10041 m .79066 .09619 L .78833 .10255 L p F P
0 g
s
.88 .838 .8 r
.75819 .18336 m .7642 .176 L .76652 .18024 L p F P
0 g
s
.88 .838 .8 r
.76652 .18024 m .76112 .18685 L .75819 .18336 L p F P
0 g
s
.913 .836 .755 r
.77982 .14687 m .77823 .14933 L .78065 .15358 L p F P
0 g
s
.904 .835 .768 r
.77318 .15666 m .77562 .16089 L .78065 .15358 L p F P
0 g
s
.904 .835 .768 r
.78065 .15358 m .77823 .14933 L .77318 .15666 L p F P
0 g
s
.567 .723 .947 r
.6089 .27034 m .62179 .26824 L .62499 .27213 L p F P
0 g
s
.564 .722 .948 r
.62179 .26824 m .6089 .27034 L .60567 .26637 L p F P
0 g
s
.943 .818 .691 r
.78594 .11851 m .78839 .11326 L .79105 .11749 L p F P
0 g
s
.943 .818 .691 r
.79105 .11749 m .78883 .12224 L .78594 .11851 L p F P
0 g
s
.924 .829 .733 r
.78015 .13797 m .78271 .1422 L .78673 .13524 L p F P
0 g
s
.924 .829 .733 r
.78673 .13524 m .78419 .131 L .78015 .13797 L p F P
0 g
s
.789 .817 .874 r
.69383 .24969 m .68553 .25577 L .68245 .25216 L p F P
0 g
s
.75 .8 .893 r
.65749 .26807 m .65694 .26841 L .6538 .26468 L p F P
0 g
s
.719 .791 .909 r
.641 .27109 m .6538 .26468 L .65694 .26841 L p F P
0 g
s
.874 .838 .807 r
.76013 .18803 m .76112 .18685 L .75819 .18336 L p F P
0 g
s
.751 .8 .892 r
.65749 .26807 m .6697 .2607 L .66658 .25701 L p F P
0 g
s
.751 .8 .892 r
.66658 .25701 m .65495 .264 L .65749 .26807 L p F P
0 g
s
.75 .8 .893 r
.6538 .26468 m .65495 .264 L .65749 .26807 L p F P
0 g
s
.874 .838 .807 r
.75819 .18336 m .75783 .18378 L .76013 .18803 L p F P
0 g
s
.866 .837 .815 r
.75064 .19184 m .75297 .19607 L .76013 .18803 L p F P
0 g
s
.866 .837 .815 r
.76013 .18803 m .75783 .18378 L .75064 .19184 L p F P
0 g
s
.966 .792 .617 r
.78779 .09198 m .79066 .09619 L .79258 .08998 L p F P
0 g
s
.966 .792 .617 r
.79258 .08998 m .78972 .08577 L .78779 .09198 L p F P
0 g
s
.898 .835 .775 r
.76785 .16409 m .77318 .15666 L .77562 .16089 L p F P
0 g
s
.898 .835 .775 r
.76905 .16615 m .76785 .16409 L p .77562 .16089 L F P
0 g
s
.898 .835 .775 r
.77562 .16089 m .77054 .16798 L .76905 .16615 L p F P
0 g
s
.792 .819 .874 r
.69383 .24969 m .69824 .24641 L .69518 .24282 L p F P
0 g
s
.792 .819 .874 r
.69518 .24282 m .69156 .2455 L .69383 .24969 L p F P
0 g
s
.789 .817 .874 r
.68245 .25216 m .69156 .2455 L .69383 .24969 L p F P
0 g
s
.717 .789 .908 r
.6538 .26468 m .641 .27109 L .63783 .26728 L p F P
0 g
s
.672 .771 .925 r
.62499 .27213 m .63783 .26728 L .641 .27109 L p F P
0 g
s
.861 .835 .819 r
.74572 .1972 m .75064 .19184 L .75297 .19607 L p F P
0 g
s
.861 .835 .819 r
.75297 .19607 m .74868 .20074 L .74572 .1972 L p F P
0 g
s
.67 .769 .924 r
.63783 .26728 m .62499 .27213 L .62179 .26824 L p F P
0 g
s
.805 .822 .865 r
.7065 .23983 m .69824 .24641 L .69518 .24282 L p F P
0 g
s
.94 .82 .699 r
.7879 .12414 m .78883 .12224 L .78594 .11851 L p F P
0 g
s
.854 .834 .826 r
.7453 .20428 m .74868 .20074 L .74572 .1972 L p F P
0 g
s
.95 .809 .669 r
.78562 .10905 m .78839 .11326 L .79109 .10676 L p F P
0 g
s
.95 .809 .669 r
.79109 .10676 m .78833 .10255 L .78562 .10905 L p F P
0 g
s
.915 .829 .747 r
.77691 .1432 m .78015 .13797 L .78271 .1422 L p F P
0 g
s
.915 .829 .747 r
.78271 .1422 m .77982 .14687 L .77691 .1432 L p F P
0 g
s
.808 .824 .863 r
.7065 .23983 m .71091 .23625 L .70788 .23268 L p F P
0 g
s
.808 .824 .863 r
.70788 .23268 m .70421 .23564 L .7065 .23983 L p F P
0 g
s
.805 .822 .865 r
.69518 .24282 m .70421 .23564 L .7065 .23983 L p F P
0 g
s
.854 .834 .826 r
.74572 .1972 m .74299 .20006 L .7453 .20428 L p F P
0 g
s
.849 .833 .831 r
.73468 .2085 m .73702 .2127 L .7453 .20428 L p F P
0 g
s
.849 .833 .831 r
.7453 .20428 m .74299 .20006 L .73468 .2085 L p F P
0 g
s
.94 .82 .699 r
.78594 .11851 m .78526 .11991 L .7879 .12414 L p F P
0 g
s
.929 .823 .72 r
.78153 .12678 m .78419 .131 L .7879 .12414 L p F P
0 g
s
.929 .823 .72 r
.7879 .12414 m .78526 .11991 L .78153 .12678 L p F P
0 g
s
.818 .826 .855 r
.71767 .23046 m .71091 .23625 L .70788 .23268 L p F P
0 g
s
.892 .835 .783 r
.77054 .16798 m .77029 .16832 L .76905 .16615 L closepath p F P
0 g
s
.878 .833 .799 r
.76175 .17178 m .7642 .176 L .77029 .16832 L p F P
0 g
s
.878 .833 .799 r
.76762 .16438 m .76175 .17178 L p .77029 .16832 L F P
0 g
s
.878 .833 .799 r
.77029 .16832 m .76905 .16615 L .76762 .16438 L p F P
0 g
s
.349 .61 .947 r
.60243 .26245 m .60034 .26213 L .6035 .26605 L p F P
0 g
s
.349 .61 .947 r
.6035 .26605 m .60567 .26637 L .60243 .26245 L p F P
0 g
s
.842 .831 .836 r
.73317 .20998 m .73468 .2085 L .73702 .2127 L p F P
0 g
s
.842 .831 .836 r
.73702 .2127 m .73615 .21355 L .73317 .20998 L p F P
0 g
s
.822 .827 .853 r
.71767 .23046 m .72356 .22531 L .72055 .22173 L p F P
0 g
s
.822 .827 .853 r
.72055 .22173 m .71536 .22627 L .71767 .23046 L p F P
0 g
s
.818 .826 .855 r
.70788 .23268 m .71536 .22627 L .71767 .23046 L p F P
0 g
s
.835 .83 .842 r
.72776 .22144 m .73615 .21355 L .73317 .20998 L p F P
0 g
s
.77 .808 .883 r
.67657 .25613 m .6697 .2607 L .66658 .25701 L p F P
0 g
s
.835 .83 .842 r
.73317 .20998 m .72543 .21725 L .72776 .22144 L p F P
0 g
s
.831 .828 .845 r
.72055 .22173 m .72543 .21725 L .72776 .22144 L p F P
0 g
s
.831 .828 .845 r
.72776 .22144 m .72356 .22531 L .72055 .22173 L p F P
0 g
s
.91 .83 .754 r
.77823 .14933 m .77982 .14687 L .77691 .1432 L p F P
0 g
s
.956 .799 .646 r
.78546 .09835 m .78833 .10255 L .79066 .09619 L p F P
0 g
s
.956 .799 .646 r
.79066 .09619 m .78779 .09198 L .78546 .09835 L p F P
0 g
s
.772 .809 .883 r
.67657 .25613 m .68245 .25216 L .67936 .24849 L p F P
0 g
s
.772 .809 .883 r
.67936 .24849 m .67414 .25199 L .67657 .25613 L p F P
0 g
s
.77 .808 .883 r
.66658 .25701 m .67414 .25199 L .67657 .25613 L p F P
0 g
s
.901 .83 .767 r
.77062 .15244 m .77318 .15666 L .77823 .14933 L p F P
0 g
s
.901 .83 .767 r
.77823 .14933 m .77569 .1451 L .77062 .15244 L p F P
0 g
s
.91 .83 .754 r
.77691 .1432 m .77569 .1451 L .77823 .14933 L p F P
0 g
s
.878 .833 .798 r
.75539 .17956 m .76175 .17178 L .7642 .176 L p F P
0 g
s
.878 .833 .798 r
.75616 .18087 m .75539 .17956 L p .7642 .176 L F P
0 g
s
.878 .833 .798 r
.7642 .176 m .75819 .18336 L .75616 .18087 L p F P
0 g
s
.564 .722 .948 r
.60567 .26637 m .61857 .26434 L .62179 .26824 L p F P
0 g
s
.562 .722 .948 r
.61857 .26434 m .60567 .26637 L .60243 .26245 L p F P
0 g
s
.941 .813 .691 r
.78303 .11461 m .78562 .10905 L .78839 .11326 L p F P
0 g
s
.941 .813 .691 r
.78839 .11326 m .78594 .11851 L .78303 .11461 L p F P
0 g
s
.921 .823 .733 r
.77748 .13376 m .78015 .13797 L .78419 .131 L p F P
0 g
s
.921 .823 .733 r
.78419 .131 m .78153 .12678 L .77748 .13376 L p F P
0 g
s
.788 .814 .873 r
.69156 .2455 m .68245 .25216 L .67936 .24849 L p F P
0 g
s
.749 .798 .892 r
.65495 .264 m .6538 .26468 L .65065 .2609 L p F P
0 g
s
.717 .789 .908 r
.63783 .26728 m .65065 .2609 L .6538 .26468 L p F P
0 g
s
.888 .833 .787 r
.76905 .16615 m .76762 .16438 L .76785 .16409 L closepath p F P
0 g
s
.75 .798 .892 r
.65495 .264 m .66658 .25701 L .66346 .25325 L p F P
0 g
s
.75 .798 .892 r
.66346 .25325 m .65227 .25994 L .65495 .264 L p F P
0 g
s
.749 .798 .892 r
.65065 .2609 m .65227 .25994 L .65495 .264 L p F P
0 g
s
.872 .833 .806 r
.75819 .18336 m .75783 .18378 L .75616 .18087 L closepath p F P
0 g
s
.859 .831 .819 r
.74818 .18764 m .75064 .19184 L .75783 .18378 L p F P
0 g
s
.859 .831 .819 r
.75525 .17974 m .74818 .18764 L p .75783 .18378 L F P
0 g
s
.859 .831 .819 r
.75783 .18378 m .75616 .18087 L .75525 .17974 L p F P
0 g
s
.895 .829 .774 r
.76527 .15988 m .76785 .16409 L .77318 .15666 L p F P
0 g
s
.895 .829 .774 r
.77318 .15666 m .77062 .15244 L .76527 .15988 L p F P
0 g
s
.79 .816 .872 r
.69156 .2455 m .69518 .24282 L .69211 .23916 L p F P
0 g
s
.79 .816 .872 r
.69211 .23916 m .68914 .24135 L .69156 .2455 L p F P
0 g
s
.788 .814 .873 r
.67936 .24849 m .68914 .24135 L .69156 .2455 L p F P
0 g
s
.716 .786 .907 r
.65065 .2609 m .63783 .26728 L .63464 .26344 L p F P
0 g
s
.67 .769 .924 r
.62179 .26824 m .63464 .26344 L .63783 .26728 L p F P
0 g
s
.668 .767 .924 r
.63464 .26344 m .62179 .26824 L .61857 .26434 L p F P
0 g
s
.859 .83 .818 r
.74275 .19357 m .74818 .18764 L .75064 .19184 L p F P
0 g
s
.859 .83 .818 r
.75064 .19184 m .74572 .1972 L .74275 .19357 L p F P
0 g
s
.803 .818 .863 r
.70421 .23564 m .69518 .24282 L .69211 .23916 L p F P
0 g
s
.937 .815 .699 r
.78526 .11991 m .78594 .11851 L .78303 .11461 L p F P
0 g
s
.947 .804 .67 r
.78274 .10486 m .78562 .10905 L .78833 .10255 L p F P
0 g
s
.947 .804 .67 r
.78833 .10255 m .78546 .09835 L .78274 .10486 L p F P
0 g
s
.913 .824 .746 r
.77399 .1394 m .77748 .13376 L .78015 .13797 L p F P
0 g
s
.913 .824 .746 r
.78015 .13797 m .77691 .1432 L .77399 .1394 L p F P
0 g
s
.852 .83 .825 r
.74299 .20006 m .74572 .1972 L .74275 .19357 L p F P
0 g
s
.852 .83 .825 r
.74275 .19357 m .74056 .19586 L .74299 .20006 L p F P
0 g
s
.847 .829 .83 r
.7322 .20432 m .73468 .2085 L .74299 .20006 L p F P
0 g
s
.847 .829 .83 r
.74299 .20006 m .74056 .19586 L .7322 .20432 L p F P
0 g
s
.937 .815 .699 r
.78303 .11461 m .7825 .11571 L .78526 .11991 L p F P
0 g
s
.925 .817 .72 r
.77876 .12258 m .78153 .12678 L .78526 .11991 L p F P
0 g
s
.925 .817 .72 r
.78526 .11991 m .7825 .11571 L .77876 .12258 L p F P
0 g
s
.806 .82 .862 r
.70421 .23564 m .70788 .23268 L .70483 .22902 L p F P
0 g
s
.806 .82 .862 r
.70483 .22902 m .70179 .23148 L .70421 .23564 L p F P
0 g
s
.803 .818 .863 r
.69211 .23916 m .70179 .23148 L .70421 .23564 L p F P
0 g
s
.817 .822 .853 r
.71536 .22627 m .70788 .23268 L .70483 .22902 L p F P
0 g
s
.885 .828 .785 r
.76469 .16065 m .76527 .15988 L .76785 .16409 L p F P
0 g
s
.885 .828 .785 r
.76785 .16409 m .76762 .16438 L .76469 .16065 L p F P
0 g
s
.88 .829 .792 r
.76175 .17178 m .76762 .16438 L .76469 .16065 L p F P
0 g
s
.769 .805 .882 r
.67414 .25199 m .66658 .25701 L .66346 .25325 L p F P
0 g
s
.841 .827 .834 r
.73016 .20631 m .7322 .20432 L .73468 .2085 L p F P
0 g
s
.841 .827 .834 r
.73468 .2085 m .73317 .20998 L .73016 .20631 L p F P
0 g
s
.821 .823 .851 r
.71536 .22627 m .72055 .22173 L .71752 .21807 L p F P
0 g
s
.821 .823 .851 r
.71752 .21807 m .71291 .2221 L .71536 .22627 L p F P
0 g
s
.817 .822 .853 r
.70483 .22902 m .71291 .2221 L .71536 .22627 L p F P
0 g
s
.833 .826 .841 r
.72543 .21725 m .73317 .20998 L .73016 .20631 L p F P
0 g
s
.833 .826 .841 r
.73016 .20631 m .72296 .21308 L .72543 .21725 L p F P
0 g
s
.829 .825 .844 r
.71752 .21807 m .72296 .21308 L .72543 .21725 L p F P
0 g
s
.829 .825 .844 r
.72543 .21725 m .72055 .22173 L .71752 .21807 L p F P
0 g
s
.908 .825 .753 r
.77569 .1451 m .77691 .1432 L .77399 .1394 L p F P
0 g
s
.869 .831 .807 r
.75616 .18087 m .75525 .17974 L .75539 .17956 L closepath p F P
0 g
s
.898 .825 .766 r
.76794 .14825 m .77062 .15244 L .77569 .1451 L p F P
0 g
s
.898 .825 .766 r
.77569 .1451 m .77302 .1409 L .76794 .14825 L p F P
0 g
s
.908 .825 .753 r
.77399 .1394 m .77302 .1409 L .77569 .1451 L p F P
0 g
s
.769 .805 .882 r
.66346 .25325 m .67156 .24789 L .67414 .25199 L p F P
0 g
s
.771 .806 .881 r
.67414 .25199 m .67936 .24849 L .67625 .24475 L p F P
0 g
s
.771 .806 .881 r
.67625 .24475 m .67156 .24789 L .67414 .25199 L p F P
0 g
s
.562 .722 .948 r
.60243 .26245 m .61535 .26043 L .61857 .26434 L p F P
0 g
s
.88 .829 .792 r
.76469 .16065 m .75918 .16758 L .76175 .17178 L p F P
0 g
s
.876 .828 .797 r
.7528 .17538 m .75539 .17956 L .76175 .17178 L p F P
0 g
s
.876 .828 .797 r
.76175 .17178 m .75918 .16758 L .7528 .17538 L p F P
0 g
s
.937 .807 .69 r
.7801 .11053 m .78274 .10486 L .78562 .10905 L p F P
0 g
s
.937 .807 .69 r
.78562 .10905 m .78303 .11461 L .7801 .11053 L p F P
0 g
s
.918 .818 .732 r
.77469 .12958 m .77748 .13376 L .78153 .12678 L p F P
0 g
s
.918 .818 .732 r
.78153 .12678 m .77876 .12258 L .77469 .12958 L p F P
0 g
s
.748 .795 .891 r
.65227 .25994 m .65065 .2609 L .64749 .25707 L p F P
0 g
s
.716 .786 .907 r
.63464 .26344 m .64749 .25707 L .65065 .2609 L p F P
0 g
s
.786 .81 .872 r
.68914 .24135 m .67936 .24849 L .67625 .24475 L p F P
0 g
s
.749 .796 .891 r
.65227 .25994 m .66346 .25325 L .66031 .24944 L p F P
0 g
s
.749 .796 .891 r
.66031 .24944 m .64944 .25592 L .65227 .25994 L p F P
0 g
s
.748 .795 .891 r
.64749 .25707 m .64944 .25592 L .65227 .25994 L p F P
0 g
s
.867 .827 .806 r
.75228 .17599 m .7528 .17538 L .75539 .17956 L p F P
0 g
s
.867 .827 .806 r
.75539 .17956 m .75525 .17974 L .75228 .17599 L p F P
0 g
s
.862 .827 .812 r
.74818 .18764 m .75525 .17974 L .75228 .17599 L p F P
0 g
s
.893 .824 .773 r
.76257 .1557 m .76527 .15988 L .77062 .15244 L p F P
0 g
s
.893 .824 .773 r
.77062 .15244 m .76794 .14825 L .76257 .1557 L p F P
0 g
s
.715 .784 .906 r
.64749 .25707 m .63464 .26344 L .63145 .25956 L p F P
0 g
s
.668 .767 .924 r
.61857 .26434 m .63145 .25956 L .63464 .26344 L p F P
0 g
s
.668 .766 .923 r
.63145 .25956 m .61857 .26434 L .61535 .26043 L p F P
0 g
s
.789 .812 .871 r
.68914 .24135 m .69211 .23916 L .68902 .23542 L p F P
0 g
s
.789 .812 .871 r
.68902 .23542 m .68657 .23723 L .68914 .24135 L p F P
0 g
s
.786 .81 .872 r
.67625 .24475 m .68657 .23723 L .68914 .24135 L p F P
0 g
s
.862 .827 .812 r
.75228 .17599 m .7456 .18346 L .74818 .18764 L p F P
0 g
s
.857 .826 .816 r
.73976 .18984 m .7456 .18346 L .74818 .18764 L p F P
0 g
s
.857 .826 .816 r
.74818 .18764 m .74275 .19357 L .73976 .18984 L p F P
0 g
s
.802 .815 .862 r
.70179 .23148 m .69211 .23916 L .68902 .23542 L p F P
0 g
s
.933 .809 .699 r
.7825 .11571 m .78303 .11461 L .7801 .11053 L p F P
0 g
s
.91 .819 .744 r
.77105 .13546 m .77469 .12958 L .77748 .13376 L p F P
0 g
s
.91 .819 .744 r
.77748 .13376 m .77399 .1394 L .77105 .13546 L p F P
0 g
s
.85 .825 .823 r
.74056 .19586 m .74275 .19357 L .73976 .18984 L p F P
0 g
s
.933 .809 .699 r
.7801 .11053 m .77961 .11152 L .7825 .11571 L p F P
0 g
s
.922 .812 .719 r
.77586 .11841 m .77876 .12258 L .7825 .11571 L p F P
0 g
s
.922 .812 .719 r
.7825 .11571 m .77961 .11152 L .77586 .11841 L p F P
0 g
s
.85 .825 .823 r
.73976 .18984 m .73799 .19168 L .74056 .19586 L p F P
0 g
s
.845 .824 .828 r
.72959 .20017 m .7322 .20432 L .74056 .19586 L p F P
0 g
s
.845 .824 .828 r
.74056 .19586 m .73799 .19168 L .72959 .20017 L p F P
0 g
s
.805 .816 .86 r
.70179 .23148 m .70483 .22902 L .70177 .22528 L p F P
0 g
s
.805 .816 .86 r
.70177 .22528 m .69921 .22735 L .70179 .23148 L p F P
0 g
s
.802 .815 .862 r
.68902 .23542 m .69921 .22735 L .70179 .23148 L p F P
0 g
s
.815 .818 .852 r
.71291 .2221 m .70483 .22902 L .70177 .22528 L p F P
0 g
s
.883 .824 .784 r
.76173 .1568 m .76257 .1557 L .76527 .15988 L p F P
0 g
s
.883 .824 .784 r
.76527 .15988 m .76469 .16065 L .76173 .1568 L p F P
0 g
s
.768 .802 .881 r
.67156 .24789 m .66346 .25325 L .66031 .24944 L p F P
0 g
s
.878 .824 .79 r
.75918 .16758 m .76469 .16065 L .76173 .1568 L p F P
0 g
s
.839 .823 .832 r
.72715 .20257 m .72959 .20017 L .7322 .20432 L p F P
0 g
s
.839 .823 .832 r
.7322 .20432 m .73016 .20631 L .72715 .20257 L p F P
0 g
s
.819 .819 .849 r
.71291 .2221 m .71752 .21807 L .71448 .21433 L p F P
0 g
s
.819 .819 .849 r
.71448 .21433 m .71032 .21796 L .71291 .2221 L p F P
0 g
s
.815 .818 .852 r
.70177 .22528 m .71032 .21796 L .71291 .2221 L p F P
0 g
s
.832 .822 .839 r
.72296 .21308 m .73016 .20631 L .72715 .20257 L p F P
0 g
s
.832 .822 .839 r
.72715 .20257 m .72037 .20893 L .72296 .21308 L p F P
0 g
s
.828 .821 .842 r
.71448 .21433 m .72037 .20893 L .72296 .21308 L p F P
0 g
s
.828 .821 .842 r
.72296 .21308 m .71752 .21807 L .71448 .21433 L p F P
0 g
s
.905 .82 .752 r
.77302 .1409 m .77399 .1394 L .77105 .13546 L p F P
0 g
s
.905 .82 .752 r
.77105 .13546 m .77024 .13672 L .77302 .1409 L p F P
0 g
s
.896 .82 .765 r
.76514 .14408 m .76794 .14825 L .77302 .1409 L p F P
0 g
s
.896 .82 .765 r
.77302 .1409 m .77024 .13672 L .76514 .14408 L p F P
0 g
s
.878 .824 .79 r
.76173 .1568 m .75649 .16341 L .75918 .16758 L p F P
0 g
s
.874 .823 .796 r
.75009 .17122 m .7528 .17538 L .75918 .16758 L p F P
0 g
s
.874 .823 .796 r
.75918 .16758 m .75649 .16341 L .75009 .17122 L p F P
0 g
s
.77 .803 .88 r
.67156 .24789 m .67625 .24475 L .67313 .24094 L p F P
0 g
s
.77 .803 .88 r
.67313 .24094 m .66881 .24383 L .67156 .24789 L p F P
0 g
s
.768 .802 .881 r
.66031 .24944 m .66881 .24383 L .67156 .24789 L p F P
0 g
s
.915 .813 .732 r
.77179 .12541 m .77469 .12958 L .77876 .12258 L p F P
0 g
s
.915 .813 .732 r
.77876 .12258 m .77586 .11841 L .77179 .12541 L p F P
0 g
s
.746 .793 .89 r
.64944 .25592 m .64749 .25707 L .64431 .2532 L p F P
0 g
s
.715 .784 .906 r
.63145 .25956 m .64431 .2532 L .64749 .25707 L p F P
0 g
s
.785 .807 .87 r
.68657 .23723 m .67625 .24475 L .67313 .24094 L p F P
0 g
s
.748 .794 .89 r
.64944 .25592 m .66031 .24944 L .65716 .24557 L p F P
0 g
s
.748 .794 .89 r
.65716 .24557 m .64647 .25193 L .64944 .25592 L p F P
0 g
s
.746 .793 .89 r
.64431 .2532 m .64647 .25193 L .64944 .25592 L p F P
0 g
s
.865 .822 .804 r
.7493 .17214 m .75009 .17122 L .7528 .17538 L p F P
0 g
s
.865 .822 .804 r
.7528 .17538 m .75228 .17599 L .7493 .17214 L p F P
0 g
s
.86 .822 .81 r
.7456 .18346 m .75228 .17599 L .7493 .17214 L p F P
0 g
s
.89 .82 .772 r
.75976 .15155 m .76257 .1557 L .76794 .14825 L p F P
0 g
s
.89 .82 .772 r
.76794 .14825 m .76514 .14408 L .75976 .15155 L p F P
0 g
s
.668 .766 .923 r
.61535 .26043 m .62825 .25565 L .63145 .25956 L p F P
0 g
s
.715 .782 .905 r
.64431 .2532 m .63145 .25956 L .62825 .25565 L p F P
0 g
s
.788 .808 .869 r
.68657 .23723 m .68902 .23542 L .68592 .23161 L p F P
0 g
s
.788 .808 .869 r
.68592 .23161 m .68385 .23315 L .68657 .23723 L p F P
0 g
s
.785 .807 .87 r
.67313 .24094 m .68385 .23315 L .68657 .23723 L p F P
0 g
s
.86 .822 .81 r
.7493 .17214 m .74289 .17931 L .7456 .18346 L p F P
0 g
s
.856 .822 .814 r
.73675 .18601 m .74289 .17931 L .7456 .18346 L p F P
0 g
s
.856 .822 .814 r
.7456 .18346 m .73976 .18984 L .73675 .18601 L p F P
0 g
s
.8 .811 .86 r
.69921 .22735 m .68902 .23542 L .68592 .23161 L p F P
0 g
s
.907 .814 .743 r
.76808 .13139 m .77179 .12541 L .77469 .12958 L p F P
0 g
s
.907 .814 .743 r
.77469 .12958 m .77105 .13546 L .76808 .13139 L p F P
0 g
s
.849 .821 .821 r
.73799 .19168 m .73976 .18984 L .73675 .18601 L p F P
0 g
s
.849 .821 .821 r
.73675 .18601 m .73528 .18754 L .73799 .19168 L p F P
0 g
s
.843 .82 .827 r
.72686 .19604 m .72959 .20017 L .73799 .19168 L p F P
0 g
s
.843 .82 .827 r
.73799 .19168 m .73528 .18754 L .72686 .19604 L p F P
0 g
s
.804 .812 .858 r
.69921 .22735 m .70177 .22528 L .69869 .22147 L p F P
0 g
s
.804 .812 .858 r
.69869 .22147 m .69648 .22325 L .69921 .22735 L p F P
0 g
s
.8 .811 .86 r
.68592 .23161 m .69648 .22325 L .69921 .22735 L p F P
0 g
s
.814 .814 .85 r
.71032 .21796 m .70177 .22528 L .69869 .22147 L p F P
0 g
s
.881 .819 .783 r
.75876 .15285 m .75976 .15155 L .76257 .1557 L p F P
0 g
s
.881 .819 .783 r
.76257 .1557 m .76173 .1568 L .75876 .15285 L p F P
0 g
s
.767 .799 .879 r
.66881 .24383 m .66031 .24944 L .65716 .24557 L p F P
0 g
s
.876 .819 .789 r
.75649 .16341 m .76173 .1568 L .75876 .15285 L p F P
0 g
s
.838 .819 .831 r
.72412 .19873 m .72686 .19604 L .72959 .20017 L p F P
0 g
s
.838 .819 .831 r
.72959 .20017 m .72715 .20257 L .72412 .19873 L p F P
0 g
s
.818 .815 .848 r
.71032 .21796 m .71448 .21433 L .71143 .21051 L p F P
0 g
s
.818 .815 .848 r
.71143 .21051 m .70759 .21386 L .71032 .21796 L p F P
0 g
s
.814 .814 .85 r
.69869 .22147 m .70759 .21386 L .71032 .21796 L p F P
0 g
s
.83 .818 .837 r
.72037 .20893 m .72715 .20257 L .72412 .19873 L p F P
0 g
s
.83 .818 .837 r
.72412 .19873 m .71763 .20481 L .72037 .20893 L p F P
0 g
s
.826 .817 .84 r
.71143 .21051 m .71763 .20481 L .72037 .20893 L p F P
0 g
s
.826 .817 .84 r
.72037 .20893 m .71448 .21433 L .71143 .21051 L p F P
0 g
s
.902 .814 .751 r
.77024 .13672 m .77105 .13546 L .76808 .13139 L p F P
0 g
s
.902 .814 .751 r
.76808 .13139 m .76733 .13256 L .77024 .13672 L p F P
0 g
s
.893 .815 .764 r
.76221 .13993 m .76514 .14408 L .77024 .13672 L p F P
0 g
s
.893 .815 .764 r
.77024 .13672 m .76733 .13256 L .76221 .13993 L p F P
0 g
s
.876 .819 .789 r
.75876 .15285 m .75367 .15926 L .75649 .16341 L p F P
0 g
s
.871 .819 .794 r
.74725 .16709 m .75009 .17122 L .75649 .16341 L p F P
0 g
s
.871 .819 .794 r
.75649 .16341 m .75367 .15926 L .74725 .16709 L p F P
0 g
s
.769 .8 .879 r
.66881 .24383 m .67313 .24094 L .66999 .23707 L p F P
0 g
s
.769 .8 .879 r
.66999 .23707 m .6659 .2398 L .66881 .24383 L p F P
0 g
s
.767 .799 .879 r
.65716 .24557 m .6659 .2398 L .66881 .24383 L p F P
0 g
s
.746 .791 .889 r
.64647 .25193 m .64431 .2532 L .64113 .24928 L p F P
0 g
s
.715 .782 .905 r
.62825 .25565 m .64113 .24928 L .64431 .2532 L p F P
0 g
s
.784 .804 .869 r
.68385 .23315 m .67313 .24094 L .66999 .23707 L p F P
0 g
s
.747 .791 .889 r
.64647 .25193 m .65716 .24557 L .65399 .24163 L p F P
0 g
s
.747 .791 .889 r
.65399 .24163 m .64336 .24796 L .64647 .25193 L p F P
0 g
s
.746 .791 .889 r
.64113 .24928 m .64336 .24796 L .64647 .25193 L p F P
0 g
s
.863 .818 .803 r
.7463 .16819 m .74725 .16709 L .75009 .17122 L p F P
0 g
s
.863 .818 .803 r
.75009 .17122 m .7493 .17214 L .7463 .16819 L p F P
0 g
s
.858 .818 .809 r
.74289 .17931 m .7493 .17214 L .7463 .16819 L p F P
0 g
s
.888 .815 .771 r
.75682 .14741 m .75976 .15155 L .76514 .14408 L p F P
0 g
s
.888 .815 .771 r
.76514 .14408 m .76221 .13993 L .75682 .14741 L p F P
0 g
s
.786 .805 .867 r
.68385 .23315 m .68592 .23161 L .68281 .22773 L p F P
0 g
s
.786 .805 .867 r
.68281 .22773 m .68096 .2291 L .68385 .23315 L p F P
0 g
s
.784 .804 .869 r
.66999 .23707 m .68096 .2291 L .68385 .23315 L p F P
0 g
s
.858 .818 .809 r
.7463 .16819 m .74005 .17518 L .74289 .17931 L p F P
0 g
s
.854 .817 .813 r
.73373 .18208 m .74005 .17518 L .74289 .17931 L p F P
0 g
s
.854 .817 .813 r
.74289 .17931 m .73675 .18601 L .73373 .18208 L p F P
0 g
s
.799 .808 .858 r
.69648 .22325 m .68592 .23161 L .68281 .22773 L p F P
0 g
s
.847 .817 .82 r
.73528 .18754 m .73675 .18601 L .73373 .18208 L p F P
0 g
s
.847 .817 .82 r
.73373 .18208 m .73244 .18342 L .73528 .18754 L p F P
0 g
s
.841 .816 .825 r
.72399 .19194 m .72686 .19604 L .73528 .18754 L p F P
0 g
s
.841 .816 .825 r
.73528 .18754 m .73244 .18342 L .72399 .19194 L p F P
0 g
s
.802 .809 .857 r
.69648 .22325 m .69869 .22147 L .6956 .21757 L p F P
0 g
s
.802 .809 .857 r
.6956 .21757 m .6936 .21919 L .69648 .22325 L p F P
0 g
s
.799 .808 .858 r
.68281 .22773 m .6936 .21919 L .69648 .22325 L p F P
0 g
s
.766 .796 .878 r
.6659 .2398 m .65716 .24557 L .65399 .24163 L p F P
0 g
s
.879 .815 .781 r
.75577 .14878 m .75682 .14741 L .75976 .15155 L p F P
0 g
s
.879 .815 .781 r
.75976 .15155 m .75876 .15285 L .75577 .14878 L p F P
0 g
s
.813 .811 .848 r
.70759 .21386 m .69869 .22147 L .6956 .21757 L p F P
0 g
s
.874 .814 .787 r
.75367 .15926 m .75876 .15285 L .75577 .14878 L p F P
0 g
s
.836 .815 .829 r
.72107 .1948 m .72399 .19194 L .72686 .19604 L p F P
0 g
s
.836 .815 .829 r
.72686 .19604 m .72412 .19873 L .72107 .1948 L p F P
0 g
s
.816 .811 .846 r
.70759 .21386 m .71143 .21051 L .70836 .2066 L p F P
0 g
s
.816 .811 .846 r
.70836 .2066 m .70471 .20978 L .70759 .21386 L p F P
0 g
s
.813 .811 .848 r
.6956 .21757 m .70471 .20978 L .70759 .21386 L p F P
0 g
s
.829 .814 .836 r
.71763 .20481 m .72412 .19873 L .72107 .1948 L p F P
0 g
s
.829 .814 .836 r
.72107 .1948 m .71476 .20072 L .71763 .20481 L p F P
0 g
s
.825 .813 .839 r
.70836 .2066 m .71476 .20072 L .71763 .20481 L p F P
0 g
s
.825 .813 .839 r
.71763 .20481 m .71143 .21051 L .70836 .2066 L p F P
0 g
s
.874 .814 .787 r
.75577 .14878 m .75072 .15513 L .75367 .15926 L p F P
0 g
s
.869 .814 .793 r
.7443 .16297 m .74725 .16709 L .75367 .15926 L p F P
0 g
s
.869 .814 .793 r
.75367 .15926 m .75072 .15513 L .7443 .16297 L p F P
0 g
s
.768 .797 .877 r
.6659 .2398 m .66999 .23707 L .66685 .23312 L p F P
0 g
s
.768 .797 .877 r
.66685 .23312 m .66283 .2358 L .6659 .2398 L p F P
0 g
s
.766 .796 .878 r
.65399 .24163 m .66283 .2358 L .6659 .2398 L p F P
0 g
s
.783 .801 .867 r
.68096 .2291 m .66999 .23707 L .66685 .23312 L p F P
0 g
s
.862 .814 .801 r
.74329 .16414 m .7443 .16297 L .74725 .16709 L p F P
0 g
s
.862 .814 .801 r
.74725 .16709 m .7463 .16819 L .74329 .16414 L p F P
0 g
s
.856 .813 .807 r
.74005 .17518 m .7463 .16819 L .74329 .16414 L p F P
0 g
s
.785 .802 .866 r
.68096 .2291 m .68281 .22773 L .67968 .22377 L p F P
0 g
s
.785 .802 .866 r
.67968 .22377 m .6779 .22508 L .68096 .2291 L p F P
0 g
s
.783 .801 .867 r
.66685 .23312 m .6779 .22508 L .68096 .2291 L p F P
0 g
s
.856 .813 .807 r
.74329 .16414 m .73708 .17108 L .74005 .17518 L p F P
0 g
s
.852 .813 .811 r
.73069 .17805 m .73708 .17108 L .74005 .17518 L p F P
0 g
s
.852 .813 .811 r
.74005 .17518 m .73373 .18208 L .73069 .17805 L p F P
0 g
s
.798 .804 .857 r
.6936 .21919 m .68281 .22773 L .67968 .22377 L p F P
0 g
s
.845 .812 .818 r
.73244 .18342 m .73373 .18208 L .73069 .17805 L p F P
0 g
s
.845 .812 .818 r
.73069 .17805 m .72946 .17933 L .73244 .18342 L p F P
0 g
s
.839 .811 .823 r
.72099 .18787 m .72399 .19194 L .73244 .18342 L p F P
0 g
s
.839 .811 .823 r
.73244 .18342 m .72946 .17933 L .72099 .18787 L p F P
0 g
s
.801 .805 .855 r
.6936 .21919 m .6956 .21757 L .69249 .2136 L p F P
0 g
s
.801 .805 .855 r
.69249 .2136 m .69056 .21516 L .6936 .21919 L p F P
0 g
s
.798 .804 .857 r
.67968 .22377 m .69056 .21516 L .6936 .21919 L p F P
0 g
s
.811 .807 .847 r
.70471 .20978 m .6956 .21757 L .69249 .2136 L p F P
0 g
s
.834 .811 .827 r
.71801 .19079 m .72099 .18787 L .72399 .19194 L p F P
0 g
s
.834 .811 .827 r
.72399 .19194 m .72107 .1948 L .71801 .19079 L p F P
0 g
s
.815 .808 .844 r
.70471 .20978 m .70836 .2066 L .70527 .20261 L p F P
0 g
s
.815 .808 .844 r
.70527 .20261 m .70169 .20573 L .70471 .20978 L p F P
0 g
s
.811 .807 .847 r
.69249 .2136 m .70169 .20573 L .70471 .20978 L p F P
0 g
s
.827 .81 .834 r
.71476 .20072 m .72107 .1948 L .71801 .19079 L p F P
0 g
s
.827 .81 .834 r
.71801 .19079 m .71175 .19666 L .71476 .20072 L p F P
0 g
s
.823 .809 .837 r
.70527 .20261 m .71175 .19666 L .71476 .20072 L p F P
0 g
s
.823 .809 .837 r
.71476 .20072 m .70836 .2066 L .70527 .20261 L p F P
0 g
s
.25 Mabswid
.80488 0 m
.97794 .26024 L
s
.97794 .26024 m
1 .44134 L
s
1 .44134 m
.82069 .18956 L
s
.82069 .18956 m
.80488 0 L
s
.02168 .27949 m
0 .45986 L
s
0 .45986 m
.82069 .18956 L
s
.82069 .18956 m
.80488 0 L
s
.80488 0 m
.02168 .27949 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 379.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Nb000`400?l00000o`00003ooooonf[>
oookJP;o0000LOoonfX00?oooo]ZbooonfX3o`000003oookJ_l0003ooo]Z073ooo]Z003ooookJ/So
oo]Z0ol00004oookJP;o0000L?oonfX00?oooo]ZaOoonfX3o`0000Oooo]Z00?o0000oookJ_l00000
KooonfX00?oooo]Z`_oonfX3o`0000[ooo]Z00?o0000oookJ_l00000KooonfX00?oooo]Z`?oonfX2
o`0000gooo]Z00Co0000oookJ_oonf[o0000K_oonfX00?oooo]Z_OoonfX3o`0000oooo]Z00Go0000
oookJ_oonf[ooo]Zo`00001]oookJP00oooonfZjoookJP?o00004ooonfX01?l0003ooo]ZoookJ_l0
001]oookJP00oooonfZgoookJP?o00005_oonfX01Ol0003ooo]ZoookJ_oonf[o000006cooo]Z003o
oookJ[Cooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0JOoonfX0
0?oooo]Z/OoonfX3o`0001cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP1Yoook
JP00oooonfZ_oookJP;o00007ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z06So
oo]Z003ooookJZcooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0
IooonfX00?oooo]ZZOoonfX3o`0002Cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Zoook
JP1WoookJP00oooonfZVoookJP?o00009ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[o
oo]Z06Kooo]Z003ooookJZ?ooo]Z0ol0000ZoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX0IOoonfX00?oooo]ZXOoonfX2o`0002gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP1UoookJP00oooonfZNoookJP?o0000;ooonfX00ol0003ooo]ZoookJP07oookJP03o`00
0?oonf[ooo]Z06Cooo]Z003ooookJY_ooo]Z0ol0000boookJP03o`000?oonf[ooo]Z00Sooo]Z00?o
0000oookJ_oonfX0HooonfX00?oooo]ZV?oonfX3o`00017ooo]Z4Ol0000DoookJP03o`000?oonf[o
oo]Z00Oooo]Z00?o0000oookJ_oonfX0HooonfX00?oooo]ZUOoonfX3o`00017ooo]Z0ol00002oj6k
j`05o`000?n</NooS;7_ohbakol000001?n6[^l01?l0003oI9__ofBKkol00002odf=k0?o00004Ooo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z06;ooo]Z003ooookJY?ooo]Z0_l0000A
oookJP?o00001_nQ^n/00ol0003oS;7_ohbak`08o`000007ofBKkol0003oCHg/odf=k?l0003o057>
o`00000@oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0HOoonfX00?oooo]ZT?oo
nfX3o`00017ooo]Z0_l000000on``NKo0000oj6kj`07oj6kj`;o000000?oS;7^o`000?n5[Nl00on5
[Nl00ol0003oI9[^ofBJkP03o`000004odf=k?l0003o057>o`0000oooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP1QoookJP00oooonfZ=oookJP?o00004ooonfX00ol0003o/<7Vok31
iP02ok31iP03o`000?nQ^n_oXK_[00?o00000onQ^^/01?l0003oS;7^ohbak_l00004ohF]k`05o`00
0?mTV^koI9[^o`000?m>S>/00ol000000ol0DLko0000oookJP0=oookJP03o`000?oonf[ooo]Z00[o
oo]Z00?o0000oookJ_oonfX0H?oonfX00?oooo]ZR_oonfX3o`0001Cooo]Z0_l00006ok31iP;o0000
1onQ^^/Bo`0000gooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP1OoookJP00oooo
nfZ7oookJP?o00005OoonfX2o`0000Co/<7V0ol000001?n``NKo0000oj6jjonQ^^/4o`0000;oXK[[
00Co0000ohb`k_n</>ko00001?n5[>h01?l0003oII[^ofFJk_l00002odj;jPGo00003?oonfX00ol0
003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z05oooo]Z003ooookJXCooo]Z0ol0000EoookJP?o
00000_nlaN801?l0003o/<7Vo`000?l00005ok31iP;o00001onQ^^/00ol0003oS;3^o`00000:o`00
0004odj;j_lPKMko0000o`1Bc`;o00002ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[o
oo]Z05kooo]Z003ooookJX;ooo]Z0_l0000GoookJP03o`000?nkaN;o000000?o_<GR0_l00003ok31
iP?o000000?o/<7Wo`000?nQ^^/01onQ^^/2o`000003ohb`k_l0003oQJ_^00CoQJ_^00Co0000ofFI
kOl0003oCX[Y0_l000000olPKMko0000o`1Bc`02o`0000[ooo]Z00?o0000oookJ_oonfX03OoonfX0
0ol0003ooo]ZoookJP1MoookJP00oooonfYooookJP?o00006?oonfX02_l0003o^lGRok_5h_nkaN;o
0000okc5h_l0003o_<KRo`000?n``NH2o`0000Go/<7W00?o0000oj6jjonQ^^/00ol00003oj2jj`04
o`000?n</>koS;3^o`0000;oQJ_^1_l00003odj:j@Co00002_oonfX00ol0003ooo]ZoookJP0=oook
JP03o`000?oonf[ooo]Z05gooo]Z003ooookJWcooo]Z0ol0000IoookJP;o00001OnkaN800ol0003o
_<KRokc6hP02o`0000So/<7W0_l00007oj2jj`Go00000on4Z^d00ol0003oI9S]ofBHk@08o`0000Wo
oo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP1LoookJP00oooonfYioookJP?o0000
6_oonfX2o`000003olC8gOl0003o^lGR00?o000000Ko^lKRo`000?nla^;o0000okc6h_l00004ok31
i`?o00000_n``NL00ol0003oX;[[oj2jj`03o`0000?oX;W[00?o0000oh^_k_l000001On4Z^d00ol0
003oI9S]o`000002odj8j0Ko00002?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z
05_ooo]Z003ooookJWKooo]Z0ol0000LoookJP04o`000?o4b=goa<SMolC8g@;o00001Onka^801_l0
003o_<KRokc6h_nla^;o0000ok31i`;o00001_n``NL2o`0000OoX;W[3?l000001?m>R>So8V_Mo`00
0?l0D/l2o`0000Wooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP1KoookJP00oooo
nfYdoookJP;o00007OoonfX2o`0000?oa<SM00Go0000olC9g_o4bMko0000ok_6hP02o`0000;o^lKS
00?o0000okc6h_nla^800_l00004ok31i`?o000000Co[l7Wo`000?nP^N_oX;W[1?l00002oinhj`03
o`000?n;[^ko000000GoPjW]00Co0000ofBGk?l0003oCXSX0_l000000olRJmgo0000o`1Bc`02o`00
00Sooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP1JoookJP00oooonfYaoookJP?o
00007OoonfX2o`0000Coa<SM00Co0000olC9g_o4bMkoa<WN0_l00005ok_6h`;o00000_nka^<01?l0
003o/<7Wo`000?l00005ojo1i`;o00001onO^>/00ol0003oRjk^o`000002oh>Yk@Co000000?oI9O/
o`000?m>R>P00_m>R>P4o`0000Sooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP1I
oookJP00oooonfY^oookJP?o00007ooonfX3o`0000?oa<SM00Oo0000olC9g_o4bMkoa<WNo`000?o4
bMko000000?o^lKS00?o0000ok_6hol000000onka^<2o`0000?o[l7W0ol000000on_`NOo0000oinh
j`07oinhj`Go00000on2Yn`01?l0003oHiK[o`000?m>R>P3o`000004o`1@cOl0003o0000o`0000Oo
oo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP1IoookJP00oooonfY[oookJP?o0000
8OoonfX00ol0003obl[Iol_:f@02o`0000;oa<SM0_o4bMh2o`0000?oa<WN00?o0000ok_6hol00000
0onka^<3o`000003ok_6hol0003o[l7W00;o00001On_`NL00ol0003oWkS[oinhj`03o`0000?oW[SZ
0_l00006oh:Wk003o`000?mSU^_o000000;oCHOW1Ol00007oookJP03o`000?oonf[ooo]Z017ooo]Z
00?o0000oookJ_oonfX0F?oonfX00?oooo]ZJ?oonfX3o`0002?ooo]Z00Co0000ol_:fOo;b]Wobl[I
0ol00002olC9gP03o`000?o4bMkoa<WN00?oa<WN0_l00004ok_6h`04o`000?nka^?o^lKSok_6h`;o
00002?n_`NL2o`0000OoW[SZ2ol00002odf7i`Go00001_oonfX00ol0003ooo]ZoookJP0BoookJP03
o`000?oonf[ooo]Z05Oooo]Z003ooookJVKooo]Z0_l0000UoookJP05o`000?o;b]Wobl[Iol_:fOl0
00000_o;bmT00ol0003oa<WNolC9gP04olC9gP;o000000?o`/WPo`000?nka^<00_l00002ok[7i005
o`000?nka^?o0000ok_7hol000001?n_`NL3o`0000;o[/3W00?o0000oijhj_nN^>X00ol00002oifg
jP;o00001_n0Y^`01?l0003oHYC[o`000?m=Q^L7o`0000Gooo]Z00?o0000oookJ_oonfX04_oonfX0
0ol0003ooo]ZoookJP1GoookJP00oooonfYSoookJP?o00009_oonfX01Ol0003obl[Iol_:fOo;b]Wo
000000?obl_I0_l00004olC9gP04o`000?o2bN3o`/WPol;9h0;o00001Onjan@01_l0003o^lOSok_7
honkan?o0000ojo1i`;o00001_n^`>L2o`0000KoWKOZ0_l00006oh2Vk003o`000?mRU>_o000000;o
CHKW00?o0000oo^aGOl000000_l00005oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oo
nfX0E_oonfX00?oooo]ZH?oonfX3o`0002Oooo]Z0_l00003ol_:f@05o`000?o;bmWobl_Iol_;fOl0
00000_o;c=X01?l0003oa<WNolC9g_l00003ol;9h005o`000?o4bMooa<WOo`000?njan@00_l00000
0onjanCo0000ok_7h`02ok_7h`;o00001?n^`>L3o`000003ojfoiol0003oWKOZ00?oWKOZ00Co0000
oifgj_nM]n[oWKOZ2_l000001?m=Q^Oo0000o`000?ok/Ed4o`0000Cooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP1EoookJP00oooonfYMoookJP?o0000:OoonfX01_l0003odL_Do`00
0?l0003obl[Io`0000;obl_I0_l00003ol_<fP;o00001?o2bN000ol0003oa<WOolC9g`02olC9g`03
o`000?njanCo^/OT00;o^/OT0ol00002ok[7i004o`000?n^`>Oo0000o`0000Go[KoW1?l00004oibf
jP;o00001_moY>/2o`0000;oCHGV1_l00004oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oook
J_oonfX0E?oonfX00?oooo]ZF_oonfX3o`0002_ooo]Z00Co0000om7;e?oAbmCodL_D0_l00002ol_;
f@03o`000?o;c=[oblcJ00;oblcJ00?o0000ol_<fol000000oo2bN05olC9g`;o`l[O00Go0000ok[7
i?njanCo^/OTo`000004ok[7i0;o00000on]_nL3o`000003ojboiol0003oW;KZ00OoW;KZ2_l00000
0om=QNKo0000oobkL`05o`0000?ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP1D
oookJP00oooonfYGoookJP?o0000;OoonfX01?l0003odL_Dom7;e?oAbm@3o`0000;obl_I1?o;c=X0
1?l0003oblcKol_<fol00002ol;9h0?oa<WO0_l00004ol?:g`;o000000Co^LOUo`000?njanCo^/OT
0_l000000onianGo0000ojfoi`02o`0000Go[;oW00?o0000oibfj_nL]^X00ol00002oi^djP03ohJZ
kOl0003oOJ;[00GoOJ;[00GoGi3Yo`000?m<PnGo0000oobkL`05o`0000?ooo]Z00?o0000oookJ_oo
nfX05_oonfX00ol0003ooo]ZoookJP1CoookJP00oooonfYEoookJP;o0000;ooonfX01Ol0003odL_D
om7;e?oAbmCo000000;odLcE0_l00004ol_<fP03o`000?o;c=_oblcK00;oblcK00Go0000olC9goo4
bMooa<WOo`000005ol?:g`03ol?:h?l0003o^LOU00;o^LOU00?o0000okW7iOnianD00_nianD2o`00
00So[;oW0_l00006oi^djP03ohJZkOl0003oOJ;[00GoOJ;[00CoGi3Yo`000?l0003oo;]c0_l00000
1?ok/eWo0000o`000?l00003oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0D_oo
nfX00?oooo]ZD_oonfX3o`00033ooo]Z00Go0000om7;e?oAbmCodL_Do`000003om7<e@;o00000oo;
c=X00ol0003oblcKol_<f`02ol_<f`;oblgK00?o0000olC9gol000000oo3b]l2o`0000?o`l[P0_l0
00000onhanKo0000okW7i@02okW7i@04o`000?nianGo^LOUo`0000;o[;oW0ol00003oj^nj003o`00
0?nK]>[oVkCZ00GoVkCZ2Ol000001Ool`XCo0000ooflL_l0003onk=I00?o00000ooonfX00ol0003o
oo]ZoookJP0FoookJP03o`000?oonf[ooo]Z05;ooo]Z003ooookJToooo]Z0ol0000boookJP05o`00
0?o@bmGo0000om7;e?l000000ooAc=D01?l0003od/gEom;=eOl00002ol_<fP?oblcK00?o0000ol_=
foo;cM/00_o;cM/01Ol0003o`l[Ool?:goo3b]oo000000Go`l[P00Go0000okS7i_nhanKo^<OVo`00
0005okW7i@?o00001on[_^P4o`0000?oVK?Z0_l00006ogRRk@04o`000?ol`XCo0000ooflLPKo0000
0_oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z057ooo]Z003ooookJTcooo]Z0ol0
000doookJP05o`000?o@bmGod<_Eom3;eOl000000ooAc=D01?l0003od/gEom;=eOoBcMD2o`0000?o
blcK1Oo;cM/01Oo;c]co0000o`000?o3b]oo000000Co`l[P00Co0000ol?:h?o3b^3o00000_nhanH0
1?l0003o^LOUokW7iOnianD2o`000003okS7i_l0003oZkkX00?oZkkX0ol000000onZ_NSo0000oiVc
jP06oiVcjPSo000000Goo<:4o`000?l0003o0000oofmL004o`0000;ooo]Z00?o0000oookJ_oonfX0
6?oonfX00ol0003ooo]ZoookJP1@oookJP00oooonfY9oookJP?o0000=_oonfX02Ol0003oelc?o`00
0?o@bmGo0000om3<e_l0003odLcEo`000003om;=e@03o`000?oCc]CodlkD00;o00000oo;cM/2o`00
00?oblkL0_l00003ol?:h003o`000?o3b^3o`l[P00?o`l[P00?o0000okO7i_l000000_nianD00ol0
003o^<OVokS7iP02okS7iPCo00001OnZ_NP4o`0000?oUk?[0_l00005og^Oj@?o000000?oo<>3o`00
0?om_G001Ol000000ooonf[o0000oookJP0IoookJP03o`000?oonf[ooo]Z053ooo]Z003ooookJTOo
oo]Z0_l0000hoookJP05o`000?oGc<ooelc?omO<col000000oo@c=H01Ol0003od/gEom;=eOoBcMGo
000000?odlkD00Go0000ol_=foo;cM_oblgKo`000005ol_>g0;o000000?o`l[Po`000?l000001?o3
b^001_l0003o`/[Qol;:hOl0003o]lOVo`0000Go^<OV0_l00004ojZmj0?o000000?oZ;cXo`000?nG
/n/01OnG/n/00ol0003oTZoZo`000003og^Oj@07o`000?oiaiConLNDo`000?ol`h?o0000oofmL002
o`000005oo^cE?l0003o0000oookJ_l000006ooonfX00ol0003ooo]ZoookJP1?oookJP00oooonfY4
oookJP?o0000>OoonfX2o`0000;oelc?00Co0000omO=d?l0003od<cF0_l00002om;=e@04o`000?oC
c]CodlkDom?>e0?o000000?oblgKo`000?o;c]`00oo;c]`01Ol0003obloMo`000?o<c]_o000000Co
`l[P00?o0000ol;:hOo2b^400oo2b^42o`0000?o^<OV0_l00002okK7i`04o`000?nZ_NSo0000o`00
00GoZ;cX00Ko0000oiNcjonG/n_oUk?[o`000?nG/n/7o`0000;onLND1_l000000ook/eCo0000o`00
0002o`0001cooo]Z00?o0000oookJ_oonfX0C_oonfX00?oooo]Z@OoonfX3o`0003_ooo]Z00?o0000
omK<d?oFc=000_l00003omO=d003o`000?oAcMKodLgF00;o00000ooCc]@00ol0003od/kFom;>eP02
o`0000CoblkL00So0000ol_?gOo;cmgobloMo`000?o;c]co0000ol?:h0;o00001?o2b^401ol0003o
`L_Qo`000?nfanOo0000okS7i_l000001?nfanL2o`0000SoZ;cX0ol00002oiJbj`04o`000?n@[N[o
T:gZo`0000;oN9kY0ol000001?ojbI?o0000o`000?oma887o`0001cooo]Z00?o0000oookJ_oonfX0
C_oonfX00?oooo]Z?_oonfX3o`0003gooo]Z00Go0000omK<d?oFc=3oe/c@o`000003omO=d005o`00
0?oGcm3o0000om7=e_l000000ooCc]@00ol0003od/kFom;>eP02om;>eP05o`000?o;c]coblkLol_>
g?l000000oo;cmd01Oo:cmko0000ol_>g?o;c]co000000Co`/[Q00?o0000ol7;hOo1bn400_o1bn42
o`0000?o]/OW0ol00002okG4i@03o`000?nX_>SoZ;cX00?o00000onW^nP00ol0003oU[;[oiJbj`02
oiJbj`03o`000?n@[N[o000000?o000000?omlZMo`000?ojbI<00_l000001?oma8;o0000o`000?on
_fd4o`0001gooo]Z00?o0000oookJ_oonfX0COoonfX00?oooo]Z>ooonfX3o`0003oooo]Z00Wo0000
omK<d?oFc=3oe/c@o`000?oFcM7o0000omO=d?l000000ooGcm001Ol0003odLkGo`000?oCc]Co0000
00?od/kF00Ko0000om;?eol0003o0000ol_>g?l00002ol_?g@04o`000?o:cmkob/oNol[?gP;o0000
00?obloMo`000?o2b^400_l00003ol7;h@04o`000?o0cNCo`<gTo`0000;o]/OW00?o0000okG4iOne
a>D01?nea>D2o`0000OoYk_X1_l000000on=ZnWo0000o`000002ooO:W@03o`000?ojbI?o000000Co
000000?oo[m]o`000?l000000_l0000NoookJP03o`000?oonf[ooo]Z04cooo]Z003ooookJSWooo]Z
0_l00011oookJP05o`000?oFc=3oe/c@omK<d?l000000ooFcM401?l0003oelo@omO?d?oGcm02o`00
00;odLkG00Go0000om;>e_oBc]Kod/kFo`000003om;?e`;o00000_o;cmd00ol0003ob/oNol[?gP02
ol[?gP05o`000?o;cmgobloMol_?gOl000000oo1bn42o`0000?o`<gT0_l00005okG4i@;o000000Co
]<CVo`000?nW^nSoYk_X1?l00002ojFjj005o`000?nD/>_oU;3[oiB`jol000000on=ZnT00ol0003o
mlZMooO:W@03o`000003oo_:T_l0003ooLN300;o000000Coo/1[o`000?l0003o00007_oonfX00ol0
003ooo]ZoookJP1<oookJP00oooonfXfoookJP?o0000@_oonfX01Ol0003oflg;o`000?oFc=3o0000
00?oe/gA0_l00002omO?d003o`000?oHd=7of=3A00?o00000_oBc]H01Ol0003od/oGom;?eooBcmOo
dM3H00;o000000?obloMo`000?o:cmh00_o:cmh01Ol0003obM3OolW@gol0003obloM00;o00000_o1
bn400ol0003o`<gTol3=i004ol3=i003o`000?nea>Go]LCU00;o]LCU00?o0000okC4i_nda>H00_nd
a>H2o`0000OoYK[X00?o0000oiB`jol000001ol00002ooS<W@04o`000?okbY;o0000oog7P`;o0000
00?oo/1[o`000?l000000_l0000NoookJP03o`000?oonf[ooo]Z04_ooo]Z003ooookJS?ooo]Z0ol0
0014oookJP05o`000?oKcL_oflg;om_=bol000000ooFcM400ol0003oe/oBomK?dP02o`0000?of=3A
00?o0000om7@f?oAd=P00_l00002om;?e`04o`000?oAd=SodM3Hom7@f0;o00000oo:cmh00ol0003o
bM3OolW@g`02olW@g`03o`000?o:d=kob]3N00;o00001Oo0cN@01Ol0003o_lgUo`000?l0003o]LCU
00;o00000onda>H00ol0003o//?Vo`000008ojFjj0;o00000_nB[n/00ol0003oRjSYo`000002ooC<
Y@03o`000?ohc9gon<bM00;o000000?oo<bBo`000?onb8801_l0000OoookJP03o`000?oonf[ooo]Z
04[ooo]Z003ooookJS3ooo]Z0ol00016oookJP03o`000?oKcL_oflg;00;oflg;0_l000000ooFcM7o
0000omK?dP02omK?dP09o`000?oHd=7of=3AomS@dOl0003of=7Bo`000?oAd=So000000;od/oG00?o
0000om7@f?oAd=P00_oAd=P01Ol0003od]7Ho`000?o:cmko000000?obM3O00?o0000olW@h?l00000
0_o:d=h00ol0003o`<gTol3=i002ol3=i003o`000?nocNGo_lgU00;o_lgU0_l00003okC4iP03o`00
0?nb`nKo//?V00;o//?V00?o0000ojFjj?nU^^P00ol00003oj>ij004o`000?nB[n_oTZo[oi:_j`;o
00000_odc:D3o`000005ooS=W?l0003oo<bBo`000?onb8801_l0000OoookJP03o`000?oonf[ooo]Z
04[ooo]Z003ooookJRgooo]Z0ol00018oookJP03o`000?oKcL_oflg;00;oflg;00Co0000omc>bol0
003o00001?oFcm82o`000004omS@dOl0003of=7BomSAdP?o000000?od/oGo`000?oAd=P00_oAd=P0
1?l0003odM;Jo`000?oBdMP2o`0000?obM3O00Co0000olW@h?o9d>3obM3P0_l000000oo9d=oo0000
ol3=i002o`0000?o_lgU00Go0000okk<iOl0003o0000okC4iP02o`0000Ko//?V0_l00007oj>ij0Go
00000_odc:D01_l0003omLfUo`000?ohcIco0000ooc<TP?o000000?oo/Z3o`000?l000000ol0000O
oookJP03o`000?oonf[ooo]Z04Wooo]Z003ooookJR[ooo]Z0ol0001;oookJP05o`000?oKcL_oflg;
om_=bol000000_oLc//2o`0000?oe/oB00Co0000omO@d_oGd=;o00000_oHdM800ol0003of=;ComSB
d`02o`0000?odM3H00Go0000om7Bf_oAd][odM;Jo`000002om;Bf@03o`000?o9d=oo000000CobM3P
00?o0000olW@goo9d=l00_l00003oko=i@;o00000onnc>D2o`0000Co//?V0ol00002ok72iP03o`00
0?nS^NSoXkWX00?o00000_nQ]nP01Ol0003oSjk[ohn^jol0003ol/f[00;o00000_oecJD00ol0003o
n<fLo`000002o`000003ooc=TOl0003oo/Z300Go00008?oonfX00ol0003ooo]ZoookJP18oookJP00
oooonfXXoookJP;o0000COoonfX01Ol0003of/g<o`000?oKcL_o000000?og<k;0ol000001?oFcm;o
0000omO@d_oGd=82o`000003omSAd_l0003of=;C00?of=;C00Co0000om7@f?oAd=So00000ooAd]X2
o`0000;od];I0_l00002olW@h0;o000000Cob=7Qo`000?l0003o00000_o9dN000ol0003o_lgUo`00
0005okk<i@04o`000?nnbnCo0000ok;3iP;o00001_na`^H2o`0000KoXKOX0ol00002oo;=Z`05o`00
0?oecJGo0000ooK?Y?l000000_oicY`01Ol0003oo<fAo`000?l0003ool]o00Go00007ooonfX00ol0
003ooo]ZoookJP18oookJP00oooonfXUoookJP?o0000C_oonfX01Ol0003of/g<om[=c?oJcLco0000
00?og<k;00?o0000omc?c?oLcl`00_l00002omO@dP04o`000?oGdM?oem7Co`0000Cof=;C00Co0000
om7Bf_l0003o00000ooAd]X00ol0003odM?Kom7Cf`02o`000004om7Cf_l0003obM3Po`0000?ob=7Q
00?o0000olWAh?o9dN000_o9dN02o`0000?o_/cU0_l000000onlc>Ko0000okk;i002o`0000Co/L;V
0ol000001?n_`NOo0000oj6gj?nQ]nP3o`0000;oWkGX0_l00003oo;=Z`05o`000?oecJGo0000ooK?
Y?l000000_oicY`2o`000003oog>T?l0003ool]o00Go00008?oonfX00ol0003ooo]ZoookJP17oook
JP00oooonfXRoookJP?o0000D?oonfX02Ol0003of/g<om[=c?oJcLco0000om_>cOl0003og<k;o`00
0003omc?c0;o000000?oem3Bo`000?oGdM<00_oGdM<01Ol0003of=;ComSBdooHd]?o000000;of=CD
00Go0000om7Bf_oAd][odM;Jo`000003om7Cf`03o`000?oAdm[odM?J00;o00000oo8dN42o`0000;o
bM7P0_l000000oo8dN7o0000okk<i@02o`0000?o_<cV0_l00002okg;i@04o`000?na`^Ko0000o`00
00Go[l7W0_l00006oinej0;o000000Col/f[o`000?occj_o00000_ofcj@3o`000005oo[@Vol0003o
oLj@o`000?oobgl01Ol0000QoookJP03o`000?oonf[ooo]Z04Kooo]Z003ooookJQoooo]Z0ol0001C
oookJP;o000000?of/g<o`000?oKc/d00_oKc/d01_l0003og<o<omc?c?oLclco0000omc@c@;o0000
0ooGdM<01Ol0003oem?Do`000?oHd]?o000000;of=CD00Go0000omSCdol0003odM;Jo`000003om7C
f`;o000000OodM?Jo`000?oAe=_odMCKo`000?o8dN7o000000;oam7R0_l00003olSAh@;o00000onl
c>H00ol0003o^lcWo`000003okg;i@;o00000on_`NL3o`000003ojjoiol0003oWkGX00GoWkGX00Co
0000ono>/?o_c[3o00000_occj/02Ol0003om/nTooK?Y?l0003omm2To`000?ojd9_o0000oog>T002
o`000003ooo<OOl0003o000000?o00008?oonfX00ol0003ooo]ZoookJP16oookJP00oooonfXLoook
JP?o0000E_oonfX00ol0003oglg6o`000003om_>c@;o00000_oLcl`02?l0003og=3=omc@cOl0003o
gM;=o`000?oGdM?o00000ooGdm@01?l0003of=CDomSDe?l00003omSCd`05o`000?oAdm_odM?Kom7C
fol000000_o@e=`01?l0003odMCKom7DfooAe=/2o`0000?oam7R00Go0000olSAhOo8dN7ob=7Qo`00
0002olOBh`03o`000?nlc>Ko000000?o^lcW0ol000000onkbnKo0000ojo1i`02o`0000Go[[oW00?o
0000oinej?nO]NP01?l00002ono>/003o`000?occj_olln[00?o00000_ogd:@01ol0003on]2Ko`00
0?l0003oo]2>o`000?ooc7d01Ol0000QoookJP03o`000?oonf[ooo]Z04Gooo]Z003ooookJQ[ooo]Z
0_l0001HoookJP07o`000?oOcLKo0000on3>a_l0003oflk=o`000002om_@c@;o00000ooLd<d2o`00
0003omgBcOl0003oem?D00;oem?D0_l000000ooHe=Co0000omSCd`02omSCd`?o000000CodM?Ko`00
0?o@e=cod=CL0_l00002om7Df`05o`000?o@eMcod=GLo`000?o7dN800_l00002olSAh@Coam;S0_l0
0004ok_<i`04o`000?nkbnKo^l_Vok_;iP;o00002?n^_nL2o`0000?oWK?W00?o0000ono>/?o_c[00
0ol00002oo?@Z`08o`000?ogd:Co0000ooSBY?l0003onm6Ko`000?ond8h8o`00027ooo]Z00?o0000
oookJ_oonfX0A?oonfX00?oooo]Z5ooonfX3o`0005Wooo]Z00Co0000omo=a_oOcLKo00000_oPc/H0
1Ol0003ofm3=om_@cOoKd<go000000?og=3=00So0000omgBcOoMd/go0000omgCc_l0003oem?Do`00
00;oemCE00Go0000omSCdooHdm?of=?Co`000002omODe@;o00000_o@e=`00ol0003ocmGMoloEg@02
o`0000?od=GL0_l00002olKAh`04o`000?o7d^?oam;SolOBh`;o000000?oa=7To`000?nkc>L00_l0
00001OnibnSo0000ok_;i_nkbnKo000000;o^/_W00?o0000ojjoion^_nL00ol00002ojbni`03o`00
0?nM/nOoWK?W00Go00000_o`d;002Ol0003olm2[oo?@Zol0003omm2To`000?ohdZCo0000oo_AV`03
o`000003ookASOl0003o000000Co00008OoonfX00ol0003ooo]ZoookJP14oookJP00oooonfXDoook
JP?o0000FooonfX02?l0003oglg6omo=a_l0003oh<k6o`000?oPc/Ko00000ooKd<d2o`000004omc@
cOl0003ogM;=omgBc@;o000000?ogM?>o`000?l000000_oGe=D2o`0000;of=?C00Co0000omODeOoG
e=GoemCE0_l000000oo@e=co0000oloEg@02oloEg@03o`000?o@eMcod=GL00;o00000_o@e]h00ol0
003oaM;To`000002olOBh`04o`000?o4dNCoa=7TolCAi0;o00001?nibnP00ol0003o^/_Wok[;i`02
ok[;i`?o00001_n/_^L2o`000003oiZaiol0003ok<nh00;o00000_o`d;001Ol0003olm2[o`000?od
dJ_o000000;on=:T0_l00002oocCVP03o`000?ondHgo000000Go00008_oonfX00ol0003ooo]Zoook
JP13oookJP00oooonfXAoookJP?o0000GOoonfX2o`000003omo=a_l0003oh<k600;oh<k600Go0000
on7@aol0003ofm3=o`000002omcAcP04o`000?oMd/gogM;=o`0000;ogM?>00Go0000omkDcol0003o
emCEo`000002omOEeP;o00000ooGe=D01?oGeMKo0000omSFe_l00002oloEg@05o`000?o?e]ko0000
om3Eg?l000000oo@e]h01_l0003ocmOOolGBi?l0003oam;So`0000;oa=7T0_l00002olC>hP05o`00
0?nibnSo0000okO;jOl000000_njbnL2o`000004okO:j?l0003o[;kWojbni`?o00000onY_>L2o`00
00;ok<nh0_l000001?o`d;3o0000oo7A/?l00002ooCAZ`?o000000Kon=>So`000?oldi[oo=>Jo`00
0?ondHd7o`0002;ooo]Z00?o0000oookJ_oonfX0@_oonfX00?oooo]Z3_oonfX3o`0005oooo]Z00Co
0000omo=aooOcLOo00001?oPc/H2o`000004on7@aol0003og=7>omcAcP;o000000?ogM;=o`000?oM
dlh00_oMdlh00ol0003og]C?omkDc`02o`000003omOEe_l0003o000000;oemCE00Go0000omOEe_oG
eMKoemGFo`000002omOGe`05o`000?o?e]kocmKNoloFg_l000000oo@e]h00ol0003ocmOOoloGg`02
o`0000?oa=7T00?o0000olC>h_o4c^800oo4c^801_l0003o]l_YokO;jOl0003o^/_Wo`0000?o]l[X
0ol00006ojVli`05o`000?o/ckSok<nho`000?o/dKP00_l00002oo7A/00=o`000?oddJ_om=6[o`00
0?oedj[o0000ooSCXol0003oo=>Jo`000?ole9Wo0000oooBS006o`0002;ooo]Z00?o0000oookJ_oo
nfX0@_oonfX00?oooo]Z3?oonfX2o`00067ooo]Z00Go0000omo=aooOcLOoglg7o`000003on3>aP03
o`000?oQd<OohM3700;o000000Gog=7>o`000?oLdloog=??o`000003omgCcP04o`000?oMe<oo0000
o`0000;og]K@00Go0000omOFf?l0003oemCEo`000003omOEeP;o00000_oGemL2o`000003oloFg_l0
003o000000;od=KN00Wo0000oloGgoo?emoo0000olcGhOo4dNCo0000olCAi?l000001?o4c^801_l0
003o`/kSol;>hol0003o]l_Yo`0000?o]l[X0_l000000oneaNKo0000ojVli`03ojVli`Go000000Co
k<nho`000?o/dKSok=6h0ol000000oobd[7o0000o`000002ooGCZP03o`000?ohdj?o000000;o0000
00?oo=BIo`000?oodX`01_l0000SoookJP03o`000?oonf[ooo]Z047ooo]Z003ooookJPWooo]Z0ol0
001RoookJP09o`000?oOcLOoglg7omo=aol0003oglo7o`000?oPc/Ko000000;ohM370_l000000ooQ
dLSo0000omcCc`02omcCc`04o`000?oMdlkogM?>o`0000;ogMC?00Co0000omkFd?oNe]3og]K@0_l0
00000ooGe]So0000omOEeP02omOEeP03o`000?oFf=Woe]SI00;o000000?oemSHo`000?l000000_o>
e]l01Ol0003od=KNoloGgoo?emoo000000?oc=OQ00?o0000olC>h_o4c^800_o4c^800ol0003o`/kS
ol;>h`03ol;>h`;o00000_ngb^P00ol0003o]LGVokG5iP02okG5iP04o`000?nY_>Oo0000o`0000;o
Yk[W00Co0000on[@^ooZd;_o00000oo/dKP00ol0003ol=6bo`000002oo;B/@07o`000?oedj[o0000
ooKDZ_l0003onMBSo`000002oocDV@;o000000?oom>:o`000?l000000ol0000ToookJP03o`000?oo
nf[ooo]Z043ooo]Z003ooookJPKooo]Z0ol0001UoookJP;o000000?oglg7o`000?oOclL00_oOclL0
1?l0003ohM37on7@aol00002on7Ab006o`000?oRdlSo0000omcCcol0003ogMC@0_l00002omgDc`05
o`000?oMe]7o0000omkFd?l000000_oNf=42o`0000;oemGF00?o0000omKHfOoFf=T00_l000001OoG
f=So0000omOIf_l0003oc]KO00;o00000_o?eml00ol0003oc=OQolcGh@02olcGh@;o000000?oa<kR
o`000?l000001?o2c^<01_l0003o`=7Wol3Aiol0003o]l[Xo`0000Ko]LGV00?o0000ojNjionW^^L0
0_nW^^L01?l0003oj]2kon[@^ol00002oncA^00<o`000?o]d[So0000oo7C/ol0003ol]:ao`000?oe
dj[o0000ooKDZ_l0003onMBS0ol000000oomeISo0000oooCRP05o`0002Cooo]Z00?o0000oookJ_oo
nfX0@?oonfX00?oooo]Z0ooonfX3o`0006Oooo]Z00Co0000onC=`?l0003o00001?oOclL00ol0003o
hM37o`000003on7Ab004o`000?oRdlSoh]?8o`0000;ogMC@00Co0000omgDcooMe<oo00000ooMe]40
1_l0003og]SAomkHdOoNf=7o0000omKHf@;o00000_oFf=T01?l0003oe]WKo`000?l00003omOIfP05
o`000?o=en7o0000oloGgol000001?o<en401?o;en;o0000olgDgol00004ol;>h`03o`000?o0dNOo
`=7W00;o`=7W00?o0000okG5i_neaNH00_neaNH3o`0000;o/l?V00Co0000ojNjionW^^Oo00000_oZ
d;/01ol0003ojm6ko`000?o/dKSo0000ongB^?l000000_oadk<00ol0003ol]Bao`000002ooKDZP;o
00000_ojeZ801?l0003ooMFHo`000?oodhX6o`0002Cooo]Z00?o0000oookJ_oonfX0?ooonfX00?oo
oo]Z0ol0001ZoookJP04o`000?oTcL3oi<g0o`0000?oglo700?o0000on3Ab?l000000ooQdLP02_l0
003oh]?8o`000?l0003oh]G9o`000?oMe=3o0000omgDcol00003omgFd@;o00000_oNf=401?l0003o
g]WBo`000?l00002omKHf@04o`000?oFfM_oe]WKo`0000?oemWJ00Go0000omKKfoo=en7o0000oloG
g`02olcGh@;o00000oo;en801?l0003obmGQo`000?o2c^<2o`0000?o`=7W00Go0000okk@j?l0003o
0000okG5iP02o`0000Ko/l?V1?l000004OoZd;_o0000on_A^oo[dK_o0000ongB^?l0003ok]>ho`00
0?oadk?o0000oo;D/Ol0003om]BZo`000?ogeZ[o000000;on]JR00?o0000oogEV?l000001ol0000U
oookJP03o`000?oonf[ooo]Z03kooo]Z003loookJP?o0000K?oonfX01?l0003oi<g0onC=`?oTcL02
o`000004omo?aol0003oh=78on3Ab0;o000000GohM78o`000?oRdlSoh]?8o`000003on;Eb@?o0000
0ooMe]400ol0003ogMWComgId`02o`000006omkId_l0003ogMWBo`000?oFf=Wo00000ooFfM/01?l0
003oemWJomOIf_l00002omKKf`?o000000?oc=OQo`000?o;en800_o;en801?l0003obMOTo`000?o;
eN42o`0000?o`=7W00?o0000okk@j?nnd>P00_nnd>P2o`0000Co/l?V0ol000000ona`^Ko0000o`00
0002onS@_P07o`000?o[dK_ojm6kon_A^ol0003okM:ho`000002onkC^004o`000?obe;?o0000oo?E
/@;o000000OommJZo`000?ojeZ;o0000oo_GXOl0003ooMJG00Oo00009OoonfX00ol0003ooo]Zoook
JP0noookJP00n_oonfX2o`0006oooo]Z00Co0000onC=`?oTcL3o00000_oUc/401?l0003oh=78on3A
b?l00002on7Bb@04o`000?oRdlSoh]?8on;Cb0;o000000Goh]G9o`000?oSe/[ohmK:o`000002omgF
d@07o`000?oMfM?ogMWComgIdol0003og]WBo`000002omgIdP;o00000ooFfM/01?l0003oeM[Lo`00
0?l00002omKKf`05o`000?oDf=_o0000om?Gg?l000000_o;en82o`0000;obMOT0_l000000oo:e^;o
0000ol3Ai`02o`0000?o_]3X00Go0000okc?jOl0003o0000ok?3iP03o`0000Co/L;V00Go0000onS@
__oXd;koj=2no`000002on_A^`03o`000?o[d[_o000000?ok]>h00?o0000oo;D/ol000000_l00002
ooOFZP?o000000?onmNQo`000?omeYL00_l000000oooe8Oo0000o`000003o`0002Gooo]Z00?o0000
oookJ_oonfX0?OoonfX00?Oooo]Z0ol0001`oookJP04o`000?oScL7o0000o`0000?oiLk10_l00000
1OoPdLSo0000on7BbOoQd/Wo000000;oh]?800Co0000on;DbOoRe<Wo00000ooSe/X3o`0000?ogMWC
0ol00003omgIdP05o`000?oMf]Co0000omKIfol000000_oEf]`01?l0003oe]_KomKKfol00003omCH
f`;o000000?obmORo`000?o9en@00oo9en@00ol0003ob]KRol[FhP02o`0000?o_]3X0_l00002okc?
j@?o00001?na`^H4o`0000;oj=2n00Co0000onSA__l0003o00000_o[d[/2o`000004onkC^?l0003o
kmFho`0000;ol]Jc0ol000001?ohejWo0000oo_GXOokej42o`000003ookHU_l0003oomB700Go0000
9_oonfX00ol0003ooo]ZoookJP0loookJP00m?oonfX3o`0007;ooo]Z00Co0000on?=`OoScL7o0000
0ooUc/401?l0003oiM31o`000?l00002on7Bb@04o`000?oRe<[o0000o`0000;oh]C90_l00002on?F
bP03o`000?oSf<_o000000?ogMWC00?o0000omcJe?l000000ooMfM800ol0003og=[Do`000002o`00
0006omGJg?l0003oe=_Mo`000?oFfm_o00000ooDf=/01?oBg=oo0000om?Ig?l00003olWGi005o`00
0?o8enGo0000ol[Fh_l000000_o9e^@00ol0003o_]3Xo`000004okc?j@05o`000?nlcNOo_<gWo`00
0?na`^H00_l00003ojo0i`;o000000Coj=2no`000?oXdKko00000_o[d[/01?l0003ok=BkoncD^ol0
0002onoE^0;o000000Gol]Jco`000?odek7o0000ooSGZ@03o`000005oo_HXOl0003oo]RFo`000?oo
e8L01Ol0000VoookJP03o`000?oonf[ooo]Z03cooo]Z003aoookJP?o0000M?oonfX01?l0003ohlg1
on?=`OoScL42o`000004onG>`Ol0003oiM31onG@`@;o000000GohM;9o`000?oRe<[oh]C:o`000002
on;Db@03o`000?oRe/_oh]K;00;o00000_oSf</2o`000005omgIdol0003og=[DomcJe?l000000_oM
fM801?l0003og=[DomcJe?l00002omcKe@05o`000?oDfmgoe=_MomCKgOl000000_oDf=/00ol0003o
d]cOom;Lg`02o`000004om?Jg_l0003obMOTo`0000;ob=OU0_l00003olWFi0;o00000onlcnT00ol0
003o^/kYo`000002okc=i`;o00001?n_`>L01?l0003oi=33o`000?l00002onSA_P;o000000Oojm:k
o`000?o/e;_ok=Bko`000?o_eKSo000000;ol=Jh00?o0000oo?G/ol000000_l00002ooSIZ@04o`00
0?okf:7o0000ookHUP;o000000?oomF5o`000?l000000_l0000WoookJP03o`000?oonf[ooo]Z03_o
oo]Z003^oookJP?o0000M_oonfX2o`0000;ohlg100Co0000onC?`_oTcl;o00000_oUd<400ol0003o
i];2o`000002o`000005on;Db_l0003o0000on;DbOl000000ooRe//01Ol0003ohmS;on?Hbol0003o
hmW<00?o000000?og=[Do`000?oLg=H00_l00003omcJe003o`000?oLfmGog=_E00;o000000Goe=_M
o`000?l0003oe=SKo`000003om;Lg`03o`000?oCf]kodm[N00;o00000oo8enD00ol0003obMKTolWF
i002o`0000;oaMKV00?o0000okc?jOl000000_njc^T3o`0000;o^/gX00Co0000ojo0iol0003o0000
0_oTd<<2o`000005onSA__l0003ojM:nonWB__l000000_o/e;/01?l0003okMFko`000?l00002oo3F
^003o`000?ocek?o000000;o00000_ohfJT00ol0003onmRQo`000003o`000003oooEQOl0003o0000
00;o0000:?oonfX00ol0003ooo]ZoookJP0joookJP00k?oonfX2o`0007Sooo]Z00Ko0000on?=`OoS
cL7o0000on?=`Ol00002onC?`P;o000000OoiM31o`000?oVd/;oi];2o`000?oVe<?o000000;oh]K;
00?o0000on;FbooRe//00_oRe//00ol0003ohmS;o`000002on?Ic004o`000?oSf/gohm[=o`0000;o
g=cF00Ko0000omcJe?oLf]Cog=[Do`000?oKg]P2o`0000;og=gG00Co0000om?Lgol0003o00000ooB
g=l03?oAg>7o0000om?Jg_l0003odM_Po`000?o8enGo0000olKGi_l0003obMKTo`0000CoaMKV0_l0
0003ok[>j@03o`000?njcNSo^/gX00;o^/gX0ol00002onC@``04o`000?oUdL?o0000o`0000?ojM:n
00?o0000oncD^ol000000_o]eK/01_l0003ol=Jhoo3F^?l0003ol=Rho`0000;olmVe0ol000001Ooh
fZWo0000oocJWol0003oo]VD00?o000000CooLm]o`000?l0003o00009ooonfX00ol0003ooo]Zoook
JP0joookJP00jOoonfX3o`0007[ooo]Z00Go0000on?=`OoScL7ohlg1o`000002onC?`P04o`000?oU
d<;oiM32o`0000?oi];200Ko0000onKD`ol0003o0000on;Fbol00003on;Fb`03o`000?oSf<co0000
00;ohmW<00?o0000on?JcOl000000_l000000ooLg=Ko0000o`000002omcJe004o`000?oKg]SofmkH
o`0000;og=gG00Co0000om_OfOoKgmWo00000_oBg=l01Ol0003odMcQom7LhOoAg>7o000000;odM_P
0_l00003olKGiP04o`000?o5e^KoaMKVolGFiP;o00000_o4dN@2o`000004okO=j_l0003o^/gXok[=
j0;o000000Go]lcZo`000?l0003oi=33o`000003onGA``;o000000CojM:no`000?oZe;oo00000oo]
eK/00ol0003ol=Jho`000002oo3H^009o`000?ocfKGolmVeo`000?ohfZco0000ooSJZOl0003oo=ZO
00Go000000CooLm]o`000?l0003o0000:?oonfX00ol0003ooo]ZoookJP0ioookJP00i_oonfX3o`00
07cooo]Z00Co0000onO<^ol0003ohlg10_l000000ooTcl;o0000onG@`P02onG@`P06o`000?oVd/;o
i];2o`000?oWe<?o00000_oWe/@01Ol0003oh]S<o`000?oRe/_o000000;ohmS<00?o0000on?Ic?l0
00000_oSf/d01?l0003ohmc>on?Lc_l00002omcMe`;o00000_oKg]P2o`000004omcMeol0003ofmoI
om_Of@;o000000?od]cOo`000?oAg>400_oAg>401?o?g>;o0000om7Kh?l00002om3MhP;o000000Go
a]OVo`000?o5e^KoaMKVo`000003olCAi0;o`]3U00Go0000okO=j_l0003o^/gXo`000003okO<jP04
o`000?oSd<Go0000o`0000?oiM7300?o0000onSC`?l000000_oZe;l01_l0003okMFkongE^ol0003o
kMJko`0000?ol=Rh00Ko0000oo?I]Ol0003om=^co`000?ohfj`3o`000003oocKWol0003o000000Ko
0000:OoonfX00ol0003ooo]ZoookJP0hoookJP00hooonfX3o`0007oooo]Z00Co0000onO<^ooWc;_o
00000_oTcl801_l0003oiM32onG@`_oUd<;o0000onKB``;o00000_oWe<<01ol0003oimK4o`000?oX
f<Go0000on;Hc?l000000_oSf<`01?l0003oh]_>o`000?l00002on?Jc@07o`000?oSg<ko0000on?N
d?l0003og=gGo`000002om_Nf004o`000?oJgmWof]oIo`0000;ofmoI00Co0000omWLfOl0003o0000
0_oAg>400ol0003ocmcRoloLhP02o`0000;od=gR00Co0000olgLi?l0003o00000_o5e^H01?l0003o
a=7To`000?l00004ol;@i@;o00000_ngc>X3o`0000;ohm3500So0000onGA`ooUdL?oiM73o`000?oU
dlCo0000onSD`@;o000000Koj]Foo`000?o]eK_o0000ongF^ol00002oo3H^003o`000?oafKSo0000
00;om=^c00?o0000ooSK[?l000000_l000000oolfioo0000o`000006o`0002Wooo]Z00?o0000oook
J_oonfX0>?oonfX00>3ooo]Z0ol00021oookJP04o`000?oXc;[o0000onO<^`;o000000Goi<o2o`00
0?l0003oiM32o`000002onKB``06o`000?oWe<?oimC3o`000?oWe/Co00000ooXf<D2o`000005on?H
c?l0003oh]_>on;Kc_l000000_oSf/d00ol0003ohmc?o`000003on?Nd0;o000000CofmkHo`000?oJ
gmWof]oI0_l000001OoKgmWo0000omWLfOoIg=Wo000000;ofMkJ00Go0000oloLh_o?g>;ocmcRo`00
0002om3MhP04o`000?o=g>CocMcTolgLi0;o00000_o4dN@00ol0003o`]3Uol;@i@03ol;@i@;o_m?Y
00Go0000okO<j_l0003o]<GWo`000003on?@a@;o000000GoiM73o`000?oUdlCoiM?4o`000002onSD
`@0@o`000?oZeKooj]Foo`000?o]e[_o0000onkH^ol0003ol=Rho`000?oafKSo0000ooCK/ol0003o
mMbco`0000;on=f^1?l000000oonfi;o0000o`000003o`0002[ooo]Z00?o0000oookJ_oonfX0=ooo
nfX00=kooo]Z0_l00024oookJP04o`000?oXc;[oj<bjo`0000;ojLjk00Co0000onGA`ooUdL?o0000
0ooVd/<00ol0003oimC3o`000002onOFa007o`000?oXf<Goj=S5onSHaOl0003ohm[=o`000002on;K
cP;o000000Gohm[=o`000?oSg<oohmc?o`000002on?Nd004o`000?oRgM7o0000o`0000;of]oI00Co
0000om[Pfol0003o00000_oIg=T2o`000005omWNf_l0003of=oLo`000?o?g>800_l000000oo@gN;o
0000olgLi002olgLi005ol_LiOl0003o0000olCAi?l000000oo2d>D00ol0003o_m?YokoCj@02okoC
j@03o`000?ndaNOo]<GW00;o00000_oSd<D01?l0003ohm75on?AaOl00002onGCa006o`000?oVe<Co
0000onSD`Ol0003oj]Fo0_l000002?o]e[_o0000onkH^oo^f;_o0000oo7I^?l0003ol]^h0_l00000
1ooeg;?o0000ooSM[_l0003onMj[o`000?olgZ401ol0000[oookJP03o`000?oonf[ooo]Z03Kooo]Z
003KoookJP?o0000QOoonfX01?l0003oj<bjonS<^_oXc;X2o`000005onW>^ol0003o0000onGA`ol0
00000_oVd/<00ol0003oi]C4o`000002onOFa006o`000?oXf<Go0000onSHaOl0003oj=[60_l00000
1OoRflko0000on;Md?oRgM3o000000;ohmc?00Co0000on;Md?l0003o00000_oRgM42o`000005om[O
fOl0003of^3Kom[Pfol000000_oIg=T01?l0003of>7MomSQgOl00002omSOg0;o000000?oc]cTo`00
0?o@gN800_o=g>@01?l0003obmcUol_LiOo;g>D2o`0000;o`]3U0_l00003okoCj@07o`000?nld^[o
0000o`000?ndaNOo0000on7@a`02o`0000?ohm7500?o0000onGCa?l000000ooVe<@00ol0003ojMK1
o`000002on_G_`09o`000?o^f;_ok]RkonkH^ol0003olMVho`000?obfkSo000000;omMbc00Ko0000
ooSM[_l0003onMj[o`000?olgZ47o`0002_ooo]Z00?o0000oookJ_oonfX0=_oonfX00=Sooo]Z0ol0
0028oookJP;o000000Goj<bjo`000?oYc[_ojLjko`000002on[@_004o`000?oVdl?o0000o`0000;o
i]C400Co0000onOFa?oWe/Co00000_oXf<D00ol0003oj=[6onSJaP03o`0000?oh]g@00?o0000on?L
col000000_oRgM001Ol0003oh]gAon;MdOl0003ohMoB00?o000000Gof^3Ko`000?l0003ofMcIo`00
0002omSQg@;o000000Kof=oLo`000?oGhMko0000olkLi?l00002olgLi003o`000?o;g>GobmcU00;o
bmcU00Co0000ol_Ii?l0003o00000onodnT01?l0003o_=;ZokcBj_nld^X3o`000003omo@bOl0003o
000000?ohm7500?o0000onCBaOl000001?oVe<@01_l0003ojMK1o`000?l0003ojmNoo`0000;ok]Rk
00?o0000onoI^ol000000_obfkP01Ol0003omMbco`000?ofgK;o000000;onMj[0ol000000oongiKo
0000ookJP`03o`0002cooo]Z00?o0000oookJ_oonfX0=OoonfX00=Gooo]Z0ol0002:oookJP04o`00
0?oXc;_oj<bko`0000?ojLjk00Co0000on[@_?l0003ojm:l0_l00002onKDa005o`000?oWelKo0000
onOFa?l000000_oXf<D00ol0003oj=[6o`000002onSJaP;o000000?oh]g@o`000?oRgm400_l00000
1OoRgM3o0000o`000?oRgM7o000000;ohMoB00Go0000on7Qe?oQhMCo0000omWQg002o`0000;of>7M
00Co0000omKQgol0003o00000_oGhMh3o`000003olgLi?l0003obmcU00;obmcU00Oo0000olWKiol0
003o0000olWJi_l0003o_m?Y00;o00001?nld^X2o`0000?ogm390_l000001OoSdLGo0000onCBaOoT
d/Go000000?oi]C400?o0000onOEa?l000000_oZel401?l0003ok=Roo`000?l00002onoI^`05o`00
0?obfkSo0000oo?L]ol000000_ofgK800ol0003onMj[o`000003o`000003ookOU_l0003o000000Co
0000;?oonfX00ol0003ooo]ZoookJP0doookJP00d_oonfX3o`0008gooo]Z00Co0000onS<^ooXc;_o
00000_oYc[/00ol0003oj]2ko`000003on_B_003o`000?oVe<Co000000?oimO600Ko0000onSHaOoX
f<Go0000onSJa_l00003onSJaP?o000000Goh]oAo`000?l0003oh]g@o`000002on7Qe0;o000000Ko
hMoBo`000?l0003ohN7Do`000?oPhmH2o`0000;of>7M00Co0000omKQgooFhMoo00000_oGhMh00ol0
003oe=gNomCMgP02o`0000;obmcU0_l00002olWKi`03o`000?o9f^KobM[V00;o00000onld^X2o`00
0003ok[@jol0003ogm3900;ogm390_l000002OoQdLSo0000onCBaOoTd/Go0000onGDa_l0003oi]C4
o`000002onOEa0;o000000Coj]O1o`000?l0003o00000_o_fK/02Ol0003ol=^ko`000?l0003olmbg
o`000?ofgK;o0000ooOO/P03o`000004oocPXol0003o0000ookOTPGo0000;?oonfX00ol0003ooo]Z
oookJP0doookJP00cooonfX3o`0008oooo]Z00Go0000onS<^ooXc;_o0000onW?^`02o`0000;oj]2k
00Co0000on_B_?o[d[cojm:l0_l00003onOGaP;o000000Goj=S5o`000?oXf/Koj=[6o`000002onSJ
aP;o00000_oXg/T4o`0000?ohN7D00?o0000on7Od_l000000_oQh=@00ol0003oh>?Fon3SeP02o`00
0004omSQgOl0003oe^7OomKQg`;o000000?oen7No`000?oDgMh00_oDgMh2o`000003ol_LiOl0003o
bM_W00;obM_W00Coam_Xo`000?o9f^Ko00000_o6f^P00ol0003o_=;Zo`000002ok[@j`05o`000?oN
d<_o0000omo@bOl000000_oPdLT2o`000003onCBaOl0003oiMC600;oiMC600Co0000onOEa?oWeLCo
00000_oWel@00ol0003ojmS2on_H`P02o`000007onoI^ol0003ol=^ko`000?ocg;Oo0000oo?M]`02
o`000003ooOO/_l0003onN2[00Co000000?oo]nBo`000?l000000ol0000]oookJP03o`000?oonf[o
oo]Z03?ooo]Z003=oookJP;o0000T_oonfX2o`000004onS<^ol0003ojLnko`0000;oj]2k00Ko0000
on_B_?l0003ojm:lo`000?o/e;d2o`000005onOGa_l0003oim[7onOJaol000000_oXf/H01_l0003o
j=c8o`000?l0003oj=c8o`0000;oj=k900?o0000onSQbol000000ooQhM@3o`0000;ohN3D0_l00000
1?oPhmKo0000omkQeooNhML2o`000005omKQgol0003oeN;Qo`000?oGhMh00ooDgMh01?oBh^?o0000
o`000?l00002olWKi`03o`000?o7fnSoam_X00;o00000oo6f^P2o`0000;o^]3[00Go0000omk@booN
d<_og]3;o`000003on3Ab@Co00000ooUe<H00ol0003oimG4o`000003onOGa006o`000?o[f<;ojmS2
o`000?o/fL3o00000_o`fk/01Ol0003olmbgo`000?ocgKOo000000;ommnb0_l000001OojhJWo0000
o`000?l0003oo]nB00Go0000;_oonfX00ol0003ooo]ZoookJP0boookJP00b_oonfX3o`0009?ooo]Z
00Co0000onS=^_oXcK[o00000_oYck/2o`000008on[@^ol0003ojm:lon_B_?l0003ok=Bmo`000?o/
e[d2o`0000?oim[700?o0000onSJa_l000000_oXg<P01?l0003oj=c8o`000?oXg/T2o`0000;oj>7;
0_l000001?oQhMCo0000on7SeOl00002on7Pe004o`000?oOiMSo0000o`0000;og^7G0_l000001OoN
h]So0000omGRhOoEh^7o000000;oe=gN00Co0000om;RhooBh^?o00000_oBgn82o`0000?oam_X00?o
0000olKJj?o6f^P00_l00002olCCiP;o00001?oNd</01?l0003oh=79on3AbOl00002on3BbP07o`00
0?oUe<KoiMC6onGDa_l0003oiMG6o`000003onOGa005o`000?oXf<Co0000o`000?o[f/800_l00000
1?o`fk_o0000oo3L_?l00002oo?M]`08o`000?oggk;o0000ooOP/Ol0003on^6Yo`000?olhIl2o`00
0003ookPT?l0003o000000;o0000;_oonfX00ol0003ooo]ZoookJP0boookJP00aooonfX3o`0009Ko
oo]Z00Ko0000onS=^_l0003o0000onW?^ol00002on[A_007o`000?o[d[cojm:lon_B_?l0003ok=Bm
o`000002oncF_@;o000000Coim[7o`000?oXg<So00000ooXg<P2o`0000;oj=k900?o0000onSQbooX
hL/00_l000000ooVh<go0000on7Se@02o`000005on7Pe?l0003ognGHomoUf?l000000_oNhML02_l0
003ogN;Ho`000?l0003ogNCJo`000?oCh^;o0000omCMg_l00002om;Rh`;o000000Kod]oRo`000?o@
hNCod>7To`000?o7fnP2o`000003olKJj?l0003oa=?V00?oa=?V00?o0000omk@booNd</00_oNd</0
1?l0003og]7;o`000?l00003on3BbP;o000000GoiMC6o`000?oUeLKoiMG6o`000002onOGa004o`00
0?oXf<Coj=S4o`0000;ojm[20_l000001oo`fk_o0000oo3L_?l0003olmfgo`000?odgkL00_l00000
0oogh;7o0000oo[QZ@04o`000003ookPT?l0003o000000;o0000;ooonfX00ol0003ooo]ZoookJP0a
oookJP00a?oonfX3o`0009Sooo]Z00?o0000onc;]?l000000_oYck/2o`0000;oj]6l00Ko0000on_B
_?o[d[co0000oncD_Ol00002oncF_@;o000000Gok=Roo`000?l0003oj=c8o`000002onSLb0;o0000
0ooXg/T00ol0003oj>7;o`000002onOQc003o`000?oWhlko000000?o00000_oOiMP2o`000005omkQ
eol0003ogN;HomgRf?l000000_oMi=X01?l0003odn;Ro`000?l00002om;Rh`04o`000?o@h^Go0000
o`0000?od>7T0ol000000oo6f^So0000olCCiP03olCCiP;o00000ooNd</01?l0003og]7;omkAbol0
0003on3BbP04o`000?oQe<[ohMC:o`0000;oiMG600Go0000onKGa_l0003oimO4o`000002onSHa003
o`000?o[f/;o000000;ojm_400Co0000oo3L_?l0003olMfl0_l000001oodgkOo0000ooOP/Ol0003o
n>6`o`000?ojhZP02?l0000`oookJP03o`000?oonf[ooo]Z033ooo]Z0031oookJP?o0000VooonfX0
1_l0003ok<^do`000?l0003ojLnko`0000;oj]6l00Co0000on_C_?l0003o00000_o/e;d00ol0003o
k=Jmo`000002ongH_P05o`000?o]f/3okM[0o`000?oXg/T00_l000001ooXgl_o0000onSNbOoXg/Wo
0000onSQbol000000ooWhL`2o`0000;oinG?00Go0000omoUf?oOiMSo0000omkVfP02o`0000;ogN;H
0_l000000ooMi=[o0000omcWg003o`000005om;Rhol0003od>;Uom3RiOl000000oo@hN@01?l0003o
c>3WolcPiol00004olCCiP03o`000?o2d^Ko000000;o000000?og]3;o`000?oNdL/00_oNdL/2o`00
0006on3Bb_l0003ohMC:on7Db_l0003oh=G<0_l00003onKGaP06o`000?oXf<Coj=S4o`000?oYfLGo
00000oo[fl@2o`0000;olMfl00Wo0000ooCO]oodgkOo0000ooOP/Ol0003on>6`o`000?ojhZP00ol0
00000oomh8ko0000o`000002o`00033ooo]Z00?o0000oookJ_oonfX0<?oonfX00;oooo]Z0_l0002M
oookJP03o`000?o/bk?o000000;okLjd00Oo0000on[A_?l0003oj]6lo`000?o[dkco000000;ok=Bm
00?o0000oncG__l000000oo]f;h02Ol0003okM[0o`000?l0003oj=k9o`000?oXgl_o0000onSRc002
o`0000;oj>7;00?o0000onOQc?oWhL`00_l00003onOUc`?o00000_oNi]X01Ol0003ogN;HomgRf?l0
003ofnOM00;o000000?og>OLo`000?oHin000ol000001Oo@h^Go0000olkQi_l0003od>7T00;o0000
0_o<h>L01?o:gnSo0000o`000?o4dnH2o`000004ol;Bi_l0003ofm3>om_@cP;o00000ooNdL/01?l0
003ogm;;omoBbol00002on7DbP04o`000?oPeLcoh=G<o`0000?oi]O60_l000001OoXf<Co0000onWI
aOoYfLGo000000;ojm_400[o0000oncL`_l0003o0000oo7M_?l0003om=ngo`000?oehKKo00000_oh
hK02o`000004oo_SYol0003o0000oogPSPCo0000<OoonfX00ol0003ooo]ZoookJP0_oookJP00_?oo
nfX3o`0009oooo]Z00?o0000onc;/ol000000_o]c[@2o`000004on[A_?l0003ojm>lon_C_0;o0000
00Cok=Bmo`000?o/ekko00000_o]f;h00ol0003okMZoo`000002ongM`@;o000000Coj=o;o`000?oX
h/co00000_oXhL/01_l0003oinG?o`000?l0003oin?>o`0000;oinG?0_l000000ooTi=;o0000omkV
fP02o`000007omgRf?l0003ofnOMom_WgOl0003og>OLo`000002omSWh004o`000?oHiMkof>GNo`00
00;oc^7V00Go0000om3Qi?o<h>Ooc>3Wo`000002ol[Oj0?o000000?o`];Vo`000?l000000ooKd<h0
1Ol0003og=7=o`000?oNdL_o000000?ogm;;00?o0000on7Db_l000000ooPeL`2o`000005onKGa_l0
003oi]S7onKHaol000000_oYfLD01?l0003oj]_5o`000?l00002oncL`P03o`000?o`g[ko000000;o
00000_oehKH01?l0003on>6`o`000?l00002oo_SY`?o000000CooN6;o`000?l0003o0000<_oonfX0
0ol0003ooo]ZoookJP0^oookJP00^OoonfX3o`000:7ooo]Z00?o0000onc;/oo/bk<00ol00002onk@
]0;o000000gojm>lo`000?o/e[kok=Jno`000?o/ekko0000ongI_ol0003okMRno`000?o]f[oo0000
00;okMg11?l000001?oXh/co0000onSQbol00002onOUc`04o`000?oWhlko0000onGXdP;o00000_oU
i=400ol0003oiNKBo`000003o`0000;ofnOM0ol00003omSWh007o`000?oHiMko0000omOWhOl0003o
c^7Vo`000002olcPi`Cob]oX00?o0000ol[Li_o:g>H00_l00003om_@cP05o`000?oKdLoo0000omcA
cOl000000ooOd//00ol0003oh=?<o`000003on3Ec004o`000?oRe/_o0000o`0000?oi]S700?o0000
onWIaOl000000_oZflD01Ol0003ok=c2oncL`_l0003okMk200;o000000Gol=nno`000?oehKKo0000
ooGR]`03o`000006oo_SYol0003o0000oogSVol0003ooN6;0ol0000boookJP03o`000?oonf[ooo]Z
02kooo]Z002foookJP?o0000Y?oonfX3o`0000;okLfc00?o0000onk@]?o^d;@00ol00003oncF_P03
o`000?o/ekko000000;okMVo00Co0000ongJ_ol0003okMg10_l000001_o]g/;o0000ongPa?o]h<Co
0000onSTc@;o000000CoinG?o`000?l0003o00000_oUj=800ol0003oiNCAonGTd@03o`0000;oi>WD
0_l000001?oKimgo0000om[Xgol00003omSWh003omKWh_l0003o000000;oenOQ1?l00003ol[Oj006
o`000?o7g^Wo0000ol[Li_l0003ob=gY0_l000000ooKd<ko0000om_Ac`02om_Ac`;o00000_oOd//0
1?l0003oh=?<on3Cc?l00002on3Ec004o`000?oRe/_oh]K;on;Fb`;o000000?oi]S7o`000?oWfLL0
0_l00002on[Ka@03o`000?o/g<;o000000;okMk200?o0000oo3O__o`gkh00_l00002ooGR]`03o`00
0?ohhjoo000000?o000000?ooN>Ko`000?l000001?l0000boookJP03o`000?oonf[ooo]Z02gooo]Z
002coookJP?o0000Y_oonfX01?l0003ok<^bonc;/_l00002ong=/`?o00000_o_d[@01_l0003ok=Jn
oncF__l0003okMVoo`0000?okMVo00Go0000ongJ_ol0003okMg1o`000002ongN`P04o`000?o]h<Co
0000ongSa@;o000000?oinG?o`000?oVim000_l000001ooUj=;o0000o`000?oUi=7o0000onGVd_l0
00000_oTjM@4o`000003om[Xgol0003o000000;of>OP0_oFin801?l0003oenOQomOWhOl00002om;W
i@04o`000?o:gnSob]oXo`0000?oamkY0_l000001Oo8gNWo0000om[@cooJd<oo000000Cofm7?1?l0
0002on3Cc005o`000?oPeLco0000on3Ec?l000000_oRe//2o`000005onGHb?l0003oimW7onOIaol0
00000_oZflD00ol0003oj]c5o`000003ongN`P04o`000?o`gkko0000oo3Q`0;o000000KomN:go`00
0?l0003onNB_o`000?oki:H8o`0003?ooo]Z00?o0000oookJ_oonfX0;?oonfX00;7ooo]Z0_l0002X
oookJP07o`000?o/bk;ok<^bonc;/_l0003okLfco`000002ono@/`03o`000?o_d[Cokm:d00?o0000
0_o]fKl01_l0003okMVoongI_ol0003okMc0o`0000;okMg100Go0000ongN`_l0003okN33o`000002
ongSa@Co000000Goi^O@o`000?oUj=;o0000onGYd`02o`0000;oiNKB00Go0000onCYe?l0003oh^KF
o`000002on7Yf0?o000000Oof>OPomKWh_oFin;oe>OTo`000?oGin7o000000;od^OU00Co0000om?S
hol0003o00001?o7g^T00ol0003ob=gYo`000002om[@c`;o00000ooKdLl01?l0003og=;?omcBcol0
0002on3Cc005o`000?oPeLcoh=G<on3Ec?l000000_oRe//00ol0003ohmS;on?Hb`02o`000005onOI
aol0003o0000on[KaOl000000_oZg<D01_l0003okMk2ongN`_l0003ok]o2o`0000;ol>7000So0000
ooCS^Ol0003omN>go`000?oii:oo0000oo_TYP?o000000?oo>69o`000?l000000_l0000coookJP03
o`000?oonf[ooo]Z02cooo]Z002^oookJP?o0000Z_oonfX01_l0003ok<^bonc;/_l0003ok/jco`00
00?okm2c00Co0000onoB]?l0003ol=Bd0_l000000oo]fKoo0000ongK`002o`0000;okMc000Co0000
ongM`Ol0003ok]o20_l000001_o]h<?o0000ongSaOl0003okN?6o`0000;ok>G80ol00002onGYd`03
o`000?oUi];oiNKB00?o00000_oRi]H00ol0003ohNWHo`000002omkWfP03o`000?oFin;o000000;o
e>OT0_l00002om;Wi@06om3Vi_l0003o0000om7TiOl0003oamkY0_l000000oo5gN_o0000o`000002
om[@c`06o`000?oJdM3of]7@o`000?oKdLoo00000_oLd/l01Ol0003og=??o`000?oPdlco000000;o
h=G<0_l000000ooRe/_o0000on?Hb`02on?Hb`03o`000?oVfLWo000000;oim[700Go0000on[LaOoZ
g<Go0000on_Ma@02o`0000;ok]o200Ko0000oo3Q`?l0003olN>no`000?odi;T3o`000003ooWU[ol0
003o000000Oo0000=?oonfX00ol0003ooo]ZoookJP0[oookJP00ZooonfX3o`000:cooo]Z00Oo0000
ong;/_l0003ok<^bo`000?o^c[?o000000;okm2c00?o0000oo3B]?l000000_o`e;@3o`0000;okM_0
00?o0000ongL`?o]g<000ol00002onkO`P04o`000?o]h<?o0000ongSa@;o000000CokN?6o`000?o/
iLSok>G80ol000001ooUjM?o0000o`000?oUi];o0000on;[eol000000_oRi]H3o`0000;og^OJ0ol0
0003omCWi003o`000?oBinGod^OU00;od>KV00?o0000om7TiOoAi>D00_l00002olGMj`?o000000?o
f]3?o`000?oJdM000ooJdM001?l0003og=;?omcBcol00003omcCc`04o`000?oPeLcoh=G<o`0000;o
hMK<00Ko0000on?HbooSf<_ohmS;o`000?oSfL`3o`000004onOJaol0003oj]c5o`0000;ojmg500Go
0000onkO`_o^gl;o0000onkQ`P02o`000003oo7S__l0003om>Bi00Oo000000?oo>JHo`000?l00000
0ol0000eoookJP03o`000?oonf[ooo]Z02[ooo]Z002XoookJP?o0000[ooonfX03_l0003okL^bong;
/_l0003ok/jco`000?o_d;?o0000ono@/ol0003ol=:do`000?o`e;Co00000_oae[H2o`000006ongK
`?l0003okMc0o`000?o^h<?o00000oo^gl802?l0003okN33o`000?o]hlGo0000ongSa_l0003ok>G7
0_l000000oo[i/[o0000on_Xb`04o`000007on;[eol0003o0000on;Ve_l0003ogngKo`000002omkW
fP08o`000?oNj=_o0000o`000?oLjmgo0000omCWi?l00003om3ViP;o000000CodNCUo`000?o=i>So
cNCX0ol000000ooFcm;o0000o`000004om[Ad0;o000000?og=;?o`000?oLdll00ooLdll00ol0003o
h=G<o`000003on7Fc004o`000?oSf<_ohmS;o`0000;ohmW<00Go0000onKKbOoVflWo0000onSKb002
o`0000;ojmg500?o0000onkO`_l000000_o^hL800ol0003olN>no`000002o`000003ooCV^ol0003o
n>Na00[o0000=OoonfX00ol0003ooo]ZoookJP0ZoookJP00YOoonfX3o`000;7ooo]Z00Oo0000ong;
/_o]bk;okL^bo`000?o^c[?o000000;okm2c00Co0000oo3B]?l0003olMBd0_l00002oo7F]P03o`00
0?oafKSo000000;o00000_o^h<<01_l0003ok]o2onkO`_l0003ok^;4o`0000;okN?50_l00002oncU
a`04o`000?o[i/[o0000on_Xb`;o000000Goj^_=o`000?oRjmOo0000on7/f@02o`000005omo]fol0
003o0000omkWf_l000000_oNj=/01Ol0003og>_Mo`000?oIimoo000000?od>KV00Co0000olkUj?l0
003o00000_o=i>P00ol0003obN?Zo`000003omK?dP05o`000?oJdM3of]7@om[Ad?l000000_oKd]00
0ol0003og=??omcCc`02omcCc`03o`000?oKe=7o000000?ohMK<00Co0000on7GcOl0003o00000ooS
fL`01?l0003oi]_9o`000?oWg<X2o`0000;ojmg500?o0000oncOaOl000000oo^hL82o`000004oo;T
__l0003om>JkooCV^`;o000000GomnRco`000?ojj:Ko0000oo_WVP05o`0003Kooo]Z00?o0000oook
J_oonfX0:OoonfX00:;ooo]Z0ol0002doookJP06o`000?o]bk;okL^bo`000?o^c[;o00000oo_d;<0
1Ol0003ol=:do`000?oae;Co000000;olMJf00Wo0000oo;I]_l0003o0000oo;K^?l0003ok^33o`00
0?o^h/@00_l00002onkRa004o`000?o]hlGo0000o`0000?ok>G70_l00002on_Xb`03o`000?oZjlgo
j^_=00?o000000GohNcIo`000?oOkM_o0000omg]g002o`0000;og^SK0ol00002omWWg`;o000000Go
d>KVo`000?o>iNSoc^GXo`000002olgTj003o`000?o9hn[o000000?oe/oB0ol000000ooJdM3o0000
om_Bd002om_Bd005o`000?oLdloog=??omcCcol000000_oKe=42o`000005on7Fc?l0003ohMO=on7G
cOl000000ooSfL`00ol0003oi=[<o`000003onOLbP03o`000?o[gLGo000000;ok=o500?o0000onkQ
`_o^hL800_l00002oo;T_P08o`000?odi[_o0000ooGW^?l0003omnRco`000?ojj:H3o`000004ooWT
ROl0003o0000o`0003Oooo]Z00?o0000oookJ_oonfX0:?oonfX00:3ooo]Z0_l0002goookJP;o0000
00?okL^bo`000?o^c[800_l000001?o_d;?o0000oo3C/ol00002oo7D]0;o000000ColMJfo`000?ob
fKKo00000_obfkP3o`000004onkRa?l0003ok^;4onkRa0?o000000CokNG6o`000?o/iLOok>G70_l0
0002on_Xb`;o000000?oj^_=o`000?l000000_oXk=43o`0000;ogNgL00?o0000omkXfooNj=/00ol0
0002omWWg`;o000000Cof>SPo`000?o>iNSoc^GX0_l000001?o=i>SobN?ZolWSj_l00003omK?dP03
o`000?oGd=?oem3C00;o00000ooKd]001Ol0003ofm?@o`000?oLdloo000000;ofmCA00Co0000omgF
d?l0003o00000ooQeld2o`000005on?Ic?l0003oi=[<onCJc?l000000_oWg<X00ol0003oimg:o`00
0002oncOa@09o`000?o/h<Go0000o`000?o_h/;o0000oo;T__l0003ol^Fm00;o000000ComNNho`00
0?l0003on>V`2?l0000goookJP03o`000?oonf[ooo]Z02Sooo]Z002MoookJP?o0000^?oonfX01?l0
003olLVYo`000?l00002onk>/P03o`000?o_dK?o000000;ol=>c0ol00002oo7G]@09o`000?obfKKo
l]Vfo`000?obfkSo0000oo;M^Ol0003ol]nk00;o000000Ook^;4o`000?o]i/Oo0000ongUa_l0003o
k>[:00;o000000Gok>S9o`000?o[j<_o0000on[[c@02o`000005onSZcol0003oj>cAo`000?oUk=<0
0_l000001ooMkMco0000o`000?oNj=_o0000om[]h?l000000_oIiml01Ol0003oe^gTo`000?l0003o
en_S00?o000000CocNCXolWSj_l0003o00000ooFcm802Ol0003oem3ComO@dooGd=?o0000omWBd_l0
003ofm;@o`000002om_Cd0;o00000_oKe=402?l0003ogMK@omgFd?l0003oh=O?o`000?oQelgo0000
0_oRf<d01Ol0003oi=[<onCJc?l0003oiM_<00;o00000_oWgLX2o`000007oncOaOl0003ok>35o`00
0?o_h/;o0000oo3T`@02o`000003oo;U_Ol0003omNNh00?o000000?on>V`o`000?l000000_l00000
1?ogi8Co0000o`000?l0000hoookJP03o`000?oonf[ooo]Z02Oooo]Z002JoookJP?o0000^ooonfX0
0ol0003olLVYo`000003o`0000;okm6c00?o0000oo3C/ol000000_oaeK@02?l0003olMNeoo7G]Ol0
003ol]Vfo`000?obfkOo00000_obgKT01_l0003ol]nko`000?obhkco0000ongVa`;o000000GokNG6
o`000?o/j/[o0000oncXb@03o`0000;oj^_=00?o0000onSZcol000000_l00002onG/d`03o`000?oU
k]Go000000?o000000Gof^gPo`000?l0003ofNOOo`000002omK]i003o`000?oGjn?o000000;odN_W
0ol00002omG?d`03o`000?oFcm;o000000?oem3C0_oGdM<00ol0003ofM;Bo`000002om_Cd005o`00
0?oKe=7o0000om_DdOl000000_oMe]001Ol0003og]O@o`000?oPeloo000000;oh]S=0_l000001OoT
f/co0000onGKc?oUflco000000;oimg:00Go0000onKNc?l0003o0000oncPa@02o`000004onoR`_l0
003ol>C1o`0000;ol^Fm00Go0000ooGW^?l0003o0000ooSY/005o`000004ooOTQ?l0003o0000o`00
03Wooo]Z00?o0000oookJ_oonfX09_oonfX009Oooo]Z0ol0002noookJP;o00000_obc:T2o`000003
onoA/ol0003olM>c00;o00000_oaeK@01?l0003olMNeo`000?obf[H2o`000006oo;K]ol0003ol]fi
o`000?ocgk[o00000_obhk`3o`000004ongYb?l0003ok>[:oncZbP;o000000Coj^g>o`000?oZjlgo
j^_=0ol000001?oWk=7o0000onG/dooUk=<3o`000006on?`eol0003o0000om[]h?l0003of>kR0_l0
0002omK]i003om?/iOl0003o000000;odN_W00Cocn[Xo`000?l0003o00000ooEcm<01?l0003oem3C
omO@dol00004omOAd`;o000000?ofm?@o`000?oKe=400_oKe=401?l0003ogMK@omgFd?l00003omkG
d0;o000000Coh]S=o`000?oRf/koh][>0_l00002onGKc003o`000?oWgL[o000000;oi]k<00?o0000
on_Qaol000000_o/hLD2o`000005oo3T`Ol0003ol^Fmo`000?ocikd03Ol0000ioookJP03o`000?oo
nf[ooo]Z02Kooo]Z002DoookJP?o0000`?oonfX00ol0003olLVWo`000002oo;<Z@;o000000Cokm6c
o`000?oadk?o00000_oaeK@02Ol0003ol]Reo`000?l0003ol]Zfo`000?obfkOo0000oo?N^002o`00
0007oo?O^_l0003ol^>lo`000?obi;go0000oo;V_`02o`00000:oncZb_l0003o0000o`000?oZkLko
0000on[[cOl0003oio3Ao`0000;oincA00So0000onG/dol0003oiNkEo`000?oSl=Oo0000on3]fP;o
00000_oHk^801?l0003oe^gTom?/iOoCk>D2o`0000;odN_W00Oocn[Xo`000?l0003o0000om??eOl0
003oeLoC00;o000000?oem3Co`000?oGdM<00ooGdM<2o`000003omWCd_l0003ofmCA00;ofmCA0_l0
00000ooMe]3o0000omkGd003omkGd003o`000?oPfLoo000000?oh][>00Ko0000onGKc?oUflco0000
onGMc?l00003onKNc009o`000?o[hLOo0000o`000?o/hLGo0000oo3T`Ol0003ol>G100Go000000?o
m^Vfo`000?l000000ol000001?oijICo0000o`000?l0000koookJP03o`000?oonf[ooo]Z02Gooo]Z
002BoookJP;o0000`ooonfX00ol0003olLVWo`000002oo;<Z@03o`000?odcZSo000000;olM>c0_l0
00001?oaeKCo0000oo;H]Ol00002oo;J]P08o`000?obfkOo0000oo?N^?l0003olmnjo`000?ochk/2
o`000003oo;T_Ol0003ol^Jo00Go000000Goj^g>o`000?l0003o0000onO`d@02o`000004onO/dOl0
003o0000o`0000;oiNkE0_l000001?oPkM[o0000omo`fooOl=/3o`0000?odncU00?o0000om7[ioo?
j^P00_o?j^P2o`0000;odloE0_l00002omK@e003o`000?oGdM?oem7C00;oem7C00So0000omSBdooH
d]?o0000om[Ddol0003ofmCAo`0000;og=GA00?o0000omkGd?oNem000_oNem000ol0003og]SAo`00
0002o`000005on;Jc_l0003o0000onGKc?l000000_oUgL`01_l0003oi]k<onKNc?l0003oj>3:o`00
00;ojn;70_l000001Oo`i<7o0000o`000?l0003olnNm00?o000000?om^Vfo`000?l000001ol0000l
oookJP03o`000?oonf[ooo]Z02Cooo]Z002?oookJP?o0000a?oonfX00ol0003olLVWoo79Y`03o`00
00;om<jX0ol00002oo;F]008o`000?obf;Gol]Reo`000?obf[Ko0000oo?M]ol00002oo?N^005o`00
0?ocgk[o0000oo?S^ol000000_obi;d2o`000003oo7W`Ol0003ol>[300Go000000?oio3Ao`000?oV
lM<00_l000001?oTl]Ko0000onG^eOoUk]D2o`0000;oh>gJ00Co0000omo`fol0003og>gN1?l00000
0ooCk>Go0000oloZj002oloZj0;o00000_oCcmD01_l0003oe=3FomC@e_l0003oe]3Do`0000?oem7C
00?o0000omSBdooHd]<00_l00002om[Dd`05o`000?oLeM7og=GAomcEdOl000000ooNem001?l0003o
g]SAomkHdOl00002on7Jc`04o`000?oSflkohm_>o`0000;oiMg<00Co0000onKNc?l0003o00000_oX
h<X00ol0003ojn;7on_Ra`03o`000006oo3U`Ol0003o0000o`000?ocj;co00000_ofjKH3o`000003
oo[[Xol0003o000000?o0000?OoonfX00ol0003ooo]ZoookJP0SoookJP00S?oonfX3o`000<Oooo]Z
0ol00002oo?;Y`03o`000?odcZSom<jX00Co000000Kol]Jdo`000?obf;Go0000oo?L]ol00002oo?M
]`05o`000?ocg[So0000oo?Q^_l000000_ochk/01?l0003ol^Bmo`000?l00002oo7W`@;o000000Co
kn_5o`000?o_k/Koknk60ol000001_oVlM?o0000onCbe_oTl]Ko0000onG^e@;o00000_oPkMX3o`00
00;og>gN0_l00002omS/hP03o`000?o?j^Socn[X00;o000000Cod/oFo`000?oCcmGo00000ooDd=H2
o`000004omKAe?l0003oem7Co`0000;of=;C00Go0000omSDe?oHe=Co0000om[Dd`02o`000006omcE
dOl0003og=KBo`000?oNem3o00000_oNf=42o`000008on7Jcol0003ohM_@o`000?oSflko0000onGM
c?l00002onKNc003o`000?oXh<[oj>3:00Co000000?ojn?9o`000?o_i/<00ol00002oo?X_005o`00
0?ofjKKo0000o`000?oijjd01ol0000moookJP03o`000?oonf[ooo]Z02?ooo]Z0029oookJP?o0000
bOoonfX01?l0003ol/RUoo;8YOl00002oo?;Y`?o00000_odd:T01?l0003omM>/o`000?ocfK@2o`00
0005oo?L]ol0003olmfgo`000?och[X00_l000000oochK[o0000oo?S^`03o`000003oo;W__l0003o
lNO100?o000000?okn_5o`000?o_k/H00ol000001?o/lL[o0000o`000?oTl]H3o`00000:on7cf_l0
003oh>gJo`000?oLlmko0000omc]g_l0003of?;Ro`0000?of>cR1?l00003om;?eP08o`000?oDd=Ko
e=3FomC@e_l0003oe=7Fo`000?oFdM@2o`0000;of=;C00?o0000omSDe?oHe=@00_oHe=@01?l0003o
f]GCom[Edol00003omcFdP04o`000?oNf=7og]SAo`0000;ogmWA00Ko0000on7Kd?oQfm3ohM_@o`00
0?oSg<h2o`0000;oi]k<1?l000001OoYh/[o0000on_SbOl0003ok>G800;o000000OoknO4o`000?oc
j;co0000oo?Y_?l0003omn^e00Go000000Con>VAo`000?l0003o0000?_oonfX00ol0003ooo]Zoook
JP0RoookJP00Q_oonfX3o`000<cooo]Z00?o0000oo;8YOobb:D00ol00002ooC>Y`05o`000?odd:Wo
m=2Yo`000?oedj`00ol000000oocg;Oo0000ooCO]`02o`000003oo?R^_l0003oln6j00?o000000?o
lnJmo`000?obikh00ol000000ooaj/;o0000ono[a@03o`000005ong^bOl0003ok?7:o`000?oZl<h0
1?l000001OoQlm[o0000o`000?l0003og??N00?o000000Wof?;Ro`000?oHk>;of>cRo`000?oClNKo
0000omC_iOl000000ooBcmH01Ol0003odm3Fo`000?oDd=Ko000000?oe=7F00Go0000omKBe?l0003o
f=;Co`000004omSDe0;o000000Gof]GCo`000?oKe]?o0000omcFdP02o`000003omkHdOl0003ogmWA
00;ogmWA00Go0000on7Kd?oQfm3o0000on;Ld002o`000003onKNc?l0003o000000;o00000ooYh/X2
o`0000;ok>G800?o0000onoWa?o_il@00ol000000oocjKco0000o`000003o`000003ooW/XOl0003o
000000?o0000?ooonfX00ol0003ooo]ZoookJP0QoookJP00Q?oonfX2o`000<oooo]Z0ol00002ooC;
Y@09o`000?odcZOom<jWo`000?odd:Wo0000ooKCZOl0003om]J/00Co000000Com=ngo`000?och[[o
ln:j0_l000001_ocikgo0000oo?V_Ooci[go0000oo;W_P;o00000_oaj/801?l0003okn_5o`000?l0
0002ong^b@;o000000Coj_3>o`000?oYlloojO??1Ol000001OoLlmko0000o`000?l0003of?;R00Co
000000Sodo7Vo`000?oDknGo0000om3>f?l0003od/oFo`0000?odm3F00?o0000omCAe_oDdMH00_oD
dMH2o`000003omKBe?l0003of=CD00?of=CD00Co0000omWEe?oIeMCo00000ooKe]<01?l0003ogMOB
omgGd_l00003omoId@04o`000?oOfm7o0000o`0000;oh]c@1?l000000ooVglco0000o`000002onWR
bP;o00000oo/iLP01_l0003oknO4o`000?o^j<Go0000oo?[_PCo000000Gon>f[o`000?l0003o0000
ooKYSP03o`0003oooo]Z00?o0000oookJ_oonfX08OoonfX0087ooo]Z0ol0003AoookJP03o`000?oc
b:?o000000;om<^U00Go0000ooC>Yol0003om]2Wo`000002ooKCZ@;o00000_ogf:/01Ol0003omm^_
o`000?l0003oln:j00;o00000_ocikd03_l0003olnJmo`000?objl3o0000oo;Z`?l0003olN[2o`00
0?o`k/Co0000ono^a_l0003okNk90_l00002on[`cP04o`000?oYlloo0000o`0000;oiOGC1Ol00000
1?oHl^;o0000o`000?l00002om?aiP?o00000oo@c]P01?l0003odm3Fom?@e_oCd=H2o`0000?oe=7F
00?o0000omCBe_oDd]H00_l00003omSDe003o`000?oIeMCofMGD00;o00000_oKe]<2o`000003omgG
d_l0003o000000;ogmWA00?o0000omoKdOoOfm401?l00002on7MdP03o`000?oVglco000000;oin7=
0_l000001ooYhl[o0000oncUb?o/iLSo0000ongVaol000000_o^j<D2o`000003oo;/`?l0003o0000
00;o000000?on>j/o`000?l000001Ol0000ooookJP03o`000?oonf[ooo]Z023ooo]Z001noookJP?o
0000dooonfX02?l0003ollRSoo?8Xol0003om<^Uo`000?oecZGo00000_ofd:L01Ol0003om]>Yo`00
0?ogeZWo000000;ommR[00_o0000ooOK[ol0003ommf_o`000?odi;[o0000oo?W_Ol0003olnVno`00
0002oo;[`0;o000000Col>o4o`000?l0003ol>k41?l000000oo/lL[o0000on[`cP03o`000003onKb
dol0003oiOGC00?o00000_oQm]P2o`000004omKbi?l0003odo7Vom?aiP?o000000?oclkHo`000?o@
c]P00_l00002om?@eP06o`000?oCdMOodm7Go`000?oDdMKo00000_oDd]H01_l0003oeM?Go`000?l0
003of=CDo`0000;ofMGD00?o0000omWFe?oIe]@00_l00002om_Ge003o`000?oMfM;ogMWB00;o0000
00Kogm_Ao`000?l0003o0000on;Ld?l00003on7MdP;o00000ooWhLd01?l0003ojN?:o`000?oZi<X2
o`0000;okNK700Co0000onkXaOl0003o00000_obk<000ol0003om^jgo`000008o`000003oookJ_l0
003ooo]Z03kooo]Z00?o0000oookJ_oonfX07ooonfX007_ooo]Z0ol0003FoookJP04o`000?ocb:?o
0000ooC;X`;o000000ComLjUo`000?ofd:Oom]2W0ol000001_ogeZWo0000ooOHZol0003on=^/o`00
00;ommf_1Ol000000oocjKko0000oo;[`003o`000003oo3_a?l0003ol>k400Co000000Ook?7:o`00
0?l0003o0000onWccol0003oi_;C00?o000000Coh_;Ho`000?oQm]SohOKH0_l000001ooMm]go0000
o`000?oClNKo0000om7`j?l000000oo?c]P00ol0003od<oHom3?f002o`0000?odm7G0_l00002omCB
eP04o`000?oEdmOoeM?GomGCe`;o00000_oIeM@01Ol0003ofMKDomWFe?oIe]Co000000;ofmOD00Co
0000om_Ie?l0003ogMWB1?l00002on3Ld@04o`000?oQgM;ohMgBon7MdPCo000000Coin7=o`000?l0
003o00000_oZi<X00ol0003okNK7ongVa`03o`000003oo3Za?l0003ol^c000?o000000?om>nio`00
0?l000000_l000001?ocji3o0000o`000?l00002oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000
oookJ_oonfX07ooonfX007Sooo]Z0ol0003IoookJP05o`000?ocb:?o0000ooC;Xol000000_oecZD3
o`000004ooOCYol0003ommJYooOFZ@?o000000?on=^/o`000?oggJl00ol000000ooghk;o0000o`00
0003o`000003oo7^`Ol0003ol>o400?o000000?okO?7o`000?o/m<X00_l000001?oXm/ko0000onWc
cooYlll2o`000003on;he_l0003oh_;H00;o000000KohOKHo`000?l0003ogOKMo`000?oGmn82o`00
0003om7`j?l0003oclkH00;oclkH00God<oIo`000?o@cmSod<oHo`000003om?Ae`05o`000?oCd]Oo
0000omCBe_l000000ooEdmL01Ol0003oeMCGo`000?oIeMCo000000?ofMKD00Gof]OEo`000?oKemCo
0000om_Ie004o`000004omoKdOl0003oh=cAon3Ld@;o00000_oQgM800ol0003ohmoAo`000002onGQ
c`Co00000_oZi<X02?l0003okNK7o`000?o]j<Oo0000oo3Za?l0003ol>_30ol000001?odkkWo0000
o`000?oflJl6o`0000;ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0NoookJP00
MOoonfX3o`000=_ooo]Z00?o0000ooC7X?l000000_odbj<3o`0000;omm6U00?o0000ooOCYol00000
0_l000001_ohfJ[o0000ooSK[?ohfjco0000ooOM[`;o00000_oghk800ol0003omnFdo`000005o`00
0003onobaOl0003okO?700Go000000?oj?K>o`000?oYlll00ol000001?oRn=Ko0000o`000?oMn=X2
o`000003omkbg?l0003o000000;oeoOR00?o0000omSdh_l000000_o?c]P01?l0003od<oIom3?fOo@
cmT2o`000004om7@fOl0003odm7Go`0000?odm;G00Go0000omGCeooEdmOoeM?Go`000003omGDe`04
o`000?oIe]CofMKDo`0000?of]OE0ol000000ooKfMCo0000omcJe@02o`0000;oh=cA00?o0000on7M
d_oQgM800_l00002on?Od@03o`000?oUhLoo000000;oi^;?00Ko0000on[Tb_oZi<[o0000on_Vb_l0
0002ongXa`06o`000?o`j/Co0000oo3[`ol0003olnfn0_l000000ooel;Ko0000ooKa[`05o`0000Co
oo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0MoookJP00LooonfX2o`000=gooo]Z
00?o0000ooC7X?odaj000ol00002ooK>X`03o`000?ogdJGomm6U00;o00000_oheZP04?l0003on=VZ
o`000?ohfjco0000ooSN[Ol0003on>2_o`000?oghk;o0000ooOU/_l0003om^Nfo`000?ofj[P8o`00
0003on[fc?l0003oj?K>00Go000000Coh_SFo`000?l0003ogOSJ0_l000001?oNl]co0000o`000?oG
mn84o`0000;oclkH00?o0000om3?fOo@cmT00_o@cmT01Ol0003odM3Iom7@fOoAd=Wo000000?odm;G
0_l00002omGCe`04o`000?oEe=OoeMCGomGDe`;o000000?ofMKDo`000?oJemD01?l00002om_Ie003
o`000?oLf]Gog=[E00;o000000?oh=cAo`000?oQgM800_oQgM801_l0003ohmoAon?OdOl0003ohn3A
o`0000?oi^;?0ol00002on_VbP05o`000?o]j<Oo0000onkYaol000000_o`jl<3o`0000;omO2f1?l0
00000ooajX_o0000o`000005oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX07Ooo
nfX0073ooo]Z0ol0003OoookJP06o`000?odaj3om<NPo`000?ofbYoo00000_ofcZ<01Ol0003omm6U
o`000?ohe:Go000000;on=JX0_l000001_oig:_o0000ooSN[OohgZgo0000ooSP[`;o00000_ogiK82
o`000005ooKZ]_l0003om>bjo`000?odkk/01?l000000oo_ll?o0000o`000004o`000007onChdol0
003o0000o`000?oMn=[o0000om_ig@03o`000008omOgh_l0003oc<gKo`000?o=c][o0000olo>f?l0
0003om3?f@0:o`000?o@d=Wod=3Io`000?oAd=Wo0000om7AfOl0003odm;Go`0000;oe=?H0_l00003
omGDe`03o`000?oFeMSoe]GH00?o000000Cof]OEo`000?oJf=Gof]SE0_l00002omcJe@04o`000?oK
fmKofm_Fo`0000?ohMgB0_l000001OoSgm7o0000on?PdOoSh=7o000000;oi^;?00Go0000onGTdOl0
003o0000on_VbP03o`0000;ok^W700?o0000oo3[`ol000000ol000000ooel;Ko0000o`000006o`00
00Gooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0LoookJP00KOoonfX3o`000>;o
oo]Z0ol00002ooK:W`03o`000?ofcZ?om/jS00;o00000_ohe:D03_l0003on=JXo`000?oifZSo0000
ooWLZol0003on=j]o`000?oihJko0000ooSS/?l0003omnFb0ol000000oofj[Ko0000ooC/^P02o`00
0005oo;`__l0003olO72o`000?o_ll<00_l000000oo/mlOo0000o`000006o`000003om_igOl0003o
000000?o00000oo<cM/00ol0003ocLkJo`000003om3?f@03o`000?o@d=Wod=3I00;od=3I00?o0000
om7AfOoAdMT00_l00003omCCf004o`000?oEe=OoeMCGomGDe`Co000000CoeMKIo`000?oJemGo0000
0ooJf=D01?l0003og=[EomcJeOl00003om_KeP;o000000GohMgBo`000?oQg];ohMkBo`000002on?P
d@05o`000?oTh]7o0000o`000?oUi=400_l000001?oYi/co0000on_Wbol00002onkYa`?o000000Co
lNg2o`000?l0003olnnl0ol000000ooflJ_o0000o`000003o`0000Kooo]Z00?o0000oookJ_oonfX0
?OoonfX00ol0003ooo]ZoookJP0KoookJP00J_oonfX3o`000>Gooo]Z00?o0000ooK6Vol000000_of
bYl3o`000004ooSAX_l0003on=BUooSDY@?o000000?onMZXo`000?oig:/00ol000001?oihJko0000
o`000?ohik43o`0000;om^Zf0ol00002oo;`_PCo000000?okOC6o`000?l000000_l000000ooWmloo
0000onKic`02o`000003on7je?l0003o000000?o00001Oo<cM/01Ol0003ocLoKo`000?o@cmWo0000
00?od=3I00Go0000om3Af_l0003odM7Io`000002om;Bf@04o`000?oDdmSo0000omCCf0Co000000Co
e]GHo`000?oEe]WoeMKI0_l00003om[He@;o000000?og=[Eo`000?oKfmH00_oKfmH01?oMg=Ko0000
omoMe?l00002on7NdP;o000000Oohn3Ao`000?oTh]7oi>;Ao`000?oUi=7o000000;oinG?1?l00000
1?o^jLOo0000onk[aol00002oo7]`P;o000000?olnnlo`000?oelK@01ol00007oookJP03o`000?oo
nf[ooo]Z03cooo]Z00?o0000oookJ_oonfX06ooonfX006Oooo]Z0ol0003XoookJPGo00000_ohcIl0
0ol0003on=6Ro`000002o`000008ooWGYOl0003onMZXo`000?ojgJSo0000ooWOZol00002ooWQ[P;o
000000Gon>Nao`000?ogj;?o0000ooKZ]P02o`000003ooC_^_l0003ol_2n00Co000000KokOC6o`00
0?l0003oj_K<o`000?oWmll4o`000003on7je?l0003of_cI00?o00001?o<cM/01_l0003oc<kKolc>
fol0003ocLoKo`0000?od=3I00Go0000om3Af_o@dM[od=7Jo`000004om;Bf@Go00000_oFeMP00ol0
003oeMKIomGFf@02omGFf@;o000000Gof]SEo`000?oKfMKofmWFo`000002om_KeP04o`000?oMg=Ko
gMcFomgLeP;o000000?ohMkBo`000?oQgm800_l00002onCRd@?o00000ooWiLl01_l0003ojNO=o`00
0?oYjLko0000onk[a`;o000000?olNg2o`000?l000000_ockk`9o`0000Sooo]Z00?o0000oookJ_oo
nfX0??oonfX00ol0003ooo]ZoookJP0JoookJP00IOoonfX2o`000>_ooo]Z00?o0000ooO3U?l00000
0_l00002ooS=W`;o00000_oie:802_l0003onMNUo`000?oifZSo0000oo[MZ?l0003onMn[o`000?oi
hJh2o`0000;on>Na1?l000000ooekKOo0000o`000002o`000003oo7c__l0003ol??100?o00000_oZ
m/`4o`000004on?he?l0003o0000om[lf@?o00001?o<cM/00ol0003oc<kKolc>f`02olc>f`05o`00
0?o=cm_o0000om3@fOl000000oo@dMX2o`0000;od];I0ol000001_oDdmSo0000omCDf?l0003oe]GH
o`0000?oeMKI00Go0000omOHf?l0003of=SGo`000002om_IeP;o000000?ofm_Fo`000?oMg=H00_oM
g=H2o`000005omoNe?l0003o0000on7Od_l000000_oTh]400ol0003oiN?Ao`000003onOUc`?o0000
0_oYjLh5o`000003oo7^`_l0003olnnl00Wo00002OoonfX00ol0003ooo]ZoookJP0moookJP03o`00
0?oonf[ooo]Z01Wooo]Z001RoookJP?o0000k?oonfX00ol0003on<6<o`000002ooW6T`05o`000?oh
cIoo0000ooW@Wol000000_oie:82o`000004oo[JYOl0003on]fXoo[MZ0;o000000Gon^>/o`000?oi
iJko0000ooSW/@04o`000003ooG]]ol0003o000000;o00000_oalkh3o`000003oncga_l0003oj_K<
00;o000000?ohOc@o`000?oSn=@00_l000000ooJo=Wo0000o`000002o`0000?oc<gK00?o0000olc>
foo<c]/00_o<c]/00oo<cmco0000olg?f`02o`0000?od=7J00?o0000om7Bf_l000000ol00002om;C
fP05o`000?oDe=Soe=CHomCDf?l000000ooEe]T01?l0003oemSHomOHf?oGf=P2o`000005om_Ie_l0
003ofm[Fom_Je_l000000ooMg=H00ol0003ogMkFomgNeP02o`000005on3Oe?l0003o0000onCRdOl0
00000_oUhm401_l0003oinG?onOUcol0003oinO?o`0000;ojNW>0ol000000oo]kLWo0000oo7^`P03
o`000003oo?a^ol0003omO:b00Ko00002_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[o
oo]Z01Wooo]Z001OoookJP?o0000kooonfX01Ol0003on<6<o`000?l0003onLJC00;o00000_oid9l0
2?l0003onMBRo`000?ojf:?o0000oo[JYOl0003on]fX0_l00002oo[S[0;o000000Oon>^ao`000?l0
003o0000ooO/]?l0003omNfg00;o000000?olo:ko`000?oalkh00_l000000ooZn/Co0000o`000003
o`0000;ohOc@0ol000000ooJo=Wo0000o`000002olS=g@;o000000?oc<gKo`000?o<c]/00_o<c]/0
1Ol0003oc<oLolc?g?o<cmco000000;oc]3L00?o0000om3Af_l000000_l00002om7BfP07o`000?oB
dm[od]?Jo`000?oBe=[o0000omCDf002o`0000;oeMKI00So0000omOHf?oGf=SoemSHomOIfOl0003o
fMWHo`0000?ofm[F00Co0000omgLe_oMg=Ko00000ooMg]H01?l0003oh=oDo`000?oPhMD2o`0000;o
iN?A00Co0000onGTdOl0003o00000_oWill01Ol0003ojNW>o`000?oZjlgo000000;okNg91?l00000
0ooclK_o0000o`000002o`000003ooCbY_l0003o000000;o00002ooonfX00ol0003ooo]ZoookJP0l
oookJP03o`000?oonf[ooo]Z01Sooo]Z001LoookJP?o0000l_oonfX01_l0003on<6<o`000?oj`h_o
0000oo[8TP?o000000Konm>No`000?ojf:?on]RSo`000?ojfZD4o`000007oo[S[?l0003o0000o`00
0?ohjk7o0000ooS[/P02o`000003ooCb]ol0003ol_Bj00Go000000Soj_[4o`000?l0003oiOc9o`00
0?oSo<go0000on7ld0;o000000Cog?gFo`000?l0003o00001?o8cMd2o`0000?oc<kK00Co0000olc?
g?o<cmcoc<oL0_l000001?o>d=co0000o`000?l00002om7BfP;o000000CodM?Jo`000?oBdm[o0000
0ooBe=X00ol0003oeMKIomGFf@02o`0000;oemSH00Co0000omOIfOoGfMWoemWI0ol000000ooKf]Ko
0000om_Ke`02o`0000?ogMkF0ol00003on3Qe@03o`000?oUhm7o000000;oiNCA00?o0000onOWcooW
ill00ol00002on[[c@04o`000?o]kLWo0000o`0000;ol?342_l0000<oookJP03o`000?oonf[ooo]Z
03gooo]Z00?o0000oookJ_oonfX05ooonfX005Wooo]Z0ol0003eoookJP?o000000?on/>;o`000?oj
b9801Ol000001oojf:?o0000oo_KX_l0003onmjVo`000?ojhZX01?l00002ooS[/@?o00000_odl[L5
o`000005onci`Ol0003o0000o`000?oUo<T01_l000001?oLoMKo0000o`000?l00004olS=g@06olS=
g_l0003obLkMo`000?o<c]_o00000oo<cm`4o`000005olk@g?l0003o0000om7Bf_l000001?oAdmX0
2Ol0003od]CJom;Df_oBe=[o0000om?Efol0003oeMKIo`000002omOHf003o`000?oGfMWoemWI00;o
emWI00Co0000omWJf?oIf]So00000_oKfmL01ol0003ogMkFomgNe_oMg]Ko0000omkOe_l000000ooP
hMD3o`0000?oiNCA00Go0000onOWcol0003oj>S?o`000002on[[c@?o000000?ok>k;o`000?o`l<@0
0ol000000ooalkoo0000o`000002o`000003onkaVOl0003o000000gooo]Z00?o0000oookJ_oonfX0
??oonfX00ol0003ooo]ZoookJP0GoookJP00EooonfX2o`000?Oooo]Z00Go0000ooZmQ?oj_HCo0000
oo[3R`03o`000003ooc:Sol0003onlnF00?o000000?onm^Ro`000?okgZH00_l000001OojiJ[o0000
ooWX[Ol0003on>^a00;o000000Gom_2do`000?odl[Oo0000oo;d^P0Bo`0000?ob<gM00Oo0000olS=
g_o8cMkob<gNo`000?o9c]go000000;oc<oL0ol00003olg@g004o`000?o>dMcoc]7Lo`0000CodM?J
0_l00002om;DfP03o`000?oCeM_odmGK00?o000000?oemSHo`000?oGfMT00_oGfMT02Ol0003of=[I
o`000?oIf]So0000omWKf?l0003ofm_Go`000002omgNeP04o`000?oNgmKog]oFo`0000;oh>7E00?o
0000omoRe_oOh]H00_l000001?oUi=7o0000o`000?l00002onSXc`06o`000?oZjlgo0000on_/c?l0
003ok>k;0ol000000oo_lLKo0000oo7c_`02o`000003oo;e]Ol0003o000000?o00003_oonfX00ol0
003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z01Kooo]Z001DoookJP?o0000nOoonfX00ol0003o
n[f4ooZmQ002o`0000;onlF:00Co0000ooc:Sol0003onlnF0_l000000ooleY[o0000o`00000Io`00
0003onKkbOl0003o000000Co00000oo8cMd00ol0003ob<gNolS=gP03olS=gPGo00000oo=d=`01?l0
003ocM7Lo`000?o>dM`2o`0000?odM?J00?o0000om7DfooAe=/00_l00002om?Ef`03o`000?oCe]_o
dmKK00;o00000ooGfMT01Ol0003of=[IomSJfOoHf]Wo000000;ofM_H0_l000000ooLg=Oo0000o`00
0002omkOeP04o`000?oOh=Ko0000o`0000;ogn;F0_l000001?oSiM?o0000onGUdOl00002onSXc`05
o`000?oXjLoo0000o`000?o[k<`00_l000001?o]klSo0000onoaa_o_lLH2o`000003oo7d_?l0003o
l_Fe00Go00003ooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z01Gooo]Z001Aoook
JP?o0000o?oonfX3o`000004oo^oP_l0003onlF:oo_5RP;o000000?ooLf?o`000?omdI@00ol00000
1Oomf9So0000oogLWOl0003oo=nQ00;o000000?onnFUo`000?ojj:P00ol00002ooO_/0?o000000Oo
lOFio`000?l0003o0000on_i`_l0003ojO[600Ko00000_o4c>000ol0003ob<gMo`000003olS=gPCo
000000?obLkNo`000?l000000_o=d=`2o`0000?ocM7L00Ko0000olkBg?o>d]co0000om7Cf_l00003
om7Df`04o`000?oCeM_odmGKo`0000CodmKK00Co0000omOIfOoGfMWo00000ooHf]T2o`000004omWK
f?l0003of]cIom[Lf@;o00000_oNgmH01?l0003ogn3FomoPe_l00002omoReP05o`000?oQi=Go0000
o`000?oTi]<00_l000001_oXj<oo0000onSYcooXjLoo0000on_/c0?o000000?okNo8o`000?o_lLH0
0_l00002oo7d_0Oo00003ooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z01Gooo]Z
001>oookJP?o0000oooonfX01?l0003on[Qgo`000?ok_h83o`000003oog8R?l0003ooLf?00;o0000
0_one9<01?l0003ooMRHo`000?omg9d2o`000003oocRXOl0003onnFU00?o000000?on>f]o`000?og
kk000_l000000ooclkGo0000o`000002o`0000;ojoW20ol000001OoUo<So0000o`000?o4bn3o0000
00;oa<cP0_l000001?o8cMko0000o`000?l00004olS>gP05o`000?o9cmko0000olg@g?l000000oo=
dM`00ol0003oc];Mo`000003olkBg004o`000?oAe=_odMCKom7Df`;o000000?odmGKo`000?oCe]/0
0ooCe]/4o`0000?of=[I00Co0000omSKfOl0003o00000_oJg=T01Ol0003ofMkJo`000?oNgmKo0000
00;ogn3F0_l000001OoOh]Ko0000on7TeOoQi=Go000000;oi>KC00Go0000on?WeOl0003o0000onSY
c`03o`000003on_]c?l0003okNo800?o000000?ol??3o`000?oam;`00ol000000oo`m:Go0000o`00
0002o`00013ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0DoookJP00BooonfX3
o`000?oooo]Z0ooonfX00ol0003on[Qgo`000002o`000003ooc2P?l0003ooLR800;o000000Koo]2>
o`000?one9?oo]BCo`000?omf9P2o`000003oogNW?l0003oo>:Q00?o000000?on^ZXo`000?ohkJd0
0_l000000ooflJoo0000o`000002o`000003ongh^ol0003ojoW200?o000000?oiOc8o`000?l00000
0oo4bn07o`0000?ob<kN00Ko0000olW?goo9cmoo0000olW?g_l00003olgAg00;o`000?o>d]goc];M
olkBgOl0003oc];Lo`000?o?dmgo0000om7Dfol000000_oBeM/00ol0003odmKKom?Ff`02om?Ff`03
o`000?oCem_odmOK00;o00000_oHf]T01?l0003of=_IomSKfOl00002om[Lf@04o`000?oIg][ofMkJ
omWNfP;o000000Gogn3Fo`000?oOhMKogn7Fo`000002on7Te@;o000000Woi>KCo`000?oSimGohnOE
o`000?oWj]7o0000onSZcol000000_o[kL`2o`000003onkaaol0003ol??300Co000000?olOFao`00
0?l000000ol0000BoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX04ooonfX004So
oo]Z0ol0003ooookJPKooo]Z0ol000000ool^WCo0000ooc2P002o`000004ook;Qol0003oo]2>o`00
00;oo]BC0_l000000oonfiSo0000oogNW003o`000003oo_WY?l0003on^ZX00?o000000Gom_6_o`00
0?l0003o0000onog]`05o`000003omkn`ol0003o000000Coa<_P0ol00002olC<h@04o`000?o8c]ko
b<kNolS>gP;o00001?o9cml01Ol0003ob]3Oo`000?o=dMco000000Goc];M00?o0000oloCgOo?dmd0
0_l00002om;Ef`;o00000ooCe]/02?l0003odmOKom?Gfol0003od]SMo`000?oHf]Wo00000_oHfmT2
o`000003om[LfOl0003ofMkJ00;ofMkJ0_l000001?oMhMSo0000omoQe_oOhMH2o`000005on7TeOl0
003oh^GEon;UeOl000000_oSimD3o`000004onO[dOl0003o0000on_]c0;o00000_o^lLL2o`000003
oo3d`Ol0003olOFk00?o000000CokoBRo`000?l0003o00004_oonfX00ol0003ooo]ZoookJP0loook
JP03o`000?oonf[ooo]Z01?ooo]Z0016oookJP;o0000oooonfX9oookJP06o`000?oj[f?o0000oobj
M?l0003oo<:00_l000000oonbhOo0000ook@SP03o`000003ookGTol0003oo]^H00?o000000?oo>FP
o`000?okij@00_l000000oohkJOo0000o`000002o`000003oo7f/ol0003o000000Oo00000_o4bn03
o`0000;oa<cQ00Oo0000olC<hOl0003oaLgQo`000?o8c]ko000000CobLoO00?o0000olW@gol00000
0_o:d=l01?l0003oc];MolkBgOo>d]d2o`000004olkCgOl0003ocm?Mo`0000;ocmCM0_l00002om;F
f`03o`000?oCe]_o000000;odmOK00?o0000om;HgOoBf=d00ol000001OoHfmWo0000omWLf_oIg=[o
000000?ofMkJ00?o0000om_Of_l000000_l000000ooOhMKo0000omoRe`02o`0000?oh^GE00Go0000
on?WeOl0003oi>WDo`000002onO[d@?o000000?ojnk<o`000?o^lLL00_l00002oo3d`@Wo00004ooo
nfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z01;ooo]Z0013oookJP?o0000oooonfX;
oookJP03o`000?oj[f?o000000?o000000?oo/Ano`000?onbhL00ol000000ooodhgo0000ookGT`03
o`000003oogRVol0003oo>FP00;o000000?on^^So`000?ohkJL00_l000000oobm:oo0000o`000003
o`000005on?l^ol0003o0000o`000?nob^<01?l00005olC<h@05o`000?o5cN7oaLgQolG=hOl00000
1?o9cml01?l0003obM3OolW@goo9d=l2o`000004ol[Agol0003oc];Mo`0000Coc]?M00Ko0000oloD
gOo?e=go0000oloEgOl00003om;Ff`04o`000?oCem_odmOKo`0000;od]SM0_l00002omKKf`03o`00
0?oIg=[ofMcJ00;o00000_oIg]X01?l0003ofmoJom_Of_l00002omgRf0;o000000?ogn;Go`000?oR
iMD00_oRiMD3o`000008onCYe?l0003o0000onO[dOl0003oi^cCo`000?oZklh5o`000003oo3d`Ol0
003o000000Go000000?oinf<o`000?oonfX05?oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oo
nf[ooo]Z017ooo]Z0010oookJP?o0000oooonfX>oookJP?o000000Conk1Oo`000?l0003oo/An0ol0
00000ooocHGo0000oooCS@03o`000003ookNUol0003ooN:K00;o000000?onnROo`000?ojjj<03ol0
00000onob^?o0000o`000003olC<h@;o00000_o4cN401?l0003oaLgQo`000?l00003olW?g`03o`00
0?o9d=oobM3O00;obM3O00?o0000ol[Agoo:dMl00_l00003olkCg@05o`000?o>e=go0000oloDgOl0
00000oo?eMd2o`000004om;Gg?l0003odmOKo`0000;od]SM00?o0000omGJg?oEf]`00ol000001?oI
g=[o0000omWMf_oIgMX2o`0000;ofmoJ0_l000001?oMh]So0000omgSfOoMhmT2o`0000;oh^GE00Ko
0000on;VeOl0003oi>WDo`000?oUj]@2o`000006onK/dol0003o0000on[_c_l0003ojO3?0ol00000
0oo`m<7o0000o`000007o`0001Kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0A
oookJP00?OoonfX3o`000?oooo]Z4_oonfX2o`000003oo^`Gol0003o000000;o000000?oo/Mko`00
0?oocHD00_l000001?ooeX_o0000o`000?ongYL2o`000003oocUVol0003onnRO00So000000?oj?Zc
o`000?l000000ol00003oko:h`06o`000?nobn?o_l_So`000?o4c>7o00001Oo4cN401_l0003oaLkQ
olG>hOl0003obLoOo`0000?obM3O00Go0000olWAgol0003ob]7Oo`000002ol_Bg`03o`000?o>dmgo
000000?oc]CM00Oo0000oloEgOo?eMgocmGMo`000?o@e]ko000000;od]OL00Co0000om;HgOoBf=go
00000ooEf]`01?l0003oemcLomOLg?l00003omWMfP04o`000?oKgm[ofmoJo`0000;og>7I00?o0000
omgSfOoMhmT00_l000001?oOhmOo0000o`000?oRi]D3o`0000;oiN[D00Co0000onK/dol0003oinkA
0_l000000ooYl<oo0000o`00000<o`0001Kooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]Z
oookJP0@oookJP00>_oonfX3o`000?oooo]Z5OoonfX2o`000006oo^`Gol0003o0000oojnK_l0003o
o/Mk0_l000000oood8?o0000oooFR`03o`000003oogRU_l0003oo>FK00?o000000?on>jSo`000?l0
00000_l000000oo[n:oo0000o`000003o`0000?o_l[S0_l00003oko;h`;o00000oo4cN42o`000004
olC>hOl0003oaLkQolG>h@;o00000oo9d=l01Ol0003obM7OolWAgoo9dMoo000000Cobm;O00Ko0000
olkDgOo>e=go0000oloEg_l00002oloEg@03o`000?o@e]kod=KN00;o000000CodmSLo`000?oBf=go
00000ooEf]`01ooEfmco0000omOLg?l0003oemgLo`000?oIgMX00_l000001?oKgm[o0000omcQfOoL
hMT2o`000004omgSfOl0003og^CIomkTf@;o000000Coh^KEo`000?oRimKo00000ooUj]@2o`0000;o
inkA00?o0000onW`col000000_l000000oo[m<_o0000onkf``02o`000003onkh^_l0003o000000?o
00006?oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z00oooo]Z000hoookJP;o0000
oooonfXHoookJPGo000000coo[i^o`000?l0003oolUio`000?ood8?o0000oooFRol0003oo]f@o`00
0?omhYH3o`000003ooW/W_l0003on>jS00;o000000?okON[o`000?l000000_l00002okO8i`;o0000
0_nob^<4oko;h`06o`000?nobnCo_l_To`000?o4cN7o00001?o4c^42o`0000;oaLoR00?o0000olW@
gol000000oo9dMl2o`0000?obm;O0_l000000oo>e=go0000oloEgP02oloEgP;o00000_o@e]h01_l0
003od=ONom3Gg_l0003odmSLo`0000?oeM[L0ooEfm`01?l0003oemgLomOMg?oGgM`2o`000006omWN
f_l0003og>7IomcQfOl0003og>;J0_l00002omkTf@03o`000?oMiM[o000000;o000000Coh^OFo`00
0?oUj]CoiN[D0_l00003onO^d@;o000000?oj_;>o`000?o[m</00ol000000oo]mlCo0000o`000002
o`000003onSeXOl0003o000001Wooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0?
oookJP00=OoonfX3o`000?oooo]Z6ooonfX7o`000003ooo9NOl0003oom2300?o000000Goo]f@o`00
0?l0003o0000oo_XVP09o`0000Go]lSW0_l00003oko;h`;o00000onobn@2o`0000Goa<kQ00Co0000
olG?h_o5cn;oaLoR0_l00003olWAg`06o`000?o:dN3ob]7Po`000?o;d]oo00000_o;dn000ol0003o
cmGNoloEgP02oloEgP04o`000?o@e]kod=KNo`0000?od=ON0ol00002omGJg0?oeM_L0_l00002omOM
g003o`000?oGg]co000000;o000000Gog>7Io`000?oLh][og>;Jo`000002omkTf@04o`000?oMiM[o
gNGJo`0000;ohNSH00Ko0000on;Xe_l0003o0000onG/dol00002onO^d@;o00000_oZl/h2o`000004
oncebOl0003okOO4ongga0;o000000?ok?R`o`000?l000000_l0000IoookJP03o`000?oonf[ooo]Z
03cooo]Z00?o0000oookJ_oonfX03_oonfX003;ooo]Z0ol0003ooookJQkooo]Z1?l000001?ok/UKo
0000o`000?oobGT2o`000005oooCPOl0003o0000o`000?omhHh00_l000000ookj9[o0000o`000002
o`000004ooGaX_l0003o0000o`0000Co]lSW00?o0000okO8iongb>L00_l00002oko;h`?o_l_T0_l0
0002oko<i007o`000?o4c^7o0000o`000?o5c^;o0000olG?hP02o`0000;oa]3R00?o0000olWAgol0
00001?o:dN003?l0003obm?Pol_Ch?l0003oc=CPo`000?o?eMko0000oloFg_l0003od=KNo`0000?o
d=ON00Go0000oloHh?l0003o0000omGJg003omGKg003o`000?oFg=coe]cL00;o000000?oemkLo`00
0?oFgmh00ol00002omcRfP;o000000Cog^CIo`000?oMiM[ogNGJ0_l000000ooQj=So0000on7Yf002
o`000003onG/dol0003oiNgD00;o000000?oj>o@o`000?oZl/h00_l00002onceb@04o`000?o]mlCo
0000ongi_0Ko00006_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z00gooo]Z000_
oookJP?o0000oooonfXQoookJPCo000000_onk9Fo`000?l0003o0000ooo<M_l0003oom>1o`000?on
g8Oo0000oogQSP09o`0000Co]lSW00?o0000okO8iongb>L00ongb>L2o`0000?o_l_T00?o0000oko<
i?noc>@00_noc>@2o`0000CoaLkR00?o0000olK@h_o6d>800_o6d>82o`0000;ob]7P0_l000001?o:
d^3o0000ol_Ch?l00003olcDh005o`000?o?e]kocmKNoloFg_l000000oo@emh01Ol0003ocmSPoloH
h?o?f>3o000000?oeM_L00Oo0000omKLg?oFg=coe]cLo`000?oGg]co000000?oe]oN0_l000001OoL
h][o0000omcSf_oLhm[o000000;ogNGJ00Co0000omoWfOl0003o00000_oQjMP3o`000004onG]e?l0
003o0000onS_d0?o000000?oj_?=o`000?o/mLT02ol0000KoookJP03o`000?oonf[ooo]Z03_ooo]Z
00?o0000oookJ_oonfX03OoonfX002cooo]Z0ol0003ooookJRGooo]Z1ol000001Oooc7Ko0000o`00
0?l0003oo]b700?o000000?onNVCo`000?l000000_l00003oj_4k004o`000?ngb>Oo0000o`0000Co
]lSW00Co0000okO9j?l0003o00000_nobn@01?l0003o_lcToko<i?noc>@2o`000005ol3<i?l0003o
aLkRolG>h_l000000_o5cn802?l0003oa]3Ro`000?l0003oa]3Ro`000?o:dN3o00001?o:d^002?l0
003oc=CPolcDh?o<e>3o0000olcEh?l0003ocmKN0_l00002om3GgP05o`000?o?f>3ocmSPoloHh?oB
f]l00_l000000ooEfmco0000omKLg002omKLg003omKMgOl0003o000000?oe]oN0_l000001?oJh]co
0000omcSf_oLhmX2o`000005omgUf_l0003ognOIomoWfOl000000_oQjMP00ol0003oh>[Io`000005
o`000003onSadOl0003oj_?=00?o000000?ok?K8o`000?l000000ol000001?o[n:_o0000o`000?l0
000MoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX03?oonfX002[ooo]Z0_l0003o
oookJRWooo]Z1ol000000ooncW7o0000o`000005o`0000SoZlC/00Co0000okO8iongb>Oo]lSW0_l0
0004okO9j0;o00001?noc>@00ol0003o`<cTol3<i002ol3<i0;o00001?o5cn801?l0003oa]3RolK@
h_o6d>82o`0000?ob];P00?o0000ol_Ch?l000000_o<e>000ol0003oc=GPolcEh002o`0000;ocmON
0_l00002oloHh004o`000?oBf]ood][Oom;Jg`;o00000_oFg=`01?l0003oe]gMomKMgOl00003omKO
gP03o`000?oHhMgof>7M00;o000000?og>?Jo`000?oLi=X00_l00002omoWf@;o000000[ohNWHo`00
0?oPj]Woh>[Io`000?oTkMKo0000on?^eol0003oj?7A0ol000001?oZm<go0000oncfb?o/m/P3o`00
0003onci]ol0003o000000?o00007OoonfX00ol0003ooo]ZoookJP0joookJP?o00003OoonfX002Oo
oo]Z0ol0003ooookJR_ooo]Z0_l00002obAji@Oo00000_n?^?800ol0003oZlC/oj_4k003oj_4k0?o
000000?oZlC/o`000?ngb>L00_l00007okO9j0;o00000_noc>@00ol0003o`<cTol3<i002ol3<i0;o
00000oo5cn800ol0003oaM3Ro`000002olK@hP06o`000?o6dN;oa]7Ro`000?o:d^3o00000oo;dn02
o`0000;oc=GP00Ko0000olcFhOo<e^7o0000oloGg_l00002oloHh004o`000?oBf]ood][Oom;Jg`;o
00000_oCg=l00ol0003oe]gMomKMg@02o`0000;oe]oN00Ko0000omSQgOoHhMgof>7Mo`000?oJhm`2
o`000006omcTf_l0003ognOIomoWfOl0003ognSI0_l00002on3Zf@03on;/f?l0003o000000;ohnkG
1ol000001?o/m/So0000o`000?o/nKl6o`0001oooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0000;o
oo]Z00?o0000oookJ_oonfX02ooonfX002Cooo]Z0ol0000EoookJPco0000oooonfX>oookJPOo0000
1_n?^?800ol0003oZlC/o`000002o`0000GoZlC/00?o0000okO9j?ngbNP00ongbNP3o`000004okO9
j?l0003o_lcTo`0000Co`<cT0_l00002ol;>h`03o`000?o5cn;o000000?oaM3R0_l00003olKAhP;o
00001?o;dn001?l0003oc=GPolcEh?l00003olcFh@?o000000?ocmSPo`000?oBf]l00_oBf]l00ol0
003od]_Oom;Kg`03o`000004omKMgOl0003oe]kMomKNg@;o00000ooHhMd00ooIh]go0000o`000002
om_Tg0;o000000OognOIo`000?oOj=WognSIo`000?oPj]Wo000000;oh^cH00?o0000on?^eooSk]L0
0_l00002onKbd`[o000000Coj?NWo`000?l0003o00008?oonfX00ol0003ooo]ZoookJP0boookJP?o
00001OoonfX00ol0003ooo]ZoookJP0;oookJP008OoonfX3o`0001?ooo]Z1Ol00003ohbelP03o`00
0?md[?CoM:cd00;oM:cd00CoMjgdo`000?mGW_?oEikc1Ol0003ooookJPOooo]Z1ol000000omIW?;o
0000ohnhlP06ohnhlP03o`000?n[a>coZlC/00;oZlC/0ol00002oj_4k003o`000?ngbNSo000000;o
00001OngbNP2o`0000?o`<cT00?o0000ol;>hoo2c^<00_o2c^<2o`0000CoaM3R00?o0000olKAh_o6
dN800_l00002olOBhP07o`000?o;dn3o0000ol_DhOl0003oc=GPo`000003olcFh@05o`000?o=en7o
0000om3Hgol000000ooBf]l01Ol0003od]_Oom;KgooBfmoo000000;odmgO00Go0000omKNgOoFg]go
e]kMo`000002omSQg@04o`000?oIh]go0000o`0000;ofnCL00Co0000om[UgOl0003o00000_oOj=T3
o`0000;oh^cH0_l000000ooSk]Oo0000o`000002onKbd`?o000000?oj?K>o`000?l000001_l00000
0ooMlYOo0000o`00000PoookJP03o`000?oonf[ooo]Z02oooo]Z0ol00008oookJP03o`000?oonf[o
oo]Z00_ooo]Z000NoookJP?o00004ooonfX3o`0000;oWkc]00?o0000oh^el_l000000_n<]O86o`00
0003ogB/m?l0003o000000;o000000CoEikcoe^Pm?l0003o<h[]0_l0003ooookJP;ooo]Z0ol00003
oookJP04o`000?l0<[So0000obUki@Ko00001?n@^?801?l0003oZlC/o`000?l00006oj_4k003o`00
0?ngbNSo]lWX00?o]lWX0_l00002okS:j004oko<i?l0003o`<cTo`0000?o`/kS0_l00002ol7?i@07
o`000?o5d>;o0000olKAh_l0003oa]7Ro`000004olOBhP;o00000oo;e>400ol0003oc=KQolcFh@02
o`0000;ocMOQ0ol00002om;Jg`08o`000?oBfmood]_Oom;KgooBg=oo0000om?Mgol00002omCNg`0;
o`000?oGgmgo0000omSQgOl0003ofN;Mo`000?oIhmgo0000om_Tg?l000000ooJiMd01Ol0003ognSI
o`000?oOjMWo000000;oh^cH00_o0000on;]f?l0003o0000onC`e_l0003oi_;Co`000?oUlmCo0000
onSfcP04o`000003on[j`?l0003o000000Co00008_oonfX00ol0003ooo]ZoookJP0[oookJP?o0000
2ooonfX00ol0003ooo]ZoookJP0;oookJP006ooonfX3o`0001?ooo]Z0ol00006oinlk@Co00000on<
]_800ol0003oLjceog>/m@03og>/m@03o`000?mFW_CoEYkd00Co000000Co<h[]o`000?l0003o0000
nooonfX3o`0000Oooo]Z0_l000001Ol`O>Ko0000o`000?mLW?;o000000OoT;Sb00?o0000oj_4k?n[
a>`00_n[a>`3o`000003ojc5k?l0003o]lWX00?o]lWX00?o0000okS:j?nhb^P00onhb^P00ol0003o
`/kSol;>h`02ol;>h`03o`000?o1cnGo`LoU00?o`LoU00Go0000olKAh_o6dN;oa]7Ro`000004olOB
hP05o`000?o7dn?oam?So`000?o;e>400_l00002olcFh@?ocMOQ00Ko0000olkHhOo>f>7o0000om;J
gol00002om;Kg`03o`000?oBg=ood]cO00;o00000_oDg]l00ol0003oe=oOomOOg@02o`000004omWR
gOl0003ofN?MomWSg@;o00000ooJiMd02?oKimgo0000o`000?l0003ognWIo`000?oRk=So00000_oR
kMP00ol0003oi?3Fo`000002o`0000;oiO?D1?l000001OoXnL[o0000o`000?l0003oio^g00Co0000
8ooonfX00ol0003ooo]ZoookJP0VoookJPCo00003ooonfX00ol0003ooo]ZoookJP0:oookJP006Ooo
nfX2o`0001?ooo]Z0ol00002ok30i@03o`000?nO_>goWkc]00?o00000_nO_>d01?l0003oRkGboh^e
l_l00002ohbflPKo000000SoLjceo`000?l0003o0000oeJNm?mKXOCo0000oc6:k@;o000000Co2FoN
o`000?l0003o0000mOoonfX3o`0000_ooo]Z0_l00002oc1liPKo00001?nA^O801?l0003oZlC/o`00
0?l00005ojc5k004o`000?ngbNSo0000o`0000Co^<[X00Co0000okS:ionhb^Oo00000_o2c^<00ol0
003o`LoUol7?i@02ol7?i@05o`000?o1d>Go`M3Uo`000?o6dN800_l00002olOBhP;o00000oo7dn<2
o`0000;oc=GQ00Go0000olgGhOo=en7ocMOQo`000004olkHh@;o000000?od]_Oo`000?oBg=l00_oB
g=l01?l0003oe=kOomCNgol00002omCOg`;o000000?ofN;Mo`000?oIhmd00_oIhmd01?l0003of^GM
o`000?l00002om_Wg@03o`000?oNjM_og^WK00?o00000_oRkMP3o`000004onGaeOl0003oiO?DonGc
e0;o000000?oioO@o`000?oXnLX00_l000001OoXnl;o0000onOk]ol0003of_2B00;o00009?oonfX0
0ol0003ooo]ZoookJP0RoookJP?o00004ooonfX00ol0003ooo]ZoookJP0:oookJP005_oonfX3o`00
01?ooo]Z0_l00006ok30i@;o00001_nO_>d5o`0000;oSKOb00?o0000og>]m_mc[OH00omc[OH00ol0
003oEIodoeFOm004o`000005oc6:kOl0003o0000o`000?lAMN800_l0003`oookJP?o00003_oonfX0
0ol0?<3o0000ocQniP04o`0000CoTKWb00Go0000oi6il_nA^O;oTKWbo`000008ojc5k003o`000?nh
b^So^<[X00;o^<[X00?o0000okS:ionhb^L00onhb^L00ol0003o`LoUol7?i@02ol7?i@03o`000?o1
d>Go`M3U00?o`M3U00Go0000olKAhoo6dN?o0000olOBhP03olOCh`;o000000Gob=?So`000?l0003o
c=KQo`000002olgGh@03o`000?o>f>7oc]SQ00;oc]SQ00Coc]WRo`000?l0003o00000_oBg=l01Ol0
003odmgPo`000?oDg]oo000000;oe=oO00Co0000om?PhOl0003o00000ooIhmd3o`0000?ofnOM0_l0
00000ooNjM_o0000omkZf`02o`000004on;]f?l0003o0000o`0000;oiO7E00Co0000onGce?l0003o
00000_oWmm03o`0000;oj?_21Ol0000UoookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000FoookJP03
o`000?oonf[ooo]Z00[ooo]Z000CoookJP?o00005OoonfX00ol0003o_/;Mo`000002ok30i@?o0000
0on``>D3o`0000CoX;c]00Co0000oh^fl_n;]_;oRkKb2?l000001?mc[OKo0000o`000?l00002oeFO
m005o`000?l_Rngo0000o`000?l5Kmd01?l0003/oookJP?o00004_oonfX00ol0?<3o0000ocQniP02
ocQniPGo00001OnB^O800ol0003o[<G/ojc5k003o`0000?o[<G/00Co0000okS:j?l0003o00001?nh
b^L01Ol0003o^L_Wo`000?l0003o`LoU00;o00001?o1d>D01_l0003o`]3Uol;@iOl0003oa]7So`00
00?oam?S00Co0000olSChoo8dn?ob=?S0_o;e^801?l0003oc=KQo`000?o=en43olkHh@08o`000?o>
fN;oc]WRo`000?o?fn;o0000om;Lgol00003om?Mh004o`000?oDgmooe=oOo`0000?odn3Q0_l00000
1?oIhmgo0000omWTgOl00003om_Wg@04o`000?oLj=go0000o`0000;og^[K00Go0000on3^f_l0003o
h^kHo`000002onGae@?o000000?oioGAo`000?oWmm000_l000000ooXn/Oo0000onSk`P06o`0002Ko
oo]Z00?o0000oookJ_oonfX06ooonfX3o`0001Wooo]Z00?o0000oookJ_oonfX02_oonfX0013ooo]Z
0ol0000FoookJP?o000000Co_/;Mo`000?l0003o00000on``>D2o`0000;o/L3U00?o0000oj2lkOnP
_>d01?nP_>d2o`0000;oRkKc00Co0000ohfgl_n=]o;o00001Omc[_H00ol0003oCY_codjKl`04o`00
0005obn;kOl0003o0000o`000?l>MN401?l0003VoookJP?o00005_oonfX01?l0003o>7kVocQni_lh
O^H2o`0000WoT[Wb0_l00007ojc5k003o`000?nhb^Oo^<[W00;o^<[W00?o0000okW;ionibnL00_ni
bnL2o`0000Co`M3U00?o0000ol;@iOo2d>D00oo2d>D2o`0000;oam?S00Co0000olSChoo8dn?ob=?S
0oo;e^83o`0000;oc]SQ00Ko0000olkIh_o>fN;oc]WRoloJh_l00002oloKhP08o`000?oCgN3odmgP
o`000?oCg^3o0000omCOgol00003om?Ph@03omKRh?l0003oen?O00;o000000GofNCMo`000?oKimgo
fnOMo`000002omcXg@03o`000?oNj]_og^[K00?o000000Soh>oJo`000?l0003oiO7Eo`000?oTl]Go
0000onOed@?o000000?oj?W<o`000?l000001ol0000XoookJP03o`000?oonf[ooo]Z01Oooo]Z0ol0
000LoookJP03o`000?oonf[ooo]Z00[ooo]Z000=oookJP?o00005ooonfX2o`0000?o`L;K00Go0000
okk2gOnn`]go0000ok30i@02o`0000Go/L3U0ol00004oj2mk@04o`000?n;]_?oRkKcoh^fl`So0000
00?oLjkfo`000?m>Vo<00om>Vo<00ol0003o9hK[o`000008o`000>;ooo]Z0ol0000IoookJPGo0000
00CoI9oao`000?nB^O;oT[Wb1?l00002oiBjl@03o`000?n/aNco[<G/00;o[<G/0ol00002ojg6k004
o`000?nhb^Oo0000o`0000Go^L_W00Co0000ok[=j?l0003o`M3U0_l00004ol;@i@05o`000?o2dNKo
0000olOBhol000001?o8dn<3ol_FhP06o`000?o9e^CobMKTo`000?o>f>7o00000_o>fN801?l0003o
cm[RoloJh_o?f^82o`0000;od=cR00?o0000om?Nh?oCg^000_l00002om?Ph@03o`000?oFh^3oe^;P
00;o000000CoenCOo`000?l0003of^GN0_l00002omcXg@;o000000Oog^[Ko`000?oMk=go0000on3_
f_l0003ognoK00Ko000000?oi_KAo`000?oXnL`00_l000000ooXnlGo0000o`000005o`0002Sooo]Z
00?o0000oookJ_oonfX04ooonfX4o`0001oooo]Z00?o0000oookJ_oonfX02_oonfX000cooo]Z0_l0
000HoookJP05o`000?o1`]_o`L;Kol72fol000000_o1`]/01?l0003o_/;Mo`000?l00004ok70i@;o
00000_na`>D00ol0003oX;g]oj2mk@04oj2mk@;o00000_n<]o<01?l0003oS[Scohjhlol00005ogB_
mP03o`000?mGX_KoEj;f00Ko000000?o=Y3_o`000?l<MN401?l0003NoookJP?o00007OoonfX01?l0
003oB8CWodR4iom8Q>L4o`0000OoU;[a1?l00006ojg6k004o`000?nibnOo^L_WokW;i`?o000000?o
^/_Wo`000?njcNP00_l00003ol;@i@;o00001?o2dNH2o`0000?ob=?S0_o;e^82o`0000?obMKT0_l0
0002olkIhP03o`000?o?f^;ocm[R00;ocm[R00So0000om3Lh_o@g>;o0000om3Mh_l0003odmkPo`00
00;odn3Q00Oo0000omKRh?oFh^3oe^;Po`000?oGi=oo000000;of>GO0_l00002omcXg@05o`000?oL
jMgo0000o`000?oMk=d00ol00002omo_f`06o`000?oSlmOo0000on;cf?l0003oi_KA1?l000001ooX
nlGo0000o`000?l0003ohoZ`o`000?oNmZ000_l0000YoookJP03o`000?oonf[ooo]Z00oooo]Z0ol0
000SoookJP03o`000?oonf[ooo]Z00[ooo]Z000<oookJP03o`000?oonf[o000001Kooo]Z00Go0000
olc3d_l0003o`L;Ko`000004ol72f`05o`000?nn`]go_/;Mo`000?na`>D00_l00005ok70i@?o0000
1?nQ_Nd01?l0003oS;Ocohbglon<]o<8o`000003ogB_m_l0003o000000;o000000CoEj;fo`000?l`
SNko<8g^2?l0003IoookJPCo00008?oonfX2o`000006od>5j?m8Q>OoB8CWo`000?mYX_7o00001onD
^_400ol0003o[LK/ojg6k003ojg6k0?o000000?o[/O/o`000?nibnL00_l00005ok[;i`04o`000?nk
cNSo0000ol;@i@;o00001?o2dNH01_l0003o`m;Vol?Bi_o7dn?o0000olSCh`;obmKR00?o0000olWF
i?o9e^@00oo9e^@2o`000003olkIh_l0003ocm[R00;ocm[R00Go0000oloKh_l0003od=cRo`000002
om3MhP?o000000?odn3Qo`000?oFh^000_oFh^000ooFhn3o0000o`000002omSUg`06o`000?oGi^7o
0000omcXgOl0003og>WM0_l000001?oMk=go0000omo^fol00002omo_f`?o000000?oh_?Ho`000?l0
00003Ol0000[oookJP03o`000?oonf[ooo]Z00_ooo]Z0ol0000VoookJP03o`000?oonf[ooo]Z00[o
oo]Z000<oookJP04o`000?oonf[ooo]Zo`0001Cooo]Z00Go0000olc3d_o<`m;oc<?Bo`000003ol72
f`05o`000?o1`M[o`L7Jo`000?nn`]d00_l00004ok70i@;o00000_na`>D00ol0003oXKg]oj6mk@04
oj6mk@;o00000on=^?<00ol0003oSkWco`000005ogF`m`;o000000GoF:Cfo`000?l0003o0000oc2=
kP02o`000003ocJAl?l0003o000000Go0000e?oonfX3o`0002Gooo]Z0_l00003od>5j0Ko00001?nG
^o400ol0003o[LK/o`000002o`0000Go[/O/00?o0000ok[;ionjbnL00_njbnL2o`000005ok_<iol0
003o^lgXok_=j?l000001?o2dNH00ol0003o`m;Vol?BiP03ol?BiP;o00000_o;e^84olWFi005o`00
0?o:enCo0000ol_Ii?l000000_o?f^801?l0003ocm_RoloKh_o?fn82o`0000;od=gR00Go0000om7N
h_l0003odmoPo`000002omKRh004o`000?oFhn3oe^?Po`0000;of>GO00?o0000omOVhOoGi^400_l0
00000ooLjMgo0000omcZg@02o`0000;ognkK00Ko0000omo_fol0003ohO;Io`000?oRlmP3o`000003
on?ge?l0003oiO[>00Oo000000?of?JQo`000?oonfX0;?oonfX00ol0003ooo]ZoookJP07oookJP?o
0000:OoonfX00ol0003ooo]ZoookJP0:oookJP003?oonfX01Ol0003ooo]ZoookJ_oonf[o0000017o
oo]Z0_l00003olc3dP05o`000?o<`]7o0000ol72fol000001?o1`MX01Ol0003o_/7Lokk1g?l0003o
/L3U00;o00001Ona`>D3o`0000CoXKg]00?o0000ohfhlon=^?<00_n=^?<7o`000003ogF`mol0003o
000000oo0000d?oonfX3o`0002Sooo]Z1_l00002ofnTl@03o`000?nG^o7oUk_a00GoUk_a00?o0000
ojk7k?n^an`00_n^an`3o`0000;o[lS/00Co0000ok[;iol0003o00001?nkc>L2o`000003ok_>j?l0
003o`]7V00;o00001?o3d^H01Ol0003o`m;Uo`000?o4e>Ko000000?obMKT0_l00003ol[Gi004o`00
0?o;fNCobmWTo`0000Cocm_R00Co0000om3Mh_l0003o00000_oAg^83o`000004omKRh?l0003oe^?P
omKSh0;o000000?of>GOo`000?oGi^400_oGi^401_l0003of^WOo`000?l0003og>[Mo`0000;ognkK
0ol00002on7bf@;o000000Coh_GGo`000?oSmmCohoOD0_l000000ooTnloo0000onClb002o`000004
omok/Ol0003o0000o`0002gooo]Z00?o0000oookJ_oonfX01?oonfX3o`0002gooo]Z00?o0000oook
J_oonfX02OoonfX000cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0=oookJP06
o`000?o@`lgod<?=o`000?o<`m;o00000oo<`]401Ol0003o`L7Jol71f_o1`M[o000000;o`L7I00Co
0000okk1g?l0003o00001?na`>D2o`0000;o//3U00?o0000oj6mkOnQ_Nd01?nQ_Nd2o`0000?oS[Sc
00?o0000oi2jlol000001_mf/OL00ol0003oFJGgoeVUm`02oeVUm`?o000000?o=Y?ao`000?l0L=`0
1Ol0003<oookJP?o0000:ooonfX3o`0000;oCh_Y2?l00004oiVml@04o`000?n^anco0000o`0000Ko
[lS/00?o0000ok_<ionkc>L01?nkc>L00ol0003o^lkXok_>j002o`0000Co`m;V00?o0000ol?BiOo3
d^D00_o3d^D01Ol0003oa=GVo`000?o9e^Co000000?ob]OT00co0000ol[Hi?l0003obmWTo`000?o<
f^Co0000oloKh_l0003ocmcRo`000?o@gN83om7NhP03o`000?oBh>;od^3R00?o000000Goe^?Po`00
0?oFi>3o0000omSUg`03omOVh@04omWXh?l0003o0000om[Zg`?o000000CognkKo`000?oOk]co0000
0_oQl]T2o`0000;oh_GG00Go0000on?ge?l0003o0000onCkc`03o`000003on;m__l0003o000000?o
0000;_oonfX00ol0003ooo]Zo`000003o`00033ooo]Z00?o0000oookJ_oonfX02OoonfX000_ooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0;oookJP04o`000?o@`lgod<?=om33c@;o
00000oo<`]401Ol0003obl;Ao`000?o1`M[o000000Co`L7I0_l000000onn`Mco0000ok70i@02o`00
00Go//3U0ol00006oj:nk@03o`000?n>^??oS[Sc00Go00001?mg/_L7o`000003oc>@kol0003o0000
00Ko0000b?oonfX3o`0002kooo]Z1?l00002odn;j@04o`000?meYo7oMJOao`0000SoVKga00?o0000
ojo8k?n_b>`00_n_b>`3o`0000;o/LW/00?o0000ok_<iol000000_l000001?nlcNOo0000ok_>j?l0
0002okc?j004o`000?o3d^Ko0000o`0000?o`m;U00Co0000olCCi_l0003oa=GV0_l00002ol[Gi0;o
00000_o:f>@2o`0000;oc=[T0_l00002oloLhP05o`000?oAg^;odMkRom7Nh_l000000ooBh>801?l0
003odn?Rom?Sh_l00002omKTh005o`000?oGi^7oenKQo`000?oIj>000_l000000ooJj]oo0000omW[
h003o`000004omo^g?l0003o0000on7bf@;o00000_oRmML3o`000003onCidol0003o000000So0000
;_oonfX3o`0003Cooo]Z00?o0000oookJ_oonfX02OoonfX000_ooo]Z00?o0000oookJ_oonfX01Ooo
nfX00ol0003ooo]ZoookJP09oookJP05o`000?o@`lgod<?=om33cOl000000_o@`/`00ol0003oc<;A
o`000003ol_2d@05o`000?o1`MWo`L7Iol71fOl000000oo1`=T00ol0003o_/7Lo`000004ok;0i@;o
00000onc`>@00ol0003oX[k]oj:nk@03o`0000;oXkk/00Co0000ohnilon?^O?oSkWc0_nB^o<3o`00
00?oMk;g1_l000001Ol_Snoo0000ocJElOl0003o07;L00Ko0000`ooonfX3o`0003;ooo]Z1Ol00000
1Om?RnWo0000ogFWlOmeYo7o000000;oVKga0ol00003oibnl004o`000?n_b>co0000o`0000Ko/LW/
00?o0000okc=ionlcNL00onlcNL01?l0003o_<oXokc?j?nlcnP2o`0000?o`m;U0_l00002olCCiP;o
000000CoaMKVo`000?o:enCo00001?o:f>@01ol0003oc=[TolcJi?l0003oc=_To`000?o?g>800_l0
0002om7NhP07o`000?oBh>;od^3Rom;Ph_oBhN?o0000om?ShP02o`000005omKTh?l0003o0000omOV
hOl000000_oIj>000ol0003of^[Oo`000002omW[h003o`000?oMkmgogNoM00Ko000000Goh_GGo`00
0?oRmmKo0000onCid`02o`000003onClbol0003o000000;o000000Cog?Z/o`000?l0003o0000:ooo
nfX3o`0000;ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP09oookJP002ooonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Sooo]Z0_l000000oo@`lgo0000om32c003
om32c009o`000?o;`]7obl;Aol_2dOl0003obl7Ao`000?o1`MWo000000Go`L3I00Co0000okk1g?l0
003o//3U0_l00006ok?0i0;o00001_nS_^`5o`0000;oU;_b00?o0000ogRcn?mh/oP00_mh/oP01?l0
003oF:Ggo`000?mMZOP7o`000003o`1bg?l0003o000000?o0000_ooonfX3o`0003Gooo]Z00?o0023
o`000?l000000_mLTNX7o`0000OoW;k`00?o0000ok79k?nabN`00_nabN`3o`0000;o//[/00Oo0000
okc=iol0003o0000okg>iol0003o_<oX00;o00000_nmd>P00ol0003o`m;Uo`000004olCCiP03o`00
0?o5e^KoaMKV00;o00000oo:f>@01Ol0003obmWTo`000?o<f^Co000000;oc=_T0_l00002om3Mh`05
o`000?oAg^;od^3Rom;Ph_l000000_oBhN<2o`000004omCSh_l0003o0000omKUh@;o00000_oIj>00
0ooIjN3o0000o`000002omW[h0;o000000?ogNoMo`000?oLkml01_l000000ooRmmKo0000o`000002
o`0000;oi?c;0_l000000ooPo;So0000o`000002o`0002Wooo]Z0ol00006oookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX02OoonfX000_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP07oookJPCo00000oo@`/`01Ol0003od<7<o`000?o;`]7o000000?obl7A00Co0000
ol70fOo1`=Wo`L3I0_l00002ol;0f003o`000?nn`Mco000000Co/l3T0ol00002ok?0i003o`000?nS
_^coXkk/00?o00000_nU_^`00ol0003oTK[coi6jl`02oi6jl`Ko000000?oN;?ho`000?l000001?l0
00000olaT_3o0000ocRHlP02o`000003o`1afol0003o000000?o0000^ooonfX3o`0003Sooo]Z00Co
0023o`000?l0003o00000_mLTNX00ol0003oNj[aog^Zl@02og^Zl@03o`000?nL__3oW;k`00?o0000
0onO`?001?l0003o/LW/o`000?l00006ok;:k004o`000?nmc^Oo_LkWokg>i`;o00001?nmd>P2o`00
00;oa=?V0_l000001?o5e>Ko0000olGFi_l00002olKGiP03o`000?o:f>Co000000?obmWT00Co0000
olcKi?o<fnCo00000_o=g>@3o`0000;od^3R00Oo0000om;QhooBhN?od^7So`000?oDhn;o000000;o
e>CR0_l000001OoIj>3o0000omWYh?oIjN3o000000;ofN_P00Co0000om_]gol0003o00000_oLkml0
0ol0003ogo?Ko`000002o`000003on;ge_l0003o000000?o000000?oi?c;o`000?l000001_l0000V
oookJP?o00002_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z00Wooo]Z000;oook
JP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01OoonfX02?l0003ofl6oom_1_ol0003o
el74o`000?o@`/co00000oo@`L`3o`000006ol_1dOl0003obl7@o`000?o1`=Wo00001Oo2`=P01?l0
003o_l7Ko`000?nc`>@2o`0000Ko/l3T0_l00006ojFnk0;o00001?nC^o<00onF_?;o0000ogZdn003
ogZdn004o`000?mKYoSoFjOho`0000;oH:_i2ol0002goookJP?o0000>ooonfX>o`0000OoWl3`00?o
0000ok;:k?nbb^`00_nbb^`3o`0000;o/l_/00Co0000okg>ionmc^Oo00000onmd>P2o`000004okk@
j?l0003oa=?Vo`0000CoaMCV00Co0000olKGi_o6enKoa]OV0_l00002ol_Ii005o`000?o;f^Co0000
olcKi?l000000_o=g>@01_l0003oc]kUolkNiOl0003od^3Ro`0000?od^7S00?od^;So`000?l00000
0_oDi>801?l0003oeNKSo`000?l00002omWYh0;o000000?ofN_Po`000?oKkMl00_l00002omc_g`Co
000000?ogOGLo`000?l000001?l000000ooTo<_o0000o`000003o`000003omKiZ_l0003o000002?o
oo]Z1?l0000>oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX02OoonfX000_ooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP03oookJP04o`000?oK`Koofl6oom_1_`;o
000000?oel74o`000?o@`L`00_o@`L`01Ol0003od<3;om30boo@`<_o000000?obl7@00Co0000ol;0
f?o2`=So`/3H0_l00002ol:oe`03o`000?no`M_o000000Go/l3T0_l00002okC0h`03o`000?nU_^co
YKk/00?o00000_nV_n/00ol0003oTk_coi>kl`03oi>kl`Go000000?oN[Cho`000?l000003?l00000
1?l0Ckko0000o`000?l0002boookJP?o0000?_oonfX2o`000006o`0[/ol0003o0000o`000?mWU^[o
00001?n1[_400ol0003oWl3`oio0l004o`0000;oX/;`00?o0000ok;:k?l000000_l00006ok?;k003
o`000?nncnOo000000;o_M3X00Co0000okk@j?nnd>So_]3X0_l00003olGDiP04o`000?o6e^Ko0000
olKGiP;o00000_o7enH2o`0000;obm[T00Go0000olcKi?o=g>CocMcTo`000003olkNi@;o000000?o
d^7So`000?oBh^<00_oBh^<01?l0003oe>CRomCTh_l00002omGVh`;o000000?oenWRo`000?oIj^00
0_l000001OoKkMoo0000om_^gol0003og>oO00Co000000CogOGLo`000?l0003oh?SH3Ol0000Poook
JP?o00004_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z00Wooo]Z000;oookJP03
o`000?oonf[ooo]Z00[ooo]Z0_l00002oookJP05o`000?oK`Koofl6oom_1_ol000000_oJ`;l01Ol0
003oe/34o`000?o@`Lco000000?od<3;00Wo0000om2ob_l0003obl7@o`000?o;`<oo0000ol;0f?l0
00001Oo2_mL2o`000003oko0f_l0003o/l3T00;o00001Ond`><2o`0000KoY[o[0ol00003oiFllP;o
00000omm/oH2o`0000;oGJWh00Go0000of>^nOmS[_Wo0000ocJGlP03o`000003o`Aigol0003o0000
00;o000000?oS@D0o`000?oonfX0[OoonfX3o`0004;ooo]Z00?o0000oai8`Ol000000_laLn000ol0
003oIiKZo`000002oh6^l@Co00001onR`_000ol0003o/l_/ok?;k003ok?;k0?o000000?o]<c/o`00
0?nncnL00_l00004okk@j006o`000?o1d^Oo`M;Wo`000?o5e>Ko00000_o6e^H2o`0000?oamOV00Co
0000olWIiOl0003obm[T0_l00002olgLi0Coc]kU00Coc]oUo`000?o?hNGo00000ooBh^<2o`000003
omCTh_l0003oeNKS00;oeNKS00Co0000omOYh_l0003oen[R0_l000001?oKkMoo0000om_^gooKk]l3
o`000006omgcgOl0003ogOGLomgeg?l0003oh?SH0ol000001?oPnmCo0000o`000?oOoLh6o`0001ko
oo]Z0ol0000FoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX02OoonfX000_ooo]Z
00?o0000oookJ_oonfX03?oonfX01_l0003ooo]Zo`000?l0003ofl6oo`0000?of/2o0_l000000ooF
`<Co0000om30b`02om30b`05o`000?o@_l[od;o:om2ob_l000000oo;`<l01?l0003o`[oGol:oeoo2
_mL2o`0000?o`kkF00?o0000oko0f_l000001?nd`><2o`0000;o]/3R00?o0000ojJojonV_n/00ol0
0002ojNoj`03o`000?nE_?;oUKcb00CoUKcb0ol00003oh:hn003o`000?mQ[?Wo000000ko0000Z_oo
nfX3o`0004Gooo]Z00?o0000oai8`OlNB<400_l00002og:Kj@?o00000_n7/O400ol0003oX/;`oj;2
l002oj;2l0?o00000_nU`nl00ol0003o/l_/o`000002o`0000Go]<c/00?o0000oko@iol000000onn
d>P01?l0003o`M;Wol7Bioo1d^L2o`0000?oa]KV00Go0000olOGi_o7enKoamOVo`000002olWIi@;o
000000?oc=_To`000?o=g>@00oo>g^D00ol0003oc]oUolkOi@02o`000007om3RiOl0003od^;So`00
0?oChn?o0000omCThP03omGVh`06omGXhol0003o0000omOZh_l0003oencR0ol000001_oKk]oo0000
o`000?l0003ogO?Mo`0000;ogOGL0ol000001_oOnMWo0000on3ke?l0003ohOg<omomcP;o000000?o
fobgo`000?oCnJX00_l0000KoookJP?o00006_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oo
nf[ooo]Z00Sooo]Z000;oookJP03o`000?oonf[ooo]Z00gooo]Z00Co0000on2o^?oP_kSo00000ooJ
`;l02?l0003of[noomZo_ol0003oe[o4o`000?o@`<_o00000oo@_lX02Ol0003od;o:o`000?o;`<oo
0000ol^ocol0003o`[oGo`000006ol>neP?o000000?o]<3So`000?l000001Onf`>82o`0000KoYko[
0ol00004oiNmlP04o`000?n2^?SoP[Shoh:hn0Wo00000_liV_<9o`000:Gooo]Z0ol00017oookJP;o
00000_lNB<401Ol0003o@7;Ko`000?mbVnWo000000GoQk7a00Co0000oj;2l?l0003o00001_nU`nl0
0ol0003o]<c/okC<k003okC<k0;o00000_nfc^`01?l0003o_m3Wo`000?nnd>P3ol7Bi`;o00000oo1
e>T00ol0003oa]OVo`000002olOGiP?obMWU00?o0000olSKioo8fnL00_l00003olkNi@05o`000?o>
gnGoc]oUolkOiOl000000_o@h^D2o`0000;odn?S00Co0000omGVhooEi^?oeNKS0_oEj><00ol0003o
en[Ro`000002omO/hPCo000000[ofnoOo`000?oMlmgogO?Mo`000?oMmMco0000omkgf_l0003ogoWI
1?l000001OoOoLko0000o`000?l0003ofOfi00?o00006OoonfX3o`0001gooo]Z00?o0000oookJ_oo
nfX0;_oonfX00ol0003ooo]ZoookJP08oookJP002_oonfX00ol0003ooo]ZoookJP0=oookJP04o`00
0?oP_kSoh;nhon2o^0;o000000?of/2oo`000?oJ_kl00_oJ_kl2o`000003omJoa?l0003od;o:00;o
d;o:00Co0000om2ob_o@_l[od;o:0_l00002ol^oc`03o`000?o3_]Ko`kkF00;o`kkF0_l00003ol>n
e@;o00001?nf`>82o`0000;o^;kN00?o0000ojNojonW_n/00ol00002ojVojP03o`000?nG_O;oUkgb
00CoUkgb0ol00004ohFjm`07o`000?mT[o[oI:ojofB_n_m[/_[o0000ocbNm003o`0000;o2WoR1Ol0
002QoookJP?o0000B?oonfX4o`000003oaI6`_lNB<7o000000?o@7;K2?l00004ojG3k`?o000000?o
YlG_o`000?ndc>`00ondc>`00ol0003o]/k/okK>k003okK>k0;o00000oo1d^L00ol0003o`MCYol7D
j@02ol7Dj@03ol7FjOl0003oa]OV00;o00000oo9fND00ol0003ob=_WolSKi`02olSKi`;o000000?o
c]kUo`000?o>gnD00_o>gnD01?o?h>Go0000om3RiOl00002om3Ri@?o000000?oeNKSomGXhooEj><0
0_oEj><2o`0000?oencR0_l00002omS_hP;o000000GogO?Mo`000?l0003o0000omkgfP09o`000003
omgn`_l0003o000000;o00005_oonfX4o`00027ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP08oookJP002_oonfX00ol0003ooo]ZoookJP0=oookJP;o000000Coh;nho`000?oO_[Oo
gkjg0ol000001?oJ_koo0000omZn__oJ_[h3o`000003om2ob_l0003od;o:00;od;o:00Go0000om2n
b_o@_/[o0000ol^oc`02o`000003ol>ne_l0003o000000?o`kkE00Ko0000olBme?o4_MCoa;gDo`00
0?nf`>82o`0000Go^;kN0_l00006ojVojP?o00001OnI__49o`000003ofB_n_l0003o000000;o0000
00Co?9kdodNTmol0003o3H?T1_l0002LoookJP?o0000B_oonfX6o`000003oaI6`_l0003o@7;K00;o
@7;K00?o0000oi2]jOn@[NT01On@[NT01?l0003oYL?_o`000?l00005ojO5k`04o`000?ndc>co0000
o`0000Co]/k/00Co0000okS=jOnhcNWo00000_o1d^L00ol0003o`MCYol7Dj@02o`0000?o`MKY00?o
0000olOHi_l000000_o9fND5olSKi`04olWLiol0003o0000o`0000;oc]oU00?o0000oloPiOo?h>D0
0_l00002om3Ri@04o`000?oAiNGodNGUo`0000;oeNSS00Co0000omGXhol0003oen[R0ooGk>801?oH
kN;o0000omS_h_oHkn84o`000003omgcgOl0003og_OJ00?o000000?ogo[Go`000?l000000_l00000
0ooNo/Wo0000o`000004o`0001?ooo]Z0ol0000VoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000
oookJ_oonfX02?oonfX000[ooo]Z00?o0000oookJ_oonfX03?oonfX01?l0003oi;f^onBm[_l00003
omnn]`04o`000?oN_KOog[fgo`0000?of[jn00Co0000omVm__oI_Kko00000oo@_lX00ol0003od;k:
om2nbP02om2nbP04o`000?o<_lkoc;o>o`0000Co`kkE00?o0000olBme?o4_M@00oo4_M@00ol0003o
^;kNokRngP02okRngP;o00000_ng_]l00ol0003oZKoZojVojP03o`0000;oZl3Y00?o0000oiVnlOnI
__400ol00002oi^nl@03o`000?n5^?Ko000000;oR;_g1Ol00002ofNanP03o`000?m0X_Ko000000[o
0000UooonfX3o`0004cooo]Z1ol000000olFA/;o0000odmjg004o`0000OoT:gY00?o0000ojO5konW
aNl01_nWaNl00ol0003o]/k/okK>k002okK>k003o`000?nhcNWo^<gY00;o^<gY0_l00003ol7Dj@03
o`000?o1e^Wo`MKY00;o`MKY0_o2e^P2o`000005olWIiOo8fnOob=_WolSKiol000000oo9g>L01Ol0
003obmkWo`000?o>gnGo000000?ocn3U00Co0000om3RiOo@h^Go00000ooAiND3o`0000;oeNSS00Ko
0000omO/h_oGk>;oencRomS]h_l00002omS_hP?o00000_oKlml3o`000003omkgfol0003ogo[G00;o
000000?ogogAo`000?oNo/T01ol0000@oookJP?o0000:_oonfX00ol0003ooo]ZoookJP0[oookJP03
o`000?oonf[ooo]Z00Sooo]Z000:oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000onBm[_oT_Jh0
0_l000000ooO_[Oo0000omjm]`02omjm]`;o000000?of[jno`000?oI_Kh00_oI_Kh2o`000003om2o
b_l0003od;k:00?od;k:00Go0000olnnbOl0003oc;o>o`000003ol>ne@03o`000?o4_MCoa;gD00?o
a;gD0_o4_mD01?l0003o^;kNo`000?l00004okNng`?o00001_n[`>T2o`0000KoVkka1?l00003ohbm
m`03o`000?m/]?_oK;Ck00;oK;Ck0_l000000om<Y?Oo0000od2RmP02o`000003ojhZ0?l0003o0000
00?o0000TooonfX3o`0004kooo]Z2?l000000olFA/;o0000odmjg003odmjg0Go00001?n=]_400ol0
003oYlG_ojO5k`03o`0000?oZ/O_00Co0000okK>k?l0003o00000onhcNT01ol0003o^/kYo`000?ni
d>co0000ol7DjOl000000_o1e^T00ol0003o`]KXol;Fj003ol;Fj003o`000?o8fnOob=_W00;o0000
0_o9g>L01?l0003ob]gWo`000?o;g^L2o`0000;ocn3U00Co0000oloQiOl0003od>;U1?oAiND01?oA
i^Go0000om?XiOoCj>D3o`000003omO/h_l0003of>gR00;o000000Cof>oRo`000?oIlN7o00000_oK
lml01?l0003ofoKNo`000?oLn=`5o`000003omomdOl0003o000000Ko00003_oonfX3o`0002gooo]Z
00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP08oookJP002_oonfX00ol0003ooo]Zoook
JP0;oookJPCo00000_oS_:h2o`0000;og[fg00Co0000omjl]ooN_;Oo00000ooI_Kh00ol0003ofKfm
o`000002o`0000?od;k:00Wo0000olnnbOo?_/Wockk9o`000?o<_/go0000ol>neOl000000oo4_M@2
o`0000?oa;oE1?l00002okNng`;o00000_nh_]h00ol0003oZl3Yoj_0j@03o`0000;o[<3X00?o0000
oi^nlOnK__400ol00002oijol003o`000?n8^OKo000000;oS;gg1_l000001?m/]?_o0000o`000?m<
Y?L4o`000003ojhZ0?l0003o000000Co0000S_oonfX3o`0004oooo]Z2Ol000000ol0083o0000o`00
0002odmjg004o`000?m?N]co0000o`0000CoSKKa00Co0000ohfflOn=]_7oSKKa0_l00007oj[7k`04
o`000?nhcNWo^<gYokS=j@;o00000onjc^T3o`000003ol7FjOl0003o000000Co`]KX00Go0000ol?G
j?l0003oa=WYo`000003olWLi`03o`000?o:gNOob]gW00;o00000_o;gnL2o`0000;ocn7U00Oo0000
om7UiOoAiNGodNGUo`000?oAi^Go000000;odnSU00?o0000om;Yi_oBjNH00_l000000ooHkN;o0000
omS^hP02o`00000<omWahOl0003o0000om_cgol0003ofoKNo`000?oLn=co0000om_hgOl0003ogO_H
2?l000000oo7m:;o0000oookJP0;oookJP?o0000<OoonfX00ol0003ooo]ZoookJP0ZoookJP03o`00
0?oonf[ooo]Z00Sooo]Z000:oookJP03o`000?oonf[ooo]Z00_ooo]Z0_l000002OoX^ZGo0000on>l
[_oS_:ko0000on>k[_l0003og[fgo`000002omjl]`;o000000?ofKfno`000?oI_Kd00_oI_Kd01Ol0
003odkc3o`000?o@_/[o000000?ockk900Go0000olnmb?l0003oc;k=o`000003olBme003o`000?o4
_mGoa;oE00;oa;oE00Go0000olNld?o7_=3o0000okZmg002o`0000Co^;kN0ol00006ojc0j0;o0000
1_nN_o05o`0000;oSkkf00?o0000og6fnoma]_/00_ma]_/01?l0003oCjKho`000?mD[?X:o`0008[o
oo]Z0ol0001@oookJPko00000om/Qm`7o`0000GoTkWa00?o0000oj[7konZanl00ol00003ojg9kP03
o`000?nhcNWo000000Go^/kY00Co0000ok_Ajol0003o00001?o2e^P01?l0003o`mOXol?Gj?o3enP2
o`000004olGJjOl0003obMcWo`0000?ob]gW00Co0000ol_Oioo;gnOo00000_o<h>L3o`0000;odNGU
0_oAi^D2o`000003om?XiOl0003od^WV00;od^WV0ol00002omS^hP04o`000?oIlN7o0000omWbh@;o
000000OofoKNo`000?l0003o0000om_hgOl0003ogO_H00;o000000?ofokCo`000?oKolX00_l00000
1?o@nk?o0000o`000?l00008oookJPCo0000=OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oo
nf[ooo]Z00Sooo]Z000:oookJP03o`000?oonf[ooo]Z00[ooo]Z00Go0000onViXOoY^J7o0000onNi
Y@02o`0000?ohk^^00Co0000omjl]ooN_;Oo00000_oM^kH2o`0000?ofKfm0_l000000ooC_<?o0000
olnnb@02olnnb@04o`000?o?_LSockg8olnmb0?o000000?oa;gDo`000?o4_mD00_o4_mD2o`0000Co
akc@00Go0000ok^mf_nk_M[o0000okRngP02o`0000;o^KkM00?o0000ojc0j?n/`>P00ol00003ojk0
i`?o00001?nP_nl01?l0003oS;_fohbkm_n<^oH7o`000003og6fnol0003o000000So000000?o/b`0
o`000?l000000_l00025oookJP?o0000D_oonfX<o`000004o`PKW?l0003o02fao`0000CoK8OL0_l0
0009oi>il@;o00001on]bNh01?l0003o^/kYok[>jOnjc^T2o`000003ok_@jOl0003o^m7[00;o_=;Z
00Co0000ol;Fj?l0003o00001?o3enP00ol0003oaM[YolGJj@02o`0000;ob]gW00Co0000ol_Niol0
003obmoW0oo<h>L00ol0003ocN;WolgRi`02o`0000;odNKU00Co0000om7WiOl0003o00000ooBjNH0
1_oDjnGo0000o`000?oEk^Co0000omS_hP;o00000_oIl^400ol0003ofoKNo`000002o`000003om_h
gOl0003o000000;o000000GofokCo`000?l0003o0000omKn`@04o`0000Kooo]Z0ol0000ioookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX01ooonfX000[ooo]Z00?o0000oookJ_oonfX0
2_oonfX2o`000005onViXOl0003o0000onNiYOl000000ooS^jh2o`000009omjl]ol0003ogK^fomfk
]_l0003ogKZfo`000?oI_Kgo000000;of;bm00Go0000om>k`_l0003ockk9o`000004olnmb004o`00
0?o?_LSockg8o`0000?oa;oE00?o0000olNld?o7_=000oo7_=02olFldP03o`000?nk_M[o^kgJ00;o
00000oni_]d3o`0000?o[/3W0_l00002ok30i@03o`000?nP_nooX;o_00CoX;o_0_l00003ohnmmP03
o`000?nC_oGoTkoe00?o00000_me^?/2o`000003oeBZnOl0003o000000Co000000?o/b`0o`000?l0
00000ol00020oookJP?o0000DooonfX>o`000003o`PKW?l0003o02fa00Co000000CoK8OLo`000?mi
Y>ko00000_nC^O44o`0000;oVKga00?o0000ojg9k_n]bNh01?l00003ojo;kP;o00001?nkd>T01?l0
003o_=;ZokcBj_nld^X2o`0000?o`mOX0_l000002?o4f>So0000o`000?l0003oaM[Yo`000?o:gNOo
00000_o;g^L01Ol0003oc>3WolcPioo<h>Oo000000?ocN;W0_l000001_oAi^Go0000om7WiOoAinGo
0000om;YiP;o000000Koe>_Uo`000?l0003oeNkTo`000?oDknD2o`000003omWbhOl0003ofO?Q00Co
000000GofoSMo`000?l0003o0000omcmeP09o`0000Cooo]Z0ol0000moookJP03o`000?oonf[ooo]Z
02Wooo]Z00?o0000oookJ_oonfX01ooonfX000[ooo]Z00?o0000oookJ_oonfX02_oonfX02_l0003o
k;FGo`000?l0003oj;RQo`000?oV]jGo0000on>k[_l00002on:i[P04o`000?oM^kKogK^fo`0000?o
gKZf00Co0000omRl_OoH_;gof;bm0_l000000ooC^l;o0000o`000003olnmb006o`000?o?_LSockg8
o`000?o?_<Oo00000_o4_mD4olNld004o`000?o5_=;oaKcBolFldP;o00000onl_=T00ol0003o^KkM
o`000002okZng004o`000?n^`>Oo0000o`0000Go/<3U0ol00005oj?0kP?o00000_n?_OH2o`0000Go
O[Oh00?o0000oeV^n_mI[_X03?l0001loookJP?o0000E?oonfXEo`0000;oIXcS1_l00007oiVml@;o
00001?n_bnh2o`0000;o/Lg^00Oo0000ok_@jOl0003o0000okgAjOl0003o_=;Z00;o00000_nmdnX0
0ol0003o`mOXo`000003olCHj004o`000?o5f^WoaM[YolGJj@;o00000_o;g^L2o`0000;oc>3W1?o=
h^L01?o=hnOo0000o`000?l00002om7Wi@?o00000ooDjnD00ol0003oeNkTo`000002omC_i@03o`00
0?oGl^?o000000Co000000?of_ONo`000?l000000_l000001?oLoMKo0000o`000?oJom04o`000004
olch[?l0003o0000oookJP?o0000@OoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z
00Oooo]Z0009oookJP03o`000?oonf[ooo]Z00_ooo]Z00Go0000onbeUoo/]IOo0000onRhX@02o`00
0003onJgYOl0003oh[V^00;oh[V^0_l000000ooM^kKo0000omfj]P02omfj]P;o000000Gof;bmo`00
0?oH^kcof;^lo`000002om>j`@03o`000?o?_LSo000000;ockg800Co0000olnlaoo?_<Oockc70_l0
0003olNld007o`000?o5_=;oaKcBolFld_l0003oaK_Ao`000004okblf@;o00000_nj_]`2o`0000Co
/<3U0_l00002ok:oi003o`000?nS`>koXl3^00?o00000_nU`>`00ol0003oT[oeoi:om@03oi:om@oo
000000?o/b/0o`000?l000001Ol0001foookJP?o0000E_oonfXCo`000004oa/m^?l0003o0000o`00
00;oIXcS00Go0000oh6Zk_n1Z^koPJ[^o`000002oiVml@?o00000_nN`O000ol0003o[l_^ojo;kP02
ojo;kP03o`000?nacNko/Lg^00?o/Lg^00Co0000okgAjOnmdNWo_M7Y0_l00004okgCjP;o00000_o4
f>P00ol0003oaMWXo`000002olGJj@03o`000?o6fnWoa]_Y00;o000000?obmoWo`000?o<h>L00oo=
h^L01?l0003ocN?Wo`000?l00002oloVi`Co00000ooDjnD00ooDk>Go0000o`000002omC_i@03omKa
i?l0003o000000;oe_?T1_l000001OoKn]_o0000o`000?l0003of_o@00Wo0000AOoonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z00Oooo]Z0009oookJP03o`000?oonf[ooo]Z00_ooo]Z
00?o0000onbeUoo/]IL00ol000001_oX]j7o0000o`000?l0003oh[V^o`0000;ohKR^0ol000001OoM
^[Ko0000ombi]OoL^KGo000000?of;^l00Co0000om>j`OoC^/7odk[10_l000000oo?_LSo0000olnl
a`03olnla`?o000000?oakc@o`000?o5_=800_o5_=801ol0003oaK_AolFkdOo5^m7o0000okblfOl0
00000onn^mL2o`0000;o_;gK00Co0000ok30iOl0003o00001Onb_n@2o`0000KoYL3/0ol00004oiNo
l`;o00000_n3_OX5o`000003oliB0?l0003o000000Go000000?o/2D0o`000?l000000ol0001aoook
JP?o0000E_oonfXAo`000007o`00:ol0003o0000od]L`ol0003o6cfho`000002odUjg`Wo00001_nN
`O001?l0003o[l_^o`000?l00004ok7=kP04o`000?ncc^ko/lk^o`0000;o_M7Y00Co0000okgCj_nm
dn[o_M?Z0_l000001?o1e^Wo0000olCHj?l00002olGIj003o`000?o5f^Woa]_Y00;oa]_Y00?o0000
olWNj?o9g^P00_l00002olgRi`05o`000?o=hnOocN?WolgSiol000000_o?i^L01?l0003ocnKWo`00
0?l00002omC[i@07o`000?oDk>Goe>cUo`000?oDknGo0000omKai002o`0000;oe_?T00CoeoGRo`00
0?l0003of?OP2Ol000000ooGolKo0000o`000002o`0004Sooo]Z00?o0000oookJ_oonfX09ooonfX0
0ol0003ooo]ZoookJP07oookJP002OoonfX00ol0003ooo]ZoookJP0;oookJP?o00000_o[]9L2o`00
0003onRgXOl0003oiKJT00;o00000_oQ^:h01?l0003ohKN]on6g[Ol00003ombi]@;o000000Kof;^l
o`000?oH^[_o0000om>j`Ol00002om>i`0;o00000oo?_<L00ol0003ock_6olnkaP04o`000003olFl
d_l0003oaK_A00?oaK_A0_l00003okjke`05o`000?no^]Ko_k[Fo`000?nl_M/00_l00004ok:oi0;o
00000_nd_n800ol0003oYL3/ojG0k003o`0000;oZ<3[00?o0000oiNolonG_o<01?nG_o<4o`0000;o
R;oi0ol000001?o>DP3o0000o`000?o<CP0:o`0006gooo]Z0ol0001HoookJQKo000000?oBec3o`00
0?l000000_m9N]l2ogFDh`03o`000?n9[nooRJo_00;oRJo_00?o0000oik1l?nN`O001_nN`O000ol0
003o/Lg^ok7=kP02ok7=kP03o`000?ncc^ko/lk^00?o/lk^00?o0000okkBjOl000000_nmdnX01?l0
003o`MKYol7FjOo1e^T2o`0000?oaMWX00Go0000olKKjOo6fnWoa]_Yo`000002olWNj005o`000?o8
gnWo0000olgRiol000000oo=hnL03Oo>i>So0000oloViol0003ocnKWo`000?o@jNSo0000om7[iol0
003oe>cUo`000?oDkND00_l00002omKai004o`000?oFlnCo0000omOehP;o000000Gof?OPo`000?l0
003o0000omSkg@0:o`0004[ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP07oook
JP002OoonfX00ol0003ooo]ZoookJP0:oookJP04o`000?o^/8cok[2<o`0000;ojkBG00Co0000onZc
Uol0003oikFQ0_l000000ooU]JCo0000o`000003on6g[@;o000000Cog;Veo`000?oL^KGog;Ve0ol0
00000ooH^[_o0000om>i`002om>i`005o`000?oC^;oo0000olnlaol000000oo?^lH01?l0003obK[<
olVjc?o9^/`2o`0000?oaK_A00Ko0000olJkcoo6^loo0000okjkeol00004oknjeP;o000000?o_KgJ
o`000?nb_n@00_l00005okBohP;o00001_nX`>/3o`0000GoV/3b00?o0000ohBjn?l000000_l00000
0ooNKPko0000o`000003o`000003ola>0?l0003o000000;o000000?o/2D0o`000?l000001Ol0001V
oookJPCo0000F?oonfXJo`000003od]L`ol0003o000000;o000000?oMICSo`000?n9[nl01?n9[nl0
0ol0003oW/7`oik1l003o`0000?oXlC`00Co0000ok7=k_l0003o00001?ncc^h01ol0003o]M3^okG@
k_nnd^Wo0000okgCj_l000000_o1e^T2o`0000?o`=S/00?o0000olKKj?l000000_o6fnT2olWNj0;o
00000_o8gnT2o`0000;ocN?W00?o0000olkTj?o>i>P00_l000001?o?i^Oo0000om3Yj?o@jNP2o`00
0003om7/iol0003oe>gU00;o00000_oFlN@3o`0000;oeoGR00Ko0000omSgh?l0003of?WOo`000?oH
nmd2o`000003omOnf?l0003o000000;o000000CocOflo`000?l0003o0000BooonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z00Oooo]Z0009oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000onj`S?o^/8`00ol00002onZcU`;o000000GoikFQo`000?oU]JCoiKFTo`000002on6g[@04o`00
0?oP]Zgoh;J]o`0000?og;Ve00So0000om^h]?oK^;Co0000omRi^_l0003odkW0o`0000?odkRo00Wo
0000olnka_o?^lKock_6o`000?o?^/Go0000olVjc?l000000_o9^L/00ol0003oaK_Ao`000003olJk
c`;o00000ono^]H01ol0003o`;[Dol2je?o0^]Co0000okfmf_l000001?nd_n82o`0000;o^;_L00?o
0000ojS0jonX`>/00ol00002oj_0j@03o`000?nJ`?;oV/3b00?o000000?oWL3ao`000?n9_?P00_n9
_?P2o`000003omi^3_l0003o000001;o0000H?oonfX3o`0005[ooo]Z5Ol000000ol0033o0000o`00
0004o`000003od]L`ol0003oF7KF00;oF7KF2_l00007oj?4l003o`000?ncc^ko/lk^00;o/lk^00?o
0000okG@k_ned>h00oned>h01Ol0003o`MKYol7FjOo1e^Wo000000Co`=S/0_o1f^`00oo6fnSo0000
olKKj@02olWNj003o`000?o8gnWob=oY00;ob=oY00Co0000olWRj_l0003o00000oo>i>P00ol0003o
cnKWom3Yj003om3Yj004o`000?oAk>Oo0000om7/i`?o000000Coe_7To`000?l0003o00000_oGmN80
1_oGm^;o0000o`000?oHnMoo0000omSkg@;o000000CoeokHo`000?l0003oe?o>1Ol0001<oookJP03
o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX01ooonfX000Wooo]Z00?o0000oookJ_oonfX0
2_oonfX3o`0000;okZn<0ol00002onVbV0;o00000_oU]J@2o`000004on6g[Ol0003oh;J]on2f[@;o
000000?og;Veo`000?oK^;@00_oK^;@2o`000003omRi^_l0003odkRo00?odkRo0_l000000oo?^lKo
0000olnja@02olnja@04o`000?o9^L_obKW;olVib`;o00000oo6^ll01_l0003oak[>olNjc_l0003o
_k[Fo`0000Go`;[D0ol000000ond_n;o0000o`000005okRkg0;o00001_n[`>T2o`0000GoWL3a2_l0
00000oo?DP3o0000ole@0004o`000003ojhR0?l0003o000000So0000FooonfX3o`0005_ooo]Z6ol0
00000olS9Y_o0000o`h_[P02o`0000CoF7KF00?o0000oiBZiOnDZ^D01OnDZ^D00ol0003oXlC`oj?4
l003o`0000?oYlO`00Co0000ok?>k_l0003o00001?ned>h00ol0003o^Lo[o`000002ol7Fj@04o`00
0?o0f>co`=S/o`0000Go`M[/00?o0000olWNj?o9g^P01?o8gnT01?l0003obN3Yo`000?l00002ol[S
j@;o000000?oc^GXo`000?o@jNP00oo@jNP01_o@j^So0000o`000?oAk>Oo0000om;_i`?o000000Go
e_7To`000?oGmN;o0000omOfhP02o`000003omSigol0003o000000;o000000CoeokHo`000?l0003o
e?o>0ol000000onoljCo0000oookJP1=oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oo
nfX01ooonfX000Wooo]Z00?o0000oookJ_oonfX02_oonfX02?l0003ol:^0o`000?l0003okZn<o`00
0?o][Xgo00000_oY/YP01?l0003ojK6Ho`000?l00002onBdY004o`000?oP]Zgoh;J]o`0000;ogkF]
0_l00002om^h]003o`000?oK]kCofkNd00;o00000ooC^;l00ol0003odkRoom>h_`03o`000006olnj
aOl0003ockW4o`000?o9^L_o00000_o:^<T00ol0003oa[_?o`000003olNjcP;o00000oo0^]@2o`00
00Co`KWB00?o0000okRkg?nh^m`00_nh^m`2o`0000;o]kcM00?o0000oj_0jOn[`>T00ol00002ojg0
i`03o`000?nM`?7o000000;o00000_nQ`Nl01?l0003oSKogohfomon=_oL6o`000003olmB0?l0003o
000000;o000000?ob4P0o`000?l000002ol0001FoookJP?o0000G?oonfXMo`000006ob<VVol0003o
3Rn^o`h_[_l0003oMXKF1?l00004oiBZi@04o`000?nDZ^GoU:[UoiBZi@;o00001onWao000ol0003o
]M3^o`000002o`0000Co^Lo[0_l00002ol3Hk0;o00001?o1f^`01?l0003o`m[[o`000?l00003olSO
j@;o000000?obN3Yo`000?l000000_o:hnT01?l0003oc>GYo`000?l00003om3Yj006o`000?o@j^So
0000o`000?oAk>Oo00000_oBknL00ol0003odo7Vo`000003o`0000;oeoKR00?o0000omSigol00000
1_l000000ooDolko0000o`000004o`0004oooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Z
oookJP06oookJP002OoonfX00ol0003ooo]ZoookJP0:oookJP04o`000?o`Zh3o0000onnZP0;o0000
00CokJj=o`000?l0003o00000ooY/IP00ol0003oi;BTonBdY002o`000009on2f[Ol0003ogkF]omne
[Ol0003ogkB/o`000?oK^;Co000000;ofkNd00Go0000om^f/ol0003odkRoo`000003om>h_`03o`00
0?oC^;kodkRn00;o00000_o?^L@01?l0003ob[S9olZhbOo:^<T4o`000007olNjc_l0003oak[=olNj
cOl0003o`;[Do`000004ol6idP03o`000?o2_=Co`[cD00;o000000?o^;_Lo`000?ng_=d00ong_=d3
o`0000Ko[L3W00?o0000oj71konQ`Nl01?nQ`Nl5o`000003on9c6_l0003o000000[o000000?o`d40
o`000?l000000_l000000onO3P3o0000o`000005o`00053ooo]Z0ol0001LoookJP_o000000?o0`00
o`000?l000002Ol000000ol000?o0000o`000002o`000007o`00Dol0003o0000o`000?lS9Y_o0000
ob]1]P02o`0000CoMXKF1Ol00004oi6gl@03o`000?nWao3oYlO`00Co00000on[bO000ol0003o^Lo[
okW?j`02okW?j`;o000000?o^]7[o`000?nidnd00_l00004ol7Jk004o`000?o3f^_o`m[[ol?Jj`;o
a=g[00?o0000olSOjOl000000oo9h>T01?l0003ob^?Yol[SjOl00002olcUj@?o000000Kod>WXo`00
0?o@j^Sod>[Xo`000?oAk>L3om;_i`03o`000?oClNKodo7V00;odo?V00Oo0000omCfi?l0003o0000
omSigol0003oeo[O00Co000000?oe_oEo`000?l000001Ol0001AoookJP03o`000?oonf[ooo]Z02?o
oo]Z00?o0000oookJ_oonfX01_oonfX000Sooo]Z00?o0000oookJ_oonfX02ooonfX3o`0000;okjZ0
0ol000000oo/[Hgo0000o`000002onVaV0?o00000_oS/j@4o`0000?ogkB/00Co0000om^g]?oK]kCo
00000ooK][<01Ol0003odkRoom>h_ooC^;oo000000?odkRn00Co0000om>g_Ol0003ockW40_l00000
0oo:^<Wo0000olZga`03olZga`;o00000oo7^/d00ol0003o`KWBol6idP02ol6idP04o`000?o2_=Co
`[cDol:le0Go000000?o]kcMo`000?l000000_ni_=`00ol0003o[L3Wojg0i`03o`0000;o/;oU00?o
0000oj71kol000000_l00002ojC1k@03o`000?nB`OKoT/7f00[o000000?obd`0o`000?o9B@002_l0
00000onD0@3o0000o`000003o`0004_ooo]Z0ol0001MoookJR?o00000ol[@KH2o`0000?oMXKF0_l0
0008oi6gl@;o00000on[bO03o`0000;o[/c_00Co0000okW?jol0003o00000_njdN/00ol0003o^M?]
o`000002ok_Dk004o`000?o1f^co0000o`0000;o`m[[00Coa=_[o`000?o4gN_oa=g[0_l00002olWP
j@06o`000?o9hNWo0000ol[SjOl0003oc>GY0_l000002?o<i^[o0000o`000?l0003od>[Xo`000?o@
jnSo00000ooBknL2o`000007om?ai_oClnKodo?Vo`000?oDm^Co0000omCgh`02o`000006omOjgol0
003o0000omOmfol0003oe_oE1ol0001BoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oo
nfX01_oonfX000Sooo]Z00?o0000oookJ_oonfX02ooonfX02ol0003olJEbo`000?l0003okjZ0o`00
0?o^ZH7o0000onb]SOl0003ojjb=00?o000000Goik2Jo`000?oS/jCohk>To`000002on:bX`04o`00
0?oO]:cogkB/omnd[0;o000000?ofkNdo`000?oK][<00_oK][<2o`000003om>h_ol0003odkRn00;o
dkRn00Go0000om>g_OoC]kgodkNmo`000002om2h``03o`000?o:]lOob[O700;ob[O700Go0000ol^h
b?o;^<So0000olNjc@02o`0000?o`KWB00Oo0000ol:le?o2_=Co`[cDo`000?o2^=3o000000?o^[[I
0_l00003okVlg0?o00001_n`_nD00ol0003oY<7]ojC1k@04ojC1k@Co000000?oi7LQo`000?l00000
0ol000001?o@E0;o0000o`000?o;C002o`000003olM60?l0003oa48000oo0000AOoonfX3o`0005ko
oo]Z5?l000000ol000So0000o`00000<o`000003o`00QOl0003o:d6f00;o:d6f1?l000001?mfQ]Ko
0000ogjSjol00002oi6gl@?o00000onI_?401?l0003oZlW`o`000?l00006ojk<k`03o`000?njdN_o
^]7[00;o^]7[00?o0000ok_Dk?nke>`00_nke>`2o`000003ol?Jjol0003oa=_[00;oa=_[0ol00002
olGNj`;o00000_o9hNT01?l0003ob^?YolcUjOl00003olcVjP06o`000?o=jNWo0000o`000?o@jnSo
00000ooBknL2o`000004om?ai_oClnKodo?Vom?diP;o00000_oDmn<01Ol0003oe?[RomCjh_l0003o
e?gL00Oo000000?o`_Veo`000?l00000DooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[o
oo]Z00Kooo]Z0008oookJP03o`000?oonf[ooo]Z00_ooo]Z0ol000001?o`Y7?o0000o`000?o^ZH43
o`0000;ojjb=00?o0000onR`V?l000000ol00003on:bX`;o000000CogkB/o`000?oN/jcog[>/0ol0
00001?oK][?o0000omZe/ooJ]K<3o`000003om>h__l0003odkNm00?odkNm0_l000000oo@^<?o0000
olZga`02olZga`03o`000?o;^<SobkS800;obkS81?l000000oo1^M;o0000ol:le002ol:le007o`00
0?o2^=3o`[S@ol:hd?l0003o^[[Io`000002okbie`03o`000?ni_=co000000;o^[cJ00?o0000ok2o
iOn`_nD00ol000001?nb_n?o0000ojC1kOnT`Nd3o`0000?oZ<3[00Co0000onIl9?l0003oi7LQ0ol0
00000ooOKR3o0000o`000005o`000006olM60?l0003o0000ol8n0?l0003o_SX03ol0000noookJP?o
0000G_oonfX<o`000007oa400?l0003o0000o`000?lA003o0000o`D00003o`000004o`002?l0003o
0000o`004@Wo000000Co001go`000?l0003o00000_mHG[d2o`000004oe9gfOl0003oL8cNog2<gPKo
00001onI_?400ol0003o[/c_ojk<k`02ojk<k`?o00000_nac^l01Ol0003o^]7[o`000?nldn_o0000
00;o^mC/0_l000000onne^co0000o`000004olCKj`03o`000?o5g^_oaMk[00;o000000?oan3[o`00
0?l000000_l000001?o<iNWo0000olcVj_o<i^X2o`0000;ocNWY0_o?jnT3o`000004om;_iol0003o
d^oWo`0000;odo?V00?odoCVo`000?l000000_oDmn<01Ol0003oe?[RomCjh_l0003oe?gL00;o0000
00?od_oGo`000?l000001Ol0001EoookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0
1_oonfX000Sooo]Z00?o0000oookJ_oonfX02ooonfX01_l0003ol9eTo`000?o`Y7?o0000onnSM0;o
000000CokJR1o`000?o[[8gojjb=0ol00002onJ_VP;o00000_oR/Z<01?l0003oh[6So`000?l00002
omjc[004o`000?oN/Z_og[:[o`0000?of[Fc00?o0000omJd]_oF];H00_l00003om>g_@03o`000?oC
][godkJm00?o000000?ob[O7o`000?o;^<P00oo;^<P01?l0003oc;S7olbhaoo<^<L2o`0000?o`[cD
00?o0000ol:hd?o2^=000_o2^=02o`0000Co_;WG0ol000001?nj_=[o0000o`000?l00005ok:oh`;o
00000onX`>/2o`0000;oZl3Y00?o0000onIl9?l000001?l000001?oOKR3o0000o`000?l00002ol]=
00Go000000Ko`Sh0o`000?l0003o^cD0o`000?ng;`0>o`0003Sooo]Z0ol0001NoookJPko000000?o
4@00o`000?l000002_l000000ol0017o0000o`000004o`000004o`00<ol004Co0000o`00F@;o0000
0_l<5I<00ol0003oF5jmoeQN_@04o`0000;oL8cN00Go0000ohNZk?n7Z^coQj[/o`000002oiVll@?o
00000onO`O401?l0003o[/c_o`000?l00006ok7>k`07o`000?nldn_o_=?[o`000?nke>co0000okkF
k002o`0000;o_][^00Oo0000olCKjol0003oaMg[o`000?o5g^_o000000;oan3[00?o0000olORk?o7
h^`00_l00003olcVjP04o`000?o<in[o0000olgYj@;ocn_Y00?o0000olk/j_l000000_l000001?oB
knOod_3Wo`000?l00002om?diP07o`000?oDmn?oe?OSo`000?oDn^;o0000om?lg`03o`000003om;o
eol0003o000000Go0000E_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00Kooo]Z
0008oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oo2MI?l000000_l00002onnSM003o`000?o]
Z87o000000;o00000_oZZhd2o`000003onJ_V_l0003oiJjI00;o00000_oR/J<01?l0003ohK2So`00
0?l00003omjbZ`;o000000[of[Fco`000?oJ];;o0000omJd]_l0003oe[:eo`000?oC]kgo00000ooC
][d01?l0003odkFlom>e_?l00004ol^hb007o`000?o<^<Ooc;S7olbhaol0003oc;O6o`000002ol:l
e004o`000?o2^=3o`[S@ol:hd0;o00000_o3^<l00ol0003o_;WGo`000004okfhe0?o00000_nb_n<3
o`0000;o]kWK00Co0000ojS0jol0003o00001?n[`>T00ol0003oiW`To`000007o`000003om]Y8?l0
003o000000;o00000_o6A@05o`000003ok/e0?l0003o000000;o000000?o[R<0o`000?l000000ol0
00000onG103o0000o`000005o`0003;ooo]Z0ol0001MoookJPoo000000?o6@00o`000?l000001ol0
00001Ol900oo0000o`000?l0003o300O00Co000000Go000Vo`000?l0003o0000o`00<`02o`000003
o`00FOl0003o000000;o31FC00Co0000oeQN_OmHG[go00000_mMLm4:o`0000OoWl7a00?o0000ok7>
konac^l00_nac^l3o`0000;o/m7_00?o0000okcCjol000000_nne^`00ol0003o_][^okkJkP03okkJ
kP05o`000?o5gN_o0000olGNjol000000_o7h>/02Ol0003oan;/olORk?o7h^co0000olSUk?l0003o
c>KZo`000002olcWjP04o`000?o?jnWocn_Yo`0000;oc^cZ00Co0000olo_jOo?lNWoco7Y0_l00000
1OoCm>Ko0000om?di_l0003oe?OS00?o000000?odocOo`000?l000001_l000000oo5o;ko0000o`00
001HoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX01_oonfX000Sooo]Z00?o0000
oookJ_oonfX02ooonfX3o`000004oo2LIOl0003o0000onnSM0?o000000Kok:N2o`000?l0003ojZ^=
o`000?oYZXd2o`0000;oiJjI0ol00003on6`X`04o`000?oN/Z_og[:[o`0000;ogK:[0_l00002omZd
/P04o`000?oF/[Goe[:eomJb]@?o000000?odkJmo`000?oC]K`00_oC]K`3o`000003ol^hb?l0003o
c;S700;oc;S700Co0000olbga_o<]lKoc;O61?l000000oo2^=3o0000ol>hc`03ol>hc`;o00000_nm
^=@2o`0000?o_[KB0ol00006okNif`03o`000?n[`>WoZl3Y00;oZl3Y1Ol000001?oVO2Wo0000o`00
0?l00002on1a9P?o000000?ofVLQo`000?oGHA`01Ol000000ono?03o0000o`000002o`000003ok<[
0?l0003o000000Wo000000?oQ@00o`000?l000001Ol0000[oookJP?o0000GOoonfX=o`000004oad0
0?l0003o6@00oaT000[o000000Co2@0?o`000?l000[o00000_l<01l3o`000003o`009_l0003o0000
00Go000000?o001Io`000?l000000_l000000ol/?K7oF5jmo`000004oeecd@;o00001_nCYN800ol0
003oWl7aoio1l@03o`0000?oY<Ga00Co0000ok7>kol0003o00001_ncdNl2o`000003okkFk?l0003o
_][^00?o_][^00Go0000okoLk_nog>ko_mc^o`000003olOPj`Coan;/00?oan?/o`000?o8iN`00_l0
00001Oo<in[o0000olcXj_l0003ocn_Y00;oc^cZ0_l000001_o?knWoco7YoloajOo?lNWo0000om7d
i`?o000000Coe?OSo`000?l0003o00000_oCo=l;o`0005Wooo]Z00?o0000oookJ_oonfX07ooonfX0
0ol0003ooo]ZoookJP06oookJP002?oonfX00ol0003ooo]ZoookJP0<oookJPCo000000SokiaUo`00
0?l0003okZ9do`000?o/Yh;o0000on^VPP;o000000?ojJZ=o`000?l000000_oU[YT01?l0003oi:fI
o`000?l00002on6`X`;o000000Wog[:[o`000?oM/Z_ogK:[o`000?oM/J_o0000omZd/_l000000ooF
/[D01?l0003oe[:eomJb]Ol00003om>e_004o`000?oC];_o0000oljd`@?o000000?oc;S7o`000?o<
]lH00oo<]lH01?l0003oa[K:olJfb_o6]/X2o`0000?o`kS?00Go0000olBgcOl0003o_KSDo`000006
okjfdP?o000000Co]kWKo`000?l0003o00000_nf^]`01?l0003oZl3Yo`000?l00003ojjoiP[o0000
00?og6/Uo`000?oJIb401Ol000000ooAFASo0000o`00000Io`0002Kooo]Z0ol0001MoookJP_o0000
00Co8000o`000?l0003o7@002_l000002?l=003o0000oah04ol0003o2@0?o`000?l000[o00000_l<
01l2o`000003o`@0:_l002Ko000V00Go000000?o001Qo`000?l000000_l000000olP8i[o0000ob`m
/@02o`0000GoGG?A00?o0000oi>Uh_nCYN801OnCYN82o`0000OoY<Ga00?o0000ok?AkoncdNl00_nc
dNl3o`0000;o]m3/00?o0000okkJk_nnf^h00_nnf^h00ol0003o_mc^okoLkP02okoLkP04ol7LkOl0
003oan3[olOPj`;oan;/0_l000001Oo7hnco0000o`000?l0003obNG/00Co000000?ocn_Yolk/j_o>
k>X00_l000001Oo?knWoco7YoloajOo?lNWoco;Y00;o00000_o@m>P2o`000005om?hhol0003odocO
o`000?oCo=l02_l0001KoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX01_oonfX0
00Sooo]Z00?o0000oookJ_oonfX03?oonfX2o`000006onjACol0003o0000onnLIOl0003okZ9d0ol0
0002on^VPP03o`000?oYZXgo000000?o00000_oT[IT01?l0003ohjbIo`000?l00002on2_X`Co0000
0ooM/J/3o`000003omJb]Ol0003oe[:e00;oe[:e0_l000000ooC]Kco0000om>d^`02om>d^`04o`00
0?o>/kooc[>ooljc_`;o00001?o<]lH01?o<]LCo0000olJfb_l00002olNdb003o`000?o3^<oo0000
00?oa;O=00?o0000okjfd_nn]]800onn]]801Ol0003o`;[Dol2je?l0003o^;WJ00?o00000onf^]`2
o`0000Co[[oV0ol000000ooYPS;o0000o`000002o`000003on9e;Ol0003o000000Co00000_oHI2<4
o`000003om1H6_l0003obe0B01[o00008?oonfX3o`0005_ooo]Z2ol000001?lN003o0000o`000?lP
000>o`000003o`d00?l0003o000000?o000000?o600Oo`000?l<01l00ol000001Ol402[o0000o`00
0?l0003o000c00;o000000Go001=o`000?l0003o0000o`80N002o`000005ob0SV_l0003o;3faob`m
/Ol000000omlQM47o`0000?oSkC`00?o0000ojC5lOnTaO400_nTaO43o`000003ojW9lOl0003o/m7_
00?o00001Ongd>`2o`000003okkJk_l0003o000000;o_mc^00Co0000ol7LkOo1g>go`Mc]0ol00000
0oo7h^co0000olOSk002olOSk004o`000?o9iNcobNG/o`0000?obNS/0_l000001?o>k>[o0000olk]
jOl00002oloaj@04o`000?o?l^Wo0000o`0000;od?CX00?od?KWo`000?oAn>D03_l0001LoookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX01OoonfX000Sooo]Z00?o0000oookJ_oonfX0
3?oonfX3o`000003onjACol0003o000000?o000000CokJ5eo`000?l0003ojjJ20ol00002onNYSPCo
00000_oS[9T01?l0003oh:nSon2_Xol00002on2^XP;o00000_oM/J/00ol0003og;2Zomb`ZP02o`00
00;oe[:e00?o0000omJb]?oF/[@00_l00003om>d^`;o000000Goc[>oo`000?o>/Kgoc[6mo`000002
olbgaP?oc;G400Co0000olNdb?o7]<SoakC81?l000000oo4]lgo0000o`000003okjfdP;o00000oo0
^]@2o`0000?o^[SG0ol00002okRjf`04o`000?n^_nKo0000o`0000;o/KkT0_l000000ooYPS;o0000
o`000002o`000006on9e;Ol0003o0000ome^:ol0003offTW0ol000000ooFHRCo0000om=M7`05o`00
0003olU?5?l0003o000000?o000000Oo_3T0o`000?l0003o0000okD`0?l0003o[280013o00006?oo
nfX3o`0005_ooo]Z2ol00002oah000Wo000000?o:000o`000?l000001Ol000000olX01;o0000o`00
0004o`000005oaP07ol0003o300Oo`000?l902@02Ol000003?l004go0000o`000?l0003o0P1ho`00
0?l@69Co0000oe]I]_l0003o;3fao`0000GoO8GA0_l00007ohndl004o`000?nTaO7o0000o`0000Go
ZLWa00?o0000okO@k?ngd>`00_ngd>`3o`000004okWBk?l0003o0000o`0000;o_mc^0_l00004ol7L
k@04o`000?o2gngo0000o`0000;oan?/00Go0000olSTk?l0003obNG/o`000003olWXk005ol[Yk?l0
003o0000o`000?o>kNT00_l000001?o?lNWo0000olobjOo?l^T3o`000007om3fiol0003odOSUo`00
0?o@n^Co0000om3lhP02o`000003olkof_l0003o000000Go0000G_oonfX00ol0003ooo]ZoookJP0N
oookJP03o`000?oonf[ooo]Z00Gooo]Z0007oookJP03o`000?oonf[ooo]Z00kooo]Z0_l000000oo^
TDoo0000o`000003o`000003onfQMOl0003ok:1f00;o000000GojZF2o`000?l0003oijV>o`000002
onJXS`03o`000?oS[9WohjbI00?o00000ooP[Z801?l0003ogjfRo`000?l00003omb`ZP05o`000?oI
[jgo0000omJb]Ol000000_oF/[@01Ol0003oe[6do`000?oC];_o000000;od[>j00?o0000olja_Oo>
/Kd00_o>/Kd2o`0000?oc;G40_l000000oo7]<So0000olNcaP03olNcaP;o000000CoaKO<o`000?nn
]];o00001?o0^]@01_l0003o`kC<ol>dc?l0003o^[SGo`0000?o^kKD00Co0000okRjfol0003o0000
1?na_^@9o`000003on1c<?l0003ogFh[00;o000000CofFLXo`000?l0003oeV8T0_l000001?o@FAoo
0000oleD6_o=E1X2o`000004olI:4ol0003o0000ol943@Go000000?o]C00o`000?l000005?l0000@
oookJP?o0000F_oonfX<o`000003obX00?l0003o000000Wo000000?o:000o`000?l000000ol00000
0ol`013o0000obP04P02o`000003oah04ol0003o000000?o000000Co600Vo`000?l0003o2@0T2?l0
00000ol005;o0000o`000002o`000003oa@8O_l0003o7anE00;o00000_mKFKH5o`000005ogb5dOl0
003oPZ7Woh:Qiol000000on?]?03o`000003ohndl?l0003oZLWa00;oZLWa0ol00002ojg<l@04o`00
0?ngd>co0000o`0000?o^M;/0_l00002ok[FkP;o00000oo1g>d2o`000003ol;MkOl0003o000000;o
a>3]0_l000000oo8i>co0000olWUk003olWXk005o`000?o:jNco0000o`000?o;k>/00ol000000oo?
lNWo0000olobj@02olobj@0<o`000?o@m^Ood?KWo`000?oAn>Go0000om3ji?l0003od?cRolomgol0
003oc_oJ1ol0001PoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX01OoonfX000Oo
oo]Z00?o0000oookJ_oonfX03_oonfX4o`000003onf@DOl0003okYUT00?o00000_o/X7H01?l0003o
jZF2o`000?oYXh82o`0000;oiZR?0ol00002on>[V@Co00000ooO[J802?l0003og;2Zomb`Z_l0003o
g:nYo`000?oI[jgo00000_oF/[@01?l0003oe[6domJa]?oF/K@3o`000003om:c^_l0003oc[6m00;o
c[6m00Ko0000olnb_Oo?/[go0000olbea?l00002olbd``03o`000?o7/lKoak?600;oak?600Ko0000
olReaoo8]LOo0000olFgc?l00004ol2je003o`000?o3]<co`kC<00;o`kC<00?o0000ok^fe?nk]]@0
0onk]]@4o`000003ok6ni?l0003o000000Oo000000CohgTeo`000?l0003oh7<`0_l000000ooKK2go
0000omUW:003o`000003om=N9Ol0003od5TO00Go00000_o6BQ<3o`000003okhn2ol0003o000001_o
00002OoonfX3o`0005Sooo]Z3_l000000olZ003o0000o`00000:o`000005obP00?l0003o0000ocH0
2ol000000_l`0108o`000004obX0:?l0003o600VoaP09P;o000000Wo2@0To`000?lJ03Go0000o`D0
=?l0003o0@0io`000?l>04d00ol000001_l706Oo0000o`000?lD27ko0000oalOU@;o00000_mKFKH0
0ol0003oHgkHogN<fP02ogN<fPSo00001?nH^o001?l0003oZLWao`000?l00006ojg<l@03o`000?ni
d^co^M;/00?o^M;/00Oo0000ok[Fk_l0003o0000okgHkOl0003o`Mc]00;o00000_o2gNd2o`0000;o
a>3]00?o0000olKSkOl000000_l00002olWXk004o`000?o:jNcob^W/o`0000;obnc[00?o0000olc^
k?o<k^`00ol00002olobj@04o`000?o@m^Ood?KWom3gi`;o00000_o@n^@01ol0003ocogOo`000?o>
om[oc?oIo`000?o9om401?l0001QoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0
1OoonfX000Oooo]Z00?o0000oookJ_oonfX03_oonfX01Ol0003oiW/Xo`000?l0003okI1A00?o0000
00?okIQUo`000?l000001?l00002onVSPP?o00000_oUYhl2o`000004on>[VOl0003ohZZIon:ZV@;o
00000_oO[J82o`000005omb`Z_l0003og:nYo`000?oI[jd00_l000000ooF/[Co0000omJa]002omJa
]003o`000?oF/;?oe[2c00?o000000?oc[6mo`000?o?/[d00oo?/[d3o`000003olbd`ol0003oak?6
00;oak?600?o0000olReaoo8]LL00_o8]LL3o`0000;o`;[D1?o3]<`01Ol0003o`[G>ol:ec_l0003o
^kKD00;o00001?nm]=82o`0000;o][SK00Co0000oo:JE_l0003oki9=0_l000000ooVOc[o0000on=i
=@05o`000003om]/;Ol0003o000000?o000000GodehUo`000?l0003o0000oleF7`05o`0000;o_Sl@
1Ol000000on`;03o0000o`000002o`000003ojHM0?l0003o000001[o0000F?oonfX=o`000003oc<0
0?l0003o000000_o00000_lh00<2o`000004ocH02ol0003o0000oc0040Co000000?o9@0Eo`000?l0
00001?l00002oaP09P03o`000?lJ02_o000000Oo000000?o3P1=o`000?l000000_l000000ol706Oo
0000o`h3O003o`000004ocDm[Ol0003o0000o`0000?oHgkH0omgS=X01?l0003oRj[Zoh^Zj_l00008
oiRkl003o`000?n]c?7o[Lca00;o[Lca0ol00002ok3?l005o`000?nid^co0000o`000?nke>d00_l0
0003okgHk@;o00001?o2gNd01_l0003oa>3]olCPkOl0003oa^?]o`0000;oaNC]00?o0000olWXk?l0
00000_o:jN`2o`000006ol_/jol0003oc>k/olc^k?o<kn_o00000_o>lnX2o`000005om3fiol0003o
d?OWo`000?oAn>D00_o@n^@01Ol0003ocogOo`000?o>om[oc?oI00Ko0000HooonfX00ol0003ooo]Z
oookJP0LoookJP03o`000?oonf[ooo]Z00Gooo]Z0007oookJP03o`000?oonf[ooo]Z00kooo]Z1_l0
00001Oo/T5?o0000o`000?l0003ok9IT00;o000000Kojiedo`000?l0003ojJ>2o`000?oXXX<2o`00
0003onFWSol0003oiJJ?00;o00000_oRZYT01?l0003ohJVIo`000?l00002omj/XP?o000000Cog:nY
o`000?oH[Zgof:j]0ol000000ooF/KCo0000omJ`/`02omJ`/`04o`000?oE[k;o0000o`0000Cock:m
00Co0000olna_?o?/Kcock6l0ol000000oo7/lKo0000olRea`03olRea`05o`000?o9]<GobKC5olVd
aOl000001?o3]<`00ol0003o`[G>ol:ecP02ol:ecP03o`000?nm]=;o_KCB00;o_KCB00Co0000okjh
e?nn^=Co_[SD0ol000000oobVUKo0000o`000003o`000003onIo>_l0003o000000;ohGHf1?l00002
omMV;0Co00000_o=Eb83o`000003olM>7Ol0003o`TLF00Ko000000?o]S@7o`000?l000002Ol00000
0onW7P3o0000o`000002o`000003oilD0?l0003o000001;o0000C?oonfXCo`000003oc<00?l0003o
000000_o00000_lh00<3o`000003ocH02ol0003o000000Ko000000Co9@0Eo`000?l0003o=00W0_l0
00000olX02go0000oaP09P03o`000003oa00;_l0003o6`0o00So000000Co4`1[o`000?l0003o7`j0
0_l000001Olc;I_o0000ocDm[Ol0003oDEVl00Go000000?oMhcJo`000?n;Z^X00on;Z^X00ol0003o
V;_`oiRkl003o`0000?oWl7a00Co0000ojg<lOl0003o00001_n`co001?l0003o^mC]ok_DkOl00003
okgHk@;o00000onmg>l2o`000003ol?OkOl0003oa>3]00;oa^?]00Co0000olGTkOo5i>goaNC]0ol0
00001?o:jNco0000o`000?o;k>/2olc^k003o`000?o<kn_o000000;oc_?Z00Co0000olgdj_l0003o
00000_o@mnL2o`000003om3ji?l0003ocogO00;o000000?oc?oIo`000?l000001?l0001UoookJP03
o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX01OoonfX000Oooo]Z00?o0000oookJ_oonfX0
3ooonfX7o`000004on^?EOl0003o0000onbFI0?o000000KojYefo`000?l0003oj::3o`000?oWXH<2
o`0000;oiJJ?0ol00003on6YV@04o`000?oN[:;ogZbRo`0000;ogZ^Q0_l00002omR^[@03o`000?oH
[Jcof:f/00;o00000_oF/;<01?l0003oeJnbomF_/_oE[k83o`000003olnb_Ol0003ock6l00?ock6l
00Co0000olna^ol0003o00001?o8]LL01_l0003obKC5olVdaOo9]<Go0000olVca0;o000000?o`kC<
o`000?o2]Lh00oo2]Lh2o`0000?o_KCB00?o0000okjhe?nn^=@00_nn^=@5o`000003oo2IFOl0003o
000000Go000000?ohGHfo`000?l000000_oKKS<3o`000003omIU;ol0003odEhX00?o000000Coc5DT
o`000?l0003oadhM0ol000000oo2Aa[o0000o`000004o`0000;o_D4D5?l000000on7003o0000o`00
000Ao`00043ooo]Z8ol000000om600_o0000o`000002o`000003od<04ol0003o000000Oo000000Co
?00To`000?l0003o=00W0ol000000olX02go0000o`000002o`000004obd0?ol0003o0000oa/0?`;o
000000Oo3`12o`000?l@04co0000oa<0G?l0003o5@1[00;o00000_lO3X02o`000004oc<]Vol0003o
0000ocDm[@;o00000omkOl/:o`0000OoWl7a00?o0000ok3?l?n`co000_n`co03o`0000?o/];a0_l0
0002okgHk@03o`000?nmg>oo_Mc_00;o_Mc_0_nng^l00oo3gngo0000olCPk@02olKSk@CoaNC]00?o
0000olOWk_o7inh00_l000001?o:j^co0000olc^k?o<k^`2olc_j`04o`000?o>ln[oc_?Zo`0000;o
cOCZ00?oc_KXo`000?o=n>P01ol000000oo<omWo0000o`000002o`000003ok3d/_l0003o000006Ko
oo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP05oookJP001ooonfX00ol0003ooo]Z
oookJP0@oookJPCo00000_oYQT800ol0003ojhmEo`000002o`000005on^GIol0003o0000o`000?oY
W7L00_l00002onNQP`05o`000?oUYXooiJJ?o`000?oTYHl00_l00002on6YV@?o00000ooNZj401?l0
003ogJZQo`000?l00003omR][005o`000?oH[:_o0000omJ`/ol000000ooE[k82o`000003om6^]Ol0
003o000000?ock6l00Co0000olna^oo?/K_ock6k0ol000000oo8]LOo0000olVda@02olVda@05o`00
0?o9/lCobK?4o`000?o4/lT00ol00002ol:ecP06o`000?o3]<co`kC<o`000?nm]=;o00001?nn^=@0
0ol0003o`K;;ol6bb`05o`000003onnGFol0003ok95E00Go000000GoggHjo`000?oKKS?o0000omY^
=`02o`000004omIU;ol0003o0000om5N;@_o000000Cob5<Xo`000?l0003o`dTL1?l000000onl@1So
0000o`000004o`000003ojHR0?l0003o000000?o000000?oVQ00o`000?l000008Ol0000YoookJRgo
000000?oAP0;o`000?l000000_l000000om301?o0000o`000004o`000004ocl07_l0003o?00Toc`0
90Oo000000?o:00]o`000?l000000_l00002obd0?`03o`000?lK03oo000000?o000000Ko401<o`00
0?l0003o4`1Lo`000?lE06/2o`0000;o7`j000?o;2RIo`000?l000000_mSF[82o`0000KoNgo;00?o
0000oiNVh?nGY^001?nGY^000ol0003oWl7aoio1l@03o`0000?oYLKa00Co0000ok3?l?l0003o0000
1?nbd_401_l0003o]m7]okOAkOl0003o_MS]o`0000;o_Mc_00?o0000okkNkonng^l00onng^l00ol0
003oa^?]olKSk@03olGTk@03o`000?o6i^go000000;o000000?ob>[]o`000?l000000_l000001Oo<
kn_o0000olc`jol0003oc_?Z00?ocOCZ0_o>m^P2olghj005o`000?o=n^Goc?cTo`000?o;oN400_l0
00000oo7omSo0000o`000004o`0006Oooo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]Zoook
JP05oookJP001ooonfX00ol0003ooo]ZoookJP0@oookJPWo000000GojXmFo`000?o[UfOo0000onZF
J002o`000004onVLMol0003o0000onNQP`?o00000_oTYHl01?l0003ohjB?o`000?l00002on6XV@Co
00000_oMZZ45o`0000?of:b[0ol000001?oE[k;o0000omF^/_oE[[82o`000004om6^]Ol0003ock6l
o`0000?ock6k00Co0000oln`^_l0003obk2o0ol000000oo9]<Go0000olVca003olVca004o`000?o5
/LKoaK76olFaaPCo000000?o`kC<o`000?l000001?nn^=@00ol0003o`K;;ol6bb`02ol6bb`;o0000
00ColImTo`000?l0003okiMK0_l000001?o[SeGo0000onR8CooXR4l;o`0000;oefXh0ol00002om9R
<`;o000000?oc5T_o`000?l000000_o8DbP3o`000003ol177ol0003o000000Go000000?o[2/9o`00
0?l000002Ol000000onN5P3o0000o`000003o`000005ohl40?l0003o0000o`000?n500003?l00000
0omM003o0000o`000010o`000003ocl00?l0003o000000go000000?oC@00o`000?l000004Ol00002
ocl07P;o000000?o?00To`000?l000000ol000001?lb02[o0000o`000?lX02d2o`000004ocH0??l0
003o;@0oobd0?`?o000000?o901<o`000?l000000_l000001olT06?o0000o`000?l0003o5@1[o`00
0?l[5h@00_l000000olf;IWo0000o`000003of=J/P?o00001?mkOl/00ol0003oUjKPoiNVh005oiNV
h0;o00001onUa_400ol0003o/];aok;Bl@02o`0000Co]m7]0_l00002okgLk`;o00001?nng^l01?l0
003o`=k^o`000?l00002olGTk@03o`000?o6i^goa^K]00;o000000?ob>[]o`000?l000000_o8jnh5
o`000003olkcj_o=m>[ocOCZ00;o000000Goc_KXolghj?o=n>So0000olgji@02olcli008ol_mhOo9
o]oo0000olOof?l0003o`?k>o`000?n`m;82o`0006Wooo]Z00?o0000oookJ_oonfX06_oonfX00ol0
003ooo]ZoookJP04oookJP001ooonfX00ol0003ooo]ZoookJP0AoookJPCo000000?oiG/`o`000?l0
00001Ol00002onZFJ004o`000?oYW7Oo0000onRKM`;o000000?oiZ64o`000?l000000_l00002on>T
S`;o000000CohJRIo`000?oPYiWoh:NI0_l000000ooMZZ7o0000omZYY002omZYY0;o00000_oH[:/0
0ol0003of:^[omR[Z`02o`0000;oeJjb00Co0000om6^]OoA[[GodJje0ol000000oo?/K_o0000oln`
^P02oln`^P04o`000?o;[[cobjjlol^^_0;o00000oo9/l@2o`0000?oaK7600Co0000olF_a?o5[lCo
aJo40_l000001?o4]<[o0000okjhe?nn^=@4ol6bb`03o`000?o0/lgo000000;o000000?olImTo`00
0?o_Ue/00ol000000oo[SeGo0000onR8C`03o`000006on>0B_l0003o0000o`000?oNN4Ko00000_oK
LCl3o`0000;oeVTk0ol000001?o?GcGo0000olaI;oo<FBl3o`0000;oa4hW1?l000000ong?1_o0000
o`00000;o`000003oj/Z2_l0003o000006Co00000_mC000Do`000003odh09ol0003o000000;o0000
00?oB00[o`000?l000000ol00002oc80:P05o`000?lo03[o0000o`000?lf03`01ol000000olT04co
0000o`000002o`000004ob@0Hol0003o0000obD6L@;o000000?o;1R4o`000?l000000_lf;IT2o`00
00?oHeZb0_l00003ogF7e`Oo00001?nC]nl00ol0003oYLKaojG6l@03o`0000CoZL_a00Co0000okOA
kOngdNgo]m7]0_l000000onie>ko0000okOFl002o`0000Co_]k_00Co0000ol3Nk_o0g^ko00000_o1
h^l2o`0000;oa^K]00Co0000olSZkOo8j^go00000oo8jnh00ol0003obNk]olW`k@02olW`k@;o0000
00CocOCZo`000?l0003oc_KX0_o=n>P02_o<nNSo0000olcli?o<o>Co0000olWngol0003oaooHo`00
0?o0o/h4o`0006_ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP04oookJP001ooo
nfX00ol0003ooo]ZoookJP0AoookJPGo000000CoiG/`o`000?l0003oj8I61?l000001?oZUVSo0000
o`000?l00002onRKM`03o`000?oVXHCo000000;oiIn40_l000000ooSY8oo0000on:SS`02o`0000;o
h:NI00Co0000omnVVOl0003o00000ooJZJ@01?l0003ofZRSo`000?l00003omR[Z`05o`000?oGZj[o
0000omF^/_l000000ooA[[D00ol0003odZfcom:]/`02o`0000?ock2j00Wo0000ol^^_?o;[[cobjjl
o`000?o<[kgo0000olVca?l000000_o9/L800ol0003oaK76o`000003olF_a006o`000?o7//Goak;5
o`000?o4]<[o00001?o1///01ol0003o`;?=ol2ccOl0003oljM`o`000?oaWf@00ol000000oo]UUgo
0000on^?E@03o`000005onJ6D?l0003o0000o`000?oQOT`00_l000001?oNN4Ko0000o`000?l00002
omU_@@?o000000CodVDko`000?l0003ocele1?l000000oo8E2ko0000o`000002o`000005oka48ol0
003o0000o`000?ng?1/02Ol000000on`<aGo0000o`000004o`000003oilL0ol0003o000000?o0000
0_nI4P05o`000003ohX10?l0003o000004oo000000?oD`00o`000?l000004?l000000om@01go0000
o`000002odh09`Co000000CoB00[o`000?l0003o>P0V0_l000000om703Oo0000o`000003o`000004
obh0=?l0003o0000ocL0A0;o000000?o;@17o`000?l000000_lT04`00ol0003o:01Fo`000002ob@0
H`;o000000Co9@Iao`000?l/68Co;1R40_l00002ocH]V@05o`000?mJFkWo0000of=J/_l000000_mZ
O=<01ol0003oMHOGogF7eomeQmOo0000oh^Viol000002?nC]nl2o`0000?oZL_a0ol000000on]c_7o
0000okOAk@02o`0000;o^MC^00?o0000okOFl?l000000_njenl01?l0003o_]k_o`000?l00002ol3N
kP04o`000?o1h^oo`N;_o`0000;o`nC_0ol000001oo8j^go0000olS[k_o8jnko0000olS/k_l00000
0oo9l>d02oo9lNgo0000o`000?l0003ocOCZo`000?o=n>So0000olcij?l0003oc?cT00;o000000Go
bOkOo`000?o7omSo0000ol3ncP04o`0006cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Z
oookJP04oookJP001_oonfX00ol0003ooo]ZoookJP0BoookJPWo000000Coj8I6o`000?l0003ojHiJ
0_l000001?oYUFWo0000o`000?oXVgL3o`0000;oiIn400Co0000onBOQOl0003o00000_oRXhl3o`00
00?ogjJI0_l00002omZYY003o`000?oJZ:?ofZRS00;o000000?of:^[o`000?oGZjX00_oGZjX3o`00
00;odJje0ooB[K<02Ol0003odZbco`000?o?/;[o0000oln^^Ol0003objjlo`000003olb__@?o0000
0_o9/L801Ol0003oaJo4olF_a?o5[lCo000000Coak;51?l000000oo1//_o0000ol2cc@02ol2cc@03
o`000?ocYg3o000000;o000000?okieVo`000?o]UUd00ol000001OoXSEOo0000o`000?l0003oi8AB
00;o000000CohGi<o`000?l0003o00000_oLMDH3o`000004omI/@Ol0003o0000om9U>`Co000000Co
be/do`000?l0003o00000_o0C2/3o`000003oka48ol0003o000000;o000000?o_4@So`000?l00000
0_l000000onf?1ko0000o`000004o`000003ojDV3_l0003o000000?o00000_nQ7P@Mo`000003og40
0?l0003o0000023o00001?mL00000ol0003oG@00oed00005o`000003oe/00?l0003o000000Go0000
00?oF`00o`000?l000004_l00002oe007@;o000000GoCP0Wo`000?l0003o0000odh0:@04o`000004
od/0<Ol0003o0000odL0=`Go000000?o?`10o`000?l000000_lg04@2o`000003obd0Aol0003o<P1A
00?o000000?o:01Fo`000?l000000_lT06<01Ol/2W?o0000o`000?l0003o;1R400;o000000KoA3RM
o`000?l0003oAdJ]o`000?mJFkT5o`0000;oMHOG00Go0000oh^Vion;Y^OoRjKWo`000002oi>gk`?o
00000_nL__000ol0003oZL_ao`000002o`0000Go[Lka00?o0000okWDk_nie>h00_nie>h00ol0003o
^]O_ok[Gk`02ok[Gk`;o00000_o0g^h01_l0003o`N3^o`000?o1h^oo0000ol?Tk`;o00000_o3i^l0
1?l0003ob>_^olS[k_l00002olS/kP05o`000?o9l>gobO3]o`000?o9lNd00ol000001oo9m^_o0000
o`000?l0003oc?WXo`000?o<o>@00_l000001Oo9o]oo0000o`000?l0003o`?k>00Co0000K_oonfX0
0ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z00Cooo]Z0006oookJP03o`000?oonf[ooo]Z
01?ooo]Z1?l000001OoPKago0000o`000?l0003oj8I600?o000000GojHiJo`000?oYUFWo0000onRD
J`02o`000003onNJN?l0003o000000;o00000_oTWhD01Ol0003ohZ>?on:SSol0003ohJ:?00;o0000
0_oOYYT01?l0003ogZFHo`000?l00003omZXX`04o`000?oJYj;o0000o`0000?oej^Z00?o0000omNZ
ZOoGZZT00_l00002om:]/`04o`000?oB[;?odZbcom://`?o000000?ocjjio`000?o<[kd00oo<[kd0
0ol0003oc:jkolb^^`04o`000003olF_a?l0003oak;500?oak;500Go0000olNaa?o7/LCo0000ol:`
b003o`0000;o`;?=0ol000000ooaYG;o0000onnMIP03o`000005on^CGol0003o0000o`000?oVReT0
0_l000001?oTQ5;o0000o`000?l00002omikC@?o000000CofG97o`000?l0003oeVa11?l000000oo?
HC_o0000o`000002o`000004olEC<_l0003o`4`[ol1<:`Co00000_o1C2/4o`000003okY49ol0003o
000000Co000000?oZc0Io`000?l000000ol00002ojPZ41;o000000?oTPl1o`000?l000002?l00000
0on1003o0000o`00000Io`0000;oIP008Ol00002of404PWo00000_mK0244o`000003oeT0;?l0003o
000000;oCP0Y0ol00002od/0<@;o000000CoA`0go`000?l0003oAP0k0_l00003ocl0@005o`000?lg
04Co0000o`000?lm04d00ol000000olb057o0000obh0F@02o`000003ocD6I_l0003o901S00?o0000
0_li7hH01Ol0003oA3NMo`000?m4>9go000000;oAdJ]00?o0000oeYK^Ol000000omoO/P:o`0000Ko
W;k`00?o0000ojg>lOn]c_400_n]c_43o`0000;o/=;b00Ko0000okWDk_l0003o^mO^o`000?njenl3
o`000003okcKkol0003o000000;o`N3^00Go0000ol7Rkoo3i>oo`nC_o`000003ol?Vk`04o`000?o4
jNoo0000o`0000;ob>c^00?o0000olW`kOl000000_o9lNd00ol0003oboG[o`000002olWfj`04o`00
0?o:n>Wob?[XolSjj0Wo000000?o/oW2o`000?l00000L?oonfX00ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z00Cooo]Z0006oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000okLe0?l00000
0ol000001ooPL27o0000o`000?l0003oihE8o`000?oYSUX00ol00002onRDJ`?o00000_oVVWT00ol0
003oi9n5onBOQ@03o`0000;ohJ:?00Co0000on6RSol0003o00000_oNYIP3o`000009omZXXol0003o
fZNRomZWX_l0003ofJJRo`000?oGZj[o000000?oejZY00Go0000omBXZol0003odZfco`000003om:/
/`03o`000?oBZk;odZ^b00;o00000oo<[kd00ol0003oc:jkolb^^`02olb^^`04o`000?o=[K[o0000
o`0000Coak;500?o0000olNaa?o7/L@00_o7/L@01?l0003o`jk5ol>^aOo3[/D2o`0000;oljio00?o
0000oo6UL_l000000_l000001Oo^VfSo0000o`000?l0003ojI5Q00;o000000CoiX]Io`000?l0003o
00000_oQPE<3o`000004omahCOl0003o0000omUbA`?o00000_oBJ444o`000004olUJ>Ol0003o0000
olEC<PCo00000_o5E384o`000003oki;;ol0003o000000Co000000?o/CTRo`000?l000000ol00002
ojhd6`Go000000?oXBDDo`000?l000002_l000000onI6`ko0000o`000003o`000003oi0=0?l0003o
R`X300?oR`X3;?l00003ofP000Co00000_m[00`00ol0003oH`0<of<03005o`0000;oH@0B1Ol00000
1?mR027o0000o`000?l00002oe/08@Go000000?oF@0/o`000?l000000_m>02T2o`000003oeT0>Ol0
003oB`0a00;o000000?oDP0lo`000?l000000_m603/2o`0000;o?`101?l000001Oll04go?@1=o`00
0?l0003o=@1B00;o000000?o;P1Io`000?l000000_le1VH2o`000003ocDAMOl0003o000000;o>An6
00Co0000od@gWOl0003o00000_m^HK<00ol0003oAdJ]o`000005ogmnb0;o00001OnFXmd00ol0003o
W;k`oibnl003o`0000?oX/Ca00Co0000ojg>lOl0003o00001_n`d_801Ol0003o^mO^o`000?njenoo
000000;o_=__0_l00003okcOl@;o00000_o3i>l01Ol0003o`nK_ol?Vkol0003oa>O_00;o00000_o6
k>l2o`000004olW`kOl0003obO7]olWak@;o00000oo9m^/01?l0003ob_SYolSjj?o8n^P2o`000003
olKmi?l0003oa?kN00;o000000?o_okFokWlboncnL800_l0001boookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX01?oonfX000Kooo]Z00?o0000oookJ_oonfX05?oonfX01ol0003o]cD0
o`000?l0003of648o`000?oPL2401_l000000ooXSE_o0000o`000002o`000004onNDK?l0003o0000
onJJN@?o00000_oSWXD4o`0000;ohJ:?0_l000001?oNYISo0000ombSV_oLXiX2o`0000;ofZNR00?o
0000omVVX_oIYZ800_l00003omNZZ@03omJYZOl0003oe:R[00?o000000?odZbco`000?oBZk800_oB
Zk801Ol0003odJ^ao`000?o<[kgo000000Coc:jk00Co0000olf]^_o=[K[ocJfj0ol000000oo7//Go
0000olNaa003olNaa0;o00000oo3[/D3o`000005oo>^Ool0003o0000o`000?o_Y7<00ol000001?o/
VF[o0000o`000?oYTF43o`0000;oi8QJ0ol000001?oOOUCo0000o`000?oLN4d3o`0000;oeFi70_l0
00000ooBJ47o0000oleQ?`07o`0000;obE/j1?l000000oo2DSKo0000o`000003o`0000;o]T4[1Ol0
00000ond?BGo0000o`000004o`000003ojL^7_l0003o000000Co00001OnR91800ol0003oVb4Fo`00
000^o`000003og801_l0003o000001[o000000?oJ00Qo`000?mR02400ol000000omS02?o0000o`00
0008o`000004oe/0;ol0003o0000o`0000;oF@0i1_l00002odH0>`;o000000?oD@=8o`000?l00000
1?l000001Oll04go0000o`000?l0003o=@1B00;o000000?o?0ANo`000?l000000_le1VH2o`0000;o
=A5e00Go?R>7o`000?li7hKo0000of17W@02o`0000CoKV6c1?l00003ogmnb003o`000?nFXmgoUZ?M
00GoUZ?M0_l00007oj;4l@03o`000?n`d_;o/=;b00;o/=;b0ol00003ok?ElP05o`000?nlfnoo_=__
okcKkol000001?nlgo42okkOl0;o000000?o`nK_o`000?l000000_o4inl00ol0003oa^c_olK/k`02
o`000005olG]kol0003o0000o`000?o9lNd00_l00004olWfj`03o`000?o8n^Sob?[X00;o00000_o6
oN@01?o4o]ko0000o`000?noo]H4o`0007?ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]Z
oookJP04oookJP001_oonfX00ol0003ooo]ZoookJP0EoookJPSo00000_oTNcP4o`0000;oiheM0ol0
00001?oVTfgo0000o`000?oUVGT2o`000004on>NQOl0003ohif5on>MQ@;o000000?ohJ:?o`000?oP
XHl00_l00002ombSVP04o`000?oKXiWo0000o`0000?ofJJR00Wo0000omVVX_l0003oejZYo`000?oF
ZJWo0000omBXZol000000_oCYj/2o`0000;odZ^b00Co0000om6[/OoAZk7odJ^a0ol00002olb^^`04
o`000?o=[K[ocJfjolf]^P;o00000_o9[;`3o`0000;oak7400Wo0000olN^`Oo7[/7o0000ol>^aOl0
003oa;36o`000?oa]Hl00_l000001Ooa[83o0000onnTLol0003okZ5e00;o000000Cok9UZo`000?l0
003o00000_oWSf83o`000004on:5Fol0003o0000ommnE0?o00000_oIM4h3o`000003om1XA_l0003o
000000Ko00000_o=HT44o`000003olII?Ol0003o000000?o000000?o^TTbo`000?l000001?l00000
0oniARko0000o`000004o`000003oj`g:?l0003o000000Co00000_nX;adHo`0000;oSPl800?o0000
ohT<2on930/00on930/2o`0000;oRPlA00?o0000oh<73?n31``00ol00002oh@:4003o`000?mk0@_o
N`4;00So00000oml1aL00ol0003oLP0@og804007o`0000CoL00H00?o0000ofd07Om]01d01Ol00000
0omX027o0000o`000003o`0000;oH`0S2Ol00002oe/0;`?o00000omI03T5o`000004oeH4A?l0003o
0000o`0000;oD@=80_l000001?m404Oo0000o`000?l00002oc`0C@03o`000?m41EOo000000;o0000
00_o?0ANo`000?l0003o0000ocD6I_l0003o@a]io`000?le4GGo0000odDWR002o`0000?oH4NM00?o
0000ofiQ/om^HK<00_m^HK<2o`0000?oNXOE1ol00004oi>ekP03o`000?nRa?7oX/Ca00?o00000onW
b_801?l0003o/=;bo`000?l00004ok?ElP03o`000?nge>oo000000;o_=__00Co0000okcOlOnlgo7o
00000onngo001?l0003o_n?ao`000?l00003olCWk`04o`000?o6k>ooa^c_o`0000?oaNg_0_o6l>l3
o`0000;obOK[00?o0000olWfjol000000_o8n^P01_l0003oa_gTolKmi?o6oNCoa?kNo`0000;o_okF
1?l0001eoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX01?oonfX000Kooo]Z00?o
0000oookJ_oonfX05ooonfX:o`0000;oiXE<00Co0000onN=GOl0003oiXaN0_l000001OoVTfgo0000
onFINOl0003oi9Qj00;o00000_oSWHD01?l0003ohYb6o`000?l00002on2QS`Co00000_oKXiT4o`00
00?ofJJR1Ol00003om>WZ`05o`000?oCYj[o0000om:[/_l000000ooAZk400ol0003ocZRboljX/P04
o`000007olf]^_l0003ocJbiolf/^Ol0003obJblo`000002olV/_@Co000000?oajk1o`000?l00000
0_o4/<H01Ol0003olKF?oo6eSol0003olJb000?o00000_o^XGD01?l0003ok9UZo`000?oYUf`2o`00
0003onN?H_l0003oi8eT00;o000000GohXEKo`000?l0003o0000omakE@02o`000003omUdC_l0003o
e6m=00?o000000?od6Q6o`000?l000000_l00002om5YA`?o00000_o:H4@5o`000006oki@>_l0003o
0000o`000?njBC;o00000onmCSH4o`0000;o/Cla0ol000000on/=bSo0000o`000002ojhh:0Go0000
0onQ:b83o`0000;oXBPM1ol00004oiHK5QWo00000on32Q800ol0003oO0LGog`75`08o`0000?oN`TO
00Co0000og006?m`01SoL00H5?l000000om[23;o0000o`000002o`0000;oI@@c1?l000000omS23go
0000oeT0>@03o`000003oeT2??l0003o000000;oEPA40ol00002oe43B0;o000000CoA017o`000?l0
003oD0]F0ol000001?m41EOo0000o`000?ln1Ul2o`000004odLEKOlj2fWo0000o`0000;o@a]i0_l0
0002odDWR003o`000?mPAigoH4NM00;oH4NM0ol000001Om^HK?o0000ogB0dOmdP=7o000000CoNXOE
0_l00008oi>ekP;o00001onWb_800ol0003o/mGbok?ElP02o`0000Co]mC_0_l00002okcOl@;o0000
0onngo000ol0003o_n?aokoSl@02ol7Vl0;o000000Coa>W`o`000?o6k>oo00000_o5kNl01_o5k^oo
0000o`000?l0003oa_;^olKckP?o000000?obOK[o`000?o8n^P00_l00002olKmi004o`000?o3o]ko
0000okonePGo0000MooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00Cooo]Z0006
oookJP03o`000?oonf[ooo]Z01Oooo]Z0ol000001Oo8B@3o0000o`000?l0003ogg0V00Oo00000_oV
S5h00ol0003oiY=]o`000002o`0000;oi9Qj1?l00002on:LQP04o`000?oPXHooh:6?o`0000;ogIj@
0_l000001?oKXiWo0000om^RVOoKXYT2o`0000;ofJJR00?o0000omRUXOoHYJ401Ol00003om>WZP?o
000000CodJ^ao`000?oAZK3o00000_o>Z;800ol0003ocZRboljX/P02o`0000?ocJbi00?o0000olV/
_Oo9[;d00_o9[;d00ol0003obZ^kolZ[^`03o`0000;oa;3600?o0000oo6eSooa]Hl00ol000001?o_
ZX7o0000o`000?o^XGD3o`0000;ojIM/0ol00002onB=I0?o000000Cogh9Lo`000?l0003og7]E1?l0
0002omA_C@?o00000_oDKdh2o`000004om5YAol0003ocVM:oliWBP;o000000CobV14o`000?o2Ed7o
`UM10ol000000onnD3[o0000o`000003o`000004oke>=_l0003o]DLhokE7>0Co000000?o/Clao`00
0?l000001ol000000onW=2_o0000o`00000:o`000004oilY9?l0003oW2HRoi`V8R?o00001?n23Qd3
og/;8AWo00000_m[2383o`0000?oI@@c1?l000000omS23go0000o`000002o`0000;oF@8l0_l00002
oeH4A0;o000000?oF0Q9o`000?mA0dP00_l000000omC2U3o0000o`000002oe0;EP;o000000GoA0AG
o`000?l0003oDAMWoch6G`02o`0000;oAaE]0_l00002od<KN@;o00000om59hP02?mPAigo0000of17
WOmPAigo0000oeaC[ol0003oIV>k1Ol00003ogZ7e@04o`000?n>YNGoSZGUo`0000;oTkG^0ol00003
oi^ml003o`000?nWb_;oYl[b00?o00001?n/c_800ol0003o]mC_okODk`03okODk`03o`000?nhf?3o
^=S`00;o00000_nngo02o`000003okoQl?l0003o_n?a00;o`NK`00?o0000ol7XlOo1j?400_l00000
1?o5kNoo0000olG^koo5k^l2o`000003olKbk_l0003oa_?^00;o000000?oaoO/olGgk?l000001_l0
00000oo3o]ko0000o`000003o`000003oj?a]ol0003ooo]Z07Oooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP03oookJP001_oonfX00ol0003ooo]ZoookJP0HoookJPOo000000Cogg0V
o`000?l0003ohg/l1?l000001OoVS5ko0000o`000?l0003oiI9^00Co00000_oSV7/2o`000003on:L
Q_l0003o000000;o00000_oMWY001?l0003ogIj@o`000?l00002om^RV@04o`000?oJXIWo0000o`00
00?of:FQ0_l00002omFSXP;o00000_oCYjX00ol0003odjJYom>VZ@04o`000003oljX/_l0003ocZRb
00;ocZRb00Co0000oljX/_l0003ocJbi0_l00003olV/_@06o`000?o:Zk_obZ^kolZ[^ol0003obZ^j
0_l000002_o4/<Ko0000oo6eSooa]Hoo0000onncSol0003okjZ1o`000?o]Z882o`000003on^OM_l0
003o000000;o000000KoiiA]o`000?l0003oi8eTo`000?oRRVD2o`000004omn2G?l0003o0000o`00
00;oegID0_l000001?oDKdgo0000omMfEOoGMUD3o`000007om5]D?l0003o0000o`000?o>Id[o0000
olIMA`03o`0000;o`UM100Co0000ol9G@_l0003o00000_o2ECh00ol0003o_eA2o`000002o`0000?o
]DLh00?o0000okI7>?l000001_l00002oj`l=0Ko00001OnV<RP00ol0003oY3<_o`00000>o`0000Go
TQ`M0_l00006oh`G7P;o00000on54A`>o`0000?oP14U00?o0000ogT=:?mi3BP01Ol00003ogD=;@Ko
00000omb3C84o`000003ofd;=Ol0003oI@@c00So00000_mU3444o`000004of8?BOl0003o0000o`00
00;oF0Q90ol000001?mC2U3o0000o`000?l00002oe0;EP03o`000?mB4UooA0AG00;o00000_mA5fL0
1?ln1Uoo0000odLEKOm75Fd2o`0000;o@a]i00?o0000oe<bSOl000000_m59hP01Ol0003oDcfJo`00
0?mPAigo000000?oG5>_0_l00003ohJ3b0[o00001onK_O02o`0000?o[<kb0ol000000on_d_;o0000
okODk`02o`000003okWGkol0003o000000;o00000_njg?42o`0000;o_n7`00Go0000okoSlOo1i_3o
`NK`o`000002ol7Xl@04o`000?o2jo7o0000o`0000;oaNk_00?o0000olKbk_l000000oo6lnh02Ol0
003oaoO/olGgk?o5mnco0000olGjjOo4nnSo0000ol;mi002o`000007okgmg?l0003o^?cCo`000?n^
n<KoXo6go`00001joookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX00ooonfX000Go
oo]Z00?o0000oookJ_oonfX06_oonfX:o`000004on=k??l0003o0000onF4D0;o000000CoiHaOo`00
0?l0003o00000_oTTVh2o`000003on>HNol0003ohYMk00;o000000?ohIb6o`000?l000000_l00003
omfNT0Co00000_oJXIT4o`000006omRTXOl0003oeJ>RomFSX_l0003oeJ:R0_l00003om>VZ@03o`00
0?oCYZWodjJY00?o00000_o>Z;801?l0003ocZRboljX/_o>Z;84o`000003olV/_Ol0003obZ^k00;o
bZ^k00Co0000olZ[^_o:Zk[obZ^j1Ol00002onncS`?o00000_o]Z8800ol0003ojimfo`000002onVM
M`?o000000Coi99^o`000?l0003ohXYU1?l00002om]mF`;o000000CoegIDo`000?l0003o00000_oG
MUD01?l0003oe7AGo`000?l00002om5]D0Co00000_o6GDL3o`000004ol9G@Ol0003oaEa5olELA@Co
00000onoE485o`0000;o]dTi00Co0000ok14??n`A3co/4@l1?l000000on/?3Co0000oj`k<P02oj`k
<Pco00001OnM;C001?l0003oVBHYoiTV:OnI9RTCo`0000;oSAh/00?o0000ohDE9on55BL01?n55BL;
o`0000?oOA8]1Ol00002ogXC<P03o`000?mb3C;oLPdb00Go00000_m]2cD5o`000004of`A@Ol0003o
0000o`0000?oI@a11?l000001?mR3dWo0000o`000?l00002oeP8B@?o000000KoD`Y@o`000?l0003o
Ea1Go`000?m@2eH2o`000004oe8BGol0003oA0AGo`0000;oDAMW0_l00002odLEK@05o`000?mC9ggo
0000od<KNOl000000_mC<Xd3o`0000;oDcfJ0_l00004oeaC[`03o`000?n6PlSoQX?800?oQX?800?o
0000ohNDfOl000001OnHXm`00ol0003oVkg`oi^ml003o`0000?oX/Ca00Co0000ojc>l_l0003o0000
1On_d_800ol0003o^MO_okWGk`02o`0000?o^]ca0_l00002ok_QlP?o00000_o1i_03ol7Xl@03ol;Y
lOl0003o000000;o`ng`0_l000000oo6l^ko0000olKckP02olKckP04o`000?o7mncoaOO/olGgk0;o
aO[Y00Goa?_Xo`000?o2oNCo`OgSo`000002okgmg005okSldol0003o[_S6oj?a]ol00000O?oonfX0
0ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z00?ooo]Z0005oookJP03o`000?oonf[ooo]Z
01cooo]Z0ol000000oo;C03o0000o`000006o`000004onF4D?l0003o0000o`0000;oi8aQ0ol00000
0ooSTFoo0000o`000002on:GN`Co000000?ogYV6o`000?l000000_oMWY000ol0003og9f@ombMT002
o`000004omZQVOl0003ofZ6IomZQV@Co000000CoeJ>RomFRX_oEXZ;oeJ:R1?l00004om>VZ@05o`00
0?o@Xj[o0000oljX/_l000000oo>Z;800ol0003ocjNaolnW/@04o`000003olZ[^ol0003obZ^j00?o
bZ^j0_l00002onflW`?o00000_o]/I02o`000004onfXP_l0003o0000o`0000;ojIeg00?o0000onNJ
N?l000001?l000002?oRRVGo0000omn7IOoOQfGo0000om]mFol0003ofGaM0_l00002omYlF`Co0000
0_oDM5L3o`0000;ocFU@1Ol000000oo5GDSo0000o`000004o`000003ol=KB?l0003o000000Co0000
0_niCT05o`0000Co/4@l00?o0000ok13>ol000001Ol000000on/>c;o0000ojDg=P02ojDg=P?o0000
0_nT=34Xo`0000GoPaP_6?l000000omc5d;o0000of`A@@03o`000003ofhDA?l0003oI@a100So0000
0_mT54l3o`0000;oH1EE0_l00002oeL@E`?o00000_mB4Ul3o`0000;oDAMW00Go0000oeDQL_l0003o
AaE]o`000002oe<WO@;o00000omC<Xd2o`0000?oDcfJ00Go0000ofQO]OmXGkGo0000oeaC[`02o`00
00KoQX?800?o0000oiRSg?nHXm`01OnHXm`2o`0000OoX/Ca00Co0000ojoBl_n_d_;o[m;b0ol00002
ok7El`;o00001?njg?401?l0003o^n7bok_Ql_nkhO82okgQl@03o`000?o1i_3o`NK`00;o`NSa00?o
0000ol;YlOl000000_o3kO02o`000003ol?_lOl0003o000000;oa_?^0_l000000oo7mncoaOO/o`00
0002o`000005olCkj?l0003o`_gTol7mhol000000_nmoM`00onho=?o[_S6ojkhaP02o`0007kooo]Z
00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP03oookJP001OoonfX00ol0003ooo]Zoook
JP0MoookJP?o000000Cobd`0o`000?l0003o00000_oOL2/4o`0000;oi8AA00Co0000onB<HOl0003o
i8]R0_l000001_oSTFoo0000o`000?oRUg_o0000on6FN`;o000000?ogYV6o`000?oNV8H00_l00003
ombMT004o`000?oKW93o0000o`0000;ofZ6I00?o0000omVPVOoIX9T00_l00003omFRXP03o`000?oE
XZ;oeJ:R00;o00000_oCYZT2o`0000;od:>Z0ol000000oo>Z;;o0000olnW/@03olnW/@03o`000?o;
YK;objFb00?o00000oo:ZkX01_o:ZKSo0000onflWoo]_9oo0000on^jW`;o000000?okK6@o`000?o[
[i400_l000000oo[YX?o0000o`000005o`000003onBBK_l0003ohXm_00;o00000_oOQfD2o`000003
om]mFol0003ogH=R00Co00000_oHNed4o`0000;od71G1?l00002olQTC`Go00000_o7HTl5o`0000;o
^e961Ol00002okYAA@[o000000?o/4<ko`000?nZ?ch03?l000001?nT=37o0000oj8d=_l00003oih`
<`;o00000_nN<ST00ol0003oVBdeoiT]=@02o`0000CoVBlj0_nC:3H2o`0000CoTbTh00?o0000oh/Q
=?n;8C@03Ol000000on16SOo0000o`000004o`0000CoOA/m2Ol00002og<G@PCo00000_m^54@9o`00
00?oI1A?0_l000001?mL3e3o0000of0EEOmP5ED2o`000003oeL@Eol0003o000000;o000000KoDQ9O
o`000?l0003oF1eYo`000?mA5fL2o`000004oeDQL_l0003o0000o`0000;oDbMm0_l00003oe<bS@;o
000000?oG4JOo`000?mC?IX00_l00003ofQO]@Ko00000_n6PlP2o`0000;oV:?L0ol00002oiJfkP03
o`000?nRa?7oX/Ca00;oX/Ca0ol000000onWb_;o0000ojoBlP02o`0000Ko/MGc0_l00002ok[Ll@03
o`000?nkhO;o000000Co_N7a0ol000001?o1j?7o0000ol;YlOl00002ol?]l006o`000?o3ko7o`noa
ol?_lOo3l_3o00000_o2m>l2o`000005olGgk?l0003o0000o`000?o4nnP00_l000000oo1oN?o0000
okgmg002o`000004ojkha_l0003o0000o`0007oooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003o
oo]ZoookJP03oookJP001OoonfX00ol0003ooo]ZoookJP0NoookJPGo000000?odUL4o`000?l00000
0_l00002on9k@@03o`000?oTQ57o000000;o00000_oTRf801?l0003ohi5_o`000?oRT702o`000003
on6FNol0003o000000;o00000_oNV8H4o`0000?ofib@1?l00002omVPV@?o000000?oeJ:Ro`000?oE
XZ800_oEXZ802Ol0003oe:6Qo`000?oCYZWo0000om>UZ?l0003od:>Zo`000002om2SZP?o00000_o?
Yk42o`0000;objFb00?o0000olbU/_o<YK801?l000000ooX`Jko0000o`000002on^jW`04o`000?oY
]ioo0000o`0000;ojjnA00?o0000on^VPol000001?l000001?oWVWSo0000o`000?l00002on:?K`Co
000000?og8AVo`000?l000000_l00002om^2I0Co00000_oDMed4o`0000;obfUE0_l000000oo8I4oo
0000o`000002ol]YE@?o000000Coaf9?o`000?nnFDco_UU<0ol000001?nkDTKo0000o`000?nmEDL6
o`0000?o]4a40_l00002okA<A`Go000000?oZSlno`000?nY?3/01?nY?3/00ol0003oYce0ojLm@00O
o`0000?oSB@g00?o0000ohTT??l000000_l000000on98COo0000o`000003o`0000?oQR8m00?o0000
ogdK?Omm6cd02?l00003og/L@PCo00000_mf6TH4o`0000;oLAY:1?l000001?m^7E?o0000of@DComT
54l2o`000003ofLIE?l0003o000000?o000000KoI1eMo`000?l0003oG1UPo`000?mO7F<2o`0000?o
F1eY0_l00002oeDQLP?o00000_mC9gd00ol0003oGc^>o`000002oe<bS@03o`000?mSBj3o000000;o
G4JO00Ko0000of]Q]_m[HKKo0000ofQO]Ol00003ohEm``03o`000?n3Rm;oPh_B00Ko00001_nF]^h0
1?l0003oX/Cao`000?l00005ojO:lP03o`000?naeO?o/MGc00;o/MGc0ol000001OnfeO3o0000o`00
0?l0003o^n7b00;o00001?nmhO400ol0003o_NGbokgUlP02o`000005ol;YlOl0003o0000ol?]l?l0
00000_o3ko400oo3l?3o0000ol?bl002ol;dk`03o`000?o3mnko000000Ko000000?o`OgSo`000?nm
oM`01?l000000onHk;7o0000oookJP20oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oo
nfX00ooonfX000Gooo]Z00?o0000oookJ_oonfX07ooonfX6o`000005omEL3_l0003o0000o`000?oR
Nd400ol000001?oSQ5?o0000o`000?oTRf83o`0000;ohY1`0ol00002omnCN`Co00000_oMV8H2o`00
00;ofib@00?o0000om^LT?oKW9000_l000001?oIX9Wo0000omJNV_oFWYX5o`0000?oe:6Q1?l00004
om2SZP03o`000?o@XjWod:>Y00?o000000?ocZJ`o`000?l000001?o<YK801_l0003oc:Fao`000?l0
003oj<6^o`0000;ojkZO00Co0000onVgWooY]ioo00000_o[[i43o`0000;oj:>400Go0000onJQQOl0
003o0000onBHN@02o`000004on:?Kol0003ogXa_omj<K`;o000000?oghYYo`000?oMR6/00_l00002
om^2I004o`000?oGOVCo0000o`0000;oe7MM00Co0000oli_Fol0003o00000_o;JED5o`0000;obfUE
00?o0000olITEOl000000_l00002okiIC003o`000?nnFDco000000Ko00000_neCdT7o`0000Co]4a7
00?o0000oji6A?l000003_l00005oilg@0;o00001_nJ<3T2o`0000KoU2Xi0ol00002ohdT=`go0000
0_n68Sd5o`0000CoPR9300?o0000og/L@_mk74801Ol00003ogHJAP?o000000?oLAY:o`000?l00000
1?l00003ofhMD`?o00000_mW6E@3o`0000?oI1eM0_l000000omL6F3o0000oelMH`02o`0000;oF1eY
0ol00002oeDQLP06o`000?mN;gooE2Qmo`000?mC9ggo00000_mO>hh3o`0000?oHd^P0_l00002ogaY
/`03of]Q]_l0003o000000GoQGg300Co0000oh>;d_n3Rm;o00000onDW=P00ol0003oU[K^oiJfkP05
oiJfkP04o`000?nWb_;oYl[bojO:lP?o00000_n[co<01?l0003o/MGco`000?l00004okKEl004o`00
0?ngf_;o0000o`0000?o_N7a1_l000000onoj?;o0000o`000002o`0000;o`noa00Co0000ol?`l?l0
003o`o;`0_o2m>l00oo3m>oo0000o`000002ol;hk@05o`000?nonnSo_o_Xo`000?nko>801?l00000
1?n]nLooY?C2o`000?l00023oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX00ooo
nfX000Gooo]Z00?o0000oookJ_oonfX08?oonfX01?l06iCo0000o`000?o2?`02o`000005omEL3_l0
003o0000o`000?oRNd401?l000001?oRPUCo0000o`000?oRRV<7o`000004omnCNol0003ogY=lomjC
O0;o000000?ogIR6o`000?oLUhL00_l00003om^LT004o`000?oJVi3o0000o`0000?oeYjJ00?o0000
omJMVOoFWIT00_l00002omBQX@03o`000?oDXJ7oe:6Q00?o000000?od:>Zo`000?o@XjT00oo@XjT0
1?l0003od::Yo`000?l00004olbU/P03o`000?o<YK7o000000;oglBm00Co0000onJo[_l0003o0000
0ooY]il3o`0000;ojJfA0_l000001?oXXhCo0000onJQQOoVXHD3o`000007on6EN_l0003o0000o`00
0?oNS6oo0000on2?L`02o`0000;ogHQ[1?l00002omMnI0?o000000?oe7MMo`000?o>Ke/01Ol00002
oli^F@?o000000CobfUEo`000?o6I5GoaVAE1Ol00003ol5LCP03o`000?niEE3o^EE@00Co000000?o
]Dm9o`000?nfCdP00_nfCdP<o`0000GoYd5600Co0000ojDm@_nU?D;oYCe27?l000000onB;T?o0000
oh/V?`06oh/V?`03o`000?n69D?o000000Oo00000_n28T<5o`0000?oOR9800?o0000ogHJA_l00000
1_l000001?mc7e3o0000o`000?l00003ofhMD`?o00000omW6E@2o`0000CoI1eM0_l000001OmL6F3o
0000o`000?l0003oIRQ]00?o000000GoGbUdof4[MOl0003oEB5bo`000002oeh_O`?o00000omO>hh2
o`0000?oHd^P0_l00004ogaY/`03o`000?n5OL?oQGg300CoQGg300?o0000oh>;d_l000001OnDW=P4
o`0000?oWKo`00Co0000ojO:l_l0003o00001_n[co<00ol0003o]]G`okKEl003okKEl003okOJl_l0
003o000000?o^>3d00?o0000okkSl_nnho800_l00002okoXlP;o00000_nojO801?l0003o_ngbo`00
0?l00002ol?`l005o`000?o2m>oo`oC_ol?dkol000000oo2n>d01?l0003o_o_Xokokj?l00002ok_l
hP04okKlfoneo=[o0000ojgic`;o0000QOoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[o
oo]Z00?ooo]Z0005oookJP03o`000?oonf[ooo]Z027ooo]Z2?l000000ooJIbCo0000o`000004o`00
0005on:2E?l0003o0000o`000?oRRV@01?l000000ooOSG3o0000o`000002omjCO004o`000?oMTWco
0000o`0000;og9N71?l00003omZKT0Co00000ooFWIT01?l0003oeYbIo`000?l00003omBQX@03o`00
0?oAWj?odInS00?o00000_o@XjT01?l0003od::Yom2RZOo@XZT3o`0000;oc:Fb0ol00002omo4_@03
o`000?oV_jkoi[n^00Co00000_oW]J001Ol0003ojJfAonV]TOl0003oiZZB00;o00000_oVXHD01?l0
003ohij6o`000?l00002on6ENP?o00000_oPSg<4o`0000;ofXE/1?l00002om=jI@Co000000?ocFmM
o`000?o@M5l01?l00002olY/F`Ko000000?o`UmCo`000?o4HUD00ol000001Oo1G4ko0000okUED?ni
EE3o000000;o^EE?1_l000000onfCdSo0000ojm;B`02ojm;B`03o`000?n_BDWo[dU900;o[dU93?l0
00001?nU?D;o0000oj<mAOl00004oilh@P04o`000?nO>TKoWcY6o`0000CoVCA300Co0000oiTeAOnI
=DGo00000_nB;T8?o`0000CoR2Q600?o0000oh<UB?n39DP03_l00003og/UDPCo00000_mg95H4o`00
00;oLB9H1?l000000om^9V7o0000of@MG@03o`000004ofPTIOmL6F3oG1UPo`0000;oIRQ]0_l00003
oelYM0?o00000_mN;gl3o`0000?oGc^>0_l000001_mUC9oo0000of=;X?l0003oLF>bo`0000?oO6Vc
00?o0000oh:4c?n1Qm000on1Qm03ohEm``04o`000?nDW=SoU9cHoiBLf0?oTJo[00?o0000oifol?nM
_o001OnM_o000ol0003oZlocoj_?l`02oj_?l`;o00001?n^do<3o`000003okOJl_l0003o^>3d00?o
^>3d0onih_@01?l0003o_nSbokoXl_l00004okoYlP?o000000?o`>obo`000?l000000_l00002ol?d
k`05o`000?o2n>go0000ol7hk?l000000_nonnP01ol0003o^ocRok_lh_nfo=_o]OcJo`000?n]nLl0
0_l00027oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX00ooonfX000Gooo]Z00?o
0000oookJ_oonfX08_oonfX00ol06I7o04Blo`000002o`000003oli@0?l0003o000000Co000000?o
ggLoo`000?l000001_l000001?oOQV;o0000o`000?oOSG04o`0000;ogI9l1?l00002ombGQ`;o0000
0_oJVi000ol0003of9V@omRIT004o`0000?oeYbI1Ol00003om6OX`05o`000?oAWZ;o0000om2SZOl0
00000oo@XZT00ol0003ocJ2YolfPZ@03o`0000;oe<O=0_l000000ooN`[go0000o`000002o`000004
onVgWol0003oikFPonNeX0?o00000ooVZY84o`0000;ohij61?l000000ooNTW[o0000o`000002o`00
00;ogHed1?l00002omN2K0?o000000CodgYUo`000?o@MVCod7IT1?l00002olicHP?o000000?obVaK
o`000?o3I5X00_o3I5X5o`0000;o`V9H1_l000001?niEDoo0000okYFD?l00003ok=ADPOo00001On_
BDT01?l0003o[4Q<oja8C?l00002ojU5BP04o`000?nXATooZ4I?ojQ6CaKo00001?nH=TP00ol0003o
T35;oi0aB`03o`0000;oT31:00?o0000ohPXA_n8:4H01ol00004ohDYC0Co00000_n2:e800ol0003o
NbEBog/UDP05o`0000?oMbAF0ol00003og4RF0Co00000_m^9V43o`0000?oJ2AU0ol00002ofHXK@;o
00000omO:G@3o`0000;oGRmo00Co0000ofU1S_mP?8ko00000_mO>hh00ol0003oKE6Po`000002ofE<
W`;o000000GoLF>bo`000?mlJK?oO6Vco`000002oh:4c003o`000?n1Qm3oPHO@00CoPHO@00?o0000
oi6_jonA[n/01OnA[n/00ol0003oWKo`o`000002o`0000CoY<Ka0_l00003ojkCl`?o00000_ncdo40
0ol0003o]m[bo`000002okSPm003o`000?nih_Co^N;d00;o^N;d00?o^n?co`000?l000000onojO84
o`000006ol3_l_l0003o0000oko`l_l0003o`?C`1?l00002ol7hk005o`000?nonnSo_o_Xo`000?nk
o>800_l000000oneo=[o0000o`000002o`0008Wooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP02oookJP001OoonfX00ol0003ooo]ZoookJP0SoookJPKo000000?ocU40o`000?oFGaH0
1?l00002omec?@?o000000CoggiCo`000?l0003oghIR0ol00002omj<L@;o000000CogI9lo`000?oM
TWgogI9m0_l000000ooLUhOo0000om^FQ`03o`0000;of9V@00?o0000omNHTOoGV9400_l00002omJL
V@03o`000?oEW9WoeIbI00?o00000_oAWj<00ol0003odIjRom6NXP03o`000004om2RZOl0003ocj6X
o`0000;ocJ2Y00Co0000omC7cOoDalgoe<O=0ol000001?oN`[go0000onFm[ooU_Jl2o`0000;oikFP
00Co0000onFcXOl0003o00000_oVZY801?l0003oi:RConBXTol00002on>NQP05o`000?oPVhKoh9^6
o`000?oNTWX00_l000000ooPUGco0000o`000002omf=M004o`000?oJRWCo0000o`0000;oeh9/00?o
0000om9lJol000000_l000001?o@MVCo0000o`000?oANVP2o`0000;ocW=R00?o0000olIZH?l00000
0_l00003ol=TFP03o`000?o5IecoaFML00Ko00000_nlGEP6o`0000Co/e5B00?o0000ok=ADOl00000
0_ncD50;o`000003ojU5B_l0003oZ4I?00?oZ4I?00?o0000ojA2COl000001OnO?dh2o`0000KoVcQ8
00?o0000oiLgC?l000000_nH=TP>o`0000CoSBm=00?o0000ohDYC?n5:D`01Ol00002oh8[DPKo0000
0omn:UL00ol0003oMbAFo`000002o`000003ogTYFol0003oLB9H00Go00000_m^9V42o`000004og8]
JOl0003oJ2AUofPTI@;o000000?oKBe^o`000?l000000_l000001?m/<gSo0000oelYM?mO:G@2o`00
0004ofThP_l0003oGRmoo`0000;oJD6>00Co0000of0lS_l0003o00000om]DJ02o`0000;oOfZa0_l0
00000omlJK?o0000oh:4c003oh:4c003o`000?n1Qm3oPHO@00;oPHO@00?o0000oi:Rgol000000onA
[n/2o`000003oi6_jol0003o000000?oY<Ka0ol00002ojS<l`04o`000?n^do?o0000o`0000Go/m?a
00?o0000okSPm?nhh?@00_l00002okWRm004o`000?nkho?o^n?co`0000;o_>Oc0_l00002oko[lP;o
000000?o`>obo`000?nol?800_nol?82o`0000;o_oG`1Ol000000ononnSo0000o`000002o`000004
okGlf_l0003o0000o`0008cooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP02oook
JP001?oonfX00ol0003ooo]ZoookJP0VoookJPGo000000KocU40o`000?l0003oeUlJo`000?oKJbh3
o`000004omef@ol0003o0000ommnD`?o00000_oOQV@3o`000003omj<LOl0003o000000;ogI9m00Co
0000ombAOOl0003o00000_oKUXL5o`0000;oeiRA00Co0000omNHTOl0003o00000ooEW9T00ol0003o
eI^Io`000002o`0000?odIjR00?o0000om6MXOoAWJ401?l000000oo=X:Wo0000omC7c@03o`0000;o
dlG<00Oo0000omk2_Ol0003o0000onFm[ol0003ohkb`00;o00000_oU/j401?l0003ohk6Qo`000?l0
0003onBXT`?o00000ooPVhH4o`0000;oh9El1?l00002omZ:M0?o000000Coeh9/o`000?oBO6_odWa[
1?l00002om5jJ0?o000000?ocW=Ro`000?o6JV000_o6JV05o`0000;oaFML00Co0000okePG?nmH5co
_F1L0ol000000onlGESo0000o`000002okaNFPco00001On]C5<01?l0003oZdU@oj]9D?n[BE0Lo`00
0003oiTkDOl0003oTC==00KoTC==2ol00003ohT`DPCo00000_n5<5L00ol0003oORYGoghZE`02oghZ
E`Co00000_mi:E/7o`000004ogL]Hol0003o0000o`0000?oLReY0ol00003ofd]KP;o00000om/<gP3
o`000003ofPgPOl0003oJCR200;o00001?mY@Hh2o`0000?oKE6P0_l00004ogmZ/@Go00000_n2Q<`0
1?l0003oPHO@oh67d?n1Qm07o`0000CoV[[^00Co0000ojC6lOl0003o00001_nXc?<01?l0003o/m?a
ok?ClOncdo44o`000003ok?Ilol0003o000000;o^N;d0_l00002ok_Sl`04o`000?nlio?o0000o`00
00?o_>[d00Co0000ol3_l_o0ko;o00000onol?801?l0003o_oG`okoel?nomO02o`000005okcikOl0
003o^o_XokWkj?l000000_ndnn401Ol0003o[O[GojCfc?l0003oS>FZ08gooo]Z00?o0000oookJ_oo
nfX03_oonfX00ol0003ooo]ZoookJP02oookJP001?oonfX00ol0003ooo]ZoookJP0WoookJPSo0000
00CoeUlJo`000?l0003ofV`a0_l000001OoMMT?o0000o`000?l0003ogWiE00;o000000?oghITo`00
0?oNQVD00_l000000ooNS77o0000o`000002o`0000;og95m1Ol00002omRCQ`Co00000_oGV943o`00
0005omFLVOl0003oeI^Io`000?oBVYT01?l00004om6MX@03o`000?oAWJ7odIfQ00?o000000?oe<O=
o`000?oCaL`00ooCaL`01?l0003og<2momc0_Ol00003on>l/0?o00000ooS/J42o`0000;oi:RC00Co
0000on6UTol0003o00000_oPVhH2o`000005on:LQ_l0003o0000on2EO?l000000_oMTWd2o`000004
omZ:M?l0003oehIeomN6M@Go00000_oDP6h4o`0000;ocGIY1?l000001Oo6JV3o0000olIZH?l0003o
b6eR00?o000000?oaFMLo`000?nmH5`00_nmH5`00ol0003o_F1Lo`000007o`0000?o]eUI0_l00003
okEHF`co000000CoZdU@o`000?nYB5;o00001?nUAE001?l0003oY4ECojA5Dol00004oim0D004o`00
0?nO@E;oWd5Bo`0000?oVCY@3Ol00005ohlfE@?o00000_n9<584o`0000GoQC1G00?o0000oghZEol0
00000_l00002oh4`G0Co00000_mm<F<2o`0000;oMbeS0ol00003og8]J@?o00001?m];Fh00ol0003o
K3=hof`cN002of`cN0;o00000omX=h43o`0000CoJD6>0_l000001_m]DJ3o0000ofeAX?l0003oNFJa
o`0000CoOfZa0_l00003ohj7a`Oo00000_nJX]X00ol0003oV[[^oiZjkP06oiZjkP03o`000?nXc??o
Z<cc00;oZ<cc0ol000000on/dO?o0000ok?Cl@02o`0000;o]MOa0ol00002okKLl`;o00000_nkho<0
1?l0003o^nGdo`000?l00004okcZm003okc[lol0003o000000;o_o3b0ol00003okoel0;o00000_nl
nNd00onknnSo^O_XokWkj002okCkh@03o`000?n]n]OoY?K<00;o0000SooonfX00ol0003ooo]Zoook
JP0=oookJP03o`000?oonf[ooo]Z00;ooo]Z0004oookJP03o`000?oonf[ooo]Z02Wooo]Z0ol00000
0ol0KM_o0000o`000004o`000005omY/<Ol0003o0000o`000?oMMTD00ol000000ooMOUOo0000o`00
0002omj6I@?o00000_oMS782o`000004ombAOOl0003ofi1nom^@OP;o00000_oHThL00ol0003of9>7
omRCQ`02o`000004omNHTOl0003oeYNAomJGT@Ko00000_oBVIT3o`000003om6MXOl0003o000000;o
000000CoblSFo`000?oDalgo00001?oCaL`01Ol0003od/?<o`000?oL`;go000000?ohkb`00Co0000
on6i[ol0003o00000_oS/J401?l0003ohJnRo`000?l00002on6UT`09o`000?oNXYCo0000o`000?oN
VHOo0000on:LQ_l0003ogiZ700;o00000_oMTWd01?l0003ofXmno`000?l00003omN6M@04o`000?oC
PgGodh=eo`0000;oe81^00?o0000om5mL?oAOG000ol000001?o=MVWo0000olUaJ?o9LFP6o`0000;o
aFaU1Ol000000onmH5co0000okiQG002okiQG004o`000?ngG5ko]eaNokMLGPOo00001?neF5/01?l0
003o/E9Hok5BF?l00002ojm@E`04o`000?n]DE_o[E5KojeAFaOo00000onN@UL01?l0003oUceHoiLm
F?l00004oiLmF003o`000?n?=UGoScIE00[o000000?oS3IJo`000?n5<5L00_n5<5L5o`0000;oPC1L
1?l000000omm<F?o0000o`000002o`000004ogL]Hol0003o0000o`0000;oNcA[1?l00002ogHeL@03
o`000?m];FkoKBe^00?o00000_m/<gP2o`000004og8oPol0003oJ3N1ofPgP@;o000000CoLTN?o`00
0?mY@HkoJD6>0_l000000omkEigo0000ofeAX003o`000003ogUV/Ol0003oOfZa00;oOfZa00?o0000
ohF2b?l000001_n>QlL00ol0003oVZ;JoiZRfP04oiZRfP03o`000?nJ^^koV[[^00?o00000onQ`_00
1?l0003oZ<cco`000?l00005ojcAl`05o`000?neeo7o]MOaokGGlOl000000_nfg?<3o`0000;o]^;e
0_l000000onkiOCo0000o`000002okcZm004o`000?nljo?o_>_co`0000;o_Noc0ol00002okoel0;o
000000Go__S]okcikOnlnNgo0000ok_kj002okWkj0;o]?_Q0_n]n]L00onTm/co0000ogoMX`2Aoook
JP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX00_oonfX000Cooo]Z00?o0000oookJ_oo
nfX0:_oonfX;o`0000;ofV`c0_l000001?oLMTOo0000o`000?oMOUL2o`000004omj6IOl0003ogHEV
omf5IP?o000000?og8]co`000?l000000_oKT7h4o`0000?of9>700Co0000omNBR?l0003o00000ooF
Ui401?l0003oeYN@omJGT?l00003om:IV@03o`000?oBVIWo000000?o00000_nhaND01?l0003oblSF
o`000?l00003om?5c004o`000?oB`lcod/?<om;3c0?o000000Kohkb`o`000?oQ^JoohKV_o`000?oO
^;02o`0000?ohJnR1?l00002omjRU0Go00000_oOVXL4o`0000;ofXmn0ol000001?oGQWGo0000om>3
MOoCPgD3o`000006omB0K_l0003odGe`om5mL?l0003ocGU`0ol00002olUaJ0;o00000_o9M6/6o`00
00;o`FMT1Ol000000onnHEco0000okMLGP02okMLGP03o`000?nhG5go000000;o^5]M2ol000000on_
D5Oo0000ojeAF`03ojeAF`;o00001_nUBUX2o`0000KoXDAF0_l00006oii2E`03o`000?nG?ESo0000
00So00001?nC?5/00ol0003oS3MLoh`gG00Do`0000;oOS=U0ol00003og/dJ`?o00001?mf=G44o`00
0003og8hNOmd>W[o000000;o00000omb?h<3o`000003og57T?l0003oLTN?00?o00000omkEid2o`00
00?oQ6fa0_l00002ogmZ/@05o`000?n5P/SoQH;8ohF2b?l000001?n>QlL2o`0000OoVZ;J0_l00007
oj72l004o`000?n/dO?o[=7cojcAl`?o00000on^eO@01Ol0003o]M[co`000?nfg??o000000?o]^;e
00Go0000okSRm?nhh_Co^>;do`000002okcZm0;o00000_nljo<2okg_l`;o000000?o_?7co`000?nl
m?801?l000001?nlnNgo0000o`000?nknnP2okWkj003okCkhOl0003o[O[G00Co0000T_oonfX00ol0
003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00;ooo]Z0004oookJP03o`000?oonf[ooo]Z02_o
oo]Z0ol000001?l0K=[o0000o`000?lHONH8o`000005omafAol0003o0000o`000?oMOUP00_l00002
omf5IP05o`000?oLQFOo0000o`000?oLRg<01?l00002omV=O@?o000000Cof9>7o`000?oGTXSoei:8
1?l00003omJGT0Ko000000?odYVIo`000?l000001?nhaND01_l0003oblOFol_7e_l0003odlG<o`00
00?od/?<00Go0000om72booA`/_odL;;o`000003on6i[`03o`000?oO^;3ogkR`00;o00000_oQ[j80
0ol0003ogZbRomj/XP02o`000005omjRU?l0003og:2Do`000?oQXi800_l000001?oOVXOo0000ombH
QooLV8L2o`000004omZ?O_l0003oeX]nomJ;OPGo00000_oDQGL4o`000004om5mL?l0003ocGU`olei
L0Ko00000_o9M6/01?l0003oaFm[olE_Joo5Kf/3o`000003ol5WI?l0003o`6QV00;o`6QV3?l00004
ok5GG`03o`000?n`EUgo/5IM00;o/5IM8?l00004oiQ1G0;o00000onC?5/7o`0000CoSceQ00Co0000
ohPhH_n8>6;oR3QR1?l00005ohDiI`03o`000?mn<fGo000000;o000000CoPSY]o`000?mk=6_oNcA[
0_l000000omn?7?o0000ogHeL@03ogHeL@;o00000omb>7T3o`0000CoLSn30_l00004og57T0;o0000
1?mkEid2o`0000GoQ6fa4_l00004oiVfk003o`000?nQ`_3oXL;`00?o00001?nVbO82o`0000;o[]Gd
0ol00002ok?FlP;o00000onfh_D2o`0000?o^>;d00Go0000okWWmOl0003o0000okc[l`02o`0000;o
_Noc00?o0000okcalonllO<00ol000000onjm_7o0000ok[hkP04o`000003okWkj?l0003o000000Co
000000?oS^VgoookJ_oonfX0TooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z00;o
oo]Z0004oookJP03o`000?oonf[ooo]Z02cooo]Z2?l000000olOP^So0000o`000005o`000004omaf
BOl0003o0000omenF0Co00000_oLQFL3o`0000;ofh]d0_l000001?oISGgo0000omR=O_oHSGh3o`00
0004omNBR?l0003oei:8omNBR0_o00001?nhaND01?l0003o]lCTokO4i?l00002ol_7eP05o`000?oB
`lcod/?<om;3c?l000000ooA`//01Ol0003ocl3;o`000?oQ^Joo000000?ogkR`00Co0000omff/Ol0
003o00000ooN[:802Ol0003og:ZSo`000?l0003og:2Do`000?oQXi;o0000omjPTP02o`0000;og9R7
00Co0000omVDR?l0003o00000ooFRgh00ol0003odhQno`000002o`0000;oe8Eg00?o0000om22N?o@
PWP01Ol000001?o9MVoo0000olaiL?o<NG03o`000003olUdJol0003oaFm[00;oaFm[00?o0000ol5[
JOl000001_l00004ok]SIP;o00000oniHfL4o`000003ok5GGol0003o000000Go/5IM00Co0000ojiD
Gon^E5oo00000on[D5d01Ol0003oZE5PojUAH?nYDF3o000000?oYDaN00?o0000ojA=H?nTCF000_nT
CF001Ol0003oWdMNoim7G_nOAeko000000?oWTMO00?o0000oiQ1G?nH@E`02?l00003oiI3H`03o`00
0?n??F7oSceQ00CoSceQ00?o0000ohPhH_l000000_l00002oh`nI`03o`000?n5>FOoQCUW00;oQCUW
1?l00004oh8jK@?o00000omn?7<00ol0003oMSEao`000002o`000003og/oNol0003oLSQi00?o0000
00CoNTF5o`000?mb?h?oLSn30_l000000omjCI3o0000og57T002og57T0?o00000omkEid00ol0003o
PF^ao`000005ohA]/@;o00001On@QlH00ol0003oSI;Co`000004oiZPf003o`000?nI]^coVKK/00Ko
VKK/0_l00003ojK9lP?o000000?oZLodo`000?n^eO@00_l00004ok?FlP06o`000?ncfoCo/m_do`00
0?nfh_Go00000onhh_@4o`000004okWZmOl0003o0000o`0000;o_Noc0_l000000onllO?o0000o`00
0002ok[fl@04ok[fl?l0003o0000okSik@;o000000?o/o[Wo`000?n^n^000_l000000onTmmCoS^Vg
o`00002GoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX00_oonfX000Cooo]Z00?o
0000oookJ_oonfX0;_oonfX5o`000005oaEmiOl0003o0000o`000?l^Rnd01Ol000001?oLMTWo0000
o`000?l00002omanFP;o000000Sog8EWo`000?oKQ6SofhAXo`000?oKRgCo0000omV7L`?o00000_oH
SGh01?l0003of8eno`000?l00002omNBR0[o00000_nhaND2o`0000Go]lCT00Ko0000ol[6eoo:a]Oo
0000om;3c?l00003om72b`04o`000?o?`<_ocl3;olo0b`;o00000_oO^;001?l0003ogKJaomff/OoM
][42o`0000;ogZbR00?o0000ombZXooLZZ<00ol000001?oQXi;ogZ2BomjPT_oNX984o`0000;ofIB8
0ol000001OoFRgko0000om>8O_l0003oehan00Co00000oo@PWP00ol0003obgagol]lM`02o`0000?o
c7U`00?o0000olUgL_o9Mg801Ol000001Oo5Kf_o0000o`000?o3KF[o000000?o_f]]1Ol00002ok]S
I@05o`000?niHfOo^F=WokUSIol000000_neGVDWo`0000CoWDQS00?o0000oiI3I?nF@f@00_l00002
oiI3H`04o`000?n??F7oSceQohlmH@Go00001On<?VL00ol0003oQCUWo`000002o`0000;oR41^00Co
0000oh8jKOn2>VgoPSY]0ol00004oghlL`?o00001?mk?g/2o`000004ogU4Q?l0003oNTF5ogY5Q@?o
00001?mjCI03o`0000;oNENM0_l000001OmkEigo0000oh5[/On1Jk7o000000?oQ6fa0_l000000on:
Q<Oo0000oi27aP05oi27aP03o`000?nJX=SoVZ3H00CoVZ3H00?o0000oiVfk?nI]^`00ol00003oino
k`04o`000?nVbO;o0000o`0000GoZLod00?o0000ok?Fl_nce_800once_801?l0003o/m_dok?Km?nc
fo@2o`000004okSRm?l0003o0000okWUm0;o00000_nij_D00ol0003o^N_eokW[m@04o`000004okca
lol0003o0000o`0000;o^_K`0_l000001OnhnNgo]_[Xo`000?ncn^Oo[_[P00?o000000?oY?ODohkY
]ooonfX0VOoonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z007ooo]Z0004oookJP03
o`000?oonf[ooo]Z033ooo]Z1Ol000000olEONGo0000o`000008o`000005om]gBol0003o0000o`00
0?oKOE/00_l00002om^4J0Co00000_oIQg<4o`0000;of8en2Ol00005oj70k`03o`000?nga>Co]lCT
00;o]lCT0_l00003okO4i003o`000?o:a]Oo000000?odL;;00?o0000olo0boo?`</00_o?`</3o`00
0003omnh/?l0003ogKJa00;ogKJa00Co0000omZd/Ol0003o00000ooLZZ<00ol0003ofJNSo`000002
o`0000;ogZ2B00?o0000om^NTooKWY<00_l000001?oIU8So0000omFAROoETHT4o`000004omN<O_l0
003oe8YoomB:O`?o000000?od89ho`000?o;O7L00_o;O7L3o`000003olaiL?l0003obGMb00;obGMb
00Co0000ol=`LOo3L77o`g1a1?l000000oo3KF[o0000okm[K@02okm[K@03o`000?nlIf_o_6M[00Oo
000000Go^F=Wo`000?neGVGo]EiUo`000002okALI@03o`000?n^FFKo[UUV00?o[UUV00?o0000ojeF
I?n]EV@01?n]EV@2o`0000KoYU1S00?o0000ojI@IOl000001onPBf<00ol0003oWDQSoie8H`04oie8
H`03o`000?nF@fCoUT=T00Wo00000onB@fP00ol0003oS3iWoh`nI`06o`0000CoR41^00?o0000oh8j
KOl000000_l00002ohE2M003o`000?mn?7?o000000;o000000?oPdElo`000?mk?g/00omk?g/2o`00
00;oNDB400Co0000ogY5QOl0003o00001OmjCI02o`0000GoNENM1Ol000001?n1Jk7o0000ohA]/Ol0
0004ohZ4a`03o`000?n@QlKoT8O600;oT8O60_l00007oiZPf0;o00001onO_nl01?l0003oZLodojW?
m?nYco@3o`0000?o[=Ce0_l000000onbfOCo0000ok?Km003o`0000;o]>7f00Co0000okWUm?niiOCo
00000onij_D00ol0003o^N_eokW[m@03o`0000;o^O7d0ol00002ok[fl00:o`000?nhnNgo0000okKj
j?ncn^Oo0000ojkjh?n]n]oo0000ojCge0?o0000V_oonfX00ol0003ooo]ZoookJP0:oookJP03o`00
0?oonf[ooo]Z007ooo]Z0004oookJP03o`000?oonf[ooo]Z037ooo]Z0ol000000ol0JMOo0000oa9l
i002o`000003obb;kOl0003o<Xk_00;o00000_m8V_<Go`0000CoS[[d00?o0000oj70konQ`>l00ol0
0003oj30k`04o`000?nga>Co0000o`0000Ko]lCT00Go0000olS5eol0003odL;;o`000005olo0b`;o
cl7=0ol00002omff/@04o`000?oJ];7of[BaomZd/@Co00000_oIYj<2o`000003omfWWOl0003o0000
00?ofijC00Co0000omRKU?l0003o00000ooETHT2o`000003omNBR?l0003o000000;oe8Yo00?o0000
om26P?o@QX001?l000001?o;O7Oo0000olenN?o=OWP5o`000003olUgL_l0003o`g1a00;o`g1a00?o
0000olAbLOo4LW401Ol000001?noJfgo0000okaWJol00002okaWJ`04o`000?nfHVco]V9/okIRK0_o
000000Co[UUVo`000?n_FFKo00001_n]EV@00ol0003oYU1SojI@H`05ojI@H`03o`000?nPBf?oX4]S
00;oX4]S3_l00004oiM8J@;o00000onB@fP6o`0000CoSdE^00?o0000ohQ0K_n8@6h01Ol00003ohE2
M0Co00001?n3AG`00ol0003oNcmko`000002o`000003oh5:Q_l0003oNDB400?o000000?oPE:Ao`00
0?mjCI000_mjCI02o`000003ohAMW?l0003oNENM00?oNENM0_l00004oh1//Q?o00001?nI/nX00ol0
003oWko_oinok`03o`0000;oY<Ob00Co0000ojW?m?l0003o00001?n/e?D01ol0003o/MGco`000?nb
fOCo0000ok?Km?l000000ondhOH01?l0003o]>CfokCTm_ndi?H2o`0000;o^N[e0onijoD2o`0000?o
^O7d00?o^O;co`000?ngm_402Ol000001On]n]oo0000o`000?l0003oPn>a09gooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP01oookJP000ooonfX00ol0003ooo]ZoookJP0coookJP;o
000000?o05k=o`000?l000003Ol00004oeZSmP04o`000?mYZoOo0000ofb/m`Oo000000?oN[;gog^c
m_l000001_n>^_@2o`0000OoX<3_00?o0000okO4i?nga>@00_nga>@3o`0000;o]/?T00Co0000olS5
eol0003o00001?o?`</3olo1c@;o000000Cof;foo`000?oM][7o00000ooJ];400ol0003of;:bomRb
/P02o`0000;ofJNS00?o0000omfWWOoMYid00_l00002om^NT`03o`000?oHViCof9^D00?o000000?o
eI69o`000?l000000_oGTXP3o`000005omB:Ool0003od8J0om26P?l000000_o<Ph04o`000003olen
N?l0003obG]i00;obG]i1_l00003olAbL@04o`000?nmK7;o_Faboke/LPKo000000?o_6M[o`000?nf
HV`00onfHV`00ol0003o]F5[okEQJ`03okEQJ`03o`000?nbGfgo/Um]01Oo00000onTE6d00ol0003o
WTi[o`000005oii>J`04o`000?nGB6WoUdQYoiM8J@So00000_nEBVl00ol0003oSdE^ohm5KP02ohm5
KPKo00000on<AgD00ol0003oQD9do`000002o`0000;oRD]m00Co0000oh=5O?n3AGcoPdEl1?l00004
oh5:QP;o00000_n0DY800ol0003oPE:Aoh5BT@03o`0000?oQ5fL00?o0000ogUGWOmiEid00_l00000
0on9KJgo0000oh1//P03oh1//P;o00001_nCRLH01?l0003oSi;BohnBd_l00003oi^Oe`03o`000?nI
/n[oVK?Z00KoVK?Z0_l00006ojC7lP03o`000?n/e?Go[=Ce00;o00001OnaeO<2o`000003okCQm_l0
003o000000Co]>Cf0_l000001_ngjOKo0000o`000?nijoGo0000okW]m@;o000000Wo^O7do`000?ni
l_?o^O;co`000?ngm_7o0000okKflOl000000_nbn>d02Ol0003o[?WVo`000?l0003oYOOMo`000?nK
lm7oPn>ao`00002OoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX00OoonfX000?o
oo]Z00?o0000oookJ_oonfX0=?oonfX5o`000003o`mli?l0003o000000;o:X_]0ol00002odJJl`ko
00001Omj/_L4o`0000CoS[[d00?o0000oj30konP`>l00ol00003oj30k`04o`000?nga>Co0000o`00
00Ko]/?T00Co0000olO5f?o7aMSo00000_o?`</3olo1c@05o`000?o=`<kocL3>o`000?oH_Kl00ol0
00000ooJ];7o0000omRb/P02omRb/P05o`000?oE[k?o0000omVWXol000000_oMYid01?l0003ofZFO
o`000?l00003omRKU003o`000?oDV9Coe9RD00?o00000_oGTXP00ol0003oe929omB@R@04o`000004
om26P?l0003oc8>0olb3P0;o000000CocHB1o`000?l0003o00000oo9NgT00ol0003oaGMiolEgN@05
o`000003olAbLOl0003o_Fab00?o_Fab00Co0000oke/L_nmK7;o_Fab2ol00002okEQJ`04o`000?nb
Gfgo/Um]o`0000;o/5e/00?o0000ojiLK_n^G6h00on^G6h2o`0000KoZEU^00?o0000ojADK?l00000
1OnTE6d01?l0003oWTi[oii>Jol00002oii>J`Ko00000onKCg001Ol0003oUD]aoiE;LOnEBg7o0000
00;oUDY_00?o0000ohm5K_l000000_l00002oi9<MP03o`000?n<AgGoS4Me00;oS4Me1?l00004ohU;
O@03o`000?n3AGco000000;o00000_n7D8L00ol0003oPDZ6oh5:QP02oh5:QP;o00001?n0DY800ol0
003oPE:Ao`000005ohAMW0?o00000on9KJd00ol0003oP6bboh1//P02o`000003oi20__l0003oThW6
00KoThW60_l00005oi^Oe`03o`000?nI/n[oVK?Z00?o00000_nO_^h00ol0003oY<ObojC7lP03o`00
00CoZ<kc00?o0000ok7ElonaeO<00_naeO<3o`000003ok7JmOl0003o000000;o]>Cf0_l00002okOU
mPCo00000_nfk?H2o`000003okWam?l0003o000000;o^O;c0_ngm_400ol0003o]_Kaok;hk@02ok;h
k@03o`000?n/nNKo[?WV00;oYOOM00?o0000oi_cdOn3hk40XOoonfX00ol0003ooo]ZoookJP08oook
JP03o`000?oonf[ooo]Z007ooo]Z0003oookJP03o`000?oonf[ooo]Z03Kooo]Z0ol000001?l0L=_o
0000o`000?lGP>L:o`0000CoFJCf1?l000000om[[?Oo0000o`000002o`0000?oN[?g00?oNk?go`00
0?n>^_@01On>^_@2o`0000OoX<3_00?o0000okK3i?nf`n@00_nf`n@3o`0000;o]<;T00Co0000olO5
f?o7aMSo00000oo?`Ld01?l0003ocL3>olg0c_o=`<h2o`0000?oe[g100Go0000omRb/_oH/[;of;:b
o`000003omF_/`?o000000CogJNMomZUWooJYIoofZFO0ol000000ooHViCo0000omBHU002omBHU0Go
00000ooDT8T00ol0003od8b9om2<R@04o`000003oln6P?l0003ocHB100;ocHB10ol000001_o9NgWo
0000olEgNOl0003oagUio`0000?oa7Mj1ol00004oke/LP03o`000?niJW?o^FYc00;o^FYc0_l00003
okMXM2Co00000_nPDg400ol0003oVdm`oi]?L004oi]?L003o`000?nEBg7oUD]a00Ko00001OnBC7H0
0ol0003oS4Meo`000002o`0000;oSdmn00?o0000ohU;OOn9Bgd00_n9Bgd3o`0000GoQe2700?o0000
oh5:Q_l000000_l000000on7Ei;o0000oh1BTP03oh1BTPGo00000_n4GI`2o`0000KoRFf]0_l00004
oi20_P03o`000?nCRLKoThW600?oThW60_l00007oi^Oe`;o00001_nO_^h2o`0000?oZ<kc0ol00002
oj_Cm@05o`000?naeO?o0000o`000?ncfO@00ol00002ok;OmP;o00000ongiOH00ol0003o]nWfokOY
mP03okK/mP04o`000?nfkoGo0000o`0000?o^O;c0_ngm_42okKfl@03ok;hkOl0003o000000;o[?WV
00Co0000ojGggOnUmmgoVo?A0_l0002SoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oo
nfX00OoonfX000?ooo]Z00?o0000oookJ_oonfX0=ooonfX8o`000003obN;k?l0003o;Hk^01Co0000
0_mj/oL4o`0000GoSK[d00?o0000oj30konP`>l00ol00002oinok`04o`000?nf`nCo0000o`0000Ko
]<;T00Ko0000olG4fOo5a=Wo0000olo1cOl00003olg0cP03o`000?o:_/oo000000?oe[g10_l00000
0ooH/[;o0000omF_/`03omF_/`03o`000?oC[[?o000000;o00000_oJYIl00ol0003oej:PomNRX005
o`000004om:FUOl0003oeYVComJIT`Co00001?o@S8T00ol0003oc8V:o`000004o`000004olf4POl0
003ob821olR0P@Oo00000oo4MgX01_l0003o`7=jol1cN_o0Lg[o0000ol1cNPWo00000_nhJG<00ol0
003o]fQdokMXM002okMXM003o`000?ncI7;o000000Co/F9b00Go0000ojmQLon_HG?o[f5co`000002
ojaMLP03o`000?n[GG?oZeec00?oZeec00Co0000ojIIL_nVFG;o00001?nUFG800ol0003oX5=aoj1C
L@02oj1CL@03o`000?nPDg7o000000?oVdm`1ol00004oiMAN004o`000?nBC7KoTTafoi9<MPGo0000
1On?Cgh00ol0003oRD]mo`000002o`000003ohiDQol0003oQe2700?oQe271?l00004ohMGTP03o`00
0?n0DY;o000000;o00000_n6H9h00ol0003oPUnRo`000004o`0000GoRFf]0_l00005oi20_P03o`00
0?nCRLKoThW600;oThW61ol00004oiZbj@03o`000?nO_^koWkk^00?o00000_nTa_401?l0003oZ<kc
o`000?l00006oj_Cm@03o`000?ncfOCo/mWd00;o000000Co/]ofo`000?l0003o00000onbi?L01Ol0
003o]nWfokOYm_l0003o]^cf00Oo000000Go]O;dok?el_l0003o0000okKfl@02o`000003ok;hk?l0
003o[?WV00;o00000_nUmmd2o`000:Kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zoook
JP01oookJP000ooonfX00ol0003ooo]ZoookJP0ioookJPCo000000?o2G[Ro`000?l000001ol00000
0om2V_?o0000o`000005o`000003ofR/n?l0003oJJch00;oJJch00?o0000ogVcmomi/oL00_mi/oL0
0omj/oOo0000ohfjm006ohfjm0;o00001_nO_nl00ol0003o]<;TokC2i002okC2i0?o00000_nc`ND0
0ol0003oaLCIolG4f@03o`000003olg0c_l0003ob[k?00;ob[k?00?o0000omJm`Ol000000_oC_L@2
o`0000?oeJnc00Ko0000om>^/ooC[[?odjjco`000?oH[jl2o`0000Coej:P00?o0000om>OXOoCWj40
0ol00002omJIT`03o`000?oCUY?odiJC00?o000000Ood8b9o`000?o<RH[oc8V:o`000?o?S8Wo0000
00;ocHV90ol00002olR0P@03o`000?o5OH7o000000;oagj11?l000001oo4Mg[o0000ol1cN_o0Lg[o
0000ol1cN_l000001?nnLW/00ol0003o^VmjokY_NP0>o`0000;o/F9b00Co0000ojmQLon_HG?o0000
0on/GG801Ol0003oZeecoj]MLon[GG?o000000CoYUUb00Co0000ojEIL_nUFG;o00000onPDg48o`00
00CoWUMh00?o0000oiMAN?nGDGP00_nGDGP6o`0000?oUUAo00?o0000ohm?O_n?Cgh00_n?Cgh4o`00
00CoSUB700?o0000ohM@Qol000000_l00002oheKTP03o`000?n7Ei;oQeNB00;oQeNB0ol00005ohIP
WP;o00001?n9Kjl<o`0000;oT82n1Ol00002oifQe`03o`000?nJ/^WoV[;Y00KoV[;Y0_l00006ojC6
l@03o`000?n[doGoZm?e00;oZm?e0_l00003ojgGmP;o00000_nbgoH00ol0003o/^Cgok;Tm`02ok;T
m`03o`000?ndiOOo000000;o000000?o]^cfo`000?ngkOH00_l000001?nelOCo0000okGbm?nel_@3
o`000005ok7flOl0003o0000ojcgk?nXn>H00ol000001?nMm=[oTNo=o`000?mffjZXoookJP03o`00
0?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX00OoonfX000?ooo]Z00?o0000oookJ_oonfX0>_oo
nfX2o`000004o`1Td?l0003o0000o`UjhPco00000_mFY?L;o`000003ogVcmol0003o000000?o0000
1?n<^_D00ol0003oWko_oinok`03o`0000;oW[o`00Co0000okC2i?l0003o00001_nc`ND00ol0003o
`lCJol?4fP02ol?4fP;o00000oo:_/l2o`0000?odkg400Go0000om6maol0003oeJnco`000004om>^
/`03o`000?oH[joof:n_00;o00000_oGXZ001_l0003odinQom>OXOoCWj7o0000om2MXP?o00000ooC
UY<00ol0003oci:DolnBU005o`000003oln<ROl0003ocHV900;ocHV900?o0000olR5R_l000001?l0
0002olMnP@04o`000?o4O8;oa7b2olAlPP[o00000_nnLW/00ol0003o^Vmjo`000002okY^NP03o`00
0?ndJG[o]6Uj00?o]6Uj00?o0000ok=XNOncJ7T00_ncJ7TIo`0000CoXUUh00?o0000oiiGN?nNEgP0
1?nNEgP00ol0003oUe5ho`000003o`0000;oVUV00_l00005oiIDO`03o`000?n?Cgko000000;o0000
0_nCFHP00ol0003oSUB7ohiDQ`02ohiDQ`?o00001On=Fi800ol0003oQeNBohMGTP02o`000003oheU
Wol0003oQV2N00CoQV2N0_l00005ohU_[`04o`000?n8LkKo0000o`0000?oUXO22?n?Tm<00ol0003o
WJ7GoifQe`04oifQe`03o`000?nJ/^WoV[;Y00?o00000_nP_Nh00ol0003oY<KaojC6l@03o`0000Co
Ylgd0_l00003ojgGmP;o000000Co/MWeok3Nmol0003o00000_nbi?L2o`0000Co]>Gg0_ncjOL2o`00
0005okO]m_l0003o]O7dokGam?l000000_nel_@2ok;elP;o/OKa00?o[_S/o`000?n/mn`00_l00000
0onUmnCoWOCJoigdfP02oi7_c@03o`000?oonf[ooo]Z0:Oooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP01oookJP000ooonfX00ol0003ooo]ZoookJP0loookJP03of800?l0003o0000
00So000000?o>iObo`000?m0V_<01ol000000omV[?So0000ofR]n002ofR]n003o`000?mh/oSoN;?h
00?oN;?h00?o0000ohbjmOn<^_D01On<^_D2o`0000KoW[o`00?o0000ok?1iOnc`ND00_nc`ND3o`00
0003ok71i_l0003o`lCJ00;o`lCJ00Ko0000ol74g?o1a=co0000olZncol00002olNmd@03o`000?oC
_LCo000000?odKg70ol00002om>^/`;o00000_oH[jl01Ol0003oe:^^o`000?oGXZ3o000000?odinQ
00Co0000om2MX_l0003oeJ2O0ol000000ooCUY?o0000olnBU002olnBU003o`000?o<T9Coc92D00Co
00000_o=RHT00ol0003ob8F:olR5RP02olR5RPGo00001?o4O8801_l0003o`GV1ol5iPOl0003o`GV1
o`0000?o_WN21ol000000onjKW[o0000okAYNP03okAYNP03o`000?ncJ7Wo/fQi00Co/fQi00Co0000
ok5VN_naIW[o00001?n]HgT01?l0003o[6=jojaSN_l00004ojQNN@04o`000?nWGWWoYeiio`0000Oo
XUUh2Ol00005oiYIP004o`000?nEE83oUEB0o`0000;oUUAo1?l00005oi=IR003o`000?n>E8Oo0000
00;o000000?oTUnCo`000?n=Fi801On=Fi83o`0000?oSFFO00Co0000ohIPW_n6H9koQV2N0_l00000
0onAM:ko0000ohU_[`04ohU_[`;o00001_nFQl84ohnCd`;o000000?oVZ3Ho`000?nMXML01_nMXML2
o`0000KoX;g^0_l00003ojO=m0?o00000_nZdoD01?l0003o[MOfo`000?l00002ok7Im@;o00000_n`
goL2o`0000Go]>Gg0ol00002ok?/m`04ok;am_l0003o0000okGbm0;o000000Go/_Gbo`000?nam_7o
/OKaojkhk002ojcgk003o`000?nUmnCo000000;oWOCJ00?oTNo=o`000?oonfX0ZooonfX00ol0003o
oo]ZoookJP05oookJP7o00000OoonfX1oookJP000ooonfX00ol0003ooo]ZoookJP0koookJPOo0000
00?o1WWPo`000?l000002?l000000omAXoOo0000oeBTm`0<o`000003ogRcn?l0003o000000;o0000
1?n<^oD00ol0003oW[o`oijol003o`0000;oWKo`00Co0000ok?1iOl0003o00001Ona`NH00ol0003o
`lCJo`000004ol74g0;o00000oo7_M400ol0003odKg7om6ma`02om6ma`03o`000?o=]/?ocKK300?o
000000?od:ffo`000?l000000ooDZjh3o`000007om>OXOl0003od9fRom2MX_l0003oeJ2Oo`000002
om:MWPCo000000Soci:Do`000?o<T9Coc92Do`000?o?TY?o0000olf@T`?o00001?o8QHX2o`0000;o
b8F:1?l000001oo4O8;o0000ol5iPOo1NH7o0000ol5iPOl000001OnnMh800ol0003o^gB2o`000002
ok]cP@co00000_ncJ7T00ol0003o/FIjojeSN@05ojeSN@03o`000?n/Hg[o000000;oZ5ii3ol00005
oj1MP@03o`000?nJFH3oVUV000;oVUV02?l00002oiUMR@03o`000?nCFHSoTeV800;oTeV81?l00004
oi9OT`03o`000?n=Fi;oSE^B00?oSE^B0_l00006oheUW`?o00000onAM:h01?l0003oRFn_ohU_[on9
Kjl2o`000003oiF2_?l0003oUXO200GoUXO200Go0000ohnCdon?Tm?o0000oiZPf007o`0000?oWKCX
00?o0000oj2mk_nP_Nh00ol00003ojC6l@04o`000?nWcOCo0000o`0000KoZ]?e00Ko0000ok7ImOna
fOGo/MWeo`000?n`goL3o`0000?o/>Ch0_l000001_ncjOOo0000ok?/monck?Oo0000ok?]m`Co0000
00Co/O;eo`000?l0003o/OKa0ol00002ojcgk0;o00000onMm=X00ol0003ooo]ZoookJP2]oookJP03
o`000?oonf[ooo]Z00Cooo]Z0Ol00001oookJP7ooo]Z0002oookJP03o`000?oonf[ooo]Z03Wooo]Z
0ol00004oookJP07o`000?l0El7o0000o`000?l=OnCo0000oan9jP03o`000003ocVGl_l0003o?Y[c
00Oo00000_mU[?P01?l0003oIjghofN]n?l00005ogNcn003o`000?n<^oGoS;_e00GoS;_e0_l00006
oifol003o`000?na`NKo/L7V00Ko/L7V00Go0000ol74g?o1a=co`LCLo`000003oko4gP04o`000?o7
_M7o0000o`0000?odKg700Go0000olff`oo=]/?ocKK3o`000002olZda0;o00001?oDZjh00ol0003o
dJR_om6X[`04o`000003om2MX_l0003odYfN00?odYfN00?o0000olnJX?o?VZ001Ol000000oo?TY?o
0000olf@T`02olf@T`?o000000Cob8F:o`000?o6Ph[o00000_o8QHX01?l0003oa8::olB2R_o4PXX:
o`0000;o_WN200?o0000ok]dP_nkLh400onkLh400ol0003o^762okQaPP02okQaPP;o00001?ndKX8?
o`0000?oZVF100?o0000ojUUPOl000001onUHH000ol0003oX5f1o`000004oj1MP@03o`000?nJFH3o
000000;o00000_nMHHT01Ol0003oV5f9oiQMROnHGHWo000000?oVEf900?o0000oi=IR?l000000_l0
0002oiMTT`03o`000?nBGi?oTUnC00CoTUnC00?o0000oheKT_l000000_l000000onBJ9oo0000oheU
W`04oheUW`;o00001_nAM:h3o`0000CoUH:l00Co0000oiJ7`_nFQl;oUXO20_l000000onFQl;o0000
o`000002o`0000?oWjGI00?o0000oifdj?nM]>P01OnM]>P2o`0000OoY<Ka00?o0000oj[CmOnZdoD0
0_nZdoD2o`0000?o[=Og00Go0000ok7ImOn`goOo/=ogo`000004ok3Tn004o`000?nbiOSo0000o`00
00;o/ncg0_l000001?nckOOo0000ok7amOl00002ok7bm@?o000000?o[?Gao`000?l000000_l00000
0onNmN;o0000o`000003o`000;3ooo]Z00?o0000oookJ_oonfX01?oonfX1o`00007ooo]Z0OoonfX0
00;ooo]Z00?o0000oookJ_oonfX0=_oonfX3o`0000Wooo]Z0_l000001Ol0GlSo0000o`anhol0003o
78SY00Oo000000?oCj?go`000?mBY?L03?l000000omg/oSo0000o`000002o`0000CoS;cf00?o0000
oifol?nM_o000ol00002oibol@03o`000?na`NKo/L7V00?o00000on_`>L00ol0003o`LCLo`000005
oko4gPCo000000?odKg7o`000?o=]/<00_o=]/<00ol0003ob[C4olZda002olZda0?o000000?oe:^^
o`000?oAZ:l00ooAZ:l00ol0003ocJJ`olfV/003o`0000?odYfN00Go0000olnJX?o?VZ3ociZPo`00
0002ol^GX@;o00001?o=T9<00ol0003ob8bDolR<U007o`0000Coa8::00Ko0000ol5oR_o1Oh[o0000
ol9oR_l00003okimRPOo000000?o^g>1o`000?nhLH800onhLH82o`0000Ko]6j20_l00006ojmYP@03
o`000?n^JH7o000000KoZVF10_l00003ojEQP0go00001OnMHHT01_l0003oV5f9oiQMROnHGHWo0000
oiUMR@Co00001OnGI9<00ol0003oTUnCoi9OT`02oi9OT`Co00001OnBJ9l00ol0003oSFFOo`000002
o`000003oiAc[?l0003oTGB^00CoTGB^0_l00006oiF2_0Co00000onGTlh00ol0003oWjGIoinUf@05
oinUf@03o`000?nM]>SoWKCX00?o00000_nR_nh00ol0003oY<KaojC6l@03o`0000CoYlgd0_l00002
ojcGm`?o000000Co[mWfojoNn?l0003o00000_n`i?P2o`0000?o/^Gh00?o0000ok3Zn?n`j_P00_l0
0002ok?]m`;o/O7e00Go0000ok7bmOnal_Go[OGbo`000002ojcel@03ojOfk?nVm^_o000000?oW_GR
00?oUO7Go`000?l00000/ooonfX00ol0003ooo]ZoookJP03oookJP7o00000OoonfX1oookJP000_oo
nfX00ol0003ooo]ZoookJP0coookJP?o00003OoonfX7o`000003oab8jOl0003o000000Wo00000_mS
[?T01?l0003oIJgiofF]nOl00006ogJcn004o`000?n<_?KoS;cfohblmPGo00001_nL_o42o`0000Oo
[l3W00Co0000oko4g_noa=ko_lCN0_l00004okc4h0;o00000oo=]/<00ol0003ob[C4olZda002olZd
a0;ob;?600Co0000om6c_Ol0003o00000ooAZ:l00ol0003ocJJ`olfV/002olfV/003o`000?oAYjko
000000;o00000oo?VZ001?l0003obiNQol^GXOo;Uj44o`000003olf@Tol0003ob8bD00?ob8bD00?o
0000olJ:UOl000000_o8S9@4o`000004olB2R_l0003o`Gn:o`0000;o`Wn:00?o0000okimR_nnOHX0
0onnOHX2o`0000?o_7Z:9?l00003ojMYRP04o`000?nRIHWoXVF9o`0000CoXfF900?o0000oieQROnM
HHT00_nMHHT8o`0000;oW6RC00?o0000oiMTTonGI9<01?nGI9<00ol0003oTUnCo`000002o`0000;o
UfbO00?o0000oi9XWonBJ9l00_nBJ9l4o`0000GoU7>/00Co0000oi5d[_nAM:koTGB^1_l00003oiJB
cP04o`000?nGTlkoUi?>oiNCcP;o000000?oWYkDo`000?nOYMT01onOYMT2o`0000KoX[o^0_l00003
ojO=m0?o000000?oZM?fo`000?n/eoL00_l00003ojoImP;o00000_n^goP2o`0000;o/^Gh0_l00000
1on`j_So0000o`000?l0003o[nchok3]n?n^l?H00_l000001Onal_Go0000ojgel_n]mO;o000000;o
[?Ga00?o0000ojKfjol000000_nNmN801?l0003oUO7Go`000?l0002eoookJP03o`000?oonf[ooo]Z
00;ooo]Z0Ol00001oookJP7ooo]Z0002oookJP03o`000?oonf[ooo]Z033ooo]Z0ol0000BoookJPGo
000000Go6HOXo`000?l0003o0000ocBFl@03o`0000;oCJ?g00Go0000oe2Tmom@Y?Oo0000of6/n@09
o`000004ogJcn?l0003o0000o`0000CoR;[f00?o0000oibolOnL_o400ol00002oiZnl@03o`000?n_
`>Oo[l3W00?o00000on/`>P00ol0003o_lCNo`000004okc4h007o`000?nk_Mco^kgLok^mg?l0003o
cKK3o`000003olZda003o`000?o8/lKob;?600;ob;?60_l000001Oo>]L7o0000o`000?oAZ:oo0000
00?ocJJ`00?o0000ol^U/_l000000_oAYjh3o`000003olnJX?l0003obiNQ00?obiNQ00?o0000olfG
WOo=Uid01Ol000001?o8S9Co0000olJ:UOl00002olR<U004o`000?o4R9Coa8RDolB8U0[o00000_nn
OHX2o`0000Co_7Z:00?o0000okUhRoniN8/00_niN8/2o`0000Ko]GB:0_l00006ok5aRP;o00001on/
KHX2o`0000KoYfV:00Co0000oj9UROnRIHWo00001?nSIHT00ol0003oWF69o`000002o`0000;oX6ZD
00Go0000oi]VTonKIY?oVfJCo`000003oiaXT`04o`000?nGI9?oUfBCoiMTT`Go00001OnGK9l00ol0
003oTVROo`000002o`0000;oUgF[00Co0000oiAc[?nDLjcoU7>/2?l000000onKS<?oUY;>oiJBcP06
oiJBcP?o00001?nNW]@00ol0003oWjGIoinUf@03o`0000;oWkOY00?o0000oj:ok_nR_nh00ol00003
ojG7lP04o`000?nWcOCo0000o`0000GoZM?f00?o0000ojoIm_n_fOH00_n_fOH00ol0003o[]oho`00
0002o`0000;o[^Ci00Ko0000ok3Wn?l0003o/>[ho`000?n_k?P2o`000003ok3]n?l0003o000000;o
000000CoZ_Cbo`000?l0003o[?Ga1?l000000onNmN;o0000o`000003o`000;Sooo]Z00Go0000oook
J_oonf[ooo]Zo`000002oookJP000_oonfX00ol0003ooo]ZoookJP0]oookJP?o00005ooonfX00ol0
@:Oo0000o`1Zd003o`000003oaV7j?l0003o000000Co000000?oBZ;go`000?l000002ol00003ogBc
n@So00001_nJ__42o`0000Oo[<3X00Co0000okc4h?nla>3o_<CP0_l00004ok^mg0Co000000?ob[C4
o`000?o8/lH01?o8/lH00ol0003oc[G1olje`@02olje`@?o000000GocJJ`o`000?o;YK;objFbo`00
0002om6W[P03o`000?o>XjcocZ>/00Co00000_o;Uj401Ol0003ocINMolfGWOo=Uigo000000?ob9BO
1ol00004olB8U003o`000?o2QYCo000000;o`hND00Co0000okn3U?noPiCo_h>D1ol000000onlNX[o
0000okUhR`03okUhR`;o00001_neM8X2o`0000Ko/G6:0_l00007oja]RP03o`000?nWJH[oYfV:00Go
YfV:00?o0000oj9UROl000001ol00005oj1ZU004o`000?nKIY?oVfJCo`0000?oW6RC1Ol00003oi]`
X003o`000?nGK9ooUfbO00;oUfbO1?l00003oiMeZ`Ko00000_nFO;@3o`0000GoVhc31onFT/h00ol0
003oWYkDoijNe005oijNe0;o00001_nO]nT2o`0000OoYLOb00Co0000ojWCm_nYdoKoZM?f0ol00003
oj[Hm`05o`000?n_fOKo[]ohojkOn?l000000on^i?T00ol0003o[nGio`000003o`000008ojo/n?l0
003o/>ghok3]n?l0003o[O7fo`000?n/l_D5o`0000;oX?CZ0ol000001?n<kMCoPNK6ofgI/?m]fK2i
oookJP05o`000?oonf[ooo]ZoookJ_l000000_oonfX000;ooo]Z00?o0000oookJ_oonfX0:_oonfX3
o`0001cooo]Z2?l00002oc6Fl@Oo00001?mO[?T2of6]n@03o`000?mb]?WoL[Ci00?oL[Ci0_l00003
ohJjm`Go00001OnH__800ol0003o[<3Xojc0j003o`0000;oZ[oY00?o0000okc4h?l000001?nk_M`2
o`000004okNlgOl0003oaKoDolFoe0;o00001?o8/lH2o`0000?oc[G100Co0000olbga_o<]lKoc;O6
0ol000001?o;YK;o0000om6W[_l00003oljS[004o`000?o:XJkobZ6^olZQ[PKo00001Oo8U9l00ol0
003oaI:Qo`000002olRDW`?o000000?oa8RDo`000?o2QY@00_o2QY@00ol0003o`hNDo`000005okn3
U0;o00000onmPY@Do`0000;o/G6:0_l00003oja]RPko000000?oYFjCo`000?nUKY<00onUKY<00ol0
003oX6ZDoj1ZU005oj1ZU003o`000?nKIY?o000000?o000000?oX7:No`000?nKL:001OnKL:000ol0
003oUfbOo`000002o`0000;oVgR[00?o0000oiMeZol000000_l00002oiUm/`03o`000?nFO;CoUWbd
00?o000000?oW8_0o`000?nKS<<01OnKS<<00ol0003oUY;>oiJBcP09o`0000CoWZoT00?o0000oing
jOnO]nT00ol00002oj?1kP03o`000?nUao;oYLOb00?o00001?nWco@2o`0000;oZ]Sg0ol00002ojcK
n0;o00000_n^i?T2o`0000;o[nGi0_l00002ojgZn@;o00000_n`kOP2ojgamP06o`000?n/l_GoZ?Ca
o`000?nWm?7o00000_nPm>X2o`000003oiObh?n<kMCoPNK600;oKMV`_?oonfX01?l0003ooo]Zoook
J_l00002oookJP000_oonfX00ol0003ooo]ZoookJP0WoookJP?o00008OoonfX4o`000004oab<j_l0
003o0000objEl0?o00000om8X_H5o`000003oen/nOl0003o000000Go000000?oL[Cio`000?l00000
0_l00003ohBjn003o`000?nH__;oV;kb00GoV;kb0_l00006ojZoj@03o`000?nk_Mco^kgL00;o^kgL
00?o0000okNlgOng_=d00_ng_=d01?l0003oaKoDo`000?o2_mP2o`000007olRca_l0003oa[O;olJg
bol0003oc[G1o`000003olbgaP04o`000?o7[/7oajk1olN^`@?o00000oo>Xj`00ol0003obZ6^olZQ
[P03olZQ[P;o00000_o;XJd3o`0000;ob9BO00Co0000olFBXOo5TZ7o00000_o8U9l00ol0003oaI2N
olF@WP08o`0000Co_h>D00?o0000okf2U?l000001?nmPY@00ol0003o^WnDokYoU002okYoU0;o0000
1_nfNi<2o`0000Co/WZD1ol00004ojifU003o`000?nYLYCoZG:D00GoZG:D00Co0000ojE^TonUKY?o
00001?nUKY<01?l0003oX6ZDoj1ZU?nPJY@7o`0000CoX7:N00?o0000oi]`X?nKL:000_nKL:04o`00
00CoVgR[0ol00005oiUm/`?o00001OnLRl000ol0003oVhc3oi^<``03oi^<``03o`000?nFT/ko0000
00;o00000onQYMP00ol0003oWZoToij_i006oij_i0;o00001_nS`Nh2o`0000?oYlod0ol000000onX
e?Oo0000oj[Hm`02o`0000;o[=[g0ol00003oj_RnP06o`000?n_iOWo[nGiojoUnOl0003o[N[i0ol0
00000on/k?WoZ^ogoj[_m`02o`000003ojcbmOl0003o000000;oYoCa0_nPm>X4o`000003ohc]e?l0
003o00000;oooo]Z00?o0000oookJ_l000000_oonfX000;ooo]Z00?o0000oookJ_oonfX09?oonfX3
o`0002Gooo]Z2Ol000000ol^UO3o0000o`000005o`0000?oGJci00?o0000oen/nOl000001Oma]?X0
0ol0003oQ;_ho`000002ohBjn0Ko00001?nF__<00ol0003oZ[oYojZoj@03o`0000;oYko[00Co0000
ok^mg?nk_Mco00001_ng_=d00ol0003o`[oHol:of002ol:of0?o000000?oa[O;o`000?l000000oo<
]lH00ol0003oajk1olN^`@03olN^`@Co000000?ocZ>/o`000?o:XJh00oo:XJh00ol0003oaj2`o`00
0002ol^Q[@03o`000?o8WJ_ob9f[00Go000000?oaI:Qo`000?o8U9l01?o5T9h01_l0003o`HjPol6>
X?o1SZ3o0000ol>?W`Wo00000_nmPY@00ol0003o^WnDokYoU003okYoU0;o00001_nfNi<2o`0000Ko
/WZD0_l00007ojifU003o`000?nYLYCoZG:D00KoZG:D0_l00002ojE^T`Oo00000onSMIl2o`0000Ko
X7:N00?o0000oi]`X?l000000_l00002oiil[@03o`000?nKN:_oVgR[00?o000000?oWH6co`000?nI
OK<00_nIOK<3o`000003oij;_ol0003oW8_000GoW8_000Co0000oi^<`onKS<?oVhc31?l00007oj6U
f003o`000?nN[nCoWZoT00?o00000_nR^n/00ol0003oXl7^oj?1kP03o`0000?oY/[c00Co0000ojO?
m?l0003o00001OnXe?L2o`0000;o[=[g00?o0000oj_Rn_n[h_X00_n[h_X00ol0003oZnCjoj_TnP02
o`0000;o[N[i00Co0000ojc/nOl0003oZngh0ol00002ojSamP04o`000?nSlo7oXo?aoj?cl@So0000
`OoonfX01?l0003ooo]ZoookJ_l00001oookJP000_oonfX00ol0003ooo]ZoookJP0QoookJP?o0000
:_oonfX00ol0@jGo0000o`000008o`0000?oAJ;f00Go0000odVSmol0003oFZ_ioef/n@07o`000003
og6dn_l0003o000000?o00000_n1^OP00ol0003oU[kcoiJnl`05oiJnl`;o00001_nW_n/00ol0003o
]kcMokNlg@02okNlg@?o00000_nd_>000ol0003o`[oHo`000004okk0f`;o000000Co`KG>o`000?o<
]lKo00001Oo7[/401Ol0003oa:k4olB^a?l0003objjl00?o00000_o:XJh01?l0003oaj2`olNP/?o7
X;02o`0000Cob9f[00Co0000olBK[Oo4Vjgoa9^]1Ol000000oo5T9ko0000ol6>X003ol6>X003o`00
0?o3Sioo000000Co`8bN00?o0000okf;X?nmRj002ol00006okIkT`;o00001OnbNY@00ol0003o/GRD
o`000006ojifU003o`000?n]MICo000000?oZG:D2?l00003ojQhWP03o`000?nSMIooXgFO00?oXgFO
00?o0000ojAgXOl000000onPLYh5o`0000GoWWb]0ol00005oif1/`?o00001?nNRkl00ol0003oW8_0
oib;`003oib;`003o`000?nLRl3o000000Co000000?oXJ;Eo`000?nQYMP01onQYMP2o`0000KoX[_[
0_l00007ojK:l`04o`000?nXe?OoZ=CgojSDm`?o00000_n/eoH2o`0000;oZn;j0_l00003oj_TnP;o
000000?oZnWio`000?l000000_l00002oj_]n003o`000?nXlOKoZ?7f00;oYo7e1?nSlo400ol0003o
VO;Xo`000002o`0000;oP^S@00?o0000oookJ_oonfX0`OoonfX00ol0003ooo]Zo`000001oookJP00
00?ooo]Zo`000?oonfX08?oonfX3o`0002oooo]Z0ol000001Ol0Nmco0000o`000?l0003o<9Wa00?o
000000?o@Z7fodFRm_l000001Ol000000omJZoWo0000ofndnP04ofndnP04o`000?n1^oWoPK_ioh6k
n@Oo00001?nC__@00ol0003oYko[ojNoj`03o`0000;oY;o]00Co0000okNlgOl0003o00001_nd_>00
1Ol0003o_/3Kokk0fonn`=_o000000?o^l7O0ol00005olN^`@04o`000?o4[/Coa:k4olB^a0;o0000
0oo9/L85o`000003olNP/?l0003ob9f[00?ob9f[00?o0000olBK[Oo4Vjd00oo4Vjd01?l0003oaIVY
olFIZOo5VJT5o`000003ol6>X?l0003o`hnO00Go`8bN00Co0000okf;X?nmRj3o00000_nmRj000ol0
003o^XNNokZ7WP03okZ7WQko00001?n[O:000ol0003oZ7RNojQhWP04ojQhWP03o`000?nSMIooXgFO
00;oXgFO1ol00003oj>1[`04o`000?nNO:goWWb]oiil[@?o000000?oXXFeo`000?nMPK<00_nMPK<4
o`0000OoWX^o00?o0000oib;`?l000000_l00002oinHc0;o00001OnQX]D00ol0003oXJGHoj6Uf003
o`0000?oX[KW00?o0000oj:kjonR^n/00ol00002ojG5l003o`000?nVb_?oY/[c00?o00001?nWd?H2
o`0000;o[=Of0_l00003oj[Mn@;o000000?oZnCjo`000?l000000_n/i_X5o`0000;oZ>ci00?o0000
ojSam_l000000_nWlOD01Ol0003oXo?aoj?clOnPlo3o000000;oVO;X00Go0000oho_g_n2j=3oP^S@
o`000036oookJP;o00000OoonfX00003oookJ_l0003ooo]Z01gooo]Z0ol0000doookJP03o`000?l0
H/Co000000[o000000?o@Z7fo`000?mHZoT00omHZoT5o`000003ofndn_l0003o000000?oOk[i00?o
0000ogjinOl000001onC__@2o`0000KoY;o]00?o0000okBlh?nd_>000_nd_>03o`0000;o/;gS00?o
0000okk0fol000001_nk`Ml4o`000003olN^`Ol0003oa:k400;oa:k400?o0000ol:ab_l000001?o9
/L801?l0003oa:VnolBY__o4ZKh5o`000003olRMZol0003oa9^]00Coa9^]00?o0000olFIZOo5VJT0
0_o5VJT01?l0003o`IN/ol6G[?o1Uj`5o`0000;o`8bN00Go0000okf;X?nmRj3o_H^Po`000002okf;
X003o`000?njQiko^XNN00?o^XNN00?o0000okN4WOngQ9d01OngQ9d2o`0000Go]8>P00?o0000ok>2
X?l000001_n`Oj000ol0003o[gnPo`000007oj]lX003o`000?nXN9koZ7RN00GoZ7RN00?o0000oj=e
Wol000000_l00002ojN2[003o`000?nSPJooXh6_00GoXh6_0ol00002oj:5]@Ko00000onQSKl00ol0
003oWX^ooij;_`05oij;_`;o00000_nOV<`2o`000003oj:Qdol0003oXJ;E00KoXJ;E0_l00007oj:f
i`;o00001_nUaO02o`0000?oYm3f0_l00003ojOFn0?o00000_nZgOT3o`0000;oZN?j00Oo0000ojcV
n_n/i_[o[>Kjo`000?nYjoWo000000CoZ>ci0_l00002oj?`mP03o`000?nSlo7o000000;o000000Go
VO;Xo`000?l0003o0000oh;Xd002o`000<Oooo]Z0ol00001oookJP0000?ooo]Zo`000?oonfX06_oo
nfX3o`0003Wooo]Z2_l00003ocnPm@Go000000CoF:_io`000?l0003o00000om]]?X2o`0000;oOk[i
1_l00005oi6nm@?o00001?nQ_nl01?l0003o];cPo`000?l00006ok2mh`03o`000?nk`Moo^l7O00;o
^l7O0_l00002okVif@03o`000?o3^];o000000?o000000?oa:k4o`000?o2/LX00_o2/LX01?l0003o
bK72olVa`_l00004olBY_P03o`000?o1ZL;o000000;oaZVl1?l00002olBK[@;o00000oo5VJT00ol0
003o`IN/ol6G[003ol6G[004o`000?o1U:So`IBXol6DZ0Wo00001_njQih00ol0003o]hBMokN4W@04
okN4W@03o`000?nfQJ3o000000Co]8>P00Co0000ok>2X?ncPZ3o00001On`Oj001?l0003o[gnPojmo
X?l00006oj]lX0;o00000onXN9h6o`0000GoYh:/00?o0000oj>1[onSPJl01?nSPJl2o`000004oj:5
]Ol0003o0000o`0000;oXi3100?o0000oj6=_onQSKl01OnQSKl00ol0003oWX^oo`000002o`0000;o
XIS;00Co0000oinHc?l0003o00001?nRXM<4o`0000CoX[7S00?o0000oj:fionR]^L00ol00002ojC0
k@03o`000?nUaO3oYLG`00?o00001?nVcO@2o`0000?oYmKh0_l000000onZfOSo0000o`000002oj[M
n@05o`000?nYho[oZN?jojWSn_l000000onXiO/3o`0000?oZ>ci0_l00003oj?`mP?o000000?oVo7`
o`000?l000000_l000001?n6jm_o0000o`000?mXf;[6oookJP?o00001?oonfX00003oookJ_l0003o
oo]Z01Oooo]Z0ol0000noookJPGo000000Co5H_Wo`000?l0003o00000_m3Y?L00oloX?Go0000o`00
0004oeF[n@;o00001?m^]_/00ol0003oO;[jogbjnP02ogbjnP;oNkWj1?l00004ohjnmP03o`000?nQ
_nooXKo_00CoXKo_00?o0000ok2mhon`_N<00_n`_N<2o`0000?o[;kV00Co0000ok_1gol0003o0000
1?ni^MT2o`0000Co_kcG0_l00003ol:abP03o`000?o9/L;o000000Coa:Vn00Co0000ol6Y`_o1ZL;o
`JW20_l00004olB^``Go000000?oaIVYo`000?o1Uj`01?o1Uj`00ol0003o_iR_o`000004ol6DZ006
o`000?nmU:co_IB/okfD[?l0003o_I>[4Ol00004okB3X006o`000?ncPZ3o/h:Pok>2X?l0003o/7nP
4_l00003ojV6[`;o00001onWPZ`00ol0003oXh6_oj>1[`02oj>1[`Co00001_nST<400ol0003oXHfo
oj6=_`04oj6=_`;o00001_nQV</01?l0003oXZ7Coj:QdonRXM<2o`000003oj>^gol0003oX[7S00Oo
X[7S0_l00006ojC0k@;o00000onVcO@3o`0000;oY]?g00Co0000ojOFn?l0003o00000_nZfOP4o`00
0003ojWSn_l0003o000000;oZ>Gk0_l000000onXi__o0000o`000003ojG[nP;o00000_nSl?H3o`00
00;oVo7`0_l000001_nBl>Oo0000o`000?l0003oJ=Rjo`000<Cooo]Z1?l00007oookJP0000?ooo]Z
o`000?oonfX05?oonfX3o`0004?ooo]Z2?l00004od>Tm`05o`000?mH[_[oF:kjo`000?mEZoT02_l0
00001Oml^_[o0000o`000?mh^?[o000000KoS[kf0ol00005oifol0;o00001on/_^H00ol0003o^KWI
okVif@02okVif@;o00000_nd^Md00ol0003o_kcGo`000003okbnf`;o000000?o`[7:o`000?l00000
1?o4ZKh00ol0003o`JW2ol6Y`P02ol6Y`P03o`000?o4[/?oa:k300;oa:k300?o0000ol2U__o0YKh0
0_o0YKh5o`0000;o`IN/00Co0000oknH[onoV:oo00000oo1U:P00ol0003o_IB/okfD[003okfD[003
o`000?nkT:Wo^i2Y00Co^i2Y0_l00005okRA[P03o`000?ngSjgo]hn]00_o00000_naRJ`01Ol0003o
/HV/ok69[?naRJco000000?o[HN]00Go0000ojj8[_n^R:ko[XR^o`000005ojV6[`03o`000?n[RK7o
000000OoYh:/00?o0000oj>1[ol000000ol000000onWT;go0000oj>@`@06oj>@`@03o`000?nQSKoo
XHfo00?o000000CoXi[;o`000?nQV<_oXIS;0ol00003oj>QdP;o00001OnS[]l00ol0003oX[7Soj:a
h`03o`0000?oY;g[00?o0000ojC0kOnT`>d00ol00002ojG9lP04o`000?nVcOCo0000o`0000KoY]?g
00Co0000oj[In?nZfOSoZ]Wh0_l000000onWgo[o0000o`000002ojKSn`;o00000_nXi_/00ol0003o
YN_jojG[nP02ojG[nP;o00000_nOkoH3o`000004oi_al?l0003o0000o`0000;oT_3W1?l00033oook
JP?o00002ooonfX00003oookJ_l0003ooo]Z017ooo]Z0ol00018oookJPco000000?oF:kjo`000?l0
00000ol000000omT/o_o0000o`000005o`0000?oNKWj1?l00004oh[0n@03o`000?nM_o3oWKo`00?o
00000_nJ`?800ol0003o[;kVojbniP03o`0000?oZ;kY00Co0000okVifOni^MWo00001Ond^Md00ol0
003o_;kKokbnf`04okbnf`Go000000?oa:Vno`000?o1ZL800oo1ZL82o`0000?oa:k300?o0000ol2U
__o0YKh00oo0YKh2o`0000?o`JS11_l00002ol6DZ003o`000?nmU:co_IB/00Co_IB/00?o0000ok^@
ZOnkT:T00onkT:T01?l0003o^I:^okVB[_l00004okRA[P?o]hn]00Co0000okF=[OneSJgo00001Ond
S:`01?l0003o/HV/ok69[?l00004ok69[004o`000?n]Qjgo[HN]o`0000Co[XR^00?o0000ojV6[onY
QZl00_nYQZl01Ol0003oZhVaoj^9/On[RK7o000000?oYh:/1_l00005ojN@_@03o`000?nST<7oXi31
00?oXi3100Co0000oj>@`Ol0003o00001OnSV//2o`0000;oXj7B0_l00002ojF]g@03o`000?nS[]oo
XjkO00GoXjkO0_l00007ojBmj`;o00001_nUbO800ol0003oY]?gojKCm`02ojKCm`;o00000onVf?T2
o`0000;oYmoj00Go0000ojKSnonVho_oY^?ko`000002ojKUn`;o00000_nUjoX2o`0000;oYNci00?o
Wnofo`000?l000001_l000001_n>k^Oo0000o`000?l0003oKmk8oeoB]L7ooo]Z1?l0000>oookJP00
00?ooo]Zo`000?oonfX03_oonfX3o`0004gooo]Z00CoGP00o`000?l0003o00000_l>R>@01?l0003o
;9[`o`000?lbWO87o`0000;oHK;k00Co0000of>bnomS/__o00001_mf^?/01?l0003oR/3ioh[0nOn:
`?T5o`0000KoV/3b0_l00007ojRnj@03o`000?nd^Mgo];WM00;o];WM0_l000000on`^n;o0000okbn
f`02okbnf`;o00001?ni]]H5o`0000;o`JW200Ko0000okn]b?no[LSo0000olB^`ol00006ol2U_P03
okn[a_l0003o`JS100?o`JS100Co0000okfR_OnmX[go_J:m1_l00003okfD[0;o00001?nkT:T01Ol0
003o^I:^okVB[_niTZko000000?o^96^1OngSjd2o`0000Oo]8b/0_l00006ok69[0;o00001_n^R:h0
0ol0003oZHJ_o`000009o`0000?oZ96n00?o0000ojN@_OnWT;d01OnWT;d00ol0003oXi31oj>@`@03
o`0000;oYYg=00?o0000oj>JbonSV//00ol00002ojFRdP;o00001_nU[Md00ol0003oXjkOo`000002
o`0000?oYK[X00?o0000ojBmjonT_N/00ol00002ojG6l@03o`000?nUbO;oYLWb00?o00001?nVd?H2
o`0000;oY]Si1ol00002ojKSn`;o00000onViO/00ol0003oX^Wko`000002o`0000?oYNci00SoWnof
o`000?nNkoKoW^ofo`000?nFknoo0000ohk^i`;o000000CoO^OIofoNb?l0003o0000`?oonfX3o`00
01;ooo]Z00000ooonf[o0000oookJP0;oookJP?o0000D_oonfX3o`000003o`Z7h_l0003o000000Go
00000_m6YoL>o`000004ogJhnol0003o0000o`0000CoQKgi00?o0000oi[0l_nJ`?800ol00002oiK0
m003o`000?nX_^WoZ;kY00?o00000onT_nd01?l0003o];WMo`000?l00004ok2khP03o`000?nl_]_o
000000Co^KKF0_l000000one]m[o0000okfieP02okfiePCo00000_no[LP00ol0003o`:Fnol2U_P04
ol2U_P?o_j_600Co0000ol6X`Oo1Z<7o00001OnmX[d00ol0003o_JG1okfU`@02okfU`@co000000Co
^I:^o`000?nhTJko^96^1_ngSjd00ol0003o]8b/okB<[005okB<[0;o00000onaRJ`>o`0000Ko[9:k
00Co0000ojRA__nXTKkoZ96n0_l000000onYW<Wo0000ojN@_@06ojN@_@?o00001_nVWLd2o`0000;o
YJ;B00Co0000ojJ]g?nV[Mco00001onU[Md2o`0000OoYK[X0_l00006ojG6l@;o00000onVd?H2o`00
00CoYMKi0_l000001?nVfo[o0000o`000?l00004ojCRo005o`000?nViO_oY^Gko`000?nRjO/00ol0
00000onQjo[o0000o`000003o`000003oik_m_l0003o000000Go000000CoO^OIo`000?l0003o0000
__oonfX4o`0001Gooo]Z00000ooonf[o0000oookJP08oookJP?o0000F?oonfX3o`000003o`Z7h_l0
003o000000Co000000?o@ZKgo`000?l000000ol00002oefan`Ko00000omb^O/8o`0000KoU/3d0_l0
0007ojBok@03o`000?n`^n;o/;_R00Go/;_R00?o0000okVfe_ni]]H00_ni]]H00ol0003o]KOJokFg
fP02okFgfP03o`000?nm^MKo000000Co^[cK1_l00002ol2U_PCo_j_600?o0000ol6X`Ol000001Onm
X[d00onlZ<Go0000okfU`@03okfU`@07o`000?njX;ko^Z2nokZP__l0003o^ijlo`000005okVK^AOo
000000Go/IVno`000?l0003o/IVno`000007ojjH`003o`000?n/T[_o[9:k00Ko[9:k0ol00004ojVL
b@04o`000?nWT;goYi2mojN@_@?o000000CoZJ;@o`000?nVWLgoYYg=0ol00002ojJTe0;o00001_nV
[M`00ol0003oYJgMojF]g@03o`0000;oY[SV00?o0000ojFjj?nU^^P00ol00003ojG4k`03o`000?nU
a_7oYLKa00?o00000onUc_D2o`0000?oYMKi0ol000001?nUfO[o0000o`000?l00003ojCRo0;o0000
0onSi?`4o`000003oj7[n_l0003o000000?o00000_nJk_H2o`0000;oSng^1_l000000omDc;3ooo]Z
oookJP2koookJP?o00006OoonfX00003o`000?oonf[ooo]Z00Gooo]Z0ol0001MoookJP;o000000?o
3H_So`000?l000000olUUnd7o`0000?oF[3k0_mL/O/00ol0003oKkSlofnho003ofnho004o`000?n2
_o_o0000o`0000;oPKcj1?l00004oi;0mP03o`000?nT_ngoY;o]00?o00000onP`>l00ol0003o/;_R
ok2khP03o`0000;o[;gV00Co0000okVfe_ni]]Ko00001_ne]mX01?l0003o^[cKokZlfonj_=/2o`00
00?o]kCF00?o0000okfdd_l000001?l00002okn[aP;o00001OnmX[d3okbXa@04o`000?nmYL7o_JG1
o`0000Co^Z2n0_l00007okVK^@03okVS`ol0003o]io100?o]io100Go0000okJL_onfW;oo]Yboo`00
0003okBK_`05o`000?ncV[ko/iZnok>J__l000000onaVKh00ol0003o/IVnok6I_P02ok6I_P03o`00
0?n^V<3o[YS000;o[YS000?o0000ojjRc?l000001on/T[/2o`0000KoZIc900Co0000ojN@_Ol0003o
00001OnYX]02o`0000;oYZCD0_l000000onX[]co0000ojJ]g007ojJ]g0;o00001_nV^>H2o`0000Oo
YLC_0_l00002ojG>m@?o00000_nTdoP01?l0003oYMKio`000?l00002ojGInP;o00000onRh?`2o`00
00;oXnCl1Ol00003oigYnP?o000000KoV^kfo`000?l0003oUnkdo`000?n?kNh2o`000006ohCZi?l0
003o0000ogCRe?mDc;3o0000^ooonfX4o`0001cooo]Z00000ol0003ooo]ZoookJP02oookJP?o0000
H_oonfX5o`000004ob6Fk?lUUngo0000o`0000?o?ZGf00Go@jOgo`000?mF[o[oEZojoeZ`n`07o`00
0003ofnho?l0003o000000Co000000?oOKcko`000?nB`?H01OnB`?H2o`0000OoX<3_0_l00006ojbm
iP03o`000?ne]m[o]KOJ00;o]KOJ0ol00002ok6ih003o`000?nj_=_o000000Go]kCF0_l00005okVh
f0Ko00000_nmX[d4okbXa@03o`000?nmYL7o000000Co^Z2n00?o0000okRUa_l000001_niVkT3okVS
``04o`000?ngWl7o]io1o`0000Co]Ybo00Co0000okBK_ondVkoo00001OncV[h3o`0000Go/IVn00?o
0000ojjH`?n^V<000_l00003ojjRc004o`000?n/T[_o[9:kojbB^`?o000000?o[:C?o`000?nYW<T0
1_nYW<T01?l0003oZJ;@ojVRd?nYX]04ojRXeP04o`000?nVY=Co0000o`0000CoZ:kL00?o0000ojJ]
g?nV[M`00ol00003ojNhiP03o`000?nV^>KoY[SV00?o00000_nV`^h00ol0003oYLC_ojG4k`03o`00
00;oYLcd00Co0000ojG>mOl0003o00001_nTdoP2o`0000;oYMWj00Go0000oj;Po?nRh?coX^3lo`00
0003oj7So0;o000000?oX^Glo`000?nMjOX00onMjOX00onLj_[o0000oiG/mP08o`0000;oQ>[T0ol0
002koookJP?o00008?oonfX00003o`000?oonf[o000000;o0000J?oonfX4o`000006ob>Ik?l0003o
8IK/o`000?lkY?Go?ZGf1_l000001?mF[o[o0000o`000?m^^_d6o`0000;oO[kk1Ol00005oho0m`Co
00001?nK`O800ol0003o[;gVojbmiP03o`0000;oYkkZ00Co0000okFgf_l0003o00001_na^N000ol0
003o]kCFokNdeP02okNdeP;o000000?o/kKLo`000?ni^=P00_ni^=P2o`0000Co]k7C00?o0000ok^a
d?l000000ol00002okbXa@;o00001?njX;h01Ol0003o^:G6okRUa_nhYLKo000000?o^I^i1OniXl<0
0ol0003o]io1o`000006okJL_`;o00001_ncV[h00ol0003o/IVnok6I_P05ok6I_P03o`000?n^V<3o
000000Go[Z;<00Co0000ojbB^on/T[_o00001On/Y<l6o`000003oj^Xe?l0003oZ:SF00OoZ:SF00?o
0000ojR^g?nX[]`01OnX[]`2o`0000OoYkSV0_l00006ojK2kP;o00001_nUc?@00ol0003oY=?hojCC
n002ojCCn0;o00000onTeoX2o`000003oj;Po?l0003o000000CoXN?l00Go0000oj3To?l0003o0000
oigYnP02o`0000;oW>[j1?l000000onDk?Go0000o`000003o`0000;oO^OS0_l0002joookJPCo0000
8ooonfX000;o0000KOoonfX01Ol0003o07G=o`1ecOl0003o2h_Q00?o000000Co>jKeo`000?lkY?Go
00001Om@[oX2o`0000CoI[Ol00?o0000ogZlo?mj_?`00omj_?`4o`0000CoQl?k00?o0000oi_1l_nK
`O801OnK`O82o`0000KoYkkZ00?o0000ok6ih?na^N000_na^N03o`0000;o[;cU00Co0000okNde_ng
]=Ko00001?nc]]`00ol0003o^KSHo`000006okNad`;o00001?ng]]L;o`000004okRUa_l0003o^I^i
okVK^@Ko^J?30_l00006okJL_`;o00001_ncV[h00ol0003o/Z?9o`000006ok6I_P;o00001on^X/`0
1?l0003o[:C?ojbTcon/Y<l5oj^YeP;o00001On[Z=@00ol0003oZ:SFojRXeP03o`0000?oZK3M00?o
0000ojR^g?nX[]`00ol00002ojNiiP03o`000?nW^>KoYkSV00?o00000_nV`^d00ol0003oY/;^ojK2
kP03o`0000?oYL_c00?o0000ojG<m?nUc?@00ol00003ojCBn0;o00000_nTeoX3o`0000;oXMkl0_l0
0002oj7So0;o000000?oX>Clo`000?l000000ol00003oiSYnP03oicZn_l0003o000000;oU>ce00Co
0000ohW[kOl0003o00000_mnin<00omjiMoo0000o`00002ioookJP?o00009ooonfX000;ooo]Z00?o
0000oookJ_oonfX0K?oonfX7o`000003oc^VmOl0003o000000?o000000?oDK7jo`000?m@[oX02Ol0
0004ogFlo0;o00000on7`o/6o`0000CoUl7d00?o0000ojNnj_nW_^X00ol00002oj;0kP04o`000?na
^N3o0000o`0000Ko[;cU00?o0000ok>fg?nc]]`01Onc]]`00ol0003o]k7CokNad`02okNad`?o0000
00?o/kCJo`000?ng]]L00ol00004okJ`d`03o`000?nh/=7o000000Co]Z_>3ol00002okJL_`03o`00
0?ndY<Wo000000Go/iZn00?o0000ok:SbOl000003ol000000on^Z]Co0000oj^YeP03oj^YeP?o0000
00?o[:oJo`000?n[Z=@01On[Z=@3o`0000OoZK3M0_l00006ojNiiP;o00001_nV`^d2o`0000OoYL_c
0_l00002ojCBn0?o00000onReoX2o`0000;oXMkl0ol00003oikQo@06o`000?nPi?coX>Clo`000?nJ
j?_o00001?nHjOX00onEjOWo0000ohoZm@02ohoZm@Co000000GoO^OSo`000?l0003o0000oe;<^P2g
oookJPCo0000:_oonfX000?ooo]Z00?o0000oookJ_oonfX0K_oonfX3o`000003o`>7g?l0003o0000
00Go000000?oDK7jo`000?l000002_l00003ogFlo0Co00000on2_o/00ol0003oUl7doiO1m005oiO1
m0;o00001_nR`>h00ol0003o[;cUojbli@02ojbli@;o00000onW_n/00ol0003o/kKLok>fg003o`00
00;o[[[R00Co0000okNadong/M?o00001Onc]=X00ol0003o][3CokJ`d`05okJ`d`;o00001_nfZlh0
0onc/=Go0000okB`e002okB`e0;o00001?nc[M800ol0003o/jcBok>/dP0<o`0000;o/JW@0ol00005
ojnYd@04o`000?n]Z=;o0000o`0000Co[Z[D00Co0000oj^Ye_l0003o00001On/[mX00ol0003oZjSD
oj^Xe003o`0000;oZ[CP00?o0000ojV`gOnY/=d00ol00002ojRki`03o`000?nW^NKoYkWV00?o0000
0onV`nh00ol0003oY/;]ojK2k@03o`0000;oY<[c00?o0000ojG;lonUbo<00ol00004oj?An0;o0000
0_nReoX2o`000003oj3Ko?nOg?co000000?o00000_nNhOd2o`0000;oW>?m00Go0000oiOVo?l0003o
0000oiSYnP02o`0000;oUNWi00Co0000ohoZmOn?j_GoSn[e0_l000001_n3j>coMN?Oo`000?mdh]ko
0000oe;<^[Oooo]Z0ol0000^oookJP001?oonfX00ol0003ooo]ZoookJP1`oookJPKo000000?o8i_/
o`000?l000001ol00002oe^eo0Go00000om`_?d:o`0000GoT/;g0ol00005oig1lP;o00001onW_n/2
o`0000Ko[[[R00?o0000ok>df_nc]=X00_nc]=X2o`000003ojjihOl0003o][3C00?o][3C0ol00002
ok6df`04o`000?nfZlko]Z_>okJ[cPCo/k3E00?o0000okB`e?l000001_nc[M83o`0000Go/Z[@0ol0
0005ok6Yd0;o00001_n_ZM43o`0000Ko[Z[D0_l00008ojb_fP;o00001_nZ]>02o`0000KoZ;_W0_l0
0007ojK3kP;o00001_nTb_<2o`0000?oXm7h0_l00003oj7FnP;o00000_nPfo`3o`0000?oW>3m0_l0
00001?nLhogo0000o`000?nJiO`3o`000003oiCWn_l0003o000000?o000000?oSn[eo`000?l00000
2?l0002eoookJPCo0000<OoonfX000Gooo]Z00?o0000oookJ_oonfX0L_oonfX01?l0003o18WLo`00
0?l00002oanIjP?o000000?o?ZWfo`000?l000000_l00003oeNcn`;o00001Om/_?d00ol0003oO/3l
ogk0o002ogk0o0Ko00001?n9aO/00ol0003oWL7boig1lP03o`0000;oV<?e00?o0000ojNojonW_n/0
0ol00003oj71k`03o`000?n^^^;o[[[R00?o00000_nY_NP01?l0003o/kCJo`000?l00004ojjih@04
o`000?nf/=?o][3Co`0000Ko/KCK00?o0000ok>`eOnc/=D01Onc/=D00ol0003o/jgBok>]dP02ok>]
dP?o000000?o/;?Ko`000?nbZ]000onbZ]02o`000003ok2af_l0003o/JW@00?o/JW@0_l00002ojna
fP03o`000?n_ZM7o[jWA00?o00000on]/]`00ol0003o[Z[DojjZe003o`0000;o[;CO00?o0000ojb_
f_n/[mX00ol00002ojZii003o`000?nZ]>3oZ[CP00?o00000onX_^T00ol0003oZ;_WojRki`03o`00
00;oY/C_00?o0000ojK3k_nV`nh00ol00003ojC:m003o`000?nTb_?oY<[c00?o00000onRd?P2o`00
00;oXMKj2?l00002oicPo@?o00000onJh_d4o`000003oiCWn_l0003o000000;o000000GoSNSgoh[X
m?n:j?CoQnSbo`000002oggUj`;o000000?oH]S@oekFcOmJdlT0]OoonfX3o`0003Gooo]Z0006oook
JP;o0000MOoonfX3o`000004oanJjOlOVN[o0000o`0000?o>JOd0_l00002oe6bnP03o`000?mG/o_o
000000Co000000CoK;cmo`000?l0003o00001Omj_od01?l0003oRLGkohW5non9aO/5o`0000KoV<?e
0_l00007oj71k`;o00001_nY_NP00ol0003o[[WQojjih@05ojjih@03o`000?na]=_o/KCK00;o/KCK
0ol00002ojfjh`03o`000?nc/=Go/k3E00?o00000_n_]]h01?l0003o/jgBok>]d_l00005ok2cf`03
o`000?nbZ]3o000000Go/;7J00Co0000ok6Yd?naZM3o00001On_/MX2o`0000Oo[K;L0_l00006ojbd
g`;o00001_nZ^N@2o`0000OoZ;kY0_l00006ojK4k`;o00001onTb_@2o`0000;oX]3h0_l00004oj3E
nP;o000000CoW][lo`000?l0003oWMcm1?nJgod2o`0000;oV^;m0ol000000onDiOcoTNKkoi7Vn`02
oi7Vn`;o000000?oSNSgo`000?l000000_n7j?802?l0003oONG[ogWTiol0003oH]S@o`000?mJdlWo
0000/ooonfX4o`0003Sooo]Z0008oookJP03o`000?oonf[ooo]Z07Cooo]Z1?l000001_lOV^Wo0000
o`000?lhZ??o0000ocVWm0Go000000?oDK;jo`000?l000002?l00003ogZoo@?o00000on4`O/5o`00
00CoTlCh00?o0000oj71konQ`Nl00ol00003oic3l`03o`000?nY_NSoZKgX00?o00000_nS`Nh00ol0
003o[[WQojjih@03o`0000;oZKgX00Co0000ok6dfol0003o00001_n]^^<2o`0000Ko[kKN00?o0000
ok2cfon`/m/01On`/m/00ol0003o/;7Jok2afP06ok2afP03o`000?n_/M[o[k7J00;o[k7J0_l00000
0on[^NCo0000ojfbg003ojfbg0?o000000?oZ[_Uo`000?n/]=l00_n/]=l3o`0000;oZ;gX00?o0000
ojZii?nZ^N@00ol00002ojO1k003o`000?nX_^WoZ;kY00?o00000onUa_400ol0003oY/C_ojK4k`03
o`0000;oXl_e00?o0000ojC:m?nTb_@00ol00003oj7@n0;o00000onPeOX2o`000005oicJoOl0003o
0000o`000?nMg?d00onJgod2o`0000CoUn7m0_l000001?nDiOcoTNKkoi7VnonAi_/2o`000003ohkV
nOl0003oQNKd00Wo000000?o@l>eod71/ooonfX0/_oonfX3o`0003cooo]Z0009oookJP03o`000?oo
nf[ooo]Z07Oooo]Z0_l000000ol2R]Wo0000o`000005o`000003odjcn_l0003o000000?o000000?o
G[Wmo`000?l000001Ol00003og>ooPGo00000_mo`O`00ol0003oTlChoi?4n004oi?4n0;o00001onL
`o<2o`0000KoXl7^0_l00006ojVmj003o`000?n]^^?o[K[S00;o[K[S0ol00002ojRojP03o`000?n_
]]ko[kKN00?o00000_nZ_>H00ol0003o/;?Kok2cf`03o`0000;o[;[T00?o0000ok2af_n`/MX00ol0
0003ojbih`04o`000?n_/M[o0000o`0000CoZkWT00Co0000ojfbg?l0003o00001OnZ^nD3o`0000Ko
Z;gX0_l00006ojO1k0;o00001onUa_42o`0000KoXl_e0_l00002oj7@n0?o00000onNeO/2o`0000;o
W=[m0ol00003oiONoP;o00000onGhOd2o`000003oiCSoOl0003oSNCk00;oSNCk0_l000001On>i_Wo
0000o`000?l0003oP^Gb00;o000000OoN^C/ogORjOl0003oJ=cMofKKfom3`kGo00000;;ooo]Z1?l0
000ooookJP002_oonfX00ol0003ooo]ZoookJP1ioookJPGo000000?o7icYo`000?l000002?l00002
oeVgo0Go00000om^_oh2o`000003oh33oOl0003o000000Co00000on8ao`6o`0000CoU/Cg1?l00004
oik3l`03o`000?nY_NSoZKgX00?o00000_nS`Nh01?l0003o[K[So`000?l00006ojRojP;o00001_nZ
_>H2o`0000Ko[;[T0_l00007ojbih`03o`000?n[^NCoZkWT00GoZkWT00?o0000ojZkiOnZ^nD01OnZ
^nD00ol0003oZ;gXojRmj002ojRmj0;o00000onUaO000ol0003oYl7/ojO1k003o`0000;oXlSc00?o
0000ojG6lOnUa_400ol00003oj7<mPCo00001OnOdOT2o`0000;oW]Gk0_l000000onJf_go0000o`00
0003o`0000;oUmkn0ol00003oiCPoP;o000000CoU>?mo`000?n=i?_oSNCk0_l000000on:iOWo0000
ogoTl`02ogoTl`?o000000CoN^C/o`000?l0003oJ=cM0_mVfm/00ol0003ooo]ZoookJP2`oookJP?o
0000@ooonfX000_ooo]Z0_l0001koookJPCo00000olKV^L3o`000004oc^[m?l0003o0000o`0000Co
DkKk0ol00003ofRooPGo00000_mj`_d5o`0000?oQ<?l00?o0000oiK4monFa?L00ol00002oi76n@03
o`000?nN`o?oW/?c00GoW/?c0_l00006oj?1kP03o`000?nX_n[oZ;oZ00;oZ;oZ0_l00002oj;3l003
o`000?nZ_>KoZ[cV00?o00000onU`Nh00ol0003o[;[Tojbji003o`0000;oY/3/00?o0000ojbihon/
^N<00ol00003ojO0j`03o`000?n[^NCoZkWT00?o00000_nW`N`00ol0003oZ[_UojZki@03o`0000?o
Y/;^0_l00007ojG5l0;o00001_nSb?<2o`0000;oXLcf0ol00002oigAnP03o`000?nOdOWoWm7i00?o
00000_nKe_`3o`000003oi[JoOl0003o000000;oV=_n1?nDgOh2o`0000;oU>3n0_l000000on@hOgo
S>;lohSSn`02ohSSn`Co00000_moi?<4o`0000;oL=oX00?oK=gUo`000?mOemT00_l0002aoookJPCo
0000A_oonfX000gooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP04o`000004oa^J
iol0003o0000o`0000;o=JWb1?l000000omC]__o0000o`000003o`0000?oHKcm00?o0000og?2o_mc
`_h01?mc`_h8o`0000KoTLKi1?l00005oiS5m`?o00001OnNa?<2o`0000KoX/?`0_l00007ojG1kP;o
00001_nV`>`2o`0000OoYl3[0_l00006ojO1k0;o00000_nV`^h3o`0000;oXLSd00?o0000ojG5l?nU
aO000ol00002oj3;mP03o`000?nSb??oXlSc00?o00001?nOc_P2o`0000KoWM7j0_l00003oi_Fo0?o
00000_nDfoh00ol0003oV=_noiCMoP02oiCMoP;o00000onAgoh2o`000004oi3QoOn<h_coR>?kohSS
n`Co000000CoOn;fog[QlomjhO?oN^7c1Ol000001?m/gNGo0000o`000?l0002boookJP?o0000B_oo
nfX000kooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP02oookJP;o000000?o0H_F
o`000?l000002ol000000omN_?go0000o`000005o`0000GoK/;n0ol00002ogo4o@Go00000on4b?h5
o`0000CoT/Oj00?o0000oik4lonNa?<00ol00002oiS7m`03o`000?nR`o3oX/?`00?o00000_nLa_D0
0ol0003oYL7^ojG1kP03o`0000?oWlKc00?o0000ojK0k?nV`>`00ol00002oj75lP03o`000?nW`>_o
Yl3[00?o00000onRa_84o`0000GoX/Ob0_l00006oj78m0;o00001_nPboH2o`0000?oWlkh0_l00004
oi_Bn`?o00000_nHeod4o`000003oi_Fo?l0003oU=_n00?o00000onAg?h2o`0000;oTMon0ol00000
0on8hOco0000ohCQn`02ohCQn`?o000000?oOn;fog[QlomjhO<00_l000001Omgh?7oK]gZofWKi_l0
003oFM?H00;oEm;F/ooonfX3o`0004gooo]Z000?oookJP03o`000?oonf[ooo]Z07Wooo]Z00?o0000
oookJ_oonfX01OoonfX4o`000003oajNiol0003o000000So00000_mI^_`5o`0000CoIL7n00?o0000
ogS4o_mha?h01?mha?h8o`0000OoT/Oj0_l00006oiS7m`;o00001_nLa_D2o`0000OoWlKc0_l00006
oj75lP;o00000_nRa_83o`0000;oW<[g00?o0000oj;7l_nRao800ol00003oig;n003o`000?nQb?Co
XLSd00?o00000onLcOT3o`0000GoW<oj0_l00003oi_Bn`Wo000000?oUMOnoi;Jo_nBf_h00_nBf_h2
o`0000;oTMcn0_l00004ohkMoPCo00000_n4hO/2o`000003oh3QnOmigoGoM=kb00;oM=kb0_l00000
1Omgh?7oK]gZo`000?l0003oFM?H00;o0000/_oonfX4o`00053ooo]Z000@oookJP03o`000?oonf[o
oo]Z07Wooo]Z00?o0000oookJ_oonfX02?oonfX>o`0000?oD[Sj2Ol00005og74o`?o00000_n2aoh=
o`0000;oS<_m1_l00005oiK9n@Co00001OnIbOP3o`0000GoVlWg0_l00006oic:m`;o00001onMboP2
o`0000;oW<gi0_l00003oi?Bo@03o`000?nLco[oW<oj00?o00000_nCe?h5o`0000?oTMSo0_l00000
1OnEeokoT][noi;Jo_nBf_ko000000CoSM_o0_l00003ohkMoP04o`000?n2go_oP]oko`0000?oOmoj
0_l000003_n0hOWoNMoeogCNl_mdg_;o0000og3Mkol0003oH]STo`000?mAc]GoClgCo`000?li_Kco
0000/_oonfX3o`0005Cooo]Z000AoookJP;o0000N_oonfX00ol0003ooo]ZoookJP04oookJP?o0000
1?oonfX00oli003o07Njo`000006o`000003odbhn?l0003oC;Sh00Ko000000?oGKkmo`000?l00000
0ol00003ofS4oPGo00000omjaol2o`0000GoPlWn1_l00003ohO8o@Co00000on9cOh6o`0000?oSLkm
1Ol00005oiK=n`?o00001OnGc_/4o`0000CoUlok0_l00004oi?Bo@Go00001?nCe?h02?l0003oSMOo
ohgGoon=eooo0000oi7Hool0003oS]Wo0ol00003ohWJo`?o000000CoQmcno`000?l0003o00000omk
gOX2o`0000;oOmoj0_l00002og;Ll`0;o`000?m^fo7oJ][]oeoEiOmKe>;o0000odW9d_m7b=3o0000
oc:i^_l00000/ooonfX4o`0005Oooo]Z000CoookJP03o`000?oonf[ooo]Z07Sooo]Z00?o0000oook
J_oonfX00ol0000<oookJP;o000000Co08c?o`000?lLX>Co7:3T0_l000000olm/_?o0000o`000004
o`0000?oE[ck2ol00003og?7o`Co00001OmjbOl>o`000003ohW<o_l0003oSLkm00;oSLkm0_l00002
ohW<oP03o`000?nFcO_oU/gk00?o00000on9d?l00ol0003oUlkkoiO>n`03o`0000?oRm7o3Ol00004
ohoEo`;o00000_n=eol2o`0000CoR=So0_l00002ohWJo`;o000000?oPm_no`000?l000000ol00002
og_MnP05o`000?mjgO[o0000o`000?m[fO401_l000001OmZf^goGmGUo`000?l0003oBLWB00;o0000
]OoonfX3o`0005_ooo]Z000DoookJP03o`000?oonf[ooo]Z07Sooo]Z0_l0000DoookJP;o000000Ko
08o?o`000?l0003o<Jg]o`000?lh[o43o`000003odnknOl0003o000000Co00001?mH_o/;o`0000Co
M<Wo1?l00003oh7;o`03o`000?n7cOkoQlgn00?oQlgn3?l00006ohW@o`?o00001On;dOl00ol0003o
Q]?oohKCo`03o`0000GoQmCo1?l00004ohSFo`;o00000on8f?l00ol0003oPMWnoh7IoP04o`000005
oh?Ko_l0003o0000o`000?mhfoX00_l00003og;Jn0So000000CoEm7RoeC?h?mDcn3oE<oP0_l0002f
oookJPCo0000G_oonfX001Gooo]Z00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP0Hoook
JP;o08g=0_l000000olNXn?o0000o`000003o`0000?o>[;a0ol000000om@__So0000o`000004o`00
0003of74oOl0003o000000Co00000omYb?h5o`0000?oNL_o0ol00005ogk=o`?o00001On2col3o`00
00KoQM7o0ol000000on6dooo0000oh3Co`04oh3Co`?o00001On2eOl3o`000003oh?Gool0003o0000
00Ko00000_mffO/3o`0000?oL]Si0_l00002og;Jn003o`000?mQe>go000000CoH=C]00Co0000odc;
gOlm`Loo>;k;0_l0002hoookJP?o0000H_oonfX001Kooo]Z00?o0000oookJ_oonfX0M_oonfX00ol0
003ooo]ZoookJP0LoookJP03oal00?l0003o000000?o000000?o<k3/o`000?lc/>`01Ol000000om1
^?;o0000o`000004o`0000?oFL;k2_l000000om_boko0000o`000005o`0000GoN<go0ol00005og_?
o`Go00001?mddOh5o`0000?oM]?n1Ol00004ogSEoPGo000000?oLmKkog3Fn_m`e_X00om`e_X2o`00
00;oL]Si0ol000000omNd^ko0000o`000007o`000004odc;gOlm`Loo0000o`000;Sooo]Z1?l0001U
oookJP005ooonfX2o`0007Kooo]Z00?o0000oookJ_oonfX08ooonfX4o`0000?o6jCM0ol00003oc^e
k`03o`000?m@`?Oo000000Ko00001OmG`oT3o`000003ofK9oOl0003o000001Go00000_mddOh6o`00
00KoK=;k0ol00002ofgDnP03o`000?mWd_SoIm;h00Oo000000?oF<o]o`000?mFc^/00_mFc^/6o`00
0003od_9h?m9b=ko000000Co0000^_oonfX3o`0006Wooo]Z000IoookJP03o`000?oonf[ooo]Z07?o
oo]Z00?o0000oookJ_oonfX0:_oonfX00olf003o0000o`2Ab003o`0000;o8ZSP1Ol00003ocZfkA;o
000000?oF/Sho`000?l000001Ol00005oeo<n@?o00001OmSc_T3o`000003ofKAnOl0003o000000Go
000000?oIm;ho`000?l000002_l00002od33f`;o000000?o;kS<o`000?l00000__oonfX4o`0006co
oo]Z000JoookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX0<OoonfX:o`000003ob6Y
gOl0003o000000;o000000?o>[SZo`000?l000001?l00005ocfkj`[o00001?mGbOD5o`0000KoB/G/
00Co0000oe;:k_mBb^koClS/0_l000000olj_Mgo=[_IocJkf@02ocJkf@Co00000_lT/<D00ol0003o
9:o4oookJP32oookJP?o0000L?oonfX001_ooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]Z
oookJP0noookJP?o1YO60_l000000olRZmWo0000o`000005o`0000Go9JkI2_l00002objef@04o`00
0?lZ/]Ko:[;FobZbePGo000000?o;[KFo`000?lKZLD00ol0003<oookJPCo0000LooonfX001cooo]Z
00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]ZoookJP3ooookJSGooo]Z0ol0001goookJP007Ooo
nfX2o`00073ooo]Z00?o0000oookJ_oonfX0oooonfXaoookJPCo0000N_oonfX001oooo]Z00?o0000
oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP3ooookJRkooo]Z0ol0001noookJP008?oonfX00ol0
003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z0?oooo]Z:_oonfX4o`00087ooo]Z000QoookJP03
o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX0oooonfXXoookJP?o0000QOoonfX002;ooo]Z
0_l0001ZoookJP03o`000?oonf[ooo]Z0?oooo]Z9?oonfX4o`0008Sooo]Z000ToookJP03o`000?oo
nf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX0oooonfXQoookJP?o0000S?oonfX002Gooo]Z00?o0000
oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP3ooookJQgooo]Z1?l0002?oookJP009_oonfX00ol0
003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z0?oooo]Z6_oonfX3o`0009?ooo]Z000WoookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0oooonfXFoookJPCo0000U_oonfX002Sooo]Z
0_l0001ToookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX3o`0009[ooo]Z000ZoookJP03o`000?oo
nf[ooo]Z067ooo]Z00?o0000oookJ_oonfX0oooonfX?oookJPCo0000WOoonfX002_ooo]Z00?o0000
oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z0ol0002QoookJP00;?oonfX00ol0
003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX4o`000:Cooo]Z000]oookJP03
o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0oooonfX5oookJP?o0000Z?oonfX002kooo]Z
0_l0001NoookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX4o`000:_ooo]Z000`oookJP03o`000?oo
nf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX0oOoonfX3o`000:oooo]Z000aoookJP03o`000?oonf[o
oo]Z05[ooo]Z00?o0000oookJ_oonfX0nOoonfX4o`000;;ooo]Z000boookJP03o`000?oonf[ooo]Z
05Wooo]Z00?o0000oookJ_oonfX0m_oonfX3o`000;Kooo]Z000coookJP03o`000?oonf[ooo]Z05So
oo]Z00?o0000oookJ_oonfX0l_oonfX4o`000;Wooo]Z000doookJP;o0000F?oonfX00ol0003ooo]Z
oookJP3_oookJP?o0000_OoonfX003Kooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]Zoook
JP3[oookJPCo0000`?oonfX003Oooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP3X
oookJP?o0000a?oonfX003Sooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP3Uoook
JPCo0000aooonfX003Wooo]Z0_l0001BoookJP03o`000?oonf[ooo]Z0>;ooo]Z0ol0003;oookJP00
>ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z0=kooo]Z1?l0003>oookJP00??oo
nfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z0=_ooo]Z0ol0003BoookJP00?OoonfX0
0ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z0=Oooo]Z1?l0003EoookJP00?_oonfX00ol0
003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z0=Cooo]Z0ol0003IoookJP00?ooonfX2o`0004co
oo]Z00?o0000oookJ_oonfX0dOoonfX3o`000=cooo]Z0011oookJP03o`000?oonf[ooo]Z04Wooo]Z
00?o0000oookJ_oonfX0cOoonfX4o`000=oooo]Z0012oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o
0000oookJ_oonfX0b_oonfX3o`000>?ooo]Z0013oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000
oookJ_oonfX0a_oonfX4o`000>Kooo]Z0014oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX0`ooonfX3o`000>[ooo]Z0015oookJP;o0000A_oonfX00ol0003ooo]ZoookJP2ooookJPCo
0000kOoonfX004Oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP2loookJP?o0000
lOoonfX004Sooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP2hoookJPCo0000m?oo
nfX004Wooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP2eoookJP?o0000n?oonfX0
04[ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP2aoookJPCo0000nooonfX004_o
oo]Z0_l00010oookJP03o`000?oonf[ooo]Z0:kooo]Z0ol0003ooookJP00COoonfX00ol0003ooo]Z
oookJP0moookJP03o`000?oonf[ooo]Z0:[ooo]Z1?l0003ooookJP?ooo]Z001>oookJP03o`000?oo
nf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0YooonfX3o`000?oooo]Z1ooonfX004oooo]Z00?o0000
oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP2SoookJPCo0000oooonfX:oookJP00D?oonfX2o`00
03[ooo]Z00?o0000oookJ_oonfX0XOoonfX3o`000?oooo]Z3_oonfX005;ooo]Z00?o0000oookJ_oo
nfX0=ooonfX00ol0003ooo]ZoookJP2MoookJPCo0000oooonfXAoookJP00DooonfX00ol0003ooo]Z
oookJP0foookJP03o`000?oonf[ooo]Z09[ooo]Z0ol0003ooookJQGooo]Z001DoookJP03o`000?oo
nf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0U_oonfX4o`000?oooo]Z6?oonfX005Gooo]Z00?o0000
oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP2CoookJP?o0000oooonfXLoookJP00E_oonfX2o`00
03Cooo]Z00?o0000oookJ_oonfX0SooonfX4o`000?oooo]Z7ooonfX005Sooo]Z00?o0000oookJ_oo
nfX0<OoonfX00ol0003ooo]ZoookJP2<oookJP?o0000oooonfXSoookJP00FOoonfX00ol0003ooo]Z
oookJP0`oookJP03o`000?oonf[ooo]Z08Sooo]Z1?l0003ooookJRKooo]Z001JoookJP03o`000?oo
nf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0QOoonfX3o`000?oooo]Z:_oonfX005_ooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP21oookJPCo0000oooonfX]oookJP00G?oonfX2o`00
02kooo]Z00?o0000oookJ_oonfX0O_oonfX3o`000?oooo]Z<OoonfX005kooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP1joookJPCo0000oooonfXdoookJP00GooonfX00ol0003ooo]Z
oookJP0ZoookJP03o`000?oonf[ooo]Z07Oooo]Z0ol0003ooookJSSooo]Z001PoookJP03o`000?oo
nf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0LooonfX4o`000?oooo]Z>ooonfX0067ooo]Z00?o0000
oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP1`oookJP?o0000oooonfXooookJP00H_oonfX2o`00
02Sooo]Z00?o0000oookJ_oonfX0K?oonfX4o`000?oooo]Z@_oonfX006Cooo]Z00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP1YoookJP?o0000oooonfY6oookJP00IOoonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z06Gooo]Z1?l0003ooookJTWooo]Z001VoookJP03o`000?oo
nf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0H_oonfX3o`000?oooo]ZCOoonfX006Oooo]Z0_l0000S
oookJP03o`000?oonf[ooo]Z05kooo]Z1?l0003ooookJU3ooo]Z001YoookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX0G?oonfX3o`000?oooo]ZE?oonfX006[ooo]Z00?o0000oookJ_oo
nfX07_oonfX00ol0003ooo]ZoookJP1HoookJPCo0000oooonfYGoookJP00JooonfX00ol0003ooo]Z
oookJP0MoookJP03o`000?oonf[ooo]Z05Gooo]Z0ol0003ooookJU_ooo]Z001/oookJP03o`000?oo
nf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0DOoonfX4o`000?oooo]ZG_oonfX006gooo]Z0_l0000L
oookJP03o`000?oonf[ooo]Z04kooo]Z0ol0003ooookJV;ooo]Z001_oookJP03o`000?oonf[ooo]Z
01Wooo]Z00?o0000oookJ_oonfX0B_oonfX4o`000?oooo]ZIOoonfX0073ooo]Z00?o0000oookJ_oo
nfX06?oonfX00ol0003ooo]ZoookJP17oookJP?o0000oooonfYYoookJP00LOoonfX00ol0003ooo]Z
oookJP0GoookJP03o`000?oonf[ooo]Z04Cooo]Z0ol0003ooookJVcooo]Z001boookJP03o`000?oo
nf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000?oooo]ZKooonfX007?ooo]Z0_l0000F
oookJP03o`000?oonf[ooo]Z03gooo]Z0ol0003ooookJW?ooo]Z001eoookJP03o`000?oonf[ooo]Z
01?ooo]Z00?o0000oookJ_oonfX0>OoonfX4o`000?oooo]ZM_oonfX007Kooo]Z00?o0000oookJ_oo
nfX04_oonfX00ol0003ooo]ZoookJP0foookJP?o0000oooonfYjoookJP00MooonfX00ol0003ooo]Z
oookJP0AoookJP03o`000?oonf[ooo]Z03;ooo]Z1?l0003ooookJWgooo]Z001hoookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0;ooonfX3o`000?oooo]ZPOoonfX007Wooo]Z0_l0000@
oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003ooookJXCooo]Z001koookJP03o`000?oonf[ooo]Z
00gooo]Z00?o0000oookJ_oonfX0:?oonfX3o`000?oooo]ZR?oonfX007cooo]Z00?o0000oookJ_oo
nfX03?oonfX00ol0003ooo]ZoookJP0ToookJPCo0000oooonfZ;oookJP00OOoonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z027ooo]Z0ol0003ooookJXoooo]Z001noookJP;o00002ooo
nfX00ol0003ooo]ZoookJP0MoookJPCo0000oooonfZBoookJP00P?oonfX00ol0003ooo]ZoookJP07
oookJP03o`000?oonf[ooo]Z01_ooo]Z0ol0003ooookJYKooo]Z0021oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX05ooonfX4o`000?oooo]ZVOoonfX008;ooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP0DoookJP?o0000oooonfZMoookJP00PooonfX00ol0003ooo]Z
oookJP04oookJP03o`000?oonf[ooo]Z013ooo]Z1?l0003ooookJZ3ooo]Z0024oookJP;o00001?oo
nfX00ol0003ooo]ZoookJP0=oookJP?o0000oooonfZToookJP00Q_oonfX01Ol0003ooo]ZoookJ_oo
nf[o000000_ooo]Z1?l0003ooookJZOooo]Z0027oookJP04o`000?oonf[ooo]Zo`0000Sooo]Z0ol0
003ooookJZ_ooo]Z0028oookJP03o`000?oonf[o000000Cooo]Z1?l0003ooookJZkooo]Z0029oook
JP;o000000Cooo]Zo`000?l0003o0000oooonfZboookJP00R_oonfX2o`000?oooo]Z]OoonfX00001
\
\>"],
  ImageRangeCache->{{{0, 575}, {378.688, 0}} -> {0.00392505, 0.143336, \
0.0017332, 0.0017332}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
However, we can always put the octants back together like a \
puzzle\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[p1, p2]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.10157 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0651957 1.12562 2.22045e-16 1.12562 [
[ 0 0 0 0 ]
[ 1 1.10157 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07962 .26912 m
0 .93168 L
s
0 .93168 m
.2414 1.10157 L
s
.2414 1.10157 m
.27881 .47225 L
s
.27881 .47225 m
.07962 .26912 L
s
.76525 0 m
.91897 .25046 L
s
.91897 .25046 m
1 .91579 L
s
1 .91579 m
.82344 .69767 L
s
.82344 .69767 m
.76525 0 L
s
.07962 .26912 m
0 .93168 L
s
0 .93168 m
.82344 .69767 L
s
.82344 .69767 m
.76525 0 L
s
.76525 0 m
.07962 .26912 L
s
.27881 .47225 m
.91897 .25046 L
s
.91897 .25046 m
1 .91579 L
s
1 .91579 m
.2414 1.10157 L
s
.2414 1.10157 m
.27881 .47225 L
s
0 0 m
1 0 L
1 1.10157 L
0 1.10157 L
closepath
clip
newpath
.5 Mabswid
.705 .588 .722 r
.41639 .41071 m .4233 .41064 L p .42604 .4038 L F P
0 g
s
.705 .588 .722 r
.41539 .40759 m .41639 .41071 L p .42604 .4038 L F P
0 g
s
.704 .559 .687 r
.4233 .41064 m .41639 .41071 L .41789 .41629 L closepath p F P
0 g
s
.709 .579 .707 r
.41539 .40759 m .41209 .41067 L .41639 .41071 L closepath p F P
0 g
s
.709 .561 .685 r
.41753 .41672 m .41789 .41629 L .41639 .41071 L p F P
0 g
s
.709 .561 .685 r
.40667 .41663 m .41753 .41672 L p .41639 .41071 L F P
0 g
s
.709 .561 .685 r
.41639 .41071 m .41209 .41067 L .40667 .41663 L p F P
0 g
s
.705 .588 .722 r
.42604 .4038 m .41995 .40385 L .41539 .40759 L p F P
0 g
s
.706 .589 .723 r
.41995 .40385 m .41406 .40389 L .41539 .40759 L closepath p F P
0 g
s
.71 .591 .72 r
.41209 .41067 m .41539 .40759 L .41406 .40389 L p F P
0 g
s
.71 .591 .72 r
.40421 .41057 m .41209 .41067 L p .41406 .40389 L F P
0 g
s
.71 .562 .686 r
.40585 .41662 m .40667 .41663 L .41209 .41067 L p F P
0 g
s
.71 .562 .686 r
.41209 .41067 m .40421 .41057 L .40585 .41662 L p F P
0 g
s
.704 .575 .707 r
.42723 .40714 m .4233 .41064 L .42832 .41057 L closepath p F P
0 g
s
.703 .557 .686 r
.42832 .41057 m .4233 .41064 L .41789 .41629 L p F P
0 g
s
.705 .588 .722 r
.4233 .41064 m .42723 .40714 L .42604 .4038 L p F P
0 g
s
.7 .584 .722 r
.42723 .40714 m .42832 .41057 L p .43779 .40344 L F P
0 g
s
.7 .584 .722 r
.43779 .40344 m .43168 .40364 L .42723 .40714 L p F P
0 g
s
.701 .586 .723 r
.43168 .40364 m .42604 .4038 L .42723 .40714 L closepath p F P
0 g
s
.71 .591 .72 r
.40354 .40847 m .40421 .41057 L p .41406 .40389 L F P
0 g
s
.715 .582 .705 r
.40354 .40847 m .40149 .41048 L .40421 .41057 L closepath p F P
0 g
s
.715 .566 .684 r
.39643 .41632 m .40585 .41662 L .40421 .41057 L p F P
0 g
s
.715 .566 .684 r
.40421 .41057 m .40149 .41048 L .39643 .41632 L p F P
0 g
s
.71 .591 .72 r
.41406 .40389 m .40895 .40381 L .40354 .40847 L p F P
0 g
s
.711 .591 .72 r
.40895 .40381 m .40183 .40369 L .40354 .40847 L closepath p F P
0 g
s
.716 .593 .717 r
.40149 .41048 m .40354 .40847 L .40183 .40369 L p F P
0 g
s
.7 .584 .722 r
.42832 .41057 m .43527 .41035 L p .43779 .40344 L F P
0 g
s
.699 .555 .687 r
.43527 .41035 m .42832 .41057 L .42974 .41586 L closepath p F P
0 g
s
.703 .557 .686 r
.42911 .41657 m .42974 .41586 L .42832 .41057 L p F P
0 g
s
.703 .557 .686 r
.418 .41672 m .42911 .41657 L p .42832 .41057 L F P
0 g
s
.703 .557 .686 r
.41789 .41629 m .418 .41672 L p .42832 .41057 L F P
0 g
s
.716 .593 .717 r
.39178 .41016 m .40149 .41048 L p .40183 .40369 L F P
0 g
s
.715 .566 .685 r
.39342 .41622 m .39643 .41632 L .40149 .41048 L p F P
0 g
s
.715 .566 .685 r
.40149 .41048 m .39178 .41016 L .39342 .41622 L p F P
0 g
s
.705 .617 .756 r
.41406 .40389 m .41995 .40385 L p .42261 .39572 L F P
0 g
s
.705 .617 .756 r
.41284 .40083 m .41406 .40389 L p .42261 .39572 L F P
0 g
s
.709 .605 .738 r
.41284 .40083 m .40895 .40381 L .41406 .40389 L closepath p F P
0 g
s
.705 .602 .739 r
.42468 .40038 m .41995 .40385 L .42604 .4038 L closepath p F P
0 g
s
.705 .617 .756 r
.41995 .40385 m .42468 .40038 L .42261 .39572 L p F P
0 g
s
.709 .619 .754 r
.40895 .40381 m .41284 .40083 L .41056 .39574 L p F P
0 g
s
.709 .619 .754 r
.40183 .40369 m .40895 .40381 L p .41056 .39574 L F P
0 g
s
.7 .614 .757 r
.42604 .4038 m .43168 .40364 L p .43443 .39544 L F P
0 g
s
.7 .614 .757 r
.42468 .40038 m .42604 .4038 L p .43443 .39544 L F P
0 g
s
.698 .57 .707 r
.43906 .4071 m .43527 .41035 L .44003 .41017 L closepath p F P
0 g
s
.697 .552 .686 r
.44003 .41017 m .43527 .41035 L .42974 .41586 L p F P
0 g
s
.7 .584 .722 r
.43527 .41035 m .43906 .4071 L .43779 .40344 L p F P
0 g
s
.709 .619 .754 r
.40099 .40158 m .40183 .40369 L p .41056 .39574 L F P
0 g
s
.714 .607 .736 r
.40099 .40158 m .39852 .40357 L .40183 .40369 L closepath p F P
0 g
s
.716 .593 .717 r
.39167 .40981 m .39178 .41016 L p .40183 .40369 L F P
0 g
s
.716 .593 .717 r
.40183 .40369 m .39852 .40357 L .39167 .40981 L p F P
0 g
s
.7 .598 .739 r
.43652 .40021 m .43168 .40364 L .43779 .40344 L closepath p F P
0 g
s
.7 .614 .757 r
.43168 .40364 m .43652 .40021 L .43443 .39544 L p F P
0 g
s
.707 .552 .675 r
.41789 .41629 m .41753 .41672 L .418 .41672 L closepath p F P
0 g
s
.696 .581 .723 r
.44433 .40312 m .43779 .40344 L .43906 .4071 L closepath p F P
0 g
s
.695 .578 .721 r
.43906 .4071 m .44003 .41017 L p .44932 .40284 L F P
0 g
s
.695 .578 .721 r
.44932 .40284 m .44433 .40312 L .43906 .4071 L p F P
0 g
s
.695 .578 .721 r
.44003 .41017 m .44818 .40973 L p .44932 .40284 L F P
0 g
s
.693 .549 .686 r
.44818 .40973 m .44003 .41017 L .44157 .41605 L closepath p F P
0 g
s
.697 .552 .686 r
.44149 .41613 m .44157 .41605 L .44003 .41017 L p F P
0 g
s
.697 .552 .686 r
.4299 .41655 m .44149 .41613 L p .44003 .41017 L F P
0 g
s
.697 .552 .686 r
.42974 .41586 m .4299 .41655 L p .44003 .41017 L F P
0 g
s
.715 .592 .717 r
.39852 .40357 m .38935 .40322 L .39167 .40981 L closepath p F P
0 g
s
.72 .584 .702 r
.39167 .40981 m .39136 .41013 L .39178 .41016 L closepath p F P
0 g
s
.721 .595 .715 r
.39136 .41013 m .39167 .40981 L .38935 .40322 L p F P
0 g
s
.721 .569 .683 r
.38665 .41584 m .39342 .41622 L .39178 .41016 L p F P
0 g
s
.721 .569 .683 r
.39178 .41016 m .39136 .41013 L .38665 .41584 L p F P
0 g
s
.701 .531 .655 r
.42911 .41657 m .418 .41672 L .41905 .42212 L p F P
0 g
s
.706 .535 .654 r
.41382 .42209 m .41905 .42212 L .418 .41672 L p F P
0 g
s
.706 .535 .654 r
.418 .41672 m .41753 .41672 L .41382 .42209 L p F P
0 g
s
.708 .543 .662 r
.40692 .42204 m .41382 .42209 L .41753 .41672 L p F P
0 g
s
.708 .543 .662 r
.40603 .41748 m .40692 .42204 L p .41753 .41672 L F P
0 g
s
.708 .543 .662 r
.41753 .41672 m .40667 .41663 L .40603 .41748 L p F P
0 g
s
.714 .606 .734 r
.39852 .40357 m .40099 .40158 L p .38912 .40266 L F P
0 g
s
.714 .606 .734 r
.38912 .40266 m .38935 .40322 L .39852 .40357 L p F P
0 g
s
.721 .595 .715 r
.38187 .40956 m .39136 .41013 L p .38935 .40322 L F P
0 g
s
.722 .578 .692 r
.38073 .41552 m .38665 .41584 L .39136 .41013 L p F P
0 g
s
.722 .578 .692 r
.37977 .41193 m .38073 .41552 L p .39136 .41013 L F P
0 g
s
.722 .578 .692 r
.39136 .41013 m .38187 .40956 L .37977 .41193 L p F P
0 g
s
.701 .547 .675 r
.42974 .41586 m .42911 .41657 L .4299 .41655 L closepath p F P
0 g
s
.709 .544 .663 r
.40667 .41663 m .40585 .41662 L .40603 .41748 L closepath p F P
0 g
s
.715 .546 .66 r
.40312 .42194 m .40603 .41748 L .40585 .41662 L p F P
0 g
s
.715 .546 .66 r
.39454 .42169 m .40312 .42194 L p .40585 .41662 L F P
0 g
s
.715 .546 .66 r
.39414 .41961 m .39454 .42169 L p .40585 .41662 L F P
0 g
s
.715 .546 .66 r
.40585 .41662 m .39643 .41632 L .39414 .41961 L p F P
0 g
s
.705 .617 .756 r
.42261 .39572 m .42042 .39573 L .41284 .40083 L p F P
0 g
s
.705 .618 .757 r
.42042 .39573 m .41056 .39574 L .41284 .40083 L closepath p F P
0 g
s
.696 .609 .756 r
.43779 .40344 m .44433 .40312 L p .44603 .3949 L F P
0 g
s
.696 .609 .756 r
.43652 .40021 m .43779 .40344 L p .44603 .3949 L F P
0 g
s
.701 .531 .655 r
.41905 .42212 m .42515 .42203 L .42911 .41657 L p F P
0 g
s
.7 .53 .654 r
.4299 .41655 m .42911 .41657 L .42515 .42203 L p F P
0 g
s
.7 .53 .654 r
.42515 .42203 m .43094 .42192 L .4299 .41655 L p F P
0 g
s
.695 .526 .655 r
.44149 .41613 m .4299 .41655 L .43094 .42192 L p F P
0 g
s
.709 .619 .754 r
.41056 .39574 m .40933 .39572 L .40099 .40158 L p F P
0 g
s
.709 .619 .754 r
.40933 .39572 m .40099 .40158 L .3984 .39577 L p F P
0 g
s
.714 .606 .734 r
.40099 .40158 m .3984 .39577 L .38912 .40266 L p F P
0 g
s
.7 .614 .757 r
.43443 .39544 m .43222 .3955 L .42468 .40038 L p F P
0 g
s
.701 .616 .758 r
.43222 .3955 m .42261 .39572 L .42468 .40038 L closepath p F P
0 g
s
.713 .539 .653 r
.40603 .41748 m .40312 .42194 L .40692 .42204 L closepath p F P
0 g
s
.719 .608 .732 r
.38912 .40266 m .38853 .40316 L .38935 .40322 L closepath p F P
0 g
s
.721 .595 .715 r
.38935 .40322 m .38853 .40316 L .38187 .40956 L p F P
0 g
s
.715 .547 .66 r
.39643 .41632 m .39342 .41622 L .39414 .41961 L closepath p F P
0 g
s
.719 .619 .746 r
.38853 .40316 m .38912 .40266 L .38654 .39674 L p F P
0 g
s
.719 .619 .746 r
.38654 .39674 m .37917 .40254 L .38853 .40316 L p F P
0 g
s
.721 .605 .727 r
.37903 .40939 m .38187 .40956 L .38853 .40316 L p F P
0 g
s
.721 .605 .727 r
.37724 .40424 m .37903 .40939 L p .38853 .40316 L F P
0 g
s
.721 .605 .727 r
.38853 .40316 m .37917 .40254 L .37724 .40424 L p F P
0 g
s
.693 .564 .705 r
.4509 .40748 m .44818 .40973 L .45153 .40953 L closepath p F P
0 g
s
.691 .546 .685 r
.45153 .40953 m .44818 .40973 L .44157 .41605 L p F P
0 g
s
.695 .578 .721 r
.44818 .40973 m .4509 .40748 L .44932 .40284 L p F P
0 g
s
.713 .634 .767 r
.38912 .40266 m .3984 .39577 L .39825 .39546 L p F P
0 g
s
.713 .634 .767 r
.38654 .39674 m .38912 .40266 L p .39825 .39546 L F P
0 g
s
.696 .609 .756 r
.44433 .40312 m .44836 .40034 L .44603 .3949 L p F P
0 g
s
.695 .593 .737 r
.44836 .40034 m .44433 .40312 L .44932 .40284 L closepath p F P
0 g
s
.721 .549 .657 r
.39292 .42162 m .39414 .41961 L .39342 .41622 L p F P
0 g
s
.721 .549 .657 r
.38323 .42111 m .39292 .42162 L p .39342 .41622 L F P
0 g
s
.721 .549 .657 r
.39342 .41622 m .38665 .41584 L .38323 .42111 L p F P
0 g
s
.696 .609 .756 r
.44603 .3949 m .4449 .39496 L .43652 .40021 L p F P
0 g
s
.697 .612 .758 r
.4449 .39496 m .43443 .39544 L .43652 .40021 L closepath p F P
0 g
s
.689 .572 .718 r
.4509 .40748 m .45153 .40953 L p .46065 .402 L F P
0 g
s
.689 .572 .718 r
.46065 .402 m .4581 .4022 L .4509 .40748 L p F P
0 g
s
.691 .576 .721 r
.4581 .4022 m .44932 .40284 L .4509 .40748 L closepath p F P
0 g
s
.691 .546 .685 r
.44157 .41605 m .44159 .41613 L p .45153 .40953 L F P
0 g
s
.695 .541 .674 r
.44157 .41605 m .44149 .41613 L .44159 .41613 L closepath p F P
0 g
s
.693 .524 .654 r
.44159 .41613 m .44149 .41613 L .43725 .4217 L p F P
0 g
s
.695 .526 .655 r
.43094 .42192 m .43725 .4217 L .44149 .41613 L p F P
0 g
s
.722 .577 .692 r
.38187 .40956 m .37903 .40939 L .37977 .41193 L closepath p F P
0 g
s
.691 .546 .685 r
.44159 .41613 m .45305 .41544 L .45153 .40953 L p F P
0 g
s
.689 .521 .655 r
.4534 .41714 m .45305 .41544 L .44159 .41613 L p F P
0 g
s
.689 .521 .655 r
.45032 .42103 m .4534 .41714 L p .44159 .41613 L F P
0 g
s
.689 .521 .655 r
.44159 .41613 m .44261 .42147 L .45032 .42103 L p F P
0 g
s
.693 .524 .654 r
.43725 .4217 m .44261 .42147 L .44159 .41613 L p F P
0 g
s
.689 .572 .718 r
.45153 .40953 m .46225 .40871 L p .46065 .402 L F P
0 g
s
.687 .544 .686 r
.46225 .40871 m .45153 .40953 L .45305 .41544 L p F P
0 g
s
.692 .591 .738 r
.44836 .40034 m .44932 .40284 L .4581 .4022 L p F P
0 g
s
.726 .596 .711 r
.37724 .40424 m .37274 .40885 L .37903 .40939 L closepath p F P
0 g
s
.728 .579 .687 r
.37723 .41524 m .37977 .41193 L .37903 .40939 L p F P
0 g
s
.728 .579 .687 r
.36811 .41454 m .37723 .41524 L p .37903 .40939 L F P
0 g
s
.728 .579 .687 r
.37903 .40939 m .37274 .40885 L .36811 .41454 L p F P
0 g
s
.727 .571 .679 r
.37977 .41193 m .37723 .41524 L .38073 .41552 L closepath p F P
0 g
s
.721 .549 .657 r
.38187 .42103 m .38323 .42111 L .38665 .41584 L p F P
0 g
s
.721 .549 .657 r
.38665 .41584 m .38073 .41552 L .38187 .42103 L p F P
0 g
s
.72 .605 .727 r
.37917 .40254 m .37652 .40237 L .37724 .40424 L closepath p F P
0 g
s
.727 .606 .722 r
.37274 .40885 m .37724 .40424 L .37652 .40237 L p F P
0 g
s
.693 .607 .756 r
.44603 .3949 m .44836 .40034 L .45766 .39465 L p F P
0 g
s
.692 .591 .738 r
.46021 .40079 m .45766 .39465 L .44836 .40034 L p F P
0 g
s
.692 .591 .738 r
.4581 .4022 m .46021 .40079 L p .44836 .40034 L F P
0 g
s
.718 .633 .762 r
.37917 .40254 m .38654 .39674 L .38561 .39482 L p F P
0 g
s
.718 .633 .762 r
.37652 .40237 m .37917 .40254 L p .38561 .39482 L F P
0 g
s
.719 .542 .65 r
.39414 .41961 m .39292 .42162 L .39454 .42169 L closepath p F P
0 g
s
.699 .509 .628 r
.42515 .42203 m .41905 .42212 L .41971 .42708 L p F P
0 g
s
.704 .513 .627 r
.41132 .42705 m .41971 .42708 L .41905 .42212 L p F P
0 g
s
.704 .513 .627 r
.41905 .42212 m .41382 .42209 L .41132 .42705 L p F P
0 g
s
.718 .633 .762 r
.37466 .39802 m .37652 .40237 L p .38561 .39482 L F P
0 g
s
.724 .62 .741 r
.37466 .39802 m .37018 .40178 L .37652 .40237 L closepath p F P
0 g
s
.727 .606 .722 r
.36597 .4083 m .37274 .40885 L p .37652 .40237 L F P
0 g
s
.727 .606 .722 r
.36533 .40641 m .36597 .4083 L p .37652 .40237 L F P
0 g
s
.727 .606 .722 r
.37652 .40237 m .37018 .40178 L .36533 .40641 L p F P
0 g
s
.705 .515 .628 r
.40759 .42702 m .41132 .42705 L .41382 .42209 L p F P
0 g
s
.705 .515 .628 r
.41382 .42209 m .40692 .42204 L .40759 .42702 L p F P
0 g
s
.727 .553 .656 r
.37404 .42043 m .38187 .42103 L .38073 .41552 L p F P
0 g
s
.727 .553 .656 r
.38073 .41552 m .37723 .41524 L .37404 .42043 L p F P
0 g
s
.704 .629 .77 r
.41026 .39511 m .41056 .39574 L .42042 .39573 L p F P
0 g
s
.708 .63 .768 r
.41026 .39511 m .40933 .39572 L .41056 .39574 L closepath p F P
0 g
s
.711 .519 .627 r
.40077 .42684 m .40759 .42702 L .40692 .42204 L p F P
0 g
s
.711 .519 .627 r
.40692 .42204 m .40312 .42194 L .40077 .42684 L p F P
0 g
s
.703 .628 .77 r
.42211 .39467 m .42042 .39573 L .42261 .39572 L closepath p F P
0 g
s
.704 .629 .77 r
.42042 .39573 m .42211 .39467 L p .41026 .39511 L F P
0 g
s
.697 .508 .627 r
.43094 .42192 m .42515 .42203 L .42248 .42705 L p F P
0 g
s
.699 .509 .628 r
.41971 .42708 m .42248 .42705 L .42515 .42203 L p F P
0 g
s
.7 .627 .771 r
.42211 .39467 m .42261 .39572 L .43222 .3955 L p F P
0 g
s
.709 .619 .754 r
.3984 .39577 m .39886 .39548 L .40933 .39572 L p F P
0 g
s
.706 .642 .783 r
.40933 .39572 m .41026 .39511 L .40766 .39018 L p F P
0 g
s
.706 .642 .783 r
.40766 .39018 m .39886 .39548 L .40933 .39572 L p F P
0 g
s
.687 .544 .686 r
.45305 .41544 m .45507 .41529 L .46225 .40871 L p F P
0 g
s
.684 .523 .662 r
.45507 .41529 m .45305 .41544 L .4534 .41714 L closepath p F P
0 g
s
.727 .578 .687 r
.36774 .41451 m .36811 .41454 L .37274 .40885 L p F P
0 g
s
.727 .578 .687 r
.37274 .40885 m .36597 .4083 L .36774 .41451 L p F P
0 g
s
.712 .52 .627 r
.3952 .42668 m .40077 .42684 L .40312 .42194 L p F P
0 g
s
.712 .52 .627 r
.40312 .42194 m .39454 .42169 L .3952 .42668 L p F P
0 g
s
.69 .586 .734 r
.46021 .40079 m .4581 .4022 L .46065 .402 L closepath p F P
0 g
s
.692 .504 .628 r
.43725 .4217 m .43094 .42192 L .4316 .42688 L p F P
0 g
s
.697 .508 .627 r
.42248 .42705 m .4316 .42688 L .43094 .42192 L p F P
0 g
s
.704 .629 .77 r
.42211 .39467 m .41952 .38976 L .41026 .39511 L p F P
0 g
s
.7 .66 .808 r
.41952 .38976 m .41026 .39511 L .40766 .39018 L p F P
0 g
s
.685 .54 .683 r
.45507 .41529 m .46432 .41452 L .46284 .40866 L p F P
0 g
s
.685 .54 .683 r
.46284 .40866 m .46225 .40871 L .45507 .41529 L p F P
0 g
s
.682 .52 .66 r
.46432 .41452 m .45507 .41529 L .4534 .41714 L p F P
0 g
s
.687 .557 .702 r
.46274 .40832 m .46225 .40871 L .46284 .40866 L closepath p F P
0 g
s
.689 .572 .718 r
.46225 .40871 m .46274 .40832 L .46065 .402 L p F P
0 g
s
.708 .633 .771 r
.39886 .39548 m .39825 .39546 L .3984 .39577 L closepath p F P
0 g
s
.682 .555 .704 r
.47392 .40752 m .47205 .40165 L .46274 .40832 L p F P
0 g
s
.682 .555 .704 r
.46274 .40832 m .46284 .40866 L .47392 .40752 L p F P
0 g
s
.686 .569 .717 r
.46065 .402 m .46274 .40832 L .47205 .40165 L p F P
0 g
s
.727 .559 .664 r
.36888 .42003 m .37404 .42043 L .37723 .41524 L p F P
0 g
s
.727 .559 .664 r
.36784 .41495 m .36888 .42003 L p .37723 .41524 L F P
0 g
s
.727 .559 .664 r
.37723 .41524 m .36811 .41454 L .36784 .41495 L p F P
0 g
s
.681 .538 .684 r
.47458 .40995 m .47392 .40752 L .46284 .40866 L p F P
0 g
s
.681 .538 .684 r
.47008 .41395 m .47458 .40995 L p .46284 .40866 L F P
0 g
s
.681 .538 .684 r
.46284 .40866 m .46432 .41452 L .47008 .41395 L p F P
0 g
s
.699 .625 .77 r
.43396 .39445 m .43222 .3955 L .43443 .39544 L closepath p F P
0 g
s
.7 .627 .771 r
.43222 .3955 m .43396 .39445 L p .42211 .39467 L F P
0 g
s
.706 .642 .783 r
.39886 .39548 m .40766 .39018 L p .39579 .39078 L F P
0 g
s
.706 .642 .783 r
.39579 .39078 m .39825 .39546 L .39886 .39548 L p F P
0 g
s
.713 .634 .767 r
.39825 .39546 m .38912 .39499 L .38654 .39674 L p F P
0 g
s
.711 .644 .781 r
.39579 .39078 m .38912 .39499 L .39825 .39546 L closepath p F P
0 g
s
.696 .623 .771 r
.43396 .39445 m .43443 .39544 L .4449 .39496 L p F P
0 g
s
.7 .627 .771 r
.43396 .39445 m .43138 .38949 L .42211 .39467 L p F P
0 g
s
.696 .658 .808 r
.43138 .38949 m .42211 .39467 L .41952 .38976 L p F P
0 g
s
.687 .585 .736 r
.46021 .40079 m .46065 .402 L .47179 .40091 L p F P
0 g
s
.686 .569 .717 r
.47205 .40165 m .47179 .40091 L .46065 .402 L p F P
0 g
s
.69 .502 .627 r
.44261 .42147 m .43725 .4217 L .43441 .42678 L p F P
0 g
s
.692 .504 .628 r
.4316 .42688 m .43441 .42678 L .43725 .4217 L p F P
0 g
s
.718 .524 .626 r
.39072 .42646 m .3952 .42668 L .39454 .42169 L p F P
0 g
s
.718 .524 .626 r
.39454 .42169 m .39292 .42162 L .39072 .42646 L p F P
0 g
s
.712 .632 .766 r
.38912 .39499 m .38561 .39482 L .38654 .39674 L closepath p F P
0 g
s
.682 .52 .66 r
.4534 .41714 m .45408 .42079 L p .46432 .41452 L F P
0 g
s
.687 .517 .652 r
.4534 .41714 m .45032 .42103 L .45408 .42079 L closepath p F P
0 g
s
.719 .528 .631 r
.38255 .42605 m .39072 .42646 L .39292 .42162 L p F P
0 g
s
.719 .528 .631 r
.38219 .42327 m .38255 .42605 L p .39292 .42162 L F P
0 g
s
.719 .528 .631 r
.39292 .42162 m .38323 .42111 L .38219 .42327 L p F P
0 g
s
.687 .585 .736 r
.47179 .40091 m .46951 .39518 L .46021 .40079 L p F P
0 g
s
.688 .613 .767 r
.46021 .40079 m .46951 .39518 L .46855 .39301 L p F P
0 g
s
.688 .613 .767 r
.45766 .39465 m .46021 .40079 L p .46855 .39301 L F P
0 g
s
.723 .632 .755 r
.37018 .40178 m .37466 .39802 L .37269 .39388 L p F P
0 g
s
.723 .632 .755 r
.36338 .40119 m .37018 .40178 L p .37269 .39388 L F P
0 g
s
.726 .604 .721 r
.37018 .40178 m .36338 .40119 L .36533 .40641 L closepath p F P
0 g
s
.685 .498 .628 r
.45032 .42103 m .44261 .42147 L .44327 .42641 L p F P
0 g
s
.69 .502 .627 r
.43441 .42678 m .44327 .42641 L .44261 .42147 L p F P
0 g
s
.696 .623 .771 r
.44581 .39442 m .44324 .38938 L .43396 .39445 L p F P
0 g
s
.696 .623 .771 r
.4449 .39496 m .44581 .39442 L p .43396 .39445 L F P
0 g
s
.693 .654 .807 r
.44324 .38938 m .43396 .39445 L .43138 .38949 L p F P
0 g
s
.732 .596 .705 r
.36533 .40641 m .36383 .40807 L .36597 .4083 L closepath p F P
0 g
s
.734 .581 .685 r
.35955 .41363 m .36774 .41451 L .36597 .4083 L p F P
0 g
s
.734 .581 .685 r
.36597 .4083 m .36383 .40807 L .35955 .41363 L p F P
0 g
s
.732 .606 .716 r
.36383 .40807 m .36533 .40641 L .36338 .40119 L p F P
0 g
s
.718 .633 .762 r
.38561 .39482 m .37973 .39437 L .37466 .39802 L p F P
0 g
s
.717 .631 .761 r
.37973 .39437 m .37269 .39388 L .37466 .39802 L closepath p F P
0 g
s
.71 .642 .779 r
.38912 .39499 m .39579 .39078 L p .38392 .39158 L F P
0 g
s
.71 .642 .779 r
.38392 .39158 m .38561 .39482 L .38912 .39499 L p F P
0 g
s
.695 .62 .768 r
.44581 .39442 m .4449 .39496 L .44603 .3949 L closepath p F P
0 g
s
.732 .606 .716 r
.35534 .40713 m .36383 .40807 L p .36338 .40119 L F P
0 g
s
.734 .588 .693 r
.35436 .41309 m .35955 .41363 L .36383 .40807 L p F P
0 g
s
.734 .588 .693 r
.35338 .40952 m .35436 .41309 L p .36383 .40807 L F P
0 g
s
.734 .588 .693 r
.36383 .40807 m .35534 .40713 L .35338 .40952 L p F P
0 g
s
.693 .607 .756 r
.45766 .39465 m .4574 .39409 L .44603 .3949 L p F P
0 g
s
.692 .619 .77 r
.44581 .39442 m .44603 .3949 L .4574 .39409 L p F P
0 g
s
.715 .644 .776 r
.38392 .39158 m .37973 .39437 L .38561 .39482 L closepath p F P
0 g
s
.728 .561 .664 r
.36811 .41454 m .36774 .41451 L .36784 .41495 L closepath p F P
0 g
s
.72 .53 .632 r
.38323 .42111 m .38187 .42103 L .38219 .42327 L closepath p F P
0 g
s
.677 .515 .659 r
.47008 .41395 m .46432 .41452 L .46524 .41917 L closepath p F P
0 g
s
.682 .52 .66 r
.4646 .41995 m .46524 .41917 L .46432 .41452 L p F P
0 g
s
.682 .52 .66 r
.45408 .42079 m .4646 .41995 L p .46432 .41452 L F P
0 g
s
.692 .619 .77 r
.4574 .39409 m .4551 .38945 L .44581 .39442 L p F P
0 g
s
.69 .649 .804 r
.4551 .38945 m .44581 .39442 L .44324 .38938 L p F P
0 g
s
.735 .562 .659 r
.3651 .41965 m .36784 .41495 L .36774 .41451 L p F P
0 g
s
.735 .562 .659 r
.35643 .41879 m .3651 .41965 L p .36774 .41451 L F P
0 g
s
.735 .562 .659 r
.36774 .41451 m .35955 .41363 L .35643 .41879 L p F P
0 g
s
.727 .533 .629 r
.38106 .42595 m .38219 .42327 L .38187 .42103 L p F P
0 g
s
.727 .533 .629 r
.37187 .42526 m .38106 .42595 L p .38187 .42103 L F P
0 g
s
.727 .533 .629 r
.38187 .42103 m .37404 .42043 L .37187 .42526 L p F P
0 g
s
.683 .496 .627 r
.45408 .42079 m .45032 .42103 L .44728 .42618 L p F P
0 g
s
.685 .498 .628 r
.44327 .42641 m .44728 .42618 L .45032 .42103 L p F P
0 g
s
.733 .557 .654 r
.36784 .41495 m .3651 .41965 L .36888 .42003 L closepath p F P
0 g
s
.723 .632 .755 r
.36276 .39971 m .36338 .40119 L p .37269 .39388 L F P
0 g
s
.73 .619 .735 r
.36276 .39971 m .36137 .40096 L .36338 .40119 L closepath p F P
0 g
s
.732 .606 .716 r
.36338 .40119 m .36137 .40096 L .35534 .40713 L p F P
0 g
s
.678 .492 .627 r
.4646 .41995 m .45408 .42079 L .45473 .42571 L p F P
0 g
s
.683 .496 .627 r
.44728 .42618 m .45473 .42571 L .45408 .42079 L p F P
0 g
s
.68 .571 .726 r
.47205 .40165 m .47392 .40752 L p .48272 .39957 L F P
0 g
s
.68 .571 .726 r
.48272 .39957 m .47351 .40072 L .47205 .40165 L p F P
0 g
s
.683 .577 .73 r
.47351 .40072 m .47179 .40091 L .47205 .40165 L closepath p F P
0 g
s
.728 .628 .747 r
.36137 .40096 m .36276 .39971 L .36015 .39402 L p F P
0 g
s
.728 .628 .747 r
.36015 .39402 m .35301 .39997 L .36137 .40096 L p F P
0 g
s
.731 .614 .728 r
.35255 .40683 m .35534 .40713 L .36137 .40096 L p F P
0 g
s
.731 .614 .728 r
.35083 .40204 m .35255 .40683 L p .36137 .40096 L F P
0 g
s
.731 .614 .728 r
.36137 .40096 m .35301 .39997 L .35083 .40204 L p F P
0 g
s
.715 .64 .773 r
.37973 .39437 m .38392 .39158 L p .37204 .39262 L F P
0 g
s
.715 .64 .773 r
.37204 .39262 m .37269 .39388 L .37973 .39437 L p F P
0 g
s
.723 .632 .755 r
.37269 .39388 m .37057 .39367 L .36276 .39971 L p F P
0 g
s
.721 .628 .753 r
.37057 .39367 m .36276 .39971 L .36015 .39402 L p F P
0 g
s
.68 .571 .726 r
.47392 .40752 m .47833 .407 L p .48272 .39957 L F P
0 g
s
.677 .542 .693 r
.47833 .407 m .47392 .40752 L .47458 .40995 L closepath p F P
0 g
s
.683 .604 .762 r
.47179 .40091 m .47351 .40072 L p .47954 .39174 L F P
0 g
s
.683 .604 .762 r
.46951 .39518 m .47179 .40091 L p .47954 .39174 L F P
0 g
s
.69 .618 .771 r
.4589 .39396 m .4574 .39409 L .45766 .39465 L closepath p F P
0 g
s
.688 .613 .767 r
.46855 .39301 m .4589 .39396 L .45766 .39465 L p F P
0 g
s
.679 .532 .68 r
.47458 .40995 m .47008 .41395 L .47541 .41339 L closepath p F P
0 g
s
.675 .512 .656 r
.47541 .41339 m .47008 .41395 L .46524 .41917 L p F P
0 g
s
.695 .486 .6 r
.42248 .42705 m .41971 .42708 L .42004 .43168 L p F P
0 g
s
.701 .49 .599 r
.40989 .43164 m .42004 .43168 L .41971 .42708 L p F P
0 g
s
.701 .49 .599 r
.41971 .42708 m .41132 .42705 L .40989 .43164 L p F P
0 g
s
.702 .492 .6 r
.40791 .43163 m .40989 .43164 L .41132 .42705 L p F P
0 g
s
.702 .492 .6 r
.41132 .42705 m .40759 .42702 L .40791 .43163 L p F P
0 g
s
.694 .484 .599 r
.4316 .42688 m .42248 .42705 L .42097 .43167 L p F P
0 g
s
.695 .486 .6 r
.42004 .43168 m .42097 .43167 L .42248 .42705 L p F P
0 g
s
.681 .585 .741 r
.48137 .39604 m .47351 .40072 L .48272 .39957 L closepath p F P
0 g
s
.683 .604 .762 r
.47351 .40072 m .48137 .39604 L .47954 .39174 L p F P
0 g
s
.675 .537 .689 r
.47458 .40995 m .47541 .41339 L p .48484 .40618 L F P
0 g
s
.675 .537 .689 r
.48484 .40618 m .47833 .407 L .47458 .40995 L p F P
0 g
s
.709 .496 .599 r
.39942 .43141 m .40791 .43163 L .40759 .42702 L p F P
0 g
s
.709 .496 .599 r
.40759 .42702 m .40077 .42684 L .39942 .43141 L p F P
0 g
s
.726 .533 .629 r
.36958 .42508 m .37187 .42526 L .37404 .42043 L p F P
0 g
s
.726 .533 .629 r
.37404 .42043 m .36888 .42003 L .36958 .42508 L p F P
0 g
s
.689 .629 .783 r
.4551 .38945 m .4574 .39409 L .4589 .39396 L p F P
0 g
s
.724 .528 .624 r
.38219 .42327 m .38106 .42595 L .38255 .42605 L closepath p F P
0 g
s
.733 .588 .693 r
.35534 .40713 m .35255 .40683 L .35338 .40952 L closepath p F P
0 g
s
.688 .48 .6 r
.43441 .42678 m .4316 .42688 L .43194 .43147 L p F P
0 g
s
.694 .484 .599 r
.42097 .43167 m .43194 .43147 L .4316 .42688 L p F P
0 g
s
.689 .629 .783 r
.4589 .39396 m .46696 .3897 L p .4551 .38945 L F P
0 g
s
.688 .623 .778 r
.46696 .3897 m .4589 .39396 L .46855 .39301 L closepath p F P
0 g
s
.71 .497 .6 r
.39552 .43129 m .39942 .43141 L .40077 .42684 L p F P
0 g
s
.71 .497 .6 r
.40077 .42684 m .3952 .42668 L .39552 .43129 L p F P
0 g
s
.734 .561 .658 r
.35557 .4187 m .35643 .41879 L .35955 .41363 L p F P
0 g
s
.734 .561 .658 r
.35955 .41363 m .35436 .41309 L .35557 .4187 L p F P
0 g
s
.72 .643 .77 r
.37204 .39262 m .37057 .39367 L .37269 .39388 L closepath p F P
0 g
s
.686 .478 .599 r
.44327 .42641 m .43441 .42678 L .4328 .43144 L p F P
0 g
s
.688 .48 .6 r
.43194 .43147 m .4328 .43144 L .43441 .42678 L p F P
0 g
s
.677 .554 .708 r
.48391 .40309 m .47833 .407 L .48484 .40618 L closepath p F P
0 g
s
.68 .571 .726 r
.47833 .407 m .48391 .40309 L .48272 .39957 L p F P
0 g
s
.706 .642 .783 r
.40766 .39018 m .40504 .38573 L .39579 .39078 L p F P
0 g
s
.7 .676 .824 r
.39579 .39078 m .40504 .38573 L .40399 .38412 L p F P
0 g
s
.7 .676 .824 r
.39317 .38627 m .39579 .39078 L p .40399 .38412 L F P
0 g
s
.71 .642 .779 r
.39579 .39078 m .39317 .38627 L .38392 .39158 L p F P
0 g
s
.716 .502 .599 r
.38944 .431 m .39552 .43129 L .3952 .42668 L p F P
0 g
s
.716 .502 .599 r
.3952 .42668 m .39072 .42646 L .38944 .431 L p F P
0 g
s
.7 .66 .808 r
.40766 .39018 m .41691 .38533 L .41952 .38976 L p F P
0 g
s
.696 .676 .827 r
.40766 .39018 m .41691 .38533 L .41623 .38429 L p F P
0 g
s
.696 .676 .827 r
.40504 .38573 m .40766 .39018 L p .41623 .38429 L F P
0 g
s
.675 .512 .656 r
.46524 .41917 m .46536 .41988 L p .47541 .41339 L F P
0 g
s
.68 .509 .649 r
.46524 .41917 m .4646 .41995 L .46536 .41988 L closepath p F P
0 g
s
.704 .675 .819 r
.38392 .39158 m .39317 .38627 L .39149 .38365 L p F P
0 g
s
.704 .675 .819 r
.38129 .38697 m .38392 .39158 L p .39149 .38365 L F P
0 g
s
.715 .64 .773 r
.38392 .39158 m .38129 .38697 L .37204 .39262 L p F P
0 g
s
.733 .537 .628 r
.36307 .42444 m .36958 .42508 L .36888 .42003 L p F P
0 g
s
.733 .537 .628 r
.36888 .42003 m .3651 .41965 L .36307 .42444 L p F P
0 g
s
.721 .628 .753 r
.36015 .39402 m .36188 .39279 L .37057 .39367 L p F P
0 g
s
.717 .652 .783 r
.37057 .39367 m .37204 .39262 L .3694 .38787 L p F P
0 g
s
.717 .652 .783 r
.3694 .38787 m .36188 .39279 L .37057 .39367 L p F P
0 g
s
.738 .606 .71 r
.35083 .40204 m .34716 .40608 L .35255 .40683 L closepath p F P
0 g
s
.741 .59 .687 r
.35113 .41267 m .35338 .40952 L .35255 .40683 L p F P
0 g
s
.741 .59 .687 r
.34299 .41161 m .35113 .41267 L p .35255 .40683 L F P
0 g
s
.741 .59 .687 r
.35255 .40683 m .34716 .40608 L .34299 .41161 L p F P
0 g
s
.675 .537 .689 r
.47541 .41339 m .48634 .41206 L .48484 .40618 L p F P
0 g
s
.67 .508 .656 r
.48643 .41248 m .48634 .41206 L .47541 .41339 L p F P
0 g
s
.67 .508 .656 r
.48089 .41818 m .48643 .41248 L p .47541 .41339 L F P
0 g
s
.67 .508 .656 r
.47541 .41339 m .47644 .41872 L .48089 .41818 L p F P
0 g
s
.675 .512 .656 r
.46536 .41988 m .47644 .41872 L .47541 .41339 L p F P
0 g
s
.676 .489 .626 r
.46536 .41988 m .4646 .41995 L .46134 .42518 L p F P
0 g
s
.678 .492 .627 r
.45473 .42571 m .46134 .42518 L .4646 .41995 L p F P
0 g
s
.696 .658 .808 r
.41952 .38976 m .42878 .38504 L .43138 .38949 L p F P
0 g
s
.693 .675 .828 r
.41952 .38976 m .42878 .38504 L .4282 .38414 L p F P
0 g
s
.693 .675 .828 r
.41691 .38533 m .41952 .38976 L p .4282 .38414 L F P
0 g
s
.739 .582 .68 r
.35338 .40952 m .35113 .41267 L .35436 .41309 L closepath p F P
0 g
s
.671 .486 .626 r
.47707 .4234 m .47644 .41872 L .46536 .41988 L p F P
0 g
s
.671 .486 .626 r
.4769 .42367 m .47707 .4234 L p .46536 .41988 L F P
0 g
s
.671 .486 .626 r
.46536 .41988 m .466 .42478 L .4769 .42367 L p F P
0 g
s
.676 .489 .626 r
.46134 .42518 m .466 .42478 L .46536 .41988 L p F P
0 g
s
.717 .503 .599 r
.38286 .43067 m .38944 .431 L .39072 .42646 L p F P
0 g
s
.717 .503 .599 r
.39072 .42646 m .38255 .42605 L .38286 .43067 L p F P
0 g
s
.683 .604 .762 r
.47954 .39174 m .47473 .39233 L .46951 .39518 L p F P
0 g
s
.686 .61 .766 r
.47473 .39233 m .46855 .39301 L .46951 .39518 L closepath p F P
0 g
s
.68 .474 .599 r
.44728 .42618 m .44327 .42641 L .44361 .431 L p F P
0 g
s
.686 .478 .599 r
.4328 .43144 m .44361 .431 L .44327 .42641 L p F P
0 g
s
.709 .672 .812 r
.37204 .39262 m .38129 .38697 L .37873 .38292 L p F P
0 g
s
.709 .672 .812 r
.3694 .38787 m .37204 .39262 L p .37873 .38292 L F P
0 g
s
.728 .641 .762 r
.35301 .39997 m .36015 .39402 L .35941 .39255 L p F P
0 g
s
.728 .641 .762 r
.34987 .39961 m .35301 .39997 L p .35941 .39255 L F P
0 g
s
.731 .613 .727 r
.35301 .39997 m .34987 .39961 L .35083 .40204 L closepath p F P
0 g
s
.693 .654 .807 r
.43138 .38949 m .44065 .38487 L .44324 .38938 L p F P
0 g
s
.691 .672 .827 r
.43138 .38949 m .44065 .38487 L .4399 .38369 L p F P
0 g
s
.691 .672 .827 r
.42878 .38504 m .43138 .38949 L p .4399 .38369 L F P
0 g
s
.738 .614 .72 r
.34716 .40608 m .35083 .40204 L .34987 .39961 L p F P
0 g
s
.741 .566 .656 r
.34822 .41775 m .35557 .4187 L .35436 .41309 L p F P
0 g
s
.741 .566 .656 r
.35436 .41309 m .35113 .41267 L .34822 .41775 L p F P
0 g
s
.733 .541 .632 r
.35628 .42377 m .36307 .42444 L .3651 .41965 L p F P
0 g
s
.733 .541 .632 r
.3558 .42017 m .35628 .42377 L p .3651 .41965 L F P
0 g
s
.733 .541 .632 r
.3651 .41965 m .35643 .41879 L .3558 .42017 L p F P
0 g
s
.678 .471 .599 r
.45473 .42571 m .44728 .42618 L .44557 .43088 L p F P
0 g
s
.68 .474 .599 r
.44361 .431 m .44557 .43088 L .44728 .42618 L p F P
0 g
s
.723 .508 .598 r
.37985 .43045 m .38286 .43067 L .38255 .42605 L p F P
0 g
s
.723 .508 .598 r
.38255 .42605 m .38106 .42595 L .37985 .43045 L p F P
0 g
s
.674 .561 .72 r
.48391 .40309 m .48484 .40618 L p .49351 .39806 L F P
0 g
s
.674 .561 .72 r
.49351 .39806 m .49144 .39837 L .48391 .40309 L p F P
0 g
s
.677 .567 .724 r
.49144 .39837 m .48272 .39957 L .48391 .40309 L closepath p F P
0 g
s
.69 .649 .804 r
.44324 .38938 m .45253 .38483 L .4551 .38945 L p F P
0 g
s
.688 .668 .825 r
.44324 .38938 m .45253 .38483 L .45137 .38297 L p F P
0 g
s
.688 .668 .825 r
.44065 .38487 m .44324 .38938 L p .45137 .38297 L F P
0 g
s
.728 .641 .762 r
.34823 .3959 m .34987 .39961 L p .35941 .39255 L F P
0 g
s
.735 .628 .74 r
.34823 .3959 m .34493 .39889 L .34987 .39961 L closepath p F P
0 g
s
.738 .614 .72 r
.33904 .40501 m .34716 .40608 L p .34987 .39961 L F P
0 g
s
.738 .614 .72 r
.34987 .39961 m .34493 .39889 L .33904 .40501 L p F P
0 g
s
.724 .51 .6 r
.37061 .42978 m .37985 .43045 L .38106 .42595 L p F P
0 g
s
.724 .51 .6 r
.38106 .42595 m .37187 .42526 L .37061 .42978 L p F P
0 g
s
.72 .641 .769 r
.36188 .39279 m .35941 .39255 L .36015 .39402 L closepath p F P
0 g
s
.686 .622 .779 r
.46696 .3897 m .46855 .39301 L .47473 .39233 L p F P
0 g
s
.674 .561 .72 r
.48484 .40618 m .49562 .40465 L .49351 .39806 L p F P
0 g
s
.67 .532 .687 r
.49577 .40521 m .49562 .40465 L .48484 .40618 L p F P
0 g
s
.67 .532 .687 r
.487 .41196 m .49577 .40521 L p .48484 .40618 L F P
0 g
s
.67 .532 .687 r
.48484 .40618 m .48634 .41206 L .487 .41196 L p F P
0 g
s
.679 .584 .742 r
.48137 .39604 m .48272 .39957 L .49144 .39837 L p F P
0 g
s
.741 .57 .662 r
.34187 .41695 m .34822 .41775 L .35113 .41267 L p F P
0 g
s
.741 .57 .662 r
.34133 .41434 m .34187 .41695 L p .35113 .41267 L F P
0 g
s
.741 .57 .662 r
.35113 .41267 m .34299 .41161 L .34133 .41434 L p F P
0 g
s
.738 .595 .697 r
.34063 .4113 m .34299 .41161 L .34716 .40608 L p F P
0 g
s
.738 .595 .697 r
.33885 .40524 m .34063 .4113 L p .34716 .40608 L F P
0 g
s
.738 .595 .697 r
.34716 .40608 m .33904 .40501 L .33885 .40524 L p F P
0 g
s
.717 .649 .78 r
.36188 .39279 m .3694 .38787 L p .35751 .38903 L F P
0 g
s
.717 .649 .78 r
.35751 .38903 m .35941 .39255 L .36188 .39279 L p F P
0 g
s
.673 .467 .599 r
.46134 .42518 m .45473 .42571 L .45507 .43028 L p F P
0 g
s
.678 .471 .599 r
.44557 .43088 m .45507 .43028 L .45473 .42571 L p F P
0 g
s
.689 .629 .783 r
.46696 .3897 m .4644 .38493 L .4551 .38945 L p F P
0 g
s
.686 .662 .821 r
.4551 .38945 m .4644 .38493 L .46266 .38202 L p F P
0 g
s
.686 .662 .821 r
.45253 .38483 m .4551 .38945 L p .46266 .38202 L F P
0 g
s
.679 .584 .742 r
.49324 .39731 m .49071 .39101 L .48137 .39604 L p F P
0 g
s
.679 .584 .742 r
.49144 .39837 m .49324 .39731 L p .48137 .39604 L F P
0 g
s
.681 .602 .76 r
.47954 .39174 m .48137 .39604 L .49071 .39101 L p F P
0 g
s
.724 .652 .777 r
.35751 .38903 m .3536 .39177 L .35941 .39255 L closepath p F P
0 g
s
.728 .641 .762 r
.35941 .39255 m .3536 .39177 L .34823 .3959 L p F P
0 g
s
.734 .543 .633 r
.35643 .41879 m .35557 .4187 L .3558 .42017 L closepath p F P
0 g
s
.665 .483 .629 r
.48089 .41818 m .47644 .41872 L .47707 .4234 L closepath p F P
0 g
s
.742 .546 .629 r
.35446 .42355 m .3558 .42017 L .35557 .4187 L p F P
0 g
s
.742 .546 .629 r
.34624 .42251 m .35446 .42355 L p .35557 .4187 L F P
0 g
s
.742 .546 .629 r
.35557 .4187 m .34822 .41775 L .34624 .42251 L p F P
0 g
s
.684 .615 .773 r
.47883 .39019 m .47473 .39233 L .47954 .39174 L closepath p F P
0 g
s
.686 .622 .779 r
.47473 .39233 m .47883 .39019 L p .46696 .3897 L F P
0 g
s
.725 .511 .6 r
.36991 .42973 m .37061 .42978 L .37187 .42526 L p F P
0 g
s
.725 .511 .6 r
.37187 .42526 m .36958 .42508 L .36991 .42973 L p F P
0 g
s
.734 .638 .753 r
.34493 .39889 m .34823 .3959 L .34576 .39085 L p F P
0 g
s
.734 .638 .753 r
.33692 .39777 m .34493 .39889 L p .34576 .39085 L F P
0 g
s
.735 .62 .731 r
.33876 .40497 m .33904 .40501 L .34493 .39889 L p F P
0 g
s
.735 .62 .731 r
.33627 .39838 m .33876 .40497 L p .34493 .39889 L F P
0 g
s
.735 .62 .731 r
.34493 .39889 m .33692 .39777 L .33627 .39838 L p F P
0 g
s
.666 .511 .664 r
.487 .41196 m .48634 .41206 L .48643 .41248 L closepath p F P
0 g
s
.725 .637 .76 r
.3536 .39177 m .34576 .39085 L .34823 .3959 L closepath p F P
0 g
s
.671 .465 .598 r
.466 .42478 m .46134 .42518 L .45951 .42993 L p F P
0 g
s
.673 .467 .599 r
.45507 .43028 m .45951 .42993 L .46134 .42518 L p F P
0 g
s
.663 .506 .661 r
.48643 .41248 m .48734 .41735 L p .49707 .41046 L F P
0 g
s
.663 .506 .661 r
.49707 .41046 m .487 .41196 L .48643 .41248 L p F P
0 g
s
.668 .504 .654 r
.48643 .41248 m .48089 .41818 L .48734 .41735 L closepath p F P
0 g
s
.668 .527 .683 r
.49577 .40521 m .487 .41196 L .49707 .41046 L closepath p F P
0 g
s
.691 .461 .57 r
.42097 .43167 m .42004 .43168 L .42007 .43595 L p F P
0 g
s
.697 .466 .57 r
.40942 .43591 m .42007 .43595 L .42004 .43168 L p F P
0 g
s
.697 .466 .57 r
.42004 .43168 m .40989 .43164 L .40942 .43591 L p F P
0 g
s
.689 .46 .57 r
.43194 .43147 m .42097 .43167 L .42049 .43595 L p F P
0 g
s
.691 .461 .57 r
.42007 .43595 m .42049 .43595 L .42097 .43167 L p F P
0 g
s
.732 .517 .6 r
.36188 .42894 m .36991 .42973 L .36958 .42508 L p F P
0 g
s
.732 .517 .6 r
.36958 .42508 m .36307 .42444 L .36188 .42894 L p F P
0 g
s
.698 .468 .57 r
.40793 .4359 m .40942 .43591 L .40989 .43164 L p F P
0 g
s
.698 .468 .57 r
.40989 .43164 m .40791 .43163 L .40793 .4359 L p F P
0 g
s
.705 .473 .57 r
.39896 .43567 m .40793 .4359 L .40791 .43163 L p F P
0 g
s
.705 .473 .57 r
.40791 .43163 m .39942 .43141 L .39896 .43567 L p F P
0 g
s
.686 .622 .779 r
.47883 .39019 m .47628 .3852 L .46696 .3897 L p F P
0 g
s
.684 .655 .815 r
.46696 .3897 m .47628 .3852 L .47381 .38089 L p F P
0 g
s
.684 .655 .815 r
.4644 .38493 m .46696 .3897 L p .47381 .38089 L F P
0 g
s
.683 .455 .57 r
.4328 .43144 m .43194 .43147 L .43198 .43574 L p F P
0 g
s
.689 .46 .57 r
.42049 .43595 m .43198 .43574 L .43194 .43147 L p F P
0 g
s
.739 .541 .625 r
.3558 .42017 m .35446 .42355 L .35628 .42377 L closepath p F P
0 g
s
.681 .453 .569 r
.44361 .431 m .4328 .43144 L .4323 .43573 L p F P
0 g
s
.683 .455 .57 r
.43198 .43574 m .4323 .43573 L .4328 .43144 L p F P
0 g
s
.706 .474 .57 r
.39552 .43557 m .39896 .43567 L .39942 .43141 L p F P
0 g
s
.706 .474 .57 r
.39942 .43141 m .39552 .43129 L .39552 .43557 L p F P
0 g
s
.741 .57 .662 r
.34299 .41161 m .34063 .4113 L .34133 .41434 L closepath p F P
0 g
s
.665 .461 .598 r
.4769 .42367 m .466 .42478 L .46634 .42934 L p F P
0 g
s
.671 .465 .598 r
.45951 .42993 m .46634 .42934 L .466 .42478 L p F P
0 g
s
.739 .597 .697 r
.33904 .40501 m .33876 .40497 L .33885 .40524 L closepath p F P
0 g
s
.663 .48 .627 r
.48734 .41735 m .48089 .41818 L .47707 .4234 L p F P
0 g
s
.746 .591 .683 r
.33885 .40524 m .33517 .41043 L .34063 .4113 L closepath p F P
0 g
s
.748 .597 .689 r
.33517 .41043 m .33885 .40524 L .33876 .40497 L p F P
0 g
s
.744 .614 .714 r
.33627 .39838 m .33147 .40374 L .33876 .40497 L closepath p F P
0 g
s
.748 .597 .689 r
.32742 .40922 m .33517 .41043 L p .33876 .40497 L F P
0 g
s
.748 .597 .689 r
.33876 .40497 m .33147 .40374 L .32742 .40922 L p F P
0 g
s
.676 .575 .735 r
.49324 .39731 m .49144 .39837 L .49351 .39806 L closepath p F P
0 g
s
.723 .646 .772 r
.3536 .39177 m .35751 .38903 L p .34559 .39052 L F P
0 g
s
.723 .646 .772 r
.34559 .39052 m .34576 .39085 L .3536 .39177 L p F P
0 g
s
.713 .479 .57 r
.38899 .43525 m .39552 .43557 L .39552 .43129 L p F P
0 g
s
.713 .479 .57 r
.39552 .43129 m .38944 .431 L .38899 .43525 L p F P
0 g
s
.681 .602 .76 r
.49071 .39101 m .49037 .39025 L .47954 .39174 L p F P
0 g
s
.681 .614 .774 r
.47883 .39019 m .47954 .39174 L .49037 .39025 L p F P
0 g
s
.7 .676 .824 r
.40399 .38412 m .398 .38386 L .39317 .38627 L p F P
0 g
s
.699 .674 .822 r
.398 .38386 m .39149 .38365 L .39317 .38627 L closepath p F P
0 g
s
.704 .675 .819 r
.39149 .38365 m .38809 .38341 L .38129 .38697 L p F P
0 g
s
.703 .671 .816 r
.38809 .38341 m .37873 .38292 L .38129 .38697 L closepath p F P
0 g
s
.696 .675 .826 r
.40831 .38416 m .40399 .38412 L .40504 .38573 L closepath p F P
0 g
s
.696 .676 .827 r
.41623 .38429 m .40831 .38416 L .40504 .38573 L p F P
0 g
s
.709 .672 .812 r
.37873 .38292 m .37841 .38289 L .3694 .38787 L p F P
0 g
s
.707 .667 .808 r
.37841 .38289 m .3694 .38787 L .36674 .38353 L p F P
0 g
s
.717 .649 .78 r
.3694 .38787 m .36674 .38353 L .35751 .38903 L p F P
0 g
s
.749 .574 .658 r
.3401 .41668 m .34133 .41434 L .34063 .4113 L p F P
0 g
s
.749 .574 .658 r
.33235 .41548 m .3401 .41668 L p .34063 .4113 L F P
0 g
s
.749 .574 .658 r
.34063 .4113 m .33517 .41043 L .33235 .41548 L p F P
0 g
s
.732 .516 .6 r
.3566 .42841 m .36188 .42894 L .36307 .42444 L p F P
0 g
s
.732 .516 .6 r
.36307 .42444 m .35628 .42377 L .3566 .42841 L p F P
0 g
s
.693 .675 .828 r
.4282 .38414 m .41921 .38425 L .41691 .38533 L p F P
0 g
s
.693 .675 .828 r
.41921 .38425 m .41623 .38429 L .41691 .38533 L closepath p F P
0 g
s
.672 .573 .736 r
.49324 .39731 m .49351 .39806 L .5041 .39628 L p F P
0 g
s
.67 .557 .717 r
.50513 .39933 m .5041 .39628 L .49351 .39806 L p F P
0 g
s
.67 .557 .717 r
.4969 .40444 m .50513 .39933 L p .49351 .39806 L F P
0 g
s
.67 .557 .717 r
.49351 .39806 m .49562 .40465 L .4969 .40444 L p F P
0 g
s
.667 .537 .697 r
.4969 .40444 m .49562 .40465 L .49577 .40521 L closepath p F P
0 g
s
.714 .48 .57 r
.38285 .43494 m .38899 .43525 L .38944 .431 L p F P
0 g
s
.714 .48 .57 r
.38944 .431 m .38286 .43067 L .38285 .43494 L p F P
0 g
s
.675 .448 .569 r
.44557 .43088 m .44361 .431 L .44366 .43526 L p F P
0 g
s
.681 .453 .569 r
.4323 .43573 m .44366 .43526 L .44361 .431 L p F P
0 g
s
.664 .531 .692 r
.49577 .40521 m .49707 .41046 L p .50619 .40285 L F P
0 g
s
.664 .531 .692 r
.50619 .40285 m .4969 .40444 L .49577 .40521 L p F P
0 g
s
.672 .573 .736 r
.5041 .39628 m .50259 .39229 L .49324 .39731 L p F P
0 g
s
.675 .601 .765 r
.49324 .39731 m .50259 .39229 L .50099 .3885 L p F P
0 g
s
.675 .601 .765 r
.49071 .39101 m .49324 .39731 L p .50099 .3885 L F P
0 g
s
.741 .545 .629 r
.3426 .42206 m .34624 .42251 L .34822 .41775 L p F P
0 g
s
.741 .545 .629 r
.34822 .41775 m .34187 .41695 L .3426 .42206 L p F P
0 g
s
.673 .446 .569 r
.45507 .43028 m .44557 .43088 L .44505 .43518 L p F P
0 g
s
.675 .448 .569 r
.44366 .43526 m .44505 .43518 L .44557 .43088 L p F P
0 g
s
.681 .614 .774 r
.49037 .39025 m .48817 .38569 L .47883 .39019 L p F P
0 g
s
.681 .643 .806 r
.48817 .38569 m .47883 .39019 L .47628 .3852 L p F P
0 g
s
.691 .672 .827 r
.4399 .38369 m .43094 .38405 L .42878 .38504 L p F P
0 g
s
.691 .674 .829 r
.43094 .38405 m .4282 .38414 L .42878 .38504 L closepath p F P
0 g
s
.667 .548 .71 r
.50513 .39933 m .4969 .40444 L .50619 .40285 L closepath p F P
0 g
s
.71 .682 .821 r
.35751 .38903 m .36674 .38353 L .36548 .38164 L p F P
0 g
s
.71 .682 .821 r
.35484 .38451 m .35751 .38903 L p .36548 .38164 L F P
0 g
s
.723 .646 .772 r
.35751 .38903 m .35484 .38451 L .34559 .39052 L p F P
0 g
s
.734 .638 .753 r
.34576 .39085 m .34527 .39077 L .33692 .39777 L p F P
0 g
s
.732 .649 .767 r
.33596 .39763 m .33692 .39777 L .34527 .39077 L p F P
0 g
s
.735 .621 .731 r
.33692 .39777 m .33596 .39763 L .33627 .39838 L closepath p F P
0 g
s
.744 .621 .722 r
.33147 .40374 m .33627 .39838 L .33596 .39763 L p F P
0 g
s
.721 .486 .57 r
.37941 .4347 m .38285 .43494 L .38286 .43067 L p F P
0 g
s
.721 .486 .57 r
.38286 .43067 m .37985 .43045 L .37941 .4347 L p F P
0 g
s
.747 .567 .651 r
.34133 .41434 m .3401 .41668 L .34187 .41695 L closepath p F P
0 g
s
.732 .649 .767 r
.33365 .3926 m .33596 .39763 L p .34527 .39077 L F P
0 g
s
.74 .635 .743 r
.33365 .3926 m .32943 .39646 L .33596 .39763 L closepath p F P
0 g
s
.744 .621 .722 r
.3245 .40263 m .33147 .40374 L p .33596 .39763 L F P
0 g
s
.744 .621 .722 r
.32425 .40195 m .3245 .40263 L p .33596 .39763 L F P
0 g
s
.744 .621 .722 r
.33596 .39763 m .32943 .39646 L .32425 .40195 L p F P
0 g
s
.663 .48 .627 r
.4771 .42365 m .488 .42225 L .48734 .41735 L p F P
0 g
s
.663 .48 .627 r
.47707 .4234 m .4771 .42365 L p .48734 .41735 L F P
0 g
s
.663 .506 .661 r
.48734 .41735 m .4981 .41579 L .49707 .41046 L p F P
0 g
s
.658 .476 .627 r
.49831 .41721 m .4981 .41579 L .48734 .41735 L p F P
0 g
s
.658 .476 .627 r
.49523 .42121 m .49831 .41721 L p .48734 .41735 L F P
0 g
s
.658 .476 .627 r
.48734 .41735 m .488 .42225 L .49523 .42121 L p F P
0 g
s
.689 .672 .828 r
.44372 .38349 m .4399 .38369 L .44065 .38487 L closepath p F P
0 g
s
.688 .668 .825 r
.45137 .38297 m .44372 .38349 L .44065 .38487 L p F P
0 g
s
.721 .487 .57 r
.37016 .43403 m .37941 .4347 L .37985 .43045 L p F P
0 g
s
.721 .487 .57 r
.37985 .43045 m .37061 .42978 L .37016 .43403 L p F P
0 g
s
.694 .681 .833 r
.41429 .38138 m .40831 .38416 L .41623 .38429 L closepath p F P
0 g
s
.692 .68 .834 r
.41429 .38138 m .41623 .38429 L .41921 .38425 L p F P
0 g
s
.73 .649 .768 r
.34559 .39052 m .34527 .39077 L .34576 .39085 L closepath p F P
0 g
s
.692 .68 .834 r
.42617 .38109 m .41921 .38425 L .4282 .38414 L closepath p F P
0 g
s
.692 .68 .834 r
.41921 .38425 m .42617 .38109 L p .41429 .38138 L F P
0 g
s
.739 .522 .599 r
.35333 .42802 m .3566 .42841 L .35628 .42377 L p F P
0 g
s
.739 .522 .599 r
.35628 .42377 m .35446 .42355 L .35333 .42802 L p F P
0 g
s
.668 .48 .622 r
.47707 .4234 m .4769 .42367 L .4771 .42365 L closepath p F P
0 g
s
.732 .649 .767 r
.34527 .39077 m .33764 .3895 L .33365 .3926 L p F P
0 g
s
.727 .658 .781 r
.34527 .39077 m .34559 .39052 L .34292 .38578 L p F P
0 g
s
.727 .658 .781 r
.34292 .38578 m .33764 .3895 L .34527 .39077 L p F P
0 g
s
.694 .68 .832 r
.40831 .38416 m .41429 .38138 L p .40241 .38174 L F P
0 g
s
.694 .68 .832 r
.40241 .38174 m .40399 .38412 L .40831 .38416 L p F P
0 g
s
.667 .441 .569 r
.45951 .42993 m .45507 .43028 L .45513 .43455 L p F P
0 g
s
.673 .446 .569 r
.44505 .43518 m .45513 .43455 L .45507 .43028 L p F P
0 g
s
.717 .678 .812 r
.35484 .38451 m .34559 .39052 L .34292 .38578 L p F P
0 g
s
.69 .68 .835 r
.42617 .38109 m .4282 .38414 L .43094 .38405 L p F P
0 g
s
.663 .458 .597 r
.4771 .42365 m .4769 .42367 L .47495 .42847 L p F P
0 g
s
.665 .461 .598 r
.46634 .42934 m .47495 .42847 L .4769 .42367 L p F P
0 g
s
.698 .681 .831 r
.40241 .38174 m .398 .38386 L .40399 .38412 L closepath p F P
0 g
s
.656 .453 .597 r
.48836 .42682 m .488 .42225 L .4771 .42365 L p F P
0 g
s
.656 .453 .597 r
.4771 .42365 m .47744 .4282 L .48836 .42682 L p F P
0 g
s
.663 .458 .597 r
.47495 .42847 m .47744 .4282 L .4771 .42365 L p F P
0 g
s
.664 .531 .692 r
.49707 .41046 m .50752 .40874 L p .50619 .40285 L F P
0 g
s
.658 .5 .658 r
.50752 .40874 m .49707 .41046 L .4981 .41579 L p F P
0 g
s
.747 .577 .664 r
.32774 .41477 m .33235 .41548 L .33517 .41043 L p F P
0 g
s
.747 .577 .664 r
.32677 .41031 m .32774 .41477 L p .33517 .41043 L F P
0 g
s
.747 .577 .664 r
.33517 .41043 m .32742 .40922 L .32677 .41031 L p F P
0 g
s
.69 .678 .833 r
.43806 .38087 m .43094 .38405 L .4399 .38369 L closepath p F P
0 g
s
.69 .68 .835 r
.43094 .38405 m .43806 .38087 L p .42617 .38109 L F P
0 g
s
.74 .524 .601 r
.34506 .427 m .35333 .42802 L .35446 .42355 L p F P
0 g
s
.74 .524 .601 r
.35446 .42355 m .34624 .42251 L .34506 .427 L p F P
0 g
s
.686 .662 .821 r
.46266 .38202 m .45776 .38248 L .45253 .38483 L p F P
0 g
s
.688 .667 .825 r
.45776 .38248 m .45137 .38297 L .45253 .38483 L closepath p F P
0 g
s
.748 .55 .627 r
.33824 .4214 m .3426 .42206 L .34187 .41695 L p F P
0 g
s
.748 .55 .627 r
.34187 .41695 m .3401 .41668 L .33824 .4214 L p F P
0 g
s
.746 .594 .688 r
.32646 .40907 m .32742 .40922 L .33147 .40374 L p F P
0 g
s
.746 .594 .688 r
.33147 .40374 m .3245 .40263 L .32646 .40907 L p F P
0 g
s
.697 .679 .828 r
.398 .38386 m .40241 .38174 L p .39052 .3822 L F P
0 g
s
.697 .679 .828 r
.39052 .3822 m .39149 .38365 L .398 .38386 L p F P
0 g
s
.675 .601 .765 r
.50099 .3885 m .49306 .38983 L .49071 .39101 L p F P
0 g
s
.678 .609 .771 r
.49306 .38983 m .49037 .39025 L .49071 .39101 L closepath p F P
0 g
s
.664 .439 .569 r
.46634 .42934 m .45951 .42993 L .45897 .43424 L p F P
0 g
s
.667 .441 .569 r
.45513 .43455 m .45897 .43424 L .45951 .42993 L p F P
0 g
s
.749 .553 .63 r
.33042 .42022 m .33824 .4214 L .3401 .41668 L p F P
0 g
s
.749 .553 .63 r
.3401 .41668 m .33235 .41548 L .33042 .42022 L p F P
0 g
s
.688 .677 .834 r
.43806 .38087 m .4399 .38369 L .44372 .38349 L p F P
0 g
s
.679 .621 .784 r
.48817 .38569 m .49037 .39025 L .49306 .38983 L p F P
0 g
s
.701 .68 .826 r
.39052 .3822 m .38809 .38341 L .39149 .38365 L closepath p F P
0 g
s
.723 .488 .57 r
.36989 .43401 m .37016 .43403 L .37061 .42978 L p F P
0 g
s
.723 .488 .57 r
.37061 .42978 m .36991 .42973 L .36989 .43401 L p F P
0 g
s
.73 .494 .57 r
.36143 .43318 m .36989 .43401 L .36991 .42973 L p F P
0 g
s
.73 .494 .57 r
.36991 .42973 m .36188 .42894 L .36143 .43318 L p F P
0 g
s
.684 .655 .815 r
.47381 .38089 m .47327 .38096 L .4644 .38493 L p F P
0 g
s
.686 .661 .82 r
.47327 .38096 m .46266 .38202 L .4644 .38493 L closepath p F P
0 g
s
.688 .677 .834 r
.44372 .38349 m .44994 .38074 L p .43806 .38087 L F P
0 g
s
.688 .674 .831 r
.44994 .38074 m .44372 .38349 L .45137 .38297 L closepath p F P
0 g
s
.701 .676 .823 r
.38809 .38341 m .39052 .3822 L p .37864 .38277 L F P
0 g
s
.701 .676 .823 r
.37864 .38277 m .37873 .38292 L .38809 .38341 L p F P
0 g
s
.739 .645 .755 r
.32943 .39646 m .33365 .3926 L .33163 .38862 L p F P
0 g
s
.739 .645 .755 r
.32181 .3952 m .32943 .39646 L p .33163 .38862 L F P
0 g
s
.742 .617 .72 r
.32166 .39534 m .32181 .3952 L .32943 .39646 L p F P
0 g
s
.742 .617 .72 r
.32943 .39646 m .32425 .40195 L .32166 .39534 L p F P
0 g
s
.729 .644 .763 r
.33764 .3895 m .33163 .38862 L .33365 .3926 L closepath p F P
0 g
s
.676 .611 .775 r
.50006 .38648 m .49306 .38983 L .50099 .3885 L closepath p F P
0 g
s
.679 .621 .784 r
.49306 .38983 m .50006 .38648 L p .48817 .38569 L F P
0 g
s
.685 .435 .538 r
.42049 .43595 m .42007 .43595 L .41983 .43993 L p F P
0 g
s
.692 .441 .539 r
.40981 .4399 m .41983 .43993 L .42007 .43595 L p F P
0 g
s
.692 .441 .539 r
.42007 .43595 m .40942 .43591 L .40981 .4399 L p F P
0 g
s
.683 .434 .538 r
.43198 .43574 m .42049 .43595 L .42093 .43992 L p F P
0 g
s
.685 .435 .538 r
.41983 .43993 m .42093 .43992 L .42049 .43595 L p F P
0 g
s
.664 .554 .72 r
.50513 .39933 m .50619 .40285 L p .51458 .39435 L F P
0 g
s
.664 .554 .72 r
.51458 .39435 m .51371 .39452 L .50513 .39933 L p F P
0 g
s
.667 .561 .726 r
.51371 .39452 m .5041 .39628 L .50513 .39933 L closepath p F P
0 g
s
.658 .434 .569 r
.47495 .42847 m .46634 .42934 L .46641 .43361 L p F P
0 g
s
.664 .439 .569 r
.45897 .43424 m .46641 .43361 L .46634 .42934 L p F P
0 g
s
.693 .442 .539 r
.40767 .43988 m .40981 .4399 L .40942 .43591 L p F P
0 g
s
.693 .442 .539 r
.40942 .43591 m .40793 .4359 L .40767 .43988 L p F P
0 g
s
.701 .448 .539 r
.3993 .43966 m .40767 .43988 L .40793 .4359 L p F P
0 g
s
.701 .448 .539 r
.40793 .4359 m .39896 .43567 L .3993 .43966 L p F P
0 g
s
.67 .579 .744 r
.50259 .39229 m .5041 .39628 L .51371 .39452 L p F P
0 g
s
.664 .554 .72 r
.50619 .40285 m .51665 .40089 L .51458 .39435 L p F P
0 g
s
.66 .524 .688 r
.51703 .40233 m .51665 .40089 L .50619 .40285 L p F P
0 g
s
.66 .524 .688 r
.50619 .40285 m .50766 .40863 L .51703 .40233 L p F P
0 g
s
.664 .531 .692 r
.50752 .40874 m .50766 .40863 L .50619 .40285 L p F P
0 g
s
.683 .434 .538 r
.42093 .43992 m .43175 .43972 L .43198 .43574 L p F P
0 g
s
.677 .428 .538 r
.4323 .43573 m .43198 .43574 L .43175 .43972 L p F P
0 g
s
.675 .427 .538 r
.44366 .43526 m .4323 .43573 L .43279 .43968 L p F P
0 g
s
.677 .428 .538 r
.43175 .43972 m .43279 .43968 L .4323 .43573 L p F P
0 g
s
.687 .673 .831 r
.44994 .38074 m .45137 .38297 L .45776 .38248 L p F P
0 g
s
.681 .643 .806 r
.47628 .3852 m .48562 .38102 L .48817 .38569 L p F P
0 g
s
.684 .654 .814 r
.47381 .38089 m .47628 .3852 L .48562 .38102 L p F P
0 g
s
.741 .524 .601 r
.34293 .42673 m .34506 .427 L .34624 .42251 L p F P
0 g
s
.741 .524 .601 r
.34624 .42251 m .3426 .42206 L .34293 .42673 L p F P
0 g
s
.706 .678 .821 r
.37864 .38277 m .37841 .38289 L .37873 .38292 L closepath p F P
0 g
s
.726 .652 .775 r
.33764 .3895 m .34292 .38578 L p .33098 .38743 L F P
0 g
s
.726 .652 .775 r
.33098 .38743 m .33163 .38862 L .33764 .3895 L p F P
0 g
s
.702 .449 .539 r
.39525 .43954 m .3993 .43966 L .39896 .43567 L p F P
0 g
s
.702 .449 .539 r
.39896 .43567 m .39552 .43557 L .39525 .43954 L p F P
0 g
s
.701 .69 .836 r
.37841 .38289 m .37864 .38277 L .37596 .37897 L p F P
0 g
s
.701 .69 .836 r
.37596 .37897 m .36982 .38197 L .37841 .38289 L p F P
0 g
s
.707 .667 .808 r
.36674 .38353 m .36982 .38197 L .37841 .38289 L p F P
0 g
s
.75 .611 .704 r
.32425 .40195 m .32381 .4025 L .3245 .40263 L closepath p F P
0 g
s
.753 .599 .685 r
.3201 .40786 m .32646 .40907 L .3245 .40263 L p F P
0 g
s
.753 .599 .685 r
.3245 .40263 m .32381 .4025 L .3201 .40786 L p F P
0 g
s
.748 .578 .665 r
.32742 .40922 m .32646 .40907 L .32677 .41031 L closepath p F P
0 g
s
.701 .676 .823 r
.39052 .3822 m .38786 .3785 L .37864 .38277 L p F P
0 g
s
.689 .709 .863 r
.38786 .3785 m .37864 .38277 L .37596 .37897 L p F P
0 g
s
.658 .5 .658 r
.4981 .41579 m .49982 .41551 L .50752 .40874 L p F P
0 g
s
.652 .475 .632 r
.49982 .41551 m .4981 .41579 L .49831 .41721 L closepath p F P
0 g
s
.709 .455 .539 r
.38929 .43926 m .39525 .43954 L .39552 .43557 L p F P
0 g
s
.709 .455 .539 r
.39552 .43557 m .38899 .43525 L .38929 .43926 L p F P
0 g
s
.75 .62 .715 r
.32381 .4025 m .32425 .40195 L .32166 .39534 L p F P
0 g
s
.697 .679 .828 r
.40241 .38174 m .39975 .37811 L .39052 .3822 L p F P
0 g
s
.685 .712 .869 r
.39975 .37811 m .39052 .3822 L .38786 .3785 L p F P
0 g
s
.702 .68 .826 r
.36982 .38197 m .36548 .38164 L .36674 .38353 L closepath p F P
0 g
s
.73 .494 .57 r
.35657 .4327 m .36143 .43318 L .36188 .42894 L p F P
0 g
s
.73 .494 .57 r
.36188 .42894 m .3566 .42841 L .35657 .4327 L p F P
0 g
s
.75 .62 .715 r
.32166 .39534 m .31664 .40107 L .32381 .4025 L p F P
0 g
s
.754 .604 .69 r
.31274 .4065 m .3201 .40786 L .32381 .4025 L p F P
0 g
s
.754 .604 .69 r
.32381 .4025 m .31664 .40107 L .31274 .4065 L p F P
0 g
s
.756 .581 .659 r
.32473 .41422 m .32677 .41031 L .32646 .40907 L p F P
0 g
s
.756 .581 .659 r
.31737 .41287 m .32473 .41422 L p .32646 .40907 L F P
0 g
s
.756 .581 .659 r
.32646 .40907 m .3201 .40786 L .31737 .41287 L p F P
0 g
s
.651 .45 .599 r
.49523 .42121 m .488 .42225 L .48836 .42682 L p F P
0 g
s
.694 .68 .832 r
.41429 .38138 m .41165 .37778 L .40241 .38174 L p F P
0 g
s
.682 .714 .873 r
.41165 .37778 m .40241 .38174 L .39975 .37811 L p F P
0 g
s
.67 .579 .744 r
.5145 .39411 m .51197 .38767 L .50259 .39229 L p F P
0 g
s
.67 .579 .744 r
.51371 .39452 m .5145 .39411 L p .50259 .39229 L F P
0 g
s
.673 .598 .763 r
.50099 .3885 m .50259 .39229 L .51197 .38767 L p F P
0 g
s
.71 .682 .821 r
.36548 .38164 m .36119 .38106 L .35484 .38451 L p F P
0 g
s
.708 .675 .816 r
.36119 .38106 m .35484 .38451 L .35215 .38035 L p F P
0 g
s
.717 .678 .812 r
.34292 .38578 m .35215 .38035 L .35484 .38451 L p F P
0 g
s
.655 .495 .655 r
.49982 .41551 m .50868 .41399 L .50768 .40871 L p F P
0 g
s
.655 .495 .655 r
.50768 .40871 m .50752 .40874 L .49982 .41551 L p F P
0 g
s
.649 .471 .629 r
.50868 .41399 m .49982 .41551 L .49831 .41721 L p F P
0 g
s
.755 .576 .654 r
.32677 .41031 m .32473 .41422 L .32774 .41477 L closepath p F P
0 g
s
.749 .553 .63 r
.32851 .41993 m .33042 .42022 L .33235 .41548 L p F P
0 g
s
.749 .553 .63 r
.33235 .41548 m .32774 .41477 L .32851 .41993 L p F P
0 g
s
.668 .421 .538 r
.44505 .43518 m .44366 .43526 L .44345 .43925 L p F P
0 g
s
.675 .427 .538 r
.43279 .43968 m .44345 .43925 L .44366 .43526 L p F P
0 g
s
.71 .456 .539 r
.38256 .43892 m .38929 .43926 L .38899 .43525 L p F P
0 g
s
.71 .456 .539 r
.38899 .43525 m .38285 .43494 L .38256 .43892 L p F P
0 g
s
.686 .668 .827 r
.46183 .38069 m .45776 .38248 L .46266 .38202 L closepath p F P
0 g
s
.687 .673 .831 r
.45776 .38248 m .46183 .38069 L p .44994 .38074 L F P
0 g
s
.748 .53 .6 r
.33712 .42586 m .34293 .42673 L .3426 .42206 L p F P
0 g
s
.748 .53 .6 r
.3426 .42206 m .33824 .4214 L .33712 .42586 L p F P
0 g
s
.68 .714 .875 r
.42355 .3775 m .41429 .38138 L .41165 .37778 L p F P
0 g
s
.692 .68 .834 r
.42617 .38109 m .42355 .3775 L .41429 .38138 L p F P
0 g
s
.666 .419 .538 r
.45513 .43455 m .44505 .43518 L .4456 .43913 L p F P
0 g
s
.668 .421 .538 r
.44345 .43925 m .4456 .43913 L .44505 .43518 L p F P
0 g
s
.66 .515 .676 r
.50766 .40863 m .50752 .40874 L .50768 .40871 L closepath p F P
0 g
s
.654 .511 .676 r
.51809 .4067 m .51703 .40233 L .50766 .40863 L p F P
0 g
s
.654 .511 .676 r
.50766 .40863 m .50768 .40871 L .51809 .4067 L p F P
0 g
s
.649 .471 .629 r
.49831 .41721 m .49876 .42068 L p .50868 .41399 L F P
0 g
s
.655 .472 .624 r
.49831 .41721 m .49523 .42121 L .49876 .42068 L closepath p F P
0 g
s
.65 .492 .655 r
.51912 .41201 m .51809 .4067 L .50768 .40871 L p F P
0 g
s
.65 .492 .655 r
.50768 .40871 m .50868 .41399 L .51912 .41201 L p F P
0 g
s
.656 .432 .568 r
.47744 .4282 m .47495 .42847 L .47438 .4328 L p F P
0 g
s
.658 .434 .569 r
.46641 .43361 m .47438 .4328 L .47495 .42847 L p F P
0 g
s
.679 .621 .784 r
.50006 .38648 m .49753 .38149 L .48817 .38569 L p F P
0 g
s
.679 .654 .819 r
.48817 .38569 m .49753 .38149 L .49536 .37772 L p F P
0 g
s
.679 .654 .819 r
.48562 .38102 m .48817 .38569 L p .49536 .37772 L F P
0 g
s
.69 .68 .835 r
.43806 .38087 m .43545 .37726 L .42617 .38109 L p F P
0 g
s
.679 .713 .874 r
.43545 .37726 m .42617 .38109 L .42355 .3775 L p F P
0 g
s
.738 .501 .57 r
.35289 .43226 m .35657 .4327 L .3566 .42841 L p F P
0 g
s
.738 .501 .57 r
.3566 .42841 m .35333 .42802 L .35289 .43226 L p F P
0 g
s
.711 .689 .827 r
.34292 .38578 m .35215 .38035 L .35198 .38011 L p F P
0 g
s
.711 .689 .827 r
.34023 .38141 m .34292 .38578 L p .35198 .38011 L F P
0 g
s
.726 .652 .775 r
.34292 .38578 m .34023 .38141 L .33098 .38743 L p F P
0 g
s
.717 .463 .54 r
.37967 .43872 m .38256 .43892 L .38285 .43494 L p F P
0 g
s
.717 .463 .54 r
.38285 .43494 m .37941 .4347 L .37967 .43872 L p F P
0 g
s
.739 .645 .755 r
.33163 .38862 m .32987 .38829 L .32181 .3952 L p F P
0 g
s
.734 .655 .771 r
.33098 .38743 m .32987 .38829 L .33163 .38862 L closepath p F P
0 g
s
.685 .668 .827 r
.46183 .38069 m .46266 .38202 L .47327 .38096 L p F P
0 g
s
.649 .427 .568 r
.48845 .43108 m .48836 .42682 L .47744 .4282 L p F P
0 g
s
.649 .427 .568 r
.47744 .4282 m .47752 .43246 L .48845 .43108 L p F P
0 g
s
.656 .432 .568 r
.47438 .4328 m .47752 .43246 L .47744 .4282 L p F P
0 g
s
.736 .653 .768 r
.32158 .39516 m .32181 .3952 L .32987 .38829 L p F P
0 g
s
.741 .627 .733 r
.32181 .3952 m .32158 .39516 L .32166 .39534 L closepath p F P
0 g
s
.751 .627 .723 r
.31664 .40107 m .32166 .39534 L .32158 .39516 L p F P
0 g
s
.7 .685 .832 r
.36982 .38197 m .37596 .37897 L p .36406 .37957 L F P
0 g
s
.7 .685 .832 r
.36406 .37957 m .36548 .38164 L .36982 .38197 L p F P
0 g
s
.688 .677 .834 r
.44994 .38074 m .44735 .37707 L .43806 .38087 L p F P
0 g
s
.678 .71 .872 r
.44735 .37707 m .43806 .38087 L .43545 .37726 L p F P
0 g
s
.736 .653 .768 r
.31901 .38974 m .32158 .39516 L p .32987 .38829 L F P
0 g
s
.745 .641 .744 r
.31901 .38974 m .31478 .39372 L .32158 .39516 L closepath p F P
0 g
s
.751 .627 .723 r
.30973 .39977 m .31664 .40107 L p .32158 .39516 L F P
0 g
s
.751 .627 .723 r
.30959 .39938 m .30973 .39977 L p .32158 .39516 L F P
0 g
s
.751 .627 .723 r
.32158 .39516 m .31478 .39372 L .30959 .39938 L p F P
0 g
s
.718 .463 .539 r
.37042 .43804 m .37967 .43872 L .37941 .4347 L p F P
0 g
s
.718 .463 .539 r
.37941 .4347 m .37016 .43403 L .37042 .43804 L p F P
0 g
s
.673 .598 .763 r
.51197 .38767 m .51148 .38657 L .50099 .3885 L p F P
0 g
s
.674 .61 .776 r
.50006 .38648 m .50099 .3885 L .51148 .38657 L p F P
0 g
s
.739 .502 .57 r
.3446 .43125 m .35289 .43226 L .35333 .42802 L p F P
0 g
s
.739 .502 .57 r
.35333 .42802 m .34506 .427 L .3446 .43125 L p F P
0 g
s
.748 .531 .601 r
.32926 .4247 m .33712 .42586 L .33824 .4214 L p F P
0 g
s
.748 .531 .601 r
.33824 .4214 m .33042 .42022 L .32926 .4247 L p F P
0 g
s
.756 .558 .628 r
.32292 .41892 m .32851 .41993 L .32774 .41477 L p F P
0 g
s
.756 .558 .628 r
.32774 .41477 m .32473 .41422 L .32292 .41892 L p F P
0 g
s
.659 .414 .537 r
.45897 .43424 m .45513 .43455 L .45494 .43854 L p F P
0 g
s
.666 .419 .538 r
.4456 .43913 m .45494 .43854 L .45513 .43455 L p F P
0 g
s
.736 .653 .768 r
.32987 .38829 m .32262 .38689 L .31901 .38974 L p F P
0 g
s
.731 .663 .783 r
.32987 .38829 m .33098 .38743 L .32829 .38282 L p F P
0 g
s
.731 .663 .783 r
.32829 .38282 m .32262 .38689 L .32987 .38829 L p F P
0 g
s
.687 .673 .831 r
.46183 .38069 m .45925 .37692 L .44994 .38074 L p F P
0 g
s
.678 .706 .868 r
.45925 .37692 m .44994 .38074 L .44735 .37707 L p F P
0 g
s
.706 .687 .829 r
.36406 .37957 m .36119 .38106 L .36548 .38164 L closepath p F P
0 g
s
.648 .447 .597 r
.49876 .42068 m .49523 .42121 L .4928 .42618 L p F P
0 g
s
.651 .45 .599 r
.48836 .42682 m .4928 .42618 L .49523 .42121 L p F P
0 g
s
.719 .682 .814 r
.33098 .38743 m .34023 .38141 L .33795 .378 L p F P
0 g
s
.719 .682 .814 r
.32829 .38282 m .33098 .38743 L p .33795 .378 L F P
0 g
s
.754 .584 .665 r
.31313 .4121 m .31737 .41287 L .3201 .40786 L p F P
0 g
s
.754 .584 .665 r
.31211 .40758 m .31313 .4121 L p .3201 .40786 L F P
0 g
s
.754 .584 .665 r
.3201 .40786 m .31274 .4065 L .31211 .40758 L p F P
0 g
s
.657 .412 .538 r
.46641 .43361 m .45897 .43424 L .45959 .43817 L p F P
0 g
s
.659 .414 .537 r
.45494 .43854 m .45959 .43817 L .45897 .43424 L p F P
0 g
s
.674 .61 .776 r
.51148 .38657 m .50944 .38226 L .50006 .38648 L p F P
0 g
s
.675 .639 .806 r
.50944 .38226 m .50006 .38648 L .49753 .38149 L p F P
0 g
s
.666 .568 .735 r
.5145 .39411 m .51371 .39452 L .51458 .39435 L closepath p F P
0 g
s
.752 .601 .689 r
.31179 .40632 m .31274 .4065 L .31664 .40107 L p F P
0 g
s
.752 .601 .689 r
.31664 .40107 m .30973 .39977 L .31179 .40632 L p F P
0 g
s
.685 .668 .827 r
.47373 .38076 m .47116 .37686 L .46183 .38069 L p F P
0 g
s
.685 .668 .827 r
.47327 .38096 m .47373 .38076 L p .46183 .38069 L F P
0 g
s
.679 .699 .862 r
.47116 .37686 m .46183 .38069 L .45925 .37692 L p F P
0 g
s
.72 .464 .539 r
.36957 .43798 m .37042 .43804 L .37016 .43403 L p F P
0 g
s
.72 .464 .539 r
.37016 .43403 m .36989 .43401 L .36957 .43798 L p F P
0 g
s
.757 .56 .631 r
.31549 .41759 m .32292 .41892 L .32473 .41422 L p F P
0 g
s
.757 .56 .631 r
.32473 .41422 m .31737 .41287 L .31549 .41759 L p F P
0 g
s
.727 .471 .539 r
.36165 .4372 m .36957 .43798 L .36989 .43401 L p F P
0 g
s
.727 .471 .539 r
.36989 .43401 m .36143 .43318 L .36165 .4372 L p F P
0 g
s
.662 .565 .736 r
.5145 .39411 m .51458 .39435 L .52485 .39215 L p F P
0 g
s
.66 .549 .718 r
.52642 .39696 m .52485 .39215 L .51458 .39435 L p F P
0 g
s
.66 .549 .718 r
.52093 .4 m .52642 .39696 L p .51458 .39435 L F P
0 g
s
.66 .549 .718 r
.51458 .39435 m .51665 .40089 L .52093 .4 L p F P
0 g
s
.662 .565 .736 r
.52485 .39215 m .52389 .3895 L .5145 .39411 L p F P
0 g
s
.667 .593 .763 r
.5145 .39411 m .52389 .3895 L .5218 .38441 L p F P
0 g
s
.667 .593 .763 r
.51197 .38767 m .5145 .39411 L p .5218 .38441 L F P
0 g
s
.655 .527 .696 r
.52093 .4 m .51665 .40089 L .51703 .40233 L closepath p F P
0 g
s
.649 .471 .629 r
.49876 .42068 m .50934 .41889 L .50868 .41399 L p F P
0 g
s
.642 .442 .597 r
.50971 .42345 m .50934 .41889 L .49876 .42068 L p F P
0 g
s
.642 .442 .597 r
.49876 .42068 m .49911 .42523 L .50971 .42345 L p F P
0 g
s
.648 .447 .597 r
.4928 .42618 m .49911 .42523 L .49876 .42068 L p F P
0 g
s
.699 .692 .84 r
.36119 .38106 m .36406 .37957 L .36136 .37594 L p F P
0 g
s
.699 .692 .84 r
.36136 .37594 m .35254 .38016 L .36119 .38106 L p F P
0 g
s
.708 .675 .816 r
.35215 .38035 m .35254 .38016 L .36119 .38106 L p F P
0 g
s
.644 .466 .628 r
.5196 .41542 m .51912 .41201 L .50868 .41399 L p F P
0 g
s
.644 .466 .628 r
.5179 .41728 m .5196 .41542 L p .50868 .41399 L F P
0 g
s
.644 .466 .628 r
.50868 .41399 m .50934 .41889 L .5179 .41728 L p F P
0 g
s
.684 .661 .822 r
.47373 .38076 m .47327 .38096 L .47381 .38089 L closepath p F P
0 g
s
.652 .521 .691 r
.51703 .40233 m .51809 .4067 L p .52693 .39871 L F P
0 g
s
.652 .521 .691 r
.52693 .39871 m .52093 .4 L .51703 .40233 L p F P
0 g
s
.681 .66 .823 r
.47373 .38076 m .47381 .38089 L .48461 .37935 L p F P
0 g
s
.684 .654 .814 r
.48562 .38102 m .48461 .37935 L .47381 .38089 L p F P
0 g
s
.681 .66 .823 r
.48461 .37935 m .48307 .3769 L .47373 .38076 L p F P
0 g
s
.678 .69 .854 r
.48307 .3769 m .47373 .38076 L .47116 .37686 L p F P
0 g
s
.65 .407 .537 r
.47438 .4328 m .46641 .43361 L .46624 .4376 L p F P
0 g
s
.657 .412 .538 r
.45959 .43817 m .46624 .4376 L .46641 .43361 L p F P
0 g
s
.74 .502 .57 r
.34289 .43103 m .3446 .43125 L .34506 .427 L p F P
0 g
s
.74 .502 .57 r
.34506 .427 m .34293 .42673 L .34289 .43103 L p F P
0 g
s
.749 .532 .601 r
.32885 .42463 m .32926 .4247 L .33042 .42022 L p F P
0 g
s
.749 .532 .601 r
.33042 .42022 m .32851 .41993 L .32885 .42463 L p F P
0 g
s
.643 .422 .568 r
.4928 .42618 m .48836 .42682 L .48845 .43108 L p F P
0 g
s
.733 .649 .765 r
.32262 .38689 m .31701 .3859 L .31901 .38974 L closepath p F P
0 g
s
.744 .65 .756 r
.31478 .39372 m .31901 .38974 L .31701 .3859 L p F P
0 g
s
.747 .509 .57 r
.33668 .4301 m .34289 .43103 L .34293 .42673 L p F P
0 g
s
.747 .509 .57 r
.34293 .42673 m .33712 .42586 L .33668 .4301 L p F P
0 g
s
.678 .407 .505 r
.42093 .43992 m .41983 .43993 L .41934 .44365 L p F P
0 g
s
.686 .414 .506 r
.41098 .44362 m .41934 .44365 L .41983 .43993 L p F P
0 g
s
.686 .414 .506 r
.41983 .43993 m .40981 .4399 L .41098 .44362 L p F P
0 g
s
.744 .65 .756 r
.30757 .3923 m .31478 .39372 L p .31701 .3859 L F P
0 g
s
.747 .622 .72 r
.30697 .39289 m .30757 .3923 L .31478 .39372 L p F P
0 g
s
.747 .622 .72 r
.31478 .39372 m .30959 .39938 L .30697 .39289 L p F P
0 g
s
.678 .407 .505 r
.41934 .44365 m .4222 .44361 L .42093 .43992 L p F P
0 g
s
.677 .407 .505 r
.43175 .43972 m .42093 .43992 L .4222 .44361 L p F P
0 g
s
.687 .415 .505 r
.40716 .44359 m .41098 .44362 L .40981 .4399 L p F P
0 g
s
.687 .415 .505 r
.40981 .4399 m .40767 .43988 L .40716 .44359 L p F P
0 g
s
.695 .422 .507 r
.40038 .44342 m .40716 .44359 L .40767 .43988 L p F P
0 g
s
.695 .422 .507 r
.40767 .43988 m .3993 .43966 L .40038 .44342 L p F P
0 g
s
.728 .471 .539 r
.35623 .43667 m .36165 .4372 L .36143 .43318 L p F P
0 g
s
.728 .471 .539 r
.36143 .43318 m .35657 .4327 L .35623 .43667 L p F P
0 g
s
.7 .685 .832 r
.37596 .37897 m .37327 .37547 L .36406 .37957 L p F P
0 g
s
.686 .718 .873 r
.37327 .37547 m .36406 .37957 L .36136 .37594 L p F P
0 g
s
.757 .538 .6 r
.32182 .42338 m .32885 .42463 L .32851 .41993 L p F P
0 g
s
.757 .538 .6 r
.32851 .41993 m .32292 .41892 L .32182 .42338 L p F P
0 g
s
.689 .709 .863 r
.37596 .37897 m .38518 .37509 L .38786 .3785 L p F P
0 g
s
.68 .723 .882 r
.38518 .37509 m .37596 .37897 L .37327 .37547 L p F P
0 g
s
.669 .4 .504 r
.43279 .43968 m .43175 .43972 L .43129 .44344 L p F P
0 g
s
.677 .407 .505 r
.4222 .44361 m .43129 .44344 L .43175 .43972 L p F P
0 g
s
.652 .521 .691 r
.51809 .4067 m .52839 .40453 L .52693 .39871 L p F P
0 g
s
.645 .49 .658 r
.52898 .40749 m .52839 .40453 L .51809 .4067 L p F P
0 g
s
.645 .49 .658 r
.52444 .4109 m .52898 .40749 L p .51809 .4067 L F P
0 g
s
.645 .49 .658 r
.51809 .4067 m .51912 .41201 L .52444 .4109 L p F P
0 g
s
.73 .656 .777 r
.32262 .38689 m .32829 .38282 L p .31633 .38468 L F P
0 g
s
.73 .656 .777 r
.31633 .38468 m .31701 .3859 L .32262 .38689 L p F P
0 g
s
.702 .687 .833 r
.35254 .38016 m .35198 .38011 L .35215 .38035 L closepath p F P
0 g
s
.681 .664 .827 r
.49217 .37826 m .48461 .37935 L .48562 .38102 L closepath p F P
0 g
s
.679 .654 .819 r
.49536 .37772 m .49217 .37826 L .48562 .38102 L p F P
0 g
s
.667 .399 .505 r
.44345 .43925 m .43279 .43968 L .43419 .44334 L p F P
0 g
s
.669 .4 .504 r
.43129 .44344 m .43419 .44334 L .43279 .43968 L p F P
0 g
s
.696 .423 .506 r
.39472 .44325 m .40038 .44342 L .3993 .43966 L p F P
0 g
s
.696 .423 .506 r
.3993 .43966 m .39525 .43954 L .39472 .44325 L p F P
0 g
s
.667 .593 .763 r
.5218 .38441 m .51666 .38552 L .51197 .38767 L p F P
0 g
s
.67 .603 .772 r
.51666 .38552 m .51148 .38657 L .51197 .38767 L closepath p F P
0 g
s
.656 .537 .708 r
.52642 .39696 m .52093 .4 L .52693 .39871 L closepath p F P
0 g
s
.685 .712 .869 r
.38786 .3785 m .39709 .37478 L .39975 .37811 L p F P
0 g
s
.676 .727 .888 r
.39709 .37478 m .38786 .3785 L .38518 .37509 L p F P
0 g
s
.699 .691 .838 r
.35254 .38016 m .36136 .37594 L p .34945 .37656 L F P
0 g
s
.699 .691 .838 r
.34945 .37656 m .35198 .38011 L .35254 .38016 L p F P
0 g
s
.704 .43 .507 r
.39027 .44304 m .39472 .44325 L .39525 .43954 L p F P
0 g
s
.704 .43 .507 r
.39525 .43954 m .38929 .43926 L .39027 .44304 L p F P
0 g
s
.707 .693 .834 r
.34945 .37656 m .34495 .37887 L .35198 .38011 L closepath p F P
0 g
s
.711 .689 .827 r
.35198 .38011 m .34495 .37887 L .34023 .38141 L p F P
0 g
s
.755 .585 .665 r
.31274 .4065 m .31179 .40632 L .31211 .40758 L closepath p F P
0 g
s
.682 .714 .873 r
.39975 .37811 m .409 .3745 L .41165 .37778 L p F P
0 g
s
.673 .729 .893 r
.409 .3745 m .39975 .37811 L .39709 .37478 L p F P
0 g
s
.708 .681 .821 r
.34495 .37887 m .33795 .378 L .34023 .38141 L closepath p F P
0 g
s
.648 .405 .537 r
.47752 .43246 m .47438 .4328 L .47507 .4367 L p F P
0 g
s
.65 .407 .537 r
.46624 .4376 m .47507 .4367 L .47438 .4328 L p F P
0 g
s
.672 .616 .784 r
.50944 .38226 m .51148 .38657 L .51666 .38552 L p F P
0 g
s
.757 .617 .704 r
.30959 .39938 m .30935 .39969 L .30973 .39977 L closepath p F P
0 g
s
.761 .605 .685 r
.30579 .40499 m .31179 .40632 L .30973 .39977 L p F P
0 g
s
.761 .605 .685 r
.30973 .39977 m .30935 .39969 L .30579 .40499 L p F P
0 g
s
.64 .42 .567 r
.49911 .42523 m .4928 .42618 L .49212 .43056 L p F P
0 g
s
.643 .422 .568 r
.48845 .43108 m .49212 .43056 L .4928 .42618 L p F P
0 g
s
.757 .626 .715 r
.30935 .39969 m .30959 .39938 L .30697 .39289 L p F P
0 g
s
.764 .588 .659 r
.31014 .41147 m .31211 .40758 L .31179 .40632 L p F P
0 g
s
.764 .588 .659 r
.30316 .40997 m .31014 .41147 L p .31179 .40632 L F P
0 g
s
.764 .588 .659 r
.31179 .40632 m .30579 .40499 L .30316 .40997 L p F P
0 g
s
.757 .626 .715 r
.30697 .39289 m .30256 .39812 L .30935 .39969 L p F P
0 g
s
.762 .61 .69 r
.29883 .40348 m .30579 .40499 L .30935 .39969 L p F P
0 g
s
.762 .61 .69 r
.30935 .39969 m .30256 .39812 L .29883 .40348 L p F P
0 g
s
.735 .478 .54 r
.35308 .43629 m .35623 .43667 L .35657 .4327 L p F P
0 g
s
.735 .478 .54 r
.35657 .4327 m .35289 .43226 L .35308 .43629 L p F P
0 g
s
.757 .56 .63 r
.31394 .41731 m .31549 .41759 L .31737 .41287 L p F P
0 g
s
.757 .56 .63 r
.31737 .41287 m .31313 .4121 L .31394 .41731 L p F P
0 g
s
.705 .431 .507 r
.38201 .44262 m .39027 .44304 L .38929 .43926 L p F P
0 g
s
.705 .431 .507 r
.38929 .43926 m .38256 .43892 L .38201 .44262 L p F P
0 g
s
.66 .392 .504 r
.4456 .43913 m .44345 .43925 L .44301 .44298 L p F P
0 g
s
.667 .399 .505 r
.43419 .44334 m .44301 .44298 L .44345 .43925 L p F P
0 g
s
.68 .714 .875 r
.41165 .37778 m .42091 .37424 L .42355 .3775 L p F P
0 g
s
.671 .731 .895 r
.42091 .37424 m .41165 .37778 L .409 .3745 L p F P
0 g
s
.762 .583 .654 r
.31211 .40758 m .31014 .41147 L .31313 .4121 L closepath p F P
0 g
s
.658 .391 .505 r
.45494 .43854 m .4456 .43913 L .44712 .44275 L p F P
0 g
s
.66 .392 .504 r
.44301 .44298 m .44712 .44275 L .4456 .43913 L p F P
0 g
s
.747 .509 .57 r
.32881 .42894 m .33668 .4301 L .33712 .42586 L p F P
0 g
s
.747 .509 .57 r
.32881 .4289 m .32881 .42894 L p .33712 .42586 L F P
0 g
s
.747 .509 .57 r
.33712 .42586 m .32926 .4247 L .32881 .4289 L p F P
0 g
s
.641 .399 .537 r
.4883 .43508 m .48845 .43108 L .47752 .43246 L p F P
0 g
s
.641 .399 .537 r
.47752 .43246 m .47736 .43646 L .4883 .43508 L p F P
0 g
s
.648 .405 .537 r
.47507 .4367 m .47736 .43646 L .47752 .43246 L p F P
0 g
s
.671 .731 .895 r
.43283 .37399 m .42355 .3775 L .42091 .37424 L p F P
0 g
s
.679 .713 .874 r
.42355 .3775 m .43283 .37399 L .43545 .37726 L p F P
0 g
s
.675 .639 .806 r
.49753 .38149 m .50691 .37753 L .50944 .38226 L p F P
0 g
s
.679 .653 .817 r
.49536 .37772 m .49753 .38149 L .50691 .37753 L p F P
0 g
s
.719 .682 .814 r
.33795 .378 m .33681 .37778 L .32829 .38282 L p F P
0 g
s
.715 .673 .807 r
.33681 .37778 m .32829 .38282 L .32558 .37854 L p F P
0 g
s
.73 .656 .777 r
.32829 .38282 m .32558 .37854 L .31633 .38468 L p F P
0 g
s
.713 .438 .508 r
.38057 .44252 m .38201 .44262 L .38256 .43892 L p F P
0 g
s
.713 .438 .508 r
.38256 .43892 m .37967 .43872 L .38057 .44252 L p F P
0 g
s
.736 .478 .539 r
.3448 .43527 m .35308 .43629 L .35289 .43226 L p F P
0 g
s
.736 .478 .539 r
.35289 .43226 m .3446 .43125 L .3448 .43527 L p F P
0 g
s
.681 .67 .833 r
.48307 .3769 m .48461 .37935 L .49217 .37826 L p F P
0 g
s
.678 .71 .872 r
.43545 .37726 m .44474 .37374 L .44735 .37707 L p F P
0 g
s
.671 .729 .893 r
.44474 .37374 m .43545 .37726 L .43283 .37399 L p F P
0 g
s
.739 .66 .772 r
.31633 .38468 m .31527 .38551 L .31701 .3859 L closepath p F P
0 g
s
.744 .65 .756 r
.31701 .3859 m .31527 .38551 L .30757 .3923 L p F P
0 g
s
.757 .539 .601 r
.31436 .42206 m .32182 .42338 L .32292 .41892 L p F P
0 g
s
.757 .539 .601 r
.32292 .41892 m .31549 .41759 L .31436 .42206 L p F P
0 g
s
.713 .437 .506 r
.37135 .44184 m .38057 .44252 L .37967 .43872 L p F P
0 g
s
.713 .437 .506 r
.37967 .43872 m .37042 .43804 L .37135 .44184 L p F P
0 g
s
.635 .438 .598 r
.5179 .41728 m .50934 .41889 L .50971 .42345 L p F P
0 g
s
.741 .657 .767 r
.30663 .39211 m .30757 .3923 L .31527 .38551 L p F P
0 g
s
.746 .632 .733 r
.30757 .3923 m .30663 .39211 L .30697 .39289 L closepath p F P
0 g
s
.651 .385 .504 r
.45959 .43817 m .45494 .43854 L .45452 .44228 L p F P
0 g
s
.658 .391 .505 r
.44712 .44275 m .45452 .44228 L .45494 .43854 L p F P
0 g
s
.765 .566 .629 r
.30839 .41614 m .31394 .41731 L .31313 .4121 L p F P
0 g
s
.765 .566 .629 r
.31313 .4121 m .31014 .41147 L .30839 .41614 L p F P
0 g
s
.757 .633 .723 r
.30256 .39812 m .30697 .39289 L .30663 .39211 L p F P
0 g
s
.678 .706 .868 r
.44735 .37707 m .45666 .37352 L .45925 .37692 L p F P
0 g
s
.672 .725 .889 r
.45666 .37352 m .44735 .37707 L .44474 .37374 L p F P
0 g
s
.633 .414 .567 r
.50983 .42772 m .50971 .42345 L .49911 .42523 L p F P
0 g
s
.633 .414 .567 r
.49911 .42523 m .49921 .4295 L .50983 .42772 L p F P
0 g
s
.64 .42 .567 r
.49212 .43056 m .49921 .4295 L .49911 .42523 L p F P
0 g
s
.651 .534 .709 r
.53707 .39632 m .53583 .39222 L .52642 .39696 L p F P
0 g
s
.651 .534 .709 r
.52642 .39696 m .52693 .39871 L .53707 .39632 L p F P
0 g
s
.657 .551 .723 r
.52485 .39215 m .52642 .39696 L .53583 .39222 L p F P
0 g
s
.637 .463 .63 r
.52444 .4109 m .51912 .41201 L .5196 .41542 L closepath p F P
0 g
s
.659 .569 .742 r
.52389 .3895 m .52485 .39215 L .53501 .38977 L p F P
0 g
s
.657 .551 .723 r
.53583 .39222 m .53501 .38977 L .52485 .39215 L p F P
0 g
s
.668 .603 .773 r
.52136 .38342 m .51666 .38552 L .5218 .38441 L closepath p F P
0 g
s
.672 .616 .784 r
.51666 .38552 m .52136 .38342 L p .50944 .38226 L F P
0 g
s
.735 .667 .783 r
.31527 .38551 m .31633 .38468 L .31362 .38012 L p F P
0 g
s
.735 .667 .783 r
.31362 .38012 m .30842 .38395 L .31527 .38551 L p F P
0 g
s
.741 .657 .767 r
.30431 .38731 m .30663 .39211 L p .31527 .38551 L F P
0 g
s
.741 .657 .767 r
.31527 .38551 m .30842 .38395 L .30431 .38731 L p F P
0 g
s
.751 .645 .743 r
.30431 .38731 m .30085 .39069 L .30663 .39211 L closepath p F P
0 g
s
.757 .633 .723 r
.29565 .39658 m .30256 .39812 L p .30663 .39211 L F P
0 g
s
.757 .633 .723 r
.30663 .39211 m .30085 .39069 L .29565 .39658 L p F P
0 g
s
.647 .514 .687 r
.53839 .40148 m .53707 .39632 L .52693 .39871 L p F P
0 g
s
.647 .514 .687 r
.53633 .40269 m .53839 .40148 L p .52693 .39871 L F P
0 g
s
.647 .514 .687 r
.52693 .39871 m .52839 .40453 L .53633 .40269 L p F P
0 g
s
.706 .685 .828 r
.34495 .37887 m .34945 .37656 L p .33752 .37738 L F P
0 g
s
.706 .685 .828 r
.33752 .37738 m .33795 .378 L .34495 .37887 L p F P
0 g
s
.722 .686 .815 r
.31633 .38468 m .32558 .37854 L .32343 .37539 L p F P
0 g
s
.722 .686 .815 r
.31362 .38012 m .31633 .38468 L p .32343 .37539 L F P
0 g
s
.679 .699 .862 r
.45925 .37692 m .46859 .37334 L .47116 .37686 L p F P
0 g
s
.674 .719 .884 r
.46859 .37334 m .45925 .37692 L .45666 .37352 L p F P
0 g
s
.649 .384 .505 r
.46624 .4376 m .45959 .43817 L .46125 .44175 L p F P
0 g
s
.651 .385 .504 r
.45452 .44228 m .46125 .44175 L .45959 .43817 L p F P
0 g
s
.659 .569 .742 r
.53501 .38977 m .5333 .38523 L .52389 .3895 L p F P
0 g
s
.665 .589 .76 r
.5218 .38441 m .52389 .3895 L .5333 .38523 L p F P
0 g
s
.672 .616 .784 r
.52136 .38342 m .51884 .37828 L .50944 .38226 L p F P
0 g
s
.673 .648 .817 r
.50944 .38226 m .51884 .37828 L .51631 .37374 L p F P
0 g
s
.673 .648 .817 r
.50691 .37753 m .50944 .38226 L p .51631 .37374 L F P
0 g
s
.715 .438 .505 r
.36898 .44165 m .37135 .44184 L .37042 .43804 L p F P
0 g
s
.715 .438 .505 r
.37042 .43804 m .36957 .43798 L .36898 .44165 L p F P
0 g
s
.762 .59 .664 r
.29797 .40887 m .30316 .40997 L .30579 .40499 L p F P
0 g
s
.762 .59 .664 r
.29734 .40616 m .29797 .40887 L p .30579 .40499 L F P
0 g
s
.762 .59 .664 r
.30579 .40499 m .29883 .40348 L .29734 .40616 L p F P
0 g
s
.723 .446 .507 r
.36249 .44102 m .36898 .44165 L .36957 .43798 L p F P
0 g
s
.723 .446 .507 r
.36957 .43798 m .36165 .4372 L .36249 .44102 L p F P
0 g
s
.749 .511 .571 r
.32926 .4247 m .32885 .42463 L .32881 .4289 L closepath p F P
0 g
s
.765 .568 .631 r
.30135 .41467 m .30839 .41614 L .31014 .41147 L p F P
0 g
s
.765 .568 .631 r
.31014 .41147 m .30316 .40997 L .30135 .41467 L p F P
0 g
s
.737 .479 .539 r
.34253 .43499 m .3448 .43527 L .3446 .43125 L p F P
0 g
s
.737 .479 .539 r
.3446 .43125 m .34289 .43103 L .34253 .43499 L p F P
0 g
s
.757 .517 .57 r
.3288 .42894 m .32881 .4289 L .32885 .42463 L p F P
0 g
s
.757 .517 .57 r
.32137 .42761 m .3288 .42894 L p .32885 .42463 L F P
0 g
s
.757 .517 .57 r
.32885 .42463 m .32182 .42338 L .32137 .42761 L p F P
0 g
s
.678 .69 .854 r
.47116 .37686 m .48051 .37323 L .48307 .3769 L p F P
0 g
s
.675 .711 .876 r
.48051 .37323 m .47116 .37686 L .46859 .37334 L p F P
0 g
s
.758 .613 .698 r
.29653 .40298 m .29883 .40348 L .30256 .39812 L p F P
0 g
s
.758 .613 .698 r
.29483 .39768 m .29653 .40298 L p .30256 .39812 L F P
0 g
s
.758 .613 .698 r
.30256 .39812 m .29565 .39658 L .29483 .39768 L p F P
0 g
s
.681 .67 .833 r
.49217 .37826 m .49499 .37709 L p .48307 .3769 L F P
0 g
s
.679 .66 .825 r
.49499 .37709 m .49217 .37826 L .49536 .37772 L closepath p F P
0 g
s
.633 .392 .536 r
.49212 .43056 m .48845 .43108 L .4883 .43508 L p F P
0 g
s
.745 .487 .539 r
.33683 .43414 m .34253 .43499 L .34289 .43103 L p F P
0 g
s
.745 .487 .539 r
.34289 .43103 m .33668 .4301 L .33683 .43414 L p F P
0 g
s
.641 .377 .504 r
.47507 .4367 m .46624 .4376 L .46584 .44136 L p F P
0 g
s
.649 .384 .505 r
.46125 .44175 m .46584 .44136 L .46624 .4376 L p F P
0 g
s
.64 .489 .662 r
.53633 .40269 m .52839 .40453 L .52898 .40749 L closepath p F P
0 g
s
.715 .688 .823 r
.33752 .37738 m .33681 .37778 L .33795 .378 L closepath p F P
0 g
s
.758 .54 .601 r
.31429 .42205 m .31436 .42206 L .31549 .41759 L p F P
0 g
s
.758 .54 .601 r
.31549 .41759 m .31394 .41731 L .31429 .42205 L p F P
0 g
s
.681 .67 .833 r
.49499 .37709 m .49244 .37322 L .48307 .3769 L p F P
0 g
s
.676 .701 .866 r
.49244 .37322 m .48307 .3769 L .48051 .37323 L p F P
0 g
s
.642 .482 .652 r
.52898 .40749 m .52444 .4109 L .52941 .40983 L closepath p F P
0 g
s
.635 .459 .627 r
.52941 .40983 m .52444 .4109 L .5196 .41542 L p F P
0 g
s
.665 .589 .76 r
.5333 .38523 m .53195 .38202 L .5218 .38441 L p F P
0 g
s
.665 .602 .774 r
.52136 .38342 m .5218 .38441 L .53195 .38202 L p F P
0 g
s
.635 .459 .627 r
.5196 .41542 m .51979 .41692 L p .52941 .40983 L F P
0 g
s
.64 .46 .623 r
.5196 .41542 m .5179 .41728 L .51979 .41692 L closepath p F P
0 g
s
.709 .696 .836 r
.33681 .37778 m .33752 .37738 L .33479 .37367 L p F P
0 g
s
.709 .696 .836 r
.33479 .37367 m .32966 .37633 L .33681 .37778 L p F P
0 g
s
.715 .673 .807 r
.32558 .37854 m .32966 .37633 L .33681 .37778 L p F P
0 g
s
.677 .659 .825 r
.49499 .37709 m .49536 .37772 L .50585 .37575 L p F P
0 g
s
.679 .653 .817 r
.50691 .37753 m .50585 .37575 L .49536 .37772 L p F P
0 g
s
.699 .691 .838 r
.36136 .37594 m .35865 .37256 L .34945 .37656 L p F P
0 g
s
.683 .724 .881 r
.35865 .37256 m .34945 .37656 L .34672 .37303 L p F P
0 g
s
.706 .685 .828 r
.34945 .37656 m .34672 .37303 L .33752 .37738 L p F P
0 g
s
.724 .446 .506 r
.35562 .44034 m .36249 .44102 L .36165 .4372 L p F P
0 g
s
.724 .446 .506 r
.36165 .4372 m .35623 .43667 L .35562 .44034 L p F P
0 g
s
.686 .718 .873 r
.36136 .37594 m .37057 .37222 L .37327 .37547 L p F P
0 g
s
.675 .73 .891 r
.37057 .37222 m .36136 .37594 L .35865 .37256 L p F P
0 g
s
.631 .391 .536 r
.49921 .4295 m .49212 .43056 L .49301 .43441 L p F P
0 g
s
.633 .392 .536 r
.4883 .43508 m .49301 .43441 L .49212 .43056 L p F P
0 g
s
.766 .546 .6 r
.30732 .42059 m .31429 .42205 L .31394 .41731 L p F P
0 g
s
.766 .546 .6 r
.31394 .41731 m .30839 .41614 L .30732 .42059 L p F P
0 g
s
.633 .435 .597 r
.51979 .41692 m .5179 .41728 L .51474 .42251 L p F P
0 g
s
.635 .438 .598 r
.50971 .42345 m .51474 .42251 L .5179 .41728 L p F P
0 g
s
.692 .716 .868 r
.34672 .37303 m .33752 .37738 L .33479 .37367 L p F P
0 g
s
.738 .652 .764 r
.30842 .38395 m .30182 .3826 L .30431 .38731 L closepath p F P
0 g
s
.75 .654 .755 r
.30085 .39069 m .30431 .38731 L .30182 .3826 L p F P
0 g
s
.68 .723 .882 r
.37327 .37547 m .38249 .37195 L .38518 .37509 L p F P
0 g
s
.669 .736 .9 r
.38249 .37195 m .37327 .37547 L .37057 .37222 L p F P
0 g
s
.665 .602 .774 r
.53195 .38202 m .53078 .37944 L .52136 .38342 L p F P
0 g
s
.668 .627 .8 r
.53078 .37944 m .52136 .38342 L .51884 .37828 L p F P
0 g
s
.67 .378 .47 r
.4222 .44361 m .41934 .44365 L .41863 .44713 L p F P
0 g
s
.678 .386 .472 r
.41287 .44711 m .41863 .44713 L .41934 .44365 L p F P
0 g
s
.678 .386 .472 r
.41934 .44365 m .41098 .44362 L .41287 .44711 L p F P
0 g
s
.68 .387 .47 r
.40641 .44706 m .41287 .44711 L .41098 .44362 L p F P
0 g
s
.68 .387 .47 r
.41098 .44362 m .40716 .44359 L .40641 .44706 L p F P
0 g
s
.669 .378 .471 r
.43129 .44344 m .4222 .44361 L .42425 .44705 L p F P
0 g
s
.67 .378 .47 r
.41863 .44713 m .42425 .44705 L .4222 .44361 L p F P
0 g
s
.688 .395 .472 r
.40212 .44695 m .40641 .44706 L .40716 .44359 L p F P
0 g
s
.688 .395 .472 r
.40716 .44359 m .40038 .44342 L .40212 .44695 L p F P
0 g
s
.75 .654 .755 r
.29407 .38911 m .30085 .39069 L p .30182 .3826 L F P
0 g
s
.753 .636 .731 r
.29434 .39629 m .29565 .39658 L .30085 .39069 L p F P
0 g
s
.753 .636 .731 r
.29222 .39106 m .29434 .39629 L p .30085 .39069 L F P
0 g
s
.753 .636 .731 r
.30085 .39069 m .29407 .38911 L .29222 .39106 L p F P
0 g
s
.637 .483 .658 r
.52898 .40749 m .52941 .40983 L p .53855 .40216 L F P
0 g
s
.637 .483 .658 r
.53855 .40216 m .53633 .40269 L .52898 .40749 L p F P
0 g
s
.676 .727 .888 r
.38518 .37509 m .39441 .37171 L .39709 .37478 L p F P
0 g
s
.664 .741 .907 r
.39441 .37171 m .38518 .37509 L .38249 .37195 L p F P
0 g
s
.675 .688 .855 r
.50437 .37337 m .49499 .37709 L .49244 .37322 L p F P
0 g
s
.677 .659 .825 r
.50585 .37575 m .50437 .37337 L .49499 .37709 L p F P
0 g
s
.735 .66 .776 r
.30842 .38395 m .31362 .38012 L p .30161 .38224 L F P
0 g
s
.735 .66 .776 r
.30161 .38224 m .30182 .3826 L .30842 .38395 L p F P
0 g
s
.669 .378 .471 r
.42425 .44705 m .4306 .44693 L .43129 .44344 L p F P
0 g
s
.66 .37 .469 r
.43419 .44334 m .43129 .44344 L .4306 .44693 L p F P
0 g
s
.71 .684 .823 r
.32966 .37633 m .32343 .37539 L .32558 .37854 L closepath p F P
0 g
s
.689 .395 .471 r
.39395 .44671 m .40212 .44695 L .40038 .44342 L p F P
0 g
s
.689 .395 .471 r
.40038 .44342 m .39472 .44325 L .39395 .44671 L p F P
0 g
s
.635 .459 .627 r
.51979 .41692 m .53007 .41471 L .52941 .40983 L p F P
0 g
s
.626 .43 .597 r
.53046 .41927 m .53007 .41471 L .51979 .41692 L p F P
0 g
s
.626 .43 .597 r
.51979 .41692 m .52016 .42146 L .53046 .41927 L p F P
0 g
s
.633 .435 .597 r
.51474 .42251 m .52016 .42146 L .51979 .41692 L p F P
0 g
s
.659 .37 .471 r
.44301 .44298 m .43419 .44334 L .43641 .44673 L p F P
0 g
s
.66 .37 .469 r
.4306 .44693 m .43641 .44673 L .43419 .44334 L p F P
0 g
s
.745 .485 .538 r
.32896 .43297 m .33683 .43414 L .33668 .4301 L p F P
0 g
s
.745 .485 .538 r
.3288 .42896 m .32896 .43297 L p .33668 .4301 L F P
0 g
s
.745 .485 .538 r
.33668 .4301 m .32881 .42894 L .3288 .42896 L p F P
0 g
s
.639 .377 .505 r
.47736 .43646 m .47507 .4367 L .47691 .44023 L p F P
0 g
s
.641 .377 .504 r
.46584 .44136 m .47691 .44023 L .47507 .4367 L p F P
0 g
s
.673 .729 .893 r
.39709 .37478 m .40633 .37149 L .409 .3745 L p F P
0 g
s
.661 .745 .912 r
.40633 .37149 m .39709 .37478 L .39441 .37171 L p F P
0 g
s
.626 .409 .567 r
.51474 .42251 m .50971 .42345 L .50983 .42772 L p F P
0 g
s
.732 .454 .508 r
.35385 .44013 m .35562 .44034 L .35623 .43667 L p F P
0 g
s
.732 .454 .508 r
.35623 .43667 m .35308 .43629 L .35385 .44013 L p F P
0 g
s
.697 .403 .473 r
.39189 .44661 m .39395 .44671 L .39472 .44325 L p F P
0 g
s
.697 .403 .473 r
.39472 .44325 m .39027 .44304 L .39189 .44661 L p F P
0 g
s
.756 .517 .571 r
.31423 .42635 m .32137 .42761 L .32182 .42338 L p F P
0 g
s
.756 .517 .571 r
.31428 .42277 m .31423 .42635 L p .32182 .42338 L F P
0 g
s
.756 .517 .571 r
.32182 .42338 m .31436 .42206 L .31428 .42277 L p F P
0 g
s
.763 .591 .664 r
.29883 .40348 m .29653 .40298 L .29734 .40616 L closepath p F P
0 g
s
.671 .731 .895 r
.409 .3745 m .41826 .37125 L .42091 .37424 L p F P
0 g
s
.66 .747 .915 r
.41826 .37125 m .409 .3745 L .40633 .37149 L p F P
0 g
s
.631 .369 .504 r
.48794 .43884 m .4883 .43508 L .47736 .43646 L p F P
0 g
s
.631 .369 .504 r
.47736 .43646 m .47699 .44022 L .48794 .43884 L p F P
0 g
s
.639 .377 .505 r
.47691 .44023 m .47699 .44022 L .47736 .43646 L p F P
0 g
s
.698 .402 .471 r
.38213 .44611 m .39189 .44661 L .39027 .44304 L p F P
0 g
s
.698 .402 .471 r
.38151 .44474 m .38213 .44611 L p .39027 .44304 L F P
0 g
s
.698 .402 .471 r
.39027 .44304 m .38201 .44262 L .38151 .44474 L p F P
0 g
s
.765 .567 .631 r
.2988 .41413 m .30135 .41467 L .30316 .40997 L p F P
0 g
s
.765 .567 .631 r
.30316 .40997 m .29797 .40887 L .2988 .41413 L p F P
0 g
s
.651 .362 .469 r
.44712 .44275 m .44301 .44298 L .44235 .44649 L p F P
0 g
s
.659 .37 .471 r
.43641 .44673 m .44235 .44649 L .44301 .44298 L p F P
0 g
s
.733 .454 .506 r
.34558 .4391 m .35385 .44013 L .35308 .43629 L p F P
0 g
s
.733 .454 .506 r
.35308 .43629 m .3448 .43527 L .34558 .4391 L p F P
0 g
s
.637 .483 .658 r
.52941 .40983 m .53955 .40743 L .53855 .40216 L p F P
0 g
s
.628 .454 .627 r
.54023 .41233 m .53955 .40743 L .52941 .40983 L p F P
0 g
s
.628 .454 .627 r
.52941 .40983 m .53007 .41471 L .54023 .41233 L p F P
0 g
s
.718 .676 .808 r
.32199 .37505 m .31362 .38012 L .31088 .37587 L p F P
0 g
s
.735 .66 .776 r
.31362 .38012 m .31088 .37587 L .30161 .38224 L p F P
0 g
s
.722 .686 .815 r
.32343 .37539 m .32199 .37505 L .31362 .38012 L p F P
0 g
s
.759 .614 .698 r
.29565 .39658 m .29434 .39629 L .29483 .39768 L closepath p F P
0 g
s
.673 .648 .817 r
.51631 .37374 m .51631 .37374 L .50691 .37753 L p F P
0 g
s
.676 .661 .827 r
.51631 .37374 m .50585 .37575 L .50691 .37753 L closepath p F P
0 g
s
.671 .731 .895 r
.42091 .37424 m .43019 .371 L .43283 .37399 L p F P
0 g
s
.66 .748 .915 r
.43019 .371 m .42091 .37424 L .41826 .37125 L p F P
0 g
s
.647 .536 .714 r
.54708 .39374 m .54527 .38788 L .53583 .39222 L p F P
0 g
s
.647 .536 .714 r
.53583 .39222 m .53707 .39632 L .54708 .39374 L p F P
0 g
s
.652 .553 .73 r
.53501 .38977 m .53583 .39222 L .54527 .38788 L p F P
0 g
s
.649 .362 .47 r
.45452 .44228 m .44712 .44275 L .44954 .44607 L p F P
0 g
s
.651 .362 .469 r
.44235 .44649 m .44954 .44607 L .44712 .44275 L p F P
0 g
s
.623 .385 .535 r
.50971 .43172 m .50983 .42772 L .49921 .4295 L p F P
0 g
s
.623 .385 .535 r
.49921 .4295 m .49908 .4335 L .50971 .43172 L p F P
0 g
s
.631 .391 .536 r
.49301 .43441 m .49908 .4335 L .49921 .4295 L p F P
0 g
s
.656 .571 .747 r
.5333 .38523 m .53501 .38977 L .54504 .38721 L p F P
0 g
s
.652 .553 .73 r
.54527 .38788 m .54504 .38721 L .53501 .38977 L p F P
0 g
s
.768 .61 .684 r
.29483 .39768 m .29214 .40187 L .29653 .40298 L closepath p F P
0 g
s
.772 .595 .659 r
.29624 .40845 m .29734 .40616 L .29653 .40298 L p F P
0 g
s
.772 .595 .659 r
.28962 .40681 m .29624 .40845 L p .29653 .40298 L F P
0 g
s
.772 .595 .659 r
.29653 .40298 m .29214 .40187 L .28962 .40681 L p F P
0 g
s
.769 .616 .69 r
.29214 .40187 m .29483 .39768 L .29434 .39629 L p F P
0 g
s
.706 .411 .473 r
.38201 .44262 m .38151 .44474 L .38057 .44252 L closepath p F P
0 g
s
.642 .513 .691 r
.54783 .39656 m .54708 .39374 L .53707 .39632 L p F P
0 g
s
.642 .513 .691 r
.53707 .39632 m .53839 .40148 L .54783 .39656 L p F P
0 g
s
.766 .547 .601 r
.30024 .41912 m .30732 .42059 L .30839 .41614 L p F P
0 g
s
.766 .547 .601 r
.30839 .41614 m .30135 .41467 L .30024 .41912 L p F P
0 g
s
.661 .747 .914 r
.44213 .37073 m .43283 .37399 L .43019 .371 L p F P
0 g
s
.671 .729 .893 r
.43283 .37399 m .44213 .37073 L .44474 .37374 L p F P
0 g
s
.764 .63 .713 r
.29222 .39106 m .28912 .39491 L .29434 .39629 L closepath p F P
0 g
s
.769 .616 .69 r
.28557 .40021 m .29214 .40187 L p .29434 .39629 L F P
0 g
s
.769 .616 .69 r
.29434 .39629 m .28912 .39491 L .28557 .40021 L p F P
0 g
s
.707 .411 .473 r
.37287 .44543 m .37135 .44184 L .38057 .44252 L p F P
0 g
s
.707 .411 .473 r
.3812 .44606 m .37287 .44543 L p .38057 .44252 L F P
0 g
s
.707 .411 .473 r
.38057 .44252 m .38151 .44474 L .3812 .44606 L p F P
0 g
s
.707 .688 .829 r
.32966 .37633 m .33479 .37367 L p .32285 .37457 L F P
0 g
s
.707 .688 .829 r
.32285 .37457 m .32343 .37539 L .32966 .37633 L p F P
0 g
s
.642 .503 .678 r
.53839 .40148 m .53633 .40269 L .53855 .40216 L closepath p F P
0 g
s
.624 .406 .567 r
.52016 .42146 m .51474 .42251 L .51387 .42696 L p F P
0 g
s
.626 .409 .567 r
.50983 .42772 m .51387 .42696 L .51474 .42251 L p F P
0 g
s
.77 .589 .653 r
.29734 .40616 m .29624 .40845 L .29797 .40887 L closepath p F P
0 g
s
.672 .725 .889 r
.44474 .37374 m .45406 .37045 L .45666 .37352 L p F P
0 g
s
.664 .745 .91 r
.45406 .37045 m .44474 .37374 L .44213 .37073 L p F P
0 g
s
.641 .354 .469 r
.46125 .44175 m .45452 .44228 L .45389 .4458 L p F P
0 g
s
.649 .362 .47 r
.44954 .44607 m .45389 .4458 L .45452 .44228 L p F P
0 g
s
.656 .571 .747 r
.54504 .38721 m .54275 .38121 L .5333 .38523 L p F P
0 g
s
.661 .592 .767 r
.53195 .38202 m .5333 .38523 L .54275 .38121 L p F P
0 g
s
.754 .514 .569 r
.32881 .4289 m .3288 .42894 L .32881 .42894 L closepath p F P
0 g
s
.753 .493 .539 r
.32881 .42894 m .3288 .42896 L .3288 .42894 L closepath p F P
0 g
s
.753 .493 .539 r
.32149 .43166 m .32137 .42761 L .3288 .42894 L p F P
0 g
s
.753 .493 .539 r
.32842 .43289 m .32149 .43166 L p .3288 .42894 L F P
0 g
s
.753 .493 .539 r
.3288 .42894 m .3288 .42896 L .32842 .43289 L p F P
0 g
s
.747 .488 .538 r
.3288 .42896 m .32896 .43297 L .32842 .43289 L closepath p F P
0 g
s
.745 .663 .77 r
.30161 .38224 m .30133 .38248 L .30182 .3826 L closepath p F P
0 g
s
.75 .654 .755 r
.30182 .3826 m .30133 .38248 L .29407 .38911 L p F P
0 g
s
.674 .719 .884 r
.45666 .37352 m .466 .37018 L .46859 .37334 L p F P
0 g
s
.667 .74 .905 r
.466 .37018 m .45666 .37352 L .45406 .37045 L p F P
0 g
s
.748 .662 .765 r
.29103 .3884 m .29407 .38911 L .30133 .38248 L p F P
0 g
s
.753 .635 .731 r
.29407 .38911 m .29103 .3884 L .29222 .39106 L closepath p F P
0 g
s
.741 .671 .781 r
.30133 .38248 m .30161 .38224 L .29888 .37769 L p F P
0 g
s
.741 .671 .781 r
.29888 .37769 m .29491 .38075 L .30133 .38248 L p F P
0 g
s
.748 .662 .765 r
.28955 .38535 m .29103 .3884 L p .30133 .38248 L F P
0 g
s
.748 .662 .765 r
.30133 .38248 m .29491 .38075 L .28955 .38535 L p F P
0 g
s
.727 .688 .813 r
.30161 .38224 m .31088 .37587 L .30835 .37221 L p F P
0 g
s
.727 .688 .813 r
.29888 .37769 m .30161 .38224 L p .30835 .37221 L F P
0 g
s
.668 .627 .8 r
.51884 .37828 m .52826 .37447 L .53078 .37944 L p F P
0 g
s
.673 .646 .815 r
.51631 .37374 m .51884 .37828 L .52826 .37447 L p F P
0 g
s
.637 .499 .679 r
.54854 .39956 m .54783 .39656 L .53839 .40148 L p F P
0 g
s
.637 .499 .679 r
.53839 .40148 m .53855 .40216 L .54854 .39956 L p F P
0 g
s
.773 .573 .628 r
.29454 .41311 m .2988 .41413 L .29797 .40887 L p F P
0 g
s
.773 .573 .628 r
.29797 .40887 m .29624 .40845 L .29454 .41311 L p F P
0 g
s
.676 .667 .834 r
.50437 .37337 m .50585 .37575 L .51631 .37374 L p F P
0 g
s
.758 .519 .571 r
.31436 .42206 m .31429 .42205 L .31428 .42277 L closepath p F P
0 g
s
.766 .526 .57 r
.31392 .42629 m .31428 .42277 L .31429 .42205 L p F P
0 g
s
.766 .526 .57 r
.30686 .42482 m .31392 .42629 L p .31429 .42205 L F P
0 g
s
.766 .526 .57 r
.31429 .42205 m .30732 .42059 L .30686 .42482 L p F P
0 g
s
.734 .454 .505 r
.34187 .43863 m .34558 .4391 L .3448 .43527 L p F P
0 g
s
.734 .454 .505 r
.3448 .43527 m .34253 .43499 L .34187 .43863 L p F P
0 g
s
.764 .637 .721 r
.28912 .39491 m .29222 .39106 L .29103 .3884 L p F P
0 g
s
.63 .478 .657 r
.54956 .40485 m .54854 .39956 L .53855 .40216 L p F P
0 g
s
.63 .478 .657 r
.53855 .40216 m .53955 .40743 L .54956 .40485 L p F P
0 g
s
.709 .411 .47 r
.36813 .44506 m .37287 .44543 L .37135 .44184 L p F P
0 g
s
.709 .411 .47 r
.37135 .44184 m .36898 .44165 L .36813 .44506 L p F P
0 g
s
.675 .711 .876 r
.46859 .37334 m .47794 .36993 L .48051 .37323 L p F P
0 g
s
.669 .733 .897 r
.47794 .36993 m .46859 .37334 L .466 .37018 L p F P
0 g
s
.639 .354 .47 r
.46584 .44136 m .46125 .44175 L .4639 .445 L p F P
0 g
s
.641 .354 .469 r
.45389 .4458 m .4639 .445 L .46125 .44175 L p F P
0 g
s
.623 .361 .501 r
.49301 .43441 m .4883 .43508 L .48794 .43884 L p F P
0 g
s
.718 .42 .472 r
.36389 .44465 m .36813 .44506 L .36898 .44165 L p F P
0 g
s
.718 .42 .472 r
.36898 .44165 m .36249 .44102 L .36389 .44465 L p F P
0 g
s
.742 .463 .507 r
.33754 .43799 m .34187 .43863 L .34253 .43499 L p F P
0 g
s
.742 .463 .507 r
.34253 .43499 m .33683 .43414 L .33754 .43799 L p F P
0 g
s
.771 .597 .662 r
.28296 .40519 m .28962 .40681 L .29214 .40187 L p F P
0 g
s
.771 .597 .662 r
.29214 .40187 m .28557 .40021 L .28296 .40519 L p F P
0 g
s
.663 .605 .78 r
.53078 .37944 m .53195 .38202 L .54198 .37945 L p F P
0 g
s
.661 .592 .767 r
.54275 .38121 m .54198 .37945 L .53195 .38202 L p F P
0 g
s
.718 .692 .824 r
.32285 .37457 m .32199 .37505 L .32343 .37539 L closepath p F P
0 g
s
.774 .576 .631 r
.28787 .41149 m .29454 .41311 L .29624 .40845 L p F P
0 g
s
.774 .576 .631 r
.29624 .40845 m .28962 .40681 L .28787 .41149 L p F P
0 g
s
.764 .523 .569 r
.31428 .42277 m .31392 .42629 L .31423 .42635 L closepath p F P
0 g
s
.676 .701 .866 r
.48051 .37323 m .48989 .36975 L .49244 .37322 L p F P
0 g
s
.672 .723 .888 r
.48989 .36975 m .48051 .37323 L .47794 .36993 L p F P
0 g
s
.631 .347 .469 r
.47691 .44023 m .46584 .44136 L .46524 .44489 L p F P
0 g
s
.639 .354 .47 r
.4639 .445 m .46524 .44489 L .46584 .44136 L p F P
0 g
s
.758 .649 .741 r
.28955 .38535 m .28752 .38743 L .29103 .3884 L closepath p F P
0 g
s
.764 .637 .721 r
.28262 .39322 m .28912 .39491 L p .29103 .3884 L F P
0 g
s
.764 .637 .721 r
.29103 .3884 m .28752 .38743 L .28262 .39322 L p F P
0 g
s
.616 .401 .566 r
.53059 .42353 m .53046 .41927 L .52016 .42146 L p F P
0 g
s
.616 .401 .566 r
.52016 .42146 m .52028 .42573 L .53059 .42353 L p F P
0 g
s
.624 .406 .567 r
.51387 .42696 m .52028 .42573 L .52016 .42146 L p F P
0 g
s
.711 .699 .836 r
.32199 .37505 m .32285 .37457 L .32009 .37089 L p F P
0 g
s
.711 .699 .836 r
.32009 .37089 m .31526 .37344 L .32199 .37505 L p F P
0 g
s
.718 .676 .808 r
.31088 .37587 m .31526 .37344 L .32199 .37505 L p F P
0 g
s
.767 .619 .695 r
.2806 .39897 m .28557 .40021 L .28912 .39491 L p F P
0 g
s
.767 .619 .695 r
.27997 .397 m .2806 .39897 L p .28912 .39491 L F P
0 g
s
.767 .619 .695 r
.28912 .39491 m .28262 .39322 L .27997 .397 L p F P
0 g
s
.692 .716 .868 r
.33479 .37367 m .34398 .36973 L .34672 .37303 L p F P
0 g
s
.681 .727 .884 r
.34398 .36973 m .33479 .37367 L .33204 .37019 L p F P
0 g
s
.707 .688 .829 r
.33479 .37367 m .33204 .37019 L .32285 .37457 L p F P
0 g
s
.619 .425 .598 r
.54063 .41689 m .54023 .41233 L .53007 .41471 L p F P
0 g
s
.619 .425 .598 r
.53007 .41471 m .53046 .41927 L .54063 .41689 L p F P
0 g
s
.683 .724 .881 r
.34672 .37303 m .35591 .36941 L .35865 .37256 L p F P
0 g
s
.671 .735 .898 r
.35591 .36941 m .34672 .37303 L .34398 .36973 L p F P
0 g
s
.767 .548 .601 r
.29917 .4189 m .30024 .41912 L .30135 .41467 L p F P
0 g
s
.767 .548 .601 r
.30135 .41467 m .2988 .41413 L .29917 .4189 L p F P
0 g
s
.675 .688 .855 r
.49244 .37322 m .50184 .36968 L .50437 .37337 L p F P
0 g
s
.673 .711 .876 r
.50184 .36968 m .49244 .37322 L .48989 .36975 L p F P
0 g
s
.675 .73 .891 r
.35865 .37256 m .36784 .3692 L .37057 .37222 L p F P
0 g
s
.662 .742 .909 r
.36784 .3692 m .35865 .37256 L .35591 .36941 L p F P
0 g
s
.693 .719 .869 r
.33204 .37019 m .32285 .37457 L .32009 .37089 L p F P
0 g
s
.621 .361 .503 r
.49908 .4335 m .49301 .43441 L .49534 .43778 L p F P
0 g
s
.623 .361 .501 r
.48794 .43884 m .49534 .43778 L .49301 .43441 L p F P
0 g
s
.718 .419 .471 r
.35517 .44379 m .36389 .44465 L .36249 .44102 L p F P
0 g
s
.718 .419 .471 r
.3549 .44309 m .35517 .44379 L p .36249 .44102 L F P
0 g
s
.718 .419 .471 r
.36249 .44102 m .35562 .44034 L .3549 .44309 L p F P
0 g
s
.615 .378 .534 r
.51387 .42696 m .50983 .42772 L .50971 .43172 L p F P
0 g
s
.663 .605 .78 r
.54198 .37945 m .54023 .37565 L .53078 .37944 L p F P
0 g
s
.666 .632 .806 r
.54023 .37565 m .53078 .37944 L .52826 .37447 L p F P
0 g
s
.655 .748 .918 r
.37978 .36904 m .37057 .37222 L .36784 .3692 L p F P
0 g
s
.669 .736 .9 r
.37057 .37222 m .37978 .36904 L .38249 .37195 L p F P
0 g
s
.755 .494 .538 r
.31402 .43034 m .32149 .43166 L .32137 .42761 L p F P
0 g
s
.755 .494 .538 r
.31398 .42877 m .31402 .43034 L p .32137 .42761 L F P
0 g
s
.755 .494 .538 r
.32137 .42761 m .31423 .42635 L .31398 .42877 L p F P
0 g
s
.742 .462 .505 r
.32969 .43682 m .33754 .43799 L .33683 .43414 L p F P
0 g
s
.742 .462 .505 r
.33683 .43414 m .32896 .43297 L .32969 .43682 L p F P
0 g
s
.713 .686 .823 r
.31526 .37344 m .30835 .37221 L .31088 .37587 L closepath p F P
0 g
s
.7 .404 .471 r
.38151 .44474 m .38213 .44611 L .3812 .44606 L closepath p F P
0 g
s
.664 .741 .907 r
.38249 .37195 m .39171 .36889 L .39441 .37171 L p F P
0 g
s
.65 .754 .926 r
.39171 .36889 m .38249 .37195 L .37978 .36904 L p F P
0 g
s
.775 .554 .6 r
.2935 .41754 m .29917 .4189 L .2988 .41413 L p F P
0 g
s
.775 .554 .6 r
.2988 .41413 m .29454 .41311 L .2935 .41754 L p F P
0 g
s
.676 .667 .834 r
.51631 .37374 m .51379 .36978 L .50437 .37337 L p F P
0 g
s
.676 .667 .834 r
.51631 .37374 m .51631 .37374 L p .50437 .37337 L F P
0 g
s
.674 .697 .863 r
.51379 .36978 m .50437 .37337 L .50184 .36968 L p F P
0 g
s
.755 .654 .75 r
.28752 .38743 m .28955 .38535 L .28684 .38023 L p F P
0 g
s
.744 .654 .76 r
.29491 .38075 m .28955 .38535 L .28684 .38023 L p F P
0 g
s
.622 .45 .628 r
.55026 .40976 m .54956 .40485 L .53955 .40743 L p F P
0 g
s
.622 .45 .628 r
.53955 .40743 m .54023 .41233 L .55026 .40976 L p F P
0 g
s
.661 .348 .432 r
.42425 .44705 m .41863 .44713 L .4177 .45039 L p F P
0 g
s
.669 .357 .435 r
.41543 .45038 m .4177 .45039 L .41863 .44713 L p F P
0 g
s
.669 .357 .435 r
.41863 .44713 m .41287 .44711 L .41543 .45038 L p F P
0 g
s
.671 .357 .434 r
.40546 .4503 m .41543 .45038 L .41287 .44711 L p F P
0 g
s
.671 .357 .434 r
.41287 .44711 m .40641 .44706 L .40546 .4503 L p F P
0 g
s
.766 .525 .57 r
.29977 .42336 m .30686 .42482 L .30732 .42059 L p F P
0 g
s
.766 .525 .57 r
.30732 .42059 m .30024 .41912 L .29977 .42336 L p F P
0 g
s
.68 .366 .436 r
.40449 .45028 m .40546 .4503 L .40641 .44706 L p F P
0 g
s
.68 .366 .436 r
.40641 .44706 m .40212 .44695 L .40449 .45028 L p F P
0 g
s
.659 .348 .434 r
.4306 .44693 m .42425 .44705 L .42701 .45026 L p F P
0 g
s
.661 .348 .432 r
.4177 .45039 m .42701 .45026 L .42425 .44705 L p F P
0 g
s
.755 .654 .75 r
.28684 .38023 m .28118 .38568 L .28752 .38743 L p F P
0 g
s
.762 .641 .728 r
.27824 .39209 m .28262 .39322 L .28752 .38743 L p F P
0 g
s
.762 .641 .728 r
.27737 .38995 m .27824 .39209 L p .28752 .38743 L F P
0 g
s
.762 .641 .728 r
.28752 .38743 m .28118 .38568 L .27737 .38995 L p F P
0 g
s
.661 .745 .912 r
.39441 .37171 m .40365 .36873 L .40633 .37149 L p F P
0 g
s
.647 .759 .931 r
.40365 .36873 m .39441 .37171 L .39171 .36889 L p F P
0 g
s
.735 .673 .789 r
.29491 .38075 m .29888 .37769 L .29613 .37342 L p F P
0 g
s
.735 .673 .789 r
.29613 .37342 m .28825 .37911 L .29491 .38075 L p F P
0 g
s
.744 .654 .76 r
.28684 .38023 m .28825 .37911 L .29491 .38075 L p F P
0 g
s
.727 .428 .473 r
.35562 .44034 m .3549 .44309 L .35385 .44013 L closepath p F P
0 g
s
.68 .364 .433 r
.39416 .44997 m .40449 .45028 L .40212 .44695 L p F P
0 g
s
.68 .364 .433 r
.39331 .44876 m .39416 .44997 L p .40212 .44695 L F P
0 g
s
.68 .364 .433 r
.40212 .44695 m .39395 .44671 L .39331 .44876 L p F P
0 g
s
.659 .348 .434 r
.42701 .45026 m .42971 .45021 L .4306 .44693 L p F P
0 g
s
.65 .339 .432 r
.43641 .44673 m .4306 .44693 L .42971 .45021 L p F P
0 g
s
.628 .343 .467 r
.47699 .44022 m .47698 .4403 L .47691 .44023 L closepath p F P
0 g
s
.631 .347 .469 r
.4764 .44374 m .47698 .4403 L .47691 .44023 L p F P
0 g
s
.631 .347 .469 r
.46524 .44489 m .4764 .44374 L p .47691 .44023 L F P
0 g
s
.62 .336 .465 r
.48738 .44238 m .48794 .43884 L .47699 .44022 L p F P
0 g
s
.62 .336 .465 r
.48018 .44328 m .48738 .44238 L p .47699 .44022 L F P
0 g
s
.62 .336 .465 r
.47699 .44022 m .47698 .4403 L .48018 .44328 L p F P
0 g
s
.645 .544 .726 r
.54527 .38788 m .54708 .39374 L p .55492 .38443 L F P
0 g
s
.645 .544 .726 r
.55492 .38443 m .5503 .38575 L .54527 .38788 L p F P
0 g
s
.648 .554 .735 r
.5503 .38575 m .54504 .38721 L .54527 .38788 L closepath p F P
0 g
s
.613 .377 .535 r
.52028 .42573 m .51387 .42696 L .51507 .43072 L p F P
0 g
s
.615 .378 .534 r
.50971 .43172 m .51507 .43072 L .51387 .42696 L p F P
0 g
s
.653 .573 .752 r
.54275 .38121 m .54504 .38721 L .5503 .38575 L p F P
0 g
s
.621 .336 .464 r
.47698 .4403 m .48018 .44328 L .4764 .44374 L closepath p F P
0 g
s
.727 .428 .473 r
.3469 .44276 m .34558 .4391 L .35385 .44013 L p F P
0 g
s
.727 .428 .473 r
.35473 .44374 m .3469 .44276 L p .35385 .44013 L F P
0 g
s
.727 .428 .473 r
.35385 .44013 m .3549 .44309 L .35473 .44374 L p F P
0 g
s
.612 .353 .501 r
.50938 .43548 m .50971 .43172 L .49908 .4335 L p F P
0 g
s
.612 .353 .501 r
.49908 .4335 m .49874 .43727 L .50938 .43548 L p F P
0 g
s
.621 .361 .503 r
.49534 .43778 m .49874 .43727 L .49908 .4335 L p F P
0 g
s
.66 .747 .915 r
.40633 .37149 m .4156 .36853 L .41826 .37125 L p F P
0 g
s
.646 .762 .934 r
.4156 .36853 m .40633 .37149 L .40365 .36873 L p F P
0 g
s
.649 .339 .434 r
.44235 .44649 m .43641 .44673 L .4394 .44986 L p F P
0 g
s
.65 .339 .432 r
.42971 .45021 m .4394 .44986 L .43641 .44673 L p F P
0 g
s
.645 .544 .726 r
.54708 .39374 m .55697 .39097 L .55492 .38443 L p F P
0 g
s
.637 .513 .695 r
.55729 .39217 m .55697 .39097 L .54708 .39374 L p F P
0 g
s
.637 .513 .695 r
.54708 .39374 m .54783 .39656 L .55729 .39217 L p F P
0 g
s
.689 .373 .436 r
.39395 .44671 m .39331 .44876 L .39189 .44661 L closepath p F P
0 g
s
.69 .373 .435 r
.38437 .44947 m .38213 .44611 L .39189 .44661 L p F P
0 g
s
.69 .373 .435 r
.39295 .44993 m .38437 .44947 L p .39189 .44661 L F P
0 g
s
.69 .373 .435 r
.39189 .44661 m .39331 .44876 L .39295 .44993 L p F P
0 g
s
.727 .688 .813 r
.30835 .37221 m .30783 .37207 L .29888 .37769 L p F P
0 g
s
.722 .677 .805 r
.30783 .37207 m .29888 .37769 L .29613 .37342 L p F P
0 g
s
.671 .653 .824 r
.51631 .37374 m .51631 .37374 L .52645 .37129 L p F P
0 g
s
.673 .646 .815 r
.52826 .37447 m .52645 .37129 L .51631 .37374 L p F P
0 g
s
.671 .653 .824 r
.52645 .37129 m .52575 .37011 L .51631 .37374 L p F P
0 g
s
.672 .68 .849 r
.52575 .37011 m .51631 .37374 L .51379 .36978 L p F P
0 g
s
.771 .596 .661 r
.28214 .40498 m .28296 .40519 L .28557 .40021 L p F P
0 g
s
.771 .596 .661 r
.28557 .40021 m .2806 .39897 L .28214 .40498 L p F P
0 g
s
.773 .578 .635 r
.28303 .41031 m .28787 .41149 L .28962 .40681 L p F P
0 g
s
.773 .578 .635 r
.28242 .40654 m .28303 .41031 L p .28962 .40681 L F P
0 g
s
.773 .578 .635 r
.28962 .40681 m .28296 .40519 L .28242 .40654 L p F P
0 g
s
.64 .331 .431 r
.44954 .44607 m .44235 .44649 L .44149 .44978 L p F P
0 g
s
.649 .339 .434 r
.4394 .44986 m .44149 .44978 L .44235 .44649 L p F P
0 g
s
.66 .748 .915 r
.41826 .37125 m .42754 .36829 L .43019 .371 L p F P
0 g
s
.646 .764 .935 r
.42754 .36829 m .41826 .37125 L .4156 .36853 L p F P
0 g
s
.632 .499 .683 r
.55841 .39677 m .55729 .39217 L .54783 .39656 L p F P
0 g
s
.632 .499 .683 r
.54783 .39656 m .54854 .39956 L .55841 .39677 L p F P
0 g
s
.71 .69 .829 r
.31526 .37344 m .32009 .37089 L p .30813 .3719 L F P
0 g
s
.71 .69 .829 r
.30813 .3719 m .30835 .37221 L .31526 .37344 L p F P
0 g
s
.661 .747 .914 r
.43019 .371 m .4395 .368 L .44213 .37073 L p F P
0 g
s
.649 .764 .934 r
.4395 .368 m .43019 .371 L .42754 .36829 L p F P
0 g
s
.763 .502 .539 r
.31423 .42635 m .31398 .42877 L .31392 .42629 L closepath p F P
0 g
s
.775 .556 .601 r
.28679 .41593 m .2935 .41754 L .29454 .41311 L p F P
0 g
s
.775 .556 .601 r
.29454 .41311 m .28787 .41149 L .28679 .41593 L p F P
0 g
s
.744 .463 .504 r
.32771 .43651 m .32969 .43682 L .32896 .43297 L p F P
0 g
s
.744 .463 .504 r
.32896 .43297 m .32842 .43289 L .32771 .43651 L p F P
0 g
s
.766 .618 .694 r
.28262 .39322 m .27824 .39209 L .27997 .397 L closepath p F P
0 g
s
.763 .502 .539 r
.30695 .42887 m .30686 .42482 L .31392 .42629 L p F P
0 g
s
.763 .502 .539 r
.31382 .4303 m .30695 .42887 L p .31392 .42629 L F P
0 g
s
.763 .502 .539 r
.31392 .42629 m .31398 .42877 L .31382 .4303 L p F P
0 g
s
.753 .472 .506 r
.32214 .43553 m .32771 .43651 L .32842 .43289 L p F P
0 g
s
.753 .472 .506 r
.32842 .43289 m .32149 .43166 L .32214 .43553 L p F P
0 g
s
.692 .372 .43 r
.38014 .44924 m .38437 .44947 L .38213 .44611 L p F P
0 g
s
.692 .372 .43 r
.38213 .44611 m .3812 .44606 L .38014 .44924 L p F P
0 g
s
.653 .573 .752 r
.55474 .38391 m .55221 .37743 L .54275 .38121 L p F P
0 g
s
.653 .573 .752 r
.5503 .38575 m .55474 .38391 L p .54275 .38121 L F P
0 g
s
.658 .594 .772 r
.54198 .37945 m .54275 .38121 L .55221 .37743 L p F P
0 g
s
.638 .331 .434 r
.45389 .4458 m .44954 .44607 L .45279 .44913 L p F P
0 g
s
.64 .331 .431 r
.44149 .44978 m .45279 .44913 L .44954 .44607 L p F P
0 g
s
.701 .382 .434 r
.37495 .44885 m .38014 .44924 L .3812 .44606 L p F P
0 g
s
.701 .382 .434 r
.3812 .44606 m .37287 .44543 L .37495 .44885 L p F P
0 g
s
.652 .763 .93 r
.45145 .36768 m .44213 .37073 L .4395 .368 L p F P
0 g
s
.664 .745 .91 r
.44213 .37073 m .45145 .36768 L .45406 .37045 L p F P
0 g
s
.624 .474 .658 r
.55945 .40208 m .55841 .39677 L .54854 .39956 L p F P
0 g
s
.624 .474 .658 r
.54854 .39956 m .54956 .40485 L .55945 .40208 L p F P
0 g
s
.629 .322 .431 r
.4639 .445 m .45389 .4458 L .45307 .44911 L p F P
0 g
s
.638 .331 .434 r
.45279 .44913 m .45307 .44911 L .45389 .4458 L p F P
0 g
s
.667 .74 .905 r
.45406 .37045 m .46341 .36732 L .466 .37018 L p F P
0 g
s
.657 .759 .925 r
.46341 .36732 m .45406 .37045 L .45145 .36768 L p F P
0 g
s
.608 .395 .566 r
.54078 .42116 m .54063 .41689 L .53046 .41927 L p F P
0 g
s
.608 .395 .566 r
.53046 .41927 m .53059 .42353 L .54078 .42116 L p F P
0 g
s
.666 .632 .806 r
.52826 .37447 m .53772 .37081 L .54023 .37565 L p F P
0 g
s
.671 .651 .822 r
.52645 .37129 m .52826 .37447 L .53772 .37081 L p F P
0 g
s
.729 .428 .47 r
.34094 .442 m .3469 .44276 L .34558 .4391 L p F P
0 g
s
.729 .428 .47 r
.34558 .4391 m .34187 .43863 L .34094 .442 L p F P
0 g
s
.658 .594 .772 r
.55221 .37743 m .55189 .37668 L .54198 .37945 L p F P
0 g
s
.66 .608 .785 r
.54023 .37565 m .54198 .37945 L .55189 .37668 L p F P
0 g
s
.767 .527 .57 r
.2991 .42322 m .29977 .42336 L .30024 .41912 L p F P
0 g
s
.767 .527 .57 r
.30024 .41912 m .29917 .4189 L .2991 .42322 L p F P
0 g
s
.613 .377 .535 r
.51507 .43072 m .52018 .42973 L .52028 .42573 L p F P
0 g
s
.605 .37 .534 r
.5305 .42754 m .53059 .42353 L .52028 .42573 L p F P
0 g
s
.605 .37 .534 r
.52028 .42573 m .52018 .42973 L .5305 .42754 L p F P
0 g
s
.669 .733 .897 r
.466 .37018 m .47537 .36697 L .47794 .36993 L p F P
0 g
s
.662 .753 .918 r
.47537 .36697 m .466 .37018 L .46341 .36732 L p F P
0 g
s
.741 .663 .773 r
.28825 .37911 m .28587 .37853 L .28684 .38023 L closepath p F P
0 g
s
.755 .664 .76 r
.28118 .38568 m .28684 .38023 L .28587 .37853 L p F P
0 g
s
.611 .329 .465 r
.49534 .43778 m .48794 .43884 L .48738 .44238 L p F P
0 g
s
.611 .42 .598 r
.55048 .41216 m .55026 .40976 L .54023 .41233 L p F P
0 g
s
.611 .42 .598 r
.54776 .41507 m .55048 .41216 L p .54023 .41233 L F P
0 g
s
.611 .42 .598 r
.54023 .41233 m .54063 .41689 L .54776 .41507 L p F P
0 g
s
.702 .382 .433 r
.36704 .44823 m .37495 .44885 L .37287 .44543 L p F P
0 g
s
.702 .382 .433 r
.37287 .44543 m .36813 .44506 L .36704 .44823 L p F P
0 g
s
.776 .534 .57 r
.29303 .42177 m .2991 .42322 L .29917 .4189 L p F P
0 g
s
.776 .534 .57 r
.29917 .4189 m .2935 .41754 L .29303 .42177 L p F P
0 g
s
.648 .557 .738 r
.55474 .38391 m .5503 .38575 L .55492 .38443 L closepath p F P
0 g
s
.737 .669 .784 r
.28825 .37911 m .29613 .37342 L p .28409 .37557 L F P
0 g
s
.737 .669 .784 r
.28409 .37557 m .28587 .37853 L .28825 .37911 L p F P
0 g
s
.776 .614 .68 r
.27997 .397 m .27905 .39853 L .2806 .39897 L closepath p F P
0 g
s
.78 .601 .658 r
.27665 .40343 m .28214 .40498 L .2806 .39897 L p F P
0 g
s
.78 .601 .658 r
.2806 .39897 m .27905 .39853 L .27665 .40343 L p F P
0 g
s
.776 .622 .688 r
.27905 .39853 m .27997 .397 L .27824 .39209 L p F P
0 g
s
.755 .664 .76 r
.27472 .38398 m .28118 .38568 L p .28587 .37853 L F P
0 g
s
.76 .638 .726 r
.28118 .38568 m .27472 .38398 L .27737 .38995 L closepath p F P
0 g
s
.666 .745 .909 r
.48733 .36664 m .47794 .36993 L .47537 .36697 L p F P
0 g
s
.672 .723 .888 r
.47794 .36993 m .48733 .36664 L .48989 .36975 L p F P
0 g
s
.738 .437 .472 r
.33875 .44168 m .34094 .442 L .34187 .43863 L p F P
0 g
s
.738 .437 .472 r
.34187 .43863 m .33754 .43799 L .33875 .44168 L p F P
0 g
s
.681 .727 .884 r
.33204 .37019 m .34122 .36663 L .34398 .36973 L p F P
0 g
s
.669 .737 .901 r
.34122 .36663 m .33204 .37019 L .32928 .36692 L p F P
0 g
s
.693 .719 .869 r
.32009 .37089 m .32928 .36692 L .33204 .37019 L p F P
0 g
s
.682 .728 .885 r
.32928 .36692 m .32009 .37089 L .31732 .36742 L p F P
0 g
s
.71 .69 .829 r
.32009 .37089 m .31732 .36742 L .30813 .3719 L p F P
0 g
s
.722 .694 .823 r
.30813 .3719 m .30783 .37207 L .30835 .37221 L closepath p F P
0 g
s
.771 .634 .709 r
.27737 .38995 m .27621 .39149 L .27824 .39209 L closepath p F P
0 g
s
.776 .622 .688 r
.27285 .39673 m .27905 .39853 L p .27824 .39209 L F P
0 g
s
.776 .622 .688 r
.27824 .39209 m .27621 .39149 L .27285 .39673 L p F P
0 g
s
.711 .392 .436 r
.36582 .44812 m .36704 .44823 L .36813 .44506 L p F P
0 g
s
.711 .392 .436 r
.36813 .44506 m .36389 .44465 L .36582 .44812 L p F P
0 g
s
.671 .735 .898 r
.34398 .36973 m .35316 .36647 L .35591 .36941 L p F P
0 g
s
.657 .745 .914 r
.35316 .36647 m .34398 .36973 L .34122 .36663 L p F P
0 g
s
.673 .711 .876 r
.48989 .36975 m .49929 .36637 L .50184 .36968 L p F P
0 g
s
.669 .734 .898 r
.49929 .36637 m .48989 .36975 L .48733 .36664 L p F P
0 g
s
.627 .319 .43 r
.46524 .44489 m .465 .44589 L .4639 .445 L closepath p F P
0 g
s
.629 .322 .431 r
.46443 .44819 m .465 .44589 L .4639 .445 L p F P
0 g
s
.629 .322 .431 r
.45307 .44911 m .46443 .44819 L p .4639 .445 L F P
0 g
s
.603 .345 .499 r
.51507 .43072 m .50971 .43172 L .50938 .43548 L p F P
0 g
s
.716 .701 .835 r
.30783 .37207 m .30813 .3719 L .30535 .36821 L p F P
0 g
s
.716 .701 .835 r
.30535 .36821 m .30157 .37028 L .30783 .37207 L p F P
0 g
s
.722 .677 .805 r
.29613 .37342 m .30157 .37028 L .30783 .37207 L p F P
0 g
s
.774 .579 .635 r
.28296 .40519 m .28214 .40498 L .28242 .40654 L closepath p F P
0 g
s
.781 .605 .661 r
.27036 .40166 m .27665 .40343 L .27905 .39853 L p F P
0 g
s
.781 .605 .661 r
.27905 .39853 m .27285 .39673 L .27036 .40166 L p F P
0 g
s
.696 .72 .868 r
.31732 .36742 m .30813 .3719 L .30535 .36821 L p F P
0 g
s
.752 .47 .504 r
.31469 .4342 m .32214 .43553 L .32149 .43166 L p F P
0 g
s
.752 .47 .504 r
.32149 .43166 m .31402 .43034 L .31469 .4342 L p F P
0 g
s
.619 .312 .427 r
.47561 .44705 m .4764 .44374 L .46524 .44489 L p F P
0 g
s
.619 .312 .427 r
.46774 .44787 m .47561 .44705 L p .46524 .44489 L F P
0 g
s
.619 .312 .427 r
.46524 .44489 m .465 .44589 L .46774 .44787 L p F P
0 g
s
.771 .642 .719 r
.27621 .39149 m .27737 .38995 L .27472 .38398 L p F P
0 g
s
.755 .664 .76 r
.2747 .38395 m .27472 .38398 L p .28587 .37853 L F P
0 g
s
.755 .664 .76 r
.28587 .37853 m .28193 .37733 L .2747 .38395 L p F P
0 g
s
.748 .673 .777 r
.28409 .37557 m .28193 .37733 L .28587 .37853 L closepath p F P
0 g
s
.662 .742 .909 r
.35591 .36941 m .36511 .36639 L .36784 .3692 L p F P
0 g
s
.647 .752 .926 r
.36511 .36639 m .35591 .36941 L .35316 .36647 L p F P
0 g
s
.783 .584 .63 r
.28127 .40984 m .28242 .40654 L .28214 .40498 L p F P
0 g
s
.783 .584 .63 r
.27496 .40808 m .28127 .40984 L p .28214 .40498 L F P
0 g
s
.783 .584 .63 r
.28214 .40498 m .27665 .40343 L .27496 .40808 L p F P
0 g
s
.765 .503 .538 r
.29986 .42741 m .30695 .42887 L .30686 .42482 L p F P
0 g
s
.765 .503 .538 r
.30686 .42482 m .29977 .42336 L .29986 .42741 L p F P
0 g
s
.711 .389 .431 r
.35714 .44723 m .36582 .44812 L .36389 .44465 L p F P
0 g
s
.711 .389 .431 r
.36389 .44465 m .35517 .44379 L .35714 .44723 L p F P
0 g
s
.674 .697 .863 r
.50184 .36968 m .51126 .36623 L .51379 .36978 L p F P
0 g
s
.672 .72 .885 r
.51126 .36623 m .50184 .36968 L .49929 .36637 L p F P
0 g
s
.66 .608 .785 r
.55189 .37668 m .5497 .37201 L .54023 .37565 L p F P
0 g
s
.664 .635 .81 r
.5497 .37201 m .54023 .37565 L .53772 .37081 L p F P
0 g
s
.775 .555 .601 r
.2834 .41511 m .28679 .41593 L .28787 .41149 L p F P
0 g
s
.775 .555 .601 r
.28787 .41149 m .28303 .41031 L .2834 .41511 L p F P
0 g
s
.615 .445 .629 r
.55993 .40533 m .55945 .40208 L .54956 .40485 L p F P
0 g
s
.615 .445 .629 r
.55495 .40845 m .55993 .40533 L p .54956 .40485 L F P
0 g
s
.615 .445 .629 r
.54956 .40485 m .55026 .40976 L .55495 .40845 L p F P
0 g
s
.739 .436 .469 r
.33093 .44049 m .33875 .44168 L .33754 .43799 L p F P
0 g
s
.739 .436 .469 r
.33754 .43799 m .32969 .43682 L .33093 .44049 L p F P
0 g
s
.757 .496 .538 r
.31398 .42877 m .31402 .43034 L .31382 .4303 L closepath p F P
0 g
s
.655 .748 .918 r
.36784 .3692 m .37705 .36634 L .37978 .36904 L p F P
0 g
s
.639 .759 .935 r
.37705 .36634 m .36784 .3692 L .36511 .36639 L p F P
0 g
s
.683 .366 .433 r
.39331 .44876 m .39416 .44997 L .39295 .44993 L closepath p F P
0 g
s
.771 .642 .719 r
.2701 .38964 m .27621 .39149 L p .27472 .38398 L F P
0 g
s
.776 .625 .693 r
.2666 .39493 m .27285 .39673 L .27621 .39149 L p F P
0 g
s
.776 .625 .693 r
.27621 .39149 m .2701 .38964 L .2666 .39493 L p F P
0 g
s
.781 .579 .627 r
.28242 .40654 m .28127 .40984 L .28303 .41031 L closepath p F P
0 g
s
.609 .328 .467 r
.49874 .43727 m .49831 .44014 L .49534 .43778 L closepath p F P
0 g
s
.611 .329 .465 r
.49821 .44082 m .49831 .44014 L .49534 .43778 L p F P
0 g
s
.611 .329 .465 r
.48738 .44238 m .49821 .44082 L p .49534 .43778 L F P
0 g
s
.717 .687 .819 r
.30157 .37028 m .29613 .37342 L .29336 .36941 L p F P
0 g
s
.737 .669 .784 r
.29613 .37342 m .29336 .36941 L .28409 .37557 L p F P
0 g
s
.721 .422 .471 r
.3549 .44309 m .35517 .44379 L .35473 .44374 L closepath p F P
0 g
s
.633 .766 .943 r
.389 .36628 m .37978 .36904 L .37705 .36634 L p F P
0 g
s
.65 .754 .926 r
.37978 .36904 m .389 .36628 L .39171 .36889 L p F P
0 g
s
.67 .658 .829 r
.52575 .37011 m .52645 .37129 L .53649 .3687 L p F P
0 g
s
.671 .651 .822 r
.53772 .37081 m .53649 .3687 L .52645 .37129 L p F P
0 g
s
.672 .68 .849 r
.51379 .36978 m .52323 .36627 L .52575 .37011 L p F P
0 g
s
.672 .704 .871 r
.52323 .36627 m .51379 .36978 L .51126 .36623 L p F P
0 g
s
.643 .554 .739 r
.55474 .38391 m .55492 .38443 L .56465 .38143 L p F P
0 g
s
.639 .535 .721 r
.56672 .388 m .56465 .38143 L .55492 .38443 L p F P
0 g
s
.639 .535 .721 r
.55492 .38443 m .55697 .39097 L .56672 .388 L p F P
0 g
s
.643 .554 .739 r
.56465 .38143 m .56424 .38025 L .55474 .38391 L p F P
0 g
s
.649 .575 .759 r
.56424 .38025 m .55474 .38391 L .55221 .37743 L p F P
0 g
s
.776 .535 .57 r
.28631 .42017 m .29303 .42177 L .2935 .41754 L p F P
0 g
s
.776 .535 .57 r
.2935 .41754 m .28679 .41593 L .28631 .42017 L p F P
0 g
s
.632 .512 .699 r
.56679 .38824 m .56672 .388 L .55697 .39097 L p F P
0 g
s
.632 .512 .699 r
.55697 .39097 m .55729 .39217 L .56679 .38824 L p F P
0 g
s
.602 .345 .501 r
.52018 .42973 m .51507 .43072 L .51815 .43385 L p F P
0 g
s
.603 .345 .499 r
.50938 .43548 m .51815 .43385 L .51507 .43072 L p F P
0 g
s
.647 .759 .931 r
.39171 .36889 m .40096 .36619 L .40365 .36873 L p F P
0 g
s
.629 .772 .949 r
.40096 .36619 m .39171 .36889 L .389 .36628 L p F P
0 g
s
.601 .321 .465 r
.50885 .43903 m .50938 .43548 L .49874 .43727 L p F P
0 g
s
.601 .321 .465 r
.4991 .44068 m .50885 .43903 L p .49874 .43727 L F P
0 g
s
.601 .321 .465 r
.49874 .43727 m .49831 .44014 L .4991 .44068 L p F P
0 g
s
.627 .498 .686 r
.56816 .39379 m .56679 .38824 L .55729 .39217 L p F P
0 g
s
.627 .498 .686 r
.55729 .39217 m .55841 .39677 L .56816 .39379 L p F P
0 g
s
.619 .311 .427 r
.465 .44589 m .46774 .44787 L .46443 .44819 L closepath p F P
0 g
s
.713 .39 .429 r
.35357 .44686 m .35714 .44723 L .35517 .44379 L p F P
0 g
s
.713 .39 .429 r
.35517 .44379 m .35473 .44374 L .35357 .44686 L p F P
0 g
s
.648 .312 .389 r
.42701 .45026 m .4177 .45039 L .41711 .45196 L p F P
0 g
s
.658 .322 .393 r
.4177 .45039 m .41711 .45196 L .41543 .45038 L closepath p F P
0 g
s
.659 .32 .388 r
.41656 .45342 m .41711 .45196 L .41543 .45038 L p F P
0 g
s
.659 .32 .388 r
.40767 .45334 m .41656 .45342 L p .41543 .45038 L F P
0 g
s
.659 .32 .388 r
.40519 .45099 m .40767 .45334 L p .41543 .45038 L F P
0 g
s
.659 .32 .388 r
.41543 .45038 m .40546 .4503 L .40519 .45099 L p F P
0 g
s
.608 .302 .426 r
.48018 .44328 m .4764 .44374 L .47561 .44705 L p F P
0 g
s
.723 .4 .433 r
.34872 .44625 m .35357 .44686 L .35473 .44374 L p F P
0 g
s
.723 .4 .433 r
.35473 .44374 m .3469 .44276 L .34872 .44625 L p F P
0 g
s
.668 .33 .392 r
.40546 .4503 m .40519 .45099 L .40449 .45028 L closepath p F P
0 g
s
.765 .651 .736 r
.2747 .38395 m .27468 .38397 L .27472 .38398 L closepath p F P
0 g
s
.771 .642 .719 r
.27472 .38398 m .27468 .38397 L .2701 .38964 L p F P
0 g
s
.75 .653 .754 r
.28193 .37733 m .2747 .38395 L .27198 .37872 L p F P
0 g
s
.764 .658 .746 r
.27468 .38397 m .2747 .38395 L .27198 .37872 L p F P
0 g
s
.764 .658 .746 r
.27198 .37872 m .26874 .38206 L .27468 .38397 L p F P
0 g
s
.771 .647 .725 r
.26392 .38782 m .2701 .38964 L .27468 .38397 L p F P
0 g
s
.771 .647 .725 r
.27468 .38397 m .26874 .38206 L .26392 .38782 L p F P
0 g
s
.75 .653 .754 r
.27198 .37872 m .27577 .3755 L .28193 .37733 L p F P
0 g
s
.743 .677 .786 r
.28193 .37733 m .28409 .37557 L .28133 .37124 L p F P
0 g
s
.743 .677 .786 r
.28133 .37124 m .27577 .3755 L .28193 .37733 L p F P
0 g
s
.669 .33 .391 r
.39718 .45309 m .39416 .44997 L .40449 .45028 L p F P
0 g
s
.669 .33 .391 r
.40426 .4533 m .39718 .45309 L p .40449 .45028 L F P
0 g
s
.669 .33 .391 r
.40449 .45028 m .40519 .45099 L .40426 .4533 L p F P
0 g
s
.646 .762 .934 r
.40365 .36873 m .41292 .36604 L .4156 .36853 L p F P
0 g
s
.628 .776 .952 r
.41292 .36604 m .40365 .36873 L .40096 .36619 L p F P
0 g
s
.648 .312 .389 r
.4286 .45326 m .42906 .452 L .42701 .45026 L p F P
0 g
s
.648 .312 .389 r
.41876 .4534 m .4286 .45326 L p .42701 .45026 L F P
0 g
s
.648 .312 .389 r
.41711 .45196 m .41876 .4534 L p .42701 .45026 L F P
0 g
s
.647 .313 .393 r
.42971 .45021 m .42906 .452 L .42701 .45026 L closepath p F P
0 g
s
.67 .658 .829 r
.53649 .3687 m .53521 .36658 L .52575 .37011 L p F P
0 g
s
.671 .685 .854 r
.53521 .36658 m .52575 .37011 L .52323 .36627 L p F P
0 g
s
.755 .472 .503 r
.31307 .4339 m .31469 .4342 L .31402 .43034 L p F P
0 g
s
.755 .472 .503 r
.31402 .43034 m .31382 .4303 L .31307 .4339 L p F P
0 g
s
.637 .303 .389 r
.4394 .44986 m .42971 .45021 L .42906 .452 L p F P
0 g
s
.764 .481 .505 r
.30754 .43276 m .31307 .4339 L .31382 .4303 L p F P
0 g
s
.764 .481 .505 r
.31382 .4303 m .30695 .42887 L .30754 .43276 L p F P
0 g
s
.728 .698 .822 r
.28409 .37557 m .29336 .36941 L .2925 .36824 L p F P
0 g
s
.728 .698 .822 r
.28133 .37124 m .28409 .37557 L p .2925 .36824 L F P
0 g
s
.784 .562 .599 r
.28026 .41426 m .2834 .41511 L .28303 .41031 L p F P
0 g
s
.784 .562 .599 r
.28303 .41031 m .28127 .40984 L .28026 .41426 L p F P
0 g
s
.74 .437 .468 r
.32672 .43984 m .33093 .44049 L .32969 .43682 L p F P
0 g
s
.74 .437 .468 r
.32969 .43682 m .32771 .43651 L .32672 .43984 L p F P
0 g
s
.596 .362 .533 r
.5407 .42517 m .54078 .42116 L .53059 .42353 L p F P
0 g
s
.596 .362 .533 r
.53059 .42353 m .5305 .42754 L .5407 .42517 L p F P
0 g
s
.6 .388 .566 r
.54776 .41507 m .54063 .41689 L .54078 .42116 L p F P
0 g
s
.646 .764 .935 r
.4156 .36853 m .42488 .36582 L .42754 .36829 L p F P
0 g
s
.629 .78 .953 r
.42488 .36582 m .4156 .36853 L .41292 .36604 L p F P
0 g
s
.671 .331 .388 r
.39171 .4529 m .39718 .45309 L .39416 .44997 L p F P
0 g
s
.671 .331 .388 r
.39416 .44997 m .39295 .44993 L .39171 .4529 L p F P
0 g
s
.681 .341 .393 r
.38717 .45266 m .39171 .4529 L .39295 .44993 L p F P
0 g
s
.681 .341 .393 r
.39295 .44993 m .38437 .44947 L .38717 .45266 L p F P
0 g
s
.606 .303 .429 r
.48738 .44238 m .48018 .44328 L .48456 .44597 L p F P
0 g
s
.608 .302 .426 r
.47561 .44705 m .48456 .44597 L .48018 .44328 L p F P
0 g
s
.767 .505 .538 r
.29866 .42715 m .29986 .42741 L .29977 .42336 L p F P
0 g
s
.767 .505 .538 r
.29977 .42336 m .2991 .42322 L .29866 .42715 L p F P
0 g
s
.707 .702 .842 r
.30157 .37028 m .30535 .36821 L .30256 .36471 L p F P
0 g
s
.707 .702 .842 r
.30256 .36471 m .29471 .36869 L .30157 .37028 L p F P
0 g
s
.717 .687 .819 r
.29336 .36941 m .29471 .36869 L .30157 .37028 L p F P
0 g
s
.636 .303 .391 r
.44149 .44978 m .44103 .4511 L .4394 .44986 L closepath p F P
0 g
s
.637 .303 .389 r
.44042 .45285 m .44103 .4511 L .4394 .44986 L p F P
0 g
s
.637 .303 .389 r
.43059 .4532 m .44042 .45285 L p .4394 .44986 L F P
0 g
s
.637 .303 .389 r
.42906 .452 m .43059 .4532 L p .4394 .44986 L F P
0 g
s
.783 .585 .632 r
.26862 .40632 m .27496 .40808 L .27665 .40343 L p F P
0 g
s
.783 .585 .632 r
.27665 .40343 m .27036 .40166 L .26862 .40632 L p F P
0 g
s
.618 .471 .66 r
.56921 .39912 m .56816 .39379 L .55841 .39677 L p F P
0 g
s
.618 .471 .66 r
.55841 .39677 m .55945 .40208 L .56921 .39912 L p F P
0 g
s
.649 .575 .759 r
.55221 .37743 m .56171 .37385 L .56424 .38025 L p F P
0 g
s
.654 .595 .776 r
.55189 .37668 m .55221 .37743 L .56171 .37385 L p F P
0 g
s
.779 .606 .665 r
.2655 .40029 m .27036 .40166 L .27285 .39673 L p F P
0 g
s
.779 .606 .665 r
.26494 .39808 m .2655 .40029 L p .27285 .39673 L F P
0 g
s
.779 .606 .665 r
.27285 .39673 m .2666 .39493 L .26494 .39808 L p F P
0 g
s
.626 .293 .387 r
.45279 .44913 m .44149 .44978 L .44103 .4511 L p F P
0 g
s
.749 .446 .471 r
.32328 .43923 m .32672 .43984 L .32771 .43651 L p F P
0 g
s
.749 .446 .471 r
.32771 .43651 m .32214 .43553 L .32328 .43923 L p F P
0 g
s
.776 .513 .538 r
.29309 .42583 m .29866 .42715 L .2991 .42322 L p F P
0 g
s
.776 .513 .538 r
.2991 .42322 m .29303 .42177 L .29309 .42583 L p F P
0 g
s
.649 .764 .934 r
.42754 .36829 m .43685 .36553 L .4395 .368 L p F P
0 g
s
.632 .781 .952 r
.43685 .36553 m .42754 .36829 L .42488 .36582 L p F P
0 g
s
.657 .609 .789 r
.5497 .37201 m .55189 .37668 L .56165 .37371 L p F P
0 g
s
.654 .595 .776 r
.56171 .37385 m .56165 .37371 L .55189 .37668 L p F P
0 g
s
.785 .565 .601 r
.27391 .41251 m .28026 .41426 L .28127 .40984 L p F P
0 g
s
.785 .565 .601 r
.28127 .40984 m .27496 .40808 L .27391 .41251 L p F P
0 g
s
.602 .345 .501 r
.51815 .43385 m .51988 .43351 L .52018 .42973 L p F P
0 g
s
.592 .337 .499 r
.53021 .43132 m .5305 .42754 L .52018 .42973 L p F P
0 g
s
.592 .337 .499 r
.52018 .42973 m .51988 .43351 L .53021 .43132 L p F P
0 g
s
.604 .415 .599 r
.55495 .40845 m .55026 .40976 L .55048 .41216 L closepath p F P
0 g
s
.652 .763 .93 r
.4395 .368 m .44883 .36517 L .45145 .36768 L p F P
0 g
s
.638 .78 .949 r
.44883 .36517 m .4395 .368 L .43685 .36553 L p F P
0 g
s
.661 .322 .388 r
.40519 .45099 m .40767 .45334 L .40426 .4533 L closepath p F P
0 g
s
.682 .341 .391 r
.37887 .45219 m .38717 .45266 L .38437 .44947 L p F P
0 g
s
.682 .341 .391 r
.38437 .44947 m .38014 .44924 L .37887 .45219 L p F P
0 g
s
.664 .635 .81 r
.53772 .37081 m .5472 .36726 L .5497 .37201 L p F P
0 g
s
.669 .655 .828 r
.53649 .3687 m .53772 .37081 L .5472 .36726 L p F P
0 g
s
.723 .399 .431 r
.34049 .4452 m .34872 .44625 L .3469 .44276 L p F P
0 g
s
.723 .399 .431 r
.34004 .44433 m .34049 .4452 L p .3469 .44276 L F P
0 g
s
.723 .399 .431 r
.3469 .44276 m .34094 .442 L .34004 .44433 L p F P
0 g
s
.774 .628 .699 r
.26383 .39413 m .2666 .39493 L .2701 .38964 L p F P
0 g
s
.774 .628 .699 r
.2624 .38999 m .26383 .39413 L p .2701 .38964 L F P
0 g
s
.774 .628 .699 r
.2701 .38964 m .26392 .38782 L .2624 .38999 L p F P
0 g
s
.657 .759 .925 r
.45145 .36768 m .4608 .36476 L .46341 .36732 L p F P
0 g
s
.644 .778 .945 r
.4608 .36476 m .45145 .36768 L .44883 .36517 L p F P
0 g
s
.692 .352 .395 r
.37755 .4521 m .37887 .45219 L .38014 .44924 L p F P
0 g
s
.692 .352 .395 r
.38014 .44924 m .37495 .44885 L .37755 .4521 L p F P
0 g
s
.624 .291 .387 r
.45307 .44911 m .45301 .44927 L .45279 .44913 L closepath p F P
0 g
s
.626 .293 .387 r
.45202 .45218 m .45301 .44927 L .45279 .44913 L p F P
0 g
s
.626 .293 .387 r
.44334 .45269 m .45202 .45218 L p .45279 .44913 L F P
0 g
s
.626 .293 .387 r
.44103 .4511 m .44334 .45269 L p .45279 .44913 L F P
0 g
s
.662 .753 .918 r
.46341 .36732 m .47278 .3643 L .47537 .36697 L p F P
0 g
s
.651 .773 .938 r
.47278 .3643 m .46341 .36732 L .4608 .36476 L p F P
0 g
s
.615 .283 .384 r
.46342 .45129 m .46443 .44819 L .45307 .44911 L p F P
0 g
s
.615 .283 .384 r
.45725 .45179 m .46342 .45129 L p .45307 .44911 L F P
0 g
s
.615 .283 .384 r
.45307 .44911 m .45301 .44927 L .45725 .45179 L p F P
0 g
s
.777 .535 .57 r
.28333 .41944 m .28631 .42017 L .28679 .41593 L p F P
0 g
s
.777 .535 .57 r
.28679 .41593 m .2834 .41511 L .28333 .41944 L p F P
0 g
s
.682 .728 .885 r
.31732 .36742 m .32649 .36383 L .32928 .36692 L p F P
0 g
s
.67 .737 .9 r
.32649 .36383 m .31732 .36742 L .31453 .36413 L p F P
0 g
s
.696 .72 .868 r
.30535 .36821 m .31453 .36413 L .31732 .36742 L p F P
0 g
s
.596 .293 .426 r
.49746 .44414 m .49821 .44082 L .48738 .44238 L p F P
0 g
s
.596 .293 .426 r
.48738 .44238 m .48663 .44571 L .49746 .44414 L p F P
0 g
s
.606 .303 .429 r
.48456 .44597 m .48663 .44571 L .48738 .44238 L p F P
0 g
s
.685 .728 .882 r
.31453 .36413 m .30535 .36821 L .30256 .36471 L p F P
0 g
s
.669 .737 .901 r
.32928 .36692 m .33845 .36371 L .34122 .36663 L p F P
0 g
s
.655 .745 .916 r
.33845 .36371 m .32928 .36692 L .32649 .36383 L p F P
0 g
s
.666 .745 .909 r
.47537 .36697 m .48476 .36384 L .48733 .36664 L p F P
0 g
s
.658 .766 .929 r
.48476 .36384 m .47537 .36697 L .47278 .3643 L p F P
0 g
s
.616 .283 .383 r
.45301 .44927 m .45725 .45179 L .45202 .45218 L closepath p F P
0 g
s
.692 .347 .388 r
.3684 .45137 m .37755 .4521 L .37495 .44885 L p F P
0 g
s
.692 .347 .388 r
.36661 .44916 m .3684 .45137 L p .37495 .44885 L F P
0 g
s
.692 .347 .388 r
.37495 .44885 m .36704 .44823 L .36661 .44916 L p F P
0 g
s
.749 .445 .468 r
.31585 .43789 m .32328 .43923 L .32214 .43553 L p F P
0 g
s
.749 .445 .468 r
.32214 .43553 m .31469 .4342 L .31585 .43789 L p F P
0 g
s
.763 .479 .504 r
.30048 .43129 m .30754 .43276 L .30695 .42887 L p F P
0 g
s
.763 .479 .504 r
.30695 .42887 m .29986 .42741 L .30048 .43129 L p F P
0 g
s
.59 .311 .462 r
.51815 .43385 m .50938 .43548 L .50885 .43903 L p F P
0 g
s
.641 .753 .93 r
.3504 .36371 m .34122 .36663 L .33845 .36371 L p F P
0 g
s
.657 .745 .914 r
.34122 .36663 m .3504 .36371 L .35316 .36647 L p F P
0 g
s
.669 .734 .898 r
.48733 .36664 m .49674 .36341 L .49929 .36637 L p F P
0 g
s
.664 .756 .919 r
.49674 .36341 m .48733 .36664 L .48476 .36384 L p F P
0 g
s
.71 .695 .833 r
.29471 .36869 m .2925 .36824 L .29336 .36941 L closepath p F P
0 g
s
.748 .664 .767 r
.27577 .3755 m .27198 .37872 L .26924 .37385 L p F P
0 g
s
.76 .661 .753 r
.26874 .38206 m .27198 .37872 L .26924 .37385 L p F P
0 g
s
.732 .409 .434 r
.34094 .442 m .34004 .44433 L .33875 .44168 L closepath p F P
0 g
s
.608 .442 .631 r
.56942 .40054 m .56921 .39912 L .55945 .40208 L p F P
0 g
s
.608 .442 .631 r
.55945 .40208 m .55993 .40533 L .56942 .40054 L p F P
0 g
s
.651 .314 .389 r
.41711 .45196 m .41876 .4534 L .41656 .45342 L closepath p F P
0 g
s
.602 .412 .597 r
.55048 .41216 m .55067 .41432 L p .56015 .40698 L F P
0 g
s
.602 .412 .597 r
.56015 .40698 m .55495 .40845 L .55048 .41216 L p F P
0 g
s
.609 .416 .595 r
.55048 .41216 m .54776 .41507 L .55067 .41432 L closepath p F P
0 g
s
.737 .678 .793 r
.27577 .3755 m .28133 .37124 L .27854 .36715 L p F P
0 g
s
.737 .678 .793 r
.27854 .36715 m .26938 .37373 L .27577 .3755 L p F P
0 g
s
.748 .664 .767 r
.26924 .37385 m .26938 .37373 L .27577 .3755 L p F P
0 g
s
.672 .72 .885 r
.49929 .36637 m .50872 .36306 L .51126 .36623 L p F P
0 g
s
.668 .743 .906 r
.50872 .36306 m .49929 .36637 L .49674 .36341 L p F P
0 g
s
.647 .752 .926 r
.35316 .36647 m .36235 .36377 L .36511 .36639 L p F P
0 g
s
.63 .761 .942 r
.36235 .36377 m .35316 .36647 L .3504 .36371 L p F P
0 g
s
.76 .661 .753 r
.26924 .37385 m .26271 .38017 L .26874 .38206 L p F P
0 g
s
.767 .649 .731 r
.26127 .38703 m .26392 .38782 L .26874 .38206 L p F P
0 g
s
.767 .649 .731 r
.25975 .38352 m .26127 .38703 L p .26874 .38206 L F P
0 g
s
.767 .649 .731 r
.26874 .38206 m .26271 .38017 L .25975 .38352 L p F P
0 g
s
.669 .662 .834 r
.53521 .36658 m .53649 .3687 L .54641 .36593 L p F P
0 g
s
.669 .655 .828 r
.5472 .36726 m .54641 .36593 L .53649 .3687 L p F P
0 g
s
.708 .698 .838 r
.29471 .36869 m .30256 .36471 L p .29057 .36565 L F P
0 g
s
.708 .698 .838 r
.29057 .36565 m .2925 .36824 L .29471 .36869 L p F P
0 g
s
.776 .513 .538 r
.28638 .42422 m .29309 .42583 L .29303 .42177 L p F P
0 g
s
.776 .513 .538 r
.29303 .42177 m .28631 .42017 L .28638 .42422 L p F P
0 g
s
.732 .41 .434 r
.33265 .44401 m .33093 .44049 L .33875 .44168 L p F P
0 g
s
.732 .41 .434 r
.33974 .4451 m .33265 .44401 L p .33875 .44168 L F P
0 g
s
.732 .41 .434 r
.33875 .44168 m .34004 .44433 L .33974 .4451 L p F P
0 g
s
.657 .609 .789 r
.56165 .37371 m .55921 .36851 L .5497 .37201 L p F P
0 g
s
.662 .636 .813 r
.55921 .36851 m .5497 .37201 L .5472 .36726 L p F P
0 g
s
.785 .542 .57 r
.27979 .41849 m .28333 .41944 L .2834 .41511 L p F P
0 g
s
.785 .542 .57 r
.2834 .41511 m .28026 .41426 L .27979 .41849 L p F P
0 g
s
.611 .439 .624 r
.55993 .40533 m .55495 .40845 L .56015 .40698 L closepath p F P
0 g
s
.598 .386 .565 r
.55067 .41432 m .54776 .41507 L .54616 .41979 L p F P
0 g
s
.6 .388 .566 r
.54078 .42116 m .54616 .41979 L .54776 .41507 L p F P
0 g
s
.628 .294 .387 r
.44103 .4511 m .44334 .45269 L .44042 .45285 L closepath p F P
0 g
s
.702 .358 .392 r
.36704 .44823 m .36661 .44916 L .36582 .44812 L closepath p F P
0 g
s
.604 .274 .384 r
.46774 .44787 m .46443 .44819 L .46342 .45129 L p F P
0 g
s
.672 .704 .871 r
.51126 .36623 m .52071 .36284 L .52323 .36627 L p F P
0 g
s
.671 .727 .892 r
.52071 .36284 m .51126 .36623 L .50872 .36306 L p F P
0 g
s
.783 .585 .632 r
.26646 .40572 m .26862 .40632 L .27036 .40166 L p F P
0 g
s
.783 .585 .632 r
.27036 .40166 m .2655 .40029 L .26646 .40572 L p F P
0 g
s
.702 .358 .392 r
.3596 .45052 m .35714 .44723 L .36582 .44812 L p F P
0 g
s
.702 .358 .392 r
.36569 .45114 m .3596 .45052 L p .36582 .44812 L F P
0 g
s
.702 .358 .392 r
.36582 .44812 m .36661 .44916 L .36569 .45114 L p F P
0 g
s
.64 .305 .389 r
.42906 .452 m .43059 .4532 L .4286 .45326 L closepath p F P
0 g
s
.639 .759 .935 r
.36511 .36639 m .37431 .36383 L .37705 .36634 L p F P
0 g
s
.619 .77 .953 r
.37431 .36383 m .36511 .36639 L .36235 .36377 L p F P
0 g
s
.601 .321 .464 r
.49831 .44014 m .4991 .44068 L .49821 .44082 L closepath p F P
0 g
s
.779 .607 .665 r
.2666 .39493 m .26383 .39413 L .26494 .39808 L closepath p F P
0 g
s
.728 .698 .822 r
.2925 .36824 m .28841 .3669 L .28133 .37124 L p F P
0 g
s
.723 .685 .813 r
.28841 .3669 m .28133 .37124 L .27854 .36715 L p F P
0 g
s
.785 .565 .602 r
.26755 .41076 m .27391 .41251 L .27496 .40808 L p F P
0 g
s
.785 .565 .602 r
.27496 .40808 m .26862 .40632 L .26755 .41076 L p F P
0 g
s
.722 .702 .831 r
.29057 .36565 m .28841 .3669 L .2925 .36824 L closepath p F P
0 g
s
.603 .276 .388 r
.47561 .44705 m .46774 .44787 L .47264 .45038 L p F P
0 g
s
.604 .274 .384 r
.46342 .45129 m .47264 .45038 L .46774 .44787 L p F P
0 g
s
.639 .553 .742 r
.56424 .38025 m .56465 .38143 L .57426 .37824 L p F P
0 g
s
.633 .533 .723 r
.57632 .38476 m .57426 .37824 L .56465 .38143 L p F P
0 g
s
.633 .533 .723 r
.57422 .38552 m .57632 .38476 L p .56465 .38143 L F P
0 g
s
.633 .533 .723 r
.56465 .38143 m .56672 .388 L .57422 .38552 L p F P
0 g
s
.672 .709 .876 r
.5327 .36283 m .52323 .36627 L .52071 .36284 L p F P
0 g
s
.671 .685 .854 r
.52323 .36627 m .5327 .36283 L .53521 .36658 L p F P
0 g
s
.626 .51 .702 r
.57422 .38552 m .56672 .388 L .56679 .38824 L closepath p F P
0 g
s
.639 .553 .742 r
.57426 .37824 m .57377 .37684 L .56424 .38025 L p F P
0 g
s
.647 .581 .766 r
.56424 .38025 m .57377 .37684 L .57127 .37051 L p F P
0 g
s
.647 .581 .766 r
.56171 .37385 m .56424 .38025 L p .57127 .37051 L F P
0 g
s
.623 .501 .694 r
.56679 .38824 m .56816 .39379 L p .57634 .38482 L F P
0 g
s
.623 .501 .694 r
.57634 .38482 m .57422 .38552 L .56679 .38824 L p F P
0 g
s
.633 .766 .943 r
.37705 .36634 m .38628 .36388 L .389 .36628 L p F P
0 g
s
.61 .778 .961 r
.38628 .36388 m .37705 .36634 L .37431 .36383 L p F P
0 g
s
.587 .355 .531 r
.54616 .41979 m .54078 .42116 L .5407 .42517 L p F P
0 g
s
.774 .628 .699 r
.26392 .38782 m .26127 .38703 L .2624 .38999 L closepath p F P
0 g
s
.602 .412 .597 r
.55067 .41432 m .56055 .41154 L .56015 .40698 L p F P
0 g
s
.589 .38 .564 r
.56072 .41581 m .56055 .41154 L .55067 .41432 L p F P
0 g
s
.589 .38 .564 r
.55067 .41432 m .55082 .41859 L .56072 .41581 L p F P
0 g
s
.598 .386 .565 r
.54616 .41979 m .55082 .41859 L .55067 .41432 L p F P
0 g
s
.751 .446 .467 r
.31202 .43719 m .31585 .43789 L .31469 .4342 L p F P
0 g
s
.751 .446 .467 r
.31469 .4342 m .31307 .4339 L .31202 .43719 L p F P
0 g
s
.582 .328 .497 r
.54041 .42894 m .5407 .42517 L .5305 .42754 L p F P
0 g
s
.582 .328 .497 r
.5305 .42754 m .53021 .43132 L .54041 .42894 L p F P
0 g
s
.585 .282 .421 r
.4991 .44068 m .49821 .44082 L .49746 .44414 L p F P
0 g
s
.786 .544 .57 r
.27343 .41675 m .27979 .41849 L .28026 .41426 L p F P
0 g
s
.786 .544 .57 r
.28026 .41426 m .27391 .41251 L .27343 .41675 L p F P
0 g
s
.604 .433 .624 r
.5699 .40401 m .56942 .40054 L .55993 .40533 L p F P
0 g
s
.604 .433 .624 r
.55993 .40533 m .56015 .40698 L .5699 .40401 L p F P
0 g
s
.605 .784 .966 r
.39792 .36395 m .389 .36628 L .38628 .36388 L p F P
0 g
s
.629 .772 .949 r
.39837 .36396 m .40096 .36619 L p .389 .36628 L F P
0 g
s
.629 .772 .949 r
.389 .36628 m .39792 .36395 L .39837 .36396 L p F P
0 g
s
.765 .481 .503 r
.29787 .43073 m .30048 .43129 L .29986 .42741 L p F P
0 g
s
.765 .481 .503 r
.29986 .42741 m .29866 .42715 L .29787 .43073 L p F P
0 g
s
.584 .284 .425 r
.50885 .43903 m .4991 .44068 L .50472 .44296 L p F P
0 g
s
.585 .282 .421 r
.49746 .44414 m .50472 .44296 L .4991 .44068 L p F P
0 g
s
.784 .625 .684 r
.2624 .38999 m .26055 .39306 L .26383 .39413 L closepath p F P
0 g
s
.789 .611 .66 r
.26413 .39986 m .26494 .39808 L .26383 .39413 L p F P
0 g
s
.789 .611 .66 r
.2582 .39794 m .26413 .39986 L p .26383 .39413 L F P
0 g
s
.789 .611 .66 r
.26383 .39413 m .26055 .39306 L .2582 .39794 L p F P
0 g
s
.705 .359 .389 r
.35218 .44974 m .3596 .45052 L .35714 .44723 L p F P
0 g
s
.705 .359 .389 r
.35714 .44723 m .35357 .44686 L .35218 .44974 L p F P
0 g
s
.669 .662 .834 r
.54641 .36593 m .5447 .36311 L .53521 .36658 L p F P
0 g
s
.67 .689 .859 r
.5447 .36311 m .53521 .36658 L .5327 .36283 L p F P
0 g
s
.76 .456 .47 r
.3086 .43649 m .31202 .43719 L .31307 .4339 L p F P
0 g
s
.76 .456 .47 r
.31307 .4339 m .30754 .43276 L .3086 .43649 L p F P
0 g
s
.734 .409 .43 r
.32546 .4429 m .33265 .44401 L .33093 .44049 L p F P
0 g
s
.734 .409 .43 r
.33093 .44049 m .32672 .43984 L .32546 .4429 L p F P
0 g
s
.587 .309 .462 r
.51988 .43351 m .51972 .43464 L .51815 .43385 L closepath p F P
0 g
s
.59 .311 .462 r
.51937 .43706 m .51972 .43464 L .51815 .43385 L p F P
0 g
s
.59 .311 .462 r
.50885 .43903 m .51937 .43706 L p .51815 .43385 L F P
0 g
s
.785 .631 .69 r
.26055 .39306 m .2624 .38999 L .26127 .38703 L p F P
0 g
s
.774 .49 .505 r
.29363 .42973 m .29787 .43073 L .29866 .42715 L p F P
0 g
s
.774 .49 .505 r
.29866 .42715 m .29309 .42583 L .29363 .42973 L p F P
0 g
s
.593 .266 .385 r
.48456 .44597 m .47561 .44705 L .47464 .45018 L p F P
0 g
s
.603 .276 .388 r
.47264 .45038 m .47464 .45018 L .47561 .44705 L p F P
0 g
s
.695 .35 .388 r
.36661 .44916 m .3684 .45137 L .36569 .45114 L closepath p F P
0 g
s
.628 .776 .952 r
.4109 .36434 m .41292 .36604 L p .40096 .36619 L F P
0 g
s
.628 .776 .952 r
.40096 .36619 m .40817 .36431 L .4109 .36434 L p F P
0 g
s
.629 .771 .948 r
.40096 .36619 m .40817 .36431 L .39837 .36396 L closepath p F P
0 g
s
.788 .605 .654 r
.26494 .39808 m .26413 .39986 L .2655 .40029 L closepath p F P
0 g
s
.623 .501 .694 r
.56816 .39379 m .57778 .39061 L .57634 .38482 L p F P
0 g
s
.611 .466 .661 r
.57884 .39595 m .57778 .39061 L .56816 .39379 L p F P
0 g
s
.611 .466 .661 r
.56816 .39379 m .56921 .39912 L .57884 .39595 L p F P
0 g
s
.715 .371 .394 r
.35101 .44959 m .35218 .44974 L .35357 .44686 L p F P
0 g
s
.715 .371 .394 r
.35357 .44686 m .34872 .44625 L .35101 .44959 L p F P
0 g
s
.593 .405 .596 r
.57032 .40856 m .5699 .40401 L .56015 .40698 L p F P
0 g
s
.593 .405 .596 r
.56015 .40698 m .56055 .41154 L .57032 .40856 L p F P
0 g
s
.779 .643 .712 r
.25975 .38352 m .25796 .3859 L .26127 .38703 L closepath p F P
0 g
s
.785 .631 .69 r
.25469 .39111 m .26055 .39306 L p .26127 .38703 L F P
0 g
s
.785 .631 .69 r
.26127 .38703 m .25796 .3859 L .25469 .39111 L p F P
0 g
s
.744 .671 .779 r
.26938 .37373 m .26912 .37366 L .26924 .37385 L closepath p F P
0 g
s
.761 .672 .764 r
.26271 .38017 m .26924 .37385 L .26912 .37366 L p F P
0 g
s
.647 .581 .766 r
.57127 .37051 m .56821 .37153 L .56171 .37385 L p F P
0 g
s
.651 .595 .779 r
.56821 .37153 m .56165 .37371 L .56171 .37385 L closepath p F P
0 g
s
.578 .301 .46 r
.52972 .43488 m .53021 .43132 L .51988 .43351 L p F P
0 g
s
.578 .301 .46 r
.52361 .43618 m .52972 .43488 L p .51988 .43351 L F P
0 g
s
.578 .301 .46 r
.51988 .43351 m .51972 .43464 L .52361 .43618 L p F P
0 g
s
.736 .696 .814 r
.26938 .37373 m .27854 .36715 L .27588 .36348 L p F P
0 g
s
.736 .696 .814 r
.26912 .37366 m .26938 .37373 L p .27588 .36348 L F P
0 g
s
.792 .591 .629 r
.26251 .40448 m .26646 .40572 L .2655 .40029 L p F P
0 g
s
.792 .591 .629 r
.2655 .40029 m .26413 .39986 L .26251 .40448 L p F P
0 g
s
.636 .275 .341 r
.41876 .4534 m .41656 .45342 L .4152 .45623 L p F P
0 g
s
.647 .287 .347 r
.4115 .4562 m .4152 .45623 L .41656 .45342 L p F P
0 g
s
.647 .287 .347 r
.41656 .45342 m .40767 .45334 L .4115 .4562 L p F P
0 g
s
.654 .609 .791 r
.55921 .36851 m .56165 .37371 L .56821 .37153 L p F P
0 g
s
.635 .276 .345 r
.4286 .45326 m .41876 .4534 L .42289 .45616 L p F P
0 g
s
.636 .275 .341 r
.4152 .45623 m .42289 .45616 L .41876 .4534 L p F P
0 g
s
.777 .513 .537 r
.28285 .42337 m .28638 .42422 L .28631 .42017 L p F P
0 g
s
.777 .513 .537 r
.28631 .42017 m .28333 .41944 L .28285 .42337 L p F P
0 g
s
.761 .672 .764 r
.2574 .37855 m .26271 .38017 L p .26912 .37366 L F P
0 g
s
.761 .672 .764 r
.25704 .37784 m .2574 .37855 L p .26912 .37366 L F P
0 g
s
.761 .672 .764 r
.26912 .37366 m .26364 .37173 L .25704 .37784 L p F P
0 g
s
.736 .696 .814 r
.26646 .36941 m .26912 .37366 L p .27588 .36348 L F P
0 g
s
.753 .681 .781 r
.26646 .36941 m .26364 .37173 L .26912 .37366 L closepath p F P
0 g
s
.629 .78 .953 r
.42308 .36431 m .42488 .36582 L p .41292 .36604 L F P
0 g
s
.629 .78 .953 r
.41292 .36604 m .41931 .36435 L .42308 .36431 L p F P
0 g
s
.63 .777 .951 r
.41292 .36604 m .41931 .36435 L .4109 .36434 L closepath p F P
0 g
s
.648 .285 .343 r
.40287 .45609 m .4115 .4562 L .40767 .45334 L p F P
0 g
s
.648 .285 .343 r
.40767 .45334 m .40426 .4533 L .40287 .45609 L p F P
0 g
s
.659 .297 .349 r
.40074 .45603 m .40287 .45609 L .40426 .4533 L p F P
0 g
s
.659 .297 .349 r
.40426 .4533 m .39718 .45309 L .40074 .45603 L p F P
0 g
s
.635 .276 .345 r
.42289 .45616 m .42729 .4561 L .4286 .45326 L p F P
0 g
s
.624 .264 .34 r
.43059 .4532 m .4286 .45326 L .42729 .4561 L p F P
0 g
s
.714 .704 .839 r
.28841 .3669 m .29057 .36565 L .28776 .36209 L p F P
0 g
s
.714 .704 .839 r
.28776 .36209 m .28228 .36504 L .28841 .3669 L p F P
0 g
s
.723 .685 .813 r
.27854 .36715 m .28228 .36504 L .28841 .3669 L p F P
0 g
s
.766 .647 .73 r
.26271 .38017 m .2574 .37855 L .25975 .38352 L closepath p F P
0 g
s
.624 .264 .34 r
.42729 .4561 m .43506 .45585 L .43059 .4532 L p F P
0 g
s
.623 .266 .344 r
.44042 .45285 m .43059 .4532 L .43506 .45585 L p F P
0 g
s
.744 .42 .434 r
.32487 .4428 m .32546 .4429 L .32672 .43984 L p F P
0 g
s
.744 .42 .434 r
.32672 .43984 m .32328 .43923 L .32487 .4428 L p F P
0 g
s
.632 .781 .952 r
.43496 .36394 m .43685 .36553 L p .42488 .36582 L F P
0 g
s
.632 .781 .952 r
.42488 .36582 m .43141 .36406 L .43496 .36394 L p F P
0 g
s
.632 .78 .952 r
.42488 .36582 m .43141 .36406 L .42308 .36431 L closepath p F P
0 g
s
.659 .296 .345 r
.3905 .45568 m .40074 .45603 L .39718 .45309 L p F P
0 g
s
.659 .296 .345 r
.39033 .45554 m .3905 .45568 L p .39718 .45309 L F P
0 g
s
.659 .296 .345 r
.39718 .45309 m .39171 .4529 L .39033 .45554 L p F P
0 g
s
.662 .636 .813 r
.5472 .36726 m .55671 .36381 L .55921 .36851 L p F P
0 g
s
.667 .658 .832 r
.54641 .36593 m .5472 .36726 L .55671 .36381 L p F P
0 g
s
.585 .354 .532 r
.55082 .41859 m .54616 .41979 L .54842 .42321 L p F P
0 g
s
.587 .355 .531 r
.5407 .42517 m .54842 .42321 L .54616 .41979 L p F P
0 g
s
.793 .594 .632 r
.25653 .40258 m .26251 .40448 L .26413 .39986 L p F P
0 g
s
.793 .594 .632 r
.26413 .39986 m .2582 .39794 L .25653 .40258 L p F P
0 g
s
.685 .728 .882 r
.30256 .36471 m .31173 .36101 L .31453 .36413 L p F P
0 g
s
.673 .735 .897 r
.31173 .36101 m .30256 .36471 L .29975 .36138 L p F P
0 g
s
.708 .698 .838 r
.30256 .36471 m .29975 .36138 L .29057 .36565 L p F P
0 g
s
.67 .737 .9 r
.31453 .36413 m .32369 .3609 L .32649 .36383 L p F P
0 g
s
.656 .744 .915 r
.32369 .3609 m .31453 .36413 L .31173 .36101 L p F P
0 g
s
.67 .308 .351 r
.39171 .4529 m .39033 .45554 L .38717 .45266 L closepath p F P
0 g
s
.715 .367 .388 r
.34282 .44853 m .35101 .44959 L .34872 .44625 L p F P
0 g
s
.715 .367 .388 r
.34872 .44625 m .34049 .4452 L .34282 .44853 L p F P
0 g
s
.638 .78 .949 r
.44655 .36322 m .44883 .36517 L p .43685 .36553 L F P
0 g
s
.638 .78 .949 r
.43685 .36553 m .44475 .36332 L .44655 .36322 L p F P
0 g
s
.637 .782 .951 r
.43685 .36553 m .44475 .36332 L .43496 .36394 L closepath p F P
0 g
s
.79 .614 .663 r
.25225 .39603 m .2582 .39794 L .26055 .39306 L p F P
0 g
s
.79 .614 .663 r
.26055 .39306 m .25469 .39111 L .25225 .39603 L p F P
0 g
s
.612 .254 .339 r
.44334 .45269 m .44042 .45285 L .43915 .45571 L p F P
0 g
s
.623 .266 .344 r
.43506 .45585 m .43915 .45571 L .44042 .45285 L p F P
0 g
s
.778 .65 .721 r
.25796 .3859 m .25975 .38352 L .2574 .37855 L p F P
0 g
s
.786 .566 .602 r
.26688 .41058 m .26755 .41076 L .26862 .40632 L p F P
0 g
s
.786 .566 .602 r
.26862 .40632 m .26646 .40572 L .26688 .41058 L p F P
0 g
s
.691 .726 .877 r
.29975 .36138 m .29057 .36565 L .28776 .36209 L p F P
0 g
s
.761 .454 .467 r
.30156 .43501 m .3086 .43649 L .30754 .43276 L p F P
0 g
s
.761 .454 .467 r
.30754 .43276 m .30048 .43129 L .30156 .43501 L p F P
0 g
s
.655 .745 .916 r
.32649 .36383 m .33566 .36096 L .33845 .36371 L p F P
0 g
s
.639 .752 .931 r
.33566 .36096 m .32649 .36383 L .32369 .3609 L p F P
0 g
s
.611 .257 .344 r
.45202 .45218 m .44334 .45269 L .44819 .45522 L p F P
0 g
s
.612 .254 .339 r
.43915 .45571 m .44819 .45522 L .44334 .45269 L p F P
0 g
s
.644 .778 .945 r
.44883 .36517 m .45819 .36245 L .4608 .36476 L p F P
0 g
s
.642 .782 .948 r
.45792 .36224 m .45819 .36245 L .44883 .36517 L p F P
0 g
s
.642 .782 .948 r
.44883 .36517 m .44655 .36322 L .45792 .36224 L p F P
0 g
s
.785 .522 .538 r
.27982 .42255 m .28285 .42337 L .28333 .41944 L p F P
0 g
s
.785 .522 .538 r
.28333 .41944 m .27979 .41849 L .27982 .42255 L p F P
0 g
s
.669 .301 .34 r
.39026 .45567 m .39033 .45554 L .38717 .45266 L p F P
0 g
s
.669 .301 .34 r
.38084 .45512 m .39026 .45567 L p .38717 .45266 L F P
0 g
s
.669 .301 .34 r
.37844 .45296 m .38084 .45512 L p .38717 .45266 L F P
0 g
s
.669 .301 .34 r
.38717 .45266 m .37887 .45219 L .37844 .45296 L p F P
0 g
s
.726 .402 .431 r
.34004 .44433 m .34049 .4452 L .33974 .4451 L closepath p F P
0 g
s
.59 .263 .383 r
.48663 .44571 m .48633 .4467 L .48456 .44597 L closepath p F P
0 g
s
.593 .266 .385 r
.48567 .44883 m .48633 .4467 L .48456 .44597 L p F P
0 g
s
.593 .266 .385 r
.47464 .45018 m .48567 .44883 L p .48456 .44597 L F P
0 g
s
.651 .773 .938 r
.4608 .36476 m .47018 .36192 L .47278 .3643 L p F P
0 g
s
.636 .792 .957 r
.47018 .36192 m .4608 .36476 L .45819 .36245 L p F P
0 g
s
.745 .418 .429 r
.31747 .44145 m .32487 .4428 L .32328 .43923 L p F P
0 g
s
.745 .418 .429 r
.32328 .43923 m .31585 .43789 L .31747 .44145 L p F P
0 g
s
.579 .301 .459 r
.51972 .43464 m .52361 .43618 L .51937 .43706 L closepath p F P
0 g
s
.775 .489 .503 r
.28693 .42812 m .29363 .42973 L .29309 .42583 L p F P
0 g
s
.775 .489 .503 r
.29309 .42583 m .28638 .42422 L .28693 .42812 L p F P
0 g
s
.658 .766 .929 r
.47278 .3643 m .48218 .36134 L .48476 .36384 L p F P
0 g
s
.646 .785 .948 r
.48218 .36134 m .47278 .3643 L .47018 .36192 L p F P
0 g
s
.786 .544 .57 r
.26705 .415 m .27343 .41675 L .27391 .41251 L p F P
0 g
s
.786 .544 .57 r
.27391 .41251 m .26755 .41076 L .26705 .415 L p F P
0 g
s
.641 .753 .93 r
.33845 .36371 m .34762 .36112 L .3504 .36371 L p F P
0 g
s
.623 .761 .945 r
.34762 .36112 m .33845 .36371 L .33566 .36096 L p F P
0 g
s
.581 .254 .38 r
.49654 .44728 m .49746 .44414 L .48663 .44571 L p F P
0 g
s
.581 .254 .38 r
.49048 .44816 m .49654 .44728 L p .48663 .44571 L F P
0 g
s
.581 .254 .38 r
.48663 .44571 m .48633 .4467 L .49048 .44816 L p F P
0 g
s
.778 .65 .721 r
.25219 .38392 m .25796 .3859 L p .2574 .37855 L F P
0 g
s
.785 .634 .694 r
.24878 .38918 m .25469 .39111 L .25796 .3859 L p F P
0 g
s
.785 .634 .694 r
.25796 .3859 m .25219 .38392 L .24878 .38918 L p F P
0 g
s
.573 .274 .422 r
.51867 .4404 m .51937 .43706 L .50885 .43903 L p F P
0 g
s
.573 .274 .422 r
.50885 .43903 m .50815 .44238 L .51867 .4404 L p F P
0 g
s
.584 .284 .425 r
.50472 .44296 m .50815 .44238 L .50885 .43903 L p F P
0 g
s
.667 .665 .838 r
.5447 .36311 m .54641 .36593 L .5562 .36295 L p F P
0 g
s
.667 .658 .832 r
.55671 .36381 m .5562 .36295 L .54641 .36593 L p F P
0 g
s
.717 .694 .827 r
.28228 .36504 m .27588 .36348 L .27854 .36715 L closepath p F P
0 g
s
.664 .756 .919 r
.48476 .36384 m .49418 .36077 L .49674 .36341 L p F P
0 g
s
.655 .777 .939 r
.49418 .36077 m .48476 .36384 L .48218 .36134 L p F P
0 g
s
.6 .438 .633 r
.57896 .39677 m .57884 .39595 L .56921 .39912 L p F P
0 g
s
.6 .438 .633 r
.56921 .39912 m .56942 .40054 L .57896 .39677 L p F P
0 g
s
.795 .573 .6 r
.2615 .4089 m .26688 .41058 L .26646 .40572 L p F P
0 g
s
.795 .573 .6 r
.26646 .40572 m .26251 .40448 L .2615 .4089 L p F P
0 g
s
.68 .314 .346 r
.37887 .45219 m .37844 .45296 L .37755 .4521 L closepath p F P
0 g
s
.6 .245 .339 r
.45725 .45179 m .45202 .45218 L .45079 .45507 L p F P
0 g
s
.611 .257 .344 r
.44819 .45522 m .45079 .45507 L .45202 .45218 L p F P
0 g
s
.662 .766 .927 r
.50618 .36023 m .49674 .36341 L .49418 .36077 L p F P
0 g
s
.668 .743 .906 r
.49674 .36341 m .50618 .36023 L .50872 .36306 L p F P
0 g
s
.68 .314 .346 r
.37154 .45444 m .3684 .45137 L .37755 .4521 L p F P
0 g
s
.68 .314 .346 r
.37735 .4549 m .37154 .45444 L p .37755 .4521 L F P
0 g
s
.68 .314 .346 r
.37755 .4521 m .37844 .45296 L .37735 .4549 L p F P
0 g
s
.628 .517 .708 r
.57632 .38476 m .57422 .38552 L .57634 .38482 L closepath p F P
0 g
s
.607 .771 .959 r
.35959 .36131 m .3504 .36371 L .34762 .36112 L p F P
0 g
s
.63 .761 .942 r
.3504 .36371 m .35959 .36131 L .36235 .36377 L p F P
0 g
s
.671 .727 .892 r
.50872 .36306 m .51818 .35978 L .52071 .36284 L p F P
0 g
s
.667 .751 .913 r
.51818 .35978 m .50872 .36306 L .50618 .36023 L p F P
0 g
s
.654 .609 .791 r
.57124 .37045 m .56874 .36513 L .55921 .36851 L p F P
0 g
s
.654 .609 .791 r
.56821 .37153 m .57124 .37045 L p .55921 .36851 L F P
0 g
s
.66 .636 .815 r
.56874 .36513 m .55921 .36851 L .55671 .36381 L p F P
0 g
s
.716 .367 .385 r
.33826 .44792 m .34282 .44853 L .34049 .4452 L p F P
0 g
s
.716 .367 .385 r
.34049 .4452 m .33974 .4451 L .33826 .44792 L p F P
0 g
s
.576 .347 .531 r
.56067 .41982 m .56072 .41581 L .55082 .41859 L p F P
0 g
s
.576 .347 .531 r
.55082 .41859 m .55076 .4226 L .56067 .41982 L p F P
0 g
s
.585 .354 .532 r
.54842 .42321 m .55076 .4226 L .55082 .41859 L p F P
0 g
s
.597 .429 .625 r
.57954 .40084 m .57896 .39677 L .56942 .40054 L p F P
0 g
s
.597 .429 .625 r
.56942 .40054 m .5699 .40401 L .57954 .40084 L p F P
0 g
s
.599 .247 .344 r
.46342 .45129 m .46229 .45407 L .45725 .45179 L closepath p F P
0 g
s
.6 .245 .339 r
.46224 .4542 m .46229 .45407 L .45725 .45179 L p F P
0 g
s
.6 .245 .339 r
.45079 .45507 m .46224 .4542 L p .45725 .45179 L F P
0 g
s
.572 .319 .495 r
.54842 .42321 m .5407 .42517 L .54041 .42894 L p F P
0 g
s
.727 .38 .391 r
.33481 .44739 m .33826 .44792 L .33974 .4451 L p F P
0 g
s
.727 .38 .391 r
.33974 .4451 m .33265 .44401 L .33481 .44739 L p F P
0 g
s
.787 .523 .537 r
.27345 .42081 m .27982 .42255 L .27979 .41849 L p F P
0 g
s
.787 .523 .537 r
.27979 .41849 m .27343 .41675 L .27345 .42081 L p F P
0 g
s
.672 .709 .876 r
.52071 .36284 m .53019 .35949 L .5327 .36283 L p F P
0 g
s
.671 .734 .897 r
.53019 .35949 m .52071 .36284 L .51818 .35978 L p F P
0 g
s
.772 .659 .738 r
.25704 .37784 m .25664 .37828 L .2574 .37855 L closepath p F P
0 g
s
.778 .65 .721 r
.2574 .37855 m .25664 .37828 L .25219 .38392 L p F P
0 g
s
.619 .77 .953 r
.37244 .36225 m .37431 .36383 L p .36235 .36377 L F P
0 g
s
.619 .77 .953 r
.36235 .36377 m .36948 .36202 L .37244 .36225 L p F P
0 g
s
.595 .773 .965 r
.36948 .36202 m .36235 .36377 L .35959 .36131 L p F P
0 g
s
.755 .661 .758 r
.25428 .3728 m .25781 .36975 L .26364 .37173 L p F P
0 g
s
.755 .661 .758 r
.26364 .37173 m .25704 .37784 L .25428 .3728 L p F P
0 g
s
.748 .683 .788 r
.26364 .37173 m .26646 .36941 L .26365 .36521 L p F P
0 g
s
.748 .683 .788 r
.26365 .36521 m .25781 .36975 L .26364 .37173 L p F P
0 g
s
.77 .666 .747 r
.25664 .37828 m .25704 .37784 L .25428 .3728 L p F P
0 g
s
.714 .697 .832 r
.28228 .36504 m .28776 .36209 L p .27573 .36328 L F P
0 g
s
.714 .697 .832 r
.27573 .36328 m .27588 .36348 L .28228 .36504 L p F P
0 g
s
.58 .373 .564 r
.5705 .41284 m .57032 .40856 L .56055 .41154 L p F P
0 g
s
.58 .373 .564 r
.56055 .41154 m .56072 .41581 L .5705 .41284 L p F P
0 g
s
.77 .666 .747 r
.25428 .3728 m .25103 .37623 L .25664 .37828 L p F P
0 g
s
.778 .655 .726 r
.24636 .38194 m .25219 .38392 L .25664 .37828 L p F P
0 g
s
.778 .655 .726 r
.25664 .37828 m .25103 .37623 L .24636 .38194 L p F P
0 g
s
.635 .551 .743 r
.57377 .37684 m .57426 .37824 L .58375 .37484 L p F P
0 g
s
.628 .53 .724 r
.58582 .38143 m .58375 .37484 L .57426 .37824 L p F P
0 g
s
.628 .53 .724 r
.57842 .38407 m .58582 .38143 L p .57426 .37824 L F P
0 g
s
.628 .53 .724 r
.57426 .37824 m .57632 .38476 L .57842 .38407 L p F P
0 g
s
.683 .314 .342 r
.36412 .45382 m .37154 .45444 L .3684 .45137 L p F P
0 g
s
.683 .314 .342 r
.3684 .45137 m .36569 .45114 L .36412 .45382 L p F P
0 g
s
.736 .696 .814 r
.27588 .36348 m .27558 .36337 L .26646 .36941 L p F P
0 g
s
.73 .683 .805 r
.27558 .36337 m .26646 .36941 L .26365 .36521 L p F P
0 g
s
.649 .59 .775 r
.57124 .37045 m .56821 .37153 L .57127 .37051 L closepath p F P
0 g
s
.622 .513 .709 r
.57632 .38476 m .57842 .38407 L .57634 .38482 L closepath p F P
0 g
s
.617 .498 .694 r
.58727 .38724 m .57778 .39061 L .57634 .38482 L p F P
0 g
s
.617 .498 .694 r
.58589 .38167 m .58727 .38724 L p .57634 .38482 L F P
0 g
s
.617 .498 .694 r
.57634 .38482 m .57842 .38407 L .58589 .38167 L p F P
0 g
s
.671 .713 .88 r
.54219 .35943 m .5327 .36283 L .53019 .35949 L p F P
0 g
s
.67 .689 .859 r
.5327 .36283 m .54219 .35943 L .5447 .36311 L p F P
0 g
s
.588 .236 .34 r
.47264 .45038 m .46342 .45129 L .46229 .45407 L p F P
0 g
s
.635 .551 .743 r
.58375 .37484 m .58333 .37366 L .57377 .37684 L p F P
0 g
s
.64 .572 .762 r
.57127 .37051 m .57377 .37684 L .58333 .37366 L p F P
0 g
s
.567 .292 .459 r
.53994 .4325 m .54041 .42894 L .53021 .43132 L p F P
0 g
s
.567 .292 .459 r
.53021 .43132 m .52972 .43488 L .53994 .4325 L p F P
0 g
s
.581 .253 .379 r
.48633 .4467 m .49048 .44816 L .48567 .44883 L closepath p F P
0 g
s
.762 .455 .466 r
.29675 .43398 m .30156 .43501 L .30048 .43129 L p F P
0 g
s
.762 .455 .466 r
.30048 .43129 m .29787 .43073 L .29675 .43398 L p F P
0 g
s
.746 .418 .428 r
.31068 .4402 m .31747 .44145 L .31585 .43789 L p F P
0 g
s
.746 .418 .428 r
.31585 .43789 m .31202 .43719 L .31068 .4402 L p F P
0 g
s
.694 .327 .348 r
.36253 .45366 m .36412 .45382 L .36569 .45114 L p F P
0 g
s
.694 .327 .348 r
.36569 .45114 m .3596 .45052 L .36253 .45366 L p F P
0 g
s
.793 .595 .633 r
.25054 .40068 m .25653 .40258 L .2582 .39794 L p F P
0 g
s
.793 .595 .633 r
.2582 .39794 m .25225 .39603 L .25054 .40068 L p F P
0 g
s
.61 .778 .961 r
.38561 .36334 m .38628 .36388 L p .37431 .36383 L F P
0 g
s
.61 .778 .961 r
.37431 .36383 m .37831 .3629 L .38561 .36334 L p F P
0 g
s
.614 .768 .954 r
.37431 .36383 m .37831 .3629 L .37244 .36225 L closepath p F P
0 g
s
.672 .304 .341 r
.37844 .45296 m .38084 .45512 L .37735 .4549 L closepath p F P
0 g
s
.796 .575 .602 r
.25549 .40701 m .2615 .4089 L .26251 .40448 L p F P
0 g
s
.796 .575 .602 r
.26251 .40448 m .25653 .40258 L .25549 .40701 L p F P
0 g
s
.788 .616 .667 r
.24786 .39461 m .25225 .39603 L .25469 .39111 L p F P
0 g
s
.788 .616 .667 r
.24721 .39221 m .24786 .39461 L p .25469 .39111 L F P
0 g
s
.788 .616 .667 r
.25469 .39111 m .24878 .38918 L .24721 .39221 L p F P
0 g
s
.776 .49 .502 r
.28201 .42692 m .28693 .42812 L .28638 .42422 L p F P
0 g
s
.776 .49 .502 r
.28638 .42422 m .28285 .42337 L .28201 .42692 L p F P
0 g
s
.628 .78 .954 r
.42308 .36431 m .42221 .36359 L .41931 .36435 L closepath p F P
0 g
s
.629 .777 .952 r
.41952 .3616 m .42221 .36359 L .41931 .36435 L p F P
0 g
s
.629 .777 .952 r
.41023 .36377 m .41952 .3616 L p .41931 .36435 L F P
0 g
s
.629 .777 .952 r
.41931 .36435 m .4109 .36434 L .41023 .36377 L p F P
0 g
s
.569 .244 .378 r
.50472 .44296 m .49746 .44414 L .49654 .44728 L p F P
0 g
s
.627 .777 .953 r
.4109 .36434 m .41023 .36377 L .40817 .36431 L closepath p F P
0 g
s
.632 .781 .953 r
.43141 .36406 m .42308 .36431 L .42221 .36359 L p F P
0 g
s
.628 .772 .949 r
.40752 .36174 m .41023 .36377 L .40817 .36431 L p F P
0 g
s
.628 .772 .949 r
.39825 .36386 m .40752 .36174 L p .40817 .36431 L F P
0 g
s
.628 .772 .949 r
.40817 .36431 m .39837 .36396 L .39825 .36386 L p F P
0 g
s
.667 .665 .838 r
.5562 .36295 m .55421 .35971 L .5447 .36311 L p F P
0 g
s
.67 .691 .861 r
.55421 .35971 m .5447 .36311 L .54219 .35943 L p F P
0 g
s
.771 .465 .469 r
.29462 .43348 m .29675 .43398 L .29787 .43073 L p F P
0 g
s
.771 .465 .469 r
.29787 .43073 m .29363 .42973 L .29462 .43348 L p F P
0 g
s
.605 .784 .966 r
.38628 .36388 m .38788 .36351 L .39792 .36395 L p F P
0 g
s
.608 .776 .961 r
.38628 .36388 m .38788 .36351 L .38561 .36334 L closepath p F P
0 g
s
.788 .546 .57 r
.2668 .41493 m .26705 .415 L .26755 .41076 L p F P
0 g
s
.788 .546 .57 r
.26755 .41076 m .26688 .41058 L .2668 .41493 L p F P
0 g
s
.725 .374 .382 r
.32705 .44617 m .33481 .44739 L .33265 .44401 L p F P
0 g
s
.725 .374 .382 r
.32521 .44335 m .32705 .44617 L p .33265 .44401 L F P
0 g
s
.725 .374 .382 r
.33265 .44401 m .32546 .4429 L .32521 .44335 L p F P
0 g
s
.62 .506 .703 r
.57842 .38407 m .58582 .38143 L .58589 .38167 L closepath p F P
0 g
s
.585 .399 .596 r
.57996 .4054 m .57954 .40084 L .5699 .40401 L p F P
0 g
s
.585 .399 .596 r
.5699 .40401 m .57032 .40856 L .57996 .4054 L p F P
0 g
s
.632 .782 .953 r
.43496 .36394 m .4342 .3633 L .43141 .36406 L closepath p F P
0 g
s
.632 .781 .953 r
.43153 .36133 m .4342 .3633 L .43141 .36406 L p F P
0 g
s
.632 .781 .953 r
.42221 .36359 m .43153 .36133 L p .43141 .36406 L F P
0 g
s
.692 .32 .338 r
.35393 .45273 m .36253 .45366 L .3596 .45052 L p F P
0 g
s
.692 .32 .338 r
.35175 .45043 m .35393 .45273 L p .3596 .45052 L F P
0 g
s
.692 .32 .338 r
.3596 .45052 m .35218 .44974 L .35175 .45043 L p F P
0 g
s
.755 .429 .432 r
.3101 .44008 m .31068 .4402 L .31202 .43719 L p F P
0 g
s
.755 .429 .432 r
.31202 .43719 m .3086 .43649 L .3101 .44008 L p F P
0 g
s
.797 .554 .569 r
.26101 .41313 m .2668 .41493 L .26688 .41058 L p F P
0 g
s
.797 .554 .569 r
.26688 .41058 m .2615 .4089 L .26101 .41313 L p F P
0 g
s
.604 .462 .661 r
.58833 .39257 m .58727 .38724 L .57778 .39061 L p F P
0 g
s
.604 .462 .661 r
.57778 .39061 m .57884 .39595 L .58833 .39257 L p F P
0 g
s
.782 .636 .7 r
.24603 .38826 m .24878 .38918 L .25219 .38392 L p F P
0 g
s
.782 .636 .7 r
.24463 .38447 m .24603 .38826 L p .25219 .38392 L F P
0 g
s
.782 .636 .7 r
.25219 .38392 m .24636 .38194 L .24463 .38447 L p F P
0 g
s
.629 .772 .949 r
.39837 .36396 m .39825 .36386 L .39792 .36395 L closepath p F P
0 g
s
.623 .79 .962 r
.39553 .36176 m .38788 .36351 L .39792 .36395 L p F P
0 g
s
.623 .79 .962 r
.39792 .36395 m .39825 .36386 L .39553 .36176 L p F P
0 g
s
.637 .783 .952 r
.44475 .36332 m .43496 .36394 L .4342 .3633 L p F P
0 g
s
.585 .232 .338 r
.47464 .45018 m .47432 .451 L .47264 .45038 L closepath p F P
0 g
s
.588 .236 .34 r
.47348 .45309 m .47432 .451 L .47264 .45038 L p F P
0 g
s
.588 .236 .34 r
.46256 .45417 m .47348 .45309 L p .47264 .45038 L F P
0 g
s
.588 .236 .34 r
.46229 .45407 m .46256 .45417 L p .47264 .45038 L F P
0 g
s
.562 .262 .417 r
.52361 .43618 m .51937 .43706 L .51867 .4404 L p F P
0 g
s
.64 .572 .762 r
.58081 .36723 m .57428 .36943 L .57127 .37051 L p F P
0 g
s
.64 .572 .762 r
.58333 .37366 m .58081 .36723 L p .57127 .37051 L F P
0 g
s
.645 .588 .776 r
.57124 .37045 m .57428 .36943 L .57127 .37051 L closepath p F P
0 g
s
.651 .607 .792 r
.57428 .36943 m .57124 .37045 L .56874 .36513 L p F P
0 g
s
.575 .799 .984 r
.40752 .36174 m .39825 .36386 L .39553 .36176 L p F P
0 g
s
.673 .735 .897 r
.29975 .36138 m .30891 .35804 L .31173 .36101 L p F P
0 g
s
.66 .741 .91 r
.30891 .35804 m .29975 .36138 L .29693 .3582 L p F P
0 g
s
.691 .726 .877 r
.28776 .36209 m .29693 .3582 L .29975 .36138 L p F P
0 g
s
.575 .222 .333 r
.48454 .45176 m .48567 .44883 L .47464 .45018 L p F P
0 g
s
.575 .222 .333 r
.47895 .45244 m .48454 .45176 L p .47464 .45018 L F P
0 g
s
.575 .222 .333 r
.47464 .45018 m .47432 .451 L .47895 .45244 L p F P
0 g
s
.68 .732 .89 r
.29693 .3582 m .28776 .36209 L .28493 .35869 L p F P
0 g
s
.714 .697 .832 r
.28776 .36209 m .28493 .35869 L .27573 .36328 L p F P
0 g
s
.787 .522 .536 r
.26709 .41906 m .27345 .42081 L .27343 .41675 L p F P
0 g
s
.787 .522 .536 r
.27343 .41675 m .26705 .415 L .26709 .41906 L p F P
0 g
s
.656 .744 .915 r
.31173 .36101 m .32088 .35812 L .32369 .3609 L p F P
0 g
s
.64 .75 .928 r
.32088 .35812 m .31173 .36101 L .30891 .35804 L p F P
0 g
s
.607 .777 .962 r
.39279 .35984 m .39553 .36176 L .38788 .36351 L p F P
0 g
s
.607 .777 .962 r
.38354 .36168 m .39279 .35984 L p .38788 .36351 L F P
0 g
s
.607 .777 .962 r
.38788 .36351 m .38561 .36334 L .38354 .36168 L p F P
0 g
s
.784 .499 .504 r
.28031 .42647 m .28201 .42692 L .28285 .42337 L p F P
0 g
s
.784 .499 .504 r
.28285 .42337 m .27982 .42255 L .28031 .42647 L p F P
0 g
s
.729 .701 .824 r
.27573 .36328 m .27558 .36337 L .27588 .36348 L closepath p F P
0 g
s
.577 .804 .985 r
.41952 .3616 m .41023 .36377 L .40752 .36174 L p F P
0 g
s
.66 .636 .815 r
.55671 .36381 m .56625 .36044 L .56874 .36513 L p F P
0 g
s
.664 .659 .835 r
.5562 .36295 m .55671 .36381 L .56625 .36044 L p F P
0 g
s
.724 .707 .834 r
.27558 .36337 m .27573 .36328 L .2729 .35963 L p F P
0 g
s
.724 .707 .834 r
.2729 .35963 m .27005 .36128 L .27558 .36337 L p F P
0 g
s
.73 .683 .805 r
.26365 .36521 m .27005 .36128 L .27558 .36337 L p F P
0 g
s
.7 .723 .868 r
.28493 .35869 m .27573 .36328 L .2729 .35963 L p F P
0 g
s
.61 .778 .961 r
.38561 .36334 m .38354 .36168 L .37831 .3629 L closepath p F P
0 g
s
.571 .319 .495 r
.55076 .4226 m .55066 .42403 L .54842 .42321 L closepath p F P
0 g
s
.572 .319 .495 r
.55049 .42638 m .55066 .42403 L .54842 .42321 L p F P
0 g
s
.572 .319 .495 r
.54041 .42894 m .55049 .42638 L p .54842 .42321 L F P
0 g
s
.637 .781 .95 r
.44655 .36322 m .44619 .36292 L .44475 .36332 L closepath p F P
0 g
s
.637 .783 .952 r
.44354 .36094 m .44619 .36292 L .44475 .36332 L p F P
0 g
s
.637 .783 .952 r
.4342 .3633 m .44354 .36094 L p .44475 .36332 L F P
0 g
s
.757 .428 .428 r
.30307 .43859 m .3101 .44008 L .3086 .43649 L p F P
0 g
s
.757 .428 .428 r
.3086 .43649 m .30156 .43501 L .30307 .43859 L p F P
0 g
s
.703 .333 .345 r
.35218 .44974 m .35175 .45043 L .35101 .44959 L closepath p F P
0 g
s
.631 .779 .952 r
.45556 .36042 m .45792 .36224 L .44655 .36322 L p F P
0 g
s
.631 .779 .952 r
.44655 .36322 m .44619 .36292 L .45556 .36042 L p F P
0 g
s
.753 .67 .77 r
.25781 .36975 m .25428 .3728 L .2515 .36807 L p F P
0 g
s
.766 .668 .755 r
.25103 .37623 m .25428 .3728 L .2515 .36807 L p F P
0 g
s
.772 .465 .466 r
.28793 .43186 m .29462 .43348 L .29363 .42973 L p F P
0 g
s
.772 .465 .466 r
.29363 .42973 m .28693 .42812 L .28793 .43186 L p F P
0 g
s
.62 .758 .945 r
.33285 .35835 m .32369 .3609 L .32088 .35812 L p F P
0 g
s
.639 .752 .931 r
.32369 .3609 m .33285 .35835 L .33566 .36096 L p F P
0 g
s
.583 .809 .985 r
.43153 .36133 m .42221 .36359 L .41952 .3616 L p F P
0 g
s
.566 .242 .379 r
.50815 .44238 m .50776 .44373 L .50472 .44296 L closepath p F P
0 g
s
.569 .244 .378 r
.50725 .44552 m .50776 .44373 L .50472 .44296 L p F P
0 g
s
.569 .244 .378 r
.49654 .44728 m .50725 .44552 L p .50472 .44296 L F P
0 g
s
.753 .67 .77 r
.2515 .36807 m .2518 .36783 L .25781 .36975 L p F P
0 g
s
.742 .684 .795 r
.25781 .36975 m .26365 .36521 L .26083 .36122 L p F P
0 g
s
.742 .684 .795 r
.26083 .36122 m .2518 .36783 L .25781 .36975 L p F P
0 g
s
.704 .333 .344 r
.34559 .45171 m .34282 .44853 L .35101 .44959 L p F P
0 g
s
.704 .333 .344 r
.35052 .45236 m .34559 .45171 L p .35101 .44959 L F P
0 g
s
.704 .333 .344 r
.35101 .44959 m .35175 .45043 L .35052 .45236 L p F P
0 g
s
.618 .233 .29 r
.42289 .45616 m .4152 .45623 L .41425 .45784 L p F P
0 g
s
.63 .246 .297 r
.4152 .45623 m .41425 .45784 L .4115 .4562 L closepath p F P
0 g
s
.736 .386 .388 r
.32546 .4429 m .32521 .44335 L .32487 .4428 L closepath p F P
0 g
s
.63 .241 .289 r
.41364 .45884 m .41425 .45784 L .4115 .4562 L p F P
0 g
s
.63 .241 .289 r
.40507 .45872 m .41364 .45884 L p .4115 .4562 L F P
0 g
s
.63 .241 .289 r
.40227 .45703 m .40507 .45872 L p .4115 .4562 L F P
0 g
s
.63 .241 .289 r
.4115 .4562 m .40287 .45609 L .40227 .45703 L p F P
0 g
s
.618 .236 .296 r
.42729 .4561 m .42624 .45794 L .42289 .45616 L closepath p F P
0 g
s
.618 .233 .29 r
.42578 .45874 m .42624 .45794 L .42289 .45616 L p F P
0 g
s
.618 .233 .29 r
.41606 .45883 m .42578 .45874 L p .42289 .45616 L F P
0 g
s
.618 .233 .29 r
.41425 .45784 m .41606 .45883 L p .42289 .45616 L F P
0 g
s
.562 .262 .417 r
.52906 .43824 m .52924 .43731 L .52361 .43618 L p F P
0 g
s
.562 .262 .417 r
.51867 .4404 m .52906 .43824 L p .52361 .43618 L F P
0 g
s
.561 .263 .42 r
.52972 .43488 m .52924 .43731 L .52361 .43618 L closepath p F P
0 g
s
.666 .666 .841 r
.55421 .35971 m .5562 .36295 L .56583 .35974 L p F P
0 g
s
.664 .659 .835 r
.56625 .36044 m .56583 .35974 L .5562 .36295 L p F P
0 g
s
.736 .386 .387 r
.31951 .44486 m .31747 .44145 L .32487 .4428 L p F P
0 g
s
.736 .386 .387 r
.3239 .44566 m .31951 .44486 L p .32487 .4428 L F P
0 g
s
.736 .386 .387 r
.32487 .4428 m .32521 .44335 L .3239 .44566 L p F P
0 g
s
.606 .223 .29 r
.43506 .45585 m .42729 .4561 L .42624 .45794 L p F P
0 g
s
.642 .255 .296 r
.40287 .45609 m .40227 .45703 L .40074 .45603 L closepath p F P
0 g
s
.766 .668 .755 r
.2515 .36807 m .24535 .37419 L .25103 .37623 L p F P
0 g
s
.775 .657 .732 r
.24319 .38086 m .24636 .38194 L .25103 .37623 L p F P
0 g
s
.775 .657 .732 r
.24196 .37816 m .24319 .38086 L p .25103 .37623 L F P
0 g
s
.775 .657 .732 r
.25103 .37623 m .24535 .37419 L .24196 .37816 L p F P
0 g
s
.592 .812 .984 r
.44354 .36094 m .4342 .3633 L .43153 .36133 L p F P
0 g
s
.612 .768 .955 r
.38078 .35966 m .38354 .36168 L .37831 .3629 L p F P
0 g
s
.612 .768 .955 r
.37156 .36152 m .38078 .35966 L p .37831 .3629 L F P
0 g
s
.612 .768 .955 r
.37831 .3629 m .37244 .36225 L .37156 .36152 L p F P
0 g
s
.642 .255 .295 r
.39466 .45842 m .3905 .45568 L .40074 .45603 L p F P
0 g
s
.642 .255 .295 r
.40125 .45866 m .39466 .45842 L p .40074 .45603 L F P
0 g
s
.642 .255 .295 r
.40074 .45603 m .40227 .45703 L .40125 .45866 L p F P
0 g
s
.651 .607 .792 r
.58075 .36709 m .57428 .36943 L p .56874 .36513 L F P
0 g
s
.647 .593 .78 r
.57428 .36943 m .58075 .36709 L .58081 .36723 L closepath p F P
0 g
s
.793 .595 .633 r
.24893 .40017 m .25054 .40068 L .25225 .39603 L p F P
0 g
s
.793 .595 .633 r
.25225 .39603 m .24786 .39461 L .24893 .40017 L p F P
0 g
s
.603 .813 .981 r
.45556 .36042 m .44619 .36292 L .44354 .36094 L p F P
0 g
s
.623 .761 .945 r
.33566 .36096 m .34482 .35867 L .34762 .36112 L p F P
0 g
s
.598 .769 .961 r
.34482 .35867 m .33566 .36096 L .33285 .35835 L p F P
0 g
s
.561 .311 .494 r
.56042 .42361 m .56067 .41982 L .55076 .4226 L p F P
0 g
s
.561 .311 .494 r
.55565 .42495 m .56042 .42361 L p .55076 .4226 L F P
0 g
s
.561 .311 .494 r
.55076 .4226 m .55066 .42403 L .55565 .42495 L p F P
0 g
s
.605 .224 .294 r
.43915 .45571 m .43825 .45735 L .43506 .45585 L closepath p F P
0 g
s
.606 .223 .29 r
.43769 .45837 m .43825 .45735 L .43506 .45585 L p F P
0 g
s
.606 .223 .29 r
.42777 .45868 m .43769 .45837 L p .43506 .45585 L F P
0 g
s
.606 .223 .29 r
.42624 .45794 m .42777 .45868 L p .43506 .45585 L F P
0 g
s
.662 .299 .346 r
.39033 .45554 m .3905 .45568 L .39026 .45567 L closepath p F P
0 g
s
.592 .433 .634 r
.58855 .394 m .58833 .39257 L .57884 .39595 L p F P
0 g
s
.592 .433 .634 r
.57884 .39595 m .57896 .39677 L .58855 .394 L p F P
0 g
s
.786 .5 .503 r
.27395 .42472 m .28031 .42647 L .27982 .42255 L p F P
0 g
s
.786 .5 .503 r
.27982 .42255 m .27345 .42081 L .27395 .42472 L p F P
0 g
s
.796 .575 .602 r
.24947 .40512 m .25549 .40701 L .25653 .40258 L p F P
0 g
s
.796 .575 .602 r
.25653 .40258 m .25054 .40068 L .24947 .40512 L p F P
0 g
s
.636 .792 .957 r
.46915 .36108 m .47018 .36192 L p .45819 .36245 L F P
0 g
s
.636 .792 .957 r
.45819 .36245 m .45965 .36204 L .46915 .36108 L p F P
0 g
s
.634 .8 .962 r
.45819 .36245 m .45965 .36204 L .45792 .36224 L closepath p F P
0 g
s
.575 .221 .332 r
.47432 .451 m .47895 .45244 L .47348 .45309 L closepath p F P
0 g
s
.566 .339 .53 r
.57046 .41686 m .5705 .41284 L .56072 .41581 L p F P
0 g
s
.566 .339 .53 r
.56072 .41581 m .56067 .41982 L .57046 .41686 L p F P
0 g
s
.725 .691 .817 r
.27005 .36128 m .26365 .36521 L .26083 .36122 L p F P
0 g
s
.789 .616 .667 r
.24878 .38918 m .24603 .38826 L .24721 .39221 L closepath p F P
0 g
s
.644 .796 .955 r
.47018 .36192 m .47699 .35989 L .46915 .36108 L closepath p F P
0 g
s
.646 .785 .948 r
.48005 .35951 m .48218 .36134 L p .47018 .36192 L F P
0 g
s
.646 .785 .948 r
.47018 .36192 m .47699 .35989 L .48005 .35951 L p F P
0 g
s
.593 .211 .288 r
.44819 .45522 m .43915 .45571 L .43825 .45735 L p F P
0 g
s
.556 .233 .376 r
.5178 .44356 m .51867 .4404 L .50815 .44238 L p F P
0 g
s
.556 .233 .376 r
.51232 .44459 m .5178 .44356 L p .50815 .44238 L F P
0 g
s
.556 .233 .376 r
.50815 .44238 m .50776 .44373 L .51232 .44459 L p F P
0 g
s
.644 .252 .287 r
.38858 .45818 m .39466 .45842 L .3905 .45568 L p F P
0 g
s
.644 .252 .287 r
.3905 .45568 m .39026 .45567 L .38858 .45818 L p F P
0 g
s
.656 .267 .295 r
.38472 .45796 m .38858 .45818 L .39026 .45567 L p F P
0 g
s
.656 .267 .295 r
.39026 .45567 m .38084 .45512 L .38472 .45796 L p F P
0 g
s
.655 .777 .939 r
.48218 .36134 m .49161 .3584 L .49418 .36077 L p F P
0 g
s
.651 .788 .947 r
.49083 .35777 m .49161 .3584 L .48218 .36134 L p F P
0 g
s
.651 .788 .947 r
.48218 .36134 m .48005 .35951 L .49083 .35777 L p F P
0 g
s
.662 .766 .927 r
.49418 .36077 m .50363 .3577 L .50618 .36023 L p F P
0 g
s
.654 .786 .945 r
.50363 .3577 m .49418 .36077 L .49161 .3584 L p F P
0 g
s
.729 .377 .383 r
.32521 .44335 m .32705 .44617 L .3239 .44566 L closepath p F P
0 g
s
.589 .424 .626 r
.58905 .39747 m .58855 .394 L .57896 .39677 L p F P
0 g
s
.589 .424 .626 r
.57896 .39677 m .57954 .40084 L .58905 .39747 L p F P
0 g
s
.555 .282 .456 r
.55002 .42994 m .55049 .42638 L .54041 .42894 L p F P
0 g
s
.555 .282 .456 r
.54041 .42894 m .53994 .4325 L .55002 .42994 L p F P
0 g
s
.667 .751 .913 r
.50618 .36023 m .51565 .35704 L .51818 .35978 L p F P
0 g
s
.662 .774 .933 r
.51565 .35704 m .50618 .36023 L .50363 .3577 L p F P
0 g
s
.798 .554 .57 r
.25499 .41125 m .26101 .41313 L .2615 .4089 L p F P
0 g
s
.798 .554 .57 r
.2615 .4089 m .25549 .40701 L .25499 .41125 L p F P
0 g
s
.562 .211 .331 r
.49048 .44816 m .48567 .44883 L .48454 .45176 L p F P
0 g
s
.619 .77 .953 r
.37244 .36225 m .37156 .36152 L .36948 .36202 L closepath p F P
0 g
s
.633 .8 .963 r
.45965 .36204 m .45792 .36224 L .45556 .36042 L p F P
0 g
s
.671 .734 .897 r
.51818 .35978 m .52767 .3565 L .53019 .35949 L p F P
0 g
s
.668 .758 .918 r
.52767 .3565 m .51818 .35978 L .51565 .35704 L p F P
0 g
s
.607 .771 .959 r
.35882 .36069 m .35959 .36131 L p .34762 .36112 L F P
0 g
s
.607 .771 .959 r
.34762 .36112 m .35252 .36001 L .35882 .36069 L p F P
0 g
s
.585 .764 .964 r
.35252 .36001 m .34762 .36112 L .34482 .35867 L p F P
0 g
s
.651 .607 .792 r
.56874 .36513 m .57831 .36187 L .58075 .36709 L p F P
0 g
s
.657 .634 .815 r
.57831 .36187 m .56874 .36513 L .56625 .36044 L p F P
0 g
s
.695 .323 .339 r
.35175 .45043 m .35393 .45273 L .35052 .45236 L closepath p F P
0 g
s
.635 .794 .959 r
.46915 .36108 m .46758 .35981 L .45965 .36204 L closepath p F P
0 g
s
.633 .8 .963 r
.46496 .35796 m .46758 .35981 L .45965 .36204 L p F P
0 g
s
.633 .8 .963 r
.45556 .36042 m .46496 .35796 L p .45965 .36204 L F P
0 g
s
.595 .773 .965 r
.35959 .36131 m .36101 .36102 L .36948 .36202 L p F P
0 g
s
.614 .785 .963 r
.36879 .35938 m .36101 .36102 L .36948 .36202 L p F P
0 g
s
.614 .785 .963 r
.36948 .36202 m .37156 .36152 L .36879 .35938 L p F P
0 g
s
.591 .211 .291 r
.45079 .45507 m .45027 .45605 L .44819 .45522 L closepath p F P
0 g
s
.593 .211 .288 r
.44937 .45775 m .45027 .45605 L .44819 .45522 L p F P
0 g
s
.593 .211 .288 r
.44038 .45824 m .44937 .45775 L p .44819 .45522 L F P
0 g
s
.593 .211 .288 r
.43825 .45735 m .44038 .45824 L p .44819 .45522 L F P
0 g
s
.706 .333 .339 r
.33744 .45062 m .34559 .45171 L .34282 .44853 L p F P
0 g
s
.706 .333 .339 r
.33689 .44997 m .33744 .45062 L p .34282 .44853 L F P
0 g
s
.706 .333 .339 r
.34282 .44853 m .33826 .44792 L .33689 .44997 L p F P
0 g
s
.671 .713 .88 r
.53019 .35949 m .53969 .35615 L .54219 .35943 L p F P
0 g
s
.671 .738 .901 r
.53969 .35615 m .53019 .35949 L .52767 .3565 L p F P
0 g
s
.782 .637 .7 r
.24636 .38194 m .24319 .38086 L .24463 .38447 L closepath p F P
0 g
s
.571 .366 .563 r
.58015 .40967 m .57996 .4054 L .57032 .40856 L p F P
0 g
s
.571 .366 .563 r
.57032 .40856 m .5705 .41284 L .58015 .40967 L p F P
0 g
s
.657 .265 .291 r
.37561 .4574 m .38472 .45796 L .38084 .45512 L p F P
0 g
s
.657 .265 .291 r
.38084 .45512 m .37735 .4549 L .37561 .4574 L p F P
0 g
s
.581 .2 .285 r
.46084 .45689 m .46224 .4542 L .45079 .45507 L p F P
0 g
s
.581 .2 .285 r
.45412 .45741 m .46084 .45689 L p .45079 .45507 L F P
0 g
s
.581 .2 .285 r
.45079 .45507 m .45027 .45605 L .45412 .45741 L p F P
0 g
s
.757 .426 .425 r
.29605 .43709 m .30307 .43859 L .30156 .43501 L p F P
0 g
s
.757 .426 .425 r
.29568 .43619 m .29605 .43709 L p .30156 .43501 L F P
0 g
s
.757 .426 .425 r
.30156 .43501 m .29675 .43398 L .29568 .43619 L p F P
0 g
s
.789 .524 .536 r
.26629 .41884 m .26709 .41906 L .26705 .415 L p F P
0 g
s
.789 .524 .536 r
.26705 .415 m .2668 .41493 L .26629 .41884 L p F P
0 g
s
.669 .28 .299 r
.37515 .45736 m .37561 .4574 L .37735 .4549 L p F P
0 g
s
.669 .28 .299 r
.37735 .4549 m .37154 .45444 L .37515 .45736 L p F P
0 g
s
.598 .767 .96 r
.35959 .36131 m .36101 .36102 L .35882 .36069 L closepath p F P
0 g
s
.798 .533 .537 r
.26101 .41721 m .26629 .41884 L .2668 .41493 L p F P
0 g
s
.798 .533 .537 r
.2668 .41493 m .26101 .41313 L .26101 .41721 L p F P
0 g
s
.551 .254 .417 r
.53929 .43587 m .53994 .4325 L .52972 .43488 L p F P
0 g
s
.551 .254 .417 r
.5318 .43761 m .53929 .43587 L p .52972 .43488 L F P
0 g
s
.551 .254 .417 r
.52972 .43488 m .52924 .43731 L .5318 .43761 L p F P
0 g
s
.793 .634 .684 r
.24463 .38447 m .24306 .38716 L .24603 .38826 L closepath p F P
0 g
s
.799 .621 .661 r
.24637 .39408 m .24721 .39221 L .24603 .38826 L p F P
0 g
s
.799 .621 .661 r
.24077 .39202 m .24637 .39408 L p .24603 .38826 L F P
0 g
s
.799 .621 .661 r
.24603 .38826 m .24306 .38716 L .24077 .39202 L p F P
0 g
s
.561 .212 .335 r
.49654 .44728 m .49575 .4494 L .49048 .44816 L closepath p F P
0 g
s
.562 .211 .331 r
.49544 .45023 m .49575 .4494 L .49048 .44816 L p F P
0 g
s
.562 .211 .331 r
.48454 .45176 m .49544 .45023 L p .49048 .44816 L F P
0 g
s
.671 .716 .882 r
.55172 .35606 m .54219 .35943 L .53969 .35615 L p F P
0 g
s
.67 .691 .861 r
.54219 .35943 m .55172 .35606 L .55421 .35971 L p F P
0 g
s
.561 .311 .493 r
.55066 .42403 m .55565 .42495 L .55049 .42638 L closepath p F P
0 g
s
.737 .383 .379 r
.31215 .44349 m .31951 .44486 L .31747 .44145 L p F P
0 g
s
.737 .383 .379 r
.31041 .44064 m .31215 .44349 L p .31747 .44145 L F P
0 g
s
.737 .383 .379 r
.31747 .44145 m .31068 .4402 L .31041 .44064 L p F P
0 g
s
.773 .464 .464 r
.28124 .43023 m .28793 .43186 L .28693 .42812 L p F P
0 g
s
.773 .464 .464 r
.28105 .42951 m .28124 .43023 L p .28693 .42812 L F P
0 g
s
.773 .464 .464 r
.28693 .42812 m .28201 .42692 L .28105 .42951 L p F P
0 g
s
.63 .548 .744 r
.58333 .37366 m .58375 .37484 L .59311 .37125 L p F P
0 g
s
.622 .526 .725 r
.59517 .37782 m .59311 .37125 L .58375 .37484 L p F P
0 g
s
.622 .526 .725 r
.58375 .37484 m .58582 .38143 L .59517 .37782 L p F P
0 g
s
.797 .615 .655 r
.24721 .39221 m .24637 .39408 L .24786 .39461 L closepath p F P
0 g
s
.613 .502 .704 r
.5955 .37903 m .59517 .37782 L .58582 .38143 L p F P
0 g
s
.613 .502 .704 r
.58582 .38143 m .58589 .38167 L .5955 .37903 L p F P
0 g
s
.63 .548 .744 r
.59311 .37125 m .59293 .37072 L .58333 .37366 L p F P
0 g
s
.636 .567 .759 r
.59293 .37072 m .58333 .37366 L .58081 .36723 L p F P
0 g
s
.608 .487 .69 r
.59664 .38366 m .5955 .37903 L .58589 .38167 L p F P
0 g
s
.608 .487 .69 r
.58589 .38167 m .58727 .38724 L .59664 .38366 L p F P
0 g
s
.633 .244 .289 r
.40227 .45703 m .40507 .45872 L .40125 .45866 L closepath p F P
0 g
s
.717 .346 .346 r
.33826 .44792 m .33689 .44997 L .33481 .44739 L closepath p F P
0 g
s
.794 .64 .691 r
.24306 .38716 m .24463 .38447 L .24319 .38086 L p F P
0 g
s
.802 .601 .63 r
.24479 .39869 m .24893 .40017 L .24786 .39461 L p F P
0 g
s
.802 .601 .63 r
.24786 .39461 m .24637 .39408 L .24479 .39869 L p F P
0 g
s
.716 .708 .841 r
.27005 .36128 m .2729 .35963 L .27006 .35613 L p F P
0 g
s
.716 .708 .841 r
.27006 .35613 m .26422 .35929 L .27005 .36128 L p F P
0 g
s
.725 .691 .817 r
.26083 .36122 m .26422 .35929 L .27005 .36128 L p F P
0 g
s
.666 .271 .286 r
.36611 .45659 m .37515 .45736 L .37154 .45444 L p F P
0 g
s
.666 .271 .286 r
.36357 .45455 m .36611 .45659 L p .37154 .45444 L F P
0 g
s
.666 .271 .286 r
.37154 .45444 m .36412 .45382 L .36357 .45455 L p F P
0 g
s
.749 .677 .781 r
.2518 .36783 m .25124 .36765 L .2515 .36807 L closepath p F P
0 g
s
.768 .678 .764 r
.24535 .37419 m .2515 .36807 L .25124 .36765 L p F P
0 g
s
.74 .701 .814 r
.2518 .36783 m .26083 .36122 L .25812 .35757 L p F P
0 g
s
.74 .701 .814 r
.25124 .36765 m .2518 .36783 L p .25812 .35757 L F P
0 g
s
.59 .237 .339 r
.46229 .45407 m .46256 .45417 L .46224 .4542 L closepath p F P
0 g
s
.554 .791 .987 r
.38078 .35966 m .37156 .36152 L .36879 .35938 L p F P
0 g
s
.644 .796 .956 r
.47699 .35989 m .46915 .36108 L .46758 .35981 L p F P
0 g
s
.596 .767 .961 r
.366 .3574 m .36879 .35938 L .36101 .36102 L p F P
0 g
s
.596 .767 .961 r
.3568 .35904 m .366 .3574 L p .36101 .36102 L F P
0 g
s
.596 .767 .961 r
.36101 .36102 m .35882 .36069 L .3568 .35904 L p F P
0 g
s
.666 .666 .841 r
.56583 .35974 m .56376 .35635 L .55421 .35971 L p F P
0 g
s
.669 .691 .862 r
.56376 .35635 m .55421 .35971 L .55172 .35606 L p F P
0 g
s
.768 .678 .764 r
.2396 .37217 m .24535 .37419 L p .25124 .36765 L F P
0 g
s
.768 .678 .764 r
.25124 .36765 m .24636 .36569 L .2396 .37217 L p F P
0 g
s
.74 .701 .814 r
.24869 .36371 m .25124 .36765 L p .25812 .35757 L F P
0 g
s
.759 .686 .781 r
.24869 .36371 m .24636 .36569 L .25124 .36765 L closepath p F P
0 g
s
.566 .185 .279 r
.46256 .45417 m .46224 .4542 L .46084 .45689 L p F P
0 g
s
.556 .232 .374 r
.50776 .44373 m .51232 .44459 L .50725 .44552 L closepath p F P
0 g
s
.567 .19 .287 r
.47348 .45309 m .46256 .45417 L .46931 .45609 L p F P
0 g
s
.566 .185 .279 r
.46084 .45689 m .46931 .45609 L .46256 .45417 L p F P
0 g
s
.787 .651 .712 r
.24196 .37816 m .2407 .3799 L .24319 .38086 L closepath p F P
0 g
s
.794 .64 .691 r
.23753 .38507 m .24306 .38716 L p .24319 .38086 L F P
0 g
s
.794 .64 .691 r
.24319 .38086 m .2407 .3799 L .23753 .38507 L p F P
0 g
s
.576 .393 .596 r
.58948 .40204 m .58905 .39747 L .57954 .40084 L p F P
0 g
s
.576 .393 .596 r
.57954 .40084 m .57996 .4054 L .58948 .40204 L p F P
0 g
s
.773 .654 .731 r
.23922 .37258 m .2396 .37217 L .24535 .37419 L p F P
0 g
s
.773 .654 .731 r
.24535 .37419 m .24196 .37816 L .23922 .37258 L p F P
0 g
s
.786 .499 .501 r
.2676 .42297 m .27395 .42472 L .27345 .42081 L p F P
0 g
s
.786 .499 .501 r
.27345 .42081 m .26709 .41906 L .2676 .42297 L p F P
0 g
s
.68 .732 .89 r
.28493 .35869 m .29408 .35516 L .29693 .3582 L p F P
0 g
s
.667 .738 .903 r
.29408 .35516 m .28493 .35869 L .28208 .35543 L p F P
0 g
s
.7 .723 .868 r
.2729 .35963 m .28208 .35543 L .28493 .35869 L p F P
0 g
s
.717 .346 .346 r
.32967 .4494 m .32705 .44617 L .33481 .44739 L p F P
0 g
s
.717 .346 .346 r
.33654 .45049 m .32967 .4494 L p .33481 .44739 L F P
0 g
s
.717 .346 .346 r
.33481 .44739 m .33689 .44997 L .33654 .45049 L p F P
0 g
s
.804 .604 .632 r
.23914 .39665 m .24479 .39869 L .24637 .39408 L p F P
0 g
s
.804 .604 .632 r
.24637 .39408 m .24077 .39202 L .23914 .39665 L p F P
0 g
s
.797 .577 .603 r
.24939 .4051 m .24947 .40512 L .25054 .40068 L p F P
0 g
s
.797 .577 .603 r
.25054 .40068 m .24893 .40017 L .24939 .4051 L p F P
0 g
s
.767 .438 .43 r
.29675 .43398 m .29568 .43619 L .29462 .43348 L closepath p F P
0 g
s
.66 .741 .91 r
.29693 .3582 m .30607 .35521 L .30891 .35804 L p F P
0 g
s
.645 .746 .923 r
.30607 .35521 m .29693 .3582 L .29408 .35516 L p F P
0 g
s
.607 .771 .958 r
.35882 .36069 m .3568 .35904 L .35252 .36001 L closepath p F P
0 g
s
.55 .202 .331 r
.50617 .44847 m .50725 .44552 L .49654 .44728 L p F P
0 g
s
.55 .202 .331 r
.49803 .44981 m .50617 .44847 L p .49654 .44728 L F P
0 g
s
.55 .202 .331 r
.49654 .44728 m .49575 .4494 L .49803 .44981 L p F P
0 g
s
.689 .729 .881 r
.28208 .35543 m .2729 .35963 L .27006 .35613 L p F P
0 g
s
.546 .798 .991 r
.39279 .35984 m .38354 .36168 L .38078 .35966 L p F P
0 g
s
.596 .457 .662 r
.59771 .38899 m .59664 .38366 L .58727 .38724 L p F P
0 g
s
.596 .457 .662 r
.58727 .38724 m .58833 .39257 L .59771 .38899 L p F P
0 g
s
.679 .285 .294 r
.36412 .45382 m .36357 .45455 L .36253 .45366 L closepath p F P
0 g
s
.8 .624 .663 r
.23516 .38996 m .24077 .39202 L .24306 .38716 L p F P
0 g
s
.8 .624 .663 r
.24306 .38716 m .23753 .38507 L .23516 .38996 L p F P
0 g
s
.621 .235 .29 r
.41425 .45784 m .41606 .45883 L .41364 .45884 L closepath p F P
0 g
s
.636 .567 .759 r
.58081 .36723 m .5904 .3642 L .59293 .37072 L p F P
0 g
s
.642 .591 .781 r
.58075 .36709 m .58081 .36723 L .5904 .3642 L p F P
0 g
s
.542 .221 .373 r
.52819 .44138 m .52906 .43824 L .51867 .4404 L p F P
0 g
s
.542 .221 .373 r
.51867 .4404 m .5178 .44356 L .52819 .44138 L p F P
0 g
s
.642 .591 .781 r
.5904 .3642 m .59008 .36345 L .58075 .36709 L p F P
0 g
s
.646 .605 .793 r
.57831 .36187 m .58075 .36709 L .59008 .36345 L p F P
0 g
s
.679 .285 .293 r
.35735 .45571 m .35393 .45273 L .36253 .45366 L p F P
0 g
s
.679 .285 .293 r
.3623 .45625 m .35735 .45571 L p .36253 .45366 L F P
0 g
s
.679 .285 .293 r
.36253 .45366 m .36357 .45455 L .3623 .45625 L p F P
0 g
s
.64 .75 .928 r
.30891 .35804 m .31805 .35548 L .32088 .35812 L p F P
0 g
s
.622 .755 .941 r
.31805 .35548 m .30891 .35804 L .30607 .35521 L p F P
0 g
s
.798 .555 .57 r
.24931 .40947 m .25499 .41125 L .25549 .40701 L p F P
0 g
s
.798 .555 .57 r
.24938 .40583 m .24931 .40947 L p .25549 .40701 L F P
0 g
s
.798 .555 .57 r
.25549 .40701 m .24947 .40512 L .24938 .40583 L p F P
0 g
s
.581 .2 .284 r
.45027 .45605 m .45412 .45741 L .44937 .45775 L closepath p F P
0 g
s
.785 .656 .72 r
.2407 .3799 m .24196 .37816 L .23922 .37258 L p F P
0 g
s
.782 .475 .468 r
.28201 .42692 m .28105 .42951 L .28031 .42647 L closepath p F P
0 g
s
.748 .396 .386 r
.31068 .4402 m .31041 .44064 L .3101 .44008 L closepath p F P
0 g
s
.767 .438 .429 r
.28935 .43547 m .28793 .43186 L .29462 .43348 L p F P
0 g
s
.767 .438 .429 r
.29532 .43693 m .28935 .43547 L p .29462 .43348 L F P
0 g
s
.767 .438 .429 r
.29462 .43348 m .29568 .43619 L .29532 .43693 L p F P
0 g
s
.806 .584 .6 r
.24378 .4031 m .24939 .4051 L .24893 .40017 L p F P
0 g
s
.806 .584 .6 r
.24893 .40017 m .24479 .39869 L .24378 .4031 L p F P
0 g
s
.575 .799 .984 r
.39553 .36176 m .4048 .35989 L .40752 .36174 L p F P
0 g
s
.544 .804 .994 r
.4048 .35989 m .39553 .36176 L .39279 .35984 L p F P
0 g
s
.657 .634 .815 r
.56625 .36044 m .57582 .35715 L .57831 .36187 L p F P
0 g
s
.662 .659 .836 r
.56583 .35974 m .56625 .36044 L .57582 .35715 L p F P
0 g
s
.748 .396 .385 r
.305 .44203 m .30307 .43859 L .3101 .44008 L p F P
0 g
s
.748 .396 .385 r
.30903 .44289 m .305 .44203 L p .3101 .44008 L F P
0 g
s
.748 .396 .385 r
.3101 .44008 m .31041 .44064 L .30903 .44289 L p F P
0 g
s
.719 .698 .829 r
.26422 .35929 m .25812 .35757 L .26083 .36122 L closepath p F P
0 g
s
.585 .764 .964 r
.34482 .35867 m .34507 .35862 L .35252 .36001 L p F P
0 g
s
.602 .783 .967 r
.354 .35692 m .34507 .35862 L .35252 .36001 L p F P
0 g
s
.602 .783 .967 r
.35252 .36001 m .3568 .35904 L .354 .35692 L p F P
0 g
s
.609 .225 .29 r
.42624 .45794 m .42777 .45868 L .42578 .45874 L closepath p F P
0 g
s
.595 .213 .288 r
.43825 .45735 m .44038 .45824 L .43769 .45837 L closepath p F P
0 g
s
.62 .758 .945 r
.32088 .35812 m .33003 .35588 L .33285 .35835 L p F P
0 g
s
.596 .765 .96 r
.33003 .35588 m .32088 .35812 L .31805 .35548 L p F P
0 g
s
.785 .656 .72 r
.23922 .37258 m .23526 .37777 L .2407 .3799 L p F P
0 g
s
.794 .643 .695 r
.23198 .38298 m .23753 .38507 L .2407 .3799 L p F P
0 g
s
.794 .643 .695 r
.2407 .3799 m .23526 .37777 L .23198 .38298 L p F P
0 g
s
.645 .787 .95 r
.48005 .35951 m .4796 .35912 L .47699 .35989 L closepath p F P
0 g
s
.644 .796 .956 r
.477 .35719 m .4796 .35912 L .47699 .35989 L p F P
0 g
s
.644 .796 .956 r
.46758 .35981 m .477 .35719 L p .47699 .35989 L F P
0 g
s
.55 .302 .493 r
.57022 .42065 m .57046 .41686 L .56067 .41982 L p F P
0 g
s
.55 .302 .493 r
.56067 .41982 m .56042 .42361 L .57022 .42065 L p F P
0 g
s
.783 .475 .467 r
.27487 .42849 m .27395 .42472 L .28031 .42647 L p F P
0 g
s
.783 .475 .467 r
.28082 .43013 m .27487 .42849 L p .28031 .42647 L F P
0 g
s
.783 .475 .467 r
.28031 .42647 m .28105 .42951 L .28082 .43013 L p F P
0 g
s
.799 .533 .536 r
.25498 .41532 m .26101 .41721 L .26101 .41313 L p F P
0 g
s
.799 .533 .536 r
.26101 .41313 m .25499 .41125 L .25498 .41532 L p F P
0 g
s
.554 .177 .281 r
.47895 .45244 m .47348 .45309 L .47213 .45581 L p F P
0 g
s
.567 .19 .287 r
.46931 .45609 m .47213 .45581 L .47348 .45309 L p F P
0 g
s
.543 .271 .452 r
.55565 .42495 m .55049 .42638 L .55002 .42994 L p F P
0 g
s
.663 .666 .842 r
.56376 .35635 m .56583 .35974 L .57531 .35629 L p F P
0 g
s
.662 .659 .836 r
.57582 .35715 m .57531 .35629 L .56583 .35974 L p F P
0 g
s
.546 .811 .995 r
.41682 .3598 m .40752 .36174 L .4048 .35989 L p F P
0 g
s
.577 .804 .985 r
.40752 .36174 m .41682 .3598 L .41952 .3616 L p F P
0 g
s
.741 .387 .381 r
.31041 .44064 m .31215 .44349 L .30903 .44289 L closepath p F P
0 g
s
.719 .343 .337 r
.32209 .44817 m .32967 .4494 L .32705 .44617 L p F P
0 g
s
.719 .343 .337 r
.32705 .44617 m .3239 .44566 L .32209 .44817 L p F P
0 g
s
.556 .33 .529 r
.58012 .4137 m .58015 .40967 L .5705 .41284 L p F P
0 g
s
.556 .33 .529 r
.5705 .41284 m .57046 .41686 L .58012 .4137 L p F P
0 g
s
.645 .787 .95 r
.48904 .35634 m .49083 .35777 L .48005 .35951 L p F P
0 g
s
.645 .787 .95 r
.48005 .35951 m .4796 .35912 L .48904 .35634 L p F P
0 g
s
.681 .285 .288 r
.34879 .45476 m .35735 .45571 L .35393 .45273 L p F P
0 g
s
.681 .285 .288 r
.34869 .45467 m .34879 .45476 L p .35393 .45273 L F P
0 g
s
.681 .285 .288 r
.35393 .45273 m .35052 .45236 L .34869 .45467 L p F P
0 g
s
.583 .809 .985 r
.41952 .3616 m .42885 .35956 L .43153 .36133 L p F P
0 g
s
.552 .817 .995 r
.42885 .35956 m .41952 .3616 L .41682 .3598 L p F P
0 g
s
.598 .769 .961 r
.34467 .35855 m .34482 .35867 L p .33285 .35835 L F P
0 g
s
.598 .769 .961 r
.33285 .35835 m .33692 .35749 L .34467 .35855 L p F P
0 g
s
.578 .758 .963 r
.33692 .35749 m .33285 .35835 L .33003 .35588 L p F P
0 g
s
.716 .701 .834 r
.26422 .35929 m .27006 .35613 L p .25799 .3574 L F P
0 g
s
.716 .701 .834 r
.25799 .3574 m .25812 .35757 L .26422 .35929 L p F P
0 g
s
.583 .426 .634 r
.59821 .39226 m .59771 .38899 L .58833 .39257 L p F P
0 g
s
.583 .426 .634 r
.58833 .39257 m .58855 .394 L .59821 .39226 L p F P
0 g
s
.67 .274 .287 r
.36357 .45455 m .36611 .45659 L .3623 .45625 L closepath p F P
0 g
s
.537 .242 .414 r
.54938 .43329 m .55002 .42994 L .53994 .4325 L p F P
0 g
s
.537 .242 .414 r
.53994 .4325 m .53929 .43587 L .54938 .43329 L p F P
0 g
s
.55 .253 .417 r
.52924 .43731 m .5318 .43761 L .52906 .43824 L closepath p F P
0 g
s
.592 .812 .984 r
.43153 .36133 m .44088 .35917 L .44354 .36094 L p F P
0 g
s
.562 .821 .994 r
.44088 .35917 m .43153 .36133 L .42885 .35956 L p F P
0 g
s
.552 .178 .284 r
.48454 .45176 m .48371 .45349 L .47895 .45244 L closepath p F P
0 g
s
.554 .177 .281 r
.48323 .4545 m .48371 .45349 L .47895 .45244 L p F P
0 g
s
.554 .177 .281 r
.47213 .45581 m .48323 .4545 L p .47895 .45244 L F P
0 g
s
.789 .501 .5 r
.26537 .42234 m .2676 .42297 L .26709 .41906 L p F P
0 g
s
.789 .501 .5 r
.26709 .41906 m .26629 .41884 L .26537 .42234 L p F P
0 g
s
.694 .3 .297 r
.35052 .45236 m .34869 .45467 L .34559 .45171 L closepath p F P
0 g
s
.763 .681 .772 r
.23887 .37191 m .2396 .37217 L .24636 .36569 L p F P
0 g
s
.763 .681 .772 r
.23644 .3676 m .23887 .37191 L p .24636 .36569 L F P
0 g
s
.763 .681 .772 r
.24636 .36569 m .24091 .36355 L .23644 .3676 L p F P
0 g
s
.754 .689 .788 r
.24636 .36569 m .24869 .36371 L .24586 .35957 L p F P
0 g
s
.754 .689 .788 r
.24586 .35957 m .24091 .36355 L .24636 .36569 L p F P
0 g
s
.73 .357 .345 r
.32196 .44815 m .32209 .44817 L .3239 .44566 L p F P
0 g
s
.73 .357 .345 r
.3239 .44566 m .31951 .44486 L .32196 .44815 L p F P
0 g
s
.603 .813 .981 r
.44354 .36094 m .45292 .35863 L .45556 .36042 L p F P
0 g
s
.576 .825 .992 r
.45292 .35863 m .44354 .36094 L .44088 .35917 L p F P
0 g
s
.662 .774 .933 r
.50363 .3577 m .51311 .35461 L .51565 .35704 L p F P
0 g
s
.657 .789 .945 r
.51177 .35348 m .51311 .35461 L .50363 .3577 L p F P
0 g
s
.657 .789 .945 r
.50363 .3577 m .50132 .35567 L .51177 .35348 L p F P
0 g
s
.654 .786 .945 r
.50132 .35567 m .50363 .3577 L p .49161 .3584 L F P
0 g
s
.668 .758 .918 r
.51565 .35704 m .52515 .35384 L .52767 .3565 L p F P
0 g
s
.663 .781 .937 r
.52515 .35384 m .51565 .35704 L .51311 .35461 L p F P
0 g
s
.74 .701 .814 r
.25812 .35757 m .25788 .35747 L .24869 .36371 L p F P
0 g
s
.735 .687 .805 r
.25788 .35747 m .24869 .36371 L .24586 .35957 L p F P
0 g
s
.654 .786 .945 r
.49161 .3584 m .49917 .35605 L .50132 .35567 L p F P
0 g
s
.65 .802 .956 r
.49161 .3584 m .49917 .35605 L .49083 .35777 L closepath p F P
0 g
s
.591 .826 .988 r
.46496 .35796 m .45556 .36042 L .45292 .35863 L p F P
0 g
s
.624 .82 .976 r
.48904 .35634 m .4796 .35912 L .477 .35719 L p F P
0 g
s
.608 .825 .983 r
.477 .35719 m .46758 .35981 L .46496 .35796 L p F P
0 g
s
.534 .186 .324 r
.51232 .44459 m .50725 .44552 L .50617 .44847 L p F P
0 g
s
.671 .738 .901 r
.52767 .3565 m .53719 .35322 L .53969 .35615 L p F P
0 g
s
.669 .763 .921 r
.53719 .35322 m .52767 .3565 L .52515 .35384 L p F P
0 g
s
.771 .661 .741 r
.2396 .37217 m .23887 .37191 L .23922 .37258 L closepath p F P
0 g
s
.798 .51 .502 r
.26145 .42113 m .26537 .42234 L .26629 .41884 L p F P
0 g
s
.798 .51 .502 r
.26629 .41884 m .26101 .41721 L .26145 .42113 L p F P
0 g
s
.599 .186 .231 r
.41606 .45883 m .41364 .45884 L .41187 .46123 L p F P
0 g
s
.613 .202 .24 r
.41008 .4612 m .41187 .46123 L .41364 .45884 L p F P
0 g
s
.613 .202 .24 r
.41364 .45884 m .40507 .45872 L .41008 .4612 L p F P
0 g
s
.646 .605 .793 r
.59008 .36345 m .5879 .35874 L .57831 .36187 L p F P
0 g
s
.654 .63 .814 r
.5879 .35874 m .57831 .36187 L .57582 .35715 L p F P
0 g
s
.599 .19 .237 r
.42578 .45874 m .41606 .45883 L .42146 .46118 L p F P
0 g
s
.599 .186 .231 r
.41187 .46123 m .42146 .46118 L .41606 .45883 L p F P
0 g
s
.787 .663 .726 r
.23526 .37777 m .23922 .37258 L .23887 .37191 L p F P
0 g
s
.581 .418 .626 r
.59844 .39391 m .59821 .39226 L .58855 .394 L p F P
0 g
s
.581 .418 .626 r
.58855 .394 m .58905 .39747 L .59844 .39391 L p F P
0 g
s
.586 .763 .963 r
.34482 .35867 m .34507 .35862 L .34467 .35855 L closepath p F P
0 g
s
.585 .174 .229 r
.42777 .45868 m .42578 .45874 L .42407 .46116 L p F P
0 g
s
.599 .19 .237 r
.42146 .46118 m .42407 .46116 L .42578 .45874 L p F P
0 g
s
.561 .358 .563 r
.58968 .40631 m .58948 .40204 L .57996 .4054 L p F P
0 g
s
.561 .358 .563 r
.57996 .4054 m .58015 .40967 L .58968 .40631 L p F P
0 g
s
.613 .199 .234 r
.39942 .46102 m .41008 .4612 L .40507 .45872 L p F P
0 g
s
.613 .199 .234 r
.40507 .45872 m .40125 .45866 L .39942 .46102 L p F P
0 g
s
.804 .605 .634 r
.23349 .39461 m .23914 .39665 L .24077 .39202 L p F P
0 g
s
.804 .605 .634 r
.24077 .39202 m .23516 .38996 L .23349 .39461 L p F P
0 g
s
.807 .585 .602 r
.2381 .40108 m .24378 .4031 L .24479 .39869 L p F P
0 g
s
.807 .585 .602 r
.24479 .39869 m .23914 .39665 L .2381 .40108 L p F P
0 g
s
.586 .178 .236 r
.43769 .45837 m .42777 .45868 L .4336 .4609 L p F P
0 g
s
.585 .174 .229 r
.42407 .46116 m .4336 .4609 L .42777 .45868 L p F P
0 g
s
.671 .716 .882 r
.53969 .35615 m .54923 .3528 L .55172 .35606 L p F P
0 g
s
.672 .741 .903 r
.54923 .3528 m .53969 .35615 L .53719 .35322 L p F P
0 g
s
.627 .215 .243 r
.39932 .46101 m .39942 .46102 L .40125 .45866 L p F P
0 g
s
.627 .215 .243 r
.40125 .45866 m .39466 .45842 L .39932 .46101 L p F P
0 g
s
.583 .763 .964 r
.35119 .35493 m .354 .35692 L .34507 .35862 L p F P
0 g
s
.583 .763 .964 r
.34201 .3564 m .35119 .35493 L p .34507 .35862 L F P
0 g
s
.583 .763 .964 r
.34507 .35862 m .34467 .35855 L .34201 .3564 L p F P
0 g
s
.778 .672 .746 r
.23644 .3676 m .23425 .37 L .23887 .37191 L closepath p F P
0 g
s
.787 .663 .726 r
.22981 .37564 m .23526 .37777 L p .23887 .37191 L F P
0 g
s
.787 .663 .726 r
.23887 .37191 m .23425 .37 L .22981 .37564 L p F P
0 g
s
.75 .395 .381 r
.29801 .44052 m .305 .44203 L .30307 .43859 L p F P
0 g
s
.75 .395 .381 r
.30307 .43859 m .29605 .43709 L .29801 .44052 L p F P
0 g
s
.6 .769 .961 r
.34467 .35855 m .34201 .3564 L .33692 .35749 L closepath p F P
0 g
s
.769 .436 .422 r
.28269 .43383 m .28935 .43547 L .28793 .43186 L p F P
0 g
s
.769 .436 .422 r
.28793 .43186 m .28124 .43023 L .28269 .43383 L p F P
0 g
s
.8 .557 .57 r
.24947 .40512 m .24939 .4051 L .24938 .40583 L closepath p F P
0 g
s
.809 .565 .569 r
.24898 .40935 m .24938 .40583 L .24939 .4051 L p F P
0 g
s
.809 .565 .569 r
.24328 .40734 m .24898 .40935 L p .24939 .4051 L F P
0 g
s
.809 .565 .569 r
.24939 .4051 m .24378 .4031 L .24328 .40734 L p F P
0 g
s
.541 .166 .279 r
.49415 .45296 m .49544 .45023 L .48454 .45176 L p F P
0 g
s
.541 .166 .279 r
.48675 .45401 m .49415 .45296 L p .48454 .45176 L F P
0 g
s
.541 .166 .279 r
.48454 .45176 m .48371 .45349 L .48675 .45401 L p F P
0 g
s
.799 .625 .666 r
.22955 .3879 m .23516 .38996 L .23753 .38507 L p F P
0 g
s
.799 .625 .666 r
.23753 .38507 m .23198 .38298 L .22955 .3879 L p F P
0 g
s
.624 .207 .231 r
.38921 .4606 m .39932 .46101 L .39466 .45842 L p F P
0 g
s
.624 .207 .231 r
.38741 .45959 m .38921 .4606 L p .39466 .45842 L F P
0 g
s
.624 .207 .231 r
.39466 .45842 m .38858 .45818 L .38741 .45959 L p F P
0 g
s
.694 .3 .296 r
.34069 .45365 m .33744 .45062 L .34559 .45171 L p F P
0 g
s
.694 .3 .296 r
.34863 .45474 m .34069 .45365 L p .34559 .45171 L F P
0 g
s
.694 .3 .296 r
.34559 .45171 m .34869 .45467 L .34863 .45474 L p F P
0 g
s
.572 .163 .228 r
.44038 .45824 m .43769 .45837 L .43602 .46082 L p F P
0 g
s
.586 .178 .236 r
.4336 .4609 m .43602 .46082 L .43769 .45837 L p F P
0 g
s
.671 .717 .883 r
.56128 .3527 m .55172 .35606 L .54923 .3528 L p F P
0 g
s
.669 .691 .862 r
.55172 .35606 m .56128 .3527 L .56376 .35635 L p F P
0 g
s
.543 .271 .454 r
.56042 .42361 m .56027 .42487 L .55565 .42495 L closepath p F P
0 g
s
.543 .271 .452 r
.55998 .42718 m .56027 .42487 L .55565 .42495 L p F P
0 g
s
.543 .271 .452 r
.55002 .42994 m .55998 .42718 L p .55565 .42495 L F P
0 g
s
.529 .207 .366 r
.5318 .43761 m .52906 .43824 L .52819 .44138 L p F P
0 g
s
.572 .163 .228 r
.43602 .46082 m .4467 .46029 L .44038 .45824 L p F P
0 g
s
.572 .167 .236 r
.44937 .45775 m .44038 .45824 L .4467 .46029 L p F P
0 g
s
.73 .353 .337 r
.31463 .44676 m .32196 .44815 L .31951 .44486 L p F P
0 g
s
.73 .353 .337 r
.31951 .44486 m .31215 .44349 L .31463 .44676 L p F P
0 g
s
.638 .223 .24 r
.38858 .45818 m .38741 .45959 L .38472 .45796 L closepath p F P
0 g
s
.534 .785 .99 r
.366 .3574 m .3568 .35904 L .354 .35692 L p F P
0 g
s
.806 .561 .568 r
.24938 .40583 m .24898 .40935 L .24931 .40947 L closepath p F P
0 g
s
.785 .474 .463 r
.26854 .42672 m .27487 .42849 L .27395 .42472 L p F P
0 g
s
.785 .474 .463 r
.27395 .42472 m .2676 .42297 L .26854 .42672 L p F P
0 g
s
.709 .336 .34 r
.33689 .44997 m .33744 .45062 L .33654 .45049 L closepath p F P
0 g
s
.635 .213 .226 r
.38668 .46049 m .38741 .45959 L .38472 .45796 L p F P
0 g
s
.635 .213 .226 r
.37954 .46003 m .38668 .46049 L p .38472 .45796 L F P
0 g
s
.635 .213 .226 r
.37547 .45757 m .37954 .46003 L p .38472 .45796 L F P
0 g
s
.635 .213 .226 r
.38472 .45796 m .37561 .4574 L .37547 .45757 L p F P
0 g
s
.624 .544 .743 r
.59293 .37072 m .59744 .36947 L .59311 .37125 L closepath p F P
0 g
s
.619 .529 .731 r
.6044 .37401 m .59517 .37782 L .59311 .37125 L p F P
0 g
s
.619 .529 .731 r
.60257 .3681 m .6044 .37401 L p .59311 .37125 L F P
0 g
s
.619 .529 .731 r
.59311 .37125 m .59744 .36947 L .60257 .3681 L p F P
0 g
s
.55 .201 .329 r
.49575 .4494 m .49803 .44981 L .49544 .45023 L closepath p F P
0 g
s
.799 .533 .535 r
.24897 .41343 m .25498 .41532 L .25499 .41125 L p F P
0 g
s
.799 .533 .535 r
.24897 .41185 m .24897 .41343 L p .25499 .41125 L F P
0 g
s
.799 .533 .535 r
.25499 .41125 m .24931 .40947 L .24897 .41185 L p F P
0 g
s
.533 .187 .327 r
.5178 .44356 m .51726 .44506 L .51232 .44459 L closepath p F P
0 g
s
.534 .186 .324 r
.51674 .44651 m .51726 .44506 L .51232 .44459 L p F P
0 g
s
.534 .186 .324 r
.50617 .44847 m .51674 .44651 L p .51232 .44459 L F P
0 g
s
.631 .561 .757 r
.59744 .36947 m .59293 .37072 L .5904 .3642 L p F P
0 g
s
.667 .738 .903 r
.28208 .35543 m .29123 .35224 L .29408 .35516 L p F P
0 g
s
.654 .742 .915 r
.29123 .35224 m .28208 .35543 L .27922 .35229 L p F P
0 g
s
.689 .729 .881 r
.27006 .35613 m .27922 .35229 L .28208 .35543 L p F P
0 g
s
.716 .701 .834 r
.27006 .35613 m .26719 .35276 L .25799 .3574 L p F P
0 g
s
.678 .734 .892 r
.27922 .35229 m .27006 .35613 L .26719 .35276 L p F P
0 g
s
.605 .496 .703 r
.60515 .37685 m .6044 .37401 L .59517 .37782 L p F P
0 g
s
.605 .496 .703 r
.59517 .37782 m .5955 .37903 L .60515 .37685 L p F P
0 g
s
.76 .43 .426 r
.29568 .43619 m .29605 .43709 L .29532 .43693 L closepath p F P
0 g
s
.65 .803 .956 r
.49917 .35605 m .49083 .35777 L .48904 .35634 L p F P
0 g
s
.793 .645 .698 r
.22687 .38106 m .23198 .38298 L .23526 .37777 L p F P
0 g
s
.793 .645 .698 r
.22666 .3805 m .22687 .38106 L p .23526 .37777 L F P
0 g
s
.793 .645 .698 r
.23526 .37777 m .22981 .37564 L .22666 .3805 L p F P
0 g
s
.558 .152 .228 r
.45412 .45741 m .44937 .45775 L .44776 .46024 L p F P
0 g
s
.572 .167 .236 r
.4467 .46029 m .44776 .46024 L .44937 .45775 L p F P
0 g
s
.663 .666 .842 r
.57531 .35629 m .57334 .35303 L .56376 .35635 L p F P
0 g
s
.668 .69 .862 r
.57334 .35303 m .56376 .35635 L .56128 .3527 L p F P
0 g
s
.601 .482 .689 r
.60589 .37988 m .60515 .37685 L .5955 .37903 L p F P
0 g
s
.601 .482 .689 r
.5955 .37903 m .59664 .38366 L .60589 .37988 L p F P
0 g
s
.645 .746 .923 r
.29408 .35516 m .30322 .35249 L .30607 .35521 L p F P
0 g
s
.628 .75 .935 r
.30322 .35249 m .29408 .35516 L .29123 .35224 L p F P
0 g
s
.733 .705 .824 r
.25799 .3574 m .25788 .35747 L .25812 .35757 L closepath p F P
0 g
s
.529 .207 .366 r
.53846 .43903 m .5388 .43772 L .5318 .43761 L p F P
0 g
s
.529 .207 .366 r
.52819 .44138 m .53846 .43903 L p .5318 .43761 L F P
0 g
s
.528 .209 .371 r
.53929 .43587 m .5388 .43772 L .5318 .43761 L closepath p F P
0 g
s
.578 .758 .963 r
.33003 .35588 m .33007 .35588 L .33692 .35749 L p F P
0 g
s
.595 .779 .968 r
.33919 .35425 m .33007 .35588 L .33692 .35749 L p F P
0 g
s
.595 .779 .968 r
.33692 .35749 m .34201 .3564 L .33919 .35425 L p F P
0 g
s
.728 .71 .834 r
.25788 .35747 m .25799 .3574 L .25513 .35378 L p F P
0 g
s
.728 .71 .834 r
.25513 .35378 m .25269 .35523 L .25788 .35747 L p F P
0 g
s
.735 .687 .805 r
.24586 .35957 m .25269 .35523 L .25788 .35747 L p F P
0 g
s
.554 .791 .987 r
.36879 .35938 m .37801 .3578 L .38078 .35966 L p F P
0 g
s
.517 .793 .996 r
.37801 .3578 m .36879 .35938 L .366 .3574 L p F P
0 g
s
.702 .725 .868 r
.26719 .35276 m .25799 .3574 L .25513 .35378 L p F P
0 g
s
.567 .386 .596 r
.59888 .39848 m .59844 .39391 L .58905 .39747 L p F P
0 g
s
.567 .386 .596 r
.58905 .39747 m .58948 .40204 L .59888 .39848 L p F P
0 g
s
.776 .468 .465 r
.28105 .42951 m .28124 .43023 L .28082 .43013 L closepath p F P
0 g
s
.558 .154 .233 r
.46084 .45689 m .4596 .45888 L .45412 .45741 L closepath p F P
0 g
s
.558 .152 .228 r
.45927 .4594 m .4596 .45888 L .45412 .45741 L p F P
0 g
s
.558 .152 .228 r
.44776 .46024 m .45927 .4594 L p .45412 .45741 L F P
0 g
s
.649 .23 .236 r
.37561 .4574 m .37547 .45757 L .37515 .45736 L closepath p F P
0 g
s
.649 .23 .235 r
.37023 .45935 m .36611 .45659 L .37515 .45736 L p F P
0 g
s
.649 .23 .235 r
.37363 .45964 m .37023 .45935 L p .37515 .45736 L F P
0 g
s
.649 .23 .235 r
.37515 .45736 m .37547 .45757 L .37363 .45964 L p F P
0 g
s
.694 .293 .282 r
.33453 .45279 m .34069 .45365 L .33744 .45062 L p F P
0 g
s
.694 .293 .282 r
.33744 .45062 m .33654 .45049 L .33453 .45279 L p F P
0 g
s
.799 .511 .5 r
.25543 .41924 m .26145 .42113 L .26101 .41721 L p F P
0 g
s
.799 .511 .5 r
.26101 .41721 m .25498 .41532 L .25543 .41924 L p F P
0 g
s
.622 .755 .941 r
.30607 .35521 m .31521 .35294 L .31805 .35548 L p F P
0 g
s
.6 .76 .956 r
.31521 .35294 m .30607 .35521 L .30322 .35249 L p F P
0 g
s
.707 .309 .292 r
.3327 .4525 m .33453 .45279 L .33654 .45049 L p F P
0 g
s
.707 .309 .292 r
.33654 .45049 m .32967 .4494 L .3327 .4525 L p F P
0 g
s
.753 .396 .377 r
.29357 .43954 m .29801 .44052 L .29605 .43709 L p F P
0 g
s
.753 .396 .377 r
.29605 .43709 m .29532 .43693 L .29357 .43954 L p F P
0 g
s
.638 .217 .227 r
.37547 .45757 m .37954 .46003 L .37363 .45964 L closepath p F P
0 g
s
.588 .451 .662 r
.60696 .38521 m .60589 .37988 L .59664 .38366 L p F P
0 g
s
.588 .451 .662 r
.59664 .38366 m .59771 .38899 L .60696 .38521 L p F P
0 g
s
.631 .561 .757 r
.60234 .36743 m .59744 .36947 L p .5904 .3642 L F P
0 g
s
.631 .561 .757 r
.5904 .3642 m .60004 .36137 L .60234 .36743 L p F P
0 g
s
.637 .586 .781 r
.59008 .36345 m .5904 .3642 L .60004 .36137 L p F P
0 g
s
.76 .675 .768 r
.24091 .36355 m .23644 .3676 L .23363 .36291 L p F P
0 g
s
.775 .675 .753 r
.23425 .37 m .23644 .3676 L .23363 .36291 L p F P
0 g
s
.531 .262 .451 r
.56988 .42353 m .57022 .42065 L .56042 .42361 L p F P
0 g
s
.531 .262 .451 r
.56042 .42361 m .56027 .42487 L .56988 .42353 L p F P
0 g
s
.76 .675 .768 r
.23363 .36291 m .23536 .36144 L .24091 .36355 L p F P
0 g
s
.749 .69 .795 r
.24091 .36355 m .24586 .35957 L .24301 .3556 L p F P
0 g
s
.749 .69 .795 r
.24301 .3556 m .23536 .36144 L .24091 .36355 L p F P
0 g
s
.546 .798 .991 r
.38078 .35966 m .39004 .35808 L .39279 .35984 L p F P
0 g
s
.503 .8 .999 r
.39004 .35808 m .38078 .35966 L .37801 .3578 L p F P
0 g
s
.763 .41 .385 r
.29115 .43895 m .29357 .43954 L .29532 .43693 L p F P
0 g
s
.763 .41 .385 r
.29532 .43693 m .28935 .43547 L .29115 .43895 L p F P
0 g
s
.771 .437 .42 r
.27928 .43297 m .28269 .43383 L .28124 .43023 L p F P
0 g
s
.771 .437 .42 r
.28124 .43023 m .28082 .43013 L .27928 .43297 L p F P
0 g
s
.521 .175 .322 r
.52717 .44436 m .52819 .44138 L .5178 .44356 L p F P
0 g
s
.521 .175 .322 r
.52277 .44528 m .52717 .44436 L p .5178 .44356 L F P
0 g
s
.521 .175 .322 r
.5178 .44356 m .51726 .44506 L .52277 .44528 L p F P
0 g
s
.524 .149 .27 r
.49803 .44981 m .49544 .45023 L .49415 .45296 L p F P
0 g
s
.539 .293 .491 r
.5799 .41749 m .58012 .4137 L .57046 .41686 L p F P
0 g
s
.539 .293 .491 r
.57046 .41686 m .57022 .42065 L .5799 .41749 L p F P
0 g
s
.543 .139 .225 r
.46931 .45609 m .46084 .45689 L .4596 .45888 L p F P
0 g
s
.637 .586 .781 r
.60004 .36137 m .59928 .35958 L .59008 .36345 L p F P
0 g
s
.642 .601 .793 r
.5879 .35874 m .59008 .36345 L .59928 .35958 L p F P
0 g
s
.654 .63 .814 r
.57582 .35715 m .58542 .35395 L .5879 .35874 L p F P
0 g
s
.659 .657 .837 r
.57531 .35629 m .57582 .35715 L .58542 .35395 L p F P
0 g
s
.731 .352 .333 r
.30731 .44536 m .31463 .44676 L .31215 .44349 L p F P
0 g
s
.731 .352 .333 r
.3072 .4452 m .30731 .44536 L p .31215 .44349 L F P
0 g
s
.731 .352 .333 r
.31215 .44349 m .30903 .44289 L .3072 .4452 L p F P
0 g
s
.781 .449 .426 r
.2762 .43213 m .27928 .43297 L .28082 .43013 L p F P
0 g
s
.781 .449 .426 r
.28082 .43013 m .27487 .42849 L .2762 .43213 L p F P
0 g
s
.775 .675 .753 r
.23363 .36291 m .22895 .3678 L .23425 .37 L p F P
0 g
s
.785 .664 .73 r
.22432 .37351 m .22981 .37564 L .23425 .37 L p F P
0 g
s
.785 .664 .73 r
.23425 .37 m .22895 .3678 L .22432 .37351 L p F P
0 g
s
.807 .586 .602 r
.23243 .39904 m .2381 .40108 L .23914 .39665 L p F P
0 g
s
.807 .586 .602 r
.23914 .39665 m .23349 .39461 L .23243 .39904 L p F P
0 g
s
.803 .608 .638 r
.23013 .39337 m .23349 .39461 L .23516 .38996 L p F P
0 g
s
.803 .608 .638 r
.2292 .38882 m .23013 .39337 L p .23516 .38996 L F P
0 g
s
.803 .608 .638 r
.23516 .38996 m .22955 .3879 L .2292 .38882 L p F P
0 g
s
.596 .765 .96 r
.33001 .35586 m .33003 .35588 L p .31805 .35548 L F P
0 g
s
.596 .765 .96 r
.31805 .35548 m .3223 .35459 L .33001 .35586 L p F P
0 g
s
.576 .753 .962 r
.3223 .35459 m .31805 .35548 L .31521 .35294 L p F P
0 g
s
.523 .229 .409 r
.55935 .43053 m .55998 .42718 L .55002 .42994 L p F P
0 g
s
.523 .229 .409 r
.55002 .42994 m .54938 .43329 L .55935 .43053 L p F P
0 g
s
.73 .694 .816 r
.25269 .35523 m .24586 .35957 L .24301 .3556 L p F P
0 g
s
.651 .229 .229 r
.36125 .45854 m .37023 .45935 L .36611 .45659 L p F P
0 g
s
.651 .229 .229 r
.36058 .45809 m .36125 .45854 L p .36611 .45659 L F P
0 g
s
.651 .229 .229 r
.36611 .45659 m .3623 .45625 L .36058 .45809 L p F P
0 g
s
.81 .566 .569 r
.23759 .40532 m .24328 .40734 L .24378 .4031 L p F P
0 g
s
.81 .566 .569 r
.24378 .4031 m .2381 .40108 L .23759 .40532 L p F P
0 g
s
.524 .153 .277 r
.50617 .44847 m .50523 .45054 L .49803 .44981 L closepath p F P
0 g
s
.524 .149 .27 r
.50492 .45123 m .50523 .45054 L .49803 .44981 L p F P
0 g
s
.524 .149 .27 r
.49415 .45296 m .50492 .45123 L p .49803 .44981 L F P
0 g
s
.544 .804 .994 r
.39279 .35984 m .40207 .35822 L .4048 .35989 L p F P
0 g
s
.495 .806 1 r
.40207 .35822 m .39279 .35984 L .39004 .35808 L p F P
0 g
s
.661 .664 .842 r
.57334 .35303 m .57531 .35629 L .58464 .3526 L p F P
0 g
s
.659 .657 .837 r
.58542 .35395 m .58464 .3526 L .57531 .35629 L p F P
0 g
s
.799 .625 .666 r
.22894 .38767 m .22955 .3879 L .23198 .38298 L p F P
0 g
s
.799 .625 .666 r
.23198 .38298 m .22687 .38106 L .22894 .38767 L p F P
0 g
s
.545 .322 .527 r
.58967 .41034 m .58968 .40631 L .58015 .40967 L p F P
0 g
s
.545 .322 .527 r
.58015 .40967 m .58012 .4137 L .58967 .41034 L p F P
0 g
s
.787 .475 .461 r
.26407 .42546 m .26854 .42672 L .2676 .42297 L p F P
0 g
s
.787 .475 .461 r
.2676 .42297 m .26537 .42234 L .26407 .42546 L p F P
0 g
s
.622 .539 .74 r
.59744 .36947 m .60234 .36743 L .60257 .3681 L closepath p F P
0 g
s
.665 .247 .24 r
.3623 .45625 m .36058 .45809 L .35735 .45571 L closepath p F P
0 g
s
.743 .367 .342 r
.30903 .44289 m .3072 .4452 L .305 .44203 L closepath p F P
0 g
s
.808 .541 .536 r
.24931 .40947 m .24897 .41185 L .24898 .40935 L closepath p F P
0 g
s
.653 .788 .947 r
.50132 .35567 m .50108 .35546 L .49917 .35605 L closepath p F P
0 g
s
.65 .803 .956 r
.49851 .35352 m .50108 .35546 L .49917 .35605 L p F P
0 g
s
.65 .803 .956 r
.48904 .35634 m .49851 .35352 L p .49917 .35605 L F P
0 g
s
.541 .137 .226 r
.47213 .45581 m .47166 .45658 L .46931 .45609 L closepath p F P
0 g
s
.543 .139 .225 r
.47059 .45833 m .47166 .45658 L .46931 .45609 L p F P
0 g
s
.543 .139 .225 r
.46116 .45923 m .47059 .45833 L p .46931 .45609 L F P
0 g
s
.543 .139 .225 r
.4596 .45888 m .46116 .45923 L p .46931 .45609 L F P
0 g
s
.808 .542 .536 r
.24324 .41142 m .24328 .40734 L .24898 .40935 L p F P
0 g
s
.808 .542 .536 r
.24875 .41336 m .24324 .41142 L p .24898 .40935 L F P
0 g
s
.808 .542 .536 r
.24898 .40935 m .24897 .41185 L .24875 .41336 L p F P
0 g
s
.703 .297 .275 r
.32503 .45123 m .3327 .4525 L .32967 .4494 L p F P
0 g
s
.703 .297 .275 r
.32203 .44823 m .32503 .45123 L p .32967 .4494 L F P
0 g
s
.703 .297 .275 r
.32967 .4494 m .32209 .44817 L .32203 .44823 L p F P
0 g
s
.579 .757 .963 r
.33003 .35588 m .33007 .35588 L .33001 .35586 L closepath p F P
0 g
s
.546 .811 .995 r
.4048 .35989 m .41411 .35819 L .41682 .3598 L p F P
0 g
s
.496 .813 1 r
.41411 .35819 m .4048 .35989 L .40207 .35822 L p F P
0 g
s
.576 .758 .964 r
.33635 .35222 m .33919 .35425 L .33007 .35588 L p F P
0 g
s
.576 .758 .964 r
.32719 .35357 m .33635 .35222 L p .33007 .35588 L F P
0 g
s
.576 .758 .964 r
.33007 .35588 m .33001 .35586 L .32719 .35357 L p F P
0 g
s
.597 .765 .959 r
.33001 .35586 m .32719 .35357 L .3223 .35459 L closepath p F P
0 g
s
.541 .165 .277 r
.48371 .45349 m .48675 .45401 L .48323 .4545 L closepath p F P
0 g
s
.531 .261 .45 r
.5698 .42422 m .56988 .42353 L .56027 .42487 L p F P
0 g
s
.531 .261 .45 r
.56027 .42487 m .55998 .42718 L .5698 .42422 L p F P
0 g
s
.516 .198 .366 r
.54858 .43647 m .54938 .43329 L .53929 .43587 L p F P
0 g
s
.516 .198 .366 r
.54493 .4374 m .54858 .43647 L p .53929 .43587 L F P
0 g
s
.516 .198 .366 r
.53929 .43587 m .5388 .43772 L .54493 .4374 L p F P
0 g
s
.654 .788 .946 r
.51057 .35248 m .51177 .35348 L .50132 .35567 L p F P
0 g
s
.654 .788 .946 r
.50132 .35567 m .50108 .35546 L .51057 .35248 L p F P
0 g
s
.528 .124 .218 r
.48173 .45704 m .48323 .4545 L .47213 .45581 L p F P
0 g
s
.528 .124 .218 r
.47749 .45754 m .48173 .45704 L p .47213 .45581 L F P
0 g
s
.528 .124 .218 r
.47213 .45581 m .47166 .45658 L .47749 .45754 L p F P
0 g
s
.573 .418 .632 r
.60771 .39014 m .60696 .38521 L .59771 .38899 L p F P
0 g
s
.573 .418 .632 r
.60331 .39194 m .60771 .39014 L p .59771 .38899 L F P
0 g
s
.573 .418 .632 r
.59771 .38899 m .59821 .39226 L .60331 .39194 L p F P
0 g
s
.791 .643 .697 r
.22397 .37401 m .22432 .37351 L .22981 .37564 L p F P
0 g
s
.791 .643 .697 r
.22981 .37564 m .22666 .3805 L .22397 .37401 L p F P
0 g
s
.796 .486 .465 r
.2623 .42492 m .26407 .42546 L .26537 .42234 L p F P
0 g
s
.796 .486 .465 r
.26537 .42234 m .26145 .42113 L .2623 .42492 L p F P
0 g
s
.665 .246 .239 r
.3527 .45758 m .34879 .45476 L .35735 .45571 L p F P
0 g
s
.665 .246 .239 r
.36024 .45844 m .3527 .45758 L p .35735 .45571 L F P
0 g
s
.665 .246 .239 r
.35735 .45571 m .36058 .45809 L .36024 .45844 L p F P
0 g
s
.552 .817 .995 r
.42624 .35803 m .42885 .35956 L p .41682 .3598 L F P
0 g
s
.552 .817 .995 r
.41682 .3598 m .42589 .35804 L .42624 .35803 L p F P
0 g
s
.504 .82 1 r
.42589 .35804 m .41682 .3598 L .41411 .35819 L p F P
0 g
s
.669 .763 .921 r
.52515 .35384 m .53468 .35061 L .53719 .35322 L p F P
0 g
s
.664 .786 .939 r
.53468 .35061 m .52515 .35384 L .52262 .35148 L p F P
0 g
s
.663 .781 .937 r
.51311 .35461 m .52262 .35148 L .52515 .35384 L p F P
0 g
s
.672 .741 .903 r
.53719 .35322 m .54673 .3499 L .54923 .3528 L p F P
0 g
s
.67 .766 .922 r
.54673 .3499 m .53719 .35322 L .53468 .35061 L p F P
0 g
s
.659 .799 .95 r
.52193 .35092 m .52262 .35148 L .51311 .35461 L p F P
0 g
s
.659 .799 .95 r
.51311 .35461 m .51177 .35348 L .52193 .35092 L p F P
0 g
s
.642 .601 .793 r
.59928 .35958 m .59753 .35574 L .5879 .35874 L p F P
0 g
s
.65 .625 .811 r
.59753 .35574 m .5879 .35874 L .58542 .35395 L p F P
0 g
s
.628 .21 .232 r
.38741 .45959 m .38921 .4606 L .38668 .46049 L closepath p F P
0 g
s
.764 .407 .379 r
.28453 .4373 m .29115 .43895 L .28935 .43547 L p F P
0 g
s
.764 .407 .379 r
.28935 .43547 m .28269 .43383 L .28453 .4373 L p F P
0 g
s
.639 .821 .97 r
.51057 .35248 m .50108 .35546 L .49851 .35352 L p F P
0 g
s
.671 .717 .883 r
.54923 .3528 m .55879 .34945 L .56128 .3527 L p F P
0 g
s
.673 .742 .903 r
.55879 .34945 m .54923 .3528 L .54673 .3499 L p F P
0 g
s
.551 .351 .562 r
.59909 .40276 m .59888 .39848 L .58948 .40204 L p F P
0 g
s
.551 .351 .562 r
.58948 .40204 m .58968 .40631 L .59909 .40276 L p F P
0 g
s
.562 .821 .994 r
.42885 .35956 m .43821 .3576 L .44088 .35917 L p F P
0 g
s
.562 .82 .994 r
.43809 .35754 m .43821 .3576 L .42885 .35956 L p F P
0 g
s
.562 .82 .994 r
.42885 .35956 m .42624 .35803 L .43809 .35754 L p F P
0 g
s
.72 .711 .841 r
.25269 .35523 m .25513 .35378 L .25225 .35028 L p F P
0 g
s
.72 .711 .841 r
.25225 .35028 m .2473 .35305 L .25269 .35523 L p F P
0 g
s
.73 .694 .816 r
.24301 .3556 m .2473 .35305 L .25269 .35523 L p F P
0 g
s
.743 .367 .341 r
.30035 .44383 m .29801 .44052 L .305 .44203 L p F P
0 g
s
.743 .367 .341 r
.30711 .44532 m .30035 .44383 L p .305 .44203 L F P
0 g
s
.743 .367 .341 r
.305 .44203 m .3072 .4452 L .30711 .44532 L p F P
0 g
s
.799 .51 .498 r
.24943 .41734 m .25543 .41924 L .25498 .41532 L p F P
0 g
s
.799 .51 .498 r
.25498 .41532 m .24897 .41343 L .24943 .41734 L p F P
0 g
s
.622 .831 .98 r
.49851 .35352 m .48904 .35634 L .48645 .35454 L p F P
0 g
s
.624 .82 .976 r
.477 .35719 m .48645 .35454 L .48904 .35634 L p F P
0 g
s
.52 .778 .991 r
.35119 .35493 m .34201 .3564 L .33919 .35425 L p F P
0 g
s
.576 .825 .992 r
.44088 .35917 m .45027 .35705 L .45292 .35863 L p F P
0 g
s
.536 .833 .999 r
.45027 .35705 m .44088 .35917 L .43821 .3576 L p F P
0 g
s
.603 .836 .988 r
.48645 .35454 m .477 .35719 L .47439 .35549 L p F P
0 g
s
.608 .825 .983 r
.46496 .35796 m .47439 .35549 L .477 .35719 L p F P
0 g
s
.782 .448 .422 r
.26988 .43035 m .2762 .43213 L .27487 .42849 L p F P
0 g
s
.782 .448 .422 r
.27487 .42849 m .26854 .42672 L .26988 .43035 L p F P
0 g
s
.583 .837 .993 r
.47439 .35549 m .46496 .35796 L .46233 .35634 L p F P
0 g
s
.591 .826 .988 r
.45292 .35863 m .46233 .35634 L .46496 .35796 L p F P
0 g
s
.559 .836 .997 r
.46233 .35634 m .45292 .35863 L .45027 .35705 L p F P
0 g
s
.512 .14 .271 r
.51551 .44928 m .51674 .44651 L .50617 .44847 L p F P
0 g
s
.512 .14 .271 r
.50795 .45068 m .51551 .44928 L p .50617 .44847 L F P
0 g
s
.512 .14 .271 r
.50617 .44847 m .50523 .45054 L .50795 .45068 L p F P
0 g
s
.671 .716 .882 r
.57086 .34936 m .56128 .3527 L .55879 .34945 L p F P
0 g
s
.668 .69 .862 r
.56128 .3527 m .57086 .34936 L .57334 .35303 L p F P
0 g
s
.702 .725 .868 r
.25513 .35378 m .26432 .3495 L .26719 .35276 L p F P
0 g
s
.678 .734 .892 r
.26719 .35276 m .27635 .34926 L .27922 .35229 L p F P
0 g
s
.666 .738 .904 r
.27635 .34926 m .26719 .35276 L .26432 .3495 L p F P
0 g
s
.757 .682 .779 r
.23536 .36144 m .23189 .36015 L .23363 .36291 L closepath p F P
0 g
s
.775 .684 .762 r
.22895 .3678 m .23363 .36291 L .23189 .36015 L p F P
0 g
s
.521 .174 .32 r
.51726 .44506 m .52277 .44528 L .51674 .44651 L closepath p F P
0 g
s
.654 .742 .915 r
.27922 .35229 m .28835 .34942 L .29123 .35224 L p F P
0 g
s
.639 .746 .926 r
.28835 .34942 m .27922 .35229 L .27635 .34926 L p F P
0 g
s
.752 .686 .788 r
.23536 .36144 m .24301 .3556 L p .2308 .3585 L F P
0 g
s
.752 .686 .788 r
.2308 .3585 m .23189 .36015 L .23536 .36144 L p F P
0 g
s
.692 .73 .879 r
.26432 .3495 m .25513 .35378 L .25225 .35028 L p F P
0 g
s
.685 .289 .29 r
.34869 .45467 m .34879 .45476 L .34863 .45474 L closepath p F P
0 g
s
.715 .314 .286 r
.32209 .44817 m .32203 .44823 L .32196 .44815 L closepath p F P
0 g
s
.716 .313 .285 r
.31749 .44991 m .31463 .44676 L .32196 .44815 L p F P
0 g
s
.716 .313 .285 r
.31997 .45038 m .31749 .44991 L p .32196 .44815 L F P
0 g
s
.716 .313 .285 r
.32196 .44815 m .32203 .44823 L .31997 .45038 L p F P
0 g
s
.576 .753 .962 r
.31521 .35294 m .31579 .35284 L .3223 .35459 L p F P
0 g
s
.594 .774 .966 r
.32434 .35136 m .31579 .35284 L .3223 .35459 L p F P
0 g
s
.594 .774 .966 r
.3223 .35459 m .32719 .35357 L .32434 .35136 L p F P
0 g
s
.664 .237 .223 r
.34647 .45685 m .3527 .45758 L .34879 .45476 L p F P
0 g
s
.664 .237 .223 r
.34879 .45476 m .34863 .45474 L .34647 .45685 L p F P
0 g
s
.506 .162 .318 r
.53744 .44199 m .53846 .43903 L .52819 .44138 L p F P
0 g
s
.506 .162 .318 r
.52819 .44138 m .52717 .44436 L .53744 .44199 L p F P
0 g
s
.679 .256 .235 r
.34433 .45656 m .34647 .45685 L .34863 .45474 L p F P
0 g
s
.679 .256 .235 r
.34863 .45474 m .34069 .45365 L .34433 .45656 L p F P
0 g
s
.707 .302 .277 r
.32203 .44823 m .32503 .45123 L .31997 .45038 L closepath p F P
0 g
s
.809 .587 .603 r
.23065 .39838 m .23243 .39904 L .23349 .39461 L p F P
0 g
s
.809 .587 .603 r
.23349 .39461 m .23013 .39337 L .23065 .39838 L p F P
0 g
s
.805 .61 .639 r
.22955 .3879 m .22894 .38767 L .2292 .38882 L closepath p F P
0 g
s
.572 .411 .624 r
.59821 .39226 m .60331 .39194 L .59844 .39391 L closepath p F P
0 g
s
.775 .684 .762 r
.22361 .3656 m .22895 .3678 L p .23189 .36015 L F P
0 g
s
.782 .667 .737 r
.22363 .37323 m .22432 .37351 L .22895 .3678 L p F P
0 g
s
.782 .667 .737 r
.22122 .36839 m .22363 .37323 L p .22895 .3678 L F P
0 g
s
.782 .667 .737 r
.22895 .3678 m .22361 .3656 L .22122 .36839 L p F P
0 g
s
.609 .755 .948 r
.30035 .34987 m .29123 .35224 L .28835 .34942 L p F P
0 g
s
.628 .75 .935 r
.29123 .35224 m .30035 .34987 L .30322 .35249 L p F P
0 g
s
.534 .785 .99 r
.354 .35692 m .3632 .35556 L .366 .3574 L p F P
0 g
s
.49 .785 .997 r
.3632 .35556 m .354 .35692 L .35119 .35493 L p F P
0 g
s
.571 .129 .161 r
.42146 .46118 m .41187 .46123 L .41141 .46173 L p F P
0 g
s
.587 .147 .172 r
.41187 .46123 m .41141 .46173 L .41008 .4612 L closepath p F P
0 g
s
.803 .641 .682 r
.22666 .3805 m .22645 .38088 L .22687 .38106 L closepath p F P
0 g
s
.809 .63 .66 r
.22423 .38572 m .22894 .38767 L .22687 .38106 L p F P
0 g
s
.809 .63 .66 r
.22687 .38106 m .22645 .38088 L .22423 .38572 L p F P
0 g
s
.661 .664 .842 r
.58464 .3526 m .58294 .34976 L .57334 .35303 L p F P
0 g
s
.667 .687 .86 r
.58294 .34976 m .57334 .35303 L .57086 .34936 L p F P
0 g
s
.528 .123 .217 r
.47166 .45658 m .47749 .45754 L .47059 .45833 L closepath p F P
0 g
s
.798 .486 .462 r
.25629 .42303 m .2623 .42492 L .26145 .42113 L p F P
0 g
s
.798 .486 .462 r
.26145 .42113 m .25543 .41924 L .25629 .42303 L p F P
0 g
s
.802 .536 .535 r
.24897 .41185 m .24897 .41343 L .24875 .41336 L closepath p F P
0 g
s
.584 .139 .159 r
.40988 .46339 m .41141 .46173 L .41008 .4612 L p F P
0 g
s
.584 .139 .159 r
.40492 .4633 m .40988 .46339 L p .41008 .4612 L F P
0 g
s
.584 .139 .159 r
.39939 .46105 m .40492 .4633 L p .41008 .4612 L F P
0 g
s
.584 .139 .159 r
.41008 .4612 m .39942 .46102 L .39939 .46105 L p F P
0 g
s
.81 .566 .569 r
.23191 .40328 m .23759 .40532 L .2381 .40108 L p F P
0 g
s
.81 .566 .569 r
.2381 .40108 m .23243 .39904 L .23191 .40328 L p F P
0 g
s
.573 .136 .172 r
.42407 .46116 m .42344 .46188 L .42146 .46118 L closepath p F P
0 g
s
.571 .129 .161 r
.42214 .46336 m .42344 .46188 L .42146 .46118 L p F P
0 g
s
.571 .129 .161 r
.41599 .46339 m .42214 .46336 L p .42146 .46118 L F P
0 g
s
.571 .129 .161 r
.41141 .46173 m .41599 .46339 L p .42146 .46118 L F P
0 g
s
.513 .11 .214 r
.48675 .45401 m .48323 .4545 L .48173 .45704 L p F P
0 g
s
.803 .647 .69 r
.22645 .38088 m .22666 .3805 L .22397 .37401 L p F P
0 g
s
.557 .118 .161 r
.4336 .4609 m .42407 .46116 L .42344 .46188 L p F P
0 g
s
.815 .615 .632 r
.22797 .39251 m .2292 .38882 L .22894 .38767 L p F P
0 g
s
.815 .615 .632 r
.22265 .39033 m .22797 .39251 L p .22894 .38767 L F P
0 g
s
.815 .615 .632 r
.22894 .38767 m .22423 .38572 L .22265 .39033 L p F P
0 g
s
.803 .647 .69 r
.22397 .37401 m .22124 .37865 L .22645 .38088 L p F P
0 g
s
.81 .634 .663 r
.21897 .38351 m .22423 .38572 L .22645 .38088 L p F P
0 g
s
.81 .634 .663 r
.22645 .38088 m .22124 .37865 L .21897 .38351 L p F P
0 g
s
.599 .157 .171 r
.39942 .46102 m .39939 .46105 L .39932 .46101 L closepath p F P
0 g
s
.599 .157 .17 r
.39443 .46301 m .38921 .4606 L .39932 .46101 L p F P
0 g
s
.599 .157 .17 r
.39736 .46313 m .39443 .46301 L p .39932 .46101 L F P
0 g
s
.599 .157 .17 r
.39932 .46101 m .39939 .46105 L .39736 .46313 L p F P
0 g
s
.609 .516 .724 r
.6135 .37 m .61225 .36586 L .60257 .3681 L p F P
0 g
s
.609 .516 .724 r
.60257 .3681 m .6044 .37401 L .6135 .37 L p F P
0 g
s
.615 .535 .741 r
.60234 .36743 m .60257 .3681 L .61225 .36586 L p F P
0 g
s
.813 .61 .629 r
.2292 .38882 m .22797 .39251 L .23013 .39337 L closepath p F P
0 g
s
.624 .557 .759 r
.60004 .36137 m .60234 .36743 L .61142 .36338 L p F P
0 g
s
.615 .535 .741 r
.61225 .36586 m .61142 .36338 L .60234 .36743 L p F P
0 g
s
.587 .142 .161 r
.39939 .46105 m .40492 .4633 L .39736 .46313 L closepath p F P
0 g
s
.558 .122 .169 r
.43602 .46082 m .43549 .46147 L .4336 .4609 L closepath p F P
0 g
s
.557 .118 .161 r
.43415 .46306 m .43549 .46147 L .4336 .4609 L p F P
0 g
s
.557 .118 .161 r
.42779 .46323 m .43415 .46306 L p .4336 .4609 L F P
0 g
s
.557 .118 .161 r
.42344 .46188 m .42779 .46323 L p .4336 .4609 L F P
0 g
s
.724 .7 .827 r
.2473 .35305 m .24301 .3556 L .24014 .35178 L p F P
0 g
s
.752 .686 .788 r
.24301 .3556 m .24014 .35178 L .2308 .3585 L p F P
0 g
s
.596 .488 .701 r
.61486 .37522 m .6135 .37 L .6044 .37401 L p F P
0 g
s
.596 .488 .701 r
.6044 .37401 m .60515 .37685 L .61486 .37522 L p F P
0 g
s
.542 .105 .158 r
.4467 .46029 m .43602 .46082 L .43549 .46147 L p F P
0 g
s
.812 .545 .535 r
.23755 .4094 m .24324 .41142 L .24328 .40734 L p F P
0 g
s
.812 .545 .535 r
.24328 .40734 m .23759 .40532 L .23755 .4094 L p F P
0 g
s
.6 .76 .956 r
.31473 .35254 m .31521 .35294 L p .30322 .35249 L F P
0 g
s
.6 .76 .956 r
.30322 .35249 m .30854 .35136 L .31473 .35254 L p F P
0 g
s
.579 .751 .959 r
.30854 .35136 m .30322 .35249 L .30035 .34987 L p F P
0 g
s
.519 .252 .45 r
.57951 .42093 m .5799 .41749 L .57022 .42065 L p F P
0 g
s
.519 .252 .45 r
.57022 .42065 m .56988 .42353 L .57951 .42093 L p F P
0 g
s
.559 .38 .596 r
.60817 .39473 m .59888 .39848 L .59844 .39391 L p F P
0 g
s
.559 .38 .596 r
.60796 .39256 m .60817 .39473 L p .59844 .39391 L F P
0 g
s
.559 .38 .596 r
.59844 .39391 m .60331 .39194 L .60796 .39256 L p F P
0 g
s
.512 .113 .22 r
.49415 .45296 m .49317 .45468 L .48675 .45401 L closepath p F P
0 g
s
.513 .11 .214 r
.49269 .45552 m .49317 .45468 L .48675 .45401 L p F P
0 g
s
.513 .11 .214 r
.48173 .45704 m .49269 .45552 L p .48675 .45401 L F P
0 g
s
.517 .793 .996 r
.37565 .35635 m .37801 .3578 L p .366 .3574 L F P
0 g
s
.517 .793 .996 r
.366 .3574 m .37426 .35623 L .37565 .35635 L p F P
0 g
s
.47 .788 .999 r
.37426 .35623 m .366 .3574 L .3632 .35556 L p F P
0 g
s
.603 .158 .166 r
.38455 .46257 m .39443 .46301 L .38921 .4606 L p F P
0 g
s
.603 .158 .166 r
.38921 .4606 m .38668 .46049 L .38455 .46257 L p F P
0 g
s
.509 .216 .405 r
.56918 .42757 m .5698 .42422 L .55998 .42718 L p F P
0 g
s
.509 .216 .405 r
.55998 .42718 m .55935 .43053 L .56918 .42757 L p F P
0 g
s
.743 .359 .326 r
.29342 .44229 m .30035 .44383 L .29801 .44052 L p F P
0 g
s
.743 .359 .326 r
.29241 .44085 m .29342 .44229 L p .29801 .44052 L F P
0 g
s
.743 .359 .326 r
.29801 .44052 m .29357 .43954 L .29241 .44085 L p F P
0 g
s
.593 .475 .687 r
.61503 .3759 m .61486 .37522 L .60515 .37685 L p F P
0 g
s
.593 .475 .687 r
.60515 .37685 m .60589 .37988 L .61503 .3759 L p F P
0 g
s
.765 .406 .375 r
.27791 .43563 m .28453 .4373 L .28269 .43383 L p F P
0 g
s
.765 .406 .375 r
.27767 .43516 m .27791 .43563 L p .28269 .43383 L F P
0 g
s
.765 .406 .375 r
.28269 .43383 m .27928 .43297 L .27767 .43516 L p F P
0 g
s
.516 .197 .365 r
.5388 .43772 m .54493 .4374 L .53846 .43903 L closepath p F P
0 g
s
.619 .177 .179 r
.38441 .46256 m .38455 .46257 L .38668 .46049 L p F P
0 g
s
.619 .177 .179 r
.38668 .46049 m .37954 .46003 L .38441 .46256 L p F P
0 g
s
.527 .283 .489 r
.58945 .41413 m .58967 .41034 L .58012 .4137 L p F P
0 g
s
.527 .283 .489 r
.58012 .4137 m .5799 .41749 L .58945 .41413 L p F P
0 g
s
.655 .799 .952 r
.52009 .34943 m .52193 .35092 L .51177 .35348 L p F P
0 g
s
.655 .799 .952 r
.51177 .35348 m .51057 .35248 L .52009 .34943 L p F P
0 g
s
.775 .684 .762 r
.23189 .36015 m .22993 .35928 L .22361 .3656 L p F P
0 g
s
.767 .69 .778 r
.2308 .3585 m .22993 .35928 L .23189 .36015 L closepath p F P
0 g
s
.791 .65 .707 r
.22432 .37351 m .22363 .37323 L .22397 .37401 L closepath p F P
0 g
s
.675 .244 .219 r
.3363 .45541 m .34433 .45656 L .34069 .45365 L p F P
0 g
s
.675 .244 .219 r
.33381 .45344 m .3363 .45541 L p .34069 .45365 L F P
0 g
s
.675 .244 .219 r
.34069 .45365 m .33453 .45279 L .33381 .45344 L p F P
0 g
s
.542 .105 .158 r
.44593 .4625 m .44754 .4605 L .4467 .46029 L p F P
0 g
s
.542 .105 .158 r
.44048 .46278 m .44593 .4625 L p .4467 .46029 L F P
0 g
s
.542 .105 .158 r
.43549 .46147 m .44048 .46278 L p .4467 .46029 L F P
0 g
s
.542 .108 .165 r
.44776 .46024 m .44754 .4605 L .4467 .46029 L closepath p F P
0 g
s
.65 .625 .811 r
.58542 .35395 m .59505 .35084 L .59753 .35574 L p F P
0 g
s
.656 .653 .836 r
.58464 .3526 m .58542 .35395 L .59505 .35084 L p F P
0 g
s
.545 .14 .224 r
.4596 .45888 m .46116 .45923 L .45927 .4594 L closepath p F P
0 g
s
.804 .652 .694 r
.22124 .37865 m .22397 .37401 L .22363 .37323 L p F P
0 g
s
.529 .093 .156 r
.4575 .4617 m .45927 .4594 L .44776 .46024 L p F P
0 g
s
.529 .093 .156 r
.45431 .46193 m .4575 .4617 L p .44776 .46024 L F P
0 g
s
.529 .093 .156 r
.44776 .46024 m .44754 .4605 L .45431 .46193 L p F P
0 g
s
.624 .557 .759 r
.61142 .36338 m .60971 .35877 L .60004 .36137 L p F P
0 g
s
.631 .58 .779 r
.59928 .35958 m .60004 .36137 L .60971 .35877 L p F P
0 g
s
.802 .512 .497 r
.24775 .4168 m .24943 .41734 L .24897 .41343 L p F P
0 g
s
.802 .512 .497 r
.24897 .41343 m .24875 .41336 L .24775 .4168 L p F P
0 g
s
.817 .594 .6 r
.22697 .39691 m .23065 .39838 L .23013 .39337 L p F P
0 g
s
.817 .594 .6 r
.23013 .39337 m .22797 .39251 L .22697 .39691 L p F P
0 g
s
.574 .132 .162 r
.41141 .46173 m .41599 .46339 L .40988 .46339 L closepath p F P
0 g
s
.811 .522 .5 r
.24364 .41536 m .24775 .4168 L .24875 .41336 L p F P
0 g
s
.811 .522 .5 r
.24875 .41336 m .24324 .41142 L .24364 .41536 L p F P
0 g
s
.783 .446 .417 r
.26358 .42857 m .26988 .43035 L .26854 .42672 L p F P
0 g
s
.783 .446 .417 r
.26306 .42715 m .26358 .42857 L p .26854 .42672 L F P
0 g
s
.783 .446 .417 r
.26854 .42672 m .26407 .42546 L .26306 .42715 L p F P
0 g
s
.718 .313 .279 r
.31022 .44849 m .31749 .44991 L .31463 .44676 L p F P
0 g
s
.718 .313 .279 r
.31463 .44676 m .30731 .44536 L .31022 .44849 L p F P
0 g
s
.796 .663 .717 r
.22122 .36839 m .21917 .37124 L .22363 .37323 L closepath p F P
0 g
s
.804 .652 .694 r
.21605 .37641 m .22124 .37865 L p .22363 .37323 L F P
0 g
s
.804 .652 .694 r
.22363 .37323 m .21917 .37124 L .21605 .37641 L p F P
0 g
s
.581 .445 .661 r
.61609 .38122 m .61503 .3759 L .60589 .37988 L p F P
0 g
s
.581 .445 .661 r
.60589 .37988 m .60696 .38521 L .61609 .38122 L p F P
0 g
s
.577 .751 .96 r
.31521 .35294 m .31579 .35284 L .31473 .35254 L closepath p F P
0 g
s
.614 .165 .161 r
.37497 .46191 m .38441 .46256 L .37954 .46003 L p F P
0 g
s
.614 .165 .161 r
.37252 .46064 m .37497 .46191 L p .37954 .46003 L F P
0 g
s
.614 .165 .161 r
.37954 .46003 m .37363 .45964 L .37252 .46064 L p F P
0 g
s
.502 .186 .364 r
.55855 .4337 m .55935 .43053 L .54938 .43329 L p F P
0 g
s
.502 .186 .364 r
.54938 .43329 m .54858 .43647 L .55855 .4337 L p F P
0 g
s
.713 .711 .847 r
.2473 .35305 m .25225 .35028 L .24936 .34689 L p F P
0 g
s
.713 .711 .847 r
.24936 .34689 m .24155 .351 L .2473 .35305 L p F P
0 g
s
.724 .7 .827 r
.24014 .35178 m .24155 .351 L .2473 .35305 L p F P
0 g
s
.503 .8 .999 r
.38888 .35742 m .39004 .35808 L p .37801 .3578 L F P
0 g
s
.503 .8 .999 r
.37801 .3578 m .38326 .35707 L .38888 .35742 L p F P
0 g
s
.517 .791 .995 r
.37801 .3578 m .38326 .35707 L .37565 .35635 L closepath p F P
0 g
s
.494 .122 .263 r
.52277 .44528 m .51674 .44651 L .51551 .44928 L p F P
0 g
s
.638 .596 .791 r
.59753 .35574 m .59928 .35958 L .60836 .35551 L p F P
0 g
s
.631 .58 .779 r
.60971 .35877 m .60836 .35551 L .59928 .35958 L p F P
0 g
s
.574 .751 .961 r
.32148 .34925 m .32434 .35136 L .31579 .35284 L p F P
0 g
s
.574 .751 .961 r
.31235 .35055 m .32148 .34925 L p .31579 .35284 L F P
0 g
s
.574 .751 .961 r
.31579 .35284 m .31473 .35254 L .31235 .35055 L p F P
0 g
s
.534 .313 .526 r
.59909 .40679 m .59909 .40276 L .58968 .40631 L p F P
0 g
s
.534 .313 .526 r
.58968 .40631 m .58967 .41034 L .59909 .40679 L p F P
0 g
s
.529 .092 .154 r
.44754 .4605 m .45431 .46193 L .44593 .4625 L closepath p F P
0 g
s
.775 .42 .383 r
.27928 .43297 m .27767 .43516 L .2762 .43213 L closepath p F P
0 g
s
.56 .12 .161 r
.42344 .46188 m .42779 .46323 L .42214 .46336 L closepath p F P
0 g
s
.499 .099 .213 r
.50348 .45379 m .50492 .45123 L .49415 .45296 L p F P
0 g
s
.499 .099 .213 r
.49665 .4549 m .50348 .45379 L p .49415 .45296 L F P
0 g
s
.499 .099 .213 r
.49415 .45296 m .49317 .45468 L .49665 .4549 L p F P
0 g
s
.63 .184 .174 r
.37363 .45964 m .37252 .46064 L .37023 .45935 L closepath p F P
0 g
s
.754 .375 .336 r
.29357 .43954 m .29241 .44085 L .29115 .43895 L closepath p F P
0 g
s
.659 .661 .841 r
.58294 .34976 m .58464 .3526 L .59384 .3487 L p F P
0 g
s
.656 .653 .836 r
.59505 .35084 m .59384 .3487 L .58464 .3526 L p F P
0 g
s
.774 .687 .768 r
.21865 .36359 m .22361 .3656 L .22993 .35928 L p F P
0 g
s
.774 .687 .768 r
.21843 .36321 m .21865 .36359 L p .22993 .35928 L F P
0 g
s
.774 .687 .768 r
.22993 .35928 m .22488 .35697 L .21843 .36321 L p F P
0 g
s
.763 .694 .786 r
.22993 .35928 m .2308 .3585 L .22793 .35435 L p F P
0 g
s
.763 .694 .786 r
.22793 .35435 m .22488 .35697 L .22993 .35928 L p F P
0 g
s
.742 .709 .82 r
.2308 .3585 m .24014 .35178 L .23883 .35011 L p F P
0 g
s
.742 .709 .82 r
.22793 .35435 m .2308 .3585 L p .23883 .35011 L F P
0 g
s
.545 .107 .159 r
.43549 .46147 m .44048 .46278 L .43415 .46306 L closepath p F P
0 g
s
.601 .76 .955 r
.31473 .35254 m .31235 .35055 L .30854 .35136 L closepath p F P
0 g
s
.689 .263 .231 r
.33453 .45279 m .33381 .45344 L .3327 .4525 L closepath p F P
0 g
s
.514 .08 .153 r
.46116 .45923 m .45927 .4594 L .4575 .4617 L p F P
0 g
s
.495 .806 1 r
.40166 .358 m .40207 .35822 L p .39004 .35808 L F P
0 g
s
.495 .806 1 r
.39004 .35808 m .39293 .35767 L .40166 .358 L p F P
0 g
s
.508 .8 .998 r
.39004 .35808 m .39293 .35767 L .38888 .35742 L closepath p F P
0 g
s
.819 .597 .601 r
.22162 .39474 m .22697 .39691 L .22797 .39251 L p F P
0 g
s
.819 .597 .601 r
.22797 .39251 m .22265 .39033 L .22162 .39474 L p F P
0 g
s
.799 .485 .459 r
.25031 .42112 m .25629 .42303 L .25543 .41924 L p F P
0 g
s
.799 .485 .459 r
.25543 .41924 m .24943 .41734 L .25031 .42112 L p F P
0 g
s
.63 .184 .173 r
.36586 .46114 m .36125 .45854 L .37023 .45935 L p F P
0 g
s
.63 .184 .173 r
.37141 .46165 m .36586 .46114 L p .37023 .45935 L F P
0 g
s
.63 .184 .173 r
.37023 .45935 m .37252 .46064 L .37141 .46165 L p F P
0 g
s
.513 .771 .99 r
.33635 .35222 m .32719 .35357 L .32434 .35136 L p F P
0 g
s
.816 .617 .634 r
.21734 .38813 m .22265 .39033 L .22423 .38572 L p F P
0 g
s
.816 .617 .634 r
.22423 .38572 m .21897 .38351 L .21734 .38813 L p F P
0 g
s
.516 .087 .164 r
.47059 .45833 m .469 .46049 L .46116 .45923 L closepath p F P
0 g
s
.514 .08 .153 r
.46888 .46066 m .469 .46049 L .46116 .45923 L p F P
0 g
s
.514 .08 .153 r
.4575 .4617 m .46888 .46066 L p .46116 .45923 L F P
0 g
s
.781 .666 .737 r
.22361 .3656 m .21865 .36359 L .22122 .36839 L closepath p F P
0 g
s
.812 .568 .569 r
.23057 .40279 m .23191 .40328 L .23243 .39904 L p F P
0 g
s
.812 .568 .569 r
.23243 .39904 m .23065 .39838 L .23057 .40279 L p F P
0 g
s
.689 .263 .23 r
.32848 .45419 m .32503 .45123 L .3327 .4525 L p F P
0 g
s
.689 .263 .23 r
.33226 .45482 m .32848 .45419 L p .3327 .4525 L F P
0 g
s
.689 .263 .23 r
.3327 .4525 m .33381 .45344 L .33226 .45482 L p F P
0 g
s
.655 .233 .231 r
.36058 .45809 m .36125 .45854 L .36024 .45844 L closepath p F P
0 g
s
.673 .742 .903 r
.54673 .3499 m .55631 .34655 L .55879 .34945 L p F P
0 g
s
.672 .768 .922 r
.55631 .34655 m .54673 .3499 L .54423 .34732 L p F P
0 g
s
.67 .766 .922 r
.53468 .35061 m .54423 .34732 L .54673 .3499 L p F P
0 g
s
.49 .146 .31 r
.54493 .4374 m .53846 .43903 L .53744 .44199 L p F P
0 g
s
.667 .79 .94 r
.54423 .34732 m .53468 .35061 L .53216 .3483 L p F P
0 g
s
.664 .786 .939 r
.52262 .35148 m .53216 .3483 L .53468 .35061 L p F P
0 g
s
.755 .375 .335 r
.28673 .44065 m .28453 .4373 L .29115 .43895 L p F P
0 g
s
.755 .375 .335 r
.29151 .44185 m .28673 .44065 L p .29115 .43895 L F P
0 g
s
.755 .375 .335 r
.29115 .43895 m .29241 .44085 L .29151 .44185 L p F P
0 g
s
.671 .716 .882 r
.55879 .34945 m .56838 .34609 L .57086 .34936 L p F P
0 g
s
.674 .742 .902 r
.56838 .34609 m .55879 .34945 L .55631 .34655 L p F P
0 g
s
.661 .808 .954 r
.53191 .34809 m .53216 .3483 L .52262 .35148 L p F P
0 g
s
.661 .808 .954 r
.52262 .35148 m .52193 .35092 L .53191 .34809 L p F P
0 g
s
.666 .738 .904 r
.26432 .3495 m .27345 .34633 L .27635 .34926 L p F P
0 g
s
.653 .741 .914 r
.27345 .34633 m .26432 .3495 L .26142 .34635 L p F P
0 g
s
.692 .73 .879 r
.25225 .35028 m .26142 .34635 L .26432 .3495 L p F P
0 g
s
.496 .813 1 r
.41409 .35818 m .41411 .35819 L p .40207 .35822 L F P
0 g
s
.496 .813 1 r
.40207 .35822 m .40322 .35804 L .41409 .35818 L p F P
0 g
s
.505 .809 1 r
.40207 .35822 m .40322 .35804 L .40166 .358 L closepath p F P
0 g
s
.511 .139 .27 r
.50523 .45054 m .50795 .45068 L .50492 .45123 L closepath p F P
0 g
s
.792 .458 .423 r
.26407 .42546 m .26306 .42715 L .2623 .42492 L closepath p F P
0 g
s
.81 .636 .666 r
.21371 .38129 m .21897 .38351 L .22124 .37865 L p F P
0 g
s
.81 .636 .666 r
.22124 .37865 m .21605 .37641 L .21371 .38129 L p F P
0 g
s
.735 .357 .335 r
.3072 .4452 m .30731 .44536 L .30711 .44532 L closepath p F P
0 g
s
.776 .42 .382 r
.2716 .43386 m .26988 .43035 L .2762 .43213 L p F P
0 g
s
.776 .42 .382 r
.27741 .4355 m .2716 .43386 L p .2762 .43213 L F P
0 g
s
.776 .42 .382 r
.2762 .43213 m .27767 .43516 L .27741 .4355 L p F P
0 g
s
.681 .733 .89 r
.26142 .34635 m .25225 .35028 L .24936 .34689 L p F P
0 g
s
.796 .669 .724 r
.21917 .37124 m .22122 .36839 L .21865 .36359 L p F P
0 g
s
.813 .545 .534 r
.23188 .40736 m .23755 .4094 L .23759 .40532 L p F P
0 g
s
.813 .545 .534 r
.23759 .40532 m .23191 .40328 L .23188 .40736 L p F P
0 g
s
.558 .382 .598 r
.60331 .39194 m .60771 .39014 L .60796 .39256 L closepath p F P
0 g
s
.638 .596 .791 r
.60836 .35551 m .6072 .3529 L .59753 .35574 L p F P
0 g
s
.646 .617 .806 r
.6072 .3529 m .59753 .35574 L .59505 .35084 L p F P
0 g
s
.565 .411 .63 r
.61684 .38616 m .61609 .38122 L .60696 .38521 L p F P
0 g
s
.565 .411 .63 r
.60696 .38521 m .60771 .39014 L .61684 .38616 L p F P
0 g
s
.641 .829 .973 r
.52009 .34943 m .51057 .35248 L .50802 .35064 L p F P
0 g
s
.639 .821 .97 r
.49851 .35352 m .50802 .35064 L .51057 .35248 L p F P
0 g
s
.72 .311 .273 r
.30487 .44743 m .31022 .44849 L .30731 .44536 L p F P
0 g
s
.72 .311 .273 r
.30731 .44536 m .30711 .44532 L .30487 .44743 L p F P
0 g
s
.733 .329 .285 r
.30306 .44703 m .30487 .44743 L .30711 .44532 L p F P
0 g
s
.733 .329 .285 r
.30711 .44532 m .30035 .44383 L .30306 .44703 L p F P
0 g
s
.639 .746 .926 r
.27635 .34926 m .28547 .3467 L .28835 .34942 L p F P
0 g
s
.623 .748 .936 r
.28547 .3467 m .27635 .34926 L .27345 .34633 L p F P
0 g
s
.541 .343 .561 r
.60839 .39901 m .60817 .39473 L .59888 .39848 L p F P
0 g
s
.541 .343 .561 r
.59888 .39848 m .59909 .40276 L .60839 .39901 L p F P
0 g
s
.492 .122 .264 r
.52717 .44436 m .52681 .44519 L .52277 .44528 L closepath p F P
0 g
s
.494 .122 .263 r
.52596 .44712 m .52681 .44519 L .52277 .44528 L p F P
0 g
s
.494 .122 .263 r
.51551 .44928 m .52596 .44712 L p .52277 .44528 L F P
0 g
s
.667 .687 .86 r
.57086 .34936 m .58047 .34604 L .58294 .34976 L p F P
0 g
s
.671 .713 .88 r
.58047 .34604 m .57086 .34936 L .56838 .34609 L p F P
0 g
s
.821 .576 .568 r
.22646 .40115 m .23057 .40279 L .23065 .39838 L p F P
0 g
s
.821 .576 .568 r
.23065 .39838 m .22697 .39691 L .22646 .40115 L p F P
0 g
s
.629 .177 .16 r
.35793 .46038 m .36586 .46114 L .36125 .45854 L p F P
0 g
s
.629 .177 .16 r
.36125 .45854 m .36024 .45844 L .35793 .46038 L p F P
0 g
s
.504 .82 1 r
.41411 .35819 m .41416 .35818 L .42589 .35804 L p F P
0 g
s
.509 .818 1 r
.41411 .35819 m .41416 .35818 L .41409 .35818 L closepath p F P
0 g
s
.623 .84 .983 r
.50802 .35064 m .49851 .35352 L .49594 .35183 L p F P
0 g
s
.622 .831 .98 r
.48645 .35454 m .49594 .35183 L .49851 .35352 L p F P
0 g
s
.506 .818 1 r
.41416 .35818 m .41409 .35818 L .41138 .35681 L p F P
0 g
s
.494 .813 1 r
.41409 .35818 m .41138 .35681 L .40322 .35804 L closepath p F P
0 g
s
.527 .831 .999 r
.42345 .35666 m .41416 .35818 L .42589 .35804 L p F P
0 g
s
.506 .818 1 r
.42072 .3555 m .42345 .35666 L .41416 .35818 L p F P
0 g
s
.506 .818 1 r
.41138 .35681 m .42072 .3555 L p .41416 .35818 L F P
0 g
s
.52 .778 .991 r
.33919 .35425 m .34836 .35306 L .35119 .35493 L p F P
0 g
s
.473 .776 .997 r
.34836 .35306 m .33919 .35425 L .33635 .35222 L p F P
0 g
s
.646 .198 .174 r
.35701 .46028 m .35793 .46038 L .36024 .45844 L p F P
0 g
s
.646 .198 .174 r
.36024 .45844 m .3527 .45758 L .35701 .46028 L p F P
0 g
s
.579 .751 .959 r
.30035 .34987 m .30216 .34955 L .30854 .35136 L p F P
0 g
s
.598 .768 .961 r
.30947 .34825 m .30216 .34955 L .30854 .35136 L p F P
0 g
s
.598 .768 .961 r
.30854 .35136 m .31235 .35055 L .30947 .34825 L p F P
0 g
s
.502 .809 1 r
.40863 .3556 m .41138 .35681 L .40322 .35804 L p F P
0 g
s
.502 .809 1 r
.39932 .35676 m .40863 .3556 L p .40322 .35804 L F P
0 g
s
.502 .809 1 r
.40322 .35804 m .40166 .358 L .39932 .35676 L p F P
0 g
s
.527 .831 .999 r
.42589 .35804 m .42616 .35799 L .42345 .35666 L p F P
0 g
s
.55 .817 .996 r
.42624 .35803 m .42616 .35799 L .42589 .35804 L closepath p F P
0 g
s
.539 .813 .997 r
.43552 .3563 m .43809 .35754 L .42624 .35803 L p F P
0 g
s
.539 .813 .997 r
.42624 .35803 m .42616 .35799 L .43552 .3563 L p F P
0 g
s
.717 .705 .838 r
.24155 .351 m .23883 .35011 L .24014 .35178 L closepath p F P
0 g
s
.793 .459 .423 r
.25754 .42668 m .25629 .42303 L .2623 .42492 L p F P
0 g
s
.793 .459 .423 r
.26241 .42822 m .25754 .42668 L p .2623 .42492 L F P
0 g
s
.793 .459 .423 r
.2623 .42492 m .26306 .42715 L .26241 .42822 L p F P
0 g
s
.495 .806 1 r
.40166 .358 m .39932 .35676 L .39293 .35767 L closepath p F P
0 g
s
.499 .069 .154 r
.47749 .45754 m .47059 .45833 L .469 .46049 L p F P
0 g
s
.602 .844 .99 r
.49594 .35183 m .48645 .35454 L .48386 .35298 L p F P
0 g
s
.603 .836 .988 r
.47439 .35549 m .48386 .35298 L .48645 .35454 L p F P
0 g
s
.519 .252 .449 r
.57949 .42106 m .57951 .42093 L .56988 .42353 L p F P
0 g
s
.519 .252 .449 r
.56988 .42353 m .5698 .42422 L .57949 .42106 L p F P
0 g
s
.469 .825 .996 r
.43552 .3563 m .42616 .35799 L .42345 .35666 L p F P
0 g
s
.812 .522 .498 r
.23795 .41333 m .24364 .41536 L .24324 .41142 L p F P
0 g
s
.812 .522 .498 r
.24324 .41142 m .23755 .4094 L .23795 .41333 L p F P
0 g
s
.796 .669 .724 r
.21408 .36895 m .21917 .37124 L p .21865 .36359 L F P
0 g
s
.804 .655 .697 r
.21086 .37415 m .21605 .37641 L .21917 .37124 L p F P
0 g
s
.804 .655 .697 r
.21917 .37124 m .21408 .36895 L .21086 .37415 L p F P
0 g
s
.609 .755 .948 r
.29863 .34837 m .30035 .34987 L p .28835 .34942 L F P
0 g
s
.609 .755 .948 r
.28835 .34942 m .29575 .34775 L .29863 .34837 L p F P
0 g
s
.588 .751 .955 r
.29575 .34775 m .28835 .34942 L .28547 .3467 L p F P
0 g
s
.592 .842 .992 r
.48302 .35256 m .48386 .35298 L .47439 .35549 L p F P
0 g
s
.592 .842 .992 r
.47439 .35549 m .47212 .35422 L .48302 .35256 L p F P
0 g
s
.583 .837 .993 r
.47212 .35422 m .47439 .35549 L p .46233 .35634 L F P
0 g
s
.536 .833 .999 r
.4497 .35677 m .45027 .35705 L p .43821 .3576 L F P
0 g
s
.536 .833 .999 r
.43821 .3576 m .43874 .3575 L .4497 .35677 L p F P
0 g
s
.534 .834 .999 r
.43821 .3576 m .43874 .3575 L .43809 .35754 L closepath p F P
0 g
s
.583 .837 .993 r
.46233 .35634 m .46988 .35449 L .47212 .35422 L p F P
0 g
s
.575 .844 .995 r
.46233 .35634 m .46988 .35449 L .46105 .35567 L closepath p F P
0 g
s
.559 .836 .997 r
.46105 .35567 m .46233 .35634 L p .45027 .35705 L F P
0 g
s
.714 .707 .842 r
.24155 .351 m .24936 .34689 L p .23725 .34812 L F P
0 g
s
.714 .707 .842 r
.23725 .34812 m .23883 .35011 L .24155 .351 L p F P
0 g
s
.504 .8 .999 r
.39655 .35546 m .39932 .35676 L .39293 .35767 L p F P
0 g
s
.504 .8 .999 r
.38727 .35651 m .39655 .35546 L p .39293 .35767 L F P
0 g
s
.504 .8 .999 r
.39293 .35767 m .38888 .35742 L .38727 .35651 L p F P
0 g
s
.559 .836 .997 r
.45027 .35705 m .45311 .35642 L .46105 .35567 L p F P
0 g
s
.553 .84 .998 r
.45027 .35705 m .45311 .35642 L .4497 .35677 L closepath p F P
0 g
s
.679 .25 .221 r
.33381 .45344 m .3363 .45541 L .33226 .45482 L closepath p F P
0 g
s
.659 .661 .841 r
.59384 .3487 m .59258 .34655 L .58294 .34976 L p F P
0 g
s
.665 .683 .857 r
.59258 .34655 m .58294 .34976 L .58047 .34604 L p F P
0 g
s
.657 .808 .955 r
.52965 .3463 m .53191 .34809 L .52193 .35092 L p F P
0 g
s
.657 .808 .955 r
.52193 .35092 m .52009 .34943 L .52965 .3463 L p F P
0 g
s
.48 .079 .203 r
.50795 .45068 m .50492 .45123 L .50348 .45379 L p F P
0 g
s
.688 .255 .215 r
.32088 .45289 m .32848 .45419 L .32503 .45123 L p F P
0 g
s
.688 .255 .215 r
.31893 .45122 m .32088 .45289 L p .32503 .45123 L F P
0 g
s
.688 .255 .215 r
.32503 .45123 m .31997 .45038 L .31893 .45122 L p F P
0 g
s
.532 .834 .999 r
.43874 .3575 m .43809 .35754 L .43552 .3563 L p F P
0 g
s
.532 .833 .999 r
.4497 .35677 m .44761 .35573 L .43874 .3575 L closepath p F P
0 g
s
.532 .834 .999 r
.44493 .35461 m .44761 .35573 L .43874 .3575 L p F P
0 g
s
.532 .834 .999 r
.43552 .3563 m .44493 .35461 L p .43874 .3575 L F P
0 g
s
.503 .8 .999 r
.38888 .35742 m .38727 .35651 L .38326 .35707 L closepath p F P
0 g
s
.478 .107 .257 r
.53639 .4445 m .53744 .44199 L .52717 .44436 L p F P
0 g
s
.478 .107 .257 r
.52717 .44436 m .52681 .44519 L .53639 .4445 L p F P
0 g
s
.454 .771 .997 r
.35704 .35426 m .35119 .35493 L .34836 .35306 L p F P
0 g
s
.49 .785 .997 r
.36204 .35486 m .3632 .35556 L p .35119 .35493 L F P
0 g
s
.49 .785 .997 r
.35119 .35493 m .35704 .35426 L .36204 .35486 L p F P
0 g
s
.495 .203 .4 r
.57889 .42441 m .57949 .42106 L .5698 .42422 L p F P
0 g
s
.495 .203 .4 r
.5698 .42422 m .56918 .42757 L .57889 .42441 L p F P
0 g
s
.506 .242 .448 r
.58914 .41702 m .58945 .41413 L .5799 .41749 L p F P
0 g
s
.506 .242 .448 r
.5799 .41749 m .57951 .42093 L .58914 .41702 L p F P
0 g
s
.64 .184 .153 r
.34859 .45927 m .35701 .46028 L .3527 .45758 L p F P
0 g
s
.64 .184 .153 r
.34568 .45745 m .34859 .45927 L p .3527 .45758 L F P
0 g
s
.64 .184 .153 r
.3527 .45758 m .34647 .45685 L .34568 .45745 L p F P
0 g
s
.496 .067 .155 r
.48173 .45704 m .48109 .45792 L .47749 .45754 L closepath p F P
0 g
s
.499 .069 .154 r
.48004 .45938 m .48109 .45792 L .47749 .45754 L p F P
0 g
s
.499 .069 .154 r
.46968 .46057 m .48004 .45938 L p .47749 .45754 L F P
0 g
s
.499 .069 .154 r
.469 .46049 m .46968 .46057 L p .47749 .45754 L F P
0 g
s
.582 .744 .954 r
.30035 .34987 m .30216 .34955 L .29863 .34837 L closepath p F P
0 g
s
.801 .486 .457 r
.24633 .41983 m .25031 .42112 L .24943 .41734 L p F P
0 g
s
.801 .486 .457 r
.24943 .41734 m .24775 .4168 L .24633 .41983 L p F P
0 g
s
.488 .145 .311 r
.54858 .43647 m .54839 .43702 L .54493 .4374 L closepath p F P
0 g
s
.49 .146 .31 r
.54758 .43943 m .54839 .43702 L .54493 .4374 L p F P
0 g
s
.49 .146 .31 r
.53744 .44199 m .54758 .43943 L p .54493 .4374 L F P
0 g
s
.513 .792 .996 r
.38448 .35511 m .38727 .35651 L .38326 .35707 L p F P
0 g
s
.513 .792 .996 r
.37523 .3561 m .38448 .35511 L p .38326 .35707 L F P
0 g
s
.513 .792 .996 r
.38326 .35707 m .37565 .35635 L .37523 .3561 L p F P
0 g
s
.756 .371 .325 r
.28016 .43897 m .28673 .44065 L .28453 .4373 L p F P
0 g
s
.756 .371 .325 r
.28453 .4373 m .27791 .43563 L .28016 .43897 L p F P
0 g
s
.48 .082 .208 r
.51551 .44928 m .51476 .45067 L .50795 .45068 L closepath p F P
0 g
s
.48 .079 .203 r
.51411 .45186 m .51476 .45067 L .50795 .45068 L p F P
0 g
s
.48 .079 .203 r
.50348 .45379 m .51411 .45186 L p .50795 .45068 L F P
0 g
s
.768 .677 .762 r
.21559 .3585 m .21977 .35467 L .22488 .35697 L p F P
0 g
s
.768 .677 .762 r
.22488 .35697 m .21843 .36321 L .21559 .3585 L p F P
0 g
s
.759 .696 .792 r
.22488 .35697 m .22793 .35435 L .22505 .35036 L p F P
0 g
s
.759 .696 .792 r
.22505 .35036 m .21977 .35467 L .22488 .35697 L p F P
0 g
s
.618 .169 .163 r
.37252 .46064 m .37497 .46191 L .37141 .46165 L closepath p F P
0 g
s
.486 .171 .358 r
.5684 .43074 m .56918 .42757 L .55935 .43053 L p F P
0 g
s
.486 .171 .358 r
.55935 .43053 m .55855 .4337 L .5684 .43074 L p F P
0 g
s
.788 .677 .742 r
.21843 .36321 m .21825 .36341 L .21865 .36359 L closepath p F P
0 g
s
.796 .669 .724 r
.21865 .36359 m .21825 .36341 L .21408 .36895 L p F P
0 g
s
.82 .599 .602 r
.2163 .39256 m .22162 .39474 L .22265 .39033 L p F P
0 g
s
.82 .599 .602 r
.22265 .39033 m .21734 .38813 L .2163 .39256 L p F P
0 g
s
.742 .709 .82 r
.23883 .35011 m .23614 .34881 L .22793 .35435 L p F P
0 g
s
.737 .696 .812 r
.23614 .34881 m .22793 .35435 L .22505 .35036 L p F P
0 g
s
.732 .324 .276 r
.29617 .44547 m .30306 .44703 L .30035 .44383 L p F P
0 g
s
.732 .324 .276 r
.30035 .44383 m .29342 .44229 L .29617 .44547 L p F P
0 g
s
.735 .712 .83 r
.23725 .34812 m .23614 .34881 L .23883 .35011 L closepath p F P
0 g
s
.515 .273 .487 r
.59889 .41058 m .59909 .40679 L .58967 .41034 L p F P
0 g
s
.515 .273 .487 r
.58967 .41034 m .58945 .41413 L .59889 .41058 L p F P
0 g
s
.551 .841 .998 r
.45311 .35642 m .4497 .35677 L .44761 .35573 L p F P
0 g
s
.602 .509 .721 r
.62251 .36579 m .62198 .36402 L .61225 .36586 L p F P
0 g
s
.602 .509 .721 r
.61225 .36586 m .6135 .37 L .62251 .36579 L p F P
0 g
s
.606 .526 .738 r
.61142 .36338 m .61225 .36586 L .62198 .36402 L p F P
0 g
s
.823 .578 .569 r
.2211 .39899 m .22646 .40115 L .22697 .39691 L p F P
0 g
s
.823 .578 .569 r
.22697 .39691 m .22162 .39474 L .2211 .39899 L p F P
0 g
s
.786 .682 .749 r
.21825 .36341 m .21843 .36321 L .21559 .3585 L p F P
0 g
s
.747 .364 .328 r
.29241 .44085 m .29342 .44229 L .29151 .44185 L closepath p F P
0 g
s
.816 .618 .635 r
.21205 .38592 m .21734 .38813 L .21897 .38351 L p F P
0 g
s
.816 .618 .635 r
.21897 .38351 m .21371 .38129 L .21205 .38592 L p F P
0 g
s
.777 .416 .372 r
.26533 .43206 m .2716 .43386 L .26988 .43035 L p F P
0 g
s
.777 .416 .372 r
.26988 .43035 m .26358 .42857 L .26533 .43206 L p F P
0 g
s
.786 .682 .749 r
.21559 .3585 m .21331 .36105 L .21825 .36341 L p F P
0 g
s
.796 .673 .729 r
.20898 .36666 m .21408 .36895 L .21825 .36341 L p F P
0 g
s
.796 .673 .729 r
.21825 .36341 m .21331 .36105 L .20898 .36666 L p F P
0 g
s
.618 .55 .756 r
.60971 .35877 m .61142 .36338 L .62039 .35912 L p F P
0 g
s
.606 .526 .738 r
.62198 .36402 m .62039 .35912 L .61142 .36338 L p F P
0 g
s
.546 .373 .598 r
.61732 .39075 m .61684 .38616 L .60771 .39014 L p F P
0 g
s
.546 .373 .598 r
.61082 .39358 m .61732 .39075 L p .60771 .39014 L F P
0 g
s
.546 .373 .598 r
.60771 .39014 m .60796 .39256 L .61082 .39358 L p F P
0 g
s
.703 .274 .228 r
.31997 .45038 m .31893 .45122 L .31749 .44991 L closepath p F P
0 g
s
.482 .052 .146 r
.49105 .45789 m .49269 .45552 L .48173 .45704 L p F P
0 g
s
.482 .052 .146 r
.48757 .45837 m .49105 .45789 L p .48173 .45704 L F P
0 g
s
.482 .052 .146 r
.48173 .45704 m .48109 .45792 L .48757 .45837 L p F P
0 g
s
.587 .478 .698 r
.62402 .37168 m .62251 .36579 L .6135 .37 L p F P
0 g
s
.587 .478 .698 r
.617 .37499 m .62402 .37168 L p .6135 .37 L F P
0 g
s
.587 .478 .698 r
.6135 .37 m .61486 .37522 L .617 .37499 L p F P
0 g
s
.81 .498 .462 r
.24442 .41917 m .24633 .41983 L .24775 .4168 L p F P
0 g
s
.81 .498 .462 r
.24775 .4168 m .24364 .41536 L .24442 .41917 L p F P
0 g
s
.646 .617 .806 r
.59505 .35084 m .60472 .34785 L .6072 .3529 L p F P
0 g
s
.651 .648 .833 r
.59384 .3487 m .59505 .35084 L .60472 .34785 L p F P
0 g
s
.47 .788 .999 r
.3632 .35556 m .36546 .35532 L .37426 .35623 L p F P
0 g
s
.486 .781 .997 r
.3632 .35556 m .36546 .35532 L .36204 .35486 L closepath p F P
0 g
s
.498 .097 .211 r
.49317 .45468 m .49665 .4549 L .49269 .45552 L closepath p F P
0 g
s
.656 .205 .168 r
.34647 .45685 m .34568 .45745 L .34433 .45656 L closepath p F P
0 g
s
.815 .547 .533 r
.22996 .40665 m .23188 .40736 L .23191 .40328 L p F P
0 g
s
.815 .547 .533 r
.23191 .40328 m .23057 .40279 L .22996 .40665 L p F P
0 g
s
.555 .838 .998 r
.46105 .35567 m .45969 .35497 L .45311 .35642 L closepath p F P
0 g
s
.551 .841 .998 r
.45704 .35383 m .45969 .35497 L .45311 .35642 L p F P
0 g
s
.551 .841 .998 r
.44761 .35573 m .45704 .35383 L p .45311 .35642 L F P
0 g
s
.518 .793 .996 r
.37565 .35635 m .37523 .3561 L .37426 .35623 L closepath p F P
0 g
s
.81 .637 .668 r
.20846 .37905 m .21371 .38129 L .21605 .37641 L p F P
0 g
s
.81 .637 .668 r
.21605 .37641 m .21086 .37415 L .20846 .37905 L p F P
0 g
s
.515 .764 .987 r
.32148 .34925 m .31235 .35055 L .30947 .34825 L p F P
0 g
s
.542 .072 .088 r
.41599 .46339 m .40988 .46339 L .40858 .46454 L p F P
0 g
s
.56 .093 .102 r
.40988 .46339 m .40858 .46454 L .40492 .4633 L closepath p F P
0 g
s
.542 .072 .088 r
.42 .46536 m .42064 .46476 L .41599 .46339 L p F P
0 g
s
.542 .072 .088 r
.41125 .46536 m .42 .46536 L p .41599 .46339 L F P
0 g
s
.542 .072 .088 r
.40858 .46454 m .41125 .46536 L p .41599 .46339 L F P
0 g
s
.545 .081 .102 r
.42214 .46336 m .42064 .46476 L .41599 .46339 L closepath p F P
0 g
s
.528 .06 .088 r
.42779 .46323 m .42214 .46336 L .42064 .46476 L p F P
0 g
s
.579 .744 .955 r
.30658 .34603 m .30947 .34825 L .30216 .34955 L p F P
0 g
s
.579 .744 .955 r
.29747 .34736 m .30658 .34603 L p .30216 .34955 L F P
0 g
s
.579 .744 .955 r
.30216 .34955 m .29863 .34837 L .29747 .34736 L p F P
0 g
s
.501 .803 .999 r
.37243 .35457 m .36546 .35532 L .37426 .35623 L p F P
0 g
s
.501 .803 .999 r
.37426 .35623 m .37523 .3561 L .37243 .35457 L p F P
0 g
s
.556 .082 .086 r
.40767 .46534 m .40858 .46454 L .40492 .4633 L p F P
0 g
s
.556 .082 .086 r
.40043 .46517 m .40767 .46534 L p .40492 .4633 L F P
0 g
s
.556 .082 .086 r
.39653 .46382 m .40043 .46517 L p .40492 .4633 L F P
0 g
s
.556 .082 .086 r
.40492 .4633 m .39736 .46313 L .39653 .46382 L p F P
0 g
s
.703 .274 .227 r
.31349 .45151 m .31022 .44849 L .31749 .44991 L p F P
0 g
s
.703 .274 .227 r
.31758 .45231 m .31349 .45151 L p .31749 .44991 L F P
0 g
s
.703 .274 .227 r
.31749 .44991 m .31893 .45122 L .31758 .45231 L p F P
0 g
s
.618 .55 .756 r
.62039 .35912 m .61942 .35644 L .60971 .35877 L p F P
0 g
s
.623 .572 .776 r
.60836 .35551 m .60971 .35877 L .61942 .35644 L p F P
0 g
s
.477 .106 .256 r
.53627 .44478 m .53639 .4445 L .52681 .44519 L p F P
0 g
s
.477 .106 .256 r
.52681 .44519 m .52596 .44712 L .53627 .44478 L p F P
0 g
s
.656 .204 .167 r
.34039 .45818 m .3363 .45541 L .34433 .45656 L p F P
0 g
s
.656 .204 .167 r
.34404 .4587 m .34039 .45818 L p .34433 .45656 L F P
0 g
s
.656 .204 .167 r
.34433 .45656 m .34568 .45745 L .34404 .4587 L p F P
0 g
s
.473 .131 .305 r
.55801 .43538 m .55855 .4337 L .54858 .43647 L p F P
0 g
s
.473 .131 .305 r
.54858 .43647 m .54839 .43702 L .55801 .43538 L p F P
0 g
s
.786 .45 .419 r
.26306 .42715 m .26358 .42857 L .26241 .42822 L closepath p F P
0 g
s
.53 .067 .099 r
.43415 .46306 m .43272 .46447 L .42779 .46323 L closepath p F P
0 g
s
.528 .06 .088 r
.43208 .4651 m .43272 .46447 L .42779 .46323 L p F P
0 g
s
.528 .06 .088 r
.42275 .46531 m .43208 .4651 L p .42779 .46323 L F P
0 g
s
.528 .06 .088 r
.42064 .46476 m .42275 .46531 L p .42779 .46323 L F P
0 g
s
.796 .459 .417 r
.25157 .42477 m .25754 .42668 L .25629 .42303 L p F P
0 g
s
.796 .459 .417 r
.25629 .42303 m .25031 .42112 L .25157 .42477 L p F P
0 g
s
.574 .104 .101 r
.39736 .46313 m .39653 .46382 L .39443 .46301 L closepath p F P
0 g
s
.585 .466 .684 r
.61486 .37522 m .617 .37499 L .61503 .3759 L closepath p F P
0 g
s
.512 .047 .086 r
.44048 .46278 m .43415 .46306 L .43272 .46447 L p F P
0 g
s
.823 .556 .534 r
.2264 .40524 m .22996 .40665 L .23057 .40279 L p F P
0 g
s
.823 .556 .534 r
.23057 .40279 m .22646 .40115 L .2264 .40524 L p F P
0 g
s
.523 .304 .524 r
.60839 .40304 m .60839 .39901 L .59909 .40276 L p F P
0 g
s
.523 .304 .524 r
.59909 .40276 m .59909 .40679 L .60839 .40304 L p F P
0 g
s
.568 .091 .083 r
.39507 .46502 m .39653 .46382 L .39443 .46301 L p F P
0 g
s
.568 .091 .083 r
.39016 .46479 m .39507 .46502 L p .39443 .46301 L F P
0 g
s
.568 .091 .083 r
.38451 .4626 m .39016 .46479 L p .39443 .46301 L F P
0 g
s
.568 .091 .083 r
.39443 .46301 m .38455 .46257 L .38451 .4626 L p F P
0 g
s
.814 .522 .496 r
.23229 .41129 m .23795 .41333 L .23755 .4094 L p F P
0 g
s
.814 .522 .496 r
.23755 .4094 m .23188 .40736 L .23229 .41129 L p F P
0 g
s
.574 .441 .662 r
.62511 .37704 m .61609 .38122 L .61503 .3759 L p F P
0 g
s
.574 .441 .662 r
.62465 .37467 m .62511 .37704 L p .61503 .3759 L F P
0 g
s
.574 .441 .662 r
.61503 .3759 m .617 .37499 L .62465 .37467 L p F P
0 g
s
.396 .782 .99 r
.38448 .35511 m .37523 .3561 L .37243 .35457 L p F P
0 g
s
.769 .41 .377 r
.27767 .43516 m .27791 .43563 L .27741 .4355 L closepath p F P
0 g
s
.573 .844 .996 r
.46988 .35449 m .46105 .35567 L .45969 .35497 L p F P
0 g
s
.681 .733 .89 r
.24936 .34689 m .25852 .34328 L .26142 .34635 L p F P
0 g
s
.67 .736 .9 r
.25852 .34328 m .24936 .34689 L .24645 .3436 L p F P
0 g
s
.714 .707 .842 r
.24936 .34689 m .24645 .3436 L .23725 .34812 L p F P
0 g
s
.513 .051 .095 r
.44593 .4625 m .44481 .46365 L .44048 .46278 L closepath p F P
0 g
s
.512 .047 .086 r
.44391 .46457 m .44481 .46365 L .44048 .46278 L p F P
0 g
s
.512 .047 .086 r
.4351 .46498 m .44391 .46457 L p .44048 .46278 L F P
0 g
s
.512 .047 .086 r
.43272 .46447 m .4351 .46498 L p .44048 .46278 L F P
0 g
s
.653 .741 .914 r
.26142 .34635 m .27055 .34348 L .27345 .34633 L p F P
0 g
s
.639 .743 .924 r
.27055 .34348 m .26142 .34635 L .25852 .34328 L p F P
0 g
s
.548 .371 .593 r
.60796 .39256 m .61082 .39358 L .60817 .39473 L closepath p F P
0 g
s
.803 .656 .7 r
.20576 .37193 m .21086 .37415 L .21408 .36895 L p F P
0 g
s
.803 .656 .7 r
.20572 .37182 m .20576 .37193 L p .21408 .36895 L F P
0 g
s
.803 .656 .7 r
.21408 .36895 m .20898 .36666 L .20572 .37182 L p F P
0 g
s
.464 .067 .2 r
.52459 .44972 m .52596 .44712 L .51551 .44928 L p F P
0 g
s
.464 .067 .2 r
.52148 .45036 m .52459 .44972 L p .51551 .44928 L F P
0 g
s
.464 .067 .2 r
.51551 .44928 m .51476 .45067 L .52148 .45036 L p F P
0 g
s
.633 .59 .788 r
.6072 .3529 m .60836 .35551 L .61734 .35126 L p F P
0 g
s
.623 .572 .776 r
.61942 .35644 m .61734 .35126 L .60836 .35551 L p F P
0 g
s
.729 .715 .837 r
.23614 .34881 m .23725 .34812 L .23434 .34458 L p F P
0 g
s
.729 .715 .837 r
.23434 .34458 m .23123 .34643 L .23614 .34881 L p F P
0 g
s
.737 .696 .812 r
.22505 .35036 m .23123 .34643 L .23614 .34881 L p F P
0 g
s
.674 .742 .902 r
.55631 .34655 m .56591 .34317 L .56838 .34609 L p F P
0 g
s
.674 .767 .92 r
.56591 .34317 m .55631 .34655 L .55382 .34398 L p F P
0 g
s
.672 .768 .922 r
.54423 .34732 m .55382 .34398 L .55631 .34655 L p F P
0 g
s
.586 .113 .098 r
.38455 .46257 m .38451 .4626 L .38441 .46256 L closepath p F P
0 g
s
.586 .112 .097 r
.38034 .46427 m .37497 .46191 L .38441 .46256 L p F P
0 g
s
.586 .112 .097 r
.38217 .46439 m .38034 .46427 L p .38441 .46256 L F P
0 g
s
.586 .112 .097 r
.38441 .46256 m .38451 .4626 L .38217 .46439 L p F P
0 g
s
.473 .13 .303 r
.55759 .43667 m .55801 .43538 L .54839 .43702 L p F P
0 g
s
.473 .13 .303 r
.54839 .43702 m .54758 .43943 L .55759 .43667 L p F P
0 g
s
.656 .657 .839 r
.59258 .34655 m .59384 .3487 L .60293 .34461 L p F P
0 g
s
.651 .648 .833 r
.60472 .34785 m .60293 .34461 L .59384 .3487 L p F P
0 g
s
.67 .789 .938 r
.55382 .34398 m .54423 .34732 L .54173 .34504 L p F P
0 g
s
.667 .79 .94 r
.53216 .3483 m .54173 .34504 L .54423 .34732 L p F P
0 g
s
.513 .771 .99 r
.32434 .35136 m .33349 .35029 L .33635 .35222 L p F P
0 g
s
.467 .767 .996 r
.33349 .35029 m .32434 .35136 L .32148 .34925 L p F P
0 g
s
.495 .031 .082 r
.45431 .46193 m .44593 .4625 L .44481 .46365 L p F P
0 g
s
.48 .78 .997 r
.36961 .35317 m .37243 .35457 L .36546 .35532 L p F P
0 g
s
.48 .78 .997 r
.36039 .35387 m .36961 .35317 L p .36546 .35532 L F P
0 g
s
.48 .78 .997 r
.36546 .35532 m .36204 .35486 L .36039 .35387 L p F P
0 g
s
.572 .096 .085 r
.38451 .4626 m .39016 .46479 L .38217 .46439 L closepath p F P
0 g
s
.671 .713 .88 r
.56838 .34609 m .578 .34272 L .58047 .34604 L p F P
0 g
s
.674 .739 .899 r
.578 .34272 m .56838 .34609 L .56591 .34317 L p F P
0 g
s
.699 .729 .874 r
.24645 .3436 m .23725 .34812 L .23434 .34458 L p F P
0 g
s
.758 .371 .32 r
.27519 .43768 m .28016 .43897 L .27791 .43563 L p F P
0 g
s
.758 .371 .32 r
.27791 .43563 m .27741 .4355 L .27519 .43768 L p F P
0 g
s
.733 .322 .27 r
.28929 .4439 m .29617 .44547 L .29342 .44229 L p F P
0 g
s
.733 .322 .27 r
.28921 .4438 m .28929 .4439 L p .29342 .44229 L F P
0 g
s
.733 .322 .27 r
.29342 .44229 m .29151 .44185 L .28921 .4438 L p F P
0 g
s
.663 .814 .956 r
.54172 .34502 m .54173 .34504 L .53216 .3483 L p F P
0 g
s
.663 .814 .956 r
.53216 .3483 m .53191 .34809 L .54172 .34502 L p F P
0 g
s
.623 .748 .936 r
.27345 .34633 m .28257 .34405 L .28547 .3467 L p F P
0 g
s
.604 .751 .948 r
.28257 .34405 m .27345 .34633 L .27055 .34348 L p F P
0 g
s
.77 .388 .331 r
.27367 .43725 m .27519 .43768 L .27741 .4355 L p F P
0 g
s
.77 .388 .331 r
.27741 .4355 m .2716 .43386 L .27367 .43725 L p F P
0 g
s
.812 .498 .459 r
.23875 .41713 m .24442 .41917 L .24364 .41536 L p F P
0 g
s
.812 .498 .459 r
.24364 .41536 m .23795 .41333 L .23875 .41713 L p F P
0 g
s
.381 .784 .984 r
.39655 .35546 m .38727 .35651 L .38448 .35511 L p F P
0 g
s
.611 .754 .947 r
.29863 .34837 m .29747 .34736 L .29575 .34775 L closepath p F P
0 g
s
.464 .035 .14 r
.49665 .4549 m .49269 .45552 L .49105 .45789 L p F P
0 g
s
.654 .195 .15 r
.33243 .457 m .34039 .45818 L .3363 .45541 L p F P
0 g
s
.654 .195 .15 r
.33077 .45586 m .33243 .457 L p .3363 .45541 L F P
0 g
s
.654 .195 .15 r
.3363 .45541 m .33226 .45482 L .33077 .45586 L p F P
0 g
s
.67 .709 .877 r
.59011 .34275 m .58047 .34604 L .578 .34272 L p F P
0 g
s
.665 .683 .857 r
.58047 .34604 m .59011 .34275 L .59258 .34655 L p F P
0 g
s
.481 .05 .144 r
.48109 .45792 m .48757 .45837 L .48004 .45938 L closepath p F P
0 g
s
.464 .097 .257 r
.54643 .44222 m .54758 .43943 L .53744 .44199 L p F P
0 g
s
.464 .097 .257 r
.53838 .44425 m .54643 .44222 L p .53744 .44199 L F P
0 g
s
.464 .097 .257 r
.53744 .44199 m .53639 .4445 L .53838 .44425 L p F P
0 g
s
.574 .446 .668 r
.617 .37499 m .62402 .37168 L .62465 .37467 L closepath p F P
0 g
s
.645 .835 .973 r
.52965 .3463 m .52009 .34943 L .51755 .34766 L p F P
0 g
s
.641 .829 .973 r
.50802 .35064 m .51755 .34766 L .52009 .34943 L p F P
0 g
s
.78 .416 .369 r
.26038 .43062 m .26533 .43206 L .26358 .42857 L p F P
0 g
s
.78 .416 .369 r
.26358 .42857 m .26241 .42822 L .26038 .43062 L p F P
0 g
s
.492 .785 .997 r
.36204 .35486 m .36039 .35387 L .35704 .35426 L closepath p F P
0 g
s
.633 .59 .788 r
.61734 .35126 m .61691 .35024 L .6072 .3529 L p F P
0 g
s
.641 .608 .801 r
.61691 .35024 m .6072 .3529 L .60472 .34785 L p F P
0 g
s
.661 .814 .957 r
.53923 .34307 m .54172 .34502 L .53191 .34809 L p F P
0 g
s
.661 .814 .957 r
.53191 .34809 m .52965 .3463 L .53923 .34307 L p F P
0 g
s
.644 .189 .156 r
.34568 .45745 m .34859 .45927 L .34404 .4587 L closepath p F P
0 g
s
.746 .341 .283 r
.29151 .44185 m .28921 .4438 L .28673 .44065 L closepath p F P
0 g
s
.495 .031 .082 r
.45553 .46379 m .45691 .46233 L .45431 .46193 L p F P
0 g
s
.495 .031 .082 r
.44853 .46428 m .45553 .46379 L p .45431 .46193 L F P
0 g
s
.495 .031 .082 r
.44481 .46365 m .44853 .46428 L p .45431 .46193 L F P
0 g
s
.495 .034 .089 r
.4575 .4617 m .45691 .46233 L .45431 .46193 L closepath p F P
0 g
s
.586 .108 .086 r
.37099 .46358 m .38034 .46427 L .37497 .46191 L p F P
0 g
s
.586 .108 .086 r
.36959 .46295 m .37099 .46358 L p .37497 .46191 L F P
0 g
s
.586 .108 .086 r
.37497 .46191 m .37141 .46165 L .36959 .46295 L p F P
0 g
s
.701 .263 .207 r
.30629 .45006 m .31349 .45151 L .31022 .44849 L p F P
0 g
s
.701 .263 .207 r
.30406 .44801 m .30629 .45006 L p .31022 .44849 L F P
0 g
s
.701 .263 .207 r
.31022 .44849 m .30487 .44743 L .30406 .44801 L p F P
0 g
s
.766 .684 .772 r
.21274 .354 m .2146 .35238 L .21977 .35467 L p F P
0 g
s
.766 .684 .772 r
.21977 .35467 m .21559 .3585 L .21274 .354 L p F P
0 g
s
.754 .698 .798 r
.21977 .35467 m .22505 .35036 L .22216 .3465 L p F P
0 g
s
.754 .698 .798 r
.22216 .3465 m .2146 .35238 L .21977 .35467 L p F P
0 g
s
.783 .685 .755 r
.21331 .36105 m .21559 .3585 L .21274 .354 L p F P
0 g
s
.821 .6 .603 r
.21099 .39035 m .2163 .39256 L .21734 .38813 L p F P
0 g
s
.821 .6 .603 r
.21734 .38813 m .21205 .38592 L .21099 .39035 L p F P
0 g
s
.625 .848 .984 r
.51755 .34766 m .50802 .35064 L .50546 .34904 L p F P
0 g
s
.623 .84 .983 r
.49594 .35183 m .50546 .34904 L .50802 .35064 L p F P
0 g
s
.824 .579 .569 r
.21577 .3968 m .2211 .39899 L .22162 .39474 L p F P
0 g
s
.824 .579 .569 r
.22162 .39474 m .2163 .39256 L .21577 .3968 L p F P
0 g
s
.79 .431 .377 r
.25914 .43023 m .26038 .43062 L .26241 .42822 L p F P
0 g
s
.79 .431 .377 r
.26241 .42822 m .25754 .42668 L .25914 .43023 L p F P
0 g
s
.531 .335 .56 r
.61265 .39718 m .60839 .39901 L .60817 .39473 L p F P
0 g
s
.531 .335 .56 r
.60817 .39473 m .61082 .39358 L .61265 .39718 L p F P
0 g
s
.588 .751 .955 r
.28547 .3467 m .28924 .34598 L .29575 .34775 L p F P
0 g
s
.569 .741 .958 r
.28924 .34598 m .28547 .3467 L .28257 .34405 L p F P
0 g
s
.479 .018 .078 r
.46695 .46278 m .46888 .46066 L .4575 .4617 L p F P
0 g
s
.479 .018 .078 r
.46334 .46311 m .46695 .46278 L p .4575 .4617 L F P
0 g
s
.479 .018 .078 r
.4575 .4617 m .45691 .46233 L .46334 .46311 L p F P
0 g
s
.693 .26 .218 r
.31893 .45122 m .32088 .45289 L .31758 .45231 L closepath p F P
0 g
s
.376 .79 .979 r
.40863 .3556 m .39932 .35676 L .39655 .35546 L p F P
0 g
s
.579 .838 .994 r
.47212 .35422 m .47178 .35403 L .46988 .35449 L closepath p F P
0 g
s
.573 .844 .996 r
.46915 .35284 m .47178 .35403 L .46988 .35449 L p F P
0 g
s
.573 .844 .996 r
.45969 .35497 m .46915 .35284 L p .46988 .35449 L F P
0 g
s
.815 .621 .64 r
.20961 .38489 m .21205 .38592 L .21371 .38129 L p F P
0 g
s
.815 .621 .64 r
.20833 .37941 m .20961 .38489 L p .21371 .38129 L F P
0 g
s
.815 .621 .64 r
.21371 .38129 m .20846 .37905 L .20833 .37941 L p F P
0 g
s
.608 .762 .953 r
.29457 .34495 m .28924 .34598 L .29575 .34775 L p F P
0 g
s
.608 .762 .953 r
.29575 .34775 m .29747 .34736 L .29457 .34495 L p F P
0 g
s
.605 .131 .103 r
.37141 .46165 m .36959 .46295 L .36586 .46114 L closepath p F P
0 g
s
.556 .404 .63 r
.62586 .38197 m .62511 .37704 L .61609 .38122 L p F P
0 g
s
.556 .404 .63 r
.61609 .38122 m .61684 .38616 L .62586 .38197 L p F P
0 g
s
.473 .776 .997 r
.34787 .35276 m .34836 .35306 L p .33635 .35222 L F P
0 g
s
.473 .776 .997 r
.33635 .35222 m .34126 .35176 L .34787 .35276 L p F P
0 g
s
.442 .758 .995 r
.34126 .35176 m .33635 .35222 L .33349 .35029 L p F P
0 g
s
.463 .037 .144 r
.50348 .45379 m .50268 .45497 L .49665 .4549 L closepath p F P
0 g
s
.464 .035 .14 r
.50187 .45617 m .50268 .45497 L .49665 .4549 L p F P
0 g
s
.464 .035 .14 r
.49105 .45789 m .50187 .45617 L p .49665 .4549 L F P
0 g
s
.783 .685 .755 r
.21274 .354 m .20837 .35869 L .21331 .36105 L p F P
0 g
s
.794 .675 .732 r
.20388 .36435 m .20898 .36666 L .21331 .36105 L p F P
0 g
s
.794 .675 .732 r
.21331 .36105 m .20837 .35869 L .20388 .36435 L p F P
0 g
s
.671 .217 .166 r
.33226 .45482 m .33077 .45586 L .32848 .45419 L closepath p F P
0 g
s
.732 .701 .821 r
.23123 .34643 m .22505 .35036 L .22216 .3465 L p F P
0 g
s
.454 .771 .997 r
.34836 .35306 m .34919 .353 L .35704 .35426 L p F P
0 g
s
.478 .792 .999 r
.35756 .35233 m .34919 .353 L .35704 .35426 L p F P
0 g
s
.478 .792 .999 r
.35704 .35426 m .36039 .35387 L .35756 .35233 L p F P
0 g
s
.825 .557 .534 r
.22103 .40307 m .2264 .40524 L .22646 .40115 L p F P
0 g
s
.825 .557 .534 r
.22646 .40115 m .2211 .39899 L .22103 .40307 L p F P
0 g
s
.61 .85 .989 r
.50417 .34837 m .50546 .34904 L .49594 .35183 L p F P
0 g
s
.61 .85 .989 r
.49594 .35183 m .49366 .35056 L .50417 .34837 L p F P
0 g
s
.602 .844 .99 r
.49366 .35056 m .49594 .35183 L p .48386 .35298 L F P
0 g
s
.582 .84 .994 r
.48125 .35169 m .48302 .35256 L .47212 .35422 L p F P
0 g
s
.582 .84 .994 r
.47212 .35422 m .47178 .35403 L .48125 .35169 L p F P
0 g
s
.656 .657 .839 r
.60293 .34461 m .60225 .34341 L .59258 .34655 L p F P
0 g
s
.663 .676 .852 r
.60225 .34341 m .59258 .34655 L .59011 .34275 L p F P
0 g
s
.506 .241 .447 r
.58906 .41771 m .58914 .41702 L .57951 .42093 L p F P
0 g
s
.506 .241 .447 r
.57951 .42093 m .57949 .42106 L .58906 .41771 L p F P
0 g
s
.56 .086 .088 r
.39653 .46382 m .40043 .46517 L .39507 .46502 L closepath p F P
0 g
s
.797 .457 .412 r
.24563 .42284 m .25157 .42477 L .25031 .42112 L p F P
0 g
s
.797 .457 .412 r
.24517 .42151 m .24563 .42284 L p .25031 .42112 L F P
0 g
s
.797 .457 .412 r
.25031 .42112 m .24633 .41983 L .24517 .42151 L p F P
0 g
s
.48 .19 .395 r
.58847 .42106 m .58906 .41771 L .57949 .42106 L p F P
0 g
s
.48 .19 .395 r
.57949 .42106 m .57889 .42441 L .58847 .42106 L p F P
0 g
s
.811 .638 .668 r
.20821 .37894 m .20846 .37905 L .21086 .37415 L p F P
0 g
s
.811 .638 .668 r
.21086 .37415 m .20576 .37193 L .20821 .37894 L p F P
0 g
s
.383 .799 .977 r
.42072 .3555 m .41138 .35681 L .40863 .3556 L p F P
0 g
s
.602 .844 .99 r
.48386 .35298 m .49103 .35102 L .49366 .35056 L p F P
0 g
s
.589 .857 .994 r
.48386 .35298 m .49103 .35102 L .48302 .35256 L closepath p F P
0 g
s
.597 .114 .078 r
.36895 .46342 m .36959 .46295 L .36586 .46114 L p F P
0 g
s
.597 .114 .078 r
.36205 .46274 m .36895 .46342 L p .36586 .46114 L F P
0 g
s
.597 .114 .078 r
.35761 .46059 m .36205 .46274 L p .36586 .46114 L F P
0 g
s
.597 .114 .078 r
.36586 .46114 m .35793 .46038 L .35761 .46059 L p F P
0 g
s
.47 .157 .352 r
.57812 .42758 m .57889 .42441 L .56918 .42757 L p F P
0 g
s
.47 .157 .352 r
.56918 .42757 m .5684 .43074 L .57812 .42758 L p F P
0 g
s
.493 .23 .444 r
.59875 .41184 m .59889 .41058 L .58945 .41413 L p F P
0 g
s
.493 .23 .444 r
.58945 .41413 m .58914 .41702 L .59875 .41184 L p F P
0 g
s
.501 .07 .153 r
.469 .46049 m .46968 .46057 L .46888 .46066 L closepath p F P
0 g
s
.816 .524 .495 r
.22885 .41002 m .23229 .41129 L .23188 .40736 L p F P
0 g
s
.816 .524 .495 r
.23188 .40736 m .22996 .40665 L .22885 .41002 L p F P
0 g
s
.469 .825 .996 r
.42345 .35666 m .43282 .35517 L .43552 .3563 L p F P
0 g
s
.401 .81 .979 r
.43282 .35517 m .42345 .35666 L .42072 .3555 L p F P
0 g
s
.531 .857 .996 r
.48125 .35169 m .47178 .35403 L .46915 .35284 L p F P
0 g
s
.524 .757 .982 r
.30658 .34603 m .29747 .34736 L .29457 .34495 L p F P
0 g
s
.671 .217 .165 r
.32475 .45572 m .32088 .45289 L .32848 .45419 L p F P
0 g
s
.671 .217 .165 r
.32972 .45658 m .32475 .45572 L p .32848 .45419 L F P
0 g
s
.671 .217 .165 r
.32848 .45419 m .33077 .45586 L .32972 .45658 L p F P
0 g
s
.716 .283 .222 r
.30487 .44743 m .30406 .44801 L .30306 .44703 L closepath p F P
0 g
s
.428 .824 .983 r
.44493 .35461 m .43552 .3563 L .43282 .35517 L p F P
0 g
s
.501 .849 .995 r
.46915 .35284 m .45969 .35497 L .45704 .35383 L p F P
0 g
s
.746 .341 .282 r
.28274 .4422 m .28016 .43897 L .28673 .44065 L p F P
0 g
s
.746 .341 .282 r
.28913 .44386 m .28274 .4422 L p .28673 .44065 L F P
0 g
s
.746 .341 .282 r
.28673 .44065 m .28921 .4438 L .28913 .44386 L p F P
0 g
s
.463 .838 .989 r
.45704 .35383 m .44761 .35573 L .44493 .35461 L p F P
0 g
s
.462 .768 .996 r
.34836 .35306 m .34919 .353 L .34787 .35276 L closepath p F P
0 g
s
.77 .384 .324 r
.26743 .43544 m .27367 .43725 L .2716 .43386 L p F P
0 g
s
.77 .384 .324 r
.2716 .43386 m .26533 .43206 L .26743 .43544 L p F P
0 g
s
.46 0 .07 r
.46968 .46057 m .46888 .46066 L .46695 .46278 L p F P
0 g
s
.529 .334 .56 r
.61755 .39504 m .61265 .39718 L .61082 .39358 L p F P
0 g
s
.529 .334 .56 r
.61082 .39358 m .61732 .39075 L .61755 .39504 L p F P
0 g
s
.546 .076 .089 r
.40858 .46454 m .41125 .46536 L .40767 .46534 L closepath p F P
0 g
s
.463 .007 .083 r
.48004 .45938 m .47846 .46121 L .46968 .46057 L closepath p F P
0 g
s
.46 0 .07 r
.47818 .46153 m .47846 .46121 L .46968 .46057 L p F P
0 g
s
.46 0 .07 r
.46695 .46278 m .47818 .46153 L p .46968 .46057 L F P
0 g
s
.445 .05 .194 r
.53491 .44736 m .53627 .44478 L .52596 .44712 L p F P
0 g
s
.445 .05 .194 r
.52596 .44712 m .52459 .44972 L .53491 .44736 L p F P
0 g
s
.458 .119 .302 r
.56765 .43311 m .5684 .43074 L .55855 .4337 L p F P
0 g
s
.458 .119 .302 r
.55855 .4337 m .55801 .43538 L .56765 .43311 L p F P
0 g
s
.802 .654 .699 r
.20298 .3657 m .20388 .36435 L .20898 .36666 L p F P
0 g
s
.802 .654 .699 r
.20898 .36666 m .20572 .37182 L .20298 .3657 L p F P
0 g
s
.447 .02 .135 r
.51254 .45425 m .51411 .45186 L .50348 .45379 L p F P
0 g
s
.447 .02 .135 r
.50956 .45479 m .51254 .45425 L p .50348 .45379 L F P
0 g
s
.447 .02 .135 r
.50348 .45379 m .50268 .45497 L .50956 .45479 L p F P
0 g
s
.464 .065 .198 r
.51476 .45067 m .52148 .45036 L .51411 .45186 L closepath p F P
0 g
s
.716 .283 .221 r
.29925 .44854 m .29617 .44547 L .30306 .44703 L p F P
0 g
s
.716 .283 .221 r
.30232 .44924 m .29925 .44854 L p .30306 .44703 L F P
0 g
s
.716 .283 .221 r
.30306 .44703 m .30406 .44801 L .30232 .44924 L p F P
0 g
s
.502 .263 .485 r
.60832 .40447 m .60839 .40304 L .59909 .40679 L p F P
0 g
s
.502 .263 .485 r
.60336 .40878 m .60832 .40447 L p .59909 .40679 L F P
0 g
s
.502 .263 .485 r
.59909 .40679 m .59889 .41058 L .60336 .40878 L p F P
0 g
s
.722 .715 .843 r
.23123 .34643 m .23434 .34458 L .23142 .34114 L p F P
0 g
s
.722 .715 .843 r
.23142 .34114 m .22616 .3441 L .23123 .34643 L p F P
0 g
s
.732 .701 .821 r
.22216 .3465 m .22616 .3441 L .23123 .34643 L p F P
0 g
s
.615 .137 .096 r
.35793 .46038 m .35761 .46059 L .35701 .46028 L closepath p F P
0 g
s
.479 .016 .076 r
.45691 .46233 m .46334 .46311 L .45553 .46379 L closepath p F P
0 g
s
.824 .534 .498 r
.22675 .40919 m .22885 .41002 L .22996 .40665 L p F P
0 g
s
.824 .534 .498 r
.22996 .40665 m .2264 .40524 L .22675 .40919 L p F P
0 g
s
.615 .137 .094 r
.35335 .46182 m .34859 .45927 L .35701 .46028 L p F P
0 g
s
.615 .137 .094 r
.35535 .46206 m .35335 .46182 L p .35701 .46028 L F P
0 g
s
.615 .137 .094 r
.35701 .46028 m .35761 .46059 L .35535 .46206 L p F P
0 g
s
.456 .767 .996 r
.35471 .35089 m .35756 .35233 L .34919 .353 L p F P
0 g
s
.456 .767 .996 r
.34552 .35135 m .35471 .35089 L p .34919 .353 L F P
0 g
s
.456 .767 .996 r
.34919 .353 m .34787 .35276 L .34552 .35135 L p F P
0 g
s
.813 .498 .456 r
.2331 .41508 m .23875 .41713 L .23795 .41333 L p F P
0 g
s
.813 .498 .456 r
.23795 .41333 m .23229 .41129 L .2331 .41508 L p F P
0 g
s
.641 .608 .801 r
.60472 .34785 m .61442 .345 L .61691 .35024 L p F P
0 g
s
.646 .64 .83 r
.60293 .34461 m .60472 .34785 L .61442 .345 L p F P
0 g
s
.791 .43 .372 r
.25319 .4283 m .25914 .43023 L .25754 .42668 L p F P
0 g
s
.791 .43 .372 r
.25754 .42668 m .25157 .42477 L .25319 .4283 L p F P
0 g
s
.531 .063 .089 r
.42064 .46476 m .42275 .46531 L .42 .46536 L closepath p F P
0 g
s
.807 .47 .419 r
.24633 .41983 m .24517 .42151 L .24442 .41917 L closepath p F P
0 g
s
.477 .776 .997 r
.34787 .35276 m .34552 .35135 L .34126 .35176 L closepath p F P
0 g
s
.515 .764 .987 r
.30947 .34825 m .31859 .34722 L .32148 .34925 L p F P
0 g
s
.474 .76 .993 r
.31859 .34722 m .30947 .34825 L .30658 .34603 L p F P
0 g
s
.569 .741 .958 r
.28257 .34405 m .28354 .3439 L .28924 .34598 L p F P
0 g
s
.586 .762 .962 r
.29166 .34261 m .28354 .3439 L .28924 .34598 L p F P
0 g
s
.586 .762 .962 r
.28924 .34598 m .29457 .34495 L .29166 .34261 L p F P
0 g
s
.67 .736 .9 r
.24645 .3436 m .25559 .3403 L .25852 .34328 L p F P
0 g
s
.658 .738 .909 r
.25559 .3403 m .24645 .3436 L .24353 .34039 L p F P
0 g
s
.699 .729 .874 r
.23434 .34458 m .24353 .34039 L .24645 .3436 L p F P
0 g
s
.497 .033 .082 r
.44481 .46365 m .44853 .46428 L .44391 .46457 L closepath p F P
0 g
s
.538 .366 .596 r
.62635 .38656 m .62586 .38197 L .61684 .38616 L p F P
0 g
s
.538 .366 .596 r
.61684 .38616 m .61732 .39075 L .62635 .38656 L p F P
0 g
s
.588 .857 .994 r
.49103 .35102 m .48302 .35256 L .48125 .35169 L p F P
0 g
s
.515 .049 .086 r
.43272 .46447 m .4351 .46498 L .43208 .4651 L closepath p F P
0 g
s
.35 .76 .981 r
.36961 .35317 m .36039 .35387 L .35756 .35233 L p F P
0 g
s
.594 .5 .718 r
.62198 .36402 m .6277 .36321 L .62251 .36579 L closepath p F P
0 g
s
.596 .516 .734 r
.62039 .35912 m .62198 .36402 L .6277 .36321 L p F P
0 g
s
.602 .119 .082 r
.35761 .46059 m .36205 .46274 L .35535 .46206 L closepath p F P
0 g
s
.69 .732 .883 r
.24353 .34039 m .23434 .34458 L .23142 .34114 L p F P
0 g
s
.763 .69 .781 r
.2146 .35238 m .21045 .35057 L .21274 .354 L closepath p F P
0 g
s
.783 .692 .764 r
.20837 .35869 m .21274 .354 L .21045 .35057 L p F P
0 g
s
.639 .743 .924 r
.25852 .34328 m .26763 .3407 L .27055 .34348 L p F P
0 g
s
.624 .744 .933 r
.26763 .3407 m .25852 .34328 L .25559 .3403 L p F P
0 g
s
.611 .542 .752 r
.61942 .35644 m .62039 .35912 L .62927 .35469 L p F P
0 g
s
.596 .516 .734 r
.63137 .36135 m .62927 .35469 L .62039 .35912 L p F P
0 g
s
.596 .516 .734 r
.6277 .36321 m .63137 .36135 L p .62039 .35912 L F P
0 g
s
.823 .602 .603 r
.21024 .39003 m .21099 .39035 L .21205 .38592 L p F P
0 g
s
.823 .602 .603 r
.21205 .38592 m .20961 .38489 L .21024 .39003 L p F P
0 g
s
.758 .694 .791 r
.2146 .35238 m .22216 .3465 L p .20986 .34972 L F P
0 g
s
.758 .694 .791 r
.20986 .34972 m .21045 .35057 L .2146 .35238 L p F P
0 g
s
.585 .479 .7 r
.63289 .36725 m .62402 .37168 L .62251 .36579 L p F P
0 g
s
.585 .479 .7 r
.63178 .36281 m .63289 .36725 L p .62251 .36579 L F P
0 g
s
.585 .479 .7 r
.62251 .36579 m .6277 .36321 L .63178 .36281 L p F P
0 g
s
.825 .58 .569 r
.21046 .3946 m .21577 .3968 L .2163 .39256 L p F P
0 g
s
.825 .58 .569 r
.2163 .39256 m .21099 .39035 L .21046 .3946 L p F P
0 g
s
.668 .205 .144 r
.31722 .45438 m .32475 .45572 L .32088 .45289 L p F P
0 g
s
.668 .205 .144 r
.31585 .45337 m .31722 .45438 L p .32088 .45289 L F P
0 g
s
.668 .205 .144 r
.32088 .45289 m .31758 .45231 L .31585 .45337 L p F P
0 g
s
.444 .077 .247 r
.55645 .43945 m .55759 .43667 L .54758 .43943 L p F P
0 g
s
.444 .077 .247 r
.54758 .43943 m .54643 .44222 L .55645 .43945 L p F P
0 g
s
.818 .624 .641 r
.20846 .37905 m .20821 .37894 L .20833 .37941 L closepath p F P
0 g
s
.611 .542 .752 r
.62927 .35469 m .62918 .35444 L .61942 .35644 L p F P
0 g
s
.615 .562 .772 r
.61734 .35126 m .61942 .35644 L .62918 .35444 L p F P
0 g
s
.821 .643 .661 r
.20351 .37671 m .20821 .37894 L .20576 .37193 L p F P
0 g
s
.828 .628 .633 r
.20692 .38365 m .20833 .37941 L .20821 .37894 L p F P
0 g
s
.828 .628 .633 r
.20194 .38131 m .20692 .38365 L p .20821 .37894 L F P
0 g
s
.828 .628 .633 r
.20821 .37894 m .20351 .37671 L .20194 .38131 L p F P
0 g
s
.807 .47 .418 r
.23991 .42081 m .23875 .41713 L .24442 .41917 L p F P
0 g
s
.807 .47 .418 r
.24451 .42246 m .23991 .42081 L p .24442 .41917 L F P
0 g
s
.807 .47 .418 r
.24442 .41917 m .24517 .42151 L .24451 .42246 L p F P
0 g
s
.674 .739 .899 r
.56591 .34317 m .57554 .33975 L .578 .34272 L p F P
0 g
s
.676 .765 .918 r
.57554 .33975 m .56591 .34317 L .56343 .34057 L p F P
0 g
s
.674 .767 .92 r
.55382 .34398 m .56343 .34057 L .56591 .34317 L p F P
0 g
s
.825 .624 .63 r
.20833 .37941 m .20692 .38365 L .20961 .38489 L closepath p F P
0 g
s
.444 0 .07 r
.48757 .45837 m .48004 .45938 L .47846 .46121 L p F P
0 g
s
.511 .295 .523 r
.61053 .40212 m .60839 .40304 L .60839 .39901 L p F P
0 g
s
.511 .295 .523 r
.60839 .39901 m .61265 .39718 L .61053 .40212 L p F P
0 g
s
.827 .558 .533 r
.2157 .40089 m .22103 .40307 L .2211 .39899 L p F P
0 g
s
.827 .558 .533 r
.2211 .39899 m .21577 .3968 L .2157 .40089 L p F P
0 g
s
.674 .793 .938 r
.56096 .33827 m .56343 .34057 L .55382 .34398 L p F P
0 g
s
.674 .793 .938 r
.55923 .33888 m .56096 .33827 L p .55382 .34398 L F P
0 g
s
.674 .793 .938 r
.55382 .34398 m .55142 .34178 L .55923 .33888 L p F P
0 g
s
.67 .789 .938 r
.55142 .34178 m .55382 .34398 L p .54173 .34504 L F P
0 g
s
.783 .692 .764 r
.20342 .35632 m .20837 .35869 L p .21045 .35057 L F P
0 g
s
.792 .677 .738 r
.20189 .36343 m .20388 .36435 L .20837 .35869 L p F P
0 g
s
.792 .677 .738 r
.20018 .36024 m .20189 .36343 L p .20837 .35869 L F P
0 g
s
.792 .677 .738 r
.20837 .35869 m .20342 .35632 L .20018 .36024 L p F P
0 g
s
.706 .269 .211 r
.30406 .44801 m .30629 .45006 L .30232 .44924 L closepath p F P
0 g
s
.67 .709 .877 r
.578 .34272 m .58766 .33935 L .59011 .34275 L p F P
0 g
s
.675 .735 .896 r
.58766 .33935 m .578 .34272 L .57554 .33975 L p F P
0 g
s
.613 .127 .076 r
.34502 .46077 m .35335 .46182 L .34859 .45927 L p F P
0 g
s
.613 .127 .076 r
.34268 .45951 m .34502 .46077 L p .34859 .45927 L F P
0 g
s
.613 .127 .076 r
.34859 .45927 m .34404 .4587 L .34268 .45951 L p F P
0 g
s
.604 .751 .948 r
.28147 .34309 m .28257 .34405 L p .27055 .34348 L F P
0 g
s
.604 .751 .948 r
.27055 .34348 m .2773 .34202 L .28147 .34309 L p F P
0 g
s
.585 .744 .953 r
.2773 .34202 m .27055 .34348 L .26763 .3407 L p F P
0 g
s
.814 .653 .683 r
.20572 .37182 m .20568 .37189 L .20576 .37193 L closepath p F P
0 g
s
.821 .643 .661 r
.20576 .37193 m .20568 .37189 L .20351 .37671 L p F P
0 g
s
.814 .659 .69 r
.20568 .37189 m .20572 .37182 L .20298 .3657 L p F P
0 g
s
.744 .327 .258 r
.27623 .44049 m .28274 .4422 L .28016 .43897 L p F P
0 g
s
.744 .327 .258 r
.27441 .43824 m .27623 .44049 L p .28016 .43897 L F P
0 g
s
.744 .327 .258 r
.28016 .43897 m .27519 .43768 L .27441 .43824 L p F P
0 g
s
.814 .659 .69 r
.20298 .3657 m .20081 .3695 L .20568 .37189 L p F P
0 g
s
.823 .647 .664 r
.19859 .37434 m .20351 .37671 L .20568 .37189 L p F P
0 g
s
.823 .647 .664 r
.20568 .37189 m .20081 .3695 L .19859 .37434 L p F P
0 g
s
.465 .781 .998 r
.34265 .34974 m .33403 .35026 L .34126 .35176 L p F P
0 g
s
.465 .781 .998 r
.34126 .35176 m .34552 .35135 L .34265 .34974 L p F P
0 g
s
.442 .758 .995 r
.33349 .35029 m .33403 .35026 L .34126 .35176 L p F P
0 g
s
.67 .789 .938 r
.54173 .34504 m .54345 .34444 L .55142 .34178 L p F P
0 g
s
.666 .819 .957 r
.54173 .34504 m .54345 .34444 L .54172 .34502 L closepath p F P
0 g
s
.666 .819 .957 r
.54345 .34444 m .54172 .34502 L .53923 .34307 L p F P
0 g
s
.685 .228 .161 r
.31758 .45231 m .31585 .45337 L .31349 .45151 L closepath p F P
0 g
s
.726 .706 .831 r
.22616 .3441 m .22216 .3465 L .21924 .34276 L p F P
0 g
s
.758 .694 .791 r
.22216 .3465 m .21924 .34276 L .20986 .34972 L p F P
0 g
s
.396 .782 .99 r
.38215 .35406 m .38448 .35511 L p .37243 .35457 L F P
0 g
s
.396 .782 .99 r
.37243 .35457 m .3806 .35394 L .38215 .35406 L p F P
0 g
s
.328 .757 .972 r
.3806 .35394 m .37243 .35457 L .36961 .35317 L p F P
0 g
s
.467 .767 .996 r
.33312 .35005 m .33349 .35029 L p .32148 .34925 L F P
0 g
s
.467 .767 .996 r
.32148 .34925 m .32657 .34884 L .33312 .35005 L p F P
0 g
s
.438 .749 .994 r
.32657 .34884 m .32148 .34925 L .31859 .34722 L p F P
0 g
s
.827 .535 .496 r
.22138 .40702 m .22675 .40919 L .2264 .40524 L p F P
0 g
s
.827 .535 .496 r
.2264 .40524 m .22103 .40307 L .22138 .40702 L p F P
0 g
s
.769 .377 .311 r
.26122 .43361 m .26743 .43544 L .26533 .43206 L p F P
0 g
s
.769 .377 .311 r
.2597 .43119 m .26122 .43361 L p .26533 .43206 L F P
0 g
s
.769 .377 .311 r
.26533 .43206 m .26038 .43062 L .2597 .43119 L p F P
0 g
s
.562 .438 .668 r
.634 .37263 m .63289 .36725 L .62402 .37168 L p F P
0 g
s
.562 .438 .668 r
.62942 .37492 m .634 .37263 L p .62402 .37168 L F P
0 g
s
.562 .438 .668 r
.62402 .37168 m .62465 .37467 L .62942 .37492 L p F P
0 g
s
.716 .278 .209 r
.29243 .44695 m .29925 .44854 L .29617 .44547 L p F P
0 g
s
.716 .278 .209 r
.29617 .44547 m .28929 .4439 L .29243 .44695 L p F P
0 g
s
.669 .702 .872 r
.59979 .33949 m .59011 .34275 L .58766 .33935 L p F P
0 g
s
.663 .676 .852 r
.59011 .34275 m .59979 .33949 L .60225 .34341 L p F P
0 g
s
.65 .84 .973 r
.53923 .34307 m .52965 .3463 L .52712 .34458 L p F P
0 g
s
.645 .835 .973 r
.51755 .34766 m .52712 .34458 L .52965 .3463 L p F P
0 g
s
.632 .152 .095 r
.34404 .4587 m .34268 .45951 L .34039 .45818 L closepath p F P
0 g
s
.831 .608 .6 r
.20592 .38806 m .21024 .39003 L .20961 .38489 L p F P
0 g
s
.831 .608 .6 r
.20961 .38489 m .20692 .38365 L .20592 .38806 L p F P
0 g
s
.653 .651 .835 r
.60225 .34341 m .60293 .34461 L .61195 .34036 L p F P
0 g
s
.646 .64 .83 r
.61442 .345 m .61195 .34036 L .60293 .34461 L p F P
0 g
s
.49 0 .004 r
.42275 .46531 m .42 .46536 L .41784 .46699 L p F P
0 g
s
.511 .017 .021 r
.42 .46536 m .41784 .46699 L .41125 .46536 L closepath p F P
0 g
s
.505 .006 .004 r
.41765 .46714 m .41784 .46699 L .41125 .46536 L p F P
0 g
s
.505 .006 .004 r
.40722 .46708 m .41765 .46714 L p .41125 .46536 L F P
0 g
s
.505 .006 .004 r
.40575 .4667 m .40722 .46708 L p .41125 .46536 L F P
0 g
s
.505 .006 .004 r
.41125 .46536 m .40767 .46534 L .40575 .4667 L p F P
0 g
s
.526 .03 .022 r
.40767 .46534 m .40575 .4667 L .40043 .46517 L closepath p F P
0 g
s
.659 .201 .154 r
.33077 .45586 m .33243 .457 L .32972 .45658 L closepath p F P
0 g
s
.615 .562 .772 r
.62666 .34787 m .62178 .34903 L .61734 .35126 L p F P
0 g
s
.615 .562 .772 r
.62918 .35444 m .62666 .34787 L p .61734 .35126 L F P
0 g
s
.627 .582 .785 r
.61691 .35024 m .62178 .34903 L .61734 .35126 L closepath p F P
0 g
s
.494 .003 .018 r
.43208 .4651 m .42996 .46679 L .42275 .46531 L closepath p F P
0 g
s
.49 0 .004 r
.42979 .46692 m .42996 .46679 L .42275 .46531 L p F P
0 g
s
.49 0 .004 r
.41848 .46713 m .42979 .46692 L p .42275 .46531 L F P
0 g
s
.49 0 .004 r
.41784 .46699 m .41848 .46713 L p .42275 .46531 L F P
0 g
s
.463 .095 .255 r
.53639 .4445 m .53838 .44425 L .53627 .44478 L closepath p F P
0 g
s
.492 .229 .443 r
.5985 .41415 m .59875 .41184 L .58914 .41702 L p F P
0 g
s
.492 .229 .443 r
.58914 .41702 m .58906 .41771 L .5985 .41415 L p F P
0 g
s
.428 .003 .128 r
.52148 .45036 m .51411 .45186 L .51254 .45425 L p F P
0 g
s
.67 .793 .94 r
.55142 .34178 m .55133 .34169 L .54345 .34444 L closepath p F P
0 g
s
.666 .819 .957 r
.54884 .33973 m .55133 .34169 L .54345 .34444 L p F P
0 g
s
.666 .819 .957 r
.53923 .34307 m .54884 .33973 L p .54345 .34444 L F P
0 g
s
.57 .738 .955 r
.28257 .34405 m .28354 .3439 L .28147 .34309 L closepath p F P
0 g
s
.519 .017 .002 r
.40524 .46706 m .40575 .4667 L .40043 .46517 L p F P
0 g
s
.519 .017 .002 r
.39661 .46681 m .40524 .46706 L p .40043 .46517 L F P
0 g
s
.519 .017 .002 r
.39367 .46595 m .39661 .46681 L p .40043 .46517 L F P
0 g
s
.519 .017 .002 r
.40043 .46517 m .39507 .46502 L .39367 .46595 L p F P
0 g
s
.458 .118 .301 r
.56746 .43372 m .56765 .43311 L .55801 .43538 L p F P
0 g
s
.458 .118 .301 r
.55801 .43538 m .55759 .43667 L .56746 .43372 L p F P
0 g
s
.473 0 .002 r
.4351 .46498 m .43208 .4651 L .42996 .46679 L p F P
0 g
s
.598 .847 .992 r
.49366 .35056 m .49336 .35039 L .49103 .35102 L closepath p F P
0 g
s
.588 .857 .994 r
.49077 .34924 m .49336 .35039 L .49103 .35102 L p F P
0 g
s
.588 .857 .994 r
.48125 .35169 m .49077 .34924 L p .49103 .35102 L F P
0 g
s
.635 .598 .795 r
.62178 .34903 m .61691 .35024 L .61442 .345 L p F P
0 g
s
.441 0 .071 r
.49105 .45789 m .49058 .45844 L .48757 .45837 L closepath p F P
0 g
s
.444 0 .07 r
.48921 .46005 m .49058 .45844 L .48757 .45837 L p F P
0 g
s
.444 0 .07 r
.48018 .46127 m .48921 .46005 L p .48757 .45837 L F P
0 g
s
.444 0 .07 r
.47846 .46121 m .48018 .46127 L p .48757 .45837 L F P
0 g
s
.446 .018 .132 r
.50268 .45497 m .50956 .45479 L .50187 .45617 L closepath p F P
0 g
s
.792 .427 .365 r
.24728 .42636 m .25319 .4283 L .25157 .42477 L p F P
0 g
s
.792 .427 .365 r
.25157 .42477 m .24563 .42284 L .24728 .42636 L p F P
0 g
s
.63 .854 .984 r
.52712 .34458 m .51755 .34766 L .51501 .34613 L p F P
0 g
s
.625 .848 .984 r
.50546 .34904 m .51501 .34613 L .51755 .34766 L p F P
0 g
s
.541 .042 .021 r
.39507 .46502 m .39367 .46595 L .39016 .46479 L closepath p F P
0 g
s
.802 .661 .708 r
.20388 .36435 m .20189 .36343 L .20298 .3657 L closepath p F P
0 g
s
.381 .784 .984 r
.39524 .35493 m .39655 .35546 L p .38448 .35511 L F P
0 g
s
.381 .784 .984 r
.38448 .35511 m .38998 .35466 L .39524 .35493 L p F P
0 g
s
.406 .785 .992 r
.38448 .35511 m .38998 .35466 L .38215 .35406 L closepath p F P
0 g
s
.476 0 .014 r
.44391 .46457 m .44208 .46611 L .4351 .46498 L closepath p F P
0 g
s
.473 0 .002 r
.44169 .46643 m .44208 .46611 L .4351 .46498 L p F P
0 g
s
.473 0 .002 r
.43055 .46689 m .44169 .46643 L p .4351 .46498 L F P
0 g
s
.473 0 .002 r
.42996 .46679 m .43055 .46689 L p .4351 .46498 L F P
0 g
s
.815 .498 .454 r
.22748 .41301 m .2331 .41508 L .23229 .41129 L p F P
0 g
s
.815 .498 .454 r
.22742 .41272 m .22748 .41301 L p .23229 .41129 L F P
0 g
s
.815 .498 .454 r
.23229 .41129 m .22885 .41002 L .22742 .41272 L p F P
0 g
s
.685 .228 .16 r
.30996 .45295 m .30629 .45006 L .31349 .45151 L p F P
0 g
s
.685 .228 .16 r
.31489 .45396 m .30996 .45295 L p .31349 .45151 L F P
0 g
s
.685 .228 .16 r
.31349 .45151 m .31585 .45337 L .31489 .45396 L p F P
0 g
s
.563 .429 .657 r
.62465 .37467 m .62942 .37492 L .62511 .37704 L closepath p F P
0 g
s
.425 .028 .181 r
.53838 .44425 m .53627 .44478 L .53491 .44736 L p F P
0 g
s
.715 .715 .848 r
.22616 .3441 m .23142 .34114 L .22848 .33778 L p F P
0 g
s
.715 .715 .848 r
.22848 .33778 m .22084 .34186 L .22616 .3441 L p F P
0 g
s
.726 .706 .831 r
.21924 .34276 m .22084 .34186 L .22616 .3441 L p F P
0 g
s
.632 .151 .093 r
.33694 .45963 m .33243 .457 L .34039 .45818 L p F P
0 g
s
.632 .151 .093 r
.34135 .46029 m .33694 .45963 L p .34039 .45818 L F P
0 g
s
.632 .151 .093 r
.34039 .45818 m .34268 .45951 L .34135 .46029 L p F P
0 g
s
.532 .026 0 r
.39255 .46668 m .39367 .46595 L .39016 .46479 L p F P
0 g
s
.532 .026 0 r
.38653 .46637 m .39255 .46668 L p .39016 .46479 L F P
0 g
s
.532 .026 0 r
.38161 .46474 m .38653 .46637 L p .39016 .46479 L F P
0 g
s
.532 .026 0 r
.39016 .46479 m .38217 .46439 L .38161 .46474 L p F P
0 g
s
.653 .651 .835 r
.61195 .34036 m .61195 .34036 L .60225 .34341 L p F P
0 g
s
.659 .668 .847 r
.61195 .34036 m .60225 .34341 L .59979 .33949 L p F P
0 g
s
.591 .113 .089 r
.36959 .46295 m .37099 .46358 L .36895 .46342 L closepath p F P
0 g
s
.567 .737 .956 r
.28874 .34033 m .29166 .34261 L .28354 .3439 L p F P
0 g
s
.567 .737 .956 r
.27965 .3415 m .28874 .34033 L p .28354 .3439 L F P
0 g
s
.567 .737 .956 r
.28354 .3439 m .28147 .34309 L .27965 .3415 L p F P
0 g
s
.464 .177 .391 r
.59792 .4175 m .5985 .41415 L .58906 .41771 L p F P
0 g
s
.464 .177 .391 r
.58906 .41771 m .58847 .42106 L .59792 .4175 L p F P
0 g
s
.454 .142 .346 r
.58772 .42422 m .58847 .42106 L .57889 .42441 L p F P
0 g
s
.454 .142 .346 r
.57889 .42441 m .57812 .42758 L .58772 .42422 L p F P
0 g
s
.815 .664 .695 r
.20081 .3695 m .20298 .3657 L .20189 .36343 L p F P
0 g
s
.783 .692 .764 r
.21045 .35057 m .20947 .35007 L .20342 .35632 L p F P
0 g
s
.774 .698 .779 r
.20986 .34972 m .20947 .35007 L .21045 .35057 L closepath p F P
0 g
s
.449 .756 .994 r
.33349 .35029 m .33403 .35026 L .33312 .35005 L closepath p F P
0 g
s
.605 .849 .99 r
.50289 .34771 m .50417 .34837 L .49366 .35056 L p F P
0 g
s
.605 .849 .99 r
.49366 .35056 m .49336 .35039 L .50289 .34771 L p F P
0 g
s
.612 .862 .99 r
.51443 .34585 m .51501 .34613 L .50546 .34904 L p F P
0 g
s
.612 .862 .99 r
.50546 .34904 m .50417 .34837 L .51443 .34585 L p F P
0 g
s
.424 0 .06 r
.50011 .45833 m .50187 .45617 L .49105 .45789 L p F P
0 g
s
.424 0 .06 r
.49105 .45789 m .49058 .45844 L .50011 .45833 L p F P
0 g
s
.518 .326 .559 r
.62659 .39086 m .62635 .38656 L .61732 .39075 L p F P
0 g
s
.518 .326 .559 r
.61732 .39075 m .61755 .39504 L .62659 .39086 L p F P
0 g
s
.455 0 0 r
.44853 .46428 m .44391 .46457 L .44208 .46611 L p F P
0 g
s
.757 .346 .272 r
.27519 .43768 m .27441 .43824 L .27367 .43725 L closepath p F P
0 g
s
.554 .052 .018 r
.38217 .46439 m .38161 .46474 L .38034 .46427 L closepath p F P
0 g
s
.425 .031 .185 r
.54643 .44222 m .546 .44304 L .53838 .44425 L closepath p F P
0 g
s
.425 .028 .181 r
.5451 .44481 m .546 .44304 L .53838 .44425 L p F P
0 g
s
.425 .028 .181 r
.53491 .44736 m .5451 .44481 L p .53838 .44425 L F P
0 g
s
.376 .79 .979 r
.40792 .35533 m .40863 .3556 L p .39655 .35546 L F P
0 g
s
.376 .79 .979 r
.39655 .35546 m .40003 .35513 L .40792 .35533 L p F P
0 g
s
.398 .791 .988 r
.39655 .35546 m .40003 .35513 L .39524 .35493 L closepath p F P
0 g
s
.442 .755 .995 r
.34001 .34835 m .34265 .34974 L .33403 .35026 L p F P
0 g
s
.442 .755 .995 r
.33938 .34824 m .34001 .34835 L p .33403 .35026 L F P
0 g
s
.442 .755 .995 r
.33062 .34849 m .33938 .34824 L p .33403 .35026 L F P
0 g
s
.442 .755 .995 r
.33403 .35026 m .33312 .35005 L .33062 .34849 L p F P
0 g
s
.548 .398 .63 r
.63478 .37759 m .62586 .38197 L .62511 .37704 L p F P
0 g
s
.548 .398 .63 r
.63456 .37607 m .63478 .37759 L p .62511 .37704 L F P
0 g
s
.548 .398 .63 r
.62511 .37704 m .62942 .37492 L .63456 .37607 L p F P
0 g
s
.509 .293 .521 r
.61757 .39907 m .61053 .40212 L .61265 .39718 L p F P
0 g
s
.509 .293 .521 r
.61265 .39718 m .61755 .39504 L .61757 .39907 L p F P
0 g
s
.442 .105 .298 r
.57731 .43019 m .57812 .42758 L .5684 .43074 L p F P
0 g
s
.442 .105 .298 r
.5684 .43074 m .56765 .43311 L .57731 .43019 L p F P
0 g
s
.478 .217 .439 r
.59889 .41058 m .59875 .41184 L .60336 .40878 L closepath p F P
0 g
s
.457 0 .008 r
.45553 .46379 m .45421 .46495 L .44853 .46428 L closepath p F P
0 g
s
.455 0 0 r
.45336 .46568 m .45421 .46495 L .44853 .46428 L p F P
0 g
s
.455 0 0 r
.44365 .46632 m .45336 .46568 L p .44853 .46428 L F P
0 g
s
.455 0 0 r
.44208 .46611 m .44365 .46632 L p .44853 .46428 L F P
0 g
s
.553 .051 .016 r
.37686 .46578 m .37099 .46358 L .38034 .46427 L p F P
0 g
s
.553 .051 .016 r
.37955 .46598 m .37686 .46578 L p .38034 .46427 L F P
0 g
s
.553 .051 .016 r
.38034 .46427 m .38161 .46474 L .37955 .46598 L p F P
0 g
s
.524 .757 .982 r
.29457 .34495 m .30368 .34389 L .30658 .34603 L p F P
0 g
s
.491 .755 .989 r
.30368 .34389 m .29457 .34495 L .29166 .34261 L p F P
0 g
s
.801 .462 .414 r
.24517 .42151 m .24563 .42284 L .24451 .42246 L closepath p F P
0 g
s
.833 .611 .601 r
.20092 .38573 m .20592 .38806 L .20692 .38365 L p F P
0 g
s
.833 .611 .601 r
.20692 .38365 m .20194 .38131 L .20092 .38573 L p F P
0 g
s
.828 .583 .568 r
.21017 .39448 m .21046 .3946 L .21099 .39035 L p F P
0 g
s
.828 .583 .568 r
.21099 .39035 m .21024 .39003 L .21017 .39448 L p F P
0 g
s
.749 .714 .82 r
.20986 .34972 m .21924 .34276 L .21745 .34054 L p F P
0 g
s
.749 .714 .82 r
.20695 .34566 m .20986 .34972 L p .21745 .34054 L F P
0 g
s
.772 .702 .786 r
.20947 .35007 m .20986 .34972 L .20695 .34566 L p F P
0 g
s
.564 .87 .995 r
.50289 .34771 m .49336 .35039 L .49077 .34924 L p F P
0 g
s
.782 .696 .769 r
.19845 .35394 m .20342 .35632 L .20947 .35007 L p F P
0 g
s
.782 .696 .769 r
.20947 .35007 m .20478 .34759 L .19845 .35394 L p F P
0 g
s
.772 .702 .786 r
.20695 .34566 m .20478 .34759 L .20947 .35007 L p F P
0 g
s
.781 .394 .322 r
.26038 .43062 m .2597 .43119 L .25914 .43023 L closepath p F P
0 g
s
.472 .768 .995 r
.33312 .35005 m .33062 .34849 L .32657 .34884 L closepath p F P
0 g
s
.737 .328 .273 r
.28921 .4438 m .28929 .4439 L .28913 .44386 L closepath p F P
0 g
s
.807 .673 .717 r
.20018 .36024 m .19899 .36196 L .20189 .36343 L closepath p F P
0 g
s
.815 .664 .695 r
.19597 .36709 m .20081 .3695 L p .20189 .36343 L F P
0 g
s
.815 .664 .695 r
.20189 .36343 m .19899 .36196 L .19597 .36709 L p F P
0 g
s
.811 .471 .413 r
.23428 .41875 m .23991 .42081 L .23875 .41713 L p F P
0 g
s
.811 .471 .413 r
.23875 .41713 m .2331 .41508 L .23428 .41875 L p F P
0 g
s
.757 .346 .271 r
.26986 .43872 m .26743 .43544 L .27367 .43725 L p F P
0 g
s
.757 .346 .271 r
.27261 .43952 m .26986 .43872 L p .27367 .43725 L F P
0 g
s
.757 .346 .271 r
.27367 .43725 m .27441 .43824 L .27261 .43952 L p F P
0 g
s
.717 .276 .201 r
.28641 .44552 m .29243 .44695 L .28929 .4439 L p F P
0 g
s
.717 .276 .201 r
.28929 .4439 m .28913 .44386 L .28641 .44552 L p F P
0 g
s
.733 .298 .218 r
.28566 .44533 m .28641 .44552 L .28913 .44386 L p F P
0 g
s
.733 .298 .218 r
.28913 .44386 m .28274 .4422 L .28566 .44533 L p F P
0 g
s
.829 .63 .634 r
.19699 .37895 m .20194 .38131 L .20351 .37671 L p F P
0 g
s
.829 .63 .634 r
.20351 .37671 m .19859 .37434 L .19699 .37895 L p F P
0 g
s
.828 .559 .532 r
.21039 .39869 m .2157 .40089 L .21577 .3968 L p F P
0 g
s
.828 .559 .532 r
.21577 .3968 m .21046 .3946 L .21039 .39869 L p F P
0 g
s
.606 .75 .947 r
.28147 .34309 m .27965 .3415 L .2773 .34202 L closepath p F P
0 g
s
.586 .485 .706 r
.6277 .36321 m .63137 .36135 L .63178 .36281 L closepath p F P
0 g
s
.383 .799 .977 r
.42025 .35534 m .42072 .3555 L p .40863 .3556 L F P
0 g
s
.383 .799 .977 r
.40863 .3556 m .41079 .35536 L .42025 .35534 L p F P
0 g
s
.398 .8 .984 r
.40863 .3556 m .41079 .35536 L .40792 .35533 L closepath p F P
0 g
s
.836 .59 .567 r
.20539 .3923 m .21017 .39448 L .21024 .39003 L p F P
0 g
s
.836 .59 .567 r
.21024 .39003 m .20592 .38806 L .20539 .3923 L p F P
0 g
s
.531 .864 .994 r
.49077 .34924 m .48125 .35169 L .47864 .35063 L p F P
0 g
s
.531 .857 .996 r
.46915 .35284 m .47864 .35063 L .48125 .35169 L p F P
0 g
s
.781 .394 .322 r
.25516 .43173 m .25319 .4283 L .25914 .43023 L p F P
0 g
s
.781 .394 .322 r
.25796 .43264 m .25516 .43173 L p .25914 .43023 L F P
0 g
s
.781 .394 .322 r
.25914 .43023 m .2597 .43119 L .25796 .43264 L p F P
0 g
s
.436 0 0 r
.46334 .46311 m .45553 .46379 L .45421 .46495 L p F P
0 g
s
.424 0 .127 r
.52459 .44972 m .52433 .45012 L .52148 .45036 L closepath p F P
0 g
s
.428 .003 .128 r
.52303 .4521 m .52433 .45012 L .52148 .45036 L p F P
0 g
s
.428 .003 .128 r
.51254 .45425 m .52303 .4521 L p .52148 .45036 L F P
0 g
s
.658 .738 .909 r
.24353 .34039 m .25266 .33737 L .25559 .3403 L p F P
0 g
s
.646 .739 .917 r
.25266 .33737 m .24353 .34039 L .24059 .33725 L p F P
0 g
s
.69 .732 .883 r
.23142 .34114 m .24059 .33725 L .24353 .34039 L p F P
0 g
s
.79 .675 .737 r
.19735 .35521 m .19845 .35394 L .20342 .35632 L p F P
0 g
s
.79 .675 .737 r
.20342 .35632 m .20018 .36024 L .19735 .35521 L p F P
0 g
s
.824 .51 .458 r
.22885 .41002 m .22742 .41272 L .22675 .40919 L closepath p F P
0 g
s
.627 .137 .07 r
.32907 .45841 m .33694 .45963 L .33243 .457 L p F P
0 g
s
.627 .137 .07 r
.32773 .45762 m .32907 .45841 L p .33243 .457 L F P
0 g
s
.627 .137 .07 r
.33243 .457 m .32972 .45658 L .32773 .45762 L p F P
0 g
s
.68 .734 .891 r
.24059 .33725 m .23142 .34114 L .22848 .33778 L p F P
0 g
s
.319 .74 .975 r
.35471 .35089 m .34552 .35135 L .34265 .34974 L p F P
0 g
s
.551 .042 0 r
.36761 .46504 m .37686 .46578 L .37099 .46358 L p F P
0 g
s
.551 .042 0 r
.36667 .46468 m .36761 .46504 L p .37099 .46358 L F P
0 g
s
.551 .042 0 r
.37099 .46358 m .36895 .46342 L .36667 .46468 L p F P
0 g
s
.401 .81 .979 r
.43228 .35499 m .43282 .35517 L p .42072 .3555 L F P
0 g
s
.401 .81 .979 r
.42072 .3555 m .42236 .35529 L .43228 .35499 L p F P
0 g
s
.409 .811 .982 r
.42072 .3555 m .42236 .35529 L .42025 .35534 L closepath p F P
0 g
s
.515 .857 .994 r
.47768 .35034 m .47864 .35063 L .46915 .35284 L p F P
0 g
s
.515 .857 .994 r
.46915 .35284 m .46667 .35192 L .47768 .35034 L p F P
0 g
s
.501 .849 .995 r
.46667 .35192 m .46915 .35284 L p .45704 .35383 L F P
0 g
s
.424 .058 .237 r
.56633 .43649 m .56746 .43372 L .55759 .43667 L p F P
0 g
s
.424 .058 .237 r
.55759 .43667 m .55645 .43945 L .56633 .43649 L p F P
0 g
s
.828 .536 .494 r
.21605 .40484 m .22138 .40702 L .22103 .40307 L p F P
0 g
s
.828 .536 .494 r
.22103 .40307 m .2157 .40089 L .21605 .40484 L p F P
0 g
s
.823 .649 .667 r
.1937 .37195 m .19859 .37434 L .20081 .3695 L p F P
0 g
s
.823 .649 .667 r
.20081 .3695 m .19597 .36709 L .1937 .37195 L p F P
0 g
s
.68 .212 .134 r
.30283 .45146 m .30996 .45295 L .30629 .45006 L p F P
0 g
s
.68 .212 .134 r
.30094 .44997 m .30283 .45146 L p .30629 .45006 L F P
0 g
s
.68 .212 .134 r
.30629 .45006 m .30232 .44924 L .30094 .44997 L p F P
0 g
s
.489 .251 .481 r
.60839 .40304 m .60832 .40447 L .61053 .40212 L closepath p F P
0 g
s
.423 0 .057 r
.50008 .45836 m .50011 .45833 L .49058 .45844 L p F P
0 g
s
.423 0 .057 r
.49058 .45844 m .48921 .46005 L .50008 .45836 L p F P
0 g
s
.573 .069 .02 r
.36895 .46342 m .36667 .46468 L .36205 .46274 L closepath p F P
0 g
s
.624 .744 .933 r
.25559 .3403 m .2647 .33799 L .26763 .3407 L p F P
0 g
s
.608 .746 .943 r
.2647 .33799 m .25559 .3403 L .25266 .33737 L p F P
0 g
s
.635 .598 .795 r
.62617 .34674 m .62178 .34903 L p .61442 .345 L F P
0 g
s
.635 .598 .795 r
.61442 .345 m .62416 .34234 L .62617 .34674 L p F P
0 g
s
.64 .631 .826 r
.61195 .34036 m .61442 .345 L .62416 .34234 L p F P
0 g
s
.501 .849 .995 r
.45704 .35383 m .46562 .35204 L .46667 .35192 L p F P
0 g
s
.488 .85 .991 r
.45704 .35383 m .46562 .35204 L .45549 .3533 L closepath p F P
0 g
s
.463 .838 .989 r
.45549 .3533 m .45704 .35383 L p .44493 .35461 L F P
0 g
s
.428 .824 .983 r
.44402 .35431 m .44493 .35461 L p .43282 .35517 L F P
0 g
s
.428 .824 .983 r
.43282 .35517 m .43501 .35483 L .44402 .35431 L p F P
0 g
s
.428 .824 .983 r
.43282 .35517 m .43501 .35483 L .43228 .35499 L closepath p F P
0 g
s
.647 .164 .091 r
.32972 .45658 m .32773 .45762 L .32475 .45572 L closepath p F P
0 g
s
.537 .032 .002 r
.38161 .46474 m .38653 .46637 L .37955 .46598 L closepath p F P
0 g
s
.455 .838 .986 r
.44493 .35461 m .44917 .35384 L .44402 .35431 L closepath p F P
0 g
s
.463 .838 .989 r
.44493 .35461 m .44917 .35384 L .45549 .3533 L p F P
0 g
s
.624 .58 .784 r
.62178 .34903 m .62617 .34674 L .62666 .34787 L closepath p F P
0 g
s
.477 .215 .438 r
.60336 .40878 m .59875 .41184 L .5985 .41415 L p F P
0 g
s
.474 .76 .993 r
.31768 .34662 m .31859 .34722 L p .30658 .34603 L F P
0 g
s
.474 .76 .993 r
.30658 .34603 m .31281 .34555 L .31768 .34662 L p F P
0 g
s
.442 .745 .992 r
.31281 .34555 m .30658 .34603 L .30368 .34389 L p F P
0 g
s
.405 0 .116 r
.53394 .44891 m .53491 .44736 L .52459 .44972 L p F P
0 g
s
.405 0 .116 r
.52459 .44972 m .52433 .45012 L .53394 .44891 L p F P
0 g
s
.72 .71 .84 r
.22084 .34186 m .21745 .34054 L .21924 .34276 L closepath p F P
0 g
s
.794 .427 .362 r
.24228 .42469 m .24728 .42636 L .24563 .42284 L p F P
0 g
s
.794 .427 .362 r
.24563 .42284 m .24451 .42246 L .24228 .42469 L p F P
0 g
s
.805 .677 .723 r
.19899 .36196 m .20018 .36024 L .19735 .35521 L p F P
0 g
s
.436 0 0 r
.46483 .46469 m .46634 .46334 L .46334 .46311 L p F P
0 g
s
.436 0 0 r
.45808 .46529 m .46483 .46469 L p .46334 .46311 L F P
0 g
s
.436 0 0 r
.45421 .46495 m .45808 .46529 L p .46334 .46311 L F P
0 g
s
.436 0 0 r
.46695 .46278 m .46634 .46334 L .46334 .46311 L closepath p F P
0 g
s
.749 .333 .261 r
.27441 .43824 m .27623 .44049 L .27261 .43952 L closepath p F P
0 g
s
.463 .772 .997 r
.32773 .34679 m .31975 .34717 L .32657 .34884 L p F P
0 g
s
.463 .772 .997 r
.32657 .34884 m .33062 .34849 L .32773 .34679 L p F P
0 g
s
.438 .749 .994 r
.31859 .34722 m .31975 .34717 L .32657 .34884 L p F P
0 g
s
.675 .735 .896 r
.57554 .33975 m .5852 .33631 L .58766 .33935 L p F P
0 g
s
.678 .761 .913 r
.5852 .33631 m .57554 .33975 L .57307 .33711 L p F P
0 g
s
.676 .765 .918 r
.56343 .34057 m .57307 .33711 L .57554 .33975 L p F P
0 g
s
.824 .51 .458 r
.22211 .41084 m .22138 .40702 L .22675 .40919 L p F P
0 g
s
.824 .51 .458 r
.2273 .41294 m .22211 .41084 L p .22675 .40919 L F P
0 g
s
.824 .51 .458 r
.22675 .40919 m .22742 .41272 L .2273 .41294 L p F P
0 g
s
.585 .744 .953 r
.26763 .3407 m .27132 .34003 L .2773 .34202 L p F P
0 g
s
.604 .756 .951 r
.27672 .33902 m .27132 .34003 L .2773 .34202 L p F P
0 g
s
.604 .756 .951 r
.2773 .34202 m .27965 .3415 L .27672 .33902 L p F P
0 g
s
.407 0 .058 r
.50956 .45479 m .50187 .45617 L .50011 .45833 L p F P
0 g
s
.774 .383 .314 r
.2597 .43119 m .26122 .43361 L .25796 .43264 L closepath p F P
0 g
s
.677 .79 .934 r
.57307 .33711 m .56343 .34057 L .56096 .33827 L p F P
0 g
s
.38 .798 .976 r
.42025 .35534 m .41798 .35457 L .41079 .35536 L closepath p F P
0 g
s
.392 .799 .982 r
.41525 .35381 m .41798 .35457 L .41079 .35536 L p F P
0 g
s
.392 .799 .982 r
.41517 .35381 m .41525 .35381 L p .41079 .35536 L F P
0 g
s
.392 .799 .982 r
.40587 .35459 m .41517 .35381 L p .41079 .35536 L F P
0 g
s
.392 .799 .982 r
.41079 .35536 m .40792 .35533 L .40587 .35459 L p F P
0 g
s
.618 .133 .08 r
.34268 .45951 m .34502 .46077 L .34135 .46029 L closepath p F P
0 g
s
.404 .81 .98 r
.42236 .35529 m .42025 .35534 L .41798 .35457 L p F P
0 g
s
.375 .789 .978 r
.40792 .35533 m .40587 .35459 L .40003 .35513 L closepath p F P
0 g
s
.418 0 0 r
.47611 .46348 m .47818 .46153 L .46695 .46278 L p F P
0 g
s
.418 0 0 r
.47424 .46369 m .47611 .46348 L p .46695 .46278 L F P
0 g
s
.418 0 0 r
.46695 .46278 m .46634 .46334 L .47424 .46369 L p F P
0 g
s
.717 .711 .844 r
.22084 .34186 m .22848 .33778 L p .21631 .33913 L F P
0 g
s
.717 .711 .844 r
.21631 .33913 m .21745 .34054 L .22084 .34186 L p F P
0 g
s
.669 .702 .872 r
.58766 .33935 m .59734 .33599 L .59979 .33949 L p F P
0 g
s
.674 .729 .891 r
.59734 .33599 m .58766 .33935 L .5852 .33631 L p F P
0 g
s
.805 .443 .371 r
.24142 .42438 m .24228 .42469 L .24451 .42246 L p F P
0 g
s
.805 .443 .371 r
.24451 .42246 m .23991 .42081 L .24142 .42438 L p F P
0 g
s
.395 .809 .977 r
.43228 .35499 m .43011 .35429 L .42236 .35529 L closepath p F P
0 g
s
.404 .81 .98 r
.42743 .35359 m .43011 .35429 L .42236 .35529 L p F P
0 g
s
.404 .81 .98 r
.42719 .3536 m .42743 .35359 L p .42236 .35529 L F P
0 g
s
.404 .81 .98 r
.41798 .35457 m .42719 .3536 L p .42236 .35529 L F P
0 g
s
.566 .735 .955 r
.27132 .34003 m .26763 .3407 L .2647 .33799 L p F P
0 g
s
.561 .049 0 r
.36622 .46492 m .36667 .46468 L .36205 .46274 L p F P
0 g
s
.561 .049 0 r
.3588 .46415 m .36622 .46492 L p .36205 .46274 L F P
0 g
s
.561 .049 0 r
.35465 .46241 m .3588 .46415 L p .36205 .46274 L F P
0 g
s
.561 .049 0 r
.36205 .46274 m .35535 .46206 L .35465 .46241 L p F P
0 g
s
.805 .677 .723 r
.19735 .35521 m .19425 .3595 L .19899 .36196 L p F P
0 g
s
.816 .667 .698 r
.19116 .36466 m .19597 .36709 L .19899 .36196 L p F P
0 g
s
.816 .667 .698 r
.19899 .36196 m .19425 .3595 L .19116 .36466 L p F P
0 g
s
.673 .794 .939 r
.55142 .34178 m .55133 .34169 L .55923 .33888 L closepath p F P
0 g
s
.698 .237 .153 r
.30232 .44924 m .30094 .44997 L .29925 .44854 L closepath p F P
0 g
s
.35 .76 .981 r
.36865 .35275 m .36961 .35317 L p .35756 .35233 L F P
0 g
s
.35 .76 .981 r
.35756 .35233 m .36291 .3521 L .36865 .35275 L p F P
0 g
s
.306 .735 .971 r
.36291 .3521 m .35756 .35233 L .35471 .35089 L p F P
0 g
s
.391 .79 .986 r
.4031 .35374 m .40587 .35459 L .40003 .35513 L p F P
0 g
s
.391 .79 .986 r
.39377 .35434 m .4031 .35374 L p .40003 .35513 L F P
0 g
s
.391 .79 .986 r
.40003 .35513 m .39524 .35493 L .39377 .35434 L p F P
0 g
s
.528 .359 .595 r
.63527 .38218 m .63478 .37759 L .62586 .38197 L p F P
0 g
s
.528 .359 .595 r
.62586 .38197 m .62635 .38656 L .63527 .38218 L p F P
0 g
s
.488 .251 .48 r
.61738 .40285 m .61757 .39907 L .61053 .40212 L p F P
0 g
s
.488 .251 .48 r
.6082 .40682 m .61738 .40285 L p .61053 .40212 L F P
0 g
s
.488 .251 .48 r
.61053 .40212 m .60832 .40447 L .6082 .40682 L p F P
0 g
s
.606 .861 .992 r
.51245 .3449 m .51443 .34585 L .50417 .34837 L p F P
0 g
s
.606 .861 .992 r
.50417 .34837 m .50289 .34771 L .51245 .3449 L p F P
0 g
s
.669 .821 .957 r
.55923 .33888 m .55133 .34169 L .54884 .33973 L p F P
0 g
s
.477 .215 .438 r
.60781 .41038 m .6082 .40682 L .60336 .40878 L p F P
0 g
s
.477 .215 .438 r
.5985 .41415 m .60781 .41038 L p .60336 .40878 L F P
0 g
s
.5 .26 .482 r
.60832 .40447 m .60336 .40878 L .6082 .40682 L closepath p F P
0 g
s
.424 .823 .982 r
.43501 .35483 m .43228 .35499 L .43011 .35429 L p F P
0 g
s
.673 .211 .148 r
.31585 .45337 m .31722 .45438 L .31489 .45396 L closepath p F P
0 g
s
.647 .163 .089 r
.32149 .45708 m .31722 .45438 L .32475 .45572 L p F P
0 g
s
.647 .163 .089 r
.32688 .45806 m .32149 .45708 L p .32475 .45572 L F P
0 g
s
.647 .163 .089 r
.32475 .45572 m .32773 .45762 L .32688 .45806 L p F P
0 g
s
.381 .784 .984 r
.39524 .35493 m .39377 .35434 L .38998 .35466 L closepath p F P
0 g
s
.404 0 .114 r
.53339 .44977 m .53394 .44891 L .52433 .45012 L p F P
0 g
s
.404 0 .114 r
.52433 .45012 m .52303 .4521 L .53339 .44977 L p F P
0 g
s
.406 .013 .176 r
.55565 .44105 m .55645 .43945 L .54643 .44222 L p F P
0 g
s
.406 .013 .176 r
.54643 .44222 m .546 .44304 L .55565 .44105 L p F P
0 g
s
.731 .291 .206 r
.27919 .4436 m .28566 .44533 L .28274 .4422 L p F P
0 g
s
.731 .291 .206 r
.28274 .4422 m .27623 .44049 L .27919 .4436 L p F P
0 g
s
.421 .822 .981 r
.44402 .35431 m .44224 .35373 L .43501 .35483 L closepath p F P
0 g
s
.424 .823 .982 r
.43953 .35305 m .44224 .35373 L .43501 .35483 L p F P
0 g
s
.424 .823 .982 r
.43011 .35429 m .43953 .35305 L p .43501 .35483 L F P
0 g
s
.76 .344 .262 r
.26369 .43688 m .26986 .43872 L .26743 .43544 L p F P
0 g
s
.76 .344 .262 r
.26743 .43544 m .26122 .43361 L .26369 .43688 L p F P
0 g
s
.666 .694 .866 r
.6095 .3363 m .59979 .33949 L .59734 .33599 L p F P
0 g
s
.659 .668 .847 r
.59979 .33949 m .6095 .3363 L .61195 .34036 L p F P
0 g
s
.547 .4 .633 r
.62942 .37492 m .634 .37263 L .63456 .37607 L closepath p F P
0 g
s
.497 .283 .52 r
.62662 .39489 m .62659 .39086 L .61755 .39504 L p F P
0 g
s
.497 .283 .52 r
.61755 .39504 m .61757 .39907 L .62662 .39489 L p F P
0 g
s
.446 0 .069 r
.47846 .46121 m .48018 .46127 L .47818 .46153 L closepath p F P
0 g
s
.524 .022 .005 r
.39367 .46595 m .39661 .46681 L .39255 .46668 L closepath p F P
0 g
s
.603 .532 .748 r
.62918 .35444 m .63 .3543 L .62927 .35469 L closepath p F P
0 g
s
.595 .514 .733 r
.6401 .35666 m .63137 .36135 L .62927 .35469 L p F P
0 g
s
.595 .514 .733 r
.63901 .35306 m .6401 .35666 L p .62927 .35469 L F P
0 g
s
.595 .514 .733 r
.62927 .35469 m .63 .3543 L .63901 .35306 L p F P
0 g
s
.612 .547 .757 r
.63 .3543 m .62918 .35444 L .62666 .34787 L p F P
0 g
s
.399 .783 .991 r
.39097 .3534 m .39377 .35434 L .38998 .35466 L p F P
0 g
s
.399 .783 .991 r
.38168 .35386 m .39097 .3534 L p .38998 .35466 L F P
0 g
s
.399 .783 .991 r
.38998 .35466 m .38215 .35406 L .38168 .35386 L p F P
0 g
s
.657 .843 .971 r
.54884 .33973 m .53923 .34307 L .53672 .34137 L p F P
0 g
s
.65 .84 .973 r
.52712 .34458 m .53672 .34137 L .53923 .34307 L p F P
0 g
s
.574 .477 .707 r
.64165 .36254 m .6401 .35666 L .63137 .36135 L p F P
0 g
s
.574 .477 .707 r
.63137 .36135 m .63178 .36281 L .64165 .36254 L p F P
0 g
s
.812 .469 .408 r
.22868 .41668 m .23428 .41875 L .2331 .41508 L p F P
0 g
s
.812 .469 .408 r
.2331 .41508 m .22748 .41301 L .22868 .41668 L p F P
0 g
s
.448 .745 .992 r
.31859 .34722 m .31975 .34717 L .31768 .34662 L closepath p F P
0 g
s
.583 .076 .013 r
.35535 .46206 m .35465 .46241 L .35335 .46182 L closepath p F P
0 g
s
.573 .465 .692 r
.64167 .36263 m .64165 .36254 L .63178 .36281 L p F P
0 g
s
.573 .465 .692 r
.63178 .36281 m .63289 .36725 L .64167 .36263 L p F P
0 g
s
.698 .236 .152 r
.29589 .4499 m .29243 .44695 L .29925 .44854 L p F P
0 g
s
.698 .236 .152 r
.29946 .45074 m .29589 .4499 L p .29925 .44854 L F P
0 g
s
.698 .236 .152 r
.29925 .44854 m .30094 .44997 L .29946 .45074 L p F P
0 g
s
.838 .592 .567 r
.20038 .38998 m .20539 .3923 L .20592 .38806 L p F P
0 g
s
.838 .592 .567 r
.20592 .38806 m .20092 .38573 L .20038 .38998 L p F P
0 g
s
.835 .613 .602 r
.19595 .38338 m .20092 .38573 L .20194 .38131 L p F P
0 g
s
.835 .613 .602 r
.20194 .38131 m .19699 .37895 L .19595 .38338 L p F P
0 g
s
.785 .395 .315 r
.24927 .42977 m .25516 .43173 L .25319 .4283 L p F P
0 g
s
.785 .395 .315 r
.25319 .4283 m .24728 .42636 L .24927 .42977 L p F P
0 g
s
.516 .748 .98 r
.28874 .34033 m .27965 .3415 L .27672 .33902 L p F P
0 g
s
.779 .698 .774 r
.19584 .35268 m .19845 .35394 L .20478 .34759 L p F P
0 g
s
.779 .698 .774 r
.19448 .35053 m .19584 .35268 L p .20478 .34759 L F P
0 g
s
.779 .698 .774 r
.20478 .34759 m .20007 .34511 L .19448 .35053 L p F P
0 g
s
.768 .704 .791 r
.20478 .34759 m .20695 .34566 L .20403 .34173 L p F P
0 g
s
.768 .704 .791 r
.20403 .34173 m .20007 .34511 L .20478 .34759 L p F P
0 g
s
.452 .837 .985 r
.44917 .35384 m .44402 .35431 L .44224 .35373 L p F P
0 g
s
.612 .547 .757 r
.63797 .34995 m .63 .3543 L p .62666 .34787 L F P
0 g
s
.596 .521 .74 r
.63 .3543 m .63797 .34995 L .63901 .35306 L closepath p F P
0 g
s
.583 .075 .011 r
.35022 .46318 m .34502 .46077 L .35335 .46182 L p F P
0 g
s
.583 .075 .011 r
.3525 .46347 m .35022 .46318 L p .35335 .46182 L F P
0 g
s
.583 .075 .011 r
.35335 .46182 m .35465 .46241 L .3525 .46347 L p F P
0 g
s
.831 .562 .531 r
.20948 .3983 m .21039 .39869 L .21046 .3946 L p F P
0 g
s
.831 .562 .531 r
.21046 .3946 m .21017 .39448 L .20948 .3983 L p F P
0 g
s
.749 .714 .82 r
.21745 .34054 m .21566 .33955 L .20695 .34566 L p F P
0 g
s
.744 .702 .812 r
.21566 .33955 m .20695 .34566 L .20403 .34173 L p F P
0 g
s
.356 .76 .983 r
.36961 .35317 m .37156 .35309 L .36865 .35275 L closepath p F P
0 g
s
.328 .757 .972 r
.36961 .35317 m .37156 .35309 L .3806 .35394 L p F P
0 g
s
.83 .633 .636 r
.19207 .37658 m .19699 .37895 L .19859 .37434 L p F P
0 g
s
.83 .633 .636 r
.19859 .37434 m .1937 .37195 L .19207 .37658 L p F P
0 g
s
.839 .57 .532 r
.2053 .3964 m .20948 .3983 L .21017 .39448 L p F P
0 g
s
.839 .57 .532 r
.21017 .39448 m .20539 .3923 L .2053 .3964 L p F P
0 g
s
.64 .856 .982 r
.53672 .34137 m .52712 .34458 L .52459 .3431 L p F P
0 g
s
.63 .854 .984 r
.51501 .34613 m .52459 .3431 L .52712 .34458 L p F P
0 g
s
.398 .782 .99 r
.38215 .35406 m .38168 .35386 L .3806 .35394 L closepath p F P
0 g
s
.397 0 0 r
.48018 .46127 m .47818 .46153 L .47611 .46348 L p F P
0 g
s
.74 .717 .83 r
.21631 .33913 m .21566 .33955 L .21745 .34054 L closepath p F P
0 g
s
.402 0 .055 r
.51254 .45425 m .51223 .45463 L .50956 .45479 L closepath p F P
0 g
s
.407 0 .058 r
.51077 .45644 m .51223 .45463 L .50956 .45479 L p F P
0 g
s
.407 0 .058 r
.50034 .45832 m .51077 .45644 L p .50956 .45479 L F P
0 g
s
.407 0 .058 r
.50011 .45833 m .50034 .45832 L p .50956 .45479 L F P
0 g
s
.789 .681 .745 r
.19845 .35394 m .19584 .35268 L .19735 .35521 L closepath p F P
0 g
s
.368 .781 .98 r
.37887 .35278 m .37156 .35309 L .3806 .35394 L p F P
0 g
s
.368 .781 .98 r
.3806 .35394 m .38168 .35386 L .37887 .35278 L p F P
0 g
s
.44 .744 .992 r
.32483 .34516 m .32773 .34679 L .31975 .34717 L p F P
0 g
s
.44 .744 .992 r
.3157 .34531 m .32483 .34516 L p .31975 .34717 L F P
0 g
s
.44 .744 .992 r
.31975 .34717 m .31768 .34662 L .3157 .34531 L p F P
0 g
s
.452 .837 .985 r
.45169 .35224 m .45437 .35292 L .44917 .35384 L p F P
0 g
s
.452 .837 .985 r
.44224 .35373 m .45169 .35224 L p .44917 .35384 L F P
0 g
s
.454 .836 .987 r
.45549 .3533 m .45437 .35292 L .44917 .35384 L closepath p F P
0 g
s
.437 .127 .341 r
.59719 .42066 m .59792 .4175 L .58847 .42106 L p F P
0 g
s
.437 .127 .341 r
.58847 .42106 m .58772 .42422 L .59719 .42066 L p F P
0 g
s
.83 .536 .492 r
.21075 .40263 m .21605 .40484 L .2157 .40089 L p F P
0 g
s
.83 .536 .492 r
.2157 .40089 m .21039 .39869 L .21075 .40263 L p F P
0 g
s
.417 0 0 r
.46634 .46334 m .47424 .46369 L .46483 .46469 L closepath p F P
0 g
s
.509 .01 .006 r
.40575 .4667 m .40722 .46708 L .40524 .46706 L closepath p F P
0 g
s
.441 .104 .296 r
.5772 .43056 m .57731 .43019 L .56765 .43311 L p F P
0 g
s
.441 .104 .296 r
.56765 .43311 m .56746 .43372 L .5772 .43056 L p F P
0 g
s
.64 .631 .826 r
.62169 .33748 m .61195 .34036 L .61195 .34036 L p F P
0 g
s
.64 .631 .826 r
.62416 .34234 m .62169 .33748 L p .61195 .34036 L F P
0 g
s
.655 .658 .841 r
.61195 .34036 m .61195 .34036 L .6095 .3363 L p F P
0 g
s
.655 .658 .841 r
.62066 .33565 m .61195 .34036 L p .6095 .3363 L F P
0 g
s
.648 .649 .837 r
.61195 .34036 m .62066 .33565 L .62169 .33748 L closepath p F P
0 g
s
.556 .431 .664 r
.64277 .36799 m .64167 .36263 L .63289 .36725 L p F P
0 g
s
.556 .431 .664 r
.63289 .36725 m .634 .37263 L .64277 .36799 L p F P
0 g
s
.806 .683 .729 r
.19425 .3595 m .19735 .35521 L .19584 .35268 L p F P
0 g
s
.612 .547 .757 r
.62666 .34787 m .63646 .34587 L .63797 .34995 L p F P
0 g
s
.616 .576 .786 r
.62617 .34674 m .62666 .34787 L .63646 .34587 L p F P
0 g
s
.399 0 0 r
.48921 .46005 m .48797 .46125 L .48018 .46127 L closepath p F P
0 g
s
.397 0 0 r
.48718 .46201 m .48797 .46125 L .48018 .46127 L p F P
0 g
s
.397 0 0 r
.47611 .46348 m .48718 .46201 L p .48018 .46127 L F P
0 g
s
.449 .164 .387 r
.60726 .41374 m .60781 .41038 L .5985 .41415 L p F P
0 g
s
.449 .164 .387 r
.5985 .41415 m .59792 .4175 L .60726 .41374 L p F P
0 g
s
.823 .651 .669 r
.18884 .36954 m .1937 .37195 L .19597 .36709 L p F P
0 g
s
.823 .651 .669 r
.19597 .36709 m .19116 .36466 L .18884 .36954 L p F P
0 g
s
.424 .089 .292 r
.58699 .4266 m .58772 .42422 L .57812 .42758 L p F P
0 g
s
.424 .089 .292 r
.57812 .42758 m .57731 .43019 L .58699 .4266 L p F P
0 g
s
.807 .442 .366 r
.23581 .42232 m .24142 .42438 L .23991 .42081 L p F P
0 g
s
.807 .442 .366 r
.23991 .42081 m .23428 .41875 L .23581 .42232 L p F P
0 g
s
.615 .871 .99 r
.52448 .34305 m .52459 .3431 L .51501 .34613 L p F P
0 g
s
.615 .871 .99 r
.51501 .34613 m .51443 .34585 L .52448 .34305 L p F P
0 g
s
.64 .146 .061 r
.31405 .45571 m .32149 .45708 L .31722 .45438 L p F P
0 g
s
.64 .146 .061 r
.31278 .4549 m .31405 .45571 L p .31722 .45438 L F P
0 g
s
.64 .146 .061 r
.31722 .45438 m .31489 .45396 L .31278 .4549 L p F P
0 g
s
.406 .011 .174 r
.55514 .44205 m .55565 .44105 L .546 .44304 L p F P
0 g
s
.406 .011 .174 r
.546 .44304 m .5451 .44481 L .55514 .44205 L p F P
0 g
s
.566 .735 .955 r
.2647 .33799 m .26597 .3378 L .27132 .34003 L p F P
0 g
s
.583 .755 .959 r
.27378 .33659 m .26597 .3378 L .27132 .34003 L p F P
0 g
s
.583 .755 .959 r
.27132 .34003 m .27672 .33902 L .27378 .33659 L p F P
0 g
s
.627 .594 .797 r
.62416 .34234 m .62617 .34674 L .63486 .34197 L p F P
0 g
s
.616 .576 .786 r
.63646 .34587 m .63486 .34197 L .62617 .34674 L p F P
0 g
s
.381 0 .042 r
.52183 .45366 m .52303 .4521 L .51254 .45425 L p F P
0 g
s
.381 0 .042 r
.51254 .45425 m .51223 .45463 L .52183 .45366 L p F P
0 g
s
.22 .716 .915 r
.39097 .3534 m .38168 .35386 L .37887 .35278 L p F P
0 g
s
.31 .727 .975 r
.33938 .34824 m .33062 .34849 L .32773 .34679 L p F P
0 g
s
.48 .761 .992 r
.31768 .34662 m .3157 .34531 L .31281 .34555 L closepath p F P
0 g
s
.68 .734 .891 r
.22848 .33778 m .23764 .33418 L .24059 .33725 L p F P
0 g
s
.67 .735 .899 r
.23764 .33418 m .22848 .33778 L .22553 .33449 L p F P
0 g
s
.717 .711 .844 r
.22848 .33778 m .22553 .33449 L .21631 .33913 L p F P
0 g
s
.485 .85 .99 r
.46562 .35204 m .45549 .3533 L .45437 .35292 L p F P
0 g
s
.438 0 0 r
.45421 .46495 m .45808 .46529 L .45336 .46568 L closepath p F P
0 g
s
.494 0 .005 r
.41784 .46699 m .41848 .46713 L .41765 .46714 L closepath p F P
0 g
s
.491 .755 .989 r
.30134 .34223 m .30368 .34389 L p .29166 .34261 L F P
0 g
s
.491 .755 .989 r
.29166 .34261 m .3 .34189 L .30134 .34223 L p F P
0 g
s
.455 .745 .991 r
.3 .34189 m .29166 .34261 L .28874 .34033 L p F P
0 g
s
.828 .511 .453 r
.21679 .40865 m .22211 .41084 L .22138 .40702 L p F P
0 g
s
.828 .511 .453 r
.22138 .40702 m .21605 .40484 L .21679 .40865 L p F P
0 g
s
.388 0 .112 r
.54361 .44723 m .5451 .44481 L .53491 .44736 L p F P
0 g
s
.388 0 .112 r
.54303 .44737 m .54361 .44723 L p .53491 .44736 L F P
0 g
s
.388 0 .112 r
.53491 .44736 m .53394 .44891 L .54303 .44737 L p F P
0 g
s
.646 .739 .917 r
.24059 .33725 m .24971 .33451 L .25266 .33737 L p F P
0 g
s
.633 .74 .925 r
.24971 .33451 m .24059 .33725 L .23764 .33418 L p F P
0 g
s
.577 .06 0 r
.34198 .46209 m .35022 .46318 L .34502 .46077 L p F P
0 g
s
.577 .06 0 r
.33969 .46102 m .34198 .46209 L p .34502 .46077 L F P
0 g
s
.577 .06 0 r
.34502 .46077 m .34135 .46029 L .33969 .46102 L p F P
0 g
s
.567 .055 0 r
.35465 .46241 m .3588 .46415 L .3525 .46347 L closepath p F P
0 g
s
.347 .757 .981 r
.37654 .352 m .37887 .35278 L .37156 .35309 L p F P
0 g
s
.347 .757 .981 r
.37494 .35185 m .37654 .352 L p .37156 .35309 L F P
0 g
s
.347 .757 .981 r
.36678 .35193 m .37494 .35185 L p .37156 .35309 L F P
0 g
s
.347 .757 .981 r
.37156 .35309 m .36865 .35275 L .36678 .35193 L p F P
0 g
s
.661 .174 .084 r
.31489 .45396 m .31278 .4549 L .30996 .45295 L closepath p F P
0 g
s
.728 .281 .189 r
.27274 .44185 m .27919 .4436 L .27623 .44049 L p F P
0 g
s
.728 .281 .189 r
.27121 .44024 m .27274 .44185 L p .27623 .44049 L F P
0 g
s
.728 .281 .189 r
.27623 .44049 m .27261 .43952 L .27121 .44024 L p F P
0 g
s
.461 .201 .433 r
.61701 .40641 m .61738 .40285 L .6082 .40682 L p F P
0 g
s
.461 .201 .433 r
.6082 .40682 m .60781 .41038 L .61701 .40641 L p F P
0 g
s
.403 .038 .227 r
.57608 .43333 m .5772 .43056 L .56746 .43372 L p F P
0 g
s
.403 .038 .227 r
.56746 .43372 m .56633 .43649 L .57608 .43333 L p F P
0 g
s
.735 .719 .836 r
.21566 .33955 m .21631 .33913 L .21336 .33561 L p F P
0 g
s
.735 .719 .836 r
.21336 .33561 m .21113 .337 L .21566 .33955 L p F P
0 g
s
.744 .702 .812 r
.20403 .34173 m .21113 .337 L .21566 .33955 L p F P
0 g
s
.569 .878 .993 r
.51245 .3449 m .50289 .34771 L .50031 .34665 L p F P
0 g
s
.564 .87 .995 r
.49077 .34924 m .50031 .34665 L .50289 .34771 L p F P
0 g
s
.458 0 0 r
.44208 .46611 m .44365 .46632 L .44169 .46643 L closepath p F P
0 g
s
.476 0 .003 r
.42996 .46679 m .43055 .46689 L .42979 .46692 L closepath p F P
0 g
s
.507 .318 .558 r
.63552 .38647 m .63527 .38218 L .62635 .38656 L p F P
0 g
s
.507 .318 .558 r
.62635 .38656 m .62659 .39086 L .63552 .38647 L p F P
0 g
s
.759 .338 .249 r
.25754 .43502 m .26369 .43688 L .26122 .43361 L p F P
0 g
s
.759 .338 .249 r
.25643 .43354 m .25754 .43502 L p .26122 .43361 L F P
0 g
s
.759 .338 .249 r
.26122 .43361 m .25796 .43264 L .25643 .43354 L p F P
0 g
s
.703 .73 .871 r
.22553 .33449 m .21631 .33913 L .21336 .33561 L p F P
0 g
s
.443 0 0 r
.41848 .46713 m .41765 .46714 L .41506 .46868 L p F P
0 g
s
.467 0 0 r
.41499 .46868 m .41506 .46868 L .41765 .46714 L p F P
0 g
s
.467 0 0 r
.41765 .46714 m .40722 .46708 L .41499 .46868 L p F P
0 g
s
.448 0 0 r
.42979 .46692 m .41848 .46713 L .42688 .46852 L p F P
0 g
s
.443 0 0 r
.41506 .46868 m .42688 .46852 L .41848 .46713 L p F P
0 g
s
.691 .217 .121 r
.28914 .44827 m .29589 .4499 L .29243 .44695 L p F P
0 g
s
.691 .217 .121 r
.28605 .44568 m .28914 .44827 L p .29243 .44695 L F P
0 g
s
.691 .217 .121 r
.29243 .44695 m .28641 .44552 L .28605 .44568 L p F P
0 g
s
.806 .683 .729 r
.18954 .35703 m .19425 .3595 L p .19584 .35268 L F P
0 g
s
.815 .669 .701 r
.18637 .36222 m .19116 .36466 L .19425 .3595 L p F P
0 g
s
.815 .669 .701 r
.19425 .3595 m .18954 .35703 L .18637 .36222 L p F P
0 g
s
.459 0 0 r
.40392 .46856 m .41499 .46868 L .40722 .46708 L p F P
0 g
s
.459 0 0 r
.40291 .46835 m .40392 .46856 L p .40722 .46708 L F P
0 g
s
.459 0 0 r
.40722 .46708 m .40524 .46706 L .40291 .46835 L p F P
0 g
s
.354 .761 .982 r
.36865 .35275 m .36678 .35193 L .36291 .3521 L closepath p F P
0 g
s
.483 0 0 r
.40524 .46706 m .40291 .46835 L .39661 .46681 L closepath p F P
0 g
s
.608 .746 .943 r
.26295 .33641 m .2647 .33799 L p .25266 .33737 L F P
0 g
s
.608 .746 .943 r
.25266 .33737 m .26038 .33565 L .26295 .33641 L p F P
0 g
s
.59 .742 .948 r
.26038 .33565 m .25266 .33737 L .24971 .33451 L p F P
0 g
s
.819 .503 .455 r
.22742 .41272 m .22748 .41301 L .2273 .41294 L closepath p F P
0 g
s
.6 .09 .01 r
.34135 .46029 m .33969 .46102 L .33694 .45963 L closepath p F P
0 g
s
.797 .69 .747 r
.19448 .35053 m .19366 .35149 L .19584 .35268 L closepath p F P
0 g
s
.806 .683 .729 r
.19584 .35268 m .19366 .35149 L .18954 .35703 L p F P
0 g
s
.208 .715 .899 r
.4031 .35374 m .39377 .35434 L .39097 .3534 L p F P
0 g
s
.424 0 0 r
.43055 .46689 m .42979 .46692 L .42728 .46851 L p F P
0 g
s
.448 0 0 r
.42688 .46852 m .42728 .46851 L .42979 .46692 L p F P
0 g
s
.381 0 .04 r
.52131 .45431 m .52183 .45366 L .51223 .45463 L p F P
0 g
s
.381 0 .04 r
.51223 .45463 m .51077 .45644 L .52131 .45431 L p F P
0 g
s
.609 .871 .991 r
.52205 .34192 m .52448 .34305 L .51443 .34585 L p F P
0 g
s
.609 .871 .991 r
.51443 .34585 m .51245 .3449 L .52205 .34192 L p F P
0 g
s
.43 0 0 r
.44169 .46643 m .43934 .46801 L .43055 .46689 L closepath p F P
0 g
s
.424 0 0 r
.43925 .46807 m .43934 .46801 L .43055 .46689 L p F P
0 g
s
.424 0 0 r
.42728 .46851 m .43925 .46807 L p .43055 .46689 L F P
0 g
s
.686 .219 .139 r
.30094 .44997 m .30283 .45146 L .29946 .45074 L closepath p F P
0 g
s
.815 .471 .404 r
.22524 .41538 m .22868 .41668 L .22748 .41301 L p F P
0 g
s
.815 .471 .404 r
.22748 .41301 m .2273 .41294 L .22524 .41538 L p F P
0 g
s
.474 0 0 r
.40256 .46854 m .40291 .46835 L .39661 .46681 L p F P
0 g
s
.474 0 0 r
.39347 .46823 m .40256 .46854 L p .39661 .46681 L F P
0 g
s
.474 0 0 r
.39081 .46757 m .39347 .46823 L p .39661 .46681 L F P
0 g
s
.474 0 0 r
.39661 .46681 m .39255 .46668 L .39081 .46757 L p F P
0 g
s
.543 .872 .993 r
.49899 .34623 m .50031 .34665 L .49077 .34924 L p F P
0 g
s
.543 .872 .993 r
.49077 .34924 m .48841 .34839 L .49899 .34623 L p F P
0 g
s
.531 .864 .994 r
.48841 .34839 m .49077 .34924 L p .47864 .35063 L F P
0 g
s
.533 .39 .633 r
.64355 .37295 m .64277 .36799 L .634 .37263 L p F P
0 g
s
.533 .39 .633 r
.63638 .37675 m .64355 .37295 L p .634 .37263 L F P
0 g
s
.533 .39 .633 r
.634 .37263 m .63456 .37607 L .63638 .37675 L p F P
0 g
s
.379 0 0 r
.49809 .46034 m .50008 .45836 L .48921 .46005 L p F P
0 g
s
.379 0 0 r
.49344 .46107 m .49809 .46034 L p .48921 .46005 L F P
0 g
s
.379 0 0 r
.48921 .46005 m .48797 .46125 L .49344 .46107 L p F P
0 g
s
.825 .485 .412 r
.22319 .41455 m .22524 .41538 L .2273 .41294 L p F P
0 g
s
.825 .485 .412 r
.2273 .41294 m .22211 .41084 L .22319 .41455 L p F P
0 g
s
.784 .386 .3 r
.24341 .42779 m .24927 .42977 L .24728 .42636 L p F P
0 g
s
.784 .386 .3 r
.24178 .42503 m .24341 .42779 L p .24728 .42636 L F P
0 g
s
.784 .386 .3 r
.24728 .42636 m .24228 .42469 L .24178 .42503 L p F P
0 g
s
.669 .82 .956 r
.56096 .33827 m .55923 .33888 L .56094 .33826 L closepath p F P
0 g
s
.669 .821 .957 r
.55847 .33629 m .56094 .33826 L .55923 .33888 L p F P
0 g
s
.669 .821 .957 r
.54884 .33973 m .55847 .33629 L p .55923 .33888 L F P
0 g
s
.498 0 0 r
.39255 .46668 m .39081 .46757 L .38653 .46637 L closepath p F P
0 g
s
.472 .765 .995 r
.31279 .34348 m .30624 .34379 L .31281 .34555 L p F P
0 g
s
.472 .765 .995 r
.31281 .34555 m .3157 .34531 L .31279 .34348 L p F P
0 g
s
.442 .745 .992 r
.30368 .34389 m .30624 .34379 L .31281 .34555 L p F P
0 g
s
.627 .594 .797 r
.63486 .34197 m .63395 .3399 L .62416 .34234 L p F P
0 g
s
.637 .612 .807 r
.63395 .3399 m .62416 .34234 L .62169 .33748 L p F P
0 g
s
.319 .74 .975 r
.35461 .35084 m .35471 .35089 L p .34265 .34974 L F P
0 g
s
.319 .74 .975 r
.34265 .34974 m .34679 .34969 L .35461 .35084 L p F P
0 g
s
.364 .742 .988 r
.34265 .34974 m .34679 .34969 L .34001 .34835 L closepath p F P
0 g
s
.674 .729 .891 r
.5852 .33631 m .59489 .33285 L .59734 .33599 L p F P
0 g
s
.679 .755 .908 r
.59489 .33285 m .5852 .33631 L .58274 .33359 L p F P
0 g
s
.678 .761 .913 r
.57307 .33711 m .58274 .33359 L .5852 .33631 L p F P
0 g
s
.306 .735 .971 r
.35471 .35089 m .35489 .35089 L .36291 .3521 L p F P
0 g
s
.331 .759 .973 r
.36393 .35082 m .35489 .35089 L .36291 .3521 L p F P
0 g
s
.331 .759 .973 r
.36291 .3521 m .36678 .35193 L .36393 .35082 L p F P
0 g
s
.84 .594 .568 r
.1954 .38763 m .20038 .38998 L .20092 .38573 L p F P
0 g
s
.84 .594 .568 r
.20092 .38573 m .19595 .38338 L .1954 .38763 L p F P
0 g
s
.406 0 0 r
.44365 .46632 m .44169 .46643 L .43934 .46801 L p F P
0 g
s
.744 .305 .208 r
.27261 .43952 m .27121 .44024 L .26986 .43872 L closepath p F P
0 g
s
.213 .723 .892 r
.41517 .35381 m .40587 .35459 L .4031 .35374 L p F P
0 g
s
.492 .848 .993 r
.46667 .35192 m .4665 .35186 L .46562 .35204 L closepath p F P
0 g
s
.485 .85 .99 r
.46385 .35116 m .4665 .35186 L .46562 .35204 L p F P
0 g
s
.485 .85 .99 r
.45437 .35292 m .46385 .35116 L p .46562 .35204 L F P
0 g
s
.836 .615 .603 r
.19101 .381 m .19595 .38338 L .19699 .37895 L p F P
0 g
s
.836 .615 .603 r
.19699 .37895 m .19207 .37658 L .19101 .381 L p F P
0 g
s
.68 .786 .93 r
.58274 .33359 m .57307 .33711 L .57061 .33476 L p F P
0 g
s
.677 .79 .934 r
.56096 .33827 m .57061 .33476 L .57307 .33711 L p F P
0 g
s
.661 .173 .082 r
.30688 .45423 m .30283 .45146 L .30996 .45295 L p F P
0 g
s
.661 .173 .082 r
.31188 .45529 m .30688 .45423 L p .30996 .45295 L F P
0 g
s
.661 .173 .082 r
.30996 .45295 m .31278 .4549 L .31188 .45529 L p F P
0 g
s
.458 .737 .988 r
.30368 .34389 m .30624 .34379 L .30134 .34223 L closepath p F P
0 g
s
.487 0 0 r
.38977 .46809 m .39081 .46757 L .38653 .46637 L p F P
0 g
s
.487 0 0 r
.38352 .46773 m .38977 .46809 L p .38653 .46637 L F P
0 g
s
.487 0 0 r
.37872 .46636 m .38352 .46773 L p .38653 .46637 L F P
0 g
s
.487 0 0 r
.38653 .46637 m .37955 .46598 L .37872 .46636 L p F P
0 g
s
.531 .864 .994 r
.47864 .35063 m .4863 .34875 L .48841 .34839 L p F P
0 g
s
.507 .868 .986 r
.47864 .35063 m .4863 .34875 L .47768 .35034 L closepath p F P
0 g
s
.388 0 .17 r
.56532 .43856 m .56633 .43649 L .55645 .43945 L p F P
0 g
s
.388 0 .17 r
.55645 .43945 m .55565 .44105 L .56532 .43856 L p F P
0 g
s
.633 .144 .075 r
.32773 .45762 m .32907 .45841 L .32688 .45806 L closepath p F P
0 g
s
.6 .089 .008 r
.334 .4609 m .32907 .45841 L .33694 .45963 L p F P
0 g
s
.6 .089 .008 r
.33836 .46159 m .334 .4609 L p .33694 .45963 L F P
0 g
s
.6 .089 .008 r
.33694 .45963 m .33969 .46102 L .33836 .46159 L p F P
0 g
s
.473 .238 .477 r
.62645 .39868 m .62662 .39489 L .61757 .39907 L p F P
0 g
s
.473 .238 .477 r
.61757 .39907 m .61738 .40285 L .62645 .39868 L p F P
0 g
s
.41 0 0 r
.45336 .46568 m .4515 .467 L .44365 .46632 L closepath p F P
0 g
s
.406 0 0 r
.45098 .46736 m .4515 .467 L .44365 .46632 L p F P
0 g
s
.406 0 0 r
.43969 .46805 m .45098 .46736 L p .44365 .46632 L F P
0 g
s
.406 0 0 r
.43934 .46801 m .43969 .46805 L p .44365 .46632 L F P
0 g
s
.841 .572 .531 r
.20028 .39407 m .2053 .3964 L .20539 .3923 L p F P
0 g
s
.841 .572 .531 r
.20539 .3923 m .20038 .38998 L .20028 .39407 L p F P
0 g
s
.501 .852 .993 r
.47601 .34983 m .47768 .35034 L .46667 .35192 L p F P
0 g
s
.501 .852 .993 r
.46667 .35192 m .4665 .35186 L .47601 .34983 L p F P
0 g
s
.568 .731 .951 r
.2647 .33799 m .26597 .3378 L .26295 .33641 L closepath p F P
0 g
s
.773 .358 .265 r
.25796 .43264 m .25643 .43354 L .25516 .43173 L closepath p F P
0 g
s
.666 .694 .866 r
.59734 .33599 m .60705 .33266 L .6095 .3363 L p F P
0 g
s
.673 .72 .885 r
.60705 .33266 m .59734 .33599 L .59489 .33285 L p F P
0 g
s
.764 .706 .797 r
.20007 .34511 m .20403 .34173 L .20109 .3379 L p F P
0 g
s
.764 .706 .797 r
.20109 .3379 m .19535 .34262 L .20007 .34511 L p F P
0 g
s
.776 .691 .77 r
.19158 .34612 m .19535 .34262 L .20007 .34511 L p F P
0 g
s
.776 .691 .77 r
.20007 .34511 m .19448 .35053 L .19158 .34612 L p F P
0 g
s
.831 .635 .637 r
.18718 .37418 m .19207 .37658 L .1937 .37195 L p F P
0 g
s
.831 .635 .637 r
.1937 .37195 m .18884 .36954 L .18718 .37418 L p F P
0 g
s
.673 .821 .954 r
.57035 .33455 m .57061 .33476 L .56096 .33827 L p F P
0 g
s
.673 .821 .954 r
.56096 .33827 m .56094 .33826 L .57035 .33455 L p F P
0 g
s
.675 .822 .954 r
.56814 .33273 m .57035 .33455 L .56094 .33826 L p F P
0 g
s
.675 .822 .954 r
.56094 .33826 m .55847 .33629 L .56814 .33273 L p F P
0 g
s
.739 .706 .82 r
.21113 .337 m .20403 .34173 L .20109 .3379 L p F P
0 g
s
.416 .84 .958 r
.47601 .34983 m .4665 .35186 L .46385 .35116 L p F P
0 g
s
.795 .694 .753 r
.19366 .35149 m .19448 .35053 L .19158 .34612 L p F P
0 g
s
.343 .789 .957 r
.41798 .35457 m .42719 .3536 L .41525 .35381 L closepath p F P
0 g
s
.512 0 0 r
.37955 .46598 m .37872 .46636 L .37686 .46578 L closepath p F P
0 g
s
.833 .538 .491 r
.20823 .40155 m .21075 .40263 L .21039 .39869 L p F P
0 g
s
.833 .538 .491 r
.21039 .39869 m .20948 .3983 L .20823 .40155 L p F P
0 g
s
.795 .694 .753 r
.19158 .34612 m .18908 .34895 L .19366 .35149 L p F P
0 g
s
.806 .686 .732 r
.18484 .35454 m .18954 .35703 L .19366 .35149 L p F P
0 g
s
.806 .686 .732 r
.19366 .35149 m .18908 .34895 L .18484 .35454 L p F P
0 g
s
.808 .44 .36 r
.23023 .42023 m .23581 .42232 L .23428 .41875 L p F P
0 g
s
.808 .44 .36 r
.23428 .41875 m .22868 .41668 L .23023 .42023 L p F P
0 g
s
.365 .816 .942 r
.46385 .35116 m .45437 .35292 L .45169 .35224 L p F P
0 g
s
.359 .802 .957 r
.43931 .35302 m .43953 .35305 L .43011 .35429 L p F P
0 g
s
.359 .802 .957 r
.43011 .35429 m .42743 .35359 L .43931 .35302 L p F P
0 g
s
.512 0 0 r
.37397 .46709 m .36761 .46504 L .37686 .46578 L p F P
0 g
s
.512 0 0 r
.37667 .46731 m .37397 .46709 L p .37686 .46578 L F P
0 g
s
.512 0 0 r
.37686 .46578 m .37872 .46636 L .37667 .46731 L p F P
0 g
s
.556 .048 .003 r
.36667 .46468 m .36761 .46504 L .36622 .46492 L closepath p F P
0 g
s
.311 .787 .92 r
.45169 .35224 m .44224 .35373 L .43953 .35305 L p F P
0 g
s
.709 .243 .142 r
.28641 .44552 m .28605 .44568 L .28566 .44533 L closepath p F P
0 g
s
.386 0 0 r
.45808 .46529 m .45336 .46568 L .4515 .467 L p F P
0 g
s
.655 .658 .841 r
.6095 .3363 m .61924 .3332 L .62066 .33565 L p F P
0 g
s
.663 .684 .859 r
.61924 .3332 m .6095 .3363 L .60705 .33266 L p F P
0 g
s
.564 .73 .953 r
.27082 .3342 m .27378 .33659 L .26597 .3378 L p F P
0 g
s
.564 .73 .953 r
.26175 .33534 m .27082 .3342 L p .26597 .3378 L F P
0 g
s
.564 .73 .953 r
.26597 .3378 m .26295 .33641 L .26175 .33534 L p F P
0 g
s
.536 .386 .625 r
.63456 .37607 m .63638 .37675 L .63478 .37759 L closepath p F P
0 g
s
.664 .843 .969 r
.55847 .33629 m .54884 .33973 L .54634 .33804 L p F P
0 g
s
.657 .843 .971 r
.53672 .34137 m .54634 .33804 L .54884 .33973 L p F P
0 g
s
.744 .304 .206 r
.26647 .44004 m .26369 .43688 L .26986 .43872 L p F P
0 g
s
.744 .304 .206 r
.26968 .44101 m .26647 .44004 L p .26986 .43872 L F P
0 g
s
.744 .304 .206 r
.26986 .43872 m .27121 .44024 L .26968 .44101 L p F P
0 g
s
.824 .654 .672 r
.18468 .36745 m .18884 .36954 L .19116 .36466 L p F P
0 g
s
.824 .654 .672 r
.1843 .36645 m .18468 .36745 L p .19116 .36466 L F P
0 g
s
.824 .654 .672 r
.19116 .36466 m .18637 .36222 L .1843 .36645 L p F P
0 g
s
.841 .548 .494 r
.20559 .40036 m .20823 .40155 L .20948 .3983 L p F P
0 g
s
.841 .548 .494 r
.20948 .3983 m .2053 .3964 L .20559 .40036 L p F P
0 g
s
.364 0 .038 r
.53169 .45198 m .53339 .44977 L .52303 .4521 L p F P
0 g
s
.364 0 .038 r
.52832 .45275 m .53169 .45198 L p .52303 .4521 L F P
0 g
s
.364 0 .038 r
.52303 .4521 m .52183 .45366 L .52832 .45275 L p F P
0 g
s
.709 .242 .14 r
.28246 .44661 m .27919 .4436 L .28566 .44533 L p F P
0 g
s
.709 .242 .14 r
.28334 .44685 m .28246 .44661 L p .28566 .44533 L F P
0 g
s
.709 .242 .14 r
.28566 .44533 m .28605 .44568 L .28334 .44685 L p F P
0 g
s
.317 .736 .976 r
.35471 .35089 m .35489 .35089 L .35461 .35084 L closepath p F P
0 g
s
.83 .511 .45 r
.2115 .40644 m .21679 .40865 L .21605 .40484 L p F P
0 g
s
.83 .511 .45 r
.21605 .40484 m .21075 .40263 L .2115 .40644 L p F P
0 g
s
.773 .358 .263 r
.25158 .43308 m .24927 .42977 L .25516 .43173 L p F P
0 g
s
.773 .358 .263 r
.25517 .43428 m .25158 .43308 L p .25516 .43173 L F P
0 g
s
.773 .358 .263 r
.25516 .43173 m .25643 .43354 L .25517 .43428 L p F P
0 g
s
.307 .732 .972 r
.36275 .35042 m .36393 .35082 L .35489 .35089 L p F P
0 g
s
.307 .732 .972 r
.35781 .34978 m .36275 .35042 L p .35489 .35089 L F P
0 g
s
.307 .732 .972 r
.35184 .34961 m .35781 .34978 L p .35489 .35089 L F P
0 g
s
.307 .732 .972 r
.35489 .35089 m .35461 .35084 L .35184 .34961 L p F P
0 g
s
.388 0 0 r
.46483 .46469 m .46366 .46556 L .45808 .46529 L closepath p F P
0 g
s
.386 0 0 r
.4625 .4664 m .46366 .46556 L .45808 .46529 L p F P
0 g
s
.386 0 0 r
.45381 .46713 m .4625 .4664 L p .45808 .46529 L F P
0 g
s
.386 0 0 r
.4515 .467 m .45381 .46713 L p .45808 .46529 L F P
0 g
s
.327 .743 .977 r
.35461 .35084 m .35184 .34961 L .34679 .34969 L closepath p F P
0 g
s
.516 .748 .98 r
.27672 .33902 m .2858 .3381 L .28874 .34033 L p F P
0 g
s
.485 .745 .986 r
.2858 .3381 m .27672 .33902 L .27378 .33659 L p F P
0 g
s
.407 0 .056 r
.50011 .45833 m .50034 .45832 L .50008 .45836 L closepath p F P
0 g
s
.591 .07 0 r
.32622 .45964 m .334 .4609 L .32907 .45841 L p F P
0 g
s
.591 .07 0 r
.32471 .45887 m .32622 .45964 L p .32907 .45841 L F P
0 g
s
.591 .07 0 r
.32907 .45841 m .32688 .45806 L .32471 .45887 L p F P
0 g
s
.314 .721 .978 r
.32483 .34516 m .3157 .34531 L .31279 .34348 L p F P
0 g
s
.518 .35 .593 r
.63985 .3798 m .63527 .38218 L .63478 .37759 L p F P
0 g
s
.518 .35 .593 r
.63478 .37759 m .63638 .37675 L .63985 .3798 L p F P
0 g
s
.353 0 0 r
.50034 .45832 m .50008 .45836 L .49809 .46034 L p F P
0 g
s
.697 .225 .126 r
.28605 .44568 m .28914 .44827 L .28334 .44685 L closepath p F P
0 g
s
.796 .404 .313 r
.24228 .42469 m .24178 .42503 L .24142 .42438 L closepath p F P
0 g
s
.646 .862 .981 r
.54415 .33677 m .54634 .33804 L .53672 .34137 L p F P
0 g
s
.646 .862 .981 r
.53672 .34137 m .5344 .34004 L .54415 .33677 L p F P
0 g
s
.64 .856 .982 r
.5344 .34004 m .53672 .34137 L p .52459 .3431 L F P
0 g
s
.356 0 0 r
.51077 .45644 m .50969 .45755 L .50034 .45832 L closepath p F P
0 g
s
.353 0 0 r
.50882 .45844 m .50969 .45755 L .50034 .45832 L p F P
0 g
s
.353 0 0 r
.49809 .46034 m .50882 .45844 L p .50034 .45832 L F P
0 g
s
.505 0 0 r
.36483 .4663 m .37397 .46709 L .36761 .46504 L p F P
0 g
s
.505 0 0 r
.36374 .46595 m .36483 .4663 L p .36761 .46504 L F P
0 g
s
.505 0 0 r
.36761 .46504 m .36622 .46492 L .36374 .46595 L p F P
0 g
s
.366 0 .104 r
.55367 .44447 m .55514 .44205 L .5451 .44481 L p F P
0 g
s
.366 0 .104 r
.5451 .44481 m .54361 .44723 L .55367 .44447 L p F P
0 g
s
.449 .736 .989 r
.30986 .34171 m .31279 .34348 L .30624 .34379 L p F P
0 g
s
.449 .736 .989 r
.30076 .34183 m .30986 .34171 L p .30624 .34379 L F P
0 g
s
.449 .736 .989 r
.30624 .34379 m .30134 .34223 L .30076 .34183 L p F P
0 g
s
.652 .152 .049 r
.29983 .4527 m .30688 .45423 L .30283 .45146 L p F P
0 g
s
.652 .152 .049 r
.29784 .45134 m .29983 .4527 L p .30283 .45146 L F P
0 g
s
.652 .152 .049 r
.30283 .45146 m .29946 .45074 L .29784 .45134 L p F P
0 g
s
.531 0 0 r
.36622 .46492 m .36374 .46595 L .3588 .46415 L closepath p F P
0 g
s
.485 .274 .518 r
.63556 .39051 m .63552 .38647 L .62659 .39086 L p F P
0 g
s
.485 .274 .518 r
.62659 .39086 m .62662 .39489 L .63556 .39051 L p F P
0 g
s
.73 .72 .841 r
.21113 .337 m .21336 .33561 L .2104 .33216 L p F P
0 g
s
.73 .72 .841 r
.2104 .33216 m .20653 .33446 L .21113 .337 L p F P
0 g
s
.739 .706 .82 r
.20109 .3379 m .20653 .33446 L .21113 .337 L p F P
0 g
s
.505 .868 .986 r
.4863 .34875 m .47768 .35034 L .47601 .34983 L p F P
0 g
s
.615 .101 .004 r
.32688 .45806 m .32471 .45887 L .32149 .45708 L closepath p F P
0 g
s
.796 .405 .312 r
.23766 .42577 m .23581 .42232 L .24142 .42438 L p F P
0 g
s
.796 .405 .312 r
.23961 .42649 m .23766 .42577 L p .24142 .42438 L F P
0 g
s
.796 .405 .312 r
.24142 .42438 m .24178 .42503 L .23961 .42649 L p F P
0 g
s
.387 0 .109 r
.53394 .44891 m .54303 .44737 L .53339 .44977 L closepath p F P
0 g
s
.67 .735 .899 r
.22553 .33449 m .23468 .33116 L .23764 .33418 L p F P
0 g
s
.66 .736 .906 r
.23468 .33116 m .22553 .33449 L .22257 .33126 L p F P
0 g
s
.703 .73 .871 r
.21336 .33561 m .22257 .33126 L .22553 .33449 L p F P
0 g
s
.815 .671 .704 r
.18159 .35975 m .18637 .36222 L .18954 .35703 L p F P
0 g
s
.815 .671 .704 r
.18954 .35703 m .18484 .35454 L .18159 .35975 L p F P
0 g
s
.827 .485 .408 r
.21788 .41235 m .22319 .41455 L .22211 .41084 L p F P
0 g
s
.827 .485 .408 r
.22211 .41084 m .21679 .40865 L .21788 .41235 L p F P
0 g
s
.423 .087 .29 r
.5868 .4272 m .58699 .4266 L .57731 .43019 L p F P
0 g
s
.423 .087 .29 r
.57731 .43019 m .5772 .43056 L .5868 .4272 L p F P
0 g
s
.364 0 0 r
.47424 .46369 m .46483 .46469 L .46366 .46556 L p F P
0 g
s
.42 .113 .336 r
.60654 .41691 m .60726 .41374 L .59792 .4175 L p F P
0 g
s
.42 .113 .336 r
.59792 .4175 m .59719 .42066 L .60654 .41691 L p F P
0 g
s
.405 .072 .284 r
.59668 .42235 m .59719 .42066 L .58772 .42422 L p F P
0 g
s
.405 .072 .284 r
.58772 .42422 m .58699 .4266 L .59668 .42235 L p F P
0 g
s
.637 .612 .807 r
.62169 .33748 m .63147 .33477 L .63395 .3399 L p F P
0 g
s
.642 .646 .839 r
.62066 .33565 m .62169 .33748 L .63147 .33477 L p F P
0 g
s
.633 .74 .925 r
.23764 .33418 m .24675 .33169 L .24971 .33451 L p F P
0 g
s
.62 .74 .932 r
.24675 .33169 m .23764 .33418 L .23468 .33116 L p F P
0 g
s
.583 .498 .724 r
.63901 .35306 m .6477 .35238 L .6401 .35666 L closepath p F P
0 g
s
.584 .514 .742 r
.63797 .34995 m .63901 .35306 L .6477 .35238 L p F P
0 g
s
.695 .732 .879 r
.22257 .33126 m .21336 .33561 L .2104 .33216 L p F P
0 g
s
.64 .856 .982 r
.52459 .3431 m .52825 .34189 L .5344 .34004 L p F P
0 g
s
.62 .879 .989 r
.52459 .3431 m .52825 .34189 L .52448 .34305 L closepath p F P
0 g
s
.602 .542 .759 r
.63646 .34587 m .63797 .34995 L .64658 .34503 L p F P
0 g
s
.584 .514 .742 r
.64874 .35178 m .64658 .34503 L .63797 .34995 L p F P
0 g
s
.584 .514 .742 r
.6477 .35238 m .64874 .35178 L p .63797 .34995 L F P
0 g
s
.493 0 0 r
.37872 .46636 m .38352 .46773 L .37667 .46731 L closepath p F P
0 g
s
.561 .463 .7 r
.6489 .35236 m .6477 .35238 L .6401 .35666 L p F P
0 g
s
.561 .463 .7 r
.65028 .35772 m .6489 .35236 L p .6401 .35666 L F P
0 g
s
.561 .463 .7 r
.6418 .36255 m .65028 .35772 L p .6401 .35666 L F P
0 g
s
.561 .463 .7 r
.6401 .35666 m .64165 .36254 L .6418 .36255 L p F P
0 g
s
.164 .677 .895 r
.37494 .35185 m .36678 .35193 L .36393 .35082 L p F P
0 g
s
.61 .746 .941 r
.26295 .33641 m .26175 .33534 L .26038 .33565 L closepath p F P
0 g
s
.516 .351 .595 r
.64407 .37757 m .63985 .3798 L .63638 .37675 L p F P
0 g
s
.516 .351 .595 r
.63638 .37675 m .64355 .37295 L .64407 .37757 L p F P
0 g
s
.619 .88 .99 r
.52825 .34189 m .52448 .34305 L .52205 .34192 L p F P
0 g
s
.433 .151 .384 r
.61647 .40978 m .61701 .40641 L .60781 .41038 L p F P
0 g
s
.433 .151 .384 r
.60781 .41038 m .60726 .41374 L .61647 .40978 L p F P
0 g
s
.383 .019 .217 r
.58571 .42997 m .5868 .4272 L .5772 .43056 L p F P
0 g
s
.383 .019 .217 r
.5772 .43056 m .57608 .43333 L .58571 .42997 L p F P
0 g
s
.673 .181 .074 r
.29946 .45074 m .29784 .45134 L .29589 .4499 L closepath p F P
0 g
s
.841 .596 .568 r
.19046 .38526 m .1954 .38763 L .19595 .38338 L p F P
0 g
s
.841 .596 .568 r
.19595 .38338 m .19101 .381 L .19046 .38526 L p F P
0 g
s
.353 .739 .986 r
.34897 .34842 m .35184 .34961 L .34679 .34969 L p F P
0 g
s
.353 .739 .986 r
.33978 .34822 m .34897 .34842 L p .34679 .34969 L F P
0 g
s
.353 .739 .986 r
.34679 .34969 m .34001 .34835 L .33978 .34822 L p F P
0 g
s
.789 .393 .304 r
.24178 .42503 m .24341 .42779 L .23961 .42649 L closepath p F P
0 g
s
.516 0 0 r
.36322 .46616 m .36374 .46595 L .3588 .46415 L p F P
0 g
s
.516 0 0 r
.35612 .46537 m .36322 .46616 L p .3588 .46415 L F P
0 g
s
.516 0 0 r
.35169 .46377 m .35612 .46537 L p .3588 .46415 L F P
0 g
s
.516 0 0 r
.3588 .46415 m .3525 .46347 L .35169 .46377 L p F P
0 g
s
.837 .618 .605 r
.18727 .37918 m .19101 .381 L .19207 .37658 L p F P
0 g
s
.837 .618 .605 r
.18679 .37575 m .18727 .37918 L p .19207 .37658 L F P
0 g
s
.837 .618 .605 r
.19207 .37658 m .18718 .37418 L .18679 .37575 L p F P
0 g
s
.455 .745 .991 r
.28874 .34033 m .2935 .34009 L .3 .34189 L p F P
0 g
s
.429 .727 .988 r
.2935 .34009 m .28874 .34033 L .2858 .3381 L p F P
0 g
s
.843 .574 .53 r
.1953 .39173 m .20028 .39407 L .20038 .38998 L p F P
0 g
s
.843 .574 .53 r
.20038 .38998 m .1954 .38763 L .1953 .39173 L p F P
0 g
s
.583 .068 0 r
.33969 .46102 m .34198 .46209 L .33836 .46159 L closepath p F P
0 g
s
.602 .542 .759 r
.64658 .34503 m .64631 .34427 L .63646 .34587 L p F P
0 g
s
.605 .562 .779 r
.63486 .34197 m .63646 .34587 L .64631 .34427 L p F P
0 g
s
.734 .289 .194 r
.27121 .44024 m .27274 .44185 L .26968 .44101 L closepath p F P
0 g
s
.59 .742 .948 r
.24971 .33451 m .25456 .33358 L .26038 .33565 L p F P
0 g
s
.574 .733 .95 r
.25456 .33358 m .24971 .33451 L .24675 .33169 L p F P
0 g
s
.378 0 0 r
.48797 .46125 m .49344 .46107 L .48718 .46201 L closepath p F P
0 g
s
.387 0 .168 r
.56505 .4391 m .56532 .43856 L .55565 .44105 L p F P
0 g
s
.387 0 .168 r
.55565 .44105 m .55514 .44205 L .56505 .4391 L p F P
0 g
s
.773 .696 .778 r
.18866 .34187 m .19062 .34013 L .19535 .34262 L p F P
0 g
s
.773 .696 .778 r
.19535 .34262 m .19158 .34612 L .18866 .34187 L p F P
0 g
s
.76 .707 .802 r
.19535 .34262 m .20109 .3379 L .19813 .33417 L p F P
0 g
s
.76 .707 .802 r
.19813 .33417 m .19062 .34013 L .19535 .34262 L p F P
0 g
s
.281 .703 .97 r
.33184 .34683 m .32773 .34679 L .32483 .34516 L p F P
0 g
s
.31 .727 .975 r
.32773 .34679 m .33184 .34683 L .33938 .34824 L p F P
0 g
s
.832 .636 .638 r
.18648 .37383 m .18718 .37418 L .18884 .36954 L p F P
0 g
s
.832 .636 .638 r
.18884 .36954 m .18468 .36745 L .18648 .37383 L p F P
0 g
s
.793 .697 .758 r
.18908 .34895 m .19158 .34612 L .18866 .34187 L p F P
0 g
s
.809 .436 .351 r
.22468 .41812 m .23023 .42023 L .22868 .41668 L p F P
0 g
s
.809 .436 .351 r
.22395 .41641 m .22468 .41812 L p .22868 .41668 L F P
0 g
s
.809 .436 .351 r
.22868 .41668 m .22524 .41538 L .22395 .41641 L p F P
0 g
s
.745 .299 .192 r
.26036 .43816 m .26647 .44004 L .26369 .43688 L p F P
0 g
s
.745 .299 .192 r
.26369 .43688 m .25754 .43502 L .26036 .43816 L p F P
0 g
s
.614 .1 .002 r
.31872 .45828 m .31405 .45571 L .32149 .45708 L p F P
0 g
s
.614 .1 .002 r
.32373 .45923 m .31872 .45828 L p .32149 .45708 L F P
0 g
s
.614 .1 .002 r
.32149 .45708 m .32471 .45887 L .32373 .45923 L p F P
0 g
s
.711 .241 .131 r
.27606 .44485 m .28246 .44661 L .27919 .4436 L p F P
0 g
s
.711 .241 .131 r
.27919 .4436 m .27274 .44185 L .27606 .44485 L p F P
0 g
s
.577 .885 .991 r
.52205 .34192 m .51245 .3449 L .50989 .3439 L p F P
0 g
s
.569 .878 .993 r
.50031 .34665 m .50989 .3439 L .51245 .3449 L p F P
0 g
s
.843 .55 .492 r
.20057 .39804 m .20559 .40036 L .2053 .3964 L p F P
0 g
s
.843 .55 .492 r
.2053 .3964 m .20028 .39407 L .20057 .39804 L p F P
0 g
s
.365 0 0 r
.47611 .46348 m .47582 .4637 L .47424 .46369 L closepath p F P
0 g
s
.364 0 0 r
.47383 .46521 m .47582 .4637 L .47424 .46369 L p F P
0 g
s
.364 0 0 r
.4696 .46566 m .47383 .46521 L p .47424 .46369 L F P
0 g
s
.364 0 0 r
.46366 .46556 m .4696 .46566 L p .47424 .46369 L F P
0 g
s
.562 .452 .686 r
.64165 .36254 m .6418 .36255 L .64167 .36263 L closepath p F P
0 g
s
.548 .423 .662 r
.65003 .36394 m .64277 .36799 L .64167 .36263 L p F P
0 g
s
.548 .423 .662 r
.64167 .36263 m .6418 .36255 L .65003 .36394 L p F P
0 g
s
.646 .154 .067 r
.31278 .4549 m .31405 .45571 L .31188 .45529 L closepath p F P
0 g
s
.65 .656 .843 r
.61924 .3332 m .62066 .33565 L .62937 .33088 L p F P
0 g
s
.642 .646 .839 r
.63147 .33477 m .62937 .33088 L .62066 .33565 L p F P
0 g
s
.609 .75 .945 r
.25879 .33274 m .25456 .33358 L .26038 .33565 L p F P
0 g
s
.609 .75 .945 r
.26038 .33565 m .26175 .33534 L .25879 .33274 L p F P
0 g
s
.547 .426 .667 r
.65143 .36314 m .65003 .36394 L .6418 .36255 L p F P
0 g
s
.547 .426 .667 r
.6418 .36255 m .65028 .35772 L .65143 .36314 L p F P
0 g
s
.764 .345 .253 r
.25643 .43354 m .25754 .43502 L .25517 .43428 L closepath p F P
0 g
s
.734 .71 .828 r
.20653 .33446 m .20109 .3379 L .19813 .33417 L p F P
0 g
s
.497 .756 .988 r
.30134 .34223 m .30076 .34183 L .3 .34189 L closepath p F P
0 g
s
.446 .19 .43 r
.6261 .40225 m .62645 .39868 L .61738 .40285 L p F P
0 g
s
.446 .19 .43 r
.61738 .40285 m .61701 .40641 L .6261 .40225 L p F P
0 g
s
.793 .697 .758 r
.18866 .34187 m .18453 .3464 L .18908 .34895 L p F P
0 g
s
.805 .688 .736 r
.18017 .35203 m .18484 .35454 L .18908 .34895 L p F P
0 g
s
.805 .688 .736 r
.18908 .34895 m .18453 .3464 L .18017 .35203 L p F P
0 g
s
.342 0 0 r
.48535 .46347 m .48718 .46201 L .47611 .46348 L p F P
0 g
s
.342 0 0 r
.47611 .46348 m .47582 .4637 L .48535 .46347 L p F P
0 g
s
.264 .732 .945 r
.37887 .35278 m .38401 .3527 L .37654 .352 L closepath p F P
0 g
s
.22 .716 .915 r
.38987 .35309 m .39097 .3534 L p .37887 .35278 L F P
0 g
s
.22 .716 .915 r
.37887 .35278 m .38401 .3527 L .38987 .35309 L p F P
0 g
s
.542 .006 0 r
.3525 .46347 m .35169 .46377 L .35022 .46318 L closepath p F P
0 g
s
.775 .355 .251 r
.24575 .43109 m .25158 .43308 L .24927 .42977 L p F P
0 g
s
.775 .355 .251 r
.24927 .42977 m .24341 .42779 L .24575 .43109 L p F P
0 g
s
.367 0 .162 r
.57501 .43556 m .57608 .43333 L .56633 .43649 L p F P
0 g
s
.367 0 .162 r
.56633 .43649 m .56532 .43856 L .57501 .43556 L p F P
0 g
s
.673 .181 .072 r
.29297 .45111 m .28914 .44827 L .29589 .4499 L p F P
0 g
s
.673 .181 .072 r
.29626 .45191 m .29297 .45111 L p .29589 .4499 L F P
0 g
s
.673 .181 .072 r
.29589 .4499 m .29784 .45134 L .29626 .45191 L p F P
0 g
s
.479 0 0 r
.39081 .46757 m .39347 .46823 L .38977 .46809 L closepath p F P
0 g
s
.673 .72 .885 r
.59489 .33285 m .6046 .3294 L .60705 .33266 L p F P
0 g
s
.679 .746 .902 r
.6046 .3294 m .59489 .33285 L .59244 .33004 L p F P
0 g
s
.679 .755 .908 r
.58274 .33359 m .59244 .33004 L .59489 .33285 L p F P
0 g
s
.522 .865 .992 r
.48841 .34839 m .48816 .3483 L .4863 .34875 L closepath p F P
0 g
s
.505 .868 .986 r
.48555 .34765 m .48816 .3483 L .4863 .34875 L p F P
0 g
s
.505 .868 .986 r
.47601 .34983 m .48555 .34765 L p .4863 .34875 L F P
0 g
s
.825 .655 .672 r
.18159 .35976 m .18159 .35975 L .18637 .36222 L p F P
0 g
s
.825 .655 .672 r
.18637 .36222 m .1843 .36645 L .18159 .35976 L p F P
0 g
s
.682 .78 .925 r
.59244 .33004 m .58274 .33359 L .58029 .33118 L p F P
0 g
s
.68 .786 .93 r
.57061 .33476 m .58029 .33118 L .58274 .33359 L p F P
0 g
s
.833 .513 .447 r
.20644 .40429 m .2115 .40644 L .21075 .40263 L p F P
0 g
s
.833 .513 .447 r
.21075 .40263 m .20823 .40155 L .20644 .40429 L p F P
0 g
s
.605 .562 .779 r
.64378 .33778 m .6413 .33828 L .63486 .34197 L p F P
0 g
s
.605 .562 .779 r
.64631 .34427 m .64378 .33778 L p .63486 .34197 L F P
0 g
s
.62 .583 .791 r
.63395 .3399 m .6413 .33828 L .63486 .34197 L closepath p F P
0 g
s
.34 0 .026 r
.54303 .44737 m .53339 .44977 L .53169 .45198 L p F P
0 g
s
.542 .005 0 r
.34761 .46436 m .34198 .46209 L .35022 .46318 L p F P
0 g
s
.542 .005 0 r
.34936 .4646 m .34761 .46436 L p .35022 .46318 L F P
0 g
s
.542 .005 0 r
.35022 .46318 m .35169 .46377 L .34936 .4646 L p F P
0 g
s
.334 0 0 r
.5194 .45633 m .52131 .45431 L .51077 .45644 L p F P
0 g
s
.334 0 0 r
.51827 .45656 m .5194 .45633 L p .51077 .45644 L F P
0 g
s
.334 0 0 r
.51077 .45644 m .50969 .45755 L .51827 .45656 L p F P
0 g
s
.491 .761 .991 r
.29783 .33985 m .2935 .34009 L .3 .34189 L p F P
0 g
s
.491 .761 .991 r
.3 .34189 m .30076 .34183 L .29783 .33985 L p F P
0 g
s
.636 .86 .984 r
.5344 .34004 m .5342 .33992 L .52825 .34189 L closepath p F P
0 g
s
.619 .88 .99 r
.53167 .33878 m .5342 .33992 L .52825 .34189 L p F P
0 g
s
.619 .88 .99 r
.52205 .34192 m .53167 .33878 L p .52825 .34189 L F P
0 g
s
.545 .883 .988 r
.50932 .34374 m .50989 .3439 L .50031 .34665 L p F P
0 g
s
.545 .883 .988 r
.50031 .34665 m .49899 .34623 L .50932 .34374 L p F P
0 g
s
.496 .309 .557 r
.64094 .38366 m .63552 .38647 L .63527 .38218 L p F P
0 g
s
.496 .309 .557 r
.63527 .38218 m .63985 .3798 L .64094 .38366 L p F P
0 g
s
.52 .74 .975 r
.27082 .3342 m .26175 .33534 L .25879 .33274 L p F P
0 g
s
.663 .684 .859 r
.60705 .33266 m .61679 .3294 L .61924 .3332 L p F P
0 g
s
.671 .71 .878 r
.61679 .3294 m .60705 .33266 L .6046 .3294 L p F P
0 g
s
.677 .818 .951 r
.57962 .3306 m .58029 .33118 L .57061 .33476 L p F P
0 g
s
.677 .818 .951 r
.57061 .33476 m .57035 .33455 L .57962 .3306 L p F P
0 g
s
.535 .87 .992 r
.49772 .34584 m .49899 .34623 L .48841 .34839 L p F P
0 g
s
.535 .87 .992 r
.48841 .34839 m .48816 .3483 L .49772 .34584 L p F P
0 g
s
.383 .754 .991 r
.34001 .34835 m .33978 .34822 L .33938 .34824 L closepath p F P
0 g
s
.341 0 0 r
.48496 .46378 m .48535 .46347 L .47582 .4637 L p F P
0 g
s
.341 0 0 r
.47582 .4637 m .47383 .46521 L .48496 .46378 L p F P
0 g
s
.363 .755 .987 r
.33689 .34685 m .33184 .34683 L .33938 .34824 L p F P
0 g
s
.363 .755 .987 r
.33938 .34824 m .33978 .34822 L .33689 .34685 L p F P
0 g
s
.34 .72 .984 r
.30986 .34171 m .30076 .34183 L .29783 .33985 L p F P
0 g
s
.801 .407 .308 r
.2321 .42368 m .23766 .42577 L .23581 .42232 L p F P
0 g
s
.801 .407 .308 r
.23581 .42232 m .23023 .42023 L .2321 .42368 L p F P
0 g
s
.629 .597 .799 r
.6413 .33828 m .63395 .3399 L .63147 .33477 L p F P
0 g
s
.208 .715 .899 r
.40275 .35366 m .4031 .35374 L p .39097 .3534 L F P
0 g
s
.208 .715 .899 r
.39097 .3534 m .39373 .35331 L .40275 .35366 L p F P
0 g
s
.246 .731 .927 r
.39097 .3534 m .39373 .35331 L .38987 .35309 L closepath p F P
0 g
s
.68 .819 .95 r
.57783 .32907 m .57962 .3306 L .57035 .33455 L p F P
0 g
s
.68 .819 .95 r
.57035 .33455 m .56814 .33273 L .57783 .32907 L p F P
0 g
s
.171 .669 .914 r
.34897 .34842 m .33978 .34822 L .33689 .34685 L p F P
0 g
s
.828 .484 .404 r
.21261 .41013 m .21788 .41235 L .21679 .40865 L p F P
0 g
s
.828 .484 .404 r
.21679 .40865 m .2115 .40644 L .21261 .41013 L p F P
0 g
s
.819 .452 .362 r
.22524 .41538 m .22395 .41641 L .22319 .41455 L closepath p F P
0 g
s
.466 .866 .965 r
.49772 .34584 m .48816 .3483 L .48555 .34765 L p F P
0 g
s
.724 .72 .846 r
.20653 .33446 m .2104 .33216 L .20742 .32877 L p F P
0 g
s
.724 .72 .846 r
.20742 .32877 m .20183 .33194 L .20653 .33446 L p F P
0 g
s
.734 .71 .828 r
.19813 .33417 m .20183 .33194 L .20653 .33446 L p F P
0 g
s
.463 0 0 r
.40291 .46835 m .40392 .46856 L .40256 .46854 L closepath p F P
0 g
s
.671 .842 .965 r
.56814 .33273 m .55847 .33629 L .55599 .33457 L p F P
0 g
s
.664 .843 .969 r
.54634 .33804 m .55599 .33457 L .55847 .33629 L p F P
0 g
s
.603 .078 0 r
.31137 .45686 m .31872 .45828 L .31405 .45571 L p F P
0 g
s
.603 .078 0 r
.30973 .45595 m .31137 .45686 L p .31405 .45571 L F P
0 g
s
.603 .078 0 r
.31405 .45571 m .31188 .45529 L .30973 .45595 L p F P
0 g
s
.362 0 .035 r
.52183 .45366 m .52832 .45275 L .52131 .45431 L closepath p F P
0 g
s
.814 .675 .71 r
.18159 .35975 m .18159 .35975 L .18484 .35454 L p F P
0 g
s
.814 .675 .71 r
.17877 .35417 m .18159 .35975 L p .18484 .35454 L F P
0 g
s
.814 .675 .71 r
.18484 .35454 m .18017 .35203 L .17877 .35417 L p F P
0 g
s
.53 .388 .633 r
.65222 .36811 m .64355 .37295 L .64277 .36799 L p F P
0 g
s
.53 .388 .633 r
.65167 .36459 m .65222 .36811 L p .64277 .36799 L F P
0 g
s
.53 .388 .633 r
.64277 .36799 m .65003 .36394 L .65167 .36459 L p F P
0 g
s
.46 .228 .475 r
.63541 .3943 m .63556 .39051 L .62662 .39489 L p F P
0 g
s
.46 .228 .475 r
.62662 .39489 m .62645 .39868 L .63541 .3943 L p F P
0 g
s
.65 .656 .843 r
.62937 .33088 m .62901 .33023 L .61924 .3332 L p F P
0 g
s
.658 .672 .851 r
.62901 .33023 m .61924 .3332 L .61679 .3294 L p F P
0 g
s
.341 0 .089 r
.56359 .44151 m .56505 .4391 L .55514 .44205 L p F P
0 g
s
.341 0 .089 r
.55514 .44205 m .55367 .44447 L .56359 .44151 L p F P
0 g
s
.841 .524 .453 r
.20626 .4042 m .20644 .40429 L .20823 .40155 L p F P
0 g
s
.841 .524 .453 r
.20823 .40155 m .20559 .40036 L .20626 .4042 L p F P
0 g
s
.366 0 0 r
.46366 .46556 m .4696 .46566 L .4625 .4664 L closepath p F P
0 g
s
.213 .723 .892 r
.4031 .35374 m .40408 .35369 L .41517 .35381 L p F P
0 g
s
.241 .735 .914 r
.4031 .35374 m .40408 .35369 L .40275 .35366 L closepath p F P
0 g
s
.531 0 0 r
.33948 .46322 m .34761 .46436 L .34198 .46209 L p F P
0 g
s
.531 0 0 r
.3367 .4621 m .33948 .46322 L p .34198 .46209 L F P
0 g
s
.531 0 0 r
.34198 .46209 m .33836 .46159 L .3367 .4621 L p F P
0 g
s
.706 .227 .109 r
.26969 .44307 m .27606 .44485 L .27274 .44185 L p F P
0 g
s
.706 .227 .109 r
.26803 .44156 m .26969 .44307 L p .27274 .44185 L F P
0 g
s
.706 .227 .109 r
.27274 .44185 m .26968 .44101 L .26803 .44156 L p F P
0 g
s
.628 .11 0 r
.31188 .45529 m .30973 .45595 L .30688 .45423 L closepath p F P
0 g
s
.41 .843 .947 r
.48555 .34765 m .47601 .34983 L .47337 .34926 L p F P
0 g
s
.416 .84 .958 r
.46385 .35116 m .47337 .34926 L .47601 .34983 L p F P
0 g
s
.523 0 0 r
.35169 .46377 m .35612 .46537 L .34936 .4646 L closepath p F P
0 g
s
.322 0 0 r
.49344 .46107 m .48718 .46201 L .48535 .46347 L p F P
0 g
s
.743 .29 .176 r
.25428 .43627 m .26036 .43816 L .25754 .43502 L p F P
0 g
s
.743 .29 .176 r
.2532 .43504 m .25428 .43627 L p .25754 .43502 L F P
0 g
s
.743 .29 .176 r
.25754 .43502 m .25517 .43428 L .2532 .43504 L p F P
0 g
s
.38 0 0 r
.42688 .46852 m .41506 .46868 L .41504 .46868 L p F P
0 g
s
.408 0 0 r
.41506 .46868 m .41504 .46868 L .41499 .46868 L closepath p F P
0 g
s
.406 0 0 r
.41223 .46996 m .40392 .46856 L .41499 .46868 L p F P
0 g
s
.406 0 0 r
.41499 .46868 m .41504 .46868 L .41223 .46996 L p F P
0 g
s
.843 .598 .567 r
.18722 .38368 m .19046 .38526 L .19101 .381 L p F P
0 g
s
.843 .598 .567 r
.19101 .381 m .18727 .37918 L .18722 .38368 L p F P
0 g
s
.38 0 0 r
.41504 .46868 m .42403 .46986 L p .42688 .46852 L F P
0 g
s
.397 0 0 r
.42403 .46986 m .41504 .46868 L .41223 .46996 L p F P
0 g
s
.485 .745 .986 r
.28388 .33669 m .2858 .3381 L p .27378 .33659 L F P
0 g
s
.485 .745 .986 r
.27378 .33659 m .28169 .33603 L .28388 .33669 L p F P
0 g
s
.454 .733 .987 r
.28169 .33603 m .27378 .33659 L .27082 .3342 L p F P
0 g
s
.649 .737 .913 r
.23171 .32818 m .22257 .33126 L .21959 .32807 L p F P
0 g
s
.695 .732 .879 r
.2104 .33216 m .21959 .32807 L .22257 .33126 L p F P
0 g
s
.66 .736 .906 r
.22257 .33126 m .23171 .32818 L .23468 .33116 L p F P
0 g
s
.834 .653 .657 r
.1843 .36645 m .18403 .3671 L .18468 .36745 L closepath p F P
0 g
s
.841 .641 .632 r
.1825 .37169 m .18648 .37383 L .18468 .36745 L p F P
0 g
s
.841 .641 .632 r
.18468 .36745 m .18403 .3671 L .1825 .37169 L p F P
0 g
s
.84 .62 .605 r
.18718 .37418 m .18648 .37383 L .18679 .37575 L closepath p F P
0 g
s
.654 .866 .979 r
.5537 .33322 m .55599 .33457 L .54634 .33804 L p F P
0 g
s
.654 .866 .979 r
.54634 .33804 m .54415 .33677 L .5537 .33322 L p F P
0 g
s
.402 0 0 r
.41222 .46996 m .41223 .46996 L .40392 .46856 L p F P
0 g
s
.402 0 0 r
.40134 .46979 m .41222 .46996 L p .40392 .46856 L F P
0 g
s
.402 0 0 r
.40008 .46957 m .40134 .46979 L p .40392 .46856 L F P
0 g
s
.402 0 0 r
.40392 .46856 m .40256 .46854 L .40008 .46957 L p F P
0 g
s
.43 0 0 r
.40256 .46854 m .40008 .46957 L .39347 .46823 L closepath p F P
0 g
s
.845 .575 .529 r
.19035 .38935 m .1953 .39173 L .1954 .38763 L p F P
0 g
s
.845 .575 .529 r
.1954 .38763 m .19046 .38526 L .19035 .38935 L p F P
0 g
s
.389 0 0 r
.42728 .46851 m .42718 .46856 L .42688 .46852 L closepath p F P
0 g
s
.38 0 0 r
.42452 .46986 m .42718 .46856 L .42688 .46852 L p F P
0 g
s
.38 0 0 r
.42403 .46986 m .42452 .46986 L p .42688 .46852 L F P
0 g
s
.367 0 0 r
.43659 .46946 m .43925 .46807 L .42728 .46851 L p F P
0 g
s
.367 0 0 r
.42728 .46851 m .42718 .46856 L .43659 .46946 L p F P
0 g
s
.835 .658 .663 r
.18403 .3671 m .1843 .36645 L .18159 .35976 L p F P
0 g
s
.662 .156 .034 r
.2863 .44944 m .29297 .45111 L .28914 .44827 L p F P
0 g
s
.662 .156 .034 r
.28292 .44697 m .2863 .44944 L p .28914 .44827 L F P
0 g
s
.662 .156 .034 r
.28914 .44827 m .28334 .44685 L .28292 .44697 L p F P
0 g
s
.82 .453 .361 r
.21931 .41594 m .21788 .41235 L .22319 .41455 L p F P
0 g
s
.82 .453 .361 r
.22273 .41736 m .21931 .41594 L p .22319 .41455 L F P
0 g
s
.82 .453 .361 r
.22319 .41455 m .22395 .41641 L .22273 .41736 L p F P
0 g
s
.388 0 0 r
.4515 .467 m .45381 .46713 L .45098 .46736 L closepath p F P
0 g
s
.687 .733 .886 r
.21959 .32807 m .2104 .33216 L .20742 .32877 L p F P
0 g
s
.335 .786 .953 r
.42719 .3536 m .41525 .35381 L .41523 .35381 L p F P
0 g
s
.307 .77 .945 r
.41525 .35381 m .41523 .35381 L .41517 .35381 L closepath p F P
0 g
s
.255 .75 .907 r
.41246 .35328 m .40408 .35369 L .41517 .35381 L p F P
0 g
s
.255 .75 .907 r
.41517 .35381 m .41523 .35381 L .41246 .35328 L p F P
0 g
s
.574 .733 .95 r
.24675 .33169 m .24935 .33127 L .25456 .33358 L p F P
0 g
s
.591 .748 .952 r
.25582 .33019 m .24935 .33127 L .25456 .33358 L p F P
0 g
s
.591 .748 .952 r
.25456 .33358 m .25879 .33274 L .25582 .33019 L p F P
0 g
s
.403 .069 .282 r
.59628 .42363 m .59668 .42235 L .58699 .4266 L p F P
0 g
s
.403 .069 .282 r
.58699 .4266 m .5868 .4272 L .59628 .42363 L p F P
0 g
s
.335 .786 .953 r
.41523 .35381 m .42463 .35312 L p .42719 .3536 L F P
0 g
s
.137 .679 .824 r
.42463 .35312 m .41523 .35381 L .41246 .35328 L p F P
0 g
s
.398 .835 .947 r
.47327 .34925 m .47337 .34926 L .46385 .35116 L p F P
0 g
s
.398 .835 .947 r
.46385 .35116 m .46224 .35086 L .47327 .34925 L p F P
0 g
s
.365 .816 .942 r
.46224 .35086 m .46385 .35116 L p .45169 .35224 L F P
0 g
s
.558 .019 0 r
.33836 .46159 m .3367 .4621 L .334 .4609 L closepath p F P
0 g
s
.366 0 0 r
.43657 .46947 m .43659 .46946 L .42718 .46856 L p F P
0 g
s
.366 0 0 r
.42718 .46856 m .42452 .46986 L .43657 .46947 L p F P
0 g
s
.232 .731 .908 r
.41091 .35308 m .41246 .35328 L .40408 .35369 L p F P
0 g
s
.232 .731 .908 r
.40605 .353 m .41091 .35308 L p .40408 .35369 L F P
0 g
s
.232 .731 .908 r
.4003 .35311 m .40605 .353 L p .40408 .35369 L F P
0 g
s
.232 .731 .908 r
.40408 .35369 m .40275 .35366 L .4003 .35311 L p F P
0 g
s
.207 .715 .899 r
.40275 .35366 m .4003 .35311 L .39373 .35331 L closepath p F P
0 g
s
.771 .701 .785 r
.19062 .34013 m .18866 .34187 L .18572 .33775 L p F P
0 g
s
.791 .699 .764 r
.18453 .3464 m .18866 .34187 L .18572 .33775 L p F P
0 g
s
.409 0 0 r
.43934 .46801 m .43969 .46805 L .43925 .46807 L closepath p F P
0 g
s
.773 .345 .234 r
.23996 .42909 m .24575 .43109 L .24341 .42779 L p F P
0 g
s
.773 .345 .234 r
.23848 .427 m .23996 .42909 L p .24341 .42779 L F P
0 g
s
.773 .345 .234 r
.24341 .42779 m .23961 .42649 L .23848 .427 L p F P
0 g
s
.757 .708 .807 r
.19062 .34013 m .19813 .33417 L .19516 .33052 L p F P
0 g
s
.757 .708 .807 r
.19516 .33052 m .18585 .33764 L .19062 .34013 L p F P
0 g
s
.771 .701 .785 r
.18572 .33775 m .18585 .33764 L .19062 .34013 L p F P
0 g
s
.835 .658 .663 r
.18159 .35976 m .17945 .36457 L .18403 .3671 L p F P
0 g
s
.844 .645 .634 r
.1779 .36917 m .1825 .37169 L .18403 .3671 L p F P
0 g
s
.844 .645 .634 r
.18403 .3671 m .17945 .36457 L .1779 .36917 L p F P
0 g
s
.846 .551 .49 r
.1956 .39569 m .20057 .39804 L .20028 .39407 L p F P
0 g
s
.846 .551 .49 r
.20028 .39407 m .1953 .39173 L .1956 .39569 L p F P
0 g
s
.62 .74 .932 r
.23468 .33116 m .24378 .32891 L .24675 .33169 L p F P
0 g
s
.606 .74 .94 r
.24378 .32891 m .23468 .33116 L .23171 .32818 L p F P
0 g
s
.848 .626 .6 r
.18615 .3786 m .18679 .37575 L .18648 .37383 L p F P
0 g
s
.848 .626 .6 r
.18149 .3761 m .18615 .3786 L p .18648 .37383 L F P
0 g
s
.848 .626 .6 r
.18648 .37383 m .1825 .37169 L .18149 .3761 L p F P
0 g
s
.323 .783 .945 r
.42743 .35359 m .42738 .35358 L .42719 .3536 L closepath p F P
0 g
s
.335 .786 .953 r
.42463 .35312 m .42738 .35358 L .42719 .3536 L p F P
0 g
s
.417 0 0 r
.39962 .46976 m .40008 .46957 L .39347 .46823 L p F P
0 g
s
.417 0 0 r
.391 .46941 m .39962 .46976 L p .39347 .46823 L F P
0 g
s
.417 0 0 r
.38794 .46878 m .391 .46941 L p .39347 .46823 L F P
0 g
s
.417 0 0 r
.39347 .46823 m .38977 .46809 L .38794 .46878 L p F P
0 g
s
.319 .78 .944 r
.43681 .35263 m .43931 .35302 L .42743 .35359 L p F P
0 g
s
.319 .78 .944 r
.42743 .35359 m .42738 .35358 L .43681 .35263 L p F P
0 g
s
.429 .727 .988 r
.2858 .3381 m .28755 .33808 L .2935 .34009 L p F P
0 g
s
.455 .75 .992 r
.29488 .33792 m .28755 .33808 L .2935 .34009 L p F P
0 g
s
.455 .75 .992 r
.2935 .34009 m .29783 .33985 L .29488 .33792 L p F P
0 g
s
.281 .703 .97 r
.32483 .34516 m .32498 .34516 L .33184 .34683 L p F P
0 g
s
.304 .729 .972 r
.33398 .34554 m .32498 .34516 L .33184 .34683 L p F P
0 g
s
.304 .729 .972 r
.33184 .34683 m .33689 .34685 L .33398 .34554 L p F P
0 g
s
.645 .863 .982 r
.54384 .33659 m .54415 .33677 L .5344 .34004 L p F P
0 g
s
.645 .863 .982 r
.5344 .34004 m .5342 .33992 L .54384 .33659 L p F P
0 g
s
.659 .161 .055 r
.29784 .45134 m .29983 .4527 L .29626 .45191 L closepath p F P
0 g
s
.171 .705 .836 r
.43681 .35263 m .42738 .35358 L .42463 .35312 L p F P
0 g
s
.365 .816 .942 r
.45169 .35224 m .45575 .35156 L .46224 .35086 L p F P
0 g
s
.349 .81 .93 r
.45169 .35224 m .45575 .35156 L .45091 .35211 L closepath p F P
0 g
s
.311 .787 .92 r
.45091 .35211 m .45169 .35224 L p .43953 .35305 L F P
0 g
s
.314 .721 .978 r
.32471 .3451 m .32483 .34516 L p .31279 .34348 L F P
0 g
s
.314 .721 .978 r
.31279 .34348 m .31787 .34359 L .32471 .3451 L p F P
0 g
s
.284 .696 .972 r
.31787 .34359 m .31279 .34348 L .30986 .34171 L p F P
0 g
s
.144 .655 .898 r
.35781 .34978 m .35184 .34961 L .34897 .34842 L p F P
0 g
s
.446 0 0 r
.38977 .46809 m .38794 .46878 L .38352 .46773 L closepath p F P
0 g
s
.346 0 0 r
.43969 .46805 m .43925 .46807 L .43659 .46946 L p F P
0 g
s
.311 .787 .92 r
.43953 .35305 m .44051 .35292 L .45091 .35211 L p F P
0 g
s
.305 .785 .916 r
.43953 .35305 m .44051 .35292 L .43931 .35302 L closepath p F P
0 g
s
.346 0 0 r
.44838 .4688 m .44878 .46858 L .43969 .46805 L p F P
0 g
s
.346 0 0 r
.43665 .46947 m .44838 .4688 L p .43969 .46805 L F P
0 g
s
.346 0 0 r
.43659 .46946 m .43665 .46947 L p .43969 .46805 L F P
0 g
s
.352 0 0 r
.45098 .46736 m .44878 .46858 L .43969 .46805 L closepath p F P
0 g
s
.759 .315 .197 r
.25517 .43428 m .2532 .43504 L .25158 .43308 L closepath p F P
0 g
s
.725 .255 .133 r
.26968 .44101 m .26803 .44156 L .26647 .44004 L closepath p F P
0 g
s
.235 .726 .922 r
.39822 .35276 m .4003 .35311 L .39373 .35331 L p F P
0 g
s
.235 .726 .922 r
.3956 .35264 m .39822 .35276 L p .39373 .35331 L F P
0 g
s
.235 .726 .922 r
.38816 .35262 m .3956 .35264 L p .39373 .35331 L F P
0 g
s
.235 .726 .922 r
.39373 .35331 m .38987 .35309 L .38816 .35262 L p F P
0 g
s
.384 .052 .274 r
.60637 .41746 m .60654 .41691 L .59719 .42066 L p F P
0 g
s
.384 .052 .274 r
.59719 .42066 m .59668 .42235 L .60637 .41746 L p F P
0 g
s
.625 .885 .988 r
.54384 .33659 m .5342 .33992 L .53167 .33878 L p F P
0 g
s
.321 0 0 r
.49809 .46034 m .49752 .4608 L .49344 .46107 L closepath p F P
0 g
s
.322 0 0 r
.4959 .46211 m .49752 .4608 L .49344 .46107 L p F P
0 g
s
.322 0 0 r
.48797 .46333 m .4959 .46211 L p .49344 .46107 L F P
0 g
s
.322 0 0 r
.48535 .46347 m .48797 .46333 L p .49344 .46107 L F P
0 g
s
.844 .526 .45 r
.20124 .40187 m .20626 .4042 L .20559 .40036 L p F P
0 g
s
.844 .526 .45 r
.20559 .40036 m .20057 .39804 L .20124 .40187 L p F P
0 g
s
.31 0 0 r
.52832 .45275 m .52131 .45431 L .5194 .45633 L p F P
0 g
s
.791 .699 .764 r
.18572 .33775 m .18 .34383 L .18453 .3464 L p F P
0 g
s
.804 .691 .739 r
.17657 .35007 m .18017 .35203 L .18453 .3464 L p F P
0 g
s
.804 .691 .739 r
.17592 .34896 m .17657 .35007 L p .18453 .3464 L F P
0 g
s
.804 .691 .739 r
.18453 .3464 m .18 .34383 L .17592 .34896 L p F P
0 g
s
.845 .621 .598 r
.18679 .37575 m .18615 .3786 L .18727 .37918 L closepath p F P
0 g
s
.222 .717 .916 r
.38987 .35309 m .38816 .35262 L .38401 .3527 L closepath p F P
0 g
s
.432 0 0 r
.38673 .46923 m .38794 .46878 L .38352 .46773 L p F P
0 g
s
.432 0 0 r
.38114 .46887 m .38673 .46923 L p .38352 .46773 L F P
0 g
s
.432 0 0 r
.37583 .46759 m .38114 .46887 L p .38352 .46773 L F P
0 g
s
.432 0 0 r
.38352 .46773 m .37667 .46731 L .37583 .46759 L p F P
0 g
s
.628 .11 0 r
.30425 .45536 m .29983 .4527 L .30688 .45423 L p F P
0 g
s
.628 .11 0 r
.30854 .4563 m .30425 .45536 L p .30688 .45423 L F P
0 g
s
.628 .11 0 r
.30688 .45423 m .30973 .45595 L .30854 .4563 L p F P
0 g
s
.403 .099 .331 r
.61605 .41163 m .61647 .40978 L .60726 .41374 L p F P
0 g
s
.403 .099 .331 r
.60986 .41548 m .61605 .41163 L p .60726 .41374 L F P
0 g
s
.403 .099 .331 r
.60726 .41374 m .60654 .41691 L .60986 .41548 L p F P
0 g
s
.598 .079 0 r
.32471 .45887 m .32622 .45964 L .32373 .45923 L closepath p F P
0 g
s
.629 .597 .799 r
.64345 .33701 m .6413 .33828 L p .63147 .33477 L F P
0 g
s
.629 .597 .799 r
.63147 .33477 m .64129 .3323 L .64345 .33701 L p F P
0 g
s
.634 .633 .832 r
.62937 .33088 m .63147 .33477 L .64129 .3323 L p F P
0 g
s
.299 .782 .912 r
.44051 .35292 m .43931 .35302 L .43681 .35263 L p F P
0 g
s
.825 .661 .679 r
.18159 .35975 m .18159 .35975 L .18159 .35976 L closepath p F P
0 g
s
.362 0 .209 r
.59521 .42641 m .59628 .42363 L .5868 .4272 L p F P
0 g
s
.362 0 .209 r
.5868 .4272 m .58571 .42997 L .59521 .42641 L p F P
0 g
s
.837 .663 .666 r
.17945 .36457 m .18159 .35976 L .18159 .35975 L p F P
0 g
s
.828 .673 .692 r
.17877 .35417 m .1771 .35718 L .18159 .35975 L closepath p F P
0 g
s
.837 .663 .666 r
.17492 .36201 m .17945 .36457 L p .18159 .35975 L F P
0 g
s
.837 .663 .666 r
.18159 .35975 m .1771 .35718 L .17492 .36201 L p F P
0 g
s
.558 .018 0 r
.33155 .46201 m .32622 .45964 L .334 .4609 L p F P
0 g
s
.558 .018 0 r
.33506 .46259 m .33155 .46201 L p .334 .4609 L F P
0 g
s
.558 .018 0 r
.334 .4609 m .3367 .4621 L .33506 .46259 L p F P
0 g
s
.729 .713 .835 r
.20183 .33194 m .19813 .33417 L .19516 .33052 L p F P
0 g
s
.536 .88 .987 r
.50732 .34319 m .50932 .34374 L .49899 .34623 L p F P
0 g
s
.536 .88 .987 r
.49899 .34623 m .49772 .34584 L .50732 .34319 L p F P
0 g
s
.336 0 .023 r
.54361 .44723 m .54358 .44727 L .54303 .44737 L closepath p F P
0 g
s
.34 0 .026 r
.54192 .44943 m .54358 .44727 L .54303 .44737 L p F P
0 g
s
.34 0 .026 r
.53169 .45198 m .54192 .44943 L p .54303 .44737 L F P
0 g
s
.298 .781 .912 r
.45091 .35211 m .44899 .35181 L .44051 .35292 L closepath p F P
0 g
s
.299 .782 .912 r
.44692 .35164 m .44899 .35181 L .44051 .35292 L p F P
0 g
s
.299 .782 .912 r
.44354 .35189 m .44692 .35164 L p .44051 .35292 L F P
0 g
s
.299 .782 .912 r
.43681 .35263 m .44354 .35189 L p .44051 .35292 L F P
0 g
s
.557 .724 .952 r
.24935 .33127 m .24675 .33169 L .24378 .32891 L p F P
0 g
s
.493 .307 .557 r
.64433 .38187 m .64094 .38366 L .63985 .3798 L p F P
0 g
s
.493 .307 .557 r
.63985 .3798 m .64407 .37757 L .64433 .38187 L p F P
0 g
s
.311 0 .009 r
.55324 .44503 m .55367 .44447 L .54361 .44723 L p F P
0 g
s
.311 0 .009 r
.54361 .44723 m .54358 .44727 L .55324 .44503 L p F P
0 g
s
.801 .404 .299 r
.22658 .42156 m .2321 .42368 L .23023 .42023 L p F P
0 g
s
.801 .404 .299 r
.23023 .42023 m .22468 .41812 L .22658 .42156 L p F P
0 g
s
.472 .265 .516 r
.63988 .38827 m .63556 .39051 L .63552 .38647 L p F P
0 g
s
.472 .265 .516 r
.63552 .38647 m .64094 .38366 L .63988 .38827 L p F P
0 g
s
.506 .343 .595 r
.65273 .37272 m .65222 .36811 L .64355 .37295 L p F P
0 g
s
.506 .343 .595 r
.64355 .37295 m .64407 .37757 L .65273 .37272 L p F P
0 g
s
.31 0 .006 r
.55201 .44668 m .55324 .44503 L .54358 .44727 L p F P
0 g
s
.31 0 .006 r
.54358 .44727 m .54192 .44943 L .55201 .44668 L p F P
0 g
s
.253 .726 .94 r
.38533 .352 m .38816 .35262 L .38401 .3527 L p F P
0 g
s
.253 .726 .94 r
.37604 .35184 m .38533 .352 L p .38401 .3527 L F P
0 g
s
.253 .726 .94 r
.38401 .3527 m .37654 .352 L .37604 .35184 L p F P
0 g
s
.325 0 0 r
.45381 .46713 m .45098 .46736 L .44878 .46858 L p F P
0 g
s
.44 .722 .985 r
.2858 .3381 m .28755 .33808 L .28388 .33669 L closepath p F P
0 g
s
.461 0 0 r
.37667 .46731 m .37583 .46759 L .37397 .46709 L closepath p F P
0 g
s
.332 0 0 r
.50969 .45755 m .51827 .45656 L .50882 .45844 L closepath p F P
0 g
s
.83 .48 .393 r
.20738 .40789 m .21261 .41013 L .2115 .40644 L p F P
0 g
s
.83 .48 .393 r
.20631 .40441 m .20738 .40789 L p .2115 .40644 L F P
0 g
s
.83 .48 .393 r
.2115 .40644 m .20644 .40429 L .20631 .40441 L p F P
0 g
s
.33 0 0 r
.4625 .4664 m .46097 .46729 L .45381 .46713 L closepath p F P
0 g
s
.325 0 0 r
.45996 .46788 m .46097 .46729 L .45381 .46713 L p F P
0 g
s
.325 0 0 r
.45055 .46864 m .45996 .46788 L p .45381 .46713 L F P
0 g
s
.325 0 0 r
.44878 .46858 m .45055 .46864 L p .45381 .46713 L F P
0 g
s
.418 .139 .38 r
.62571 .40468 m .6261 .40225 L .61701 .40641 L p F P
0 g
s
.418 .139 .38 r
.62313 .40673 m .62571 .40468 L p .61701 .40641 L F P
0 g
s
.418 .139 .38 r
.61701 .40641 m .61647 .40978 L .62313 .40673 L p F P
0 g
s
.511 0 0 r
.36374 .46595 m .36483 .4663 L .36322 .46616 L closepath p F P
0 g
s
.683 .187 .06 r
.28334 .44685 m .28292 .44697 L .28246 .44661 L closepath p F P
0 g
s
.46 0 0 r
.37166 .4682 m .36483 .4663 L .37397 .46709 L p F P
0 g
s
.46 0 0 r
.37351 .46836 m .37166 .4682 L p .37397 .46709 L F P
0 g
s
.46 0 0 r
.37397 .46709 m .37583 .46759 L .37351 .46836 L p F P
0 g
s
.296 0 0 r
.50712 .45987 m .50882 .45844 L .49809 .46034 L p F P
0 g
s
.296 0 0 r
.49809 .46034 m .49752 .4608 L .50712 .45987 L p F P
0 g
s
.572 .479 .711 r
.6477 .35238 m .64874 .35178 L .6489 .35236 L closepath p F P
0 g
s
.345 0 .152 r
.58472 .43203 m .58571 .42997 L .57608 .43333 L p F P
0 g
s
.345 0 .152 r
.57608 .43333 m .57501 .43556 L .58472 .43203 L p F P
0 g
s
.596 .889 .99 r
.53167 .33878 m .52205 .34192 L .5195 .34097 L p F P
0 g
s
.577 .885 .991 r
.50989 .3439 m .5195 .34097 L .52205 .34192 L p F P
0 g
s
.725 .255 .131 r
.26348 .44122 m .26036 .43816 L .26647 .44004 L p F P
0 g
s
.725 .255 .131 r
.26635 .44211 m .26348 .44122 L p .26647 .44004 L F P
0 g
s
.725 .255 .131 r
.26647 .44004 m .26803 .44156 L .26635 .44211 L p F P
0 g
s
.787 .367 .252 r
.23961 .42649 m .23848 .427 L .23766 .42577 L closepath p F P
0 g
s
.164 .677 .895 r
.36393 .35082 m .36618 .35089 L .37494 .35185 L p F P
0 g
s
.208 .695 .927 r
.36393 .35082 m .36618 .35089 L .36275 .35042 L closepath p F P
0 g
s
.366 0 .159 r
.57482 .43594 m .57501 .43556 L .56532 .43856 L p F P
0 g
s
.366 0 .159 r
.56532 .43856 m .56505 .4391 L .57482 .43594 L p F P
0 g
s
.718 .72 .851 r
.20183 .33194 m .20742 .32877 L .20443 .32543 L p F P
0 g
s
.718 .72 .851 r
.20443 .32543 m .19699 .32948 L .20183 .33194 L p F P
0 g
s
.729 .713 .835 r
.19516 .33052 m .19699 .32948 L .20183 .33194 L p F P
0 g
s
.851 .604 .565 r
.18561 .38284 m .18722 .38368 L .18727 .37918 L p F P
0 g
s
.851 .604 .565 r
.18727 .37918 m .18615 .3786 L .18561 .38284 L p F P
0 g
s
.684 .772 .918 r
.60216 .32647 m .59244 .33004 L .58999 .32754 L p F P
0 g
s
.682 .78 .925 r
.58029 .33118 m .58999 .32754 L .59244 .33004 L p F P
0 g
s
.679 .746 .902 r
.59244 .33004 m .60216 .32647 L .6046 .3294 L p F P
0 g
s
.813 .442 .354 r
.22395 .41641 m .22468 .41812 L .22273 .41736 L closepath p F P
0 g
s
.671 .71 .878 r
.6046 .3294 m .61435 .32598 L .61679 .3294 L p F P
0 g
s
.678 .736 .895 r
.61435 .32598 m .6046 .3294 L .60216 .32647 L p F P
0 g
s
.683 .186 .058 r
.27967 .44775 m .27606 .44485 L .28246 .44661 L p F P
0 g
s
.683 .186 .058 r
.2799 .44782 m .27967 .44775 L p .28246 .44661 L F P
0 g
s
.683 .186 .058 r
.28246 .44661 m .28292 .44697 L .2799 .44782 L p F P
0 g
s
.76 .315 .195 r
.24839 .4343 m .24575 .43109 L .25158 .43308 L p F P
0 g
s
.76 .315 .195 r
.25195 .43552 m .24839 .4343 L p .25158 .43308 L F P
0 g
s
.76 .315 .195 r
.25158 .43308 m .2532 .43504 L .25195 .43552 L p F P
0 g
s
.344 .808 .927 r
.45575 .35156 m .45091 .35211 L .44899 .35181 L p F P
0 g
s
.815 .676 .711 r
.18017 .35203 m .17657 .35007 L .17877 .35417 L closepath p F P
0 g
s
.291 .704 .973 r
.32483 .34516 m .32498 .34516 L .32471 .3451 L closepath p F P
0 g
s
.251 .725 .939 r
.37654 .352 m .37604 .35184 L .37494 .35185 L closepath p F P
0 g
s
.278 .698 .969 r
.33334 .34528 m .33398 .34554 L .32498 .34516 L p F P
0 g
s
.278 .698 .969 r
.32761 .3441 m .33334 .34528 L p .32498 .34516 L F P
0 g
s
.278 .698 .969 r
.32191 .34365 m .32761 .3441 L p .32498 .34516 L F P
0 g
s
.278 .698 .969 r
.32498 .34516 m .32471 .3451 L .32191 .34365 L p F P
0 g
s
.682 .814 .946 r
.5887 .32637 m .58999 .32754 L .58029 .33118 L p F P
0 g
s
.682 .814 .946 r
.58029 .33118 m .57962 .3306 L .5887 .32637 L p F P
0 g
s
.214 .712 .914 r
.37319 .35107 m .36618 .35089 L .37494 .35185 L p F P
0 g
s
.214 .712 .914 r
.37494 .35185 m .37604 .35184 L .37319 .35107 L p F P
0 g
s
.326 .725 .981 r
.32471 .3451 m .32191 .34365 L .31787 .34359 L closepath p F P
0 g
s
.592 .529 .752 r
.64631 .34427 m .64822 .34404 L .64658 .34503 L closepath p F P
0 g
s
.583 .508 .737 r
.65721 .34661 m .64874 .35178 L .64658 .34503 L p F P
0 g
s
.583 .508 .737 r
.65624 .34344 m .65721 .34661 L p .64658 .34503 L F P
0 g
s
.583 .508 .737 r
.64658 .34503 m .64822 .34404 L .65624 .34344 L p F P
0 g
s
.616 .578 .788 r
.6413 .33828 m .64345 .33701 L .64378 .33778 L closepath p F P
0 g
s
.558 .47 .712 r
.65881 .35263 m .65721 .34661 L .64874 .35178 L p F P
0 g
s
.558 .47 .712 r
.65829 .35294 m .65881 .35263 L p .64874 .35178 L F P
0 g
s
.558 .47 .712 r
.64874 .35178 m .6489 .35236 L .65829 .35294 L p F P
0 g
s
.52 .74 .975 r
.25879 .33274 m .26786 .33185 L .27082 .3342 L p F P
0 g
s
.498 .734 .978 r
.26786 .33185 m .25879 .33274 L .25582 .33019 L p F P
0 g
s
.658 .672 .851 r
.61679 .3294 m .62657 .32622 L .62901 .33023 L p F P
0 g
s
.667 .698 .869 r
.62657 .32622 m .61679 .3294 L .61435 .32598 L p F P
0 g
s
.559 .458 .696 r
.6489 .35236 m .65829 .35294 L .65028 .35772 L closepath p F P
0 g
s
.603 .542 .759 r
.64822 .34404 m .64631 .34427 L .64378 .33778 L p F P
0 g
s
.302 0 0 r
.4696 .46566 m .4625 .4664 L .46097 .46729 L p F P
0 g
s
.544 0 0 r
.32388 .4607 m .33155 .46201 L .32622 .45964 L p F P
0 g
s
.544 0 0 r
.32169 .45972 m .32388 .4607 L p .32622 .45964 L F P
0 g
s
.544 0 0 r
.32622 .45964 m .32373 .45923 L .32169 .45972 L p F P
0 g
s
.669 .166 .041 r
.28292 .44697 m .2863 .44944 L .2799 .44782 L closepath p F P
0 g
s
.824 .454 .354 r
.21405 .41372 m .21931 .41594 L .21788 .41235 L p F P
0 g
s
.824 .454 .354 r
.21788 .41235 m .21261 .41013 L .21405 .41372 L p F P
0 g
s
.854 .608 .566 r
.18094 .38036 m .18561 .38284 L .18615 .3786 L p F P
0 g
s
.854 .608 .566 r
.18615 .3786 m .18149 .3761 L .18094 .38036 L p F P
0 g
s
.431 .719 .985 r
.29192 .33603 m .29488 .33792 L .28755 .33808 L p F P
0 g
s
.431 .719 .985 r
.28285 .33594 m .29192 .33603 L p .28755 .33808 L F P
0 g
s
.431 .719 .985 r
.28755 .33808 m .28388 .33669 L .28285 .33594 L p F P
0 g
s
.448 0 0 r
.36265 .46736 m .37166 .4682 L .36483 .4663 L p F P
0 g
s
.448 0 0 r
.36081 .46685 m .36265 .46736 L p .36483 .4663 L F P
0 g
s
.448 0 0 r
.36483 .4663 m .36322 .46616 L .36081 .46685 L p F P
0 g
s
.351 .81 .933 r
.46224 .35086 m .46118 .35068 L .45575 .35156 L closepath p F P
0 g
s
.344 .808 .927 r
.4585 .35043 m .46118 .35068 L .45575 .35156 L p F P
0 g
s
.344 .808 .927 r
.44899 .35181 m .4585 .35043 L p .45575 .35156 L F P
0 g
s
.788 .367 .251 r
.23429 .42703 m .2321 .42368 L .23766 .42577 L p F P
0 g
s
.788 .367 .251 r
.2365 .42786 m .23429 .42703 L p .23766 .42577 L F P
0 g
s
.788 .367 .251 r
.23766 .42577 m .23848 .427 L .2365 .42786 L p F P
0 g
s
.549 .892 .982 r
.51943 .34096 m .5195 .34097 L .50989 .3439 L p F P
0 g
s
.549 .892 .982 r
.50989 .3439 m .50932 .34374 L .51943 .34096 L p F P
0 g
s
.557 .724 .952 r
.24378 .32891 m .24453 .32881 L .24935 .33127 L p F P
0 g
s
.572 .745 .958 r
.25284 .32766 m .24453 .32881 L .24935 .33127 L p F P
0 g
s
.572 .745 .958 r
.24935 .33127 m .25582 .33019 L .25284 .32766 L p F P
0 g
s
.848 .577 .528 r
.18644 .38744 m .19035 .38935 L .19046 .38526 L p F P
0 g
s
.848 .577 .528 r
.19046 .38526 m .18722 .38368 L .18644 .38744 L p F P
0 g
s
.306 0 0 r
.53169 .45198 m .53145 .45224 L .52832 .45275 L closepath p F P
0 g
s
.31 0 0 r
.5298 .45399 m .53145 .45224 L .52832 .45275 L p F P
0 g
s
.31 0 0 r
.5194 .45633 m .5298 .45399 L p .52832 .45275 L F P
0 g
s
.613 .083 0 r
.2973 .45379 m .30425 .45536 L .29983 .4527 L p F P
0 g
s
.613 .083 0 r
.29475 .45226 m .2973 .45379 L p .29983 .4527 L F P
0 g
s
.613 .083 0 r
.29983 .4527 m .29626 .45191 L .29475 .45226 L p F P
0 g
s
.85 .628 .601 r
.17687 .37359 m .18149 .3761 L .1825 .37169 L p F P
0 g
s
.85 .628 .601 r
.1825 .37169 m .1779 .36917 L .17687 .37359 L p F P
0 g
s
.828 .678 .697 r
.1771 .35718 m .17877 .35417 L .17657 .35007 L p F P
0 g
s
.432 .179 .428 r
.6353 .39543 m .63541 .3943 L .62645 .39868 L p F P
0 g
s
.432 .179 .428 r
.63139 .39967 m .6353 .39543 L p .62645 .39868 L F P
0 g
s
.432 .179 .428 r
.62645 .39868 m .6261 .40225 L .63139 .39967 L p F P
0 g
s
.479 0 0 r
.36322 .46616 m .36081 .46685 L .35612 .46537 L closepath p F P
0 g
s
.316 0 .074 r
.57338 .43834 m .57482 .43594 L .56505 .4391 L p F P
0 g
s
.316 0 .074 r
.56505 .4391 m .56359 .44151 L .57338 .43834 L p F P
0 g
s
.678 .839 .96 r
.57783 .32907 m .56814 .33273 L .56567 .33097 L p F P
0 g
s
.671 .842 .965 r
.55599 .33457 m .56567 .33097 L .56814 .33273 L p F P
0 g
s
.848 .552 .488 r
.19066 .39331 m .1956 .39569 L .1953 .39173 L p F P
0 g
s
.848 .552 .488 r
.1953 .39173 m .19035 .38935 L .19066 .39331 L p F P
0 g
s
.572 .03 0 r
.32373 .45923 m .32169 .45972 L .31872 .45828 L closepath p F P
0 g
s
.026 .593 .782 r
.38533 .352 m .37604 .35184 L .37319 .35107 L p F P
0 g
s
.768 .705 .792 r
.18585 .33764 m .18549 .33745 L .18572 .33775 L closepath p F P
0 g
s
.792 .707 .77 r
.18 .34383 m .18572 .33775 L .18549 .33745 L p F P
0 g
s
.756 .721 .819 r
.18585 .33764 m .19516 .33052 L .19248 .32732 L p F P
0 g
s
.756 .721 .819 r
.18549 .33745 m .18585 .33764 L p .19248 .32732 L F P
0 g
s
.645 .646 .836 r
.62901 .33023 m .63196 .32938 L .62937 .33088 L closepath p F P
0 g
s
.634 .633 .832 r
.63883 .32746 m .63196 .32938 L .62937 .33088 L p F P
0 g
s
.634 .633 .832 r
.64129 .3323 m .63883 .32746 L p .62937 .33088 L F P
0 g
s
.34 .72 .984 r
.30857 .34097 m .30986 .34171 L p .29783 .33985 L F P
0 g
s
.34 .72 .984 r
.29783 .33985 m .30479 .34 L .30857 .34097 L p F P
0 g
s
.299 .697 .976 r
.30479 .34 m .29783 .33985 L .29488 .33792 L p F P
0 g
s
.845 .647 .635 r
.17334 .36662 m .1779 .36917 L .17945 .36457 L p F P
0 g
s
.845 .647 .635 r
.17945 .36457 m .17492 .36201 L .17334 .36662 L p F P
0 g
s
.295 0 0 r
.50668 .46023 m .50712 .45987 L .49752 .4608 L p F P
0 g
s
.295 0 0 r
.49752 .4608 m .4959 .46211 L .50668 .46023 L p F P
0 g
s
.382 .049 .271 r
.60564 .41986 m .60637 .41746 L .59668 .42235 L p F P
0 g
s
.382 .049 .271 r
.59668 .42235 m .59628 .42363 L .60564 .41986 L p F P
0 g
s
.438 0 0 r
.37583 .46759 m .38114 .46887 L .37351 .46836 L closepath p F P
0 g
s
.543 .427 .671 r
.65994 .35803 m .65143 .36314 L .65028 .35772 L p F P
0 g
s
.543 .427 .671 r
.6589 .35305 m .65994 .35803 L p .65028 .35772 L F P
0 g
s
.543 .427 .671 r
.65028 .35772 m .65829 .35294 L .6589 .35305 L p F P
0 g
s
.756 .721 .819 r
.18275 .33383 m .18549 .33745 L p .19248 .32732 L F P
0 g
s
.781 .711 .786 r
.18275 .33383 m .1815 .33499 L .18549 .33745 L closepath p F P
0 g
s
.792 .707 .77 r
.17548 .34124 m .18 .34383 L p .18549 .33745 L F P
0 g
s
.792 .707 .77 r
.18549 .33745 m .1815 .33499 L .17548 .34124 L p F P
0 g
s
.306 0 0 r
.47383 .46521 m .47316 .46561 L .4696 .46566 L closepath p F P
0 g
s
.302 0 0 r
.47134 .46672 m .47316 .46561 L .4696 .46566 L p F P
0 g
s
.302 0 0 r
.46607 .46727 m .47134 .46672 L p .4696 .46566 L F P
0 g
s
.302 0 0 r
.46097 .46729 m .46607 .46727 L p .4696 .46566 L F P
0 g
s
.194 .688 .92 r
.37157 .3507 m .37319 .35107 L .36618 .35089 L p F P
0 g
s
.194 .688 .92 r
.36775 .35028 m .37157 .3507 L p .36618 .35089 L F P
0 g
s
.194 .688 .92 r
.36106 .34986 m .36775 .35028 L p .36618 .35089 L F P
0 g
s
.194 .688 .92 r
.36618 .35089 m .36275 .35042 L .36106 .34986 L p F P
0 g
s
.649 .737 .913 r
.21959 .32807 m .22872 .32524 L .23171 .32818 L p F P
0 g
s
.639 .736 .919 r
.22872 .32524 m .21959 .32807 L .21661 .32494 L p F P
0 g
s
.687 .733 .886 r
.20742 .32877 m .21661 .32494 L .21959 .32807 L p F P
0 g
s
.37 .82 .939 r
.47071 .34898 m .47327 .34925 L .46224 .35086 L p F P
0 g
s
.37 .82 .939 r
.46224 .35086 m .46118 .35068 L .47071 .34898 L p F P
0 g
s
.684 .815 .945 r
.58755 .32533 m .5887 .32637 L .57962 .3306 L p F P
0 g
s
.684 .815 .945 r
.57962 .3306 m .57783 .32907 L .58755 .32533 L p F P
0 g
s
.679 .734 .892 r
.21661 .32494 m .20742 .32877 L .20443 .32543 L p F P
0 g
s
.603 .542 .759 r
.65502 .33982 m .64822 .34404 L p .64378 .33778 L F P
0 g
s
.583 .514 .742 r
.64822 .34404 m .65502 .33982 L .65624 .34344 L closepath p F P
0 g
s
.652 .659 .843 r
.63196 .32938 m .62901 .33023 L .62657 .32622 L p F P
0 g
s
.846 .527 .447 r
.19627 .39952 m .20124 .40187 L .20057 .39804 L p F P
0 g
s
.846 .527 .447 r
.20057 .39804 m .1956 .39569 L .19627 .39952 L p F P
0 g
s
.466 .866 .965 r
.48555 .34765 m .49512 .34528 L .49772 .34584 L p F P
0 g
s
.484 .876 .966 r
.50732 .34319 m .49772 .34584 L .49512 .34528 L p F P
0 g
s
.28 0 0 r
.54112 .45031 m .54192 .44943 L .53169 .45198 L p F P
0 g
s
.28 0 0 r
.53169 .45198 m .53145 .45224 L .54112 .45031 L p F P
0 g
s
.603 .542 .759 r
.64378 .33778 m .65368 .33618 L .65502 .33982 L p F P
0 g
s
.606 .572 .79 r
.64345 .33701 m .64378 .33778 L .65368 .33618 L p F P
0 g
s
.538 0 0 r
.3367 .4621 m .33948 .46322 L .33506 .46259 L closepath p F P
0 g
s
.639 .117 0 r
.29626 .45191 m .29475 .45226 L .29297 .45111 L closepath p F P
0 g
s
.664 .867 .976 r
.56319 .32945 m .56567 .33097 L .55599 .33457 L p F P
0 g
s
.664 .867 .976 r
.5595 .33084 m .56319 .32945 L p .55599 .33457 L F P
0 g
s
.664 .867 .976 r
.55599 .33457 m .5537 .33322 L .5595 .33084 L p F P
0 g
s
.803 .4 .289 r
.2211 .41942 m .22658 .42156 L .22468 .41812 L p F P
0 g
s
.803 .4 .289 r
.22058 .41845 m .2211 .41942 L p .22468 .41812 L F P
0 g
s
.803 .4 .289 r
.22468 .41812 m .22273 .41736 L .22058 .41845 L p F P
0 g
s
.46 0 0 r
.35992 .4671 m .36081 .46685 L .35612 .46537 L p F P
0 g
s
.46 0 0 r
.35399 .4664 m .35992 .4671 L p .35612 .46537 L F P
0 g
s
.46 0 0 r
.34873 .46475 m .35399 .4664 L p .35612 .46537 L F P
0 g
s
.46 0 0 r
.35612 .46537 m .34936 .4646 L .34873 .46475 L p F P
0 g
s
.802 .687 .738 r
.17302 .34423 m .17548 .34124 L .18 .34383 L p F P
0 g
s
.802 .687 .738 r
.18 .34383 m .17592 .34896 L .17302 .34423 L p F P
0 g
s
.482 .299 .556 r
.65301 .37703 m .65273 .37272 L .64407 .37757 L p F P
0 g
s
.482 .299 .556 r
.64407 .37757 m .64433 .38187 L .65301 .37703 L p F P
0 g
s
.171 .669 .914 r
.34837 .3482 m .34897 .34842 L p .33689 .34685 L F P
0 g
s
.171 .669 .914 r
.33689 .34685 m .34214 .34716 L .34837 .3482 L p F P
0 g
s
.131 .638 .901 r
.34214 .34716 m .33689 .34685 L .33398 .34554 L p F P
0 g
s
.606 .572 .79 r
.65368 .33618 m .65186 .33174 L .64345 .33701 L p F P
0 g
s
.619 .592 .801 r
.64129 .3323 m .64345 .33701 L .65186 .33174 L p F P
0 g
s
.541 .889 .982 r
.51694 .34033 m .51943 .34096 L .50932 .34374 L p F P
0 g
s
.541 .889 .982 r
.50932 .34374 m .50732 .34319 L .51694 .34033 L p F P
0 g
s
.529 .39 .636 r
.65003 .36394 m .65143 .36314 L .65167 .36459 L closepath p F P
0 g
s
.828 .678 .697 r
.17265 .35458 m .1771 .35718 L p .17657 .35007 L F P
0 g
s
.838 .665 .668 r
.17042 .35943 m .17492 .36201 L .1771 .35718 L p F P
0 g
s
.838 .665 .668 r
.1771 .35718 m .17265 .35458 L .17042 .35943 L p F P
0 g
s
.206 .696 .924 r
.36275 .35042 m .36106 .34986 L .35781 .34978 L closepath p F P
0 g
s
.713 .236 .115 r
.26803 .44156 m .26969 .44307 L .26635 .44211 L closepath p F P
0 g
s
.281 0 0 r
.48271 .46521 m .48496 .46378 L .47383 .46521 L p F P
0 g
s
.281 0 0 r
.47383 .46521 m .47316 .46561 L .48271 .46521 L p F P
0 g
s
.454 .733 .987 r
.27082 .3342 m .27568 .33402 L .28169 .33603 L p F P
0 g
s
.43 .717 .985 r
.27568 .33402 m .27082 .3342 L .26786 .33185 L p F P
0 g
s
.273 0 0 r
.51827 .45656 m .50882 .45844 L .50712 .45987 L p F P
0 g
s
.724 .247 .114 r
.25744 .43931 m .26348 .44122 L .26036 .43816 L p F P
0 g
s
.724 .247 .114 r
.26036 .43816 m .25428 .43627 L .25744 .43931 L p F P
0 g
s
.606 .74 .94 r
.24247 .32771 m .24378 .32891 L p .23171 .32818 L F P
0 g
s
.606 .74 .94 r
.23171 .32818 m .23921 .32653 L .24247 .32771 L p F P
0 g
s
.591 .735 .943 r
.23921 .32653 m .23171 .32818 L .22872 .32524 L p F P
0 g
s
.284 .696 .972 r
.30986 .34171 m .31132 .3418 L .31787 .34359 L p F P
0 g
s
.316 .724 .978 r
.31898 .3422 m .31132 .3418 L .31787 .34359 L p F P
0 g
s
.316 .724 .978 r
.31787 .34359 m .32191 .34365 L .31898 .3422 L p F P
0 g
s
.684 .183 .047 r
.27335 .44595 m .27967 .44775 L .27606 .44485 L p F P
0 g
s
.684 .183 .047 r
.27606 .44485 m .26969 .44307 L .27335 .44595 L p F P
0 g
s
.033 .6 .777 r
.3956 .35264 m .38816 .35262 L .38533 .352 L p F P
0 g
s
.611 .087 0 r
.30973 .45595 m .31137 .45686 L .30854 .4563 L closepath p F P
0 g
s
.654 .867 .98 r
.5535 .3331 m .5537 .33322 L .54415 .33677 L p F P
0 g
s
.654 .867 .98 r
.54415 .33677 m .54384 .33659 L .5535 .3331 L p F P
0 g
s
.838 .494 .402 r
.20644 .40429 m .20631 .40441 L .20626 .4042 L closepath p F P
0 g
s
.779 .353 .239 r
.23848 .427 m .23996 .42909 L .2365 .42786 L closepath p F P
0 g
s
.572 .028 0 r
.31642 .45931 m .31137 .45686 L .31872 .45828 L p F P
0 g
s
.572 .028 0 r
.32025 .46007 m .31642 .45931 L p .31872 .45828 L F P
0 g
s
.572 .028 0 r
.31872 .45828 m .32169 .45972 L .32025 .46007 L p F P
0 g
s
.492 .746 .985 r
.28388 .33669 m .28285 .33594 L .28169 .33603 L closepath p F P
0 g
s
.839 .494 .401 r
.20225 .4056 m .20124 .40187 L .20626 .4042 L p F P
0 g
s
.839 .494 .401 r
.20408 .40645 m .20225 .4056 L p .20626 .4042 L F P
0 g
s
.839 .494 .401 r
.20626 .4042 m .20631 .40441 L .20408 .40645 L p F P
0 g
s
.724 .716 .843 r
.19699 .32948 m .19248 .32732 L .19516 .33052 L closepath p F P
0 g
s
.279 0 0 r
.54006 .45146 m .54112 .45031 L .53145 .45224 L p F P
0 g
s
.279 0 0 r
.53145 .45224 m .5298 .45399 L .54006 .45146 L p F P
0 g
s
.819 .686 .717 r
.17592 .34896 m .17557 .34948 L .17657 .35007 L closepath p F P
0 g
s
.828 .678 .697 r
.17657 .35007 m .17557 .34948 L .17265 .35458 L p F P
0 g
s
.76 .309 .179 r
.24263 .43228 m .24839 .4343 L .24575 .43109 L p F P
0 g
s
.76 .309 .179 r
.24575 .43109 m .23996 .42909 L .24263 .43228 L p F P
0 g
s
.437 .859 .947 r
.49474 .34524 m .49512 .34528 L .48555 .34765 L p F P
0 g
s
.437 .859 .947 r
.48555 .34765 m .48415 .34743 L .49474 .34524 L p F P
0 g
s
.41 .843 .947 r
.48415 .34743 m .48555 .34765 L p .47337 .34926 L F P
0 g
s
.834 .485 .396 r
.20631 .40441 m .20738 .40789 L .20408 .40645 L closepath p F P
0 g
s
.446 .217 .473 r
.63686 .39355 m .63541 .3943 L .63556 .39051 L p F P
0 g
s
.446 .217 .473 r
.63556 .39051 m .63988 .38827 L .63686 .39355 L p F P
0 g
s
.288 0 0 r
.56294 .44239 m .56359 .44151 L .55367 .44447 L p F P
0 g
s
.288 0 0 r
.55367 .44447 m .55324 .44503 L .56294 .44239 L p F P
0 g
s
.855 .585 .529 r
.18548 .38695 m .18644 .38744 L .18722 .38368 L p F P
0 g
s
.855 .585 .529 r
.18722 .38368 m .18561 .38284 L .18548 .38695 L p F P
0 g
s
.468 .261 .515 r
.64438 .3859 m .63988 .38827 L .64094 .38366 L p F P
0 g
s
.468 .261 .515 r
.64094 .38366 m .64433 .38187 L .64438 .3859 L p F P
0 g
s
.423 0 0 r
.38794 .46878 m .391 .46941 L .38673 .46923 L closepath p F P
0 g
s
.749 .299 .182 r
.2532 .43504 m .25428 .43627 L .25195 .43552 L closepath p F P
0 g
s
.814 .42 .305 r
.22273 .41736 m .22058 .41845 L .21931 .41594 L closepath p F P
0 g
s
.323 0 0 r
.48535 .46347 m .48797 .46333 L .48496 .46378 L closepath p F P
0 g
s
.639 .116 0 r
.29048 .45217 m .2863 .44944 L .29297 .45111 L p F P
0 g
s
.639 .116 0 r
.29269 .45273 m .29048 .45217 L p .29297 .45111 L F P
0 g
s
.639 .116 0 r
.29297 .45111 m .29475 .45226 L .29269 .45273 L p F P
0 g
s
.144 .655 .898 r
.34897 .34842 m .34994 .34848 L .35781 .34978 L p F P
0 g
s
.18 .685 .905 r
.35818 .34901 m .34994 .34848 L .35781 .34978 L p F P
0 g
s
.18 .685 .905 r
.35781 .34978 m .36106 .34986 L .35818 .34901 L p F P
0 g
s
.491 0 0 r
.34936 .4646 m .34873 .46475 L .34761 .46436 L closepath p F P
0 g
s
.638 .888 .986 r
.5535 .3331 m .54384 .33659 L .54133 .33545 L p F P
0 g
s
.625 .885 .988 r
.53167 .33878 m .54133 .33545 L .54384 .33659 L p F P
0 g
s
.72 .717 .846 r
.19699 .32948 m .20443 .32543 L p .19217 .32695 L F P
0 g
s
.72 .717 .846 r
.19217 .32695 m .19248 .32732 L .19699 .32948 L p F P
0 g
s
.652 .659 .843 r
.63786 .32573 m .63196 .32938 L p .62657 .32622 L F P
0 g
s
.643 .648 .84 r
.63196 .32938 m .63786 .32573 L .63883 .32746 L closepath p F P
0 g
s
.511 .378 .636 r
.66075 .36302 m .65994 .35803 L .65143 .36314 L p F P
0 g
s
.511 .378 .636 r
.65503 .36645 m .66075 .36302 L p .65143 .36314 L F P
0 g
s
.511 .378 .636 r
.65143 .36314 m .65167 .36459 L .65503 .36645 L p F P
0 g
s
.819 .69 .723 r
.17557 .34948 m .17592 .34896 L .17302 .34423 L p F P
0 g
s
.153 .685 .858 r
.4003 .35311 m .40605 .353 L .39822 .35276 L closepath p F P
0 g
s
.487 .749 .987 r
.27989 .33383 m .27568 .33402 L .28169 .33603 L p F P
0 g
s
.487 .749 .987 r
.28169 .33603 m .28285 .33594 L .27989 .33383 L p F P
0 g
s
.49 0 0 r
.34552 .46537 m .33948 .46322 L .34761 .46436 L p F P
0 g
s
.49 0 0 r
.34592 .46543 m .34552 .46537 L p .34761 .46436 L F P
0 g
s
.49 0 0 r
.34761 .46436 m .34873 .46475 L .34592 .46543 L p F P
0 g
s
.305 .697 .977 r
.30986 .34171 m .31132 .3418 L .30857 .34097 L closepath p F P
0 g
s
.558 .722 .95 r
.24378 .32891 m .24453 .32881 L .24247 .32771 L closepath p F P
0 g
s
.819 .69 .723 r
.17302 .34423 m .17122 .34683 L .17557 .34948 L p F P
0 g
s
.829 .682 .7 r
.16823 .35196 m .17265 .35458 L .17557 .34948 L p F P
0 g
s
.829 .682 .7 r
.17557 .34948 m .17122 .34683 L .16823 .35196 L p F P
0 g
s
.375 .831 .92 r
.47337 .34926 m .47409 .34911 L .47327 .34925 L closepath p F P
0 g
s
.41 .843 .947 r
.47337 .34926 m .47409 .34911 L .48415 .34743 L p F P
0 g
s
.791 .367 .242 r
.22879 .42489 m .23429 .42703 L .2321 .42368 L p F P
0 g
s
.791 .367 .242 r
.2321 .42368 m .22658 .42156 L .22879 .42489 L p F P
0 g
s
.362 .031 .262 r
.60654 .41691 m .60637 .41746 L .60986 .41548 L closepath p F P
0 g
s
.826 .452 .348 r
.20884 .41146 m .21405 .41372 L .21261 .41013 L p F P
0 g
s
.826 .452 .348 r
.21261 .41013 m .20738 .40789 L .20884 .41146 L p F P
0 g
s
.341 0 .201 r
.60458 .42264 m .60564 .41986 L .59628 .42363 L p F P
0 g
s
.341 0 .201 r
.59628 .42363 m .59521 .42641 L .60458 .42264 L p F P
0 g
s
.371 .829 .918 r
.47409 .34911 m .47327 .34925 L .47071 .34898 L p F P
0 g
s
.517 .375 .627 r
.65167 .36459 m .65503 .36645 L .65222 .36811 L closepath p F P
0 g
s
.172 .666 .917 r
.34897 .34842 m .34994 .34848 L .34837 .3482 L closepath p F P
0 g
s
.393 .837 .936 r
.48415 .34743 m .48292 .34724 L .47409 .34911 L closepath p F P
0 g
s
.371 .829 .918 r
.48037 .34709 m .48292 .34724 L .47409 .34911 L p F P
0 g
s
.371 .829 .918 r
.47964 .34721 m .48037 .34709 L p .47409 .34911 L F P
0 g
s
.371 .829 .918 r
.47071 .34898 m .47964 .34721 L p .47409 .34911 L F P
0 g
s
.553 .721 .952 r
.24985 .32516 m .25284 .32766 L .24453 .32881 L p F P
0 g
s
.553 .721 .952 r
.24079 .32618 m .24985 .32516 L p .24453 .32881 L F P
0 g
s
.553 .721 .952 r
.24453 .32881 m .24247 .32771 L .24079 .32618 L p F P
0 g
s
.856 .61 .566 r
.17631 .37784 m .18094 .38036 L .18149 .3761 L p F P
0 g
s
.856 .61 .566 r
.18149 .3761 m .17687 .37359 L .17631 .37784 L p F P
0 g
s
.858 .588 .528 r
.1808 .38446 m .18548 .38695 L .18561 .38284 L p F P
0 g
s
.858 .588 .528 r
.18561 .38284 m .18094 .38036 L .1808 .38446 L p F P
0 g
s
.619 .592 .801 r
.65186 .33174 m .65117 .33014 L .64129 .3323 L p F P
0 g
s
.631 .608 .808 r
.65117 .33014 m .64129 .3323 L .63883 .32746 L p F P
0 g
s
.137 .679 .824 r
.42324 .35298 m .42463 .35312 L p .41246 .35328 L F P
0 g
s
.137 .679 .824 r
.41246 .35328 m .41734 .35306 L .42324 .35298 L p F P
0 g
s
.16 .694 .847 r
.41246 .35328 m .41734 .35306 L .41091 .35308 L closepath p F P
0 g
s
.407 0 0 r
.40008 .46957 m .40134 .46979 L .39962 .46976 L closepath p F P
0 g
s
.251 .762 .851 r
.47071 .34898 m .46118 .35068 L .4585 .35043 L p F P
0 g
s
.383 .08 .322 r
.61647 .40978 m .61605 .41163 L .62313 .40673 L closepath p F P
0 g
s
.279 0 0 r
.48253 .46532 m .48271 .46521 L .47316 .46561 L p F P
0 g
s
.279 0 0 r
.47316 .46561 m .47134 .46672 L .48253 .46532 L p F P
0 g
s
.256 0 0 r
.48797 .46333 m .48496 .46378 L .48271 .46521 L p F P
0 g
s
.852 .631 .602 r
.17229 .37105 m .17687 .37359 L .1779 .36917 L p F P
0 g
s
.852 .631 .602 r
.1779 .36917 m .17334 .36662 L .17229 .37105 L p F P
0 g
s
.678 .736 .895 r
.60216 .32647 m .61192 .3229 L .61435 .32598 L p F P
0 g
s
.684 .762 .911 r
.61192 .3229 m .60216 .32647 L .59973 .32385 L p F P
0 g
s
.684 .772 .918 r
.58999 .32754 m .59973 .32385 L .60216 .32647 L p F P
0 g
s
.32 0 .14 r
.59445 .428 m .59521 .42641 L .58571 .42997 L p F P
0 g
s
.32 0 .14 r
.58571 .42997 m .58472 .43203 L .59445 .428 L p F P
0 g
s
.331 .705 .982 r
.29192 .33603 m .28285 .33594 L .27989 .33383 L p F P
0 g
s
.85 .553 .485 r
.18576 .39091 m .19066 .39331 L .19035 .38935 L p F P
0 g
s
.85 .553 .485 r
.18563 .38915 m .18576 .39091 L p .19035 .38935 L F P
0 g
s
.85 .553 .485 r
.19035 .38935 m .18644 .38744 L .18563 .38915 L p F P
0 g
s
.604 .898 .987 r
.53919 .33467 m .54133 .33545 L .53167 .33878 L p F P
0 g
s
.604 .898 .987 r
.53167 .33878 m .52941 .33796 L .53919 .33467 L p F P
0 g
s
.596 .889 .99 r
.52941 .33796 m .53167 .33878 L p .5195 .34097 L F P
0 g
s
.667 .698 .869 r
.61435 .32598 m .62413 .32262 L .62657 .32622 L p F P
0 g
s
.675 .724 .886 r
.62413 .32262 m .61435 .32598 L .61192 .3229 L p F P
0 g
s
.554 0 0 r
.30917 .45785 m .31642 .45931 L .31137 .45686 L p F P
0 g
s
.554 0 0 r
.30668 .45663 m .30917 .45785 L p .31137 .45686 L F P
0 g
s
.554 0 0 r
.31137 .45686 m .30854 .4563 L .30668 .45663 L p F P
0 g
s
.343 0 .149 r
.58446 .43258 m .58472 .43203 L .57501 .43556 L p F P
0 g
s
.343 0 .149 r
.57501 .43556 m .57482 .43594 L .58446 .43258 L p F P
0 g
s
.171 .705 .836 r
.43524 .3525 m .43681 .35263 L p .42463 .35312 L F P
0 g
s
.171 .705 .836 r
.42463 .35312 m .42971 .35273 L .43524 .3525 L p F P
0 g
s
.182 .711 .846 r
.42463 .35312 m .42971 .35273 L .42324 .35298 L closepath p F P
0 g
s
.286 0 0 r
.56196 .44372 m .56294 .44239 L .55324 .44503 L p F P
0 g
s
.286 0 0 r
.55324 .44503 m .55201 .44668 L .56196 .44372 L p F P
0 g
s
.262 .766 .873 r
.45832 .35043 m .4585 .35043 L .44899 .35181 L p F P
0 g
s
.262 .766 .873 r
.44899 .35181 m .44692 .35164 L .45832 .35043 L p F P
0 g
s
.687 .807 .939 r
.59752 .32174 m .59973 .32385 L .58999 .32754 L p F P
0 g
s
.687 .807 .939 r
.58999 .32754 m .5887 .32637 L .59752 .32174 L p F P
0 g
s
.468 0 0 r
.34873 .46475 m .35399 .4664 L .34592 .46543 L closepath p F P
0 g
s
.361 .028 .26 r
.60986 .41548 m .60637 .41746 L .60564 .41986 L p F P
0 g
s
.217 .736 .856 r
.43681 .35263 m .44354 .35189 L .43524 .3525 L closepath p F P
0 g
s
.291 .692 .974 r
.3175 .3415 m .31898 .3422 L .31132 .3418 L p F P
0 g
s
.291 .692 .974 r
.31407 .34067 m .3175 .3415 L p .31132 .3418 L F P
0 g
s
.291 .692 .974 r
.30692 .34003 m .31407 .34067 L p .31132 .3418 L F P
0 g
s
.291 .692 .974 r
.31132 .3418 m .30857 .34097 L .30692 .34003 L p F P
0 g
s
.752 .71 .813 r
.19204 .32704 m .18275 .33383 L .17977 .32999 L p F P
0 g
s
.779 .713 .791 r
.1815 .33499 m .18275 .33383 L .17977 .32999 L p F P
0 g
s
.756 .721 .819 r
.19248 .32732 m .19204 .32704 L .18275 .33383 L p F P
0 g
s
.779 .713 .791 r
.17977 .32999 m .17721 .3323 L .1815 .33499 L p F P
0 g
s
.791 .709 .774 r
.17099 .33863 m .17548 .34124 L .1815 .33499 L p F P
0 g
s
.791 .709 .774 r
.1815 .33499 m .17721 .3323 L .17099 .33863 L p F P
0 g
s
.847 .65 .637 r
.16882 .36405 m .17334 .36662 L .17492 .36201 L p F P
0 g
s
.847 .65 .637 r
.17492 .36201 m .17042 .35943 L .16882 .36405 L p F P
0 g
s
.156 .658 .909 r
.35747 .34883 m .35818 .34901 L .34994 .34848 L p F P
0 g
s
.156 .658 .909 r
.35133 .34791 m .35747 .34883 L p .34994 .34848 L F P
0 g
s
.156 .658 .909 r
.34607 .34737 m .35133 .34791 L p .34994 .34848 L F P
0 g
s
.156 .658 .909 r
.34994 .34848 m .34837 .3482 L .34607 .34737 L p F P
0 g
s
.675 .164 .016 r
.26707 .44413 m .27335 .44595 L .26969 .44307 L p F P
0 g
s
.675 .164 .016 r
.26487 .44239 m .26707 .44413 L p .26969 .44307 L F P
0 g
s
.675 .164 .016 r
.26969 .44307 m .26635 .44211 L .26487 .44239 L p F P
0 g
s
.258 0 0 r
.4959 .46211 m .49492 .46276 L .48797 .46333 L closepath p F P
0 g
s
.256 0 0 r
.49351 .46367 m .49492 .46276 L .48797 .46333 L p F P
0 g
s
.256 0 0 r
.48393 .46512 m .49351 .46367 L p .48797 .46333 L F P
0 g
s
.256 0 0 r
.48271 .46521 m .48393 .46512 L p .48797 .46333 L F P
0 g
s
.271 0 0 r
.5194 .45633 m .5193 .45642 L .51827 .45656 L closepath p F P
0 g
s
.273 0 0 r
.51729 .45813 m .5193 .45642 L .51827 .45656 L p F P
0 g
s
.273 0 0 r
.51138 .45931 m .51729 .45813 L p .51827 .45656 L F P
0 g
s
.273 0 0 r
.50712 .45987 m .51138 .45931 L p .51827 .45656 L F P
0 g
s
.719 .234 .091 r
.25145 .43737 m .25744 .43931 L .25428 .43627 L p F P
0 g
s
.719 .234 .091 r
.24999 .43596 m .25145 .43737 L p .25428 .43627 L F P
0 g
s
.719 .234 .091 r
.25428 .43627 m .25195 .43552 L .24999 .43596 L p F P
0 g
s
.849 .527 .444 r
.19134 .39714 m .19627 .39952 L .1956 .39569 L p F P
0 g
s
.849 .527 .444 r
.1956 .39569 m .19066 .39331 L .19134 .39714 L p F P
0 g
s
.815 .42 .304 r
.21581 .4172 m .21405 .41372 L .21931 .41594 L p F P
0 g
s
.815 .42 .304 r
.21973 .41887 m .21581 .4172 L p .21931 .41594 L F P
0 g
s
.815 .42 .304 r
.21931 .41594 m .22058 .41845 L .21973 .41887 L p F P
0 g
s
.389 0 0 r
.41223 .46996 m .41229 .46996 L .41222 .46996 L closepath p F P
0 g
s
.397 0 0 r
.41223 .46996 m .41229 .46996 L .42403 .46986 L p F P
0 g
s
.473 0 0 r
.33751 .46418 m .34552 .46537 L .33948 .46322 L p F P
0 g
s
.473 0 0 r
.33371 .46284 m .33751 .46418 L p .33948 .46322 L F P
0 g
s
.473 0 0 r
.33948 .46322 m .33506 .46259 L .33371 .46284 L p F P
0 g
s
.304 0 0 r
.46097 .46729 m .46607 .46727 L .45996 .46788 L closepath p F P
0 g
s
.315 0 0 r
.41229 .46996 m .41222 .46996 L .40942 .47088 L p F P
0 g
s
.347 0 0 r
.41222 .46996 m .40942 .47088 L .40134 .46979 L closepath p F P
0 g
s
.322 0 0 r
.42162 .47091 m .41229 .46996 L .42403 .46986 L p F P
0 g
s
.315 0 0 r
.42151 .47095 m .42162 .47091 L .41229 .46996 L p F P
0 g
s
.315 0 0 r
.41037 .47098 m .42151 .47095 L p .41229 .46996 L F P
0 g
s
.315 0 0 r
.40942 .47088 m .41037 .47098 L p .41229 .46996 L F P
0 g
s
.498 .734 .978 r
.25582 .33019 m .26488 .32953 L .26786 .33185 L p F P
0 g
s
.466 .729 .983 r
.26488 .32953 m .25582 .33019 L .25284 .32766 L p F P
0 g
s
.184 .676 .921 r
.34837 .3482 m .34607 .34737 L .34214 .34716 L closepath p F P
0 g
s
.325 0 0 r
.42452 .46986 m .42441 .4699 L .42403 .46986 L closepath p F P
0 g
s
.322 0 0 r
.42403 .46986 m .42441 .4699 L .42162 .47091 L p F P
0 g
s
.299 0 0 r
.43383 .47055 m .43657 .46947 L .42452 .46986 L p F P
0 g
s
.299 0 0 r
.42452 .46986 m .42441 .4699 L .43383 .47055 L p F P
0 g
s
.652 .659 .843 r
.62657 .32622 m .63638 .32319 L .63786 .32573 L p F P
0 g
s
.662 .684 .86 r
.63638 .32319 m .62657 .32622 L .62413 .32262 L p F P
0 g
s
.242 0 0 r
.52895 .45474 m .5298 .45399 L .5194 .45633 L p F P
0 g
s
.242 0 0 r
.5194 .45633 m .5193 .45642 L .52895 .45474 L p F P
0 g
s
.4 .124 .375 r
.6261 .40225 m .62571 .40468 L .63139 .39967 L closepath p F P
0 g
s
.585 .038 0 r
.30854 .4563 m .30668 .45663 L .30425 .45536 L closepath p F P
0 g
s
.333 0 0 r
.40911 .47098 m .40942 .47088 L .40134 .46979 L p F P
0 g
s
.333 0 0 r
.3995 .47078 m .40911 .47098 L p .40134 .46979 L F P
0 g
s
.333 0 0 r
.39724 .47046 m .3995 .47078 L p .40134 .46979 L F P
0 g
s
.333 0 0 r
.40134 .46979 m .39962 .46976 L .39724 .47046 L p F P
0 g
s
.685 .833 .955 r
.58755 .32533 m .57783 .32907 L .57537 .32725 L p F P
0 g
s
.678 .839 .96 r
.56567 .33097 m .57537 .32725 L .57783 .32907 L p F P
0 g
s
.365 0 0 r
.39962 .46976 m .39724 .47046 L .391 .46941 L closepath p F P
0 g
s
.455 .251 .513 r
.65307 .38107 m .65301 .37703 L .64433 .38187 L p F P
0 g
s
.455 .251 .513 r
.64433 .38187 m .64438 .3859 L .65307 .38107 L p F P
0 g
s
.29 0 .06 r
.58304 .43498 m .58446 .43258 L .57482 .43594 L p F P
0 g
s
.29 0 .06 r
.57482 .43594 m .57338 .43834 L .58304 .43498 L p F P
0 g
s
.622 .086 0 r
.2839 .45046 m .29048 .45217 L .2863 .44944 L p F P
0 g
s
.622 .086 0 r
.27979 .44784 m .2839 .45046 L p .2863 .44944 L F P
0 g
s
.622 .086 0 r
.2863 .44944 m .2799 .44782 L .27979 .44784 L p F P
0 g
s
.256 0 0 r
.55081 .44802 m .55201 .44668 L .54192 .44943 L p F P
0 g
s
.256 0 0 r
.54192 .44943 m .54112 .45031 L .55081 .44802 L p F P
0 g
s
.622 .093 0 r
.29475 .45226 m .2973 .45379 L .29269 .45273 L closepath p F P
0 g
s
.802 .693 .745 r
.17009 .33968 m .17099 .33863 L .17548 .34124 L p F P
0 g
s
.802 .693 .745 r
.17548 .34124 m .17302 .34423 L .17009 .33968 L p F P
0 g
s
.608 .74 .939 r
.24247 .32771 m .24079 .32618 L .23921 .32653 L closepath p F P
0 g
s
.756 .296 .156 r
.23691 .43023 m .24263 .43228 L .23996 .42909 L p F P
0 g
s
.756 .296 .156 r
.23521 .4282 m .23691 .43023 L p .23996 .42909 L F P
0 g
s
.756 .296 .156 r
.23996 .42909 m .2365 .42786 L .23521 .4282 L p F P
0 g
s
.311 0 0 r
.43383 .47055 m .42441 .4699 L .42162 .47091 L p F P
0 g
s
.327 0 0 r
.44878 .46858 m .45055 .46864 L .44838 .4688 L closepath p F P
0 g
s
.242 0 0 r
.52773 .45581 m .52895 .45474 L .5193 .45642 L p F P
0 g
s
.242 0 0 r
.5193 .45642 m .51729 .45813 L .52773 .45581 L p F P
0 g
s
.361 .028 .26 r
.61487 .41588 m .61576 .41293 L .60986 .41548 L p F P
0 g
s
.361 .028 .26 r
.60564 .41986 m .61487 .41588 L p .60986 .41548 L F P
0 g
s
.398 .092 .326 r
.61605 .41163 m .60986 .41548 L .61576 .41293 L closepath p F P
0 g
s
.13 .629 .907 r
.32761 .3441 m .32191 .34365 L .31898 .3422 L p F P
0 g
s
.596 .889 .99 r
.5195 .34097 m .52165 .34028 L .52941 .33796 L p F P
0 g
s
.556 .9 .978 r
.5195 .34097 m .52165 .34028 L .51943 .34096 L closepath p F P
0 g
s
.679 .734 .892 r
.20443 .32543 m .21361 .32183 L .21661 .32494 L p F P
0 g
s
.671 .734 .898 r
.21361 .32183 m .20443 .32543 L .20143 .32214 L p F P
0 g
s
.72 .717 .846 r
.20443 .32543 m .20143 .32214 L .19217 .32695 L p F P
0 g
s
.495 .335 .593 r
.65777 .36976 m .65273 .37272 L .65222 .36811 L p F P
0 g
s
.495 .335 .593 r
.65222 .36811 m .65503 .36645 L .65777 .36976 L p F P
0 g
s
.839 .668 .67 r
.16597 .35682 m .17042 .35943 L .17265 .35458 L p F P
0 g
s
.839 .668 .67 r
.17265 .35458 m .16823 .35196 L .16597 .35682 L p F P
0 g
s
.349 0 0 r
.43659 .46946 m .43665 .46947 L .43657 .46947 L closepath p F P
0 g
s
.845 .499 .4 r
.19728 .40324 m .20225 .4056 L .20124 .40187 L p F P
0 g
s
.845 .499 .4 r
.20124 .40187 m .19627 .39952 L .19728 .40324 L p F P
0 g
s
.275 0 0 r
.43665 .46947 m .43657 .46947 L .43383 .47055 L p F P
0 g
s
0 .565 .784 r
.36775 .35028 m .36106 .34986 L .35818 .34901 L p F P
0 g
s
.284 0 0 r
.44838 .4688 m .44605 .46978 L .43665 .46947 L closepath p F P
0 g
s
.275 0 0 r
.44553 .47 m .44605 .46978 L .43665 .46947 L p F P
0 g
s
.275 0 0 r
.43454 .47057 m .44553 .47 L p .43665 .46947 L F P
0 g
s
.275 0 0 r
.43383 .47055 m .43454 .47057 L p .43665 .46947 L F P
0 g
s
.353 .725 .987 r
.30857 .34097 m .30692 .34003 L .30479 .34 L closepath p F P
0 g
s
.349 0 0 r
.39641 .4707 m .39724 .47046 L .391 .46941 L p F P
0 g
s
.349 0 0 r
.38922 .47037 m .39641 .4707 L p .391 .46941 L F P
0 g
s
.349 0 0 r
.38507 .46966 m .38922 .47037 L p .391 .46941 L F P
0 g
s
.349 0 0 r
.391 .46941 m .38673 .46923 L .38507 .46966 L p F P
0 g
s
.639 .736 .919 r
.21661 .32494 m .22572 .32232 L .22872 .32524 L p F P
0 g
s
.628 .735 .924 r
.22572 .32232 m .21661 .32494 L .21361 .32183 L p F P
0 g
s
.555 .9 .978 r
.52165 .34028 m .51943 .34096 L .51694 .34033 L p F P
0 g
s
.44 .212 .469 r
.64422 .38968 m .63686 .39355 L .63988 .38827 L p F P
0 g
s
.44 .212 .469 r
.63988 .38827 m .64438 .3859 L .64422 .38968 L p F P
0 g
s
.506 0 0 r
.33506 .46259 m .33371 .46284 L .33155 .46201 L closepath p F P
0 g
s
.739 .264 .118 r
.25195 .43552 m .24999 .43596 L .24839 .4343 L closepath p F P
0 g
s
.746 .723 .83 r
.19217 .32695 m .19204 .32704 L .19248 .32732 L closepath p F P
0 g
s
.552 .003 0 r
.32169 .45972 m .32388 .4607 L .32025 .46007 L closepath p F P
0 g
s
.43 .717 .985 r
.26786 .33185 m .27012 .33184 L .27568 .33402 L p F P
0 g
s
.456 .739 .989 r
.27691 .33176 m .27012 .33184 L .27568 .33402 L p F P
0 g
s
.456 .739 .989 r
.27568 .33402 m .27989 .33383 L .27691 .33176 L p F P
0 g
s
.382 0 0 r
.38673 .46923 m .38507 .46966 L .38114 .46887 L closepath p F P
0 g
s
.818 .694 .728 r
.17122 .34683 m .17302 .34423 L .17009 .33968 L p F P
0 g
s
.698 .197 .047 r
.26635 .44211 m .26487 .44239 L .26348 .44122 L closepath p F P
0 g
s
.419 .851 .942 r
.49251 .34501 m .49474 .34524 L .48415 .34743 L p F P
0 g
s
.419 .851 .942 r
.48415 .34743 m .48292 .34724 L .49251 .34501 L p F P
0 g
s
.674 .861 .97 r
.57537 .32725 m .56567 .33097 L .56319 .32945 L p F P
0 g
s
.743 .725 .835 r
.19204 .32704 m .19217 .32695 L .18917 .32346 L p F P
0 g
s
.743 .725 .835 r
.18917 .32346 m .18788 .32429 L .19204 .32704 L p F P
0 g
s
.752 .71 .813 r
.17977 .32999 m .18788 .32429 L .19204 .32704 L p F P
0 g
s
.709 .732 .869 r
.20143 .32214 m .19217 .32695 L .18917 .32346 L p F P
0 g
s
.299 .697 .976 r
.29488 .33792 m .29843 .33813 L .30479 .34 L p F P
0 g
s
.268 .672 .968 r
.29843 .33813 m .29488 .33792 L .29192 .33603 L p F P
0 g
s
.791 .362 .231 r
.22334 .42274 m .22879 .42489 L .22658 .42156 L p F P
0 g
s
.791 .362 .231 r
.22658 .42156 m .2211 .41942 L .22334 .42274 L p F P
0 g
s
.131 .638 .901 r
.33398 .34554 m .33488 .34563 L .34214 .34716 L p F P
0 g
s
.165 .669 .908 r
.34316 .3464 m .33488 .34563 L .34214 .34716 L p F P
0 g
s
.165 .669 .908 r
.34214 .34716 m .34607 .34737 L .34316 .3464 L p F P
0 g
s
.584 .037 0 r
.30208 .45633 m .2973 .45379 L .30425 .45536 L p F P
0 g
s
.584 .037 0 r
.30484 .45696 m .30208 .45633 L p .30425 .45536 L F P
0 g
s
.584 .037 0 r
.30425 .45536 m .30668 .45663 L .30484 .45696 L p F P
0 g
s
.231 0 0 r
.50454 .46169 m .50668 .46023 L .4959 .46211 L p F P
0 g
s
.231 0 0 r
.4959 .46211 m .49492 .46276 L .50454 .46169 L p F P
0 g
s
.364 0 0 r
.3834 .47008 m .38507 .46966 L .38114 .46887 L p F P
0 g
s
.364 0 0 r
.3794 .4698 m .3834 .47008 L p .38114 .46887 L F P
0 g
s
.364 0 0 r
.37293 .46849 m .3794 .4698 L p .38114 .46887 L F P
0 g
s
.364 0 0 r
.38114 .46887 m .37351 .46836 L .37293 .46849 L p F P
0 g
s
.591 .735 .943 r
.22872 .32524 m .23387 .32425 L .23921 .32653 L p F P
0 g
s
.577 .727 .945 r
.23387 .32425 m .22872 .32524 L .22572 .32232 L p F P
0 g
s
.253 0 0 r
.45055 .46864 m .44838 .4688 L .44605 .46978 L p F P
0 g
s
.505 0 0 r
.3296 .46294 m .32388 .4607 L .33155 .46201 L p F P
0 g
s
.505 0 0 r
.33143 .46326 m .3296 .46294 L p .33155 .46201 L F P
0 g
s
.505 0 0 r
.33155 .46201 m .33371 .46284 L .33143 .46326 L p F P
0 g
s
.586 .892 .989 r
.52941 .33796 m .52914 .33786 L .52165 .34028 L closepath p F P
0 g
s
.555 .9 .978 r
.5266 .33725 m .52914 .33786 L .52165 .34028 L p F P
0 g
s
.555 .9 .978 r
.51694 .34033 m .5266 .33725 L p .52165 .34028 L F P
0 g
s
.827 .448 .337 r
.20366 .40919 m .20884 .41146 L .20738 .40789 L p F P
0 g
s
.827 .448 .337 r
.20284 .40715 m .20366 .40919 L p .20738 .40789 L F P
0 g
s
.827 .448 .337 r
.20738 .40789 m .20408 .40645 L .20284 .40715 L p F P
0 g
s
.631 .608 .808 r
.63883 .32746 m .64869 .32496 L .65117 .33014 L p F P
0 g
s
.635 .644 .842 r
.63786 .32573 m .63883 .32746 L .64869 .32496 L p F P
0 g
s
.414 .163 .421 r
.63541 .3943 m .6353 .39543 L .63686 .39355 L closepath p F P
0 g
s
.455 0 0 r
.36081 .46685 m .36265 .46736 L .35992 .4671 L closepath p F P
0 g
s
.261 0 0 r
.45996 .46788 m .45827 .46864 L .45055 .46864 L closepath p F P
0 g
s
.253 0 0 r
.45718 .46912 m .45827 .46864 L .45055 .46864 L p F P
0 g
s
.253 0 0 r
.44831 .4698 m .45718 .46912 L p .45055 .46864 L F P
0 g
s
.253 0 0 r
.44605 .46978 m .44831 .4698 L p .45055 .46864 L F P
0 g
s
.497 .886 .961 r
.51536 .34008 m .51694 .34033 L .50732 .34319 L p F P
0 g
s
.497 .886 .961 r
.50732 .34319 m .50514 .34279 L .51536 .34008 L p F P
0 g
s
.484 .876 .966 r
.50514 .34279 m .50732 .34319 L p .49512 .34528 L F P
0 g
s
.858 .563 .488 r
.18644 .38744 m .18563 .38915 L .18548 .38695 L closepath p F P
0 g
s
.818 .694 .728 r
.17009 .33968 m .1669 .34416 L .17122 .34683 L p F P
0 g
s
.83 .685 .702 r
.16386 .34931 m .16823 .35196 L .17122 .34683 L p F P
0 g
s
.83 .685 .702 r
.17122 .34683 m .1669 .34416 L .16386 .34931 L p F P
0 g
s
.607 .743 .941 r
.2378 .32347 m .23387 .32425 L .23921 .32653 L p F P
0 g
s
.607 .743 .941 r
.23921 .32653 m .24079 .32618 L .2378 .32347 L p F P
0 g
s
.262 0 0 r
.57266 .43933 m .57338 .43834 L .56359 .44151 L p F P
0 g
s
.262 0 0 r
.56359 .44151 m .56294 .44239 L .57266 .43933 L p F P
0 g
s
.381 .077 .32 r
.62313 .40673 m .61605 .41163 L .61576 .41293 L p F P
0 g
s
.404 .7 .982 r
.27012 .33184 m .26786 .33185 L .26488 .32953 L p F P
0 g
s
.343 .725 .985 r
.30397 .33841 m .29843 .33813 L .30479 .34 L p F P
0 g
s
.343 .725 .985 r
.30479 .34 m .30692 .34003 L .30397 .33841 L p F P
0 g
s
.663 .868 .976 r
.5537 .33322 m .5535 .3331 L .5595 .33084 L closepath p F P
0 g
s
.569 .49 .726 r
.65624 .34344 m .66222 .34341 L .65721 .34661 L closepath p F P
0 g
s
.568 .505 .744 r
.65502 .33982 m .65624 .34344 L .66222 .34341 L p F P
0 g
s
.773 .323 .18 r
.2365 .42786 m .23521 .4282 L .23429 .42703 L closepath p F P
0 g
s
.687 .808 .939 r
.59729 .32152 m .59752 .32174 L .5887 .32637 L p F P
0 g
s
.687 .808 .939 r
.5887 .32637 m .58755 .32533 L .59729 .32152 L p F P
0 g
s
.555 .463 .705 r
.66716 .34724 m .65881 .35263 L .65721 .34661 L p F P
0 g
s
.555 .463 .705 r
.66626 .34371 m .66716 .34724 L p .65721 .34661 L F P
0 g
s
.555 .463 .705 r
.65721 .34661 m .66222 .34341 L .66626 .34371 L p F P
0 g
s
.398 0 0 r
.37351 .46836 m .37293 .46849 L .37166 .4682 L closepath p F P
0 g
s
.026 .593 .782 r
.3851 .35196 m .38533 .352 L p .37319 .35107 L F P
0 g
s
.026 .593 .782 r
.37319 .35107 m .37652 .35125 L .3851 .35196 L p F P
0 g
s
.086 .63 .843 r
.37319 .35107 m .37652 .35125 L .37157 .3507 L closepath p F P
0 g
s
.591 .536 .761 r
.65368 .33618 m .66207 .33527 L .65502 .33982 L closepath p F P
0 g
s
.568 .505 .744 r
.66364 .33516 m .66207 .33527 L .65502 .33982 L p F P
0 g
s
.568 .505 .744 r
.66557 .34122 m .66364 .33516 L p .65502 .33982 L F P
0 g
s
.568 .505 .744 r
.66222 .34341 m .66557 .34122 L p .65502 .33982 L F P
0 g
s
.861 .59 .528 r
.17616 .38195 m .1808 .38446 L .18094 .38036 L p F P
0 g
s
.861 .59 .528 r
.18094 .38036 m .17631 .37784 L .17616 .38195 L p F P
0 g
s
.859 .613 .566 r
.17172 .37531 m .17631 .37784 L .17687 .37359 L p F P
0 g
s
.859 .613 .566 r
.17687 .37359 m .17229 .37105 L .17172 .37531 L p F P
0 g
s
.698 .196 .045 r
.26089 .44226 m .25744 .43931 L .26348 .44122 L p F P
0 g
s
.698 .196 .045 r
.26261 .44281 m .26089 .44226 L p .26348 .44122 L F P
0 g
s
.698 .196 .045 r
.26348 .44122 m .26487 .44239 L .26261 .44281 L p F P
0 g
s
.397 0 0 r
.36995 .46911 m .36265 .46736 L .37166 .4682 L p F P
0 g
s
.397 0 0 r
.37006 .46912 m .36995 .46911 L p .37166 .4682 L F P
0 g
s
.397 0 0 r
.37166 .4682 m .37293 .46849 L .37006 .46912 L p F P
0 g
s
.647 .891 .984 r
.5595 .33084 m .5535 .3331 L .55101 .33194 L p F P
0 g
s
.638 .888 .986 r
.54133 .33545 m .55101 .33194 L .5535 .3331 L p F P
0 g
s
.859 .564 .488 r
.18105 .38844 m .1808 .38446 L .18548 .38695 L p F P
0 g
s
.859 .564 .488 r
.18496 .39052 m .18105 .38844 L p .18548 .38695 L F P
0 g
s
.859 .564 .488 r
.18548 .38695 m .18563 .38915 L .18496 .39052 L p F P
0 g
s
.739 .264 .116 r
.2456 .43538 m .24263 .43228 L .24839 .4343 L p F P
0 g
s
.739 .264 .116 r
.24829 .43633 m .2456 .43538 L p .24839 .4343 L F P
0 g
s
.739 .264 .116 r
.24839 .4343 m .24999 .43596 L .24829 .43633 L p F P
0 g
s
.649 .122 0 r
.2799 .44782 m .27979 .44784 L .27967 .44775 L closepath p F P
0 g
s
.854 .634 .603 r
.16776 .36848 m .17229 .37105 L .17334 .36662 L p F P
0 g
s
.854 .634 .603 r
.17334 .36662 m .16882 .36405 L .16776 .36848 L p F P
0 g
s
.15 .687 .839 r
.41734 .35306 m .41091 .35308 L .40967 .35294 L p F P
0 g
s
.113 .661 .821 r
.41091 .35308 m .40967 .35294 L .40605 .353 L closepath p F P
0 g
s
.129 .674 .817 r
.42324 .35298 m .42187 .35286 L .41734 .35306 L closepath p F P
0 g
s
.15 .687 .839 r
.4194 .35281 m .42187 .35286 L .41734 .35306 L p F P
0 g
s
.15 .687 .839 r
.41808 .35282 m .4194 .35281 L p .41734 .35306 L F P
0 g
s
.15 .687 .839 r
.40967 .35294 m .41808 .35282 L p .41734 .35306 L F P
0 g
s
.648 .119 0 r
.27667 .44829 m .27335 .44595 L .27967 .44775 L p F P
0 g
s
.648 .119 0 r
.27967 .44775 m .27979 .44784 L .27667 .44829 L p F P
0 g
s
.273 0 0 r
.50712 .45987 m .51138 .45931 L .50668 .46023 L closepath p F P
0 g
s
.157 .648 .918 r
.33398 .34554 m .33488 .34563 L .33334 .34528 L closepath p F P
0 g
s
.141 .677 .849 r
.40692 .35278 m .40967 .35294 L .40605 .353 L p F P
0 g
s
.141 .677 .849 r
.40671 .35277 m .40692 .35278 L p .40605 .353 L F P
0 g
s
.141 .677 .849 r
.39749 .35264 m .40671 .35277 L p .40605 .353 L F P
0 g
s
.141 .677 .849 r
.40605 .353 m .39822 .35276 L .39749 .35264 L p F P
0 g
s
.173 .705 .839 r
.42971 .35273 m .42324 .35298 L .42187 .35286 L p F P
0 g
s
.413 .161 .42 r
.64388 .39324 m .64422 .38968 L .63686 .39355 L p F P
0 g
s
.413 .161 .42 r
.63506 .39786 m .64388 .39324 L p .63686 .39355 L F P
0 g
s
.413 .161 .42 r
.63686 .39355 m .6353 .39543 L .63506 .39786 L p F P
0 g
s
.542 .43 .675 r
.65829 .35294 m .65881 .35263 L .6589 .35305 L closepath p F P
0 g
s
.591 .555 .782 r
.65186 .33174 m .65368 .33618 L .66207 .33527 L p F P
0 g
s
.492 .334 .594 r
.66129 .36765 m .65777 .36976 L .65503 .36645 L p F P
0 g
s
.492 .334 .594 r
.65503 .36645 m .66075 .36302 L .66129 .36765 L p F P
0 g
s
.637 .108 0 r
.2839 .45046 m .27979 .44784 L .27667 .44829 L p F P
0 g
s
.23 0 0 r
.46607 .46727 m .45996 .46788 L .45827 .46864 L p F P
0 g
s
.518 .729 .97 r
.24985 .32516 m .24079 .32618 L .2378 .32347 L p F P
0 g
s
.818 .418 .293 r
.21061 .41494 m .21581 .4172 L .21405 .41372 L p F P
0 g
s
.818 .418 .293 r
.21405 .41372 m .20884 .41146 L .21061 .41494 L p F P
0 g
s
.646 .656 .845 r
.63638 .32319 m .63786 .32573 L .64631 .32048 L p F P
0 g
s
.635 .644 .842 r
.64869 .32496 m .64631 .32048 L .63786 .32573 L p F P
0 g
s
.115 .659 .836 r
.39822 .35276 m .39749 .35264 L .3956 .35264 L closepath p F P
0 g
s
.484 .876 .966 r
.49512 .34528 m .50003 .34397 L .50514 .34279 L p F P
0 g
s
.434 .864 .932 r
.49512 .34528 m .50003 .34397 L .49474 .34524 L closepath p F P
0 g
s
.16 .697 .826 r
.43524 .3525 m .43407 .35241 L .42971 .35273 L closepath p F P
0 g
s
.173 .705 .839 r
.43151 .35242 m .43407 .35241 L .42971 .35273 L p F P
0 g
s
.173 .705 .839 r
.43061 .35245 m .43151 .35242 L p .42971 .35273 L F P
0 g
s
.173 .705 .839 r
.42187 .35286 m .43061 .35245 L p .42971 .35273 L F P
0 g
s
.851 .528 .44 r
.18645 .39474 m .19134 .39714 L .19066 .39331 L p F P
0 g
s
.851 .528 .44 r
.19066 .39331 m .18576 .39091 L .18645 .39474 L p F P
0 g
s
.426 .172 .423 r
.6353 .39543 m .63139 .39967 L .63506 .39786 L closepath p F P
0 g
s
.808 .408 .294 r
.22058 .41845 m .2211 .41942 L .21973 .41887 L closepath p F P
0 g
s
.848 .653 .638 r
.16434 .36145 m .16882 .36405 L .17042 .35943 L p F P
0 g
s
.848 .653 .638 r
.17042 .35943 m .16597 .35682 L .16434 .36145 L p F P
0 g
s
.254 0 0 r
.55018 .44871 m .55081 .44802 L .54112 .45031 L p F P
0 g
s
.254 0 0 r
.54112 .45031 m .54006 .45146 L .55018 .44871 L p F P
0 g
s
.033 .6 .777 r
.38533 .352 m .38586 .35202 L .3956 .35264 L p F P
0 g
s
.07 .629 .789 r
.39466 .35236 m .38586 .35202 L .3956 .35264 L p F P
0 g
s
.07 .629 .789 r
.3956 .35264 m .39749 .35264 L .39466 .35236 L p F P
0 g
s
.525 .418 .676 r
.66834 .35269 m .66716 .34724 L .65881 .35263 L p F P
0 g
s
.525 .418 .676 r
.66493 .35488 m .66834 .35269 L p .65881 .35263 L F P
0 g
s
.525 .418 .676 r
.65881 .35263 m .6589 .35305 L .66493 .35488 L p F P
0 g
s
.413 .134 .378 r
.62571 .40468 m .62313 .40673 L .62557 .40561 L closepath p F P
0 g
s
.381 .077 .32 r
.62485 .40874 m .62557 .40561 L .62313 .40673 L p F P
0 g
s
.381 .077 .32 r
.61576 .41293 m .62485 .40874 L p .62313 .40673 L F P
0 g
s
.789 .711 .778 r
.16833 .33706 m .17099 .33863 L .17721 .3323 L p F P
0 g
s
.789 .711 .778 r
.16714 .33535 m .16833 .33706 L p .17721 .3323 L F P
0 g
s
.789 .711 .778 r
.17721 .3323 m .17294 .32959 L .16714 .33535 L p F P
0 g
s
.776 .715 .795 r
.17721 .3323 m .17977 .32999 L .17677 .32624 L p F P
0 g
s
.776 .715 .795 r
.17677 .32624 m .17294 .32959 L .17721 .3323 L p F P
0 g
s
.773 .322 .178 r
.23129 .42814 m .22879 .42489 L .23429 .42703 L p F P
0 g
s
.773 .322 .178 r
.23292 .42877 m .23129 .42814 L p .23429 .42703 L F P
0 g
s
.773 .322 .178 r
.23429 .42703 m .23521 .4282 L .23292 .42877 L p F P
0 g
s
.748 .713 .819 r
.18788 .32429 m .17977 .32999 L .17677 .32624 L p F P
0 g
s
.529 .412 .663 r
.6589 .35305 m .66493 .35488 L .65994 .35803 L closepath p F P
0 g
s
.209 .732 .849 r
.44354 .35189 m .43524 .3525 L .43407 .35241 L p F P
0 g
s
.218 0 0 r
.53863 .45274 m .54006 .45146 L .5298 .45399 L p F P
0 g
s
.218 0 0 r
.5298 .45399 m .52895 .45474 L .53863 .45274 L p F P
0 g
s
.484 0 0 r
.32204 .46159 m .3296 .46294 L .32388 .4607 L p F P
0 g
s
.484 0 0 r
.31867 .46027 m .32204 .46159 L p .32388 .4607 L F P
0 g
s
.484 0 0 r
.32388 .4607 m .32025 .46007 L .31867 .46027 L p F P
0 g
s
.47 .29 .554 r
.65867 .3737 m .65301 .37703 L .65273 .37272 L p F P
0 g
s
.47 .29 .554 r
.65273 .37272 m .65777 .36976 L .65867 .3737 L p F P
0 g
s
.398 .122 .373 r
.63139 .39967 m .62571 .40468 L .62557 .40561 L p F P
0 g
s
.14 .639 .909 r
.34275 .34628 m .34316 .3464 L .33488 .34563 L p F P
0 g
s
.14 .639 .909 r
.33623 .34505 m .34275 .34628 L p .33488 .34563 L F P
0 g
s
.14 .639 .909 r
.33106 .34436 m .33623 .34505 L p .33488 .34563 L F P
0 g
s
.14 .639 .909 r
.33488 .34563 m .33334 .34528 L .33106 .34436 L p F P
0 g
s
.06 .618 .806 r
.38533 .352 m .38586 .35202 L .3851 .35196 L closepath p F P
0 g
s
.682 .75 .902 r
.6217 .31937 m .61192 .3229 L .60949 .32014 L p F P
0 g
s
.684 .762 .911 r
.59973 .32385 m .60949 .32014 L .61192 .3229 L p F P
0 g
s
.675 .724 .886 r
.61192 .3229 m .6217 .31937 L .62413 .32262 L p F P
0 g
s
.379 0 0 r
.36107 .46822 m .36995 .46911 L .36265 .46736 L p F P
0 g
s
.379 0 0 r
.35788 .46745 m .36107 .46822 L p .36265 .46736 L F P
0 g
s
.379 0 0 r
.36265 .46736 m .35992 .4671 L .35788 .46745 L p F P
0 g
s
.837 .465 .35 r
.20408 .40645 m .20284 .40715 L .20225 .4056 L closepath p F P
0 g
s
.398 .122 .373 r
.63452 .4012 m .63506 .39786 L .63139 .39967 L p F P
0 g
s
.398 .122 .373 r
.62557 .40561 m .63452 .4012 L p .63139 .39967 L F P
0 g
s
.372 0 0 r
.37293 .46849 m .3794 .4698 L .37006 .46912 L closepath p F P
0 g
s
.563 .004 0 r
.29523 .45471 m .30208 .45633 L .2973 .45379 L p F P
0 g
s
.563 .004 0 r
.29167 .45284 m .29523 .45471 L p .2973 .45379 L F P
0 g
s
.563 .004 0 r
.2973 .45379 m .29269 .45273 L .29167 .45284 L p F P
0 g
s
.318 0 .137 r
.59397 .429 m .59445 .428 L .58472 .43203 L p F P
0 g
s
.318 0 .137 r
.58472 .43203 m .58446 .43258 L .59397 .429 L p F P
0 g
s
.236 0 0 r
.47134 .46672 m .4705 .46712 L .46607 .46727 L closepath p F P
0 g
s
.23 0 0 r
.46863 .468 m .4705 .46712 L .46607 .46727 L p F P
0 g
s
.23 0 0 r
.46367 .4685 m .46863 .468 L p .46607 .46727 L F P
0 g
s
.23 0 0 r
.45827 .46864 m .46367 .4685 L p .46607 .46727 L F P
0 g
s
.141 .629 .917 r
.31407 .34067 m .30692 .34003 L .30397 .33841 L p F P
0 g
s
.319 0 .194 r
.61393 .41839 m .61487 .41588 L .60564 .41986 L p F P
0 g
s
.319 0 .194 r
.61192 .41949 m .61393 .41839 L p .60564 .41986 L F P
0 g
s
.319 0 .194 r
.60564 .41986 m .60458 .42264 L .61192 .41949 L p F P
0 g
s
.689 .798 .932 r
.60706 .31767 m .60949 .32014 L .59973 .32385 L p F P
0 g
s
.689 .798 .932 r
.59925 .32074 m .60706 .31767 L p .59973 .32385 L F P
0 g
s
.689 .798 .932 r
.59973 .32385 m .59752 .32174 L .59925 .32074 L p F P
0 g
s
.801 .698 .752 r
.17099 .33863 m .16833 .33706 L .17009 .33968 L closepath p F P
0 g
s
.847 .499 .396 r
.19236 .40086 m .19728 .40324 L .19627 .39952 L p F P
0 g
s
.847 .499 .396 r
.19627 .39952 m .19134 .39714 L .19236 .40086 L p F P
0 g
s
.423 .726 .989 r
.27392 .3297 m .2649 .32953 L .27012 .33184 L p F P
0 g
s
.423 .726 .989 r
.27012 .33184 m .27691 .33176 L .27392 .3297 L p F P
0 g
s
.404 .7 .982 r
.26488 .32953 m .2649 .32953 L .27012 .33184 L p F P
0 g
s
.618 .903 .985 r
.54877 .3311 m .55101 .33194 L .54133 .33545 L p F P
0 g
s
.618 .903 .985 r
.54133 .33545 m .53919 .33467 L .54877 .3311 L p F P
0 g
s
.662 .684 .86 r
.62413 .32262 m .63395 .31936 L .63638 .32319 L p F P
0 g
s
.671 .71 .877 r
.63395 .31936 m .62413 .32262 L .6217 .31937 L p F P
0 g
s
.426 .2 .466 r
.65293 .38486 m .65307 .38107 L .64438 .3859 L p F P
0 g
s
.426 .2 .466 r
.64438 .3859 m .64422 .38968 L .65293 .38486 L p F P
0 g
s
.185 .668 .928 r
.33334 .34528 m .33106 .34436 L .32761 .3441 L closepath p F P
0 g
s
.591 .555 .782 r
.6611 .32847 m .65553 .32935 L .65186 .33174 L p F P
0 g
s
.591 .555 .782 r
.66337 .3344 m .6611 .32847 L p .65186 .33174 L F P
0 g
s
.591 .555 .782 r
.66207 .33527 m .66337 .3344 L p .65186 .33174 L F P
0 g
s
.611 .578 .793 r
.65117 .33014 m .65553 .32935 L .65186 .33174 L closepath p F P
0 g
s
.415 0 0 r
.35992 .4671 m .35788 .46745 L .35399 .4664 L closepath p F P
0 g
s
.482 0 0 r
.33371 .46284 m .33751 .46418 L .33143 .46326 L closepath p F P
0 g
s
.338 .008 .251 r
.62398 .4117 m .62485 .40874 L .61576 .41293 L p F P
0 g
s
.338 .008 .251 r
.61576 .41293 m .61487 .41588 L .62398 .4117 L p F P
0 g
s
.046 .608 .795 r
.39409 .35234 m .39466 .35236 L .38586 .35202 L p F P
0 g
s
.046 .608 .795 r
.38626 .35186 m .39409 .35234 L p .38586 .35202 L F P
0 g
s
.046 .608 .795 r
.38248 .35157 m .38626 .35186 L p .38586 .35202 L F P
0 g
s
.046 .608 .795 r
.38586 .35202 m .3851 .35196 L .38248 .35157 L p F P
0 g
s
.431 .863 .93 r
.50003 .34397 m .49474 .34524 L .49251 .34501 L p F P
0 g
s
.819 .699 .733 r
.1669 .34416 m .17009 .33968 L .16833 .33706 L p F P
0 g
s
.031 .597 .786 r
.3851 .35196 m .38248 .35157 L .37652 .35125 L closepath p F P
0 g
s
.84 .671 .672 r
.16156 .35419 m .16597 .35682 L .16823 .35196 L p F P
0 g
s
.84 .671 .672 r
.16823 .35196 m .16386 .34931 L .16156 .35419 L p F P
0 g
s
.295 0 .126 r
.60419 .42346 m .60458 .42264 L .59521 .42641 L p F P
0 g
s
.295 0 .126 r
.59521 .42641 m .59445 .428 L .60419 .42346 L p F P
0 g
s
.204 0 0 r
.51138 .45931 m .50668 .46023 L .50454 .46169 L p F P
0 g
s
.354 .824 .897 r
.49109 .345 m .49251 .34501 L .48292 .34724 L p F P
0 g
s
.354 .824 .897 r
.48292 .34724 m .48037 .34709 L .49109 .345 L p F P
0 g
s
.23 0 0 r
.56053 .44534 m .56196 .44372 L .55201 .44668 L p F P
0 g
s
.23 0 0 r
.55201 .44668 m .55081 .44802 L .56053 .44534 L p F P
0 g
s
.205 .729 .846 r
.44692 .35164 m .44628 .35159 L .44354 .35189 L closepath p F P
0 g
s
.209 .732 .849 r
.44356 .35163 m .44628 .35159 L .44354 .35189 L p F P
0 g
s
.209 .732 .849 r
.43407 .35241 m .44356 .35163 L p .44354 .35189 L F P
0 g
s
.331 .705 .982 r
.29129 .33564 m .29192 .33603 L p .27989 .33383 L F P
0 g
s
.331 .705 .982 r
.27989 .33383 m .28637 .33412 L .29129 .33564 L p F P
0 g
s
.299 .683 .975 r
.28637 .33412 m .27989 .33383 L .27691 .33176 L p F P
0 g
s
.519 0 0 r
.32025 .46007 m .31867 .46027 L .31642 .45931 L closepath p F P
0 g
s
.791 .357 .217 r
.21793 .42056 m .22334 .42274 L .2211 .41942 L p F P
0 g
s
.791 .357 .217 r
.21727 .41956 m .21793 .42056 L p .2211 .41942 L F P
0 g
s
.791 .357 .217 r
.2211 .41942 m .21973 .41887 L .21727 .41956 L p F P
0 g
s
.26 0 0 r
.57177 .44056 m .57266 .43933 L .56294 .44239 L p F P
0 g
s
.26 0 0 r
.56294 .44239 m .56196 .44372 L .57177 .44056 L p F P
0 g
s
.683 .175 .025 r
.26487 .44239 m .26707 .44413 L .26261 .44281 L closepath p F P
0 g
s
.563 .011 0 r
.30668 .45663 m .30917 .45785 L .30484 .45696 L closepath p F P
0 g
s
.268 .672 .968 r
.29192 .33603 m .29251 .33609 L .29843 .33813 L p F P
0 g
s
.294 .702 .974 r
.301 .33682 m .29251 .33609 L .29843 .33813 L p F P
0 g
s
.294 .702 .974 r
.29843 .33813 m .30397 .33841 L .301 .33682 L p F P
0 g
s
.69 .826 .948 r
.59729 .32152 m .58755 .32533 L .5851 .32342 L p F P
0 g
s
.685 .833 .955 r
.57537 .32725 m .5851 .32342 L .58755 .32533 L p F P
0 g
s
.229 0 0 r
.50434 .46182 m .50454 .46169 L .49492 .46276 L p F P
0 g
s
.229 0 0 r
.49492 .46276 m .49351 .46367 L .50434 .46182 L p F P
0 g
s
.222 .74 .854 r
.4558 .35046 m .45832 .35043 L .44692 .35164 L p F P
0 g
s
.222 .74 .854 r
.44692 .35164 m .44628 .35159 L .4558 .35046 L p F P
0 g
s
.209 0 0 r
.48007 .46654 m .48253 .46532 L .47134 .46672 L p F P
0 g
s
.209 0 0 r
.47134 .46672 m .4705 .46712 L .48007 .46654 L p F P
0 g
s
.621 .59 .798 r
.65553 .32935 m .65117 .33014 L .64869 .32496 L p F P
0 g
s
.854 .558 .486 r
.18563 .38915 m .18576 .39091 L .18496 .39052 L closepath p F P
0 g
s
.662 .734 .903 r
.21059 .31876 m .20143 .32214 L .19842 .31888 L p F P
0 g
s
.709 .732 .869 r
.18917 .32346 m .19842 .31888 L .20143 .32214 L p F P
0 g
s
.671 .734 .898 r
.20143 .32214 m .21059 .31876 L .21361 .32183 L p F P
0 g
s
.088 0 0 r
.40671 .35277 m .39749 .35264 L .39466 .35236 L p F P
0 g
s
.603 .898 .987 r
.53881 .33454 m .53919 .33467 L .52941 .33796 L p F P
0 g
s
.603 .898 .987 r
.52941 .33796 m .52914 .33786 L .53881 .33454 L p F P
0 g
s
.466 .729 .983 r
.26484 .3295 m .26488 .32953 L p .25284 .32766 L F P
0 g
s
.466 .729 .983 r
.25284 .32766 m .25917 .3274 L .26484 .3295 L p F P
0 g
s
.445 .714 .981 r
.25917 .3274 m .25284 .32766 L .24985 .32516 L p F P
0 g
s
.357 .054 .308 r
.63383 .40435 m .63452 .4012 L .62557 .40561 L p F P
0 g
s
.357 .054 .308 r
.62557 .40561 m .62485 .40874 L .63383 .40435 L p F P
0 g
s
.838 .466 .349 r
.19862 .40686 m .19728 .40324 L .20225 .4056 L p F P
0 g
s
.838 .466 .349 r
.20116 .40806 m .19862 .40686 L p .20225 .4056 L F P
0 g
s
.838 .466 .349 r
.20225 .4056 m .20284 .40715 L .20116 .40806 L p F P
0 g
s
0 .545 .791 r
.35133 .34791 m .34607 .34737 L .34316 .3464 L p F P
0 g
s
.739 .726 .839 r
.18788 .32429 m .18917 .32346 L .18616 .32001 L p F P
0 g
s
.739 .726 .839 r
.18616 .32001 m .18373 .32154 L .18788 .32429 L p F P
0 g
s
.748 .713 .819 r
.17677 .32624 m .18373 .32154 L .18788 .32429 L p F P
0 g
s
.264 0 .047 r
.59256 .4314 m .59397 .429 L .58446 .43258 L p F P
0 g
s
.264 0 .047 r
.58446 .43258 m .58304 .43498 L .59256 .4314 L p F P
0 g
s
.577 .727 .945 r
.22572 .32232 m .229 .32178 L .23387 .32425 L p F P
0 g
s
.592 .74 .946 r
.23479 .32078 m .229 .32178 L .23387 .32425 L p F P
0 g
s
.592 .74 .946 r
.23387 .32425 m .2378 .32347 L .23479 .32078 L p F P
0 g
s
.628 .735 .924 r
.21361 .32183 m .22271 .31943 L .22572 .32232 L p F P
0 g
s
.617 .734 .929 r
.22271 .31943 m .21361 .32183 L .21059 .31876 L p F P
0 g
s
.646 .656 .845 r
.64631 .32048 m .64624 .32034 L .63638 .32319 L p F P
0 g
s
.655 .668 .85 r
.64624 .32034 m .63638 .32319 L .63395 .31936 L p F P
0 g
s
.391 0 0 r
.3563 .46772 m .35788 .46745 L .35399 .4664 L p F P
0 g
s
.391 0 0 r
.35242 .46724 m .3563 .46772 L p .35399 .4664 L F P
0 g
s
.391 0 0 r
.34577 .46545 m .35242 .46724 L p .35399 .4664 L F P
0 g
s
.391 0 0 r
.35399 .4664 m .34592 .46543 L .34577 .46545 L p F P
0 g
s
.696 .189 .027 r
.25494 .44031 m .26089 .44226 L .25744 .43931 L p F P
0 g
s
.696 .189 .027 r
.25744 .43931 m .25145 .43737 L .25494 .44031 L p F P
0 g
s
.293 .789 .861 r
.47071 .34898 m .47964 .34721 L .4695 .34896 L closepath p F P
0 g
s
.251 .762 .851 r
.4695 .34896 m .47071 .34898 L p .4585 .35043 L F P
0 g
s
.763 .305 .163 r
.23521 .4282 m .23691 .43023 L .23292 .42877 L closepath p F P
0 g
s
.507 .371 .631 r
.66918 .35771 m .66075 .36302 L .65994 .35803 L p F P
0 g
s
.507 .371 .631 r
.66914 .35746 m .66918 .35771 L p .65994 .35803 L F P
0 g
s
.507 .371 .631 r
.65994 .35803 m .66493 .35488 L .66914 .35746 L p F P
0 g
s
.071 .62 .831 r
.3808 .3514 m .38248 .35157 L .37652 .35125 L p F P
0 g
s
.071 .62 .831 r
.377 .35105 m .3808 .3514 L p .37652 .35125 L F P
0 g
s
.071 .62 .831 r
.37032 .35043 m .377 .35105 L p .37652 .35125 L F P
0 g
s
.071 .62 .831 r
.37652 .35125 m .37157 .3507 L .37032 .35043 L p F P
0 g
s
.356 0 0 r
.38507 .46966 m .38922 .47037 L .3834 .47008 L closepath p F P
0 g
s
.595 .044 0 r
.29269 .45273 m .29167 .45284 L .29048 .45217 L closepath p F P
0 g
s
.654 .127 0 r
.27106 .44691 m .26707 .44413 L .27335 .44595 L p F P
0 g
s
.654 .127 0 r
.27604 .44837 m .27106 .44691 L p .27335 .44595 L F P
0 g
s
.654 .127 0 r
.27335 .44595 m .27667 .44829 L .27604 .44837 L p F P
0 g
s
.805 .381 .239 r
.21973 .41887 m .21727 .41956 L .21581 .4172 L closepath p F P
0 g
s
.65 .888 .983 r
.56319 .32945 m .5595 .33084 L .56309 .3294 L closepath p F P
0 g
s
.647 .891 .984 r
.56071 .32825 m .56309 .3294 L .5595 .33084 L p F P
0 g
s
.647 .891 .984 r
.55101 .33194 m .56071 .32825 L p .5595 .33084 L F P
0 g
s
.703 .733 .874 r
.19842 .31888 m .18917 .32346 L .18616 .32001 L p F P
0 g
s
.727 .244 .098 r
.24999 .43596 m .25145 .43737 L .24829 .43633 L closepath p F P
0 g
s
.739 .256 .098 r
.23991 .43332 m .2456 .43538 L .24263 .43228 L p F P
0 g
s
.739 .256 .098 r
.24263 .43228 m .23691 .43023 L .23991 .43332 L p F P
0 g
s
.565 .907 .975 r
.53881 .33454 m .52914 .33786 L .5266 .33725 L p F P
0 g
s
.518 0 0 r
.31459 .46019 m .30917 .45785 L .31642 .45931 L p F P
0 g
s
.518 0 0 r
.3164 .46056 m .31459 .46019 L p .31642 .45931 L F P
0 g
s
.518 0 0 r
.31642 .45931 m .31867 .46027 L .3164 .46056 L p F P
0 g
s
.204 0 0 r
.51729 .45813 m .51676 .4585 L .51138 .45931 L closepath p F P
0 g
s
.204 0 0 r
.51498 .45972 m .51676 .4585 L .51138 .45931 L p F P
0 g
s
.204 0 0 r
.50643 .46142 m .51498 .45972 L p .51138 .45931 L F P
0 g
s
.204 0 0 r
.50454 .46169 m .50643 .46142 L p .51138 .45931 L F P
0 g
s
.819 .699 .733 r
.16263 .34146 m .1669 .34416 L p .16833 .33706 L F P
0 g
s
.831 .687 .705 r
.15952 .34664 m .16386 .34931 L .1669 .34416 L p F P
0 g
s
.831 .687 .705 r
.1669 .34416 m .16263 .34146 L .15952 .34664 L p F P
0 g
s
.062 .625 .769 r
.40967 .35294 m .41808 .35282 L .40692 .35278 L closepath p F P
0 g
s
.683 .856 .965 r
.5851 .32342 m .57537 .32725 L .57291 .32567 L p F P
0 g
s
.674 .861 .97 r
.56319 .32945 m .57291 .32567 L .57537 .32725 L p F P
0 g
s
.13 .629 .907 r
.31898 .3422 m .32078 .34241 L .32761 .3441 L p F P
0 g
s
.171 .663 .919 r
.32812 .34324 m .32078 .34241 L .32761 .3441 L p F P
0 g
s
.171 .663 .919 r
.32761 .3441 m .33106 .34436 L .32812 .34324 L p F P
0 g
s
.251 .762 .851 r
.4585 .35043 m .45958 .35026 L .4695 .34896 L p F P
0 g
s
.223 .744 .823 r
.4585 .35043 m .45958 .35026 L .45832 .35043 L closepath p F P
0 g
s
.863 .593 .527 r
.17157 .37942 m .17616 .38195 L .17631 .37784 L p F P
0 g
s
.863 .593 .527 r
.17631 .37784 m .17172 .37531 L .17157 .37942 L p F P
0 g
s
.466 .872 .956 r
.50514 .34279 m .50474 .34272 L .50003 .34397 L closepath p F P
0 g
s
.431 .863 .93 r
.50214 .34254 m .50474 .34272 L .50003 .34397 L p F P
0 g
s
.431 .863 .93 r
.49251 .34501 m .50214 .34254 L p .50003 .34397 L F P
0 g
s
.861 .615 .566 r
.16718 .37274 m .17172 .37531 L .17229 .37105 L p F P
0 g
s
.861 .615 .566 r
.17229 .37105 m .16776 .36848 L .16718 .37274 L p F P
0 g
s
.07 .62 .831 r
.37157 .3507 m .37032 .35043 L .36775 .35028 L closepath p F P
0 g
s
.809 .705 .751 r
.16714 .33535 m .16663 .33596 L .16833 .33706 L closepath p F P
0 g
s
.819 .699 .733 r
.16833 .33706 m .16663 .33596 L .16263 .34146 L p F P
0 g
s
.864 .568 .486 r
.17641 .38593 m .18105 .38844 L .1808 .38446 L p F P
0 g
s
.864 .568 .486 r
.1808 .38446 m .17616 .38195 L .17641 .38593 L p F P
0 g
s
.594 .043 0 r
.28841 .45308 m .2839 .45046 L .29048 .45217 L p F P
0 g
s
.594 .043 0 r
.28873 .45316 m .28841 .45308 L p .29048 .45217 L F P
0 g
s
.594 .043 0 r
.29048 .45217 m .29167 .45284 L .28873 .45316 L p F P
0 g
s
.257 0 0 r
.48271 .46521 m .48393 .46512 L .48253 .46532 L closepath p F P
0 g
s
.563 .72 .947 r
.229 .32178 m .22572 .32232 L .22271 .31943 L p F P
0 g
s
.083 .643 .765 r
.42187 .35286 m .43061 .35245 L .4194 .35281 L closepath p F P
0 g
s
.819 .415 .284 r
.20546 .41265 m .21061 .41494 L .20884 .41146 L p F P
0 g
s
.819 .415 .284 r
.20884 .41146 m .20366 .40919 L .20546 .41265 L p F P
0 g
s
.856 .636 .603 r
.16326 .36589 m .16776 .36848 L .16882 .36405 L p F P
0 g
s
.856 .636 .603 r
.16882 .36405 m .16434 .36145 L .16326 .36589 L p F P
0 g
s
.073 .635 .711 r
.4558 .35046 m .44628 .35159 L .44356 .35163 L p F P
0 g
s
.376 .101 .363 r
.64337 .39659 m .64388 .39324 L .63506 .39786 L p F P
0 g
s
.376 .101 .363 r
.63506 .39786 m .63452 .4012 L .64337 .39659 L p F P
0 g
s
.217 .74 .817 r
.45958 .35026 m .45832 .35043 L .4558 .35046 L p F P
0 g
s
.166 .641 .929 r
.31898 .3422 m .32078 .34241 L .3175 .3415 L closepath p F P
0 g
s
.776 .321 .168 r
.22587 .42598 m .23129 .42814 L .22879 .42489 L p F P
0 g
s
.776 .321 .168 r
.22879 .42489 m .22334 .42274 L .22587 .42598 L p F P
0 g
s
.114 .666 .772 r
.44332 .35165 m .44356 .35163 L .43407 .35241 L p F P
0 g
s
.114 .666 .772 r
.43407 .35241 m .43151 .35242 L .44332 .35165 L p F P
0 g
s
.216 0 0 r
.53802 .45328 m .53863 .45274 L .52895 .45474 L p F P
0 g
s
.216 0 0 r
.52895 .45474 m .52773 .45581 L .53802 .45328 L p F P
0 g
s
.234 0 0 r
.5824 .43586 m .58304 .43498 L .57338 .43834 L p F P
0 g
s
.234 0 0 r
.57338 .43834 m .57266 .43933 L .5824 .43586 L p F P
0 g
s
0 .565 .784 r
.35818 .34901 m .35944 .34914 L .36775 .35028 L p F P
0 g
s
.039 .6 .799 r
.36744 .34994 m .35944 .34914 L .36775 .35028 L p F P
0 g
s
.039 .6 .799 r
.36775 .35028 m .37032 .35043 L .36744 .34994 L p F P
0 g
s
.428 0 0 r
.34592 .46543 m .34577 .46545 L .34552 .46537 L closepath p F P
0 g
s
.854 .53 .437 r
.1828 .39291 m .18645 .39474 L .18576 .39091 L p F P
0 g
s
.854 .53 .437 r
.18576 .39091 m .18496 .39052 L .1828 .39291 L p F P
0 g
s
.338 0 0 r
.39724 .47046 m .3995 .47078 L .39641 .4707 L closepath p F P
0 g
s
.23 .748 .833 r
.4695 .34896 m .46804 .34894 L .45958 .35026 L closepath p F P
0 g
s
.217 .74 .817 r
.46607 .3491 m .46804 .34894 L .45958 .35026 L p F P
0 g
s
.217 .74 .817 r
.46132 .3497 m .46607 .3491 L p .45958 .35026 L F P
0 g
s
.217 .74 .817 r
.4558 .35046 m .46132 .3497 L p .45958 .35026 L F P
0 g
s
.424 0 0 r
.34281 .46581 m .33751 .46418 L .34552 .46537 L p F P
0 g
s
.424 0 0 r
.34552 .46537 m .34577 .46545 L .34281 .46581 L p F P
0 g
s
.555 .467 .71 r
.66222 .34341 m .66557 .34122 L .66626 .34371 L closepath p F P
0 g
s
.181 0 0 r
.48393 .46512 m .48253 .46532 L .48007 .46654 L p F P
0 g
s
.832 .455 .34 r
.20284 .40715 m .20366 .40919 L .20116 .40806 L closepath p F P
0 g
s
.85 .656 .639 r
.1599 .35883 m .16434 .36145 L .16597 .35682 L p F P
0 g
s
.85 .656 .639 r
.16597 .35682 m .16156 .35419 L .1599 .35883 L p F P
0 g
s
.281 .673 .971 r
.29192 .33603 m .29251 .33609 L .29129 .33564 L closepath p F P
0 g
s
.408 0 0 r
.35242 .46724 m .34577 .46545 L .34281 .46581 L p F P
0 g
s
.034 .588 .821 r
.35818 .34901 m .35944 .34914 L .35747 .34883 L closepath p F P
0 g
s
.185 0 0 r
.49351 .46367 m .49231 .4643 L .48393 .46512 L closepath p F P
0 g
s
.181 0 0 r
.49091 .46501 m .49231 .4643 L .48393 .46512 L p F P
0 g
s
.181 0 0 r
.48133 .46642 m .49091 .46501 L p .48393 .46512 L F P
0 g
s
.181 0 0 r
.48007 .46654 m .48133 .46642 L p .48393 .46512 L F P
0 g
s
.442 .242 .511 r
.65791 .37822 m .65307 .38107 L .65301 .37703 L p F P
0 g
s
.442 .242 .511 r
.65301 .37703 m .65867 .3737 L .65791 .37822 L p F P
0 g
s
.774 .717 .8 r
.17294 .32959 m .17677 .32624 L .17376 .32256 L p F P
0 g
s
.774 .717 .8 r
.17376 .32256 m .1687 .32687 L .17294 .32959 L p F P
0 g
s
.786 .705 .775 r
.16416 .33123 m .1687 .32687 L .17294 .32959 L p F P
0 g
s
.786 .705 .775 r
.17294 .32959 m .16714 .33535 L .16416 .33123 L p F P
0 g
s
.659 .89 .981 r
.57235 .32537 m .57291 .32567 L .56319 .32945 L p F P
0 g
s
.659 .89 .981 r
.56319 .32945 m .56309 .3294 L .57235 .32537 L p F P
0 g
s
.509 .895 .956 r
.52536 .33707 m .5266 .33725 L .51694 .34033 L p F P
0 g
s
.509 .895 .956 r
.51694 .34033 m .51536 .34008 L .52536 .33707 L p F P
0 g
s
.408 .699 .981 r
.26488 .32953 m .2649 .32953 L .26484 .3295 L closepath p F P
0 g
s
.862 .542 .444 r
.18165 .3923 m .1828 .39291 L .18496 .39052 L p F P
0 g
s
.862 .542 .444 r
.18496 .39052 m .18105 .38844 L .18165 .3923 L p F P
0 g
s
.396 .695 .981 r
.27251 .32874 m .27392 .3297 L .2649 .32953 L p F P
0 g
s
.396 .695 .981 r
.26944 .32763 m .27251 .32874 L p .2649 .32953 L F P
0 g
s
.396 .695 .981 r
.26188 .32726 m .26944 .32763 L p .2649 .32953 L F P
0 g
s
.396 .695 .981 r
.2649 .32953 m .26484 .3295 L .26188 .32726 L p F P
0 g
s
.191 0 0 r
.54835 .45038 m .55018 .44871 L .54006 .45146 L p F P
0 g
s
.191 0 0 r
.54006 .45146 m .53863 .45274 L .54835 .45038 L p F P
0 g
s
.206 0 0 r
.47987 .46663 m .48007 .46654 L .4705 .46712 L p F P
0 g
s
.206 0 0 r
.4705 .46712 m .46863 .468 L .47987 .46663 L p F P
0 g
s
.475 .731 .982 r
.26484 .3295 m .26188 .32726 L .25917 .3274 L closepath p F P
0 g
s
.744 .716 .825 r
.18373 .32154 m .17677 .32624 L .17376 .32256 L p F P
0 g
s
.624 .627 .833 r
.64631 .32048 m .64869 .32496 L .6586 .32278 L p F P
0 g
s
.621 .59 .798 r
.66015 .32622 m .65553 .32935 L p .64869 .32496 L F P
0 g
s
.621 .59 .798 r
.64869 .32496 m .6586 .32278 L .66015 .32622 L p F P
0 g
s
.174 0 0 r
.52643 .45673 m .52773 .45581 L .51729 .45813 L p F P
0 g
s
.174 0 0 r
.51729 .45813 m .51676 .4585 L .52643 .45673 L p F P
0 g
s
.662 .892 .98 r
.57044 .32438 m .57235 .32537 L .56309 .3294 L p F P
0 g
s
.662 .892 .98 r
.56309 .3294 m .56071 .32825 L .57044 .32438 L p F P
0 g
s
.849 .499 .39 r
.18749 .39845 m .19236 .40086 L .19134 .39714 L p F P
0 g
s
.849 .499 .39 r
.19134 .39714 m .18645 .39474 L .18749 .39845 L p F P
0 g
s
.604 .569 .788 r
.65553 .32935 m .66015 .32622 L .6611 .32847 L closepath p F P
0 g
s
.265 .666 .967 r
.3006 .33661 m .301 .33682 L .29251 .33609 L p F P
0 g
s
.265 .666 .967 r
.29509 .33497 m .3006 .33661 L p .29251 .33609 L F P
0 g
s
.265 .666 .967 r
.28895 .33421 m .29509 .33497 L p .29251 .33609 L F P
0 g
s
.265 .666 .967 r
.29251 .33609 m .29129 .33564 L .28895 .33421 L p F P
0 g
s
.808 .708 .755 r
.16663 .33596 m .16714 .33535 L .16416 .33123 L p F P
0 g
s
.319 0 0 r
.40942 .47088 m .41037 .47098 L .40911 .47098 L closepath p F P
0 g
s
.492 .884 .96 r
.51438 .33993 m .51536 .34008 L .50514 .34279 L p F P
0 g
s
.492 .884 .96 r
.50514 .34279 m .50474 .34272 L .51438 .33993 L p F P
0 g
s
.808 .708 .755 r
.16416 .33123 m .16248 .3332 L .16663 .33596 L p F P
0 g
s
.819 .702 .736 r
.15839 .33874 m .16263 .34146 L .16663 .33596 L p F P
0 g
s
.819 .702 .736 r
.16663 .33596 m .16248 .3332 L .15839 .33874 L p F P
0 g
s
.482 .327 .593 r
.66971 .36234 m .66918 .35771 L .66075 .36302 L p F P
0 g
s
.482 .327 .593 r
.66075 .36302 m .66129 .36765 L .66971 .36234 L p F P
0 g
s
.573 .016 0 r
.29167 .45284 m .29523 .45471 L .28873 .45316 L closepath p F P
0 g
s
.806 .381 .237 r
.21269 .41832 m .21061 .41494 L .21581 .4172 L p F P
0 g
s
.806 .381 .237 r
.21619 .41985 m .21269 .41832 L p .21581 .4172 L F P
0 g
s
.806 .381 .237 r
.21581 .4172 m .21727 .41956 L .21619 .41985 L p F P
0 g
s
.493 0 0 r
.30745 .45867 m .31459 .46019 L .30917 .45785 L p F P
0 g
s
.493 0 0 r
.30362 .45704 m .30745 .45867 L p .30917 .45785 L F P
0 g
s
.493 0 0 r
.30917 .45785 m .30484 .45696 L .30362 .45704 L p F P
0 g
s
.466 .288 .554 r
.66157 .37197 m .65867 .3737 L .65777 .36976 L p F P
0 g
s
.466 .288 .554 r
.65777 .36976 m .66129 .36765 L .66157 .37197 L p F P
0 g
s
.518 .729 .97 r
.2378 .32347 m .24684 .32266 L .24985 .32516 L p F P
0 g
s
.5 .723 .972 r
.24684 .32266 m .2378 .32347 L .23479 .32078 L p F P
0 g
s
.232 0 0 r
.45827 .46864 m .46367 .4685 L .45718 .46912 L closepath p F P
0 g
s
.841 .674 .674 r
.15719 .35153 m .16156 .35419 L .16386 .34931 L p F P
0 g
s
.841 .674 .674 r
.16386 .34931 m .15952 .34664 L .15719 .35153 L p F P
0 g
s
.292 0 .123 r
.60335 .42522 m .60419 .42346 L .59445 .428 L p F P
0 g
s
.292 0 .123 r
.59445 .428 m .59397 .429 L .60335 .42522 L p F P
0 g
s
.686 .167 0 r
.24902 .43833 m .25494 .44031 L .25145 .43737 L p F P
0 g
s
.686 .167 0 r
.2468 .43646 m .24902 .43833 L p .25145 .43737 L F P
0 g
s
.686 .167 0 r
.25145 .43737 m .24829 .43633 L .2468 .43646 L p F P
0 g
s
.632 .09 0 r
.26487 .44504 m .27106 .44691 L .26707 .44413 L p F P
0 g
s
.632 .09 0 r
.26171 .44287 m .26487 .44504 L p .26707 .44413 L F P
0 g
s
.632 .09 0 r
.26707 .44413 m .26261 .44281 L .26171 .44287 L p F P
0 g
s
.346 .71 .985 r
.29129 .33564 m .28895 .33421 L .28637 .33412 L closepath p F P
0 g
s
.146 .631 .92 r
.32729 .34294 m .32812 .34324 L .32078 .34241 L p F P
0 g
s
.146 .631 .92 r
.32219 .34178 m .32729 .34294 L p .32078 .34241 L F P
0 g
s
.146 .631 .92 r
.31603 .34083 m .32219 .34178 L p .32078 .34241 L F P
0 g
s
.146 .631 .92 r
.32078 .34241 m .3175 .3415 L .31603 .34083 L p F P
0 g
s
.311 0 0 r
.43365 .47062 m .43383 .47055 L p .42162 .47091 L F P
0 g
s
.311 0 0 r
.42162 .47091 m .42199 .47094 L .43365 .47062 L p F P
0 g
s
.299 0 0 r
.42162 .47091 m .42199 .47094 L .42151 .47095 L closepath p F P
0 g
s
.016 .576 .808 r
.367 .34988 m .36744 .34994 L .35944 .34914 L p F P
0 g
s
.016 .576 .808 r
.35981 .34895 m .367 .34988 L p .35944 .34914 L F P
0 g
s
.016 .576 .808 r
.35528 .3483 m .35981 .34895 L p .35944 .34914 L F P
0 g
s
.016 .576 .808 r
.35944 .34914 m .35747 .34883 L .35528 .3483 L p F P
0 g
s
.494 0 0 r
.31867 .46027 m .32204 .46159 L .3164 .46056 L closepath p F P
0 g
s
.256 0 0 r
.44605 .46978 m .44831 .4698 L .44553 .47 L closepath p F P
0 g
s
.843 .469 .343 r
.19371 .40447 m .19862 .40686 L .19728 .40324 L p F P
0 g
s
.843 .469 .343 r
.19728 .40324 m .19236 .40086 L .19371 .40447 L p F P
0 g
s
.394 .146 .416 r
.65267 .38773 m .65293 .38486 L .64422 .38968 L p F P
0 g
s
.394 .146 .416 r
.65188 .38882 m .65267 .38773 L p .64422 .38968 L F P
0 g
s
.394 .146 .416 r
.64422 .38968 m .64388 .39324 L .65188 .38882 L p F P
0 g
s
.671 .71 .877 r
.6217 .31937 m .63152 .31591 L .63395 .31936 L p F P
0 g
s
.679 .736 .893 r
.63152 .31591 m .6217 .31937 L .61928 .31645 L p F P
0 g
s
.682 .75 .902 r
.60949 .32014 m .61928 .31645 L .6217 .31937 L p F P
0 g
s
.25 0 0 r
.42151 .47095 m .41883 .47161 L .41037 .47098 L closepath p F P
0 g
s
.234 0 0 r
.41822 .47176 m .41883 .47161 L .41037 .47098 L p F P
0 g
s
.234 0 0 r
.40926 .47174 m .41822 .47176 L p .41037 .47098 L F P
0 g
s
.234 0 0 r
.4066 .47153 m .40926 .47174 L p .41037 .47098 L F P
0 g
s
.234 0 0 r
.41037 .47098 m .40911 .47098 L .4066 .47153 L p F P
0 g
s
.27 0 0 r
.40911 .47098 m .4066 .47153 L .3995 .47078 L closepath p F P
0 g
s
.278 0 0 r
.43383 .47055 m .43454 .47057 L .43365 .47062 L closepath p F P
0 g
s
.403 0 0 r
.34211 .4659 m .34281 .46581 L .33751 .46418 L p F P
0 g
s
.403 0 0 r
.33606 .46495 m .34211 .4659 L p .33751 .46418 L F P
0 g
s
.403 0 0 r
.33072 .46332 m .33606 .46495 L p .33751 .46418 L F P
0 g
s
.403 0 0 r
.33751 .46418 m .33143 .46326 L .33072 .46332 L p F P
0 g
s
.287 .786 .857 r
.47964 .34721 m .4695 .34896 L .46804 .34894 L p F P
0 g
s
.215 0 0 r
.42199 .47094 m .42151 .47095 L .41883 .47161 L p F P
0 g
s
.215 0 0 r
.43045 .47149 m .43107 .47133 L .42199 .47094 L p F P
0 g
s
.215 0 0 r
.42085 .47171 m .43045 .47149 L p .42199 .47094 L F P
0 g
s
.215 0 0 r
.41883 .47161 m .42085 .47171 L p .42199 .47094 L F P
0 g
s
.228 0 0 r
.43365 .47062 m .43107 .47133 L .42199 .47094 L closepath p F P
0 g
s
.689 .775 .917 r
.61928 .31645 m .60949 .32014 L .60706 .31767 L p F P
0 g
s
.73 .237 .066 r
.23427 .43123 m .23991 .43332 L .23691 .43023 L p F P
0 g
s
.73 .237 .066 r
.23197 .42888 m .23427 .43123 L p .23691 .43023 L F P
0 g
s
.73 .237 .066 r
.23691 .43023 m .23292 .42877 L .23197 .42888 L p F P
0 g
s
.563 .72 .947 r
.22271 .31943 m .22444 .31919 L .229 .32178 L p F P
0 g
s
.577 .736 .951 r
.23177 .31811 m .22444 .31919 L .229 .32178 L p F P
0 g
s
.577 .736 .951 r
.229 .32178 m .23479 .32078 L .23177 .31811 L p F P
0 g
s
.689 .798 .933 r
.59752 .32174 m .59729 .32152 L .59925 .32074 L closepath p F P
0 g
s
.201 0 0 r
.57028 .44226 m .57177 .44056 L .56196 .44372 L p F P
0 g
s
.201 0 0 r
.56196 .44372 m .56053 .44534 L .57028 .44226 L p F P
0 g
s
.033 .589 .817 r
.35747 .34883 m .35528 .3483 L .35133 .34791 L closepath p F P
0 g
s
.581 .519 .751 r
.66207 .33527 m .66337 .3344 L .66364 .33516 L closepath p F P
0 g
s
.416 .86 .908 r
.51438 .33993 m .50474 .34272 L .50214 .34254 L p F P
0 g
s
.637 .108 0 r
.27667 .44829 m .27735 .44873 L .2839 .45046 L p F P
0 g
s
.588 .032 0 r
.28193 .45132 m .28841 .45308 L .2839 .45046 L p F P
0 g
s
.588 .032 0 r
.2839 .45046 m .27735 .44873 L .28193 .45132 L p F P
0 g
s
.253 0 0 r
.40571 .47171 m .4066 .47153 L .3995 .47078 L p F P
0 g
s
.253 0 0 r
.3984 .47152 m .40571 .47171 L p .3995 .47078 L F P
0 g
s
.253 0 0 r
.39439 .47108 m .3984 .47152 L p .3995 .47078 L F P
0 g
s
.253 0 0 r
.3995 .47078 m .39641 .4707 L .39439 .47108 L p F P
0 g
s
.635 .907 .983 r
.55823 .32726 m .56071 .32825 L .55101 .33194 L p F P
0 g
s
.635 .907 .983 r
.55605 .3281 m .55823 .32726 L p .55101 .33194 L F P
0 g
s
.635 .907 .983 r
.55101 .33194 m .54877 .3311 L .55605 .3281 L p F P
0 g
s
.29 0 0 r
.39641 .4707 m .39439 .47108 L .38922 .47037 L closepath p F P
0 g
s
.227 0 0 r
.56015 .44576 m .56053 .44534 L .55081 .44802 L p F P
0 g
s
.227 0 0 r
.55081 .44802 m .55018 .44871 L .56015 .44576 L p F P
0 g
s
.734 .726 .843 r
.18373 .32154 m .18616 .32001 L .18313 .3166 L p F P
0 g
s
.734 .726 .843 r
.18313 .3166 m .17956 .31877 L .18373 .32154 L p F P
0 g
s
.744 .716 .825 r
.17376 .32256 m .17956 .31877 L .18373 .32154 L p F P
0 g
s
.133 0 0 r
.377 .35105 m .37032 .35043 L .36744 .34994 L p F P
0 g
s
0 .532 .8 r
.33623 .34505 m .33106 .34436 L .32812 .34324 L p F P
0 g
s
.194 0 0 r
.43454 .47057 m .43365 .47062 L .43107 .47133 L p F P
0 g
s
.655 .668 .85 r
.63395 .31936 m .6438 .31626 L .64624 .32034 L p F P
0 g
s
.665 .694 .867 r
.6438 .31626 m .63395 .31936 L .63152 .31591 L p F P
0 g
s
.205 0 0 r
.44553 .47 m .44331 .47067 L .43454 .47057 L closepath p F P
0 g
s
.194 0 0 r
.44242 .47094 m .44331 .47067 L .43454 .47057 L p F P
0 g
s
.194 0 0 r
.43338 .47137 m .44242 .47094 L p .43454 .47057 L F P
0 g
s
.194 0 0 r
.43107 .47133 m .43338 .47137 L p .43454 .47057 L F P
0 g
s
.687 .825 .949 r
.59925 .32074 m .59729 .32152 L .59485 .31949 L p F P
0 g
s
.69 .826 .948 r
.5851 .32342 m .59485 .31949 L .59729 .32152 L p F P
0 g
s
.53 0 0 r
.30484 .45696 m .30362 .45704 L .30208 .45633 L closepath p F P
0 g
s
.172 0 0 r
.52546 .45742 m .52643 .45673 L .51676 .4585 L p F P
0 g
s
.172 0 0 r
.51676 .4585 m .51498 .45972 L .52546 .45742 L p F P
0 g
s
.662 .734 .903 r
.19842 .31888 m .20757 .3157 L .21059 .31876 L p F P
0 g
s
.654 .733 .908 r
.20757 .3157 m .19842 .31888 L .19539 .31565 L p F P
0 g
s
.703 .733 .874 r
.18616 .32001 m .19539 .31565 L .19842 .31888 L p F P
0 g
s
.156 0 0 r
.50195 .46309 m .50434 .46182 L .49351 .46367 L p F P
0 g
s
.156 0 0 r
.49351 .46367 m .49231 .4643 L .50195 .46309 L p F P
0 g
s
.387 0 0 r
.35788 .46745 m .36107 .46822 L .3563 .46772 L closepath p F P
0 g
s
.27 0 0 r
.3929 .47135 m .39439 .47108 L .38922 .47037 L p F P
0 g
s
.27 0 0 r
.38811 .4711 m .3929 .47135 L p .38922 .47037 L F P
0 g
s
.27 0 0 r
.38219 .47027 m .38811 .4711 L p .38922 .47037 L F P
0 g
s
.27 0 0 r
.38922 .47037 m .3834 .47008 L .38219 .47027 L p F P
0 g
s
.21 .671 .944 r
.3175 .3415 m .31603 .34083 L .31407 .34067 L closepath p F P
0 g
s
.831 .69 .707 r
.15523 .34394 m .15952 .34664 L .16263 .34146 L p F P
0 g
s
.831 .69 .707 r
.16263 .34146 m .15839 .33874 L .15523 .34394 L p F P
0 g
s
.617 .904 .985 r
.54851 .33101 m .54877 .3311 L .53919 .33467 L p F P
0 g
s
.617 .904 .985 r
.53919 .33467 m .53881 .33454 L .54851 .33101 L p F P
0 g
s
.71 .204 .028 r
.24829 .43633 m .2468 .43646 L .2456 .43538 L closepath p F P
0 g
s
.866 .595 .526 r
.16703 .37685 m .17157 .37942 L .17172 .37531 L p F P
0 g
s
.866 .595 .526 r
.17172 .37531 m .16718 .37274 L .16703 .37685 L p F P
0 g
s
.82 .41 .269 r
.20035 .41035 m .20546 .41265 L .20366 .40919 L p F P
0 g
s
.82 .41 .269 r
.19945 .40857 m .20035 .41035 L p .20366 .40919 L F P
0 g
s
.82 .41 .269 r
.20366 .40919 m .20116 .40806 L .19945 .40857 L p F P
0 g
s
.696 .733 .879 r
.19539 .31565 m .18616 .32001 L .18313 .3166 L p F P
0 g
s
.232 0 0 r
.58144 .43719 m .5824 .43586 L .57266 .43933 L p F P
0 g
s
.232 0 0 r
.57266 .43933 m .57177 .44056 L .58144 .43719 L p F P
0 g
s
.774 .314 .154 r
.22049 .42379 m .22587 .42598 L .22334 .42274 L p F P
0 g
s
.774 .314 .154 r
.22334 .42274 m .21793 .42056 L .22049 .42379 L p F P
0 g
s
.863 .618 .565 r
.16268 .37015 m .16718 .37274 L .16776 .36848 L p F P
0 g
s
.863 .618 .565 r
.16776 .36848 m .16326 .36589 L .16268 .37015 L p F P
0 g
s
.141 .629 .917 r
.30397 .33841 m .30751 .33886 L .31407 .34067 L p F P
0 g
s
.111 .601 .908 r
.30751 .33886 m .30397 .33841 L .301 .33682 L p F P
0 g
s
.505 .372 .633 r
.66493 .35488 m .66834 .35269 L .66914 .35746 L closepath p F P
0 g
s
.617 .734 .929 r
.21059 .31876 m .21969 .31655 L .22271 .31943 L p F P
0 g
s
.606 .733 .935 r
.21969 .31655 m .21059 .31876 L .20757 .3157 L p F P
0 g
s
.295 0 .184 r
.62367 .41253 m .62398 .4117 L .61487 .41588 L p F P
0 g
s
.295 0 .184 r
.61487 .41588 m .61393 .41839 L .62367 .41253 L p F P
0 g
s
.267 0 .11 r
.60458 .42264 m .60419 .42346 L .61192 .41949 L closepath p F P
0 g
s
.867 .57 .484 r
.17182 .38339 m .17641 .38593 L .17616 .38195 L p F P
0 g
s
.867 .57 .484 r
.17616 .38195 m .17157 .37942 L .17182 .38339 L p F P
0 g
s
.308 0 0 r
.3834 .47008 m .38219 .47027 L .3794 .4698 L closepath p F P
0 g
s
.299 .683 .975 r
.27691 .33176 m .28051 .33204 L .28637 .33412 L p F P
0 g
s
.271 .66 .968 r
.28051 .33204 m .27691 .33176 L .27392 .3297 L p F P
0 g
s
.565 .494 .734 r
.6738 .33558 m .6737 .33523 L .66364 .33516 L p F P
0 g
s
.565 .494 .734 r
.66364 .33516 m .66557 .34122 L .6738 .33558 L p F P
0 g
s
.565 .51 .753 r
.66337 .3344 m .66364 .33516 L .6737 .33523 L p F P
0 g
s
.537 .455 .711 r
.67541 .34161 m .6738 .33558 L .66557 .34122 L p F P
0 g
s
.537 .455 .711 r
.67115 .34455 m .67541 .34161 L p .66557 .34122 L F P
0 g
s
.537 .455 .711 r
.66557 .34122 m .66626 .34371 L .67115 .34455 L p F P
0 g
s
.441 0 0 r
.33143 .46326 m .33072 .46332 L .3296 .46294 L closepath p F P
0 g
s
.588 .54 .769 r
.6611 .32847 m .66337 .3344 L .67155 .32868 L p F P
0 g
s
.565 .51 .753 r
.6737 .33523 m .67155 .32868 L .66337 .3344 L p F P
0 g
s
.172 0 0 r
.44831 .4698 m .44553 .47 L .44331 .47067 L p F P
0 g
s
0 .545 .791 r
.34316 .3464 m .34377 .34649 L .35133 .34791 L p F P
0 g
s
.011 .575 .795 r
.35192 .34764 m .34377 .34649 L .35133 .34791 L p F P
0 g
s
.011 .575 .795 r
.35262 .34775 m .35192 .34764 L p .35133 .34791 L F P
0 g
s
.011 .575 .795 r
.35133 .34791 m .35528 .3483 L .35262 .34775 L p F P
0 g
s
.423 .699 .979 r
.25383 .32511 m .24985 .32516 L .24684 .32266 L p F P
0 g
s
.445 .714 .981 r
.24985 .32516 m .25383 .32511 L .25917 .3274 L p F P
0 g
s
.858 .639 .605 r
.15972 .3638 m .16326 .36589 L .16434 .36145 L p F P
0 g
s
.858 .639 .605 r
.15926 .36141 m .15972 .3638 L p .16434 .36145 L F P
0 g
s
.858 .639 .605 r
.16434 .36145 m .1599 .35883 L .15926 .36141 L p F P
0 g
s
.661 .13 0 r
.26261 .44281 m .26171 .44287 L .26089 .44226 L closepath p F P
0 g
s
.688 .812 .942 r
.60706 .31767 m .59925 .32074 L .60632 .31701 L closepath p F P
0 g
s
.687 .825 .949 r
.60463 .3155 m .60632 .31701 L .59925 .32074 L p F P
0 g
s
.687 .825 .949 r
.59485 .31949 m .60463 .3155 L p .59925 .32074 L F P
0 g
s
.529 0 0 r
.30035 .45714 m .29523 .45471 L .30208 .45633 L p F P
0 g
s
.529 0 0 r
.30074 .45723 m .30035 .45714 L p .30208 .45633 L F P
0 g
s
.529 0 0 r
.30208 .45633 m .30362 .45704 L .30074 .45723 L p F P
0 g
s
.356 .828 .877 r
.50153 .34256 m .50214 .34254 L .49251 .34501 L p F P
0 g
s
.356 .828 .877 r
.49251 .34501 m .49109 .345 L .50153 .34256 L p F P
0 g
s
.54 .445 .696 r
.66626 .34371 m .67115 .34455 L .66716 .34724 L closepath p F P
0 g
s
.865 .543 .441 r
.17701 .38979 m .18165 .3923 L .18105 .38844 L p F P
0 g
s
.865 .543 .441 r
.18105 .38844 m .17641 .38593 L .17701 .38979 L p F P
0 g
s
.287 0 0 r
.37977 .47064 m .38219 .47027 L .3794 .4698 L p F P
0 g
s
.287 0 0 r
.37828 .47052 m .37977 .47064 L p .3794 .4698 L F P
0 g
s
.287 0 0 r
.37002 .46912 m .37828 .47052 L p .3794 .4698 L F P
0 g
s
.287 0 0 r
.3794 .4698 m .37006 .46912 L .37002 .46912 L p F P
0 g
s
.182 0 0 r
.45718 .46912 m .45556 .46965 L .44831 .4698 L closepath p F P
0 g
s
.172 0 0 r
.45415 .47011 m .45556 .46965 L .44831 .4698 L p F P
0 g
s
.172 0 0 r
.4471 .47062 m .45415 .47011 L p .44831 .4698 L F P
0 g
s
.172 0 0 r
.44331 .47067 m .4471 .47062 L p .44831 .4698 L F P
0 g
s
.474 .732 .983 r
.25888 .325 m .25383 .32511 L .25917 .3274 L p F P
0 g
s
.474 .732 .983 r
.25917 .3274 m .26188 .32726 L .25888 .325 L p F P
0 g
s
.691 .849 .959 r
.59485 .31949 m .5851 .32342 L .58265 .32175 L p F P
0 g
s
.683 .856 .965 r
.57291 .32567 m .58265 .32175 L .5851 .32342 L p F P
0 g
s
.318 0 .246 r
.63339 .40584 m .63383 .40435 L .62485 .40874 L p F P
0 g
s
.318 0 .246 r
.62778 .40985 m .63339 .40584 L p .62485 .40874 L F P
0 g
s
.318 0 .246 r
.62485 .40874 m .62398 .4117 L .62778 .40985 L p F P
0 g
s
.341 .71 .984 r
.28596 .33242 m .28051 .33204 L .28637 .33412 L p F P
0 g
s
.341 .71 .984 r
.28637 .33412 m .28895 .33421 L .28596 .33242 L p F P
0 g
s
.636 .102 0 r
.27667 .44829 m .27735 .44873 L .27604 .44837 L closepath p F P
0 g
s
.439 0 0 r
.32772 .46355 m .32204 .46159 L .3296 .46294 L p F P
0 g
s
.439 0 0 r
.3296 .46294 m .33072 .46332 L .32772 .46355 L p F P
0 g
s
.238 0 .036 r
.60197 .42762 m .60335 .42522 L .59397 .429 L p F P
0 g
s
.238 0 .036 r
.59397 .429 m .59256 .4314 L .60197 .42762 L p F P
0 g
s
.638 .641 .837 r
.64624 .32034 m .64671 .32021 L .64631 .32048 L closepath p F P
0 g
s
.624 .627 .833 r
.65614 .3178 m .64671 .32021 L .64631 .32048 L p F P
0 g
s
.624 .627 .833 r
.6586 .32278 m .65614 .3178 L p .64631 .32048 L F P
0 g
s
.587 .914 .975 r
.54851 .33101 m .53881 .33454 L .53629 .33393 L p F P
0 g
s
.565 .907 .975 r
.5266 .33725 m .53629 .33393 L .53881 .33454 L p F P
0 g
s
.647 .652 .841 r
.64671 .32021 m .64624 .32034 L .6438 .31626 L p F P
0 g
s
0 .547 .728 r
.38248 .35157 m .38626 .35186 L .3808 .3514 L closepath p F P
0 g
s
.197 .668 .938 r
.31307 .33953 m .30751 .33886 L .31407 .34067 L p F P
0 g
s
.197 .668 .938 r
.31407 .34067 m .31603 .34083 L .31307 .33953 L p F P
0 g
s
.851 .66 .644 r
.15851 .35798 m .1599 .35883 L .16156 .35419 L p F P
0 g
s
.851 .66 .644 r
.15669 .35287 m .15851 .35798 L p .16156 .35419 L F P
0 g
s
.851 .66 .644 r
.16156 .35419 m .15719 .35153 L .15669 .35287 L p F P
0 g
s
.751 .269 .097 r
.23292 .42877 m .23197 .42888 L .23129 .42814 L closepath p F P
0 g
s
.647 .652 .841 r
.65448 .31475 m .64671 .32021 L p .6438 .31626 L F P
0 g
s
.635 .64 .837 r
.64671 .32021 m .65448 .31475 L .65614 .3178 L closepath p F P
0 g
s
.661 .128 0 r
.25856 .44305 m .25494 .44031 L .26089 .44226 L p F P
0 g
s
.661 .128 0 r
.26089 .44226 m .26171 .44287 L .25856 .44305 L p F P
0 g
s
.454 .279 .552 r
.67001 .36666 m .66971 .36234 L .66129 .36765 L p F P
0 g
s
.454 .279 .552 r
.66129 .36765 m .66157 .37197 L .67001 .36666 L p F P
0 g
s
.146 0 0 r
.53613 .45465 m .53802 .45328 L .52773 .45581 L p F P
0 g
s
.146 0 0 r
.52773 .45581 m .52643 .45673 L .53613 .45465 L p F P
0 g
s
.851 .496 .38 r
.18266 .39602 m .18749 .39845 L .18645 .39474 L p F P
0 g
s
.851 .496 .38 r
.18194 .39343 m .18266 .39602 L p .18645 .39474 L F P
0 g
s
.851 .496 .38 r
.18645 .39474 m .1828 .39291 L .18194 .39343 L p F P
0 g
s
.548 .713 .949 r
.22444 .31919 m .22271 .31943 L .21969 .31655 L p F P
0 g
s
.521 .41 .668 r
.67661 .34711 m .66834 .35269 L .66716 .34724 L p F P
0 g
s
.521 .41 .668 r
.67646 .34637 m .67661 .34711 L p .66716 .34724 L F P
0 g
s
.521 .41 .668 r
.66716 .34724 m .67115 .34455 L .67646 .34637 L p F P
0 g
s
.771 .719 .804 r
.1687 .32687 m .17376 .32256 L .17074 .31893 L p F P
0 g
s
.771 .719 .804 r
.17074 .31893 m .16448 .32412 L .1687 .32687 L p F P
0 g
s
.785 .709 .781 r
.16116 .32722 m .16448 .32412 L .1687 .32687 L p F P
0 g
s
.785 .709 .781 r
.1687 .32687 m .16416 .33123 L .16116 .32722 L p F P
0 g
s
.311 .799 .88 r
.48037 .34709 m .48028 .34708 L .47964 .34721 L closepath p F P
0 g
s
.287 .786 .857 r
.47763 .34722 m .48028 .34708 L .47964 .34721 L p F P
0 g
s
.287 .786 .857 r
.46804 .34894 m .47763 .34722 L p .47964 .34721 L F P
0 g
s
.71 .203 .025 r
.24319 .43632 m .23991 .43332 L .2456 .43538 L p F P
0 g
s
.71 .203 .025 r
.24415 .43667 m .24319 .43632 L p .2456 .43538 L F P
0 g
s
.71 .203 .025 r
.2456 .43538 m .2468 .43646 L .24415 .43667 L p F P
0 g
s
.412 .19 .464 r
.65564 .38327 m .65293 .38486 L .65307 .38107 L p F P
0 g
s
.412 .19 .464 r
.65307 .38107 m .65791 .37822 L .65564 .38327 L p F P
0 g
s
.808 .377 .223 r
.20756 .41602 m .21269 .41832 L .21061 .41494 L p F P
0 g
s
.808 .377 .223 r
.21061 .41494 m .20546 .41265 L .20756 .41602 L p F P
0 g
s
.588 .54 .769 r
.67155 .32868 m .6711 .32744 L .6611 .32847 L p F P
0 g
s
.59 .561 .79 r
.66015 .32622 m .6611 .32847 L .6711 .32744 L p F P
0 g
s
.34 .816 .89 r
.48989 .345 m .49109 .345 L .48037 .34709 L p F P
0 g
s
.34 .816 .89 r
.48037 .34709 m .48028 .34708 L .48989 .345 L p F P
0 g
s
.806 .711 .759 r
.16248 .3332 m .16416 .33123 L .16116 .32722 L p F P
0 g
s
.149 0 0 r
.46367 .4685 m .45718 .46912 L .45556 .46965 L p F P
0 g
s
.325 0 0 r
.37006 .46912 m .37002 .46912 L .36995 .46911 L closepath p F P
0 g
s
.831 .431 .288 r
.20116 .40806 m .19945 .40857 L .19862 .40686 L closepath p F P
0 g
s
.318 0 0 r
.36712 .46944 m .36107 .46822 L .36995 .46911 L p F P
0 g
s
.318 0 0 r
.36995 .46911 m .37002 .46912 L .36712 .46944 L p F P
0 g
s
.797 .366 .223 r
.21727 .41956 m .21793 .42056 L .21619 .41985 L closepath p F P
0 g
s
.741 .719 .831 r
.17956 .31877 m .17376 .32256 L .17074 .31893 L p F P
0 g
s
.573 .008 0 r
.27548 .44955 m .28193 .45132 L .27735 .44873 L p F P
0 g
s
.573 .008 0 r
.27356 .44845 m .27548 .44955 L p .27735 .44873 L F P
0 g
s
.573 .008 0 r
.27735 .44873 m .27604 .44837 L .27356 .44845 L p F P
0 g
s
.162 0 0 r
.55817 .44759 m .56015 .44576 L .55018 .44871 L p F P
0 g
s
.162 0 0 r
.55518 .44848 m .55817 .44759 L p .55018 .44871 L F P
0 g
s
.162 0 0 r
.55018 .44871 m .54835 .45038 L .55518 .44848 L p F P
0 g
s
.3 0 0 r
.37828 .47052 m .37002 .46912 L .36712 .46944 L p F P
0 g
s
.203 0 0 r
.50454 .46169 m .50643 .46142 L .50434 .46182 L closepath p F P
0 g
s
.339 .041 .305 r
.64308 .39793 m .64337 .39659 L .63452 .4012 L p F P
0 g
s
.339 .041 .305 r
.63844 .40195 m .64308 .39793 L p .63452 .4012 L F P
0 g
s
.339 .041 .305 r
.63452 .4012 m .63383 .40435 L .63844 .40195 L p F P
0 g
s
.006 .561 .818 r
.34316 .3464 m .34377 .34649 L .34275 .34628 L closepath p F P
0 g
s
.238 .755 .801 r
.48989 .345 m .48028 .34708 L .47763 .34722 L p F P
0 g
s
.504 .893 .954 r
.52405 .33689 m .52536 .33707 L .51536 .34008 L p F P
0 g
s
.504 .893 .954 r
.51536 .34008 m .51438 .33993 L .52405 .33689 L p F P
0 g
s
.205 0 0 r
.59216 .43196 m .59256 .4314 L .58304 .43498 L p F P
0 g
s
.205 0 0 r
.58304 .43498 m .5824 .43586 L .59216 .43196 L p F P
0 g
s
.421 0 0 r
.33606 .46495 m .33072 .46332 L .32772 .46355 L p F P
0 g
s
.806 .711 .759 r
.16116 .32722 m .15838 .33042 L .16248 .3332 L p F P
0 g
s
.819 .705 .738 r
.1542 .33599 m .15839 .33874 L .16248 .3332 L p F P
0 g
s
.819 .705 .738 r
.16248 .3332 m .15838 .33042 L .1542 .33599 L p F P
0 g
s
.751 .269 .095 r
.22867 .42913 m .22587 .42598 L .23129 .42814 L p F P
0 g
s
.751 .269 .095 r
.22882 .42918 m .22867 .42913 L p .23129 .42814 L F P
0 g
s
.751 .269 .095 r
.23129 .42814 m .23197 .42888 L .22882 .42918 L p F P
0 g
s
.672 .887 .977 r
.58142 .32105 m .58265 .32175 L .57291 .32567 L p F P
0 g
s
.672 .887 .977 r
.57291 .32567 m .57235 .32537 L .58142 .32105 L p F P
0 g
s
.265 0 .107 r
.61192 .41949 m .60419 .42346 L .60335 .42522 L p F P
0 g
s
.842 .677 .678 r
.15584 .35069 m .15719 .35153 L .15952 .34664 L p F P
0 g
s
.842 .677 .678 r
.1539 .34665 m .15584 .35069 L p .15952 .34664 L F P
0 g
s
.842 .677 .678 r
.15952 .34664 m .15523 .34394 L .1539 .34665 L p F P
0 g
s
.607 .053 0 r
.27604 .44837 m .27356 .44845 L .27106 .44691 L closepath p F P
0 g
s
.845 .468 .337 r
.18885 .40206 m .19371 .40447 L .19236 .40086 L p F P
0 g
s
.845 .468 .337 r
.19236 .40086 m .18749 .39845 L .18885 .40206 L p F P
0 g
s
.088 0 0 r
.39466 .35236 m .39615 .35244 L .40671 .35277 L p F P
0 g
s
.047 0 0 r
.39466 .35236 m .39615 .35244 L .39409 .35234 L closepath p F P
0 g
s
.59 .561 .79 r
.66858 .32105 m .66724 .32125 L .66015 .32622 L p F P
0 g
s
.59 .561 .79 r
.6711 .32744 m .66858 .32105 L p .66015 .32622 L F P
0 g
s
.609 .585 .8 r
.6586 .32278 m .66724 .32125 L .66015 .32622 L closepath p F P
0 g
s
.438 .237 .51 r
.66164 .376 m .65791 .37822 L .65867 .3737 L p F P
0 g
s
.438 .237 .51 r
.65867 .3737 m .66157 .37197 L .66164 .376 L p F P
0 g
s
0 .548 .803 r
.34411 .34629 m .35192 .34764 L .34377 .34649 L p F P
0 g
s
0 .548 .803 r
.34023 .34557 m .34411 .34629 L p .34377 .34649 L F P
0 g
s
0 .548 .803 r
.34377 .34649 m .34275 .34628 L .34023 .34557 L p F P
0 g
s
.125 0 0 r
.50643 .46142 m .50434 .46182 L .50195 .46309 L p F P
0 g
s
.504 0 0 r
.30362 .45704 m .30745 .45867 L .30074 .45723 L closepath p F P
0 g
s
.649 .113 0 r
.26487 .44504 m .26171 .44287 L .25856 .44305 L p F P
0 g
s
.157 0 0 r
.46863 .468 m .46782 .46828 L .46367 .4685 L closepath p F P
0 g
s
.149 0 0 r
.46567 .46903 m .46782 .46828 L .46367 .4685 L p F P
0 g
s
.149 0 0 r
.4624 .46935 m .46567 .46903 L p .46367 .4685 L F P
0 g
s
.149 0 0 r
.45556 .46965 m .4624 .46935 L p .46367 .4685 L F P
0 g
s
.548 .713 .949 r
.21969 .31655 m .22009 .3165 L .22444 .31919 L p F P
0 g
s
.562 .732 .955 r
.22874 .31543 m .22009 .3165 L .22444 .31919 L p F P
0 g
s
.562 .732 .955 r
.22444 .31919 m .23177 .31811 L .22874 .31543 L p F P
0 g
s
.022 .575 .824 r
.34275 .34628 m .34023 .34557 L .33623 .34505 L closepath p F P
0 g
s
.526 .904 .953 r
.53516 .33377 m .53629 .33393 L .5266 .33725 L p F P
0 g
s
.526 .904 .953 r
.5266 .33725 m .52536 .33707 L .53516 .33377 L p F P
0 g
s
.412 0 0 r
.32743 .46357 m .32772 .46355 L .32204 .46159 L p F P
0 g
s
.412 0 0 r
.32071 .4623 m .32743 .46357 L p .32204 .46159 L F P
0 g
s
.412 0 0 r
.31565 .46058 m .32071 .4623 L p .32204 .46159 L F P
0 g
s
.412 0 0 r
.32204 .46159 m .3164 .46056 L .31565 .46058 L p F P
0 g
s
.188 0 0 r
.54817 .45055 m .54835 .45038 L .53863 .45274 L p F P
0 g
s
.188 0 0 r
.53863 .45274 m .53802 .45328 L .54817 .45055 L p F P
0 g
s
.191 .722 .776 r
.47705 .34731 m .47763 .34722 L .46804 .34894 L p F P
0 g
s
.191 .722 .776 r
.46804 .34894 m .46607 .3491 L .47705 .34731 L p F P
0 g
s
0 .529 .814 r
.32219 .34178 m .31603 .34083 L .31307 .33953 L p F P
0 g
s
.318 .68 .977 r
.26944 .32763 m .26188 .32726 L .25888 .325 L p F P
0 g
s
.5 0 0 r
.29361 .45548 m .30035 .45714 L .29523 .45471 L p F P
0 g
s
.5 0 0 r
.28858 .45316 m .29361 .45548 L p .29523 .45471 L F P
0 g
s
.5 0 0 r
.29523 .45471 m .28873 .45316 L .28858 .45316 L p F P
0 g
s
.299 0 0 r
.36625 .46953 m .36712 .46944 L .36107 .46822 L p F P
0 g
s
.299 0 0 r
.36008 .46887 m .36625 .46953 L p .36107 .46822 L F P
0 g
s
.299 0 0 r
.35495 .46782 m .36008 .46887 L p .36107 .46822 L F P
0 g
s
.299 0 0 r
.36107 .46822 m .3563 .46772 L .35495 .46782 L p F P
0 g
s
.128 0 0 r
.51498 .45972 m .5142 .46015 L .50643 .46142 L closepath p F P
0 g
s
.125 0 0 r
.51246 .4611 m .5142 .46015 L .50643 .46142 L p F P
0 g
s
.125 0 0 r
.50346 .46286 m .51246 .4611 L p .50643 .46142 L F P
0 g
s
.125 0 0 r
.50195 .46309 m .50346 .46286 L p .50643 .46142 L F P
0 g
s
.14 .612 .923 r
.29509 .33497 m .28895 .33421 L .28596 .33242 L p F P
0 g
s
.025 .597 .727 r
.4194 .35281 m .41909 .35281 L .41808 .35282 L closepath p F P
0 g
s
.049 .616 .757 r
.41629 .35299 m .41909 .35281 L .41808 .35282 L p F P
0 g
s
.049 .616 .757 r
.41808 .35282 m .40692 .35278 L .40687 .35277 L p F P
0 g
s
.049 .616 .757 r
.40687 .35277 m .41629 .35299 L p .41808 .35282 L F P
0 g
s
.072 .634 .755 r
.43061 .35245 m .4194 .35281 L .41909 .35281 L p F P
0 g
s
.011 .586 .734 r
.40692 .35278 m .40687 .35277 L .40671 .35277 L closepath p F P
0 g
s
.041 0 0 r
.40404 .35285 m .39615 .35244 L .40671 .35277 L p F P
0 g
s
.041 0 0 r
.40671 .35277 m .40687 .35277 L .40404 .35285 L p F P
0 g
s
.5 .723 .972 r
.23479 .32078 m .24382 .32018 L .24684 .32266 L p F P
0 g
s
.476 .718 .976 r
.24382 .32018 m .23479 .32078 L .23177 .31811 L p F P
0 g
s
.73 .727 .847 r
.17956 .31877 m .18313 .3166 L .18009 .31323 L p F P
0 g
s
.73 .727 .847 r
.18009 .31323 m .17539 .316 L .17956 .31877 L p F P
0 g
s
.741 .719 .831 r
.17074 .31893 m .17539 .316 L .17956 .31877 L p F P
0 g
s
.771 .303 .132 r
.21515 .42157 m .22049 .42379 L .21793 .42056 L p F P
0 g
s
.771 .303 .132 r
.21398 .42008 m .21515 .42157 L p .21793 .42056 L F P
0 g
s
.771 .303 .132 r
.21793 .42056 m .21619 .41985 L .21398 .42008 L p F P
0 g
s
.484 .358 .632 r
.67744 .35211 m .67661 .34711 L .66834 .35269 L p F P
0 g
s
.484 .358 .632 r
.66933 .35761 m .67744 .35211 L p .66834 .35269 L F P
0 g
s
.484 .358 .632 r
.66834 .35269 m .66914 .35746 L .66933 .35761 L p F P
0 g
s
.17 0 0 r
.41629 .35299 m .40687 .35277 L .40404 .35285 L p F P
0 g
s
.278 0 0 r
.38219 .47027 m .38811 .4711 L .37977 .47064 L closepath p F P
0 g
s
.738 .248 .075 r
.23197 .42888 m .23427 .43123 L .22882 .42918 L closepath p F P
0 g
s
.127 0 0 r
.47741 .46753 m .47987 .46663 L .46863 .468 L p F P
0 g
s
.127 0 0 r
.46863 .468 m .46782 .46828 L .47741 .46753 L p F P
0 g
s
.832 .431 .286 r
.19537 .40798 m .19371 .40447 L .19862 .40686 L p F P
0 g
s
.832 .431 .286 r
.19763 .40908 m .19537 .40798 L p .19862 .40686 L F P
0 g
s
.832 .431 .286 r
.19862 .40686 m .19945 .40857 L .19763 .40908 L p F P
0 g
s
.695 .18 .003 r
.2468 .43646 m .24902 .43833 L .24415 .43667 L closepath p F P
0 g
s
.153 0 0 r
.50178 .46318 m .50195 .46309 L .49231 .4643 L p F P
0 g
s
.153 0 0 r
.49231 .4643 m .49091 .46501 L .50178 .46318 L p F P
0 g
s
.675 .889 .976 r
.5802 .32036 m .58142 .32105 L .57235 .32537 L p F P
0 g
s
.675 .889 .976 r
.57235 .32537 m .57044 .32438 L .5802 .32036 L p F P
0 g
s
.359 .088 .36 r
.64618 .39504 m .64337 .39659 L .64388 .39324 L p F P
0 g
s
.359 .088 .36 r
.64388 .39324 m .65188 .38882 L .64618 .39504 L p F P
0 g
s
.679 .736 .893 r
.61928 .31645 m .6291 .3128 L .63152 .31591 L p F P
0 g
s
.687 .761 .908 r
.6291 .3128 m .61928 .31645 L .61686 .31382 L p F P
0 g
s
.689 .775 .917 r
.60706 .31767 m .61686 .31382 L .61928 .31645 L p F P
0 g
s
.055 .622 .736 r
.43151 .35242 m .43132 .35242 L .43061 .35245 L closepath p F P
0 g
s
.072 .634 .755 r
.42855 .35268 m .43132 .35242 L .43061 .35245 L p F P
0 g
s
.072 .634 .755 r
.41909 .35281 m .42855 .35268 L p .43061 .35245 L F P
0 g
s
.06 0 0 r
.40329 .35292 m .40404 .35285 L .39615 .35244 L p F P
0 g
s
.06 0 0 r
.39563 .35262 m .40329 .35292 L p .39615 .35244 L F P
0 g
s
.06 0 0 r
.39182 .35228 m .39563 .35262 L p .39615 .35244 L F P
0 g
s
.06 0 0 r
.39615 .35244 m .39409 .35234 L .39182 .35228 L p F P
0 g
s
.111 .601 .908 r
.301 .33682 m .3014 .33688 L .30751 .33886 L p F P
0 g
s
.135 .631 .911 r
.30913 .33812 m .3014 .33688 L .30751 .33886 L p F P
0 g
s
.135 .631 .911 r
.31087 .33859 m .30913 .33812 L p .30751 .33886 L F P
0 g
s
.135 .631 .911 r
.30751 .33886 m .31307 .33953 L .31087 .33859 L p F P
0 g
s
.125 .674 .734 r
.4558 .35046 m .46132 .3497 L .45485 .35056 L closepath p F P
0 g
s
.073 .635 .711 r
.45485 .35056 m .4558 .35046 L p .44356 .35163 L F P
0 g
s
.066 .63 .742 r
.44081 .35193 m .44332 .35165 L .43151 .35242 L p F P
0 g
s
.066 .63 .742 r
.43151 .35242 m .43132 .35242 L .44081 .35193 L p F P
0 g
s
.271 .66 .968 r
.27392 .3297 m .27501 .32983 L .28051 .33204 L p F P
0 g
s
.298 .689 .976 r
.28296 .33064 m .27501 .32983 L .28051 .33204 L p F P
0 g
s
.298 .689 .976 r
.28051 .33204 m .28596 .33242 L .28296 .33064 L p F P
0 g
s
.675 .72 .883 r
.64137 .31257 m .63152 .31591 L .6291 .3128 L p F P
0 g
s
.665 .694 .867 r
.63152 .31591 m .64137 .31257 L .6438 .31626 L p F P
0 g
s
.869 .597 .524 r
.16253 .37426 m .16703 .37685 L .16718 .37274 L p F P
0 g
s
.869 .597 .524 r
.16718 .37274 m .16268 .37015 L .16253 .37426 L p F P
0 g
s
.087 0 0 r
.39409 .35234 m .39182 .35228 L .38626 .35186 L closepath p F P
0 g
s
.621 .596 .804 r
.66724 .32125 m .6586 .32278 L .65614 .3178 L p F P
0 g
s
.34 0 0 r
.3563 .46772 m .35495 .46782 L .35242 .46724 L closepath p F P
0 g
s
.17 0 0 r
.58004 .43879 m .58144 .43719 L .57177 .44056 L p F P
0 g
s
.17 0 0 r
.57177 .44056 m .57028 .44226 L .58004 .43879 L p F P
0 g
s
.832 .693 .71 r
.15112 .3413 m .15523 .34394 L .15839 .33874 L p F P
0 g
s
.832 .693 .71 r
.15103 .34114 m .15112 .3413 L p .15839 .33874 L F P
0 g
s
.832 .693 .71 r
.15839 .33874 m .1542 .33599 L .15103 .34114 L p F P
0 g
s
.866 .62 .565 r
.15976 .36843 m .16268 .37015 L .16326 .36589 L p F P
0 g
s
.866 .62 .565 r
.16326 .36589 m .15972 .3638 L .15976 .36843 L p F P
0 g
s
.654 .905 .981 r
.57044 .32438 m .56071 .32825 L .55823 .32726 L p F P
0 g
s
.869 .572 .482 r
.16728 .38083 m .17182 .38339 L .17157 .37942 L p F P
0 g
s
.869 .572 .482 r
.17157 .37942 m .16703 .37685 L .16728 .38083 L p F P
0 g
s
.447 .721 .984 r
.25586 .32275 m .2488 .3227 L .25383 .32511 L p F P
0 g
s
.447 .721 .984 r
.25383 .32511 m .25888 .325 L .25586 .32275 L p F P
0 g
s
.423 .699 .979 r
.24684 .32266 m .2488 .3227 L .25383 .32511 L p F P
0 g
s
.139 0 0 r
.42855 .35268 m .41909 .35281 L .41629 .35299 L p F P
0 g
s
.859 .511 .391 r
.1828 .39291 m .18194 .39343 L .18165 .3923 L closepath p F P
0 g
s
.694 .814 .939 r
.61486 .31188 m .61686 .31382 L .60706 .31767 L p F P
0 g
s
.694 .814 .939 r
.60706 .31767 m .60632 .31701 L .61486 .31188 L p F P
0 g
s
.646 .732 .912 r
.20454 .31266 m .19539 .31565 L .19236 .31244 L p F P
0 g
s
.696 .733 .879 r
.18313 .3166 m .19236 .31244 L .19539 .31565 L p F P
0 g
s
.654 .733 .908 r
.19539 .31565 m .20454 .31266 L .20757 .3157 L p F P
0 g
s
0 0 0 r
.44356 .35163 m .44471 .35152 L .44332 .35165 L closepath p F P
0 g
s
.073 .635 .711 r
.44356 .35163 m .44471 .35152 L .45485 .35056 L p F P
0 g
s
0 .524 .755 r
.35528 .3483 m .35981 .34895 L .35262 .34775 L closepath p F P
0 g
s
.666 .135 0 r
.25283 .44116 m .24902 .43833 L .25494 .44031 L p F P
0 g
s
.666 .135 0 r
.2584 .44306 m .25283 .44116 L p .25494 .44031 L F P
0 g
s
.666 .135 0 r
.25494 .44031 m .25856 .44305 L .2584 .44306 L p F P
0 g
s
.093 0 0 r
.44081 .35193 m .43132 .35242 L .42855 .35268 L p F P
0 g
s
.861 .643 .605 r
.1599 .35883 m .15851 .35798 L .15926 .36141 L closepath p F P
0 g
s
.868 .545 .438 r
.17243 .38725 m .17701 .38979 L .17641 .38593 L p F P
0 g
s
.868 .545 .438 r
.17641 .38593 m .17182 .38339 L .17243 .38725 L p F P
0 g
s
.789 .333 .161 r
.21619 .41985 m .21398 .42008 L .21269 .41832 L closepath p F P
0 g
s
.69 .733 .884 r
.19236 .31244 m .18313 .3166 L .18009 .31323 L p F P
0 g
s
.453 0 0 r
.3164 .46056 m .31565 .46058 L .31459 .46019 L closepath p F P
0 g
s
0 .534 .713 r
.39028 .35232 m .39182 .35228 L .38626 .35186 L p F P
0 g
s
0 .534 .713 r
.3858 .35201 m .39028 .35232 L p .38626 .35186 L F P
0 g
s
0 .534 .713 r
.38626 .35186 m .3808 .3514 L .37961 .35129 L p F P
0 g
s
0 .534 .713 r
.37961 .35129 m .3858 .35201 L p .38626 .35186 L F P
0 g
s
.607 .051 0 r
.26918 .44772 m .26487 .44504 L .27106 .44691 L p F P
0 g
s
.607 .051 0 r
.27173 .44849 m .26918 .44772 L p .27106 .44691 L F P
0 g
s
.607 .051 0 r
.27106 .44691 m .27356 .44845 L .27173 .44849 L p F P
0 g
s
.71 .198 .009 r
.23758 .43422 m .24319 .43632 L .23991 .43332 L p F P
0 g
s
.71 .198 .009 r
.23991 .43332 m .23427 .43123 L .23758 .43422 L p F P
0 g
s
0 .532 .8 r
.32812 .34324 m .32919 .34343 L .33623 .34505 L p F P
0 g
s
.006 .566 .809 r
.33687 .34473 m .32919 .34343 L .33623 .34505 L p F P
0 g
s
.006 .566 .809 r
.33756 .34487 m .33687 .34473 L p .33623 .34505 L F P
0 g
s
.006 .566 .809 r
.33623 .34505 m .34023 .34557 L .33756 .34487 L p F P
0 g
s
.408 0 0 r
.34281 .46581 m .34406 .46616 L .35242 .46724 L p F P
0 g
s
.338 0 0 r
.35141 .46789 m .34406 .46616 L .35242 .46724 L p F P
0 g
s
.338 0 0 r
.35234 .46801 m .35141 .46789 L p .35242 .46724 L F P
0 g
s
.338 0 0 r
.35242 .46724 m .35495 .46782 L .35234 .46801 L p F P
0 g
s
.46 .88 .924 r
.52405 .33689 m .51438 .33993 L .5118 .3398 L p F P
0 g
s
.416 .86 .908 r
.50214 .34254 m .5118 .3398 L .51438 .33993 L p F P
0 g
s
.34 .819 .87 r
.49954 .34264 m .50153 .34256 L .49109 .345 L p F P
0 g
s
.34 .819 .87 r
.49109 .345 m .48989 .345 L .49954 .34264 L p F P
0 g
s
.647 .652 .841 r
.6438 .31626 m .65369 .31336 L .65448 .31475 L p F P
0 g
s
.657 .676 .856 r
.65369 .31336 m .6438 .31626 L .64137 .31257 L p F P
0 g
s
.259 0 0 r
.39439 .47108 m .3984 .47152 L .3929 .47135 L closepath p F P
0 g
s
.198 0 0 r
.56999 .44259 m .57028 .44226 L .56053 .44534 L p F P
0 g
s
.198 0 0 r
.56053 .44534 m .56015 .44576 L .56999 .44259 L p F P
0 g
s
.201 0 0 r
.59098 .4336 m .59216 .43196 L .5824 .43586 L p F P
0 g
s
.201 0 0 r
.5824 .43586 m .58144 .43719 L .59098 .4336 L p F P
0 g
s
.606 .733 .935 r
.21872 .31563 m .21969 .31655 L p .20757 .3157 L F P
0 g
s
.606 .733 .935 r
.20757 .3157 m .21517 .31403 L .21872 .31563 L p F P
0 g
s
.594 .728 .937 r
.21517 .31403 m .20757 .3157 L .20454 .31266 L p F P
0 g
s
0 0 0 r
.44471 .35152 m .44332 .35165 L .44081 .35193 L p F P
0 g
s
.401 0 0 r
.34281 .46581 m .34406 .46616 L .34211 .4659 L closepath p F P
0 g
s
.424 .227 .507 r
.67009 .3707 m .67001 .36666 L .66157 .37197 L p F P
0 g
s
.424 .227 .507 r
.66157 .37197 m .66164 .376 L .67009 .3707 L p F P
0 g
s
.181 0 0 r
.48007 .46654 m .48133 .46642 L .47987 .46663 L closepath p F P
0 g
s
.315 0 .191 r
.61393 .41839 m .61192 .41949 L .61383 .41866 L closepath p F P
0 g
s
.265 0 .107 r
.6126 .42122 m .61383 .41866 L .61192 .41949 L p F P
0 g
s
.265 0 .107 r
.60335 .42522 m .6126 .42122 L p .61192 .41949 L F P
0 g
s
.861 .512 .39 r
.17795 .39353 m .17701 .38979 L .18165 .3923 L p F P
0 g
s
.861 .512 .39 r
.17993 .3946 m .17795 .39353 L p .18165 .3923 L F P
0 g
s
.861 .512 .39 r
.18165 .3923 m .18194 .39343 L .17993 .3946 L p F P
0 g
s
.45 0 0 r
.31262 .46065 m .30745 .45867 L .31459 .46019 L p F P
0 g
s
.45 0 0 r
.31459 .46019 m .31565 .46058 L .31262 .46065 L p F P
0 g
s
.808 .373 .211 r
.20247 .4137 m .20756 .41602 L .20546 .41265 L p F P
0 g
s
.808 .373 .211 r
.20546 .41265 m .20035 .41035 L .20247 .4137 L p F P
0 g
s
.853 .663 .644 r
.15719 .35153 m .15584 .35069 L .15669 .35287 L closepath p F P
0 g
s
0 0 0 r
.45485 .35056 m .45309 .35075 L .44471 .35152 L closepath p F P
0 g
s
0 0 0 r
.45165 .35103 m .45309 .35075 L .44471 .35152 L p F P
0 g
s
0 0 0 r
.44438 .35168 m .45165 .35103 L p .44471 .35152 L F P
0 g
s
0 0 0 r
.44081 .35193 m .44438 .35168 L p .44471 .35152 L F P
0 g
s
.634 .908 .983 r
.54877 .3311 m .54851 .33101 L .55605 .3281 L closepath p F P
0 g
s
.116 0 0 r
.54596 .45216 m .54817 .45055 L .53802 .45328 L p F P
0 g
s
.116 0 0 r
.54373 .45277 m .54596 .45216 L p .53802 .45328 L F P
0 g
s
.116 0 0 r
.53802 .45328 m .53613 .45465 L .54373 .45277 L p F P
0 g
s
.696 .839 .951 r
.60463 .3155 m .59485 .31949 L .59242 .31772 L p F P
0 g
s
.691 .849 .959 r
.58265 .32175 m .59242 .31772 L .59485 .31949 L p F P
0 g
s
.064 0 0 r
.3808 .3514 m .37961 .35129 L .377 .35105 L closepath p F P
0 g
s
.52 .411 .671 r
.67115 .34455 m .67541 .34161 L .67646 .34637 L closepath p F P
0 g
s
.538 0 0 r
.28873 .45316 m .28858 .45316 L .28841 .45308 L closepath p F P
0 g
s
.783 .713 .786 r
.15814 .3233 m .16029 .32135 L .16448 .32412 L p F P
0 g
s
.783 .713 .786 r
.16448 .32412 m .16116 .32722 L .15814 .3233 L p F P
0 g
s
.769 .72 .808 r
.16448 .32412 m .17074 .31893 L .1677 .31536 L p F P
0 g
s
.769 .72 .808 r
.1677 .31536 m .16029 .32135 L .16448 .32412 L p F P
0 g
s
.754 .269 .085 r
.22332 .42692 m .22867 .42913 L .22587 .42598 L p F P
0 g
s
.754 .269 .085 r
.22587 .42598 m .22049 .42379 L .22332 .42692 L p F P
0 g
s
.805 .713 .764 r
.15838 .33042 m .16116 .32722 L .15814 .3233 L p F P
0 g
s
.535 0 0 r
.2855 .45315 m .28193 .45132 L .28841 .45308 L p F P
0 g
s
.535 0 0 r
.28841 .45308 m .28858 .45316 L .2855 .45315 L p F P
0 g
s
.86 .661 .632 r
.15669 .35287 m .15562 .35614 L .15851 .35798 L closepath p F P
0 g
s
.869 .647 .599 r
.15885 .36326 m .15926 .36141 L .15851 .35798 L p F P
0 g
s
.869 .647 .599 r
.1546 .36055 m .15885 .36326 L p .15851 .35798 L F P
0 g
s
.869 .647 .599 r
.15851 .35798 m .15562 .35614 L .1546 .36055 L p F P
0 g
s
.096 0 0 r
.48133 .46642 m .47987 .46663 L .47741 .46753 L p F P
0 g
s
.291 0 .181 r
.62294 .41445 m .62367 .41253 L .61393 .41839 L p F P
0 g
s
.291 0 .181 r
.61393 .41839 m .61383 .41866 L .62294 .41445 L p F P
0 g
s
.401 .685 .976 r
.2488 .3227 m .24684 .32266 L .24382 .32018 L p F P
0 g
s
.518 0 0 r
.29361 .45548 m .28858 .45316 L .2855 .45315 L p F P
0 g
s
.406 .184 .461 r
.6615 .37978 m .65564 .38327 L .65791 .37822 L p F P
0 g
s
.406 .184 .461 r
.65791 .37822 m .66164 .376 L .6615 .37978 L p F P
0 g
s
.095 0 0 r
.52389 .4583 m .52546 .45742 L .51498 .45972 L p F P
0 g
s
.095 0 0 r
.51498 .45972 m .5142 .46015 L .52389 .4583 L p F P
0 g
s
.133 0 0 r
.36744 .34994 m .36828 .35005 L .377 .35105 L p F P
0 g
s
.096 0 0 r
.37665 .35115 m .36828 .35005 L .377 .35105 L p F P
0 g
s
.096 0 0 r
.37677 .35116 m .37665 .35115 L p .377 .35105 L F P
0 g
s
.096 0 0 r
.377 .35105 m .37961 .35129 L .37677 .35116 L p F P
0 g
s
.239 0 0 r
.4066 .47153 m .40926 .47174 L .40571 .47171 L closepath p F P
0 g
s
.492 .357 .624 r
.66914 .35746 m .66933 .35761 L .66918 .35771 L closepath p F P
0 g
s
.603 .919 .974 r
.55605 .3281 m .54851 .33101 L .546 .33037 L p F P
0 g
s
.587 .914 .975 r
.53629 .33393 m .546 .33037 L .54851 .33101 L p F P
0 g
s
.004 .551 .831 r
.32812 .34324 m .32919 .34343 L .32729 .34294 L closepath p F P
0 g
s
.695 .815 .939 r
.61444 .31147 m .61486 .31188 L .60632 .31701 L p F P
0 g
s
.695 .815 .939 r
.60632 .31701 m .60463 .3155 L .61444 .31147 L p F P
0 g
s
.286 .66 .971 r
.27392 .3297 m .27501 .32983 L .27251 .32874 L closepath p F P
0 g
s
.103 0 0 r
.49091 .46501 m .48968 .46549 L .48133 .46642 L closepath p F P
0 g
s
.096 0 0 r
.48807 .4661 m .48968 .46549 L .48133 .46642 L p F P
0 g
s
.096 0 0 r
.48018 .46724 m .48807 .4661 L p .48133 .46642 L F P
0 g
s
.096 0 0 r
.47741 .46753 m .48018 .46724 L p .48133 .46642 L F P
0 g
s
.124 0 0 r
.47697 .46769 m .47741 .46753 L .46782 .46828 L p F P
0 g
s
.124 0 0 r
.46782 .46828 m .46567 .46903 L .47697 .46769 L p F P
0 g
s
.143 0 0 r
.53579 .4549 m .53613 .45465 L .52643 .45673 L p F P
0 g
s
.143 0 0 r
.52643 .45673 m .52546 .45742 L .53579 .4549 L p F P
0 g
s
.469 .317 .591 r
.67158 .36109 m .66971 .36234 L .66918 .35771 L p F P
0 g
s
.469 .317 .591 r
.66918 .35771 m .66933 .35761 L .67158 .36109 L p F P
0 g
s
.863 .665 .634 r
.15562 .35614 m .15669 .35287 L .15584 .35069 L p F P
0 g
s
.825 .418 .274 r
.19945 .40857 m .20035 .41035 L .19763 .40908 L closepath p F P
0 g
s
.847 .466 .329 r
.18404 .39961 m .18885 .40206 L .18749 .39845 L p F P
0 g
s
.847 .466 .329 r
.18749 .39845 m .18266 .39602 L .18404 .39961 L p F P
0 g
s
.737 .721 .837 r
.17539 .316 m .17074 .31893 L .1677 .31536 L p F P
0 g
s
.377 .133 .412 r
.65293 .38486 m .65267 .38773 L .65564 .38327 L closepath p F P
0 g
s
.467 .316 .592 r
.67799 .35676 m .67158 .36109 L .66933 .35761 L p F P
0 g
s
.467 .316 .592 r
.66933 .35761 m .67744 .35211 L .67799 .35676 L p F P
0 g
s
.805 .713 .764 r
.15814 .3233 m .15431 .32761 L .15838 .33042 L p F P
0 g
s
.82 .707 .741 r
.15005 .33322 m .1542 .33599 L .15838 .33042 L p F P
0 g
s
.82 .707 .741 r
.15838 .33042 m .15431 .32761 L .15005 .33322 L p F P
0 g
s
.129 .606 .918 r
.301 .33682 m .3014 .33688 L .3006 .33661 L closepath p F P
0 g
s
.234 0 .089 r
.62174 .41702 m .62294 .41445 L .61383 .41866 L p F P
0 g
s
.234 0 .089 r
.61383 .41866 m .6126 .42122 L .62174 .41702 L p F P
0 g
s
.844 .68 .679 r
.15523 .34394 m .15112 .3413 L .1539 .34665 L closepath p F P
0 g
s
.853 .676 .662 r
.1539 .34665 m .15298 .3488 L .15584 .35069 L closepath p F P
0 g
s
.863 .665 .634 r
.15144 .3534 m .15562 .35614 L p .15584 .35069 L F P
0 g
s
.863 .665 .634 r
.15584 .35069 m .15298 .3488 L .15144 .3534 L p F P
0 g
s
.549 .712 .947 r
.21969 .31655 m .22009 .3165 L .21872 .31563 L closepath p F P
0 g
s
.309 0 0 r
.34319 .46675 m .35141 .46789 L .34406 .46616 L p F P
0 g
s
.309 0 0 r
.33985 .46596 m .34319 .46675 L p .34406 .46616 L F P
0 g
s
.309 0 0 r
.34406 .46616 m .34211 .4659 L .33985 .46596 L p F P
0 g
s
.431 0 0 r
.32071 .4623 m .31565 .46058 L .31262 .46065 L p F P
0 g
s
.866 .642 .597 r
.15926 .36141 m .15885 .36326 L .15972 .3638 L closepath p F P
0 g
s
.128 0 0 r
.56802 .44442 m .56999 .44259 L .56015 .44576 L p F P
0 g
s
.128 0 0 r
.56015 .44576 m .55817 .44759 L .56802 .44442 L p F P
0 g
s
.523 .904 .952 r
.53376 .33358 m .53516 .33377 L .52536 .33707 L p F P
0 g
s
.523 .904 .952 r
.52536 .33707 m .52405 .33689 L .53376 .33358 L p F P
0 g
s
.101 0 0 r
.36744 .34994 m .36828 .35005 L .367 .34988 L closepath p F P
0 g
s
.856 .503 .383 r
.18194 .39343 m .18266 .39602 L .17993 .3946 L closepath p F P
0 g
s
.364 .834 .863 r
.51174 .33981 m .5118 .3398 L .50214 .34254 L p F P
0 g
s
.364 .834 .863 r
.50214 .34254 m .50153 .34256 L .51174 .33981 L p F P
0 g
s
.219 0 0 r
.41883 .47161 m .42085 .47171 L .41822 .47176 L closepath p F P
0 g
s
.267 0 .166 r
.62398 .4117 m .62367 .41253 L .62778 .40985 L closepath p F P
0 g
s
.118 .668 .726 r
.46132 .3497 m .45485 .35056 L .45309 .35075 L p F P
0 g
s
.15 0 0 r
.45556 .46965 m .4624 .46935 L .45415 .47011 L closepath p F P
0 g
s
.212 0 .026 r
.61172 .42276 m .6126 .42122 L .60335 .42522 L p F P
0 g
s
.212 0 .026 r
.60249 .42739 m .61172 .42276 L p .60335 .42522 L F P
0 g
s
.212 0 .026 r
.60335 .42522 m .60197 .42762 L .60249 .42739 L p F P
0 g
s
.543 .71 .949 r
.2257 .31276 m .22874 .31543 L .22009 .3165 L p F P
0 g
s
.543 .71 .949 r
.21666 .31369 m .2257 .31276 L p .22009 .3165 L F P
0 g
s
.543 .71 .949 r
.22009 .3165 m .21872 .31563 L .21666 .31369 L p F P
0 g
s
.107 .594 .907 r
.3027 .33625 m .30913 .33812 L .3014 .33688 L p F P
0 g
s
.107 .594 .907 r
.29802 .3353 m .3027 .33625 L p .3014 .33688 L F P
0 g
s
.107 .594 .907 r
.3014 .33688 m .3006 .33661 L .29802 .3353 L p F P
0 g
s
.686 .882 .971 r
.59026 .31637 m .59242 .31772 L .58265 .32175 L p F P
0 g
s
.686 .882 .971 r
.58265 .32175 m .58142 .32105 L .59026 .31637 L p F P
0 g
s
.353 0 0 r
.34211 .4659 m .33985 .46596 L .33606 .46495 L closepath p F P
0 g
s
.79 .333 .158 r
.20993 .41931 m .20756 .41602 L .21269 .41832 L p F P
0 g
s
.79 .333 .158 r
.21207 .42026 m .20993 .41931 L p .21269 .41832 L F P
0 g
s
.79 .333 .158 r
.21269 .41832 m .21398 .42008 L .21207 .42026 L p F P
0 g
s
.197 0 0 r
.43107 .47133 m .43338 .47137 L .43045 .47149 L closepath p F P
0 g
s
.621 .596 .804 r
.66832 .32047 m .66724 .32125 L p .65614 .3178 L F P
0 g
s
.621 .596 .804 r
.65614 .3178 m .66609 .31562 L .66832 .32047 L p F P
0 g
s
.624 .635 .84 r
.65448 .31475 m .65614 .3178 L .66609 .31562 L p F P
0 g
s
.174 0 0 r
.44331 .47067 m .4471 .47062 L .44242 .47094 L closepath p F P
0 g
s
0 .536 .815 r
.32959 .34318 m .33687 .34473 L .32919 .34343 L p F P
0 g
s
0 .536 .815 r
.32516 .34222 m .32959 .34318 L p .32919 .34343 L F P
0 g
s
0 .536 .815 r
.32919 .34343 m .32729 .34294 L .32516 .34222 L p F P
0 g
s
.873 .626 .563 r
.15828 .36751 m .15976 .36843 L .15972 .3638 L p F P
0 g
s
.873 .626 .563 r
.15972 .3638 m .15885 .36326 L .15828 .36751 L p F P
0 g
s
.268 .652 .967 r
.28231 .33027 m .28296 .33064 L .27501 .32983 L p F P
0 g
s
.268 .652 .967 r
.27769 .32863 m .28231 .33027 L p .27501 .32983 L F P
0 g
s
.268 .652 .967 r
.27092 .32768 m .27769 .32863 L p .27501 .32983 L F P
0 g
s
.268 .652 .967 r
.27501 .32983 m .27251 .32874 L .27092 .32768 L p F P
0 g
s
.194 .651 .943 r
.3006 .33661 m .29802 .3353 L .29509 .33497 L closepath p F P
0 g
s
.837 .433 .279 r
.19052 .40556 m .19537 .40798 L .19371 .40447 L p F P
0 g
s
.837 .433 .279 r
.19371 .40447 m .18885 .40206 L .19052 .40556 L p F P
0 g
s
.119 0 0 r
.36779 .35019 m .37665 .35115 L .36828 .35005 L p F P
0 g
s
.119 0 0 r
.36453 .34961 m .36779 .35019 L p .36828 .35005 L F P
0 g
s
.119 0 0 r
.36828 .35005 m .367 .34988 L .36453 .34961 L p F P
0 g
s
.639 .09 0 r
.247 .43915 m .25283 .44116 L .24902 .43833 L p F P
0 g
s
.639 .09 0 r
.24361 .43666 m .247 .43915 L p .24902 .43833 L F P
0 g
s
.639 .09 0 r
.24902 .43833 m .24415 .43667 L .24361 .43666 L p F P
0 g
s
.308 0 0 r
.35495 .46782 m .36008 .46887 L .35234 .46801 L closepath p F P
0 g
s
.293 0 .233 r
.63383 .40435 m .63339 .40584 L .63844 .40195 L closepath p F P
0 g
s
.726 .727 .851 r
.17539 .316 m .18009 .31323 L .17704 .30988 L p F P
0 g
s
.726 .727 .851 r
.17704 .30988 m .1712 .31323 L .17539 .316 L p F P
0 g
s
.737 .721 .837 r
.1677 .31536 m .1712 .31323 L .17539 .316 L p F P
0 g
s
.419 0 0 r
.31215 .46065 m .31262 .46065 L .30745 .45867 L p F P
0 g
s
.419 0 0 r
.30621 .45933 m .31215 .46065 L p .30745 .45867 L F P
0 g
s
.419 0 0 r
.30057 .45723 m .30621 .45933 L p .30745 .45867 L F P
0 g
s
.419 0 0 r
.30745 .45867 m .30074 .45723 L .30057 .45723 L p F P
0 g
s
.649 .113 0 r
.25856 .44305 m .25871 .44315 L .26487 .44504 L p F P
0 g
s
.594 .032 0 r
.26308 .44581 m .26918 .44772 L .26487 .44504 L p F P
0 g
s
.594 .032 0 r
.26487 .44504 m .25871 .44315 L .26308 .44581 L p F P
0 g
s
.117 0 0 r
.367 .34988 m .36453 .34961 L .35981 .34895 L closepath p F P
0 g
s
.42 .71 .983 r
.25284 .3205 m .24401 .32019 L .2488 .3227 L p F P
0 g
s
.42 .71 .983 r
.2488 .3227 m .25586 .32275 L .25284 .3205 L p F P
0 g
s
.401 .685 .976 r
.24382 .32018 m .24401 .32019 L .2488 .3227 L p F P
0 g
s
.173 0 0 r
.60194 .42766 m .60197 .42762 L .59256 .4314 L p F P
0 g
s
.173 0 0 r
.59256 .4314 m .59216 .43196 L .60194 .42766 L p F P
0 g
s
.872 .6 .523 r
.15879 .37205 m .16253 .37426 L .16268 .37015 L p F P
0 g
s
.872 .6 .523 r
.16268 .37015 m .15976 .36843 L .15879 .37205 L p F P
0 g
s
.038 .578 .848 r
.32729 .34294 m .32516 .34222 L .32219 .34178 L closepath p F P
0 g
s
.854 .681 .667 r
.15298 .3488 m .1539 .34665 L .15112 .3413 L p F P
0 g
s
.128 .676 .741 r
.46607 .3491 m .46536 .34916 L .46132 .3497 L closepath p F P
0 g
s
.118 .668 .726 r
.46294 .3496 m .46536 .34916 L .46132 .3497 L p F P
0 g
s
.118 .668 .726 r
.46116 .34982 m .46294 .3496 L p .46132 .3497 L F P
0 g
s
.118 .668 .726 r
.45309 .35075 m .46116 .34982 L p .46132 .3497 L F P
0 g
s
.693 .167 0 r
.23202 .4321 m .23758 .43422 L .23427 .43123 L p F P
0 g
s
.693 .167 0 r
.22873 .42918 m .23202 .4321 L p .23427 .43123 L F P
0 g
s
.693 .167 0 r
.23427 .43123 m .22882 .42918 L .22873 .42918 L p F P
0 g
s
.872 .574 .479 r
.16279 .37823 m .16728 .38083 L .16703 .37685 L p F P
0 g
s
.872 .574 .479 r
.16703 .37685 m .16253 .37426 L .16279 .37823 L p F P
0 g
s
.876 .63 .563 r
.15402 .36481 m .15828 .36751 L .15885 .36326 L p F P
0 g
s
.876 .63 .563 r
.15885 .36326 m .1546 .36055 L .15402 .36481 L p F P
0 g
s
.608 .733 .934 r
.21872 .31563 m .21666 .31369 L .21517 .31403 L closepath p F P
0 g
s
.832 .692 .709 r
.14809 .33631 m .15005 .33322 L .1542 .33599 L p F P
0 g
s
.832 .692 .709 r
.1542 .33599 m .15103 .34114 L .14809 .33631 L p F P
0 g
s
.547 .914 .953 r
.54477 .33019 m .546 .33037 L .53629 .33393 L p F P
0 g
s
.547 .914 .953 r
.53629 .33393 m .53516 .33377 L .54477 .33019 L p F P
0 g
s
.072 0 0 r
.49934 .46415 m .50178 .46318 L .49091 .46501 L p F P
0 g
s
.072 0 0 r
.49091 .46501 m .48968 .46549 L .49934 .46415 L p F P
0 g
s
.264 .772 .8 r
.4983 .34282 m .49954 .34264 L .48989 .345 L p F P
0 g
s
.264 .772 .8 r
.48989 .345 m .48778 .34521 L .4983 .34282 L p F P
0 g
s
.238 .755 .801 r
.48778 .34521 m .48989 .345 L p .47763 .34722 L F P
0 g
s
.126 0 0 r
.42085 .47171 m .41822 .47176 L .41603 .47207 L p F P
0 g
s
.164 0 0 r
.41822 .47176 m .41603 .47207 L .40926 .47174 L closepath p F P
0 g
s
.871 .546 .434 r
.16789 .38468 m .17243 .38725 L .17182 .38339 L p F P
0 g
s
.871 .546 .434 r
.17182 .38339 m .16728 .38083 L .16789 .38468 L p F P
0 g
s
.421 0 0 r
.32772 .46355 m .32819 .4637 L .33606 .46495 L p F P
0 g
s
.351 0 0 r
.33515 .46555 m .32819 .4637 L .33606 .46495 L p F P
0 g
s
.351 0 0 r
.33794 .466 m .33515 .46555 L p .33606 .46495 L F P
0 g
s
.351 0 0 r
.33606 .46495 m .33985 .46596 L .33794 .466 L p F P
0 g
s
.146 0 0 r
.41463 .47226 m .41603 .47207 L .40926 .47174 L p F P
0 g
s
.146 0 0 r
.40894 .47222 m .41463 .47226 L p .40926 .47174 L F P
0 g
s
.146 0 0 r
.40377 .47194 m .40894 .47222 L p .40926 .47174 L F P
0 g
s
.146 0 0 r
.40926 .47174 m .40571 .47171 L .40377 .47194 L p F P
0 g
s
.54 0 0 r
.28039 .45204 m .27548 .44955 L .28193 .45132 L p F P
0 g
s
.54 0 0 r
.28429 .45313 m .28039 .45204 L p .28193 .45132 L F P
0 g
s
.54 0 0 r
.28193 .45132 m .2855 .45315 L .28429 .45313 L p F P
0 g
s
.185 0 0 r
.40571 .47171 m .40377 .47194 L .3984 .47152 L closepath p F P
0 g
s
.584 .022 0 r
.27356 .44845 m .27548 .44955 L .27173 .44849 L closepath p F P
0 g
s
.142 0 0 r
.43045 .47149 m .42829 .47186 L .42085 .47171 L closepath p F P
0 g
s
.126 0 0 r
.42697 .47207 m .42829 .47186 L .42085 .47171 L p F P
0 g
s
.126 0 0 r
.42059 .47219 m .42697 .47207 L p .42085 .47171 L F P
0 g
s
.126 0 0 r
.41603 .47207 m .42059 .47219 L p .42085 .47171 L F P
0 g
s
.35 .826 .856 r
.50921 .33998 m .51174 .33981 L .50153 .34256 L p F P
0 g
s
.35 .826 .856 r
.50153 .34256 m .49954 .34264 L .50921 .33998 L p F P
0 g
s
.13 0 0 r
.37961 .35129 m .3858 .35201 L .37677 .35116 L closepath p F P
0 g
s
.871 .65 .6 r
.1504 .35782 m .1546 .36055 L .15562 .35614 L p F P
0 g
s
.871 .65 .6 r
.15562 .35614 m .15144 .3534 L .1504 .35782 L p F P
0 g
s
.264 0 .163 r
.62778 .40985 m .62367 .41253 L .62294 .41445 L p F P
0 g
s
.376 .131 .411 r
.66118 .38333 m .6615 .37978 L .65564 .38327 L p F P
0 g
s
.376 .131 .411 r
.65261 .38842 m .66118 .38333 L p .65564 .38327 L F P
0 g
s
.376 .131 .411 r
.65564 .38327 m .65267 .38773 L .65261 .38842 L p F P
0 g
s
.092 0 0 r
.52298 .4588 m .52389 .4583 L .5142 .46015 L p F P
0 g
s
.092 0 0 r
.5142 .46015 m .51246 .4611 L .52298 .4588 L p F P
0 g
s
.476 .718 .976 r
.24348 .3199 m .24382 .32018 L p .23177 .31811 L F P
0 g
s
.476 .718 .976 r
.23177 .31811 m .23882 .31782 L .24348 .3199 L p F P
0 g
s
.458 .706 .975 r
.23882 .31782 m .23177 .31811 L .22874 .31543 L p F P
0 g
s
.318 .68 .977 r
.25888 .325 m .26389 .32541 L .26944 .32763 L p F P
0 g
s
.293 .66 .971 r
.26389 .32541 m .25888 .325 L .25586 .32275 L p F P
0 g
s
.55 .476 .724 r
.6737 .33523 m .67422 .33527 L .6738 .33558 L closepath p F P
0 g
s
.548 .489 .741 r
.67155 .32868 m .6737 .33523 L .67422 .33527 L p F P
0 g
s
.675 .72 .883 r
.6291 .3128 m .63896 .30923 L .64137 .31257 L p F P
0 g
s
.684 .745 .898 r
.63896 .30923 m .6291 .3128 L .62669 .30999 L p F P
0 g
s
.687 .761 .908 r
.61686 .31382 m .62669 .30999 L .6291 .3128 L p F P
0 g
s
.534 .446 .702 r
.68208 .33679 m .67541 .34161 L .6738 .33558 L p F P
0 g
s
.534 .446 .702 r
.6738 .33558 m .67422 .33527 L .68208 .33679 L p F P
0 g
s
.67 .902 .978 r
.5802 .32036 m .57044 .32438 L .56797 .32333 L p F P
0 g
s
.654 .905 .981 r
.55823 .32726 m .56797 .32333 L .57044 .32438 L p F P
0 g
s
.806 .362 .189 r
.19744 .41136 m .20247 .4137 L .20035 .41035 L p F P
0 g
s
.806 .362 .189 r
.1961 .40923 m .19744 .41136 L p .20035 .41035 L F P
0 g
s
.806 .362 .189 r
.20035 .41035 m .19763 .40908 L .1961 .40923 L p F P
0 g
s
.166 0 0 r
.40201 .47214 m .40377 .47194 L .3984 .47152 L p F P
0 g
s
.166 0 0 r
.39803 .47201 m .40201 .47214 L p .3984 .47152 L F P
0 g
s
.166 0 0 r
.39153 .47147 m .39803 .47201 L p .3984 .47152 L F P
0 g
s
.166 0 0 r
.3984 .47152 m .3929 .47135 L .39153 .47147 L p F P
0 g
s
.365 .704 .985 r
.27251 .32874 m .27092 .32768 L .26944 .32763 L closepath p F P
0 g
s
.105 0 0 r
.43338 .47137 m .43045 .47149 L .42829 .47186 L p F P
0 g
s
0 .501 .757 r
.34023 .34557 m .34411 .34629 L .33756 .34487 L closepath p F P
0 g
s
.162 .702 .759 r
.47496 .34763 m .47705 .34731 L .46607 .3491 L p F P
0 g
s
.162 .702 .759 r
.46607 .3491 m .46536 .34916 L .47496 .34763 L p F P
0 g
s
.575 .523 .759 r
.6711 .32744 m .67338 .32734 L .67155 .32868 L closepath p F P
0 g
s
.548 .489 .741 r
.68121 .3275 m .67338 .32734 L .67155 .32868 L p F P
0 g
s
.548 .489 .741 r
.68186 .32962 m .68121 .3275 L p .67155 .32868 L F P
0 g
s
.548 .489 .741 r
.67422 .33527 m .68186 .32962 L p .67155 .32868 L F P
0 g
s
.158 0 0 r
.54835 .45038 m .55518 .44848 L .54817 .45055 L closepath p F P
0 g
s
.751 .26 .068 r
.21802 .42469 m .22332 .42692 L .22049 .42379 L p F P
0 g
s
.751 .26 .068 r
.22049 .42379 m .21515 .42157 L .21802 .42469 L p F P
0 g
s
.315 .019 .293 r
.64337 .39659 m .64308 .39793 L .64618 .39504 L closepath p F P
0 g
s
.119 0 0 r
.44242 .47094 m .44057 .4713 L .43338 .47137 L closepath p F P
0 g
s
.105 0 0 r
.43904 .47159 m .44057 .4713 L .43338 .47137 L p F P
0 g
s
.105 0 0 r
.43316 .47184 m .43904 .47159 L p .43338 .47137 L F P
0 g
s
.105 0 0 r
.42829 .47186 m .43316 .47184 L p .43338 .47137 L F P
0 g
s
.866 .517 .388 r
.17336 .39099 m .17795 .39353 L .17701 .38979 L p F P
0 g
s
.866 .517 .388 r
.17701 .38979 m .17243 .38725 L .17336 .39099 L p F P
0 g
s
.646 .732 .912 r
.19236 .31244 m .20149 .30963 L .20454 .31266 L p F P
0 g
s
.638 .731 .915 r
.20149 .30963 m .19236 .31244 L .18931 .30925 L p F P
0 g
s
.69 .733 .884 r
.18009 .31323 m .18931 .30925 L .19236 .31244 L p F P
0 g
s
.206 0 0 r
.3929 .47135 m .39153 .47147 L .38811 .4711 L closepath p F P
0 g
s
.695 .8 .93 r
.62427 .30745 m .62669 .30999 L .61686 .31382 L p F P
0 g
s
.695 .8 .93 r
.61715 .31036 m .62427 .30745 L p .61686 .31382 L F P
0 g
s
.695 .8 .93 r
.61686 .31382 m .61486 .31188 L .61715 .31036 L p F P
0 g
s
.587 .534 .763 r
.67338 .32734 m .6711 .32744 L .66858 .32105 L p F P
0 g
s
0 .509 .738 r
.36277 .34948 m .36453 .34961 L .35981 .34895 L p F P
0 g
s
0 .509 .738 r
.35947 .34902 m .36277 .34948 L p .35981 .34895 L F P
0 g
s
0 .509 .738 r
.35981 .34895 m .35262 .34775 L .35237 .3477 L p F P
0 g
s
0 .509 .738 r
.35237 .3477 m .35947 .34902 L p .35981 .34895 L F P
0 g
s
.684 .733 .888 r
.18931 .30925 m .18009 .31323 L .17704 .30988 L p F P
0 g
s
.657 .676 .856 r
.64137 .31257 m .65126 .3094 L .65369 .31336 L p F P
0 g
s
.668 .702 .872 r
.65126 .3094 m .64137 .31257 L .63896 .30923 L p F P
0 g
s
.533 .449 .705 r
.68352 .33573 m .68208 .33679 L .67422 .33527 L p F P
0 g
s
.533 .449 .705 r
.67422 .33527 m .68186 .32962 L .68352 .33573 L p F P
0 g
s
.14 .612 .923 r
.28596 .33242 m .28911 .33293 L .29509 .33497 L p F P
0 g
s
.11 .585 .913 r
.28911 .33293 m .28596 .33242 L .28296 .33064 L p F P
0 g
s
.391 .172 .458 r
.66997 .37449 m .67009 .3707 L .66164 .376 L p F P
0 g
s
.391 .172 .458 r
.66164 .376 m .6615 .37978 L .66997 .37449 L p F P
0 g
s
.137 0 0 r
.58983 .43493 m .59098 .4336 L .58144 .43719 L p F P
0 g
s
.137 0 0 r
.58144 .43719 m .58004 .43879 L .58983 .43493 L p F P
0 g
s
.854 .681 .667 r
.14886 .34602 m .15298 .3488 L p .15112 .3413 L F P
0 g
s
.865 .669 .635 r
.14731 .35063 m .15144 .3534 L .15298 .3488 L p F P
0 g
s
.865 .669 .635 r
.15298 .3488 m .14886 .34602 L .14731 .35063 L p F P
0 g
s
.639 .648 .843 r
.65369 .31336 m .65804 .3122 L .65448 .31475 L closepath p F P
0 g
s
.624 .635 .84 r
.66364 .31077 m .65804 .3122 L .65448 .31475 L p F P
0 g
s
.624 .635 .84 r
.66609 .31562 m .66364 .31077 L p .65448 .31475 L F P
0 g
s
.441 .269 .55 r
.67236 .36509 m .67001 .36666 L .66971 .36234 L p F P
0 g
s
.441 .269 .55 r
.66971 .36234 m .67158 .36109 L .67236 .36509 L p F P
0 g
s
.184 0 0 r
.38907 .47167 m .39153 .47147 L .38811 .4711 L p F P
0 g
s
.184 0 0 r
.38769 .47159 m .38907 .47167 L p .38811 .4711 L F P
0 g
s
.184 0 0 r
.37931 .47066 m .38769 .47159 L p .38811 .4711 L F P
0 g
s
.184 0 0 r
.38811 .4711 m .37977 .47064 L .37931 .47066 L p F P
0 g
s
.31 0 .238 r
.63339 .40584 m .62778 .40985 L .63297 .40729 L closepath p F P
0 g
s
.264 0 .163 r
.63193 .41003 m .63297 .40729 L .62778 .40985 L p F P
0 g
s
.264 0 .163 r
.62294 .41445 m .63193 .41003 L p .62778 .40985 L F P
0 g
s
.169 0 0 r
.60039 .4298 m .60194 .42766 L .59216 .43196 L p F P
0 g
s
.169 0 0 r
.59216 .43196 m .59098 .4336 L .60039 .4298 L p F P
0 g
s
.065 0 0 r
.53361 .45614 m .53579 .4549 L .52546 .45742 L p F P
0 g
s
.065 0 0 r
.52546 .45742 m .52389 .4583 L .53361 .45614 L p F P
0 g
s
0 .529 .814 r
.31307 .33953 m .31552 .34001 L .32219 .34178 L p F P
0 g
s
.027 .555 .858 r
.31307 .33953 m .31552 .34001 L .31087 .33859 L closepath p F P
0 g
s
.3 0 0 r
.36712 .46944 m .36899 .46976 L .37828 .47052 L p F P
0 g
s
.292 0 0 r
.36712 .46944 m .36899 .46976 L .36625 .46953 L closepath p F P
0 g
s
.026 .572 .837 r
.32219 .34125 m .31552 .34001 L .32219 .34178 L p F P
0 g
s
.026 .572 .837 r
.32219 .34178 m .32516 .34222 L .32219 .34125 L p F P
0 g
s
.19 .65 .94 r
.29502 .33381 m .28911 .33293 L .29509 .33497 L p F P
0 g
s
.19 .65 .94 r
.29509 .33497 m .29802 .3353 L .29502 .33381 L p F P
0 g
s
.781 .717 .792 r
.16029 .32135 m .15814 .3233 L .15511 .31946 L p F P
0 g
s
.804 .716 .767 r
.15431 .32761 m .15814 .3233 L .15511 .31946 L p F P
0 g
s
.081 0 0 r
.55518 .44848 m .54817 .45055 L .54596 .45216 L p F P
0 g
s
.766 .722 .811 r
.16029 .32135 m .1677 .31536 L .16465 .31183 L p F P
0 g
s
.766 .722 .811 r
.16465 .31183 m .15613 .31856 L .16029 .32135 L p F P
0 g
s
.781 .717 .792 r
.15511 .31946 m .15613 .31856 L .16029 .32135 L p F P
0 g
s
.084 0 0 r
.4471 .47062 m .44242 .47094 L .44057 .4713 L p F P
0 g
s
.608 .918 .976 r
.55823 .32726 m .55605 .3281 L .55816 .32725 L closepath p F P
0 g
s
.603 .919 .974 r
.55574 .32659 m .55816 .32725 L .55605 .3281 L p F P
0 g
s
.603 .919 .974 r
.546 .33037 m .55574 .32659 L p .55605 .3281 L F P
0 g
s
.238 .755 .801 r
.47763 .34722 m .4828 .34616 L .48778 .34521 L p F P
0 g
s
.182 .714 .739 r
.47763 .34722 m .4828 .34616 L .47705 .34731 L closepath p F P
0 g
s
.602 .574 .795 r
.66724 .32125 m .66832 .32047 L .66858 .32105 L closepath p F P
0 g
s
.413 0 0 r
.32772 .46355 m .32819 .4637 L .32743 .46357 L closepath p F P
0 g
s
.462 0 0 r
.30074 .45723 m .30057 .45723 L .30035 .45714 L closepath p F P
0 g
s
.779 .314 .14 r
.21398 .42008 m .21515 .42157 L .21207 .42026 L closepath p F P
0 g
s
.848 .462 .316 r
.17928 .39715 m .18404 .39961 L .18266 .39602 L p F P
0 g
s
.848 .462 .316 r
.17847 .39501 m .17928 .39715 L p .18266 .39602 L F P
0 g
s
.848 .462 .316 r
.18266 .39602 m .17993 .3946 L .17847 .39501 L p F P
0 g
s
.584 .722 .938 r
.21033 .31151 m .20454 .31266 L .20149 .30963 L p F P
0 g
s
.594 .728 .937 r
.20454 .31266 m .21033 .31151 L .21517 .31403 L p F P
0 g
s
.498 .397 .671 r
.68392 .33747 m .68208 .33679 L .67541 .34161 L p F P
0 g
s
.498 .397 .671 r
.68472 .34122 m .68392 .33747 L p .67541 .34161 L F P
0 g
s
.498 .397 .671 r
.67716 .34671 m .68472 .34122 L p .67541 .34161 L F P
0 g
s
.498 .397 .671 r
.67541 .34161 m .67646 .34637 L .67716 .34671 L p F P
0 g
s
.457 0 0 r
.29752 .45711 m .29361 .45548 L .30035 .45714 L p F P
0 g
s
.457 0 0 r
.30035 .45714 m .30057 .45723 L .29752 .45711 L p F P
0 g
s
.696 .839 .951 r
.59242 .31772 m .60221 .3136 L .60463 .3155 L p F P
0 g
s
.7 .828 .943 r
.61444 .31147 m .60463 .3155 L .60221 .3136 L p F P
0 g
s
.142 0 0 r
.39182 .35228 m .39563 .35262 L .39028 .35232 L closepath p F P
0 g
s
.67 .134 0 r
.24415 .43667 m .24361 .43666 L .24319 .43632 L closepath p F P
0 g
s
.686 .883 .971 r
.58998 .31619 m .59026 .31637 L .58142 .32105 L p F P
0 g
s
.686 .883 .971 r
.58142 .32105 m .5802 .32036 L .58998 .31619 L p F P
0 g
s
.39 .143 .414 r
.65267 .38773 m .65188 .38882 L .65261 .38842 L closepath p F P
0 g
s
.225 0 0 r
.37977 .47064 m .37931 .47066 L .37828 .47052 L closepath p F P
0 g
s
.096 0 0 r
.45415 .47011 m .45285 .47039 L .4471 .47062 L closepath p F P
0 g
s
.084 0 0 r
.45086 .47082 m .45285 .47039 L .4471 .47062 L p F P
0 g
s
.084 0 0 r
.44693 .47109 m .45086 .47082 L p .4471 .47062 L F P
0 g
s
.084 0 0 r
.44057 .4713 m .44693 .47109 L p .4471 .47062 L F P
0 g
s
.166 0 0 r
.57968 .43921 m .58004 .43879 L .57028 .44226 L p F P
0 g
s
.166 0 0 r
.57028 .44226 m .56999 .44259 L .57968 .43921 L p F P
0 g
s
.437 0 0 r
.30621 .45933 m .30057 .45723 L .29752 .45711 L p F P
0 g
s
.471 .889 .914 r
.53163 .33351 m .53376 .33358 L .52405 .33689 L p F P
0 g
s
.471 .889 .914 r
.52405 .33689 m .52179 .33681 L .53163 .33351 L p F P
0 g
s
.46 .88 .924 r
.52179 .33681 m .52405 .33689 L p .5118 .3398 L F P
0 g
s
.218 0 0 r
.37643 .47081 m .36899 .46976 L .37828 .47052 L p F P
0 g
s
.218 0 0 r
.37828 .47052 m .37931 .47066 L .37643 .47081 L p F P
0 g
s
.845 .69 .69 r
.15103 .34114 m .15099 .34121 L .15112 .3413 L closepath p F P
0 g
s
.854 .681 .667 r
.15112 .3413 m .15099 .34121 L .14886 .34602 L p F P
0 g
s
.646 .107 0 r
.25856 .44305 m .25871 .44315 L .2584 .44306 L closepath p F P
0 g
s
.318 0 0 r
.32742 .46423 m .33515 .46555 L .32819 .4637 L p F P
0 g
s
.318 0 0 r
.32473 .46351 m .32742 .46423 L p .32819 .4637 L F P
0 g
s
.318 0 0 r
.32819 .4637 m .32743 .46357 L .32473 .46351 L p F P
0 g
s
.846 .694 .694 r
.15099 .34121 m .15103 .34114 L .14809 .33631 L p F P
0 g
s
.608 .734 .934 r
.21362 .31084 m .21033 .31151 L .21517 .31403 L p F P
0 g
s
.608 .734 .934 r
.21517 .31403 m .21666 .31369 L .21362 .31084 L p F P
0 g
s
.363 .704 .985 r
.2679 .32569 m .26389 .32541 L .26944 .32763 L p F P
0 g
s
.363 .704 .985 r
.26944 .32763 m .27092 .32768 L .2679 .32569 L p F P
0 g
s
.878 .607 .524 r
.15811 .37163 m .15879 .37205 L .15976 .36843 L p F P
0 g
s
.878 .607 .524 r
.15976 .36843 m .15828 .36751 L .15811 .37163 L p F P
0 g
s
.349 .076 .351 r
.65209 .39174 m .64618 .39504 L .65188 .38882 L p F P
0 g
s
.349 .076 .351 r
.65188 .38882 m .65261 .38842 L .65209 .39174 L p F P
0 g
s
.791 .33 .145 r
.20487 .41698 m .20993 .41931 L .20756 .41602 L p F P
0 g
s
.791 .33 .145 r
.20756 .41602 m .20247 .4137 L .20487 .41698 L p F P
0 g
s
.804 .716 .767 r
.15511 .31946 m .15029 .32477 L .15431 .32761 L p F P
0 g
s
.82 .71 .744 r
.14595 .33041 m .15005 .33322 L .15431 .32761 L p F P
0 g
s
.82 .71 .744 r
.15431 .32761 m .15029 .32477 L .14595 .33041 L p F P
0 g
s
.846 .694 .694 r
.14809 .33631 m .14696 .33839 L .15099 .34121 L p F P
0 g
s
.856 .685 .669 r
.1448 .34322 m .14886 .34602 L .15099 .34121 L p F P
0 g
s
.856 .685 .669 r
.15099 .34121 m .14696 .33839 L .1448 .34322 L p F P
0 g
s
.733 .723 .842 r
.1712 .31323 m .1677 .31536 L .16465 .31183 L p F P
0 g
s
.29 0 .231 r
.63844 .40195 m .63339 .40584 L .63297 .40729 L p F P
0 g
s
.648 .658 .846 r
.65804 .3122 m .65369 .31336 L .65126 .3094 L p F P
0 g
s
.365 0 0 r
.32743 .46357 m .32473 .46351 L .32071 .4623 L closepath p F P
0 g
s
.578 .008 0 r
.25702 .44388 m .26308 .44581 L .25871 .44315 L p F P
0 g
s
.578 .008 0 r
.25542 .44289 m .25702 .44388 L p .25871 .44315 L F P
0 g
s
.578 .008 0 r
.25871 .44315 m .2584 .44306 L .25542 .44289 L p F P
0 g
s
.669 .131 0 r
.24043 .43652 m .23758 .43422 L .24319 .43632 L p F P
0 g
s
.669 .131 0 r
.24319 .43632 m .24361 .43666 L .24043 .43652 L p F P
0 g
s
.124 0 0 r
.50195 .46309 m .50346 .46286 L .50178 .46318 L closepath p F P
0 g
s
.82 .389 .215 r
.19763 .40908 m .1961 .40923 L .19537 .40798 L closepath p F P
0 g
s
.616 .057 0 r
.2584 .44306 m .25542 .44289 L .25283 .44116 L closepath p F P
0 g
s
.587 .534 .763 r
.67959 .32268 m .67338 .32734 L p .66858 .32105 L F P
0 g
s
.587 .534 .763 r
.66858 .32105 m .67863 .32009 L .67959 .32268 L p F P
0 g
s
.587 .566 .797 r
.66832 .32047 m .66858 .32105 L .67863 .32009 L p F P
0 g
s
.624 .923 .975 r
.56742 .32316 m .56797 .32333 L .55823 .32726 L p F P
0 g
s
.624 .923 .975 r
.55823 .32726 m .55816 .32725 L .56742 .32316 L p F P
0 g
s
.562 .502 .746 r
.67338 .32734 m .67959 .32268 L .68121 .3275 L closepath p F P
0 g
s
0 .525 .751 r
.35262 .34775 m .35237 .3477 L .35192 .34764 L closepath p F P
0 g
s
0 0 0 r
.474 .34788 m .47496 .34763 L .46536 .34916 L p F P
0 g
s
0 0 0 r
.46536 .34916 m .46294 .3496 L .474 .34788 L p F P
0 g
s
.607 .589 .807 r
.66609 .31562 m .66832 .32047 L .67633 .3144 L p F P
0 g
s
.587 .566 .797 r
.67863 .32009 m .67633 .3144 L .66832 .32047 L p F P
0 g
s
.061 0 0 r
.4624 .46935 m .45415 .47011 L .45285 .47039 L p F P
0 g
s
.627 .925 .974 r
.5655 .32257 m .56742 .32316 L .55816 .32725 L p F P
0 g
s
.627 .925 .974 r
.55816 .32725 m .55574 .32659 L .5655 .32257 L p F P
0 g
s
.838 .431 .27 r
.18572 .40311 m .19052 .40556 L .18885 .40206 L p F P
0 g
s
.838 .431 .27 r
.18885 .40206 m .18404 .39961 L .18572 .40311 L p F P
0 g
s
0 .504 .717 r
.34943 .34724 m .34411 .34629 L .35192 .34764 L p F P
0 g
s
0 .504 .717 r
.35192 .34764 m .35237 .3477 L .34943 .34724 L p F P
0 g
s
.33 .061 .346 r
.66068 .38666 m .66118 .38333 L .65261 .38842 L p F P
0 g
s
.33 .061 .346 r
.65261 .38842 m .65209 .39174 L .66068 .38666 L p F P
0 g
s
.719 .206 .002 r
.22882 .42918 m .22873 .42918 L .22867 .42913 L closepath p F P
0 g
s
.039 0 0 r
.50346 .46286 m .50178 .46318 L .49934 .46415 L p F P
0 g
s
.29 0 .231 r
.64182 .40265 m .64268 .39972 L .63844 .40195 L p F P
0 g
s
.29 0 .231 r
.63297 .40729 m .64182 .40265 L p .63844 .40195 L F P
0 g
s
.331 .031 .297 r
.64308 .39793 m .63844 .40195 L .64268 .39972 L closepath p F P
0 g
s
.405 .683 .974 r
.24382 .32018 m .24401 .32019 L .24348 .3199 L closepath p F P
0 g
s
.505 0 0 r
.27405 .45022 m .28039 .45204 L .27548 .44955 L p F P
0 g
s
.505 0 0 r
.27044 .44841 m .27405 .45022 L p .27548 .44955 L F P
0 g
s
.505 0 0 r
.27548 .44955 m .27173 .44849 L .27044 .44841 L p F P
0 g
s
.17 0 0 r
.41589 .35304 m .41629 .35299 L p .40404 .35285 L F P
0 g
s
.17 0 0 r
.40404 .35285 m .40618 .35297 L .41589 .35304 L p F P
0 g
s
.138 0 0 r
.40404 .35285 m .40618 .35297 L .40329 .35292 L closepath p F P
0 g
s
.719 .204 0 r
.22552 .42906 m .22332 .42692 L .22867 .42913 L p F P
0 g
s
.719 .204 0 r
.22867 .42913 m .22873 .42918 L .22552 .42906 L p F P
0 g
s
.437 .266 .55 r
.6783 .36108 m .67236 .36509 L .67158 .36109 L p F P
0 g
s
.437 .266 .55 r
.67158 .36109 m .67799 .35676 L .6783 .36108 L p F P
0 g
s
.194 0 0 r
.38769 .47159 m .37931 .47066 L .37643 .47081 L p F P
0 g
s
.656 .114 0 r
.247 .43915 m .24361 .43666 L .24043 .43652 L p F P
0 g
s
.313 .017 .291 r
.6514 .39486 m .65209 .39174 L .64618 .39504 L p F P
0 g
s
.313 .017 .291 r
.64268 .39972 m .6514 .39486 L p .64618 .39504 L F P
0 g
s
.313 .017 .291 r
.64618 .39504 m .64308 .39793 L .64268 .39972 L p F P
0 g
s
.708 .189 0 r
.23202 .4321 m .22873 .42918 L .22552 .42906 L p F P
0 g
s
.392 .679 .974 r
.25141 .31944 m .25284 .3205 L .24401 .32019 L p F P
0 g
s
.392 .679 .974 r
.24861 .3182 m .25141 .31944 L p .24401 .32019 L F P
0 g
s
.392 .679 .974 r
.24079 .31772 m .24861 .3182 L p .24401 .32019 L F P
0 g
s
.392 .679 .974 r
.24401 .32019 m .24348 .3199 L .24079 .31772 L p F P
0 g
s
.546 .914 .952 r
.54349 .33 m .54477 .33019 L .53516 .33377 L p F P
0 g
s
.546 .914 .952 r
.53516 .33377 m .53376 .33358 L .54349 .33 L p F P
0 g
s
.695 .873 .965 r
.59978 .31193 m .60221 .3136 L .59242 .31772 L p F P
0 g
s
.695 .873 .965 r
.59238 .31514 m .59978 .31193 L p .59242 .31772 L F P
0 g
s
.695 .873 .965 r
.59242 .31772 m .59026 .31637 L .59238 .31514 L p F P
0 g
s
.093 0 0 r
.57773 .44103 m .57968 .43921 L .56999 .44259 L p F P
0 g
s
.093 0 0 r
.56999 .44259 m .56802 .44442 L .57773 .44103 L p F P
0 g
s
.271 0 0 r
.35947 .34902 m .35237 .3477 L .34943 .34724 L p F P
0 g
s
.52 .716 .962 r
.2257 .31276 m .21666 .31369 L .21362 .31084 L p F P
0 g
s
.194 0 0 r
.37578 .47083 m .37643 .47081 L .36899 .46976 L p F P
0 g
s
.194 0 0 r
.36868 .4702 m .37578 .47083 L p .36899 .46976 L F P
0 g
s
.194 0 0 r
.3642 .46956 m .36868 .4702 L p .36899 .46976 L F P
0 g
s
.194 0 0 r
.36899 .46976 m .36625 .46953 L .3642 .46956 L p F P
0 g
s
.176 .709 .733 r
.4828 .34616 m .47705 .34731 L .47496 .34763 L p F P
0 g
s
.505 .392 .659 r
.67646 .34637 m .67716 .34671 L .67661 .34711 L closepath p F P
0 g
s
.723 .727 .854 r
.1712 .31323 m .17704 .30988 L .17398 .30655 L p F P
0 g
s
.723 .727 .854 r
.17398 .30655 m .167 .31045 L .1712 .31323 L p F P
0 g
s
.733 .723 .842 r
.16465 .31183 m .167 .31045 L .1712 .31323 L p F P
0 g
s
.044 0 0 r
.51246 .4611 m .51162 .46145 L .50346 .46286 L closepath p F P
0 g
s
.039 0 0 r
.50972 .46223 m .51162 .46145 L .50346 .46286 L p F P
0 g
s
.039 0 0 r
.50248 .46363 m .50972 .46223 L p .50346 .46286 L F P
0 g
s
.039 0 0 r
.49934 .46415 m .50248 .46363 L p .50346 .46286 L F P
0 g
s
0 0 0 r
.45309 .35075 m .46116 .34982 L .45165 .35103 L closepath p F P
0 g
s
.485 .72 .975 r
.24348 .3199 m .24079 .31772 L .23882 .31782 L closepath p F P
0 g
s
.483 .355 .629 r
.68082 .34971 m .67744 .35211 L .67661 .34711 L p F P
0 g
s
.483 .355 .629 r
.67661 .34711 m .67716 .34671 L .68082 .34971 L p F P
0 g
s
.881 .61 .523 r
.15384 .36894 m .15811 .37163 L .15828 .36751 L p F P
0 g
s
.881 .61 .523 r
.15828 .36751 m .15402 .36481 L .15384 .36894 L p F P
0 g
s
.16 .61 .934 r
.27769 .32863 m .27092 .32768 L .2679 .32569 L p F P
0 g
s
.238 0 0 r
.36625 .46953 m .3642 .46956 L .36008 .46887 L closepath p F P
0 g
s
.876 .575 .475 r
.15834 .37561 m .16279 .37823 L .16253 .37426 L p F P
0 g
s
.876 .575 .475 r
.15817 .3729 m .15834 .37561 L p .16253 .37426 L F P
0 g
s
.876 .575 .475 r
.16253 .37426 m .15879 .37205 L .15817 .3729 L p F P
0 g
s
.139 0 0 r
.42813 .35275 m .42855 .35268 L p .41629 .35299 L F P
0 g
s
.139 0 0 r
.41629 .35299 m .4176 .35301 L .42813 .35275 L p F P
0 g
s
.119 0 0 r
.41629 .35299 m .4176 .35301 L .41589 .35304 L closepath p F P
0 g
s
.858 .481 .333 r
.17993 .3946 m .17847 .39501 L .17795 .39353 L closepath p F P
0 g
s
.879 .633 .563 r
.14981 .36209 m .15402 .36481 L .1546 .36055 L p F P
0 g
s
.879 .633 .563 r
.1546 .36055 m .1504 .35782 L .14981 .36209 L p F P
0 g
s
.072 0 0 r
.46567 .46903 m .46513 .46916 L .4624 .46935 L closepath p F P
0 g
s
.061 0 0 r
.46246 .46979 m .46513 .46916 L .4624 .46935 L p F P
0 g
s
.061 0 0 r
.46228 .46981 m .46246 .46979 L p .4624 .46935 L F P
0 g
s
.061 0 0 r
.45285 .47039 m .46228 .46981 L p .4624 .46935 L F P
0 g
s
.068 0 0 r
.49899 .46429 m .49934 .46415 L .48968 .46549 L p F P
0 g
s
.068 0 0 r
.48968 .46549 m .48807 .4661 L .49899 .46429 L p F P
0 g
s
.832 .698 .715 r
.14512 .33168 m .14595 .33041 L .15005 .33322 L p F P
0 g
s
.832 .698 .715 r
.15005 .33322 m .14809 .33631 L .14512 .33168 L p F P
0 g
s
.112 0 0 r
.53613 .45465 m .54373 .45277 L .53579 .4549 L closepath p F P
0 g
s
.002 .539 .842 r
.32164 .34108 m .32219 .34125 L .31552 .34001 L p F P
0 g
s
.002 .539 .842 r
.31607 .33968 m .32164 .34108 L p .31552 .34001 L F P
0 g
s
.002 .539 .842 r
.31009 .33827 m .31607 .33968 L p .31552 .34001 L F P
0 g
s
.002 .539 .842 r
.31552 .34001 m .31087 .33859 L .31009 .33827 L p F P
0 g
s
.038 0 0 r
.44081 .35193 m .44438 .35168 L .44004 .35208 L closepath p F P
0 g
s
.093 0 0 r
.44004 .35208 m .44081 .35193 L p .42855 .35268 L F P
0 g
s
.873 .548 .43 r
.1634 .38208 m .16789 .38468 L .16728 .38083 L p F P
0 g
s
.873 .548 .43 r
.16728 .38083 m .16279 .37823 L .1634 .38208 L p F P
0 g
s
.093 0 0 r
.42855 .35268 m .43017 .35264 L .44004 .35208 L p F P
0 g
s
.085 0 0 r
.42855 .35268 m .43017 .35264 L .42813 .35275 L closepath p F P
0 g
s
.821 .389 .213 r
.19248 .40898 m .19052 .40556 L .19537 .40798 L p F P
0 g
s
.821 .389 .213 r
.19343 .40945 m .19248 .40898 L p .19537 .40798 L F P
0 g
s
.821 .389 .213 r
.19537 .40798 m .1961 .40923 L .19343 .40945 L p F P
0 g
s
.378 .843 .854 r
.5118 .3398 m .51353 .33926 L .51174 .33981 L closepath p F P
0 g
s
.46 .88 .924 r
.5118 .3398 m .51353 .33926 L .52179 .33681 L p F P
0 g
s
.741 .24 .033 r
.21276 .42244 m .21802 .42469 L .21515 .42157 L p F P
0 g
s
.741 .24 .033 r
.21072 .42021 m .21276 .42244 L p .21515 .42157 L F P
0 g
s
.741 .24 .033 r
.21515 .42157 m .21207 .42026 L .21072 .42021 L p F P
0 g
s
.481 .355 .631 r
.68558 .34626 m .68082 .34971 L .67716 .34671 L p F P
0 g
s
.481 .355 .631 r
.67716 .34671 m .68472 .34122 L .68558 .34626 L p F P
0 g
s
.431 0 0 r
.31262 .46065 m .31329 .46088 L .32071 .4623 L p F P
0 g
s
.363 0 0 r
.31987 .46284 m .31329 .46088 L .32071 .4623 L p F P
0 g
s
.363 0 0 r
.323 .46346 m .31987 .46284 L p .32071 .4623 L F P
0 g
s
.363 0 0 r
.32071 .4623 m .32473 .46351 L .323 .46346 L p F P
0 g
s
.375 .841 .852 r
.51353 .33926 m .51174 .33981 L .50921 .33998 L p F P
0 g
s
.518 0 0 r
.2855 .45315 m .28689 .4538 L .29361 .45548 L p F P
0 g
s
.462 0 0 r
.29243 .45609 m .28689 .4538 L .29361 .45548 L p F P
0 g
s
.462 0 0 r
.29618 .45705 m .29243 .45609 L p .29361 .45548 L F P
0 g
s
.462 0 0 r
.29361 .45548 m .29752 .45711 L .29618 .45705 L p F P
0 g
s
.874 .653 .601 r
.14626 .35506 m .1504 .35782 L .15144 .3534 L p F P
0 g
s
.874 .653 .601 r
.15144 .3534 m .14731 .35063 L .14626 .35506 L p F P
0 g
s
.32 0 0 r
.33985 .46596 m .34319 .46675 L .33794 .466 L closepath p F P
0 g
s
0 .51 .827 r
.3027 .33625 m .29802 .3353 L .29502 .33381 L p F P
0 g
s
.11 .585 .913 r
.28296 .33064 m .28349 .33075 L .28911 .33293 L p F P
0 g
s
.135 .617 .918 r
.29078 .33214 m .28349 .33075 L .28911 .33293 L p F P
0 g
s
.135 .617 .918 r
.2932 .33292 m .29078 .33214 L p .28911 .33293 L F P
0 g
s
.135 .617 .918 r
.28911 .33293 m .29502 .33381 L .2932 .33292 L p F P
0 g
s
.038 0 0 r
.47474 .46825 m .47697 .46769 L .46567 .46903 L p F P
0 g
s
.038 0 0 r
.46567 .46903 m .46513 .46916 L .47474 .46825 L p F P
0 g
s
.172 0 0 r
.39153 .47147 m .39803 .47201 L .38907 .47167 L closepath p F P
0 g
s
0 .413 .684 r
.32959 .34318 m .32516 .34222 L .32219 .34125 L p F P
0 g
s
.869 .517 .383 r
.16883 .38842 m .17336 .39099 L .17243 .38725 L p F P
0 g
s
.869 .517 .383 r
.17243 .38725 m .16789 .38468 L .16883 .38842 L p F P
0 g
s
.547 0 0 r
.27173 .44849 m .27044 .44841 L .26918 .44772 L closepath p F P
0 g
s
.21 0 .083 r
.63129 .4114 m .63193 .41003 L .62294 .41445 L p F P
0 g
s
.21 0 .083 r
.62442 .41571 m .63129 .4114 L p .62294 .41445 L F P
0 g
s
.21 0 .083 r
.62294 .41445 m .62174 .41702 L .62442 .41571 L p F P
0 g
s
.081 0 0 r
.55817 .44759 m .55809 .44764 L .55518 .44848 L closepath p F P
0 g
s
.081 0 0 r
.55598 .4492 m .55809 .44764 L .55518 .44848 L p F P
0 g
s
.081 0 0 r
.54596 .45216 m .55598 .4492 L p .55518 .44848 L F P
0 g
s
.211 0 0 r
.36209 .46959 m .3642 .46956 L .36008 .46887 L p F P
0 g
s
.211 0 0 r
.3597 .46931 m .36209 .46959 L p .36008 .46887 L F P
0 g
s
.211 0 0 r
.35201 .46801 m .3597 .46931 L p .36008 .46887 L F P
0 g
s
.211 0 0 r
.36008 .46887 m .35234 .46801 L .35201 .46801 L p F P
0 g
s
.178 0 .004 r
.6215 .41742 m .62174 .41702 L .6126 .42122 L p F P
0 g
s
.178 0 .004 r
.6126 .42122 m .61172 .42276 L .6215 .41742 L p F P
0 g
s
0 .483 .738 r
.34811 .34707 m .34943 .34724 L .34411 .34629 L p F P
0 g
s
0 .483 .738 r
.34385 .34631 m .34811 .34707 L p .34411 .34629 L F P
0 g
s
0 .483 .738 r
.34411 .34629 m .33756 .34487 L .33728 .3448 L p F P
0 g
s
0 .483 .738 r
.33728 .3448 m .34385 .34631 L p .34411 .34629 L F P
0 g
s
.41 .217 .505 r
.67181 .36956 m .67009 .3707 L .67001 .36666 L p F P
0 g
s
.41 .217 .505 r
.67001 .36666 m .67236 .36509 L .67181 .36956 L p F P
0 g
s
.129 0 0 r
.4176 .35301 m .41589 .35304 L .41347 .35341 L p F P
0 g
s
.175 0 0 r
.41589 .35304 m .41347 .35341 L .40618 .35297 L closepath p F P
0 g
s
.648 .658 .846 r
.66254 .30881 m .65804 .3122 L p .65126 .3094 L F P
0 g
s
.636 .645 .843 r
.65804 .3122 m .66254 .30881 L .66364 .31077 L closepath p F P
0 g
s
.573 .923 .956 r
.55419 .32632 m .55574 .32659 L .546 .33037 L p F P
0 g
s
.573 .923 .956 r
.546 .33037 m .54477 .33019 L .55419 .32632 L p F P
0 g
s
.129 0 0 r
.42499 .3534 m .42576 .35319 L .4176 .35301 L p F P
0 g
s
.129 0 0 r
.41615 .35356 m .42499 .3534 L p .4176 .35301 L F P
0 g
s
.129 0 0 r
.41347 .35341 m .41615 .35356 L p .4176 .35301 L F P
0 g
s
.149 0 0 r
.42813 .35275 m .42576 .35319 L .4176 .35301 L closepath p F P
0 g
s
.15 0 0 r
.41263 .35359 m .41347 .35341 L .40618 .35297 L p F P
0 g
s
.15 0 0 r
.4048 .35348 m .41263 .35359 L p .40618 .35297 L F P
0 g
s
.15 0 0 r
.4012 .35313 m .4048 .35348 L p .40618 .35297 L F P
0 g
s
.15 0 0 r
.40618 .35297 m .40329 .35292 L .4012 .35313 L p F P
0 g
s
.208 .734 .772 r
.48778 .34521 m .48726 .34526 L .4828 .34616 L closepath p F P
0 g
s
.176 .709 .733 r
.48477 .34578 m .48726 .34526 L .4828 .34616 L p F P
0 g
s
.176 .709 .733 r
.48327 .34606 m .48477 .34578 L p .4828 .34616 L F P
0 g
s
.176 .709 .733 r
.47496 .34763 m .48327 .34606 L p .4828 .34616 L F P
0 g
s
.685 .897 .973 r
.58998 .31619 m .5802 .32036 L .57774 .31922 L p F P
0 g
s
.67 .902 .978 r
.56797 .32333 m .57774 .31922 L .5802 .32036 L p F P
0 g
s
.187 0 0 r
.40329 .35292 m .4012 .35313 L .39563 .35262 L closepath p F P
0 g
s
.607 .589 .807 r
.67633 .3144 m .67611 .3139 L .66609 .31562 L p F P
0 g
s
.62 .6 .808 r
.67611 .3139 m .66609 .31562 L .66364 .31077 L p F P
0 g
s
.513 0 0 r
.2855 .45315 m .28689 .4538 L .28429 .45313 L closepath p F P
0 g
s
.434 .87 .905 r
.52179 .33681 m .52149 .3368 L .51353 .33926 L closepath p F P
0 g
s
.375 .841 .852 r
.51893 .33701 m .52149 .3368 L .51353 .33926 L p F P
0 g
s
.375 .841 .852 r
.50921 .33998 m .51893 .33701 L p .51353 .33926 L F P
0 g
s
.236 0 .15 r
.64106 .4047 m .64182 .40265 L .63297 .40729 L p F P
0 g
s
.236 0 .15 r
.63827 .40672 m .64106 .4047 L p .63297 .40729 L F P
0 g
s
.236 0 .15 r
.63297 .40729 m .63193 .41003 L .63827 .40672 L p F P
0 g
s
.867 .672 .637 r
.14323 .34783 m .14731 .35063 L .14886 .34602 L p F P
0 g
s
.867 .672 .637 r
.14886 .34602 m .1448 .34322 L .14323 .34783 L p F P
0 g
s
.096 0 0 r
.47741 .46753 m .48018 .46724 L .47697 .46769 L closepath p F P
0 g
s
.031 0 0 r
.54373 .45277 m .53579 .4549 L .53361 .45614 L p F P
0 g
s
.095 0 0 r
.43017 .35264 m .42813 .35275 L .42576 .35319 L p F P
0 g
s
.139 0 0 r
.60197 .42762 m .60194 .42766 L .60249 .42739 L closepath p F P
0 g
s
.846 .698 .698 r
.14696 .33839 m .14809 .33631 L .14512 .33168 L p F P
0 g
s
.695 .801 .931 r
.61486 .31188 m .61444 .31147 L .61715 .31036 L closepath p F P
0 g
s
.859 .481 .331 r
.17462 .39463 m .17336 .39099 L .17795 .39353 L p F P
0 g
s
.859 .481 .331 r
.1763 .39557 m .17462 .39463 L p .17795 .39353 L F P
0 g
s
.859 .481 .331 r
.17795 .39353 m .17847 .39501 L .1763 .39557 L p F P
0 g
s
.615 .055 0 r
.25111 .44189 m .247 .43915 L .25283 .44116 L p F P
0 g
s
.615 .055 0 r
.25364 .44277 m .25111 .44189 L p .25283 .44116 L F P
0 g
s
.615 .055 0 r
.25283 .44116 m .25542 .44289 L .25364 .44277 L p F P
0 g
s
.684 .733 .888 r
.17704 .30988 m .18625 .30607 L .18931 .30925 L p F P
0 g
s
.679 .733 .891 r
.18625 .30607 m .17704 .30988 L .17398 .30655 L p F P
0 g
s
.136 0 0 r
.60249 .42739 m .60194 .42766 L .60039 .4298 L p F P
0 g
s
.108 0 0 r
.44004 .35208 m .43805 .35249 L .43017 .35264 L closepath p F P
0 g
s
.095 0 0 r
.437 .35279 m .43805 .35249 L .43017 .35264 L p F P
0 g
s
.095 0 0 r
.42865 .35322 m .437 .35279 L p .43017 .35264 L F P
0 g
s
.095 0 0 r
.42576 .35319 m .42865 .35322 L p .43017 .35264 L F P
0 g
s
.293 .66 .971 r
.25586 .32275 m .25866 .32307 L .26389 .32541 L p F P
0 g
s
.328 .687 .98 r
.26488 .32369 m .25866 .32307 L .26389 .32541 L p F P
0 g
s
.328 .687 .98 r
.26389 .32541 m .2679 .32569 L .26488 .32369 L p F P
0 g
s
.668 .702 .872 r
.63896 .30923 m .64885 .30581 L .65126 .3094 L p F P
0 g
s
.678 .728 .887 r
.64885 .30581 m .63896 .30923 L .63654 .30621 L p F P
0 g
s
.684 .745 .898 r
.62669 .30999 m .63654 .30621 L .63896 .30923 L p F P
0 g
s
.152 0 0 r
.40377 .47194 m .40894 .47222 L .40201 .47214 L closepath p F P
0 g
s
.638 .731 .915 r
.18931 .30925 m .19844 .3066 L .20149 .30963 L p F P
0 g
s
.631 .729 .918 r
.19844 .3066 m .18931 .30925 L .18625 .30607 L p F P
0 g
s
.78 .72 .797 r
.15613 .31856 m .15223 .3159 L .15511 .31946 L closepath p F P
0 g
s
.805 .722 .773 r
.15029 .32477 m .15511 .31946 L .15223 .3159 L p F P
0 g
s
.157 0 0 r
.3999 .35334 m .4012 .35313 L .39563 .35262 L p F P
0 g
s
.157 0 0 r
.39434 .35309 m .3999 .35334 L p .39563 .35262 L F P
0 g
s
.157 0 0 r
.38895 .35237 m .39434 .35309 L p .39563 .35262 L F P
0 g
s
.157 0 0 r
.39563 .35262 m .39028 .35232 L .38895 .35237 L p F P
0 g
s
.773 .722 .805 r
.15613 .31856 m .16465 .31183 L p .15206 .3157 L F P
0 g
s
.773 .722 .805 r
.15206 .3157 m .15223 .3159 L .15613 .31856 L p F P
0 g
s
.458 .706 .975 r
.22874 .31543 m .23385 .31536 L .23882 .31782 L p F P
0 g
s
.44 .694 .973 r
.23385 .31536 m .22874 .31543 L .2257 .31276 L p F P
0 g
s
.692 .77 .911 r
.63654 .30621 m .62669 .30999 L .62427 .30745 L p F P
0 g
s
.354 .112 .403 r
.66996 .37457 m .66997 .37449 L .6615 .37978 L p F P
0 g
s
.354 .112 .403 r
.66674 .37986 m .66996 .37457 L p .6615 .37978 L F P
0 g
s
.354 .112 .403 r
.6615 .37978 m .66118 .38333 L .66674 .37986 L p F P
0 g
s
.675 .137 0 r
.23563 .43499 m .23202 .4321 L .23758 .43422 L p F P
0 g
s
.675 .137 0 r
.23944 .43646 m .23563 .43499 L p .23758 .43422 L F P
0 g
s
.675 .137 0 r
.23758 .43422 m .24043 .43652 L .23944 .43646 L p F P
0 g
s
.201 0 .013 r
.61172 .42276 m .60249 .42739 L .61122 .4236 L closepath p F P
0 g
s
.136 0 0 r
.60967 .42579 m .61122 .4236 L .60249 .42739 L p F P
0 g
s
.136 0 0 r
.60039 .4298 m .60967 .42579 L p .60249 .42739 L F P
0 g
s
.19 0 0 r
.36453 .34961 m .36779 .35019 L .36277 .34948 L closepath p F P
0 g
s
.423 0 0 r
.31262 .46065 m .31329 .46088 L .31215 .46065 L closepath p F P
0 g
s
.79 .324 .13 r
.19986 .41462 m .20487 .41698 L .20247 .4137 L p F P
0 g
s
.79 .324 .13 r
.20247 .4137 m .19744 .41136 L .19986 .41462 L p F P
0 g
s
.545 0 0 r
.26733 .44817 m .26308 .44581 L .26918 .44772 L p F P
0 g
s
.545 0 0 r
.26918 .44772 m .27044 .44841 L .26733 .44817 L p F P
0 g
s
.584 .722 .938 r
.20149 .30963 m .20582 .30886 L .21033 .31151 L p F P
0 g
s
.597 .731 .938 r
.21057 .30798 m .20582 .30886 L .21033 .31151 L p F P
0 g
s
.597 .731 .938 r
.21033 .31151 m .21362 .31084 L .21057 .30798 L p F P
0 g
s
.182 0 0 r
.39028 .35232 m .38895 .35237 L .3858 .35201 L closepath p F P
0 g
s
.046 0 0 r
.56786 .44453 m .56802 .44442 L .55817 .44759 L p F P
0 g
s
.046 0 0 r
.55817 .44759 m .55809 .44764 L .56786 .44453 L p F P
0 g
s
.268 .64 .964 r
.25866 .32307 m .25586 .32275 L .25284 .3205 L p F P
0 g
s
.256 0 0 r
.35234 .46801 m .35201 .46801 L .35141 .46789 L closepath p F P
0 g
s
.812 .373 .197 r
.1961 .40923 m .19744 .41136 L .19343 .40945 L closepath p F P
0 g
s
.035 0 0 r
.47381 .46848 m .47474 .46825 L .46513 .46916 L p F P
0 g
s
.035 0 0 r
.46513 .46916 m .46246 .46979 L .47381 .46848 L p F P
0 g
s
.081 .596 .884 r
.31087 .33859 m .31009 .33827 L .30913 .33812 L closepath p F P
0 g
s
.276 .779 .784 r
.50858 .3401 m .50921 .33998 L .49954 .34264 L p F P
0 g
s
.276 .779 .784 r
.49954 .34264 m .4983 .34282 L .50858 .3401 L p F P
0 g
s
.764 .276 .071 r
.21207 .42026 m .21072 .42021 L .20993 .41931 L closepath p F P
0 g
s
.01 0 0 r
.52133 .4595 m .52298 .4588 L .51246 .4611 L p F P
0 g
s
.01 0 0 r
.51246 .4611 m .51162 .46145 L .52133 .4595 L p F P
0 g
s
.13 0 0 r
.41603 .47207 m .42059 .47219 L .41463 .47226 L closepath p F P
0 g
s
.248 0 0 r
.34907 .46793 m .34319 .46675 L .35141 .46789 L p F P
0 g
s
.248 0 0 r
.35141 .46789 m .35201 .46801 L .34907 .46793 L p F P
0 g
s
.455 .308 .591 r
.68295 .35324 m .67799 .35676 L .67744 .35211 L p F P
0 g
s
.455 .308 .591 r
.67744 .35211 m .68082 .34971 L .68295 .35324 L p F P
0 g
s
.648 .658 .846 r
.65126 .3094 m .6612 .30646 L .66254 .30881 L p F P
0 g
s
.659 .682 .861 r
.6612 .30646 m .65126 .3094 L .64885 .30581 L p F P
0 g
s
.043 0 0 r
.56585 .44603 m .56786 .44453 L .55809 .44764 L p F P
0 g
s
.043 0 0 r
.55809 .44764 m .55598 .4492 L .56585 .44603 L p F P
0 g
s
.047 0 0 r
.44438 .35168 m .44004 .35208 L .43805 .35249 L p F P
0 g
s
.693 .826 .946 r
.61715 .31036 m .61444 .31147 L .61202 .30942 L p F P
0 g
s
.7 .828 .943 r
.60221 .3136 m .61202 .30942 L .61444 .31147 L p F P
0 g
s
.262 0 .217 r
.6508 .39697 m .6514 .39486 L .64268 .39972 L p F P
0 g
s
.262 0 .217 r
.64846 .39897 m .6508 .39697 L p .64268 .39972 L F P
0 g
s
.262 0 .217 r
.64268 .39972 m .64182 .40265 L .64846 .39897 L p F P
0 g
s
.724 .211 0 r
.22114 .42774 m .21802 .42469 L .22332 .42692 L p F P
0 g
s
.724 .211 0 r
.22409 .42899 m .22114 .42774 L p .22332 .42692 L F P
0 g
s
.724 .211 0 r
.22332 .42692 m .22552 .42906 L .22409 .42899 L p F P
0 g
s
.25 .762 .791 r
.49692 .34303 m .4983 .34282 L .48778 .34521 L p F P
0 g
s
.25 .762 .791 r
.48778 .34521 m .48726 .34526 L .49692 .34303 L p F P
0 g
s
.147 0 0 r
.3867 .35259 m .38895 .35237 L .3858 .35201 L p F P
0 g
s
.147 0 0 r
.38462 .35242 m .3867 .35259 L p .3858 .35201 L F P
0 g
s
.147 0 0 r
.37673 .35116 m .38462 .35242 L p .3858 .35201 L F P
0 g
s
.147 0 0 r
.3858 .35201 m .37677 .35116 L .37673 .35116 L p F P
0 g
s
.846 .698 .698 r
.14512 .33168 m .14297 .33554 L .14696 .33839 L p F P
0 g
s
.858 .688 .671 r
.14079 .34038 m .1448 .34322 L .14696 .33839 L p F P
0 g
s
.858 .688 .671 r
.14696 .33839 m .14297 .33554 L .14079 .34038 L p F P
0 g
s
.805 .722 .773 r
.14631 .3219 m .15029 .32477 L p .15223 .3159 L F P
0 g
s
.82 .712 .746 r
.14276 .32817 m .14595 .33041 L .15029 .32477 L p F P
0 g
s
.82 .712 .746 r
.14212 .32728 m .14276 .32817 L p .15029 .32477 L F P
0 g
s
.82 .712 .746 r
.15029 .32477 m .14631 .3219 L .14212 .32728 L p F P
0 g
s
.573 .716 .939 r
.20582 .30886 m .20149 .30963 L .19844 .3066 L p F P
0 g
s
.84 .428 .26 r
.18098 .40064 m .18572 .40311 L .18404 .39961 L p F P
0 g
s
.84 .428 .26 r
.18404 .39961 m .17928 .39715 L .18098 .40064 L p F P
0 g
s
.006 0 0 r
.48018 .46724 m .47697 .46769 L .47474 .46825 L p F P
0 g
s
.325 0 0 r
.31259 .46136 m .31987 .46284 L .31329 .46088 L p F P
0 g
s
.325 0 0 r
.3096 .46046 m .31259 .46136 L p .31329 .46088 L F P
0 g
s
.325 0 0 r
.31329 .46088 m .31215 .46065 L .3096 .46046 L p F P
0 g
s
.063 0 0 r
.45285 .47039 m .46228 .46981 L .45086 .47082 L closepath p F P
0 g
s
.102 0 0 r
.59963 .43067 m .60039 .4298 L .59098 .4336 L p F P
0 g
s
.102 0 0 r
.59098 .4336 m .58983 .43493 L .59963 .43067 L p F P
0 g
s
.484 .72 .975 r
.23776 .31526 m .23385 .31536 L .23882 .31782 L p F P
0 g
s
.484 .72 .975 r
.23882 .31782 m .24079 .31772 L .23776 .31526 L p F P
0 g
s
.108 0 0 r
.42829 .47186 m .43316 .47184 L .42697 .47207 L closepath p F P
0 g
s
.729 .725 .846 r
.167 .31045 m .16465 .31183 L .16159 .30834 L p F P
0 g
s
.773 .722 .805 r
.16465 .31183 m .16159 .30834 L .15206 .3157 L p F P
0 g
s
.061 0 0 r
.53335 .45629 m .53361 .45614 L .52389 .4583 L p F P
0 g
s
.061 0 0 r
.52389 .4583 m .52298 .4588 L .53335 .45629 L p F P
0 g
s
.086 0 0 r
.44057 .4713 m .44693 .47109 L .43904 .47159 L closepath p F P
0 g
s
.068 .591 .874 r
.3071 .33709 m .3027 .33625 L .30913 .33812 L p F P
0 g
s
.068 .591 .874 r
.30913 .33812 m .31009 .33827 L .3071 .33709 L p F P
0 g
s
.222 0 0 r
.3597 .46931 m .35201 .46801 L .34907 .46793 L p F P
0 g
s
.374 0 0 r
.31215 .46065 m .3096 .46046 L .30621 .45933 L closepath p F P
0 g
s
.051 0 0 r
.45165 .35103 m .45036 .3513 L .44438 .35168 L closepath p F P
0 g
s
.047 0 0 r
.44868 .3518 m .45036 .3513 L .44438 .35168 L p F P
0 g
s
.047 0 0 r
.44279 .3523 m .44868 .3518 L p .44438 .35168 L F P
0 g
s
.047 0 0 r
.43805 .35249 m .44279 .3523 L p .44438 .35168 L F P
0 g
s
0 .517 .765 r
.33756 .34487 m .33728 .3448 L .33687 .34473 L closepath p F P
0 g
s
.133 0 0 r
.58923 .43561 m .58983 .43493 L .58004 .43879 L p F P
0 g
s
.133 0 0 r
.58004 .43879 m .57968 .43921 L .58923 .43561 L p F P
0 g
s
.422 0 0 r
.28584 .45436 m .29243 .45609 L .28689 .4538 L p F P
0 g
s
.422 0 0 r
.28242 .45295 m .28584 .45436 L p .28689 .4538 L F P
0 g
s
.422 0 0 r
.28689 .4538 m .28429 .45313 L .28242 .45295 L p F P
0 g
s
.881 .584 .479 r
.15879 .37205 m .15817 .3729 L .15811 .37163 L closepath p F P
0 g
s
.129 .59 .922 r
.28296 .33064 m .28349 .33075 L .28231 .33027 L closepath p F P
0 g
s
0 .501 .739 r
.33432 .34416 m .32959 .34318 L .33687 .34473 L p F P
0 g
s
0 .501 .739 r
.33687 .34473 m .33728 .3448 L .33432 .34416 L p F P
0 g
s
.404 .212 .504 r
.67839 .36512 m .67181 .36956 L .67236 .36509 L p F P
0 g
s
.404 .212 .504 r
.67236 .36509 m .6783 .36108 L .67839 .36512 L p F P
0 g
s
.647 .925 .975 r
.57649 .31877 m .57774 .31922 L .56797 .32333 L p F P
0 g
s
.647 .925 .975 r
.56797 .32333 m .56742 .32316 L .57649 .31877 L p F P
0 g
s
.016 0 0 r
.48807 .4661 m .48704 .46638 L .48018 .46724 L closepath p F P
0 g
s
.006 0 0 r
.48498 .46693 m .48704 .46638 L .48018 .46724 L p F P
0 g
s
.006 0 0 r
.48051 .46757 m .48498 .46693 L p .48018 .46724 L F P
0 g
s
.006 0 0 r
.47474 .46825 m .48051 .46757 L p .48018 .46724 L F P
0 g
s
.5 .903 .917 r
.54126 .32991 m .54349 .33 L .53376 .33358 L p F P
0 g
s
.5 .903 .917 r
.53376 .33358 m .53163 .33351 L .54126 .32991 L p F P
0 g
s
.853 .47 .321 r
.17847 .39501 m .17928 .39715 L .1763 .39557 L closepath p F P
0 g
s
.719 .727 .857 r
.167 .31045 m .17398 .30655 L .17091 .30325 L p F P
0 g
s
.719 .727 .857 r
.17091 .30325 m .16277 .30767 L .167 .31045 L p F P
0 g
s
.729 .725 .846 r
.16159 .30834 m .16277 .30767 L .167 .31045 L p F P
0 g
s
.283 0 0 r
.34385 .34631 m .33728 .3448 L .33432 .34416 L p F P
0 g
s
.694 .809 .937 r
.62427 .30745 m .61715 .31036 L .62331 .30656 L closepath p F P
0 g
s
.693 .826 .946 r
.62186 .3052 m .62331 .30656 L .61715 .31036 L p F P
0 g
s
.693 .826 .946 r
.61202 .30942 m .62186 .3052 L p .61715 .31036 L F P
0 g
s
.525 0 0 r
.27405 .45022 m .27044 .44841 L .26733 .44817 L p F P
0 g
s
.883 .585 .478 r
.15403 .37293 m .15384 .36894 L .15811 .37163 L p F P
0 g
s
.883 .585 .478 r
.15683 .37469 m .15403 .37293 L p .15811 .37163 L F P
0 g
s
.883 .585 .478 r
.15811 .37163 m .15817 .3729 L .15683 .37469 L p F P
0 g
s
.884 .613 .522 r
.14963 .36621 m .15384 .36894 L .15402 .36481 L p F P
0 g
s
.884 .613 .522 r
.15402 .36481 m .14981 .36209 L .14963 .36621 L p F P
0 g
s
.764 .275 .067 r
.20746 .42006 m .20487 .41698 L .20993 .41931 L p F P
0 g
s
.764 .275 .067 r
.20993 .41931 m .21072 .42021 L .20746 .42006 L p F P
0 g
s
.104 .577 .911 r
.28486 .33005 m .29078 .33214 L .28349 .33075 L p F P
0 g
s
.104 .577 .911 r
.27995 .32892 m .28486 .33005 L p .28349 .33075 L F P
0 g
s
.104 .577 .911 r
.28349 .33075 m .28231 .33027 L .27995 .32892 L p F P
0 g
s
.159 0 0 r
.37677 .35116 m .37673 .35116 L .37665 .35115 L closepath p F P
0 g
s
.704 .851 .953 r
.61202 .30942 m .60221 .3136 L .59978 .31193 L p F P
0 g
s
.193 0 0 r
.37383 .35123 m .36779 .35019 L .37665 .35115 L p F P
0 g
s
.193 0 0 r
.37665 .35115 m .37673 .35116 L .37383 .35123 L p F P
0 g
s
.332 0 0 r
.38462 .35242 m .37673 .35116 L .37383 .35123 L p F P
0 g
s
0 .417 .707 r
.31607 .33968 m .31009 .33827 L .3071 .33709 L p F P
0 g
s
.825 .391 .206 r
.18769 .40652 m .19248 .40898 L .19052 .40556 L p F P
0 g
s
.825 .391 .206 r
.19052 .40556 m .18572 .40311 L .18769 .40652 L p F P
0 g
s
0 0 0 r
.46116 .34982 m .45165 .35103 L .45036 .3513 L p F P
0 g
s
.881 .636 .563 r
.14566 .35933 m .14981 .36209 L .1504 .35782 L p F P
0 g
s
.881 .636 .563 r
.1504 .35782 m .14626 .35506 L .14566 .35933 L p F P
0 g
s
.877 .549 .426 r
.15897 .37945 m .1634 .38208 L .16279 .37823 L p F P
0 g
s
.877 .549 .426 r
.16279 .37823 m .15834 .37561 L .15897 .37945 L p F P
0 g
s
.164 .698 .702 r
.49535 .34343 m .49692 .34303 L .48726 .34526 L p F P
0 g
s
.164 .698 .702 r
.48726 .34526 m .48477 .34578 L .49535 .34343 L p F P
0 g
s
.47 0 0 r
.28429 .45313 m .28242 .45295 L .28039 .45204 L closepath p F P
0 g
s
.219 0 0 r
.34796 .46789 m .34907 .46793 L .34319 .46675 L p F P
0 g
s
.219 0 0 r
.34289 .46714 m .34796 .46789 L p .34319 .46675 L F P
0 g
s
.219 0 0 r
.33688 .46594 m .34289 .46714 L p .34319 .46675 L F P
0 g
s
.219 0 0 r
.34319 .46675 m .33794 .466 L .33688 .46594 L p F P
0 g
s
.288 0 .282 r
.66047 .38765 m .66068 .38666 L .65209 .39174 L p F P
0 g
s
.288 0 .282 r
.65621 .39203 m .66047 .38765 L p .65209 .39174 L F P
0 g
s
.288 0 .282 r
.65209 .39174 m .6514 .39486 L .65621 .39203 L p F P
0 g
s
.833 .703 .72 r
.14595 .33041 m .14276 .32817 L .14512 .33168 L closepath p F P
0 g
s
.62 .6 .808 r
.66364 .31077 m .67364 .30861 L .67611 .3139 L p F P
0 g
s
.623 .64 .846 r
.66254 .30881 m .66364 .31077 L .67364 .30861 L p F P
0 g
s
.52 .716 .962 r
.21362 .31084 m .22265 .31007 L .2257 .31276 L p F P
0 g
s
.508 .711 .963 r
.22265 .31007 m .21362 .31084 L .21057 .30798 L p F P
0 g
s
.215 .647 .953 r
.28231 .33027 m .27995 .32892 L .27769 .32863 L closepath p F P
0 g
s
.336 .67 .976 r
.24861 .3182 m .24079 .31772 L .23776 .31526 L p F P
0 g
s
.059 0 0 r
.58747 .43727 m .58923 .43561 L .57968 .43921 L p F P
0 g
s
.059 0 0 r
.58059 .43996 m .58747 .43727 L p .57968 .43921 L F P
0 g
s
.059 0 0 r
.57968 .43921 m .57773 .44103 L .58059 .43996 L p F P
0 g
s
.573 .924 .954 r
.55324 .32616 m .55419 .32632 L .54477 .33019 L p F P
0 g
s
.573 .924 .954 r
.54477 .33019 m .54349 .33 L .55324 .32616 L p F P
0 g
s
.876 .657 .601 r
.14216 .35227 m .14626 .35506 L .14731 .35063 L p F P
0 g
s
.876 .657 .601 r
.14731 .35063 m .14323 .34783 L .14216 .35227 L p F P
0 g
s
.872 .518 .377 r
.16436 .38582 m .16883 .38842 L .16789 .38468 L p F P
0 g
s
.872 .518 .377 r
.16789 .38468 m .1634 .38208 L .16436 .38582 L p F P
0 g
s
.602 .036 0 r
.24538 .43982 m .25111 .44189 L .247 .43915 L p F P
0 g
s
.602 .036 0 r
.247 .43915 m .24122 .43711 L .24538 .43982 L p F P
0 g
s
.656 .114 0 r
.24043 .43652 m .24122 .43711 L .247 .43915 L p F P
0 g
s
.033 0 0 r
.54596 .45216 m .54587 .45222 L .54373 .45277 L closepath p F P
0 g
s
.031 0 0 r
.54355 .45356 m .54587 .45222 L .54373 .45277 L p F P
0 g
s
.031 0 0 r
.5394 .45468 m .54355 .45356 L p .54373 .45277 L F P
0 g
s
.031 0 0 r
.53361 .45614 m .5394 .45468 L p .54373 .45277 L F P
0 g
s
.847 .703 .702 r
.14297 .33554 m .14512 .33168 L .14276 .32817 L p F P
0 g
s
.695 .874 .965 r
.59026 .31637 m .58998 .31619 L .59238 .31514 L closepath p F P
0 g
s
.468 .888 .912 r
.53122 .3335 m .53163 .33351 L .52179 .33681 L p F P
0 g
s
.468 .888 .912 r
.52179 .33681 m .52149 .3368 L .53122 .3335 L p F P
0 g
s
.649 .926 .974 r
.57528 .31835 m .57649 .31877 L .56742 .32316 L p F P
0 g
s
.649 .926 .974 r
.56742 .32316 m .5655 .32257 L .57528 .31835 L p F P
0 g
s
.512 .411 .677 r
.68208 .33679 m .68352 .33573 L .68392 .33747 L closepath p F P
0 g
s
.548 0 0 r
.26171 .44643 m .25702 .44388 L .26308 .44581 L p F P
0 g
s
.548 0 0 r
.26691 .44813 m .26171 .44643 L p .26308 .44581 L F P
0 g
s
.548 0 0 r
.26308 .44581 m .26733 .44817 L .26691 .44813 L p F P
0 g
s
.203 0 0 r
.3642 .46956 m .36868 .4702 L .36209 .46959 L closepath p F P
0 g
s
.268 .64 .964 r
.25284 .3205 m .25368 .32062 L .25866 .32307 L p F P
0 g
s
.293 .668 .973 r
.26175 .32167 m .25368 .32062 L .25866 .32307 L p F P
0 g
s
.293 .668 .973 r
.26196 .32176 m .26175 .32167 L p .25866 .32307 L F P
0 g
s
.293 .668 .973 r
.25866 .32307 m .26488 .32369 L .26196 .32176 L p F P
0 g
s
.708 .189 0 r
.22552 .42906 m .22651 .42995 L .23202 .4321 L p F P
0 g
s
.663 .118 0 r
.23015 .43282 m .23563 .43499 L .23202 .4321 L p F P
0 g
s
.663 .118 0 r
.23202 .4321 m .22651 .42995 L .23015 .43282 L p F P
0 g
s
.006 0 0 r
.52028 .45995 m .52133 .4595 L .51162 .46145 L p F P
0 g
s
.006 0 0 r
.51162 .46145 m .50972 .46223 L .52028 .45995 L p F P
0 g
s
.33 0 0 r
.32473 .46351 m .32742 .46423 L .323 .46346 L closepath p F P
0 g
s
.437 0 0 r
.29752 .45711 m .29922 .45775 L .30621 .45933 L p F P
0 g
s
.373 0 0 r
.30543 .45983 m .29922 .45775 L .30621 .45933 L p F P
0 g
s
.373 0 0 r
.30744 .4603 m .30543 .45983 L p .30621 .45933 L F P
0 g
s
.373 0 0 r
.30621 .45933 m .3096 .46046 L .30744 .4603 L p F P
0 g
s
.879 .58 .476 r
.15817 .3729 m .15834 .37561 L .15683 .37469 L closepath p F P
0 g
s
.375 .16 .455 r
.67003 .37445 m .66997 .37449 L .67009 .3707 L p F P
0 g
s
.375 .16 .455 r
.67009 .3707 m .67181 .36956 L .67003 .37445 L p F P
0 g
s
0 0 0 r
.49672 .46493 m .49899 .46429 L .48807 .4661 L p F P
0 g
s
0 0 0 r
.48807 .4661 m .48704 .46638 L .49672 .46493 L p F P
0 g
s
.172 0 0 r
.62036 .41937 m .6215 .41742 L .61172 .42276 L p F P
0 g
s
.172 0 0 r
.61172 .42276 m .61122 .4236 L .62036 .41937 L p F P
0 g
s
.209 0 0 r
.37303 .35129 m .37383 .35123 L .36779 .35019 L p F P
0 g
s
.209 0 0 r
.36669 .35054 m .37303 .35129 L p .36779 .35019 L F P
0 g
s
.209 0 0 r
.36161 .34941 m .36669 .35054 L p .36779 .35019 L F P
0 g
s
.209 0 0 r
.36779 .35019 m .36277 .34948 L .36161 .34941 L p F P
0 g
s
.267 0 0 r
.33794 .466 m .33688 .46594 L .33515 .46555 L closepath p F P
0 g
s
.545 .477 .73 r
.68121 .3275 m .68419 .32782 L .68186 .32962 L closepath p F P
0 g
s
.541 .49 .747 r
.67959 .32268 m .68121 .3275 L .68419 .32782 L p F P
0 g
s
.755 .261 .056 r
.21276 .42244 m .21072 .42021 L .20746 .42006 L p F P
0 g
s
.864 .485 .326 r
.17009 .39205 m .17462 .39463 L .17336 .39099 L p F P
0 g
s
.864 .485 .326 r
.17336 .39099 m .16883 .38842 L .17009 .39205 L p F P
0 g
s
.526 .444 .706 r
.69149 .32956 m .68352 .33573 L .68186 .32962 L p F P
0 g
s
.526 .444 .706 r
.69147 .32948 m .69149 .32956 L p .68186 .32962 L F P
0 g
s
.526 .444 .706 r
.68186 .32962 m .68419 .32782 L .69147 .32948 L p F P
0 g
s
.431 0 0 r
.29752 .45711 m .29922 .45775 L .29618 .45705 L closepath p F P
0 g
s
.869 .675 .638 r
.1392 .345 m .14323 .34783 L .1448 .34322 L p F P
0 g
s
.869 .675 .638 r
.1448 .34322 m .14079 .34038 L .1392 .345 L p F P
0 g
s
.783 .305 .096 r
.1949 .41224 m .19986 .41462 L .19744 .41136 L p F P
0 g
s
.783 .305 .096 r
.19278 .40941 m .1949 .41224 L p .19744 .41136 L F P
0 g
s
.783 .305 .096 r
.19744 .41136 m .19343 .40945 L .19278 .40941 L p F P
0 g
s
.591 .024 0 r
.25542 .44289 m .25702 .44388 L .25364 .44277 L closepath p F P
0 g
s
0 .413 .684 r
.32285 .34142 m .32959 .34318 L p .32236 .34129 L F P
0 g
s
0 .414 .696 r
.32257 .34141 m .3279 .34274 L p .32285 .34142 L F P
0 g
s
.152 0 0 r
.32945 .34312 m .32285 .34142 L .32959 .34318 L p F P
0 g
s
0 .414 .696 r
.3279 .34274 m .32945 .34312 L .32285 .34142 L p F P
0 g
s
0 .413 .684 r
.32219 .34125 m .32285 .34142 L p .32236 .34129 L F P
0 g
s
.152 0 0 r
.33268 .34384 m .32945 .34312 L p .32959 .34318 L F P
0 g
s
.152 0 0 r
.32959 .34318 m .33432 .34416 L .33268 .34384 L p F P
0 g
s
.805 .722 .773 r
.15223 .3159 m .15202 .31574 L .14631 .3219 L p F P
0 g
s
.794 .725 .787 r
.15206 .3157 m .15202 .31574 L .15223 .3159 L closepath p F P
0 g
s
.133 .585 .925 r
.2721 .32642 m .2679 .32569 L .26488 .32369 L p F P
0 g
s
.16 .61 .934 r
.2679 .32569 m .2721 .32642 L .27769 .32863 L p F P
0 g
s
.685 .897 .973 r
.59238 .31514 m .58998 .31619 L .58754 .31495 L p F P
0 g
s
.685 .897 .973 r
.57774 .31922 m .58754 .31495 L .58998 .31619 L p F P
0 g
s
.424 .257 .548 r
.6837 .35726 m .6783 .36108 L .67799 .35676 L p F P
0 g
s
.424 .257 .548 r
.67799 .35676 m .68295 .35324 L .6837 .35726 L p F P
0 g
s
.571 .525 .765 r
.67863 .32009 m .68303 .31997 L .67959 .32268 L closepath p F P
0 g
s
.541 .49 .747 r
.68878 .3202 m .68303 .31997 L .67959 .32268 L p F P
0 g
s
.541 .49 .747 r
.68979 .32339 m .68878 .3202 L p .67959 .32268 L F P
0 g
s
.541 .49 .747 r
.68419 .32782 m .68979 .32339 L p .67959 .32268 L F P
0 g
s
0 0 0 r
.55564 .4494 m .55598 .4492 L .54596 .45216 L p F P
0 g
s
0 0 0 r
.54596 .45216 m .54587 .45222 L .55564 .4494 L p F P
0 g
s
.233 0 0 r
.38895 .35237 m .39434 .35309 L .3867 .35259 L closepath p F P
0 g
s
0 0 0 r
.47496 .34763 m .48327 .34606 L .474 .34788 L closepath p F P
0 g
s
0 .51 .827 r
.29502 .33381 m .29668 .33422 L .3027 .33625 L p F P
0 g
s
.009 .548 .841 r
.30351 .3358 m .29668 .33422 L .3027 .33625 L p F P
0 g
s
.009 .548 .841 r
.30461 .33612 m .30351 .3358 L p .3027 .33625 L F P
0 g
s
.009 .548 .841 r
.3027 .33625 m .3071 .33709 L .30461 .33612 L p F P
0 g
s
.397 .854 .851 r
.53122 .3335 m .52149 .3368 L .51893 .33701 L p F P
0 g
s
.602 .932 .959 r
.56341 .32213 m .5655 .32257 L .55574 .32659 L p F P
0 g
s
.602 .932 .959 r
.55574 .32659 m .55419 .32632 L .56341 .32213 L p F P
0 g
s
.764 .732 .823 r
.15206 .3157 m .16159 .30834 L .15851 .30489 L p F P
0 g
s
.764 .732 .823 r
.149 .31204 m .15206 .3157 L p .15851 .30489 L F P
0 g
s
.793 .727 .791 r
.15202 .31574 m .15206 .3157 L .149 .31204 L p F P
0 g
s
.805 .724 .775 r
.14239 .31901 m .14631 .3219 L .15202 .31574 L p F P
0 g
s
.805 .724 .775 r
.15202 .31574 m .14821 .3128 L .14239 .31901 L p F P
0 g
s
.793 .727 .791 r
.149 .31204 m .14821 .3128 L .15202 .31574 L p F P
0 g
s
0 0 0 r
.46294 .3496 m .46266 .34965 L .46116 .34982 L closepath p F P
0 g
s
0 0 0 r
.46004 .35041 m .46266 .34965 L .46116 .34982 L p F P
0 g
s
0 0 0 r
.45947 .35048 m .46004 .35041 L p .46116 .34982 L F P
0 g
s
0 0 0 r
.45036 .3513 m .45947 .35048 L p .46116 .34982 L F P
0 g
s
.469 0 0 r
.27927 .45261 m .27405 .45022 L .28039 .45204 L p F P
0 g
s
.469 0 0 r
.27938 .45264 m .27927 .45261 L p .28039 .45204 L F P
0 g
s
.469 0 0 r
.28039 .45204 m .28242 .45295 L .27938 .45264 L p F P
0 g
s
.573 .716 .939 r
.19844 .3066 m .20154 .30611 L .20582 .30886 L p F P
0 g
s
.586 .727 .941 r
.2075 .30512 m .20154 .30611 L .20582 .30886 L p F P
0 g
s
.586 .727 .941 r
.20582 .30886 m .21057 .30798 L .2075 .30512 L p F P
0 g
s
0 0 0 r
.53108 .45728 m .53335 .45629 L .52298 .4588 L p F P
0 g
s
0 0 0 r
.52298 .4588 m .52133 .4595 L .53108 .45728 L p F P
0 g
s
.719 .199 0 r
.21592 .42547 m .22114 .42774 L .21802 .42469 L p F P
0 g
s
.719 .199 0 r
.21802 .42469 m .21276 .42244 L .21592 .42547 L p F P
0 g
s
.639 .653 .848 r
.6612 .30646 m .66788 .3047 L .66254 .30881 L closepath p F P
0 g
s
.623 .64 .846 r
.67118 .30386 m .66788 .3047 L .66254 .30881 L p F P
0 g
s
.623 .64 .846 r
.67364 .30861 m .67118 .30386 L p .66254 .30881 L F P
0 g
s
0 0 0 r
.55359 .45059 m .55564 .4494 L .54587 .45222 L p F P
0 g
s
0 0 0 r
.54587 .45222 m .54355 .45356 L .55359 .45059 L p F P
0 g
s
.452 .307 .592 r
.68615 .35093 m .68295 .35324 L .68082 .34971 L p F P
0 g
s
.452 .307 .592 r
.68082 .34971 m .68558 .34626 L .68615 .35093 L p F P
0 g
s
.262 0 0 r
.3339 .46574 m .32742 .46423 L .33515 .46555 L p F P
0 g
s
.262 0 0 r
.33515 .46555 m .33688 .46594 L .3339 .46574 L p F P
0 g
s
.569 .542 .785 r
.67633 .3144 m .67863 .32009 L .68303 .31997 L p F P
0 g
s
.262 .77 .775 r
.50662 .34046 m .50858 .3401 L .4983 .34282 L p F P
0 g
s
.262 .77 .775 r
.4983 .34282 m .49692 .34303 L .50662 .34046 L p F P
0 g
s
0 0 0 r
.47228 .34834 m .474 .34788 L .46294 .3496 L p F P
0 g
s
0 0 0 r
.46294 .3496 m .46266 .34965 L .47228 .34834 L p F P
0 g
s
.679 .733 .891 r
.17398 .30655 m .18319 .3029 L .18625 .30607 L p F P
0 g
s
.673 .732 .894 r
.18319 .3029 m .17398 .30655 L .17091 .30325 L p F P
0 g
s
.035 0 0 r
.42059 .47219 m .41463 .47226 L .41322 .47233 L p F P
0 g
s
.074 0 0 r
.41463 .47226 m .41322 .47233 L .40894 .47222 L closepath p F P
0 g
s
.055 0 0 r
.41072 .47245 m .41322 .47233 L .40894 .47222 L p F P
0 g
s
.055 0 0 r
.40944 .47243 m .41072 .47245 L p .40894 .47222 L F P
0 g
s
.055 0 0 r
.40094 .47216 m .40944 .47243 L p .40894 .47222 L F P
0 g
s
.055 0 0 r
.40894 .47222 m .40201 .47214 L .40094 .47216 L p F P
0 g
s
.204 0 0 r
.36277 .34948 m .36161 .34941 L .35947 .34902 L closepath p F P
0 g
s
.052 0 0 r
.42697 .47207 m .42551 .47218 L .42059 .47219 L closepath p F P
0 g
s
.035 0 0 r
.42318 .47234 m .42551 .47218 L .42059 .47219 L p F P
0 g
s
.035 0 0 r
.4212 .47237 m .42318 .47234 L p .42059 .47219 L F P
0 g
s
.035 0 0 r
.41322 .47233 m .4212 .47237 L p .42059 .47219 L F P
0 g
s
.631 .729 .918 r
.18625 .30607 m .19538 .30357 L .19844 .3066 L p F P
0 g
s
.624 .727 .921 r
.19538 .30357 m .18625 .30607 L .18319 .3029 L p F P
0 g
s
.44 .694 .973 r
.2257 .31276 m .22914 .31279 L .23385 .31536 L p F P
0 g
s
.464 .711 .976 r
.23471 .31278 m .22914 .31279 L .23385 .31536 L p F P
0 g
s
.464 .711 .976 r
.23385 .31536 m .23776 .31526 L .23471 .31278 L p F P
0 g
s
.839 .419 .239 r
.17628 .39813 m .18098 .40064 L .17928 .39715 L p F P
0 g
s
.839 .419 .239 r
.17507 .39562 m .17628 .39813 L p .17928 .39715 L F P
0 g
s
.839 .419 .239 r
.17928 .39715 m .1763 .39557 L .17507 .39562 L p F P
0 g
s
.096 0 0 r
.40201 .47214 m .40094 .47216 L .39803 .47201 L closepath p F P
0 g
s
.488 .396 .677 r
.6927 .33507 m .69149 .32956 L .68352 .33573 L p F P
0 g
s
.488 .396 .677 r
.68735 .33922 m .6927 .33507 L p .68352 .33573 L F P
0 g
s
.488 .396 .677 r
.68352 .33573 m .68392 .33747 L .68735 .33922 L p F P
0 g
s
.014 0 0 r
.43316 .47184 m .42697 .47207 L .42551 .47218 L p F P
0 g
s
.678 .728 .887 r
.63654 .30621 m .64643 .30255 L .64885 .30581 L p F P
0 g
s
.688 .752 .901 r
.64643 .30255 m .63654 .30621 L .63414 .30348 L p F P
0 g
s
.692 .77 .911 r
.62427 .30745 m .63414 .30348 L .63654 .30621 L p F P
0 g
s
.654 .108 0 r
.24043 .43652 m .24122 .43711 L .23944 .43646 L closepath p F P
0 g
s
.075 0 0 r
.39809 .47222 m .40094 .47216 L .39803 .47201 L p F P
0 g
s
.075 0 0 r
.38867 .47168 m .39809 .47222 L p .39803 .47201 L F P
0 g
s
.075 0 0 r
.39803 .47201 m .38907 .47167 L .38867 .47168 L p F P
0 g
s
.271 0 0 r
.34943 .34724 m .35151 .34772 L .35947 .34902 L p F P
0 g
s
.226 0 0 r
.34943 .34724 m .35151 .34772 L .34811 .34707 L closepath p F P
0 g
s
.707 .185 0 r
.22552 .42906 m .22651 .42995 L .22409 .42899 L closepath p F P
0 g
s
.313 .049 .344 r
.66228 .38567 m .66068 .38666 L .66118 .38333 L p F P
0 g
s
.313 .049 .344 r
.66118 .38333 m .66674 .37986 L .66228 .38567 L p F P
0 g
s
.685 .897 .973 r
.59735 .31054 m .599 .31148 L .59238 .31514 L p F P
0 g
s
.685 .897 .973 r
.58754 .31495 m .59735 .31054 L p .59238 .31514 L F P
0 g
s
.69 .885 .97 r
.59978 .31193 m .59238 .31514 L .599 .31148 L closepath p F P
0 g
s
.659 .682 .861 r
.64885 .30581 m .65878 .30258 L .6612 .30646 L p F P
0 g
s
.67 .708 .876 r
.65878 .30258 m .64885 .30581 L .64643 .30255 L p F P
0 g
s
.184 0 0 r
.37643 .47081 m .37794 .47098 L .37578 .47083 L closepath p F P
0 g
s
.194 0 0 r
.37643 .47081 m .37794 .47098 L .38769 .47159 L p F P
0 g
s
.847 .703 .702 r
.13904 .33266 m .14297 .33554 L p .14276 .32817 L F P
0 g
s
.86 .692 .672 r
.13683 .33751 m .14079 .34038 L .14297 .33554 L p F P
0 g
s
.86 .692 .672 r
.14297 .33554 m .13904 .33266 L .13683 .33751 L p F P
0 g
s
.819 .711 .746 r
.13909 .32314 m .14239 .31901 L .14631 .3219 L p F P
0 g
s
.819 .711 .746 r
.14631 .3219 m .14212 .32728 L .13909 .32314 L p F P
0 g
s
.007 .528 .857 r
.29502 .33381 m .29668 .33422 L .2932 .33292 L closepath p F P
0 g
s
.03 0 0 r
.43904 .47159 m .43781 .47171 L .43316 .47184 L closepath p F P
0 g
s
.014 0 0 r
.43535 .47193 m .43781 .47171 L .43316 .47184 L p F P
0 g
s
.014 0 0 r
.43391 .47199 m .43535 .47193 L p .43316 .47184 L F P
0 g
s
.014 0 0 r
.42551 .47218 m .43391 .47199 L p .43316 .47184 L F P
0 g
s
.368 .154 .452 r
.67827 .3689 m .67003 .37445 L .67181 .36956 L p F P
0 g
s
.368 .154 .452 r
.67181 .36956 m .67839 .36512 L .67827 .3689 L p F P
0 g
s
.424 .682 .971 r
.22914 .31279 m .2257 .31276 L .22265 .31007 L p F P
0 g
s
.214 .646 .952 r
.27692 .32719 m .2721 .32642 L .27769 .32863 L p F P
0 g
s
.214 .646 .952 r
.27769 .32863 m .27995 .32892 L .27692 .32719 L p F P
0 g
s
.037 0 0 r
.49934 .46415 m .50248 .46363 L .49899 .46429 L closepath p F P
0 g
s
.021 0 0 r
.47118 .34875 m .47228 .34834 L .46266 .34965 L p F P
0 g
s
.021 0 0 r
.46266 .34965 m .46004 .35041 L .47118 .34875 L p F P
0 g
s
.225 0 0 r
.35855 .3493 m .35151 .34772 L .35947 .34902 L p F P
0 g
s
.225 0 0 r
.35875 .34933 m .35855 .3493 L p .35947 .34902 L F P
0 g
s
.225 0 0 r
.35947 .34902 m .36161 .34941 L .35875 .34933 L p F P
0 g
s
.228 0 0 r
.4012 .35313 m .4048 .35348 L .3999 .35334 L closepath p F P
0 g
s
.701 .811 .934 r
.63173 .30101 m .63414 .30348 L .62427 .30745 L p F P
0 g
s
.701 .811 .934 r
.63019 .30166 m .63173 .30101 L p .62427 .30745 L F P
0 g
s
.701 .811 .934 r
.62427 .30745 m .62331 .30656 L .63019 .30166 L p F P
0 g
s
.497 .391 .665 r
.68392 .33747 m .68735 .33922 L .68472 .34122 L closepath p F P
0 g
s
.011 0 0 r
.57766 .44109 m .57773 .44103 L .56802 .44442 L p F P
0 g
s
.011 0 0 r
.56802 .44442 m .56786 .44453 L .57766 .44109 L p F P
0 g
s
.117 0 0 r
.38907 .47167 m .38867 .47168 L .38769 .47159 L closepath p F P
0 g
s
.726 .727 .851 r
.16277 .30767 m .15851 .30489 L .16159 .30834 L closepath p F P
0 g
s
.107 0 0 r
.3858 .47164 m .37794 .47098 L .38769 .47159 L p F P
0 g
s
.107 0 0 r
.38769 .47159 m .38867 .47168 L .3858 .47164 L p F P
0 g
s
0 0 0 r
.44693 .47109 m .43904 .47159 L .43781 .47171 L p F P
0 g
s
.142 0 0 r
.62174 .41702 m .6215 .41742 L .62442 .41571 L closepath p F P
0 g
s
.769 .281 .068 r
.20255 .4178 m .19986 .41462 L .20487 .41698 L p F P
0 g
s
.769 .281 .068 r
.2073 .42005 m .20255 .4178 L p .20487 .41698 L F P
0 g
s
.769 .281 .068 r
.20487 .41698 m .20746 .42006 L .2073 .42005 L p F P
0 g
s
0 .434 .718 r
.32219 .34125 m .32285 .34142 L .32164 .34108 L closepath p F P
0 g
s
.563 .711 .94 r
.20154 .30611 m .19844 .3066 L .19538 .30357 L p F P
0 g
s
.178 0 .063 r
.63193 .41003 m .63129 .4114 L .63827 .40672 L closepath p F P
0 g
s
.33 0 0 r
.29857 .45819 m .30543 .45983 L .29922 .45775 L p F P
0 g
s
.33 0 0 r
.29446 .45683 m .29857 .45819 L p .29922 .45775 L F P
0 g
s
.33 0 0 r
.29922 .45775 m .29618 .45705 L .29446 .45683 L p F P
0 g
s
.837 .709 .723 r
.14212 .32728 m .14193 .32756 L .14276 .32817 L closepath p F P
0 g
s
.847 .703 .702 r
.14276 .32817 m .14193 .32756 L .13904 .33266 L p F P
0 g
s
.097 0 0 r
.59865 .4318 m .59963 .43067 L .58983 .43493 L p F P
0 g
s
.097 0 0 r
.58983 .43493 m .58923 .43561 L .59865 .4318 L p F P
0 g
s
.722 .727 .854 r
.16277 .30767 m .17091 .30325 L p .15851 .30488 L F P
0 g
s
.722 .727 .854 r
.15851 .30488 m .15851 .30489 L .16277 .30767 L p F P
0 g
s
.106 0 0 r
.61928 .4209 m .62036 .41937 L .61122 .4236 L p F P
0 g
s
.106 0 0 r
.61265 .42442 m .61928 .4209 L p .61122 .4236 L F P
0 g
s
.106 0 0 r
.61122 .4236 m .60967 .42579 L .61265 .42442 L p F P
0 g
s
.007 0 0 r
.57558 .44263 m .57766 .44109 L .56786 .44453 L p F P
0 g
s
.007 0 0 r
.56786 .44453 m .56585 .44603 L .57558 .44263 L p F P
0 g
s
.826 .387 .194 r
.18296 .40404 m .18769 .40652 L .18572 .40311 L p F P
0 g
s
.826 .387 .194 r
.18572 .40311 m .18098 .40064 L .18296 .40404 L p F P
0 g
s
.28 .639 .965 r
.25284 .3205 m .25368 .32062 L .25141 .31944 L closepath p F P
0 g
s
.594 .569 .796 r
.67611 .3139 m .6771 .31378 L .67633 .3144 L closepath p F P
0 g
s
.569 .542 .785 r
.68621 .31301 m .6771 .31378 L .67633 .3144 L p F P
0 g
s
.569 .542 .785 r
.68748 .31639 m .68621 .31301 L p .67633 .3144 L F P
0 g
s
.569 .542 .785 r
.68303 .31997 m .68748 .31639 L p .67633 .3144 L F P
0 g
s
.888 .591 .477 r
.14982 .3702 m .15403 .37293 L .15384 .36894 L p F P
0 g
s
.888 .591 .477 r
.15384 .36894 m .14963 .36621 L .14982 .3702 L p F P
0 g
s
.67 .923 .974 r
.58532 .31403 m .58754 .31495 L .57774 .31922 L p F P
0 g
s
.67 .923 .974 r
.57774 .31922 m .57649 .31877 L .58532 .31403 L p F P
0 g
s
.888 .616 .521 r
.14547 .36345 m .14963 .36621 L .14981 .36209 L p F P
0 g
s
.888 .616 .521 r
.14981 .36209 m .14566 .35933 L .14547 .36345 L p F P
0 g
s
.579 .004 0 r
.23969 .43774 m .24538 .43982 L .24122 .43711 L p F P
0 g
s
.579 .004 0 r
.23726 .43614 m .23969 .43774 L p .24122 .43711 L F P
0 g
s
.579 .004 0 r
.24122 .43711 m .23944 .43646 L .23726 .43614 L p F P
0 g
s
.076 0 0 r
.45036 .3513 m .45947 .35048 L .44868 .3518 L closepath p F P
0 g
s
.233 0 0 r
.34289 .46714 m .33688 .46594 L .3339 .46574 L p F P
0 g
s
.209 0 0 r
.41347 .35341 m .41615 .35356 L .41263 .35359 L closepath p F P
0 g
s
.506 0 0 r
.25575 .44445 m .26171 .44643 L .25702 .44388 L p F P
0 g
s
.506 0 0 r
.25227 .44257 m .25575 .44445 L p .25702 .44388 L F P
0 g
s
.506 0 0 r
.25702 .44388 m .25364 .44277 L .25227 .44257 L p F P
0 g
s
.605 .578 .797 r
.6771 .31378 m .67611 .3139 L .67364 .30861 L p F P
0 g
s
0 0 0 r
.50248 .46363 m .49899 .46429 L .49672 .46493 L p F P
0 g
s
.649 .661 .849 r
.66788 .3047 m .6612 .30646 L .65878 .30258 L p F P
0 g
s
.88 .55 .421 r
.15459 .3768 m .15897 .37945 L .15834 .37561 L p F P
0 g
s
.88 .55 .421 r
.15447 .37606 m .15459 .3768 L p .15834 .37561 L F P
0 g
s
.88 .55 .421 r
.15834 .37561 m .15683 .37469 L .15447 .37606 L p F P
0 g
s
.007 0 0 r
.45086 .47082 m .45012 .47091 L .44693 .47109 L closepath p F P
0 g
s
0 0 0 r
.44738 .47122 m .45012 .47091 L .44693 .47109 L p F P
0 g
s
0 0 0 r
.43781 .47171 m .44738 .47122 L p .44693 .47109 L F P
0 g
s
.525 .446 .708 r
.68419 .32782 m .68979 .32339 L .69147 .32948 L closepath p F P
0 g
s
.226 0 0 r
.33334 .46569 m .3339 .46574 L .32742 .46423 L p F P
0 g
s
.226 0 0 r
.32718 .46458 m .33334 .46569 L p .32742 .46423 L F P
0 g
s
.226 0 0 r
.32173 .46333 m .32718 .46458 L p .32742 .46423 L F P
0 g
s
.226 0 0 r
.32742 .46423 m .323 .46346 L .32173 .46333 L p F P
0 g
s
.296 .791 .777 r
.51863 .33707 m .51893 .33701 L .50921 .33998 L p F P
0 g
s
.296 .791 .777 r
.50921 .33998 m .50858 .3401 L .51863 .33707 L p F P
0 g
s
0 .414 .696 r
.32285 .34142 m .32164 .34108 L .3192 .34038 L p F P
0 g
s
0 .414 .696 r
.3192 .34038 m .32257 .34141 L p .32285 .34142 L F P
0 g
s
.884 .639 .562 r
.14155 .35654 m .14566 .35933 L .14626 .35506 L p F P
0 g
s
.884 .639 .562 r
.14626 .35506 m .14216 .35227 L .14155 .35654 L p F P
0 g
s
.079 0 0 r
.39809 .47222 m .38867 .47168 L .3858 .47164 L p F P
0 g
s
.083 0 0 r
.38486 .47162 m .3858 .47164 L .37794 .47098 L p F P
0 g
s
.083 0 0 r
.37841 .47116 m .38486 .47162 L p .37794 .47098 L F P
0 g
s
.083 0 0 r
.37353 .47074 m .37841 .47116 L p .37794 .47098 L F P
0 g
s
.083 0 0 r
.37794 .47098 m .37578 .47083 L .37353 .47074 L p F P
0 g
s
.707 .837 .944 r
.62186 .3052 m .61202 .30942 L .6096 .3076 L p F P
0 g
s
.704 .851 .953 r
.59978 .31193 m .6096 .3076 L .61202 .30942 L p F P
0 g
s
0 0 0 r
.49595 .46514 m .49672 .46493 L .48704 .46638 L p F P
0 g
s
0 0 0 r
.48704 .46638 m .48498 .46693 L .49595 .46514 L p F P
0 g
s
.133 0 0 r
.43805 .35249 m .44279 .3523 L .437 .35279 L closepath p F P
0 g
s
.178 0 0 r
.42576 .35319 m .42865 .35322 L .42499 .3534 L closepath p F P
0 g
s
.533 .918 .924 r
.55074 .32599 m .55324 .32616 L .54349 .33 L p F P
0 g
s
.533 .918 .924 r
.54899 .32669 m .55074 .32599 L p .54349 .33 L F P
0 g
s
.533 .918 .924 r
.54349 .33 m .54126 .32991 L .54899 .32669 L p F P
0 g
s
.837 .712 .726 r
.14193 .32756 m .14212 .32728 L .13909 .32314 L p F P
0 g
s
.643 .088 0 r
.22473 .43063 m .23015 .43282 L .22651 .42995 L p F P
0 g
s
.643 .088 0 r
.22231 .42872 m .22473 .43063 L p .22651 .42995 L F P
0 g
s
.643 .088 0 r
.22651 .42995 m .22409 .42899 L .22231 .42872 L p F P
0 g
s
.21 0 .14 r
.64182 .40265 m .64106 .4047 L .64846 .39897 L closepath p F P
0 g
s
.802 .337 .131 r
.19343 .40945 m .19278 .40941 L .19248 .40898 L closepath p F P
0 g
s
.471 .348 .631 r
.69079 .34229 m .68558 .34626 L .68472 .34122 L p F P
0 g
s
.471 .348 .631 r
.68472 .34122 m .68735 .33922 L .69079 .34229 L p F P
0 g
s
.139 0 0 r
.62442 .41571 m .6215 .41742 L .62036 .41937 L p F P
0 g
s
.128 0 0 r
.37578 .47083 m .37353 .47074 L .36868 .4702 L closepath p F P
0 g
s
0 0 0 r
.46228 .46981 m .45086 .47082 L .45012 .47091 L p F P
0 g
s
.837 .712 .726 r
.13909 .32314 m .13809 .32464 L .14193 .32756 L p F P
0 g
s
.849 .706 .704 r
.13517 .32975 m .13904 .33266 L .14193 .32756 L p F P
0 g
s
.849 .706 .704 r
.14193 .32756 m .13809 .32464 L .13517 .32975 L p F P
0 g
s
.437 0 0 r
.28242 .45295 m .28584 .45436 L .27938 .45264 L closepath p F P
0 g
s
.875 .519 .371 r
.15993 .38319 m .16436 .38582 L .1634 .38208 L p F P
0 g
s
.875 .519 .371 r
.1634 .38208 m .15897 .37945 L .15993 .38319 L p F P
0 g
s
.065 0 0 r
.60945 .42605 m .60967 .42579 L .60039 .4298 L p F P
0 g
s
.065 0 0 r
.60039 .4298 m .59963 .43067 L .60945 .42605 L p F P
0 g
s
.26 .63 .961 r
.2564 .31934 m .26175 .32167 L .25368 .32062 L p F P
0 g
s
.26 .63 .961 r
.2498 .31826 m .2564 .31934 L p .25368 .32062 L F P
0 g
s
.26 .63 .961 r
.25368 .32062 m .25141 .31944 L .2498 .31826 L p F P
0 g
s
0 .469 .742 r
.32164 .34108 m .3192 .34038 L .31607 .33968 L closepath p F P
0 g
s
.382 0 0 r
.29618 .45705 m .29446 .45683 L .29243 .45609 L closepath p F P
0 g
s
.584 .554 .787 r
.6771 .31378 m .68416 .308 L .68621 .31301 L closepath p F P
0 g
s
.605 .578 .797 r
.68416 .308 m .6771 .31378 L p .67364 .30861 L F P
0 g
s
.525 0 0 r
.26733 .44817 m .26774 .44838 L .27405 .45022 L p F P
0 g
s
.453 0 0 r
.27304 .45074 m .27927 .45261 L .27405 .45022 L p F P
0 g
s
.453 0 0 r
.27405 .45022 m .26774 .44838 L .27304 .45074 L p F P
0 g
s
0 0 0 r
.48327 .34606 m .474 .34788 L .47228 .34834 L p F P
0 g
s
0 .51 .84 r
.29728 .33383 m .30351 .3358 L .29668 .33422 L p F P
0 g
s
0 .51 .84 r
.29201 .33236 m .29728 .33383 L p .29668 .33422 L F P
0 g
s
0 .51 .84 r
.29668 .33422 m .2932 .33292 L .29201 .33236 L p F P
0 g
s
.879 .66 .602 r
.13812 .34944 m .14216 .35227 L .14323 .34783 L p F P
0 g
s
.879 .66 .602 r
.14323 .34783 m .1392 .345 L .13812 .34944 L p F P
0 g
s
.851 .443 .263 r
.1763 .39557 m .17507 .39562 L .17462 .39463 L closepath p F P
0 g
s
.621 .058 0 r
.23944 .43646 m .23726 .43614 L .23563 .43499 L closepath p F P
0 g
s
.027 0 0 r
.53361 .45614 m .5394 .45468 L .53335 .45629 L closepath p F P
0 g
s
.246 0 0 r
.35052 .34802 m .35855 .3493 L .35151 .34772 L p F P
0 g
s
.246 0 0 r
.34648 .34689 m .35052 .34802 L p .35151 .34772 L F P
0 g
s
.246 0 0 r
.35151 .34772 m .34811 .34707 L .34648 .34689 L p F P
0 g
s
0 0 0 r
.50972 .46223 m .50903 .46244 L .50248 .46363 L closepath p F P
0 g
s
0 0 0 r
.50674 .46311 m .50903 .46244 L .50248 .46363 L p F P
0 g
s
0 0 0 r
.50353 .46373 m .50674 .46311 L p .50248 .46363 L F P
0 g
s
0 0 0 r
.49672 .46493 m .50353 .46373 L p .50248 .46363 L F P
0 g
s
.338 0 0 r
.3096 .46046 m .31259 .46136 L .30744 .4603 L closepath p F P
0 g
s
.802 .336 .125 r
.18949 .40914 m .18769 .40652 L .19248 .40898 L p F P
0 g
s
.802 .336 .125 r
.19248 .40898 m .19278 .40941 L .18949 .40914 L p F P
0 g
s
.063 0 0 r
.40944 .47243 m .40094 .47216 L .39809 .47222 L p F P
0 g
s
0 .507 .846 r
.28486 .33005 m .27995 .32892 L .27692 .32719 L p F P
0 g
s
.701 .812 .934 r
.62331 .30656 m .62186 .3052 L .63019 .30166 L closepath p F P
0 g
s
.274 0 0 r
.36161 .34941 m .36669 .35054 L .35875 .34933 L closepath p F P
0 g
s
.866 .485 .319 r
.16562 .38945 m .17009 .39205 L .16883 .38842 L p F P
0 g
s
.866 .485 .319 r
.16883 .38842 m .16436 .38582 L .16562 .38945 L p F P
0 g
s
.199 0 .071 r
.63129 .4114 m .62442 .41571 L .63073 .41258 L closepath p F P
0 g
s
.139 0 0 r
.62937 .41493 m .63073 .41258 L .62442 .41571 L p F P
0 g
s
.139 0 0 r
.62036 .41937 m .62937 .41493 L p .62442 .41571 L F P
0 g
s
.277 0 0 r
.323 .46346 m .32173 .46333 L .31987 .46284 L closepath p F P
0 g
s
.39 .201 .501 r
.68322 .36171 m .67839 .36512 L .6783 .36108 L p F P
0 g
s
.39 .201 .501 r
.6783 .36108 m .6837 .35726 L .68322 .36171 L p F P
0 g
s
.006 0 0 r
.47474 .46825 m .48051 .46757 L .47381 .46848 L closepath p F P
0 g
s
.886 .562 .43 r
.15683 .37469 m .15447 .37606 L .15403 .37293 L closepath p F P
0 g
s
.755 .261 .056 r
.20746 .42006 m .20755 .42016 L .21276 .42244 L p F P
0 g
s
.712 .187 0 r
.21074 .42318 m .21592 .42547 L .21276 .42244 L p F P
0 g
s
.712 .187 0 r
.21276 .42244 m .20755 .42016 L .21074 .42318 L p F P
0 g
s
.102 0 0 r
.37139 .47064 m .37353 .47074 L .36868 .4702 L p F P
0 g
s
.102 0 0 r
.36902 .47041 m .37139 .47064 L p .36868 .4702 L F P
0 g
s
.102 0 0 r
.36128 .46953 m .36902 .47041 L p .36868 .4702 L F P
0 g
s
.102 0 0 r
.36868 .4702 m .36209 .46959 L .36128 .46953 L p F P
0 g
s
.508 .711 .963 r
.21057 .30798 m .21959 .30737 L .22265 .31007 L p F P
0 g
s
.493 .707 .966 r
.21959 .30737 m .21057 .30798 L .2075 .30512 L p F P
0 g
s
.556 .502 .75 r
.68303 .31997 m .68748 .31639 L .68878 .3202 L closepath p F P
0 g
s
.552 0 0 r
.25364 .44277 m .25227 .44257 L .25111 .44189 L closepath p F P
0 g
s
.871 .679 .639 r
.13522 .34214 m .1392 .345 L .14079 .34038 L p F P
0 g
s
.871 .679 .639 r
.14079 .34038 m .13683 .33751 L .13522 .34214 L p F P
0 g
s
.331 .093 .394 r
.66997 .37449 m .66996 .37457 L .67003 .37445 L closepath p F P
0 g
s
.497 .902 .915 r
.54096 .3299 m .54126 .32991 L .53163 .33351 L p F P
0 g
s
.497 .902 .915 r
.53163 .33351 m .53122 .3335 L .54096 .3299 L p F P
0 g
s
.329 .091 .392 r
.67797 .37245 m .67827 .3689 L .67003 .37445 L p F P
0 g
s
.329 .091 .392 r
.66964 .37802 m .67797 .37245 L p .67003 .37445 L F P
0 g
s
.329 .091 .392 r
.67003 .37445 m .66996 .37457 L .66964 .37802 L p F P
0 g
s
.345 .103 .397 r
.66996 .37457 m .66674 .37986 L .66964 .37802 L closepath p F P
0 g
s
0 0 0 r
.5394 .45468 m .53335 .45629 L .53108 .45728 L p F P
0 g
s
.679 .137 0 r
.22409 .42899 m .22231 .42872 L .22114 .42774 L closepath p F P
0 g
s
.238 0 .208 r
.6514 .39486 m .6508 .39697 L .65621 .39203 L closepath p F P
0 g
s
.794 .324 .116 r
.1949 .41224 m .19278 .40941 L .18949 .40914 L p F P
0 g
s
.316 .654 .971 r
.24352 .31577 m .23776 .31526 L .23471 .31278 L p F P
0 g
s
.336 .67 .976 r
.23776 .31526 m .24352 .31577 L .24861 .3182 L p F P
0 g
s
.223 0 0 r
.34811 .34707 m .34648 .34689 L .34385 .34631 L closepath p F P
0 g
s
.563 .711 .94 r
.19538 .30357 m .19745 .30328 L .20154 .30611 L p F P
0 g
s
.575 .723 .943 r
.20443 .30224 m .19745 .30328 L .20154 .30611 L p F P
0 g
s
.575 .723 .943 r
.20154 .30611 m .2075 .30512 L .20443 .30224 L p F P
0 g
s
.701 .887 .966 r
.6075 .30622 m .6096 .3076 L .59978 .31193 L p F P
0 g
s
.701 .887 .966 r
.59978 .31193 m .599 .31148 L .6075 .30622 L p F P
0 g
s
.039 0 0 r
.41322 .47233 m .4212 .47237 L .41072 .47245 L closepath p F P
0 g
s
0 0 0 r
.46246 .46979 m .46243 .4698 L .46228 .46981 L closepath p F P
0 g
s
0 0 0 r
.45972 .47014 m .46243 .4698 L .46228 .46981 L p F P
0 g
s
0 0 0 r
.45012 .47091 m .45972 .47014 L p .46228 .46981 L F P
0 g
s
.764 .732 .823 r
.15851 .30489 m .15851 .30489 L .149 .31204 L p F P
0 g
s
.761 .726 .819 r
.15851 .30489 m .149 .31204 L .14591 .30844 L p F P
0 g
s
.792 .729 .794 r
.14821 .3128 m .149 .31204 L .14591 .30844 L p F P
0 g
s
0 0 0 r
.47205 .46874 m .47381 .46848 L .46246 .46979 L p F P
0 g
s
0 0 0 r
.46246 .46979 m .46243 .4698 L .47205 .46874 L p F P
0 g
s
.792 .729 .794 r
.14591 .30844 m .14444 .30983 L .14821 .3128 L p F P
0 g
s
.805 .727 .778 r
.13852 .31608 m .14239 .31901 L .14821 .3128 L p F P
0 g
s
.805 .727 .778 r
.14821 .3128 m .14444 .30983 L .13852 .31608 L p F P
0 g
s
.286 .784 .77 r
.51635 .33753 m .51863 .33707 L .50858 .3401 L p F P
0 g
s
.286 .784 .77 r
.50858 .3401 m .50662 .34046 L .51635 .33753 L p F P
0 g
s
.424 .682 .971 r
.22265 .31007 m .22463 .31014 L .22914 .31279 L p F P
0 g
s
.445 .702 .976 r
.23165 .31029 m .22463 .31014 L .22914 .31279 L p F P
0 g
s
.445 .702 .976 r
.22914 .31279 m .23471 .31278 L .23165 .31029 L p F P
0 g
s
.133 .585 .925 r
.26488 .32369 m .26681 .32409 L .2721 .32642 L p F P
0 g
s
.171 .62 .938 r
.27389 .32546 m .26681 .32409 L .2721 .32642 L p F P
0 g
s
.171 .62 .938 r
.2721 .32642 m .27692 .32719 L .27389 .32546 L p F P
0 g
s
.379 0 0 r
.2914 .45643 m .28584 .45436 L .29243 .45609 L p F P
0 g
s
.379 0 0 r
.29243 .45609 m .29446 .45683 L .2914 .45643 L p F P
0 g
s
.021 0 0 r
.5973 .43306 m .59865 .4318 L .58923 .43561 L p F P
0 g
s
.021 0 0 r
.58923 .43561 m .58747 .43727 L .5973 .43306 L p F P
0 g
s
0 0 0 r
.47205 .46874 m .46243 .4698 L .45972 .47014 L p F P
0 g
s
.852 .443 .261 r
.17165 .3956 m .17009 .39205 L .17462 .39463 L p F P
0 g
s
.852 .443 .261 r
.17183 .3957 m .17165 .3956 L p .17462 .39463 L F P
0 g
s
.852 .443 .261 r
.17462 .39463 m .17507 .39562 L .17183 .3957 L p F P
0 g
s
0 0 0 r
.56543 .44628 m .56585 .44603 L .55598 .4492 L p F P
0 g
s
0 0 0 r
.55598 .4492 m .55564 .4494 L .56543 .44628 L p F P
0 g
s
.272 0 0 r
.31872 .46298 m .31259 .46136 L .31987 .46284 L p F P
0 g
s
.272 0 0 r
.31987 .46284 m .32173 .46333 L .31872 .46298 L p F P
0 g
s
.602 .932 .958 r
.56302 .32205 m .56341 .32213 L .55419 .32632 L p F P
0 g
s
.602 .932 .958 r
.55419 .32632 m .55324 .32616 L .56302 .32205 L p F P
0 g
s
.222 0 0 r
.34907 .46793 m .35114 .46829 L .3597 .46931 L p F P
0 g
s
.213 0 0 r
.34907 .46793 m .35114 .46829 L .34796 .46789 L closepath p F P
0 g
s
.181 .706 .686 r
.50567 .34073 m .50662 .34046 L .49692 .34303 L p F P
0 g
s
.181 .706 .686 r
.49692 .34303 m .49535 .34343 L .50567 .34073 L p F P
0 g
s
.22 0 0 r
.41615 .35356 m .41263 .35359 L .41064 .35406 L p F P
0 g
s
.263 0 0 r
.41263 .35359 m .41064 .35406 L .4048 .35348 L closepath p F P
0 g
s
.632 .937 .963 r
.57282 .31772 m .57528 .31835 L .5655 .32257 L p F P
0 g
s
.632 .937 .963 r
.56782 .31993 m .57282 .31772 L p .5655 .32257 L F P
0 g
s
.632 .937 .963 r
.5655 .32257 m .56341 .32213 L .56782 .31993 L p F P
0 g
s
.376 .692 .981 r
.25141 .31944 m .2498 .31826 L .24861 .3182 L closepath p F P
0 g
s
.239 0 0 r
.42499 .3534 m .42295 .35396 L .41615 .35356 L closepath p F P
0 g
s
.22 0 0 r
.42204 .35428 m .42295 .35396 L .41615 .35356 L p F P
0 g
s
.22 0 0 r
.41393 .35437 m .42204 .35428 L p .41615 .35356 L F P
0 g
s
.22 0 0 r
.41064 .35406 m .41393 .35437 L p .41615 .35356 L F P
0 g
s
.148 0 0 r
.36209 .46959 m .36128 .46953 L .3597 .46931 L closepath p F P
0 g
s
.017 0 0 r
.42551 .47218 m .43391 .47199 L .42318 .47234 L closepath p F P
0 g
s
.241 0 0 r
.40957 .35438 m .41064 .35406 L .4048 .35348 L p F P
0 g
s
.241 0 0 r
.40273 .35424 m .40957 .35438 L p .4048 .35348 L F P
0 g
s
.241 0 0 r
.39834 .35362 m .40273 .35424 L p .4048 .35348 L F P
0 g
s
.241 0 0 r
.4048 .35348 m .3999 .35334 L .39834 .35362 L p F P
0 g
s
0 .417 .707 r
.3071 .33709 m .30964 .3378 L .31607 .33968 L p F P
0 g
s
0 .452 .765 r
.3071 .33709 m .30964 .3378 L .30461 .33612 L closepath p F P
0 g
s
0 0 0 r
.45972 .47014 m .45012 .47091 L .44738 .47122 L p F P
0 g
s
.085 .586 .895 r
.2932 .33292 m .29201 .33236 L .29078 .33214 L closepath p F P
0 g
s
.188 0 0 r
.42865 .35322 m .42499 .3534 L .42295 .35396 L p F P
0 g
s
0 0 0 r
.44727 .47123 m .44738 .47122 L .43781 .47171 L p F P
0 g
s
0 0 0 r
.43781 .47171 m .43535 .47193 L .44727 .47123 L p F P
0 g
s
.605 .578 .797 r
.67364 .30861 m .6837 .30696 L .68416 .308 L p F P
0 g
s
.619 .603 .812 r
.6837 .30696 m .67364 .30861 L .67118 .30386 L p F P
0 g
s
.274 0 0 r
.3999 .35334 m .39834 .35362 L .39434 .35309 L closepath p F P
0 g
s
.193 0 0 r
.31614 .33952 m .3162 .33954 L .3162 .33954 L p F P
0 g
s
0 .465 .736 r
.30982 .33785 m .31607 .33968 L p .31614 .33952 L F P
0 g
s
.193 0 0 r
.3162 .33954 m .31318 .33879 L p .31614 .33952 L F P
0 g
s
0 .465 .736 r
.31614 .33952 m .30964 .3378 L .30982 .33785 L p F P
0 g
s
0 .465 .736 r
.31625 .33955 m .31614 .33952 L p .31607 .33968 L F P
0 g
s
0 .465 .736 r
.31607 .33968 m .3192 .34038 L .31625 .33955 L p F P
0 g
s
.283 0 0 r
.33432 .34416 m .33652 .34477 L .34385 .34631 L p F P
0 g
s
.237 0 0 r
.33432 .34416 m .33652 .34477 L .33268 .34384 L closepath p F P
0 g
s
.673 .732 .894 r
.17091 .30325 m .18011 .29973 L .18319 .3029 L p F P
0 g
s
.668 .731 .897 r
.18011 .29973 m .17091 .30325 L .16783 .29995 L p F P
0 g
s
.722 .727 .854 r
.17091 .30325 m .16783 .29995 L .15851 .30488 L p F P
0 g
s
.14 0 0 r
.35836 .46931 m .35114 .46829 L .3597 .46931 L p F P
0 g
s
.14 0 0 r
.3597 .46931 m .36128 .46953 L .35836 .46931 L p F P
0 g
s
.42 .254 .548 r
.68647 .35526 m .6837 .35726 L .68295 .35324 L p F P
0 g
s
.42 .254 .548 r
.68295 .35324 m .68615 .35093 L .68647 .35526 L p F P
0 g
s
.201 0 0 r
.437 .35279 m .43528 .35331 L .42865 .35322 L closepath p F P
0 g
s
.188 0 0 r
.43414 .35376 m .43528 .35331 L .42865 .35322 L p F P
0 g
s
.188 0 0 r
.42626 .35411 m .43414 .35376 L p .42865 .35322 L F P
0 g
s
.188 0 0 r
.42295 .35396 m .42626 .35411 L p .42865 .35322 L F P
0 g
s
.764 .268 .04 r
.19761 .4154 m .20255 .4178 L .19986 .41462 L p F P
0 g
s
.764 .268 .04 r
.19986 .41462 m .1949 .41224 L .19761 .4154 L p F P
0 g
s
.519 0 0 r
.26733 .44817 m .26774 .44838 L .26691 .44813 L closepath p F P
0 g
s
.438 .877 .864 r
.54096 .3299 m .53122 .3335 L .52867 .33372 L p F P
0 g
s
.397 .854 .851 r
.51893 .33701 m .52867 .33372 L .53122 .3335 L p F P
0 g
s
.862 .695 .674 r
.13293 .33461 m .13683 .33751 L .13904 .33266 L p F P
0 g
s
.862 .695 .674 r
.13904 .33266 m .13517 .32975 L .13293 .33461 L p F P
0 g
s
.819 .715 .75 r
.13604 .31913 m .13852 .31608 L .14239 .31901 L p F P
0 g
s
.819 .715 .75 r
.14239 .31901 m .13909 .32314 L .13604 .31913 L p F P
0 g
s
.549 0 0 r
.24912 .44206 m .24538 .43982 L .25111 .44189 L p F P
0 g
s
.549 0 0 r
.25111 .44189 m .25227 .44257 L .24912 .44206 L p F P
0 g
s
.238 0 0 r
.34306 .34651 m .33652 .34477 L .34385 .34631 L p F P
0 g
s
.238 0 0 r
.3438 .34665 m .34306 .34651 L p .34385 .34631 L F P
0 g
s
.238 0 0 r
.34385 .34631 m .34648 .34689 L .3438 .34665 L p F P
0 g
s
.175 0 .06 r
.63827 .40672 m .63129 .4114 L .63073 .41258 L p F P
0 g
s
.441 .298 .591 r
.6928 .34588 m .68615 .35093 L .68558 .34626 L p F P
0 g
s
.441 .298 .591 r
.68558 .34626 m .69079 .34229 L .6928 .34588 L p F P
0 g
s
.248 0 0 r
.39669 .35402 m .39834 .35362 L .39434 .35309 L p F P
0 g
s
.248 0 0 r
.3924 .35378 m .39669 .35402 L p .39434 .35309 L F P
0 g
s
.248 0 0 r
.38607 .35266 m .3924 .35378 L p .39434 .35309 L F P
0 g
s
.248 0 0 r
.39434 .35309 m .3867 .35259 L .38607 .35266 L p F P
0 g
s
.624 .727 .921 r
.18319 .3029 m .1923 .30053 L .19538 .30357 L p F P
0 g
s
.618 .725 .923 r
.1923 .30053 m .18319 .3029 L .18011 .29973 L p F P
0 g
s
.619 .056 0 r
.23405 .43563 m .23015 .43282 L .23563 .43499 L p F P
0 g
s
.619 .056 0 r
.23411 .43565 m .23405 .43563 L p .23563 .43499 L F P
0 g
s
.619 .056 0 r
.23563 .43499 m .23726 .43614 L .23411 .43565 L p F P
0 g
s
0 0 0 r
.51876 .46041 m .52028 .45995 L .50972 .46223 L p F P
0 g
s
0 0 0 r
.50972 .46223 m .50903 .46244 L .51876 .46041 L p F P
0 g
s
0 0 0 r
.53068 .45745 m .53108 .45728 L .52133 .4595 L p F P
0 g
s
0 0 0 r
.52133 .4595 m .52028 .45995 L .53068 .45745 L p F P
0 g
s
.67 .924 .973 r
.58509 .31393 m .58532 .31403 L .57649 .31877 L p F P
0 g
s
.67 .924 .973 r
.57649 .31877 m .57528 .31835 L .58509 .31393 L p F P
0 g
s
0 0 0 r
.48477 .34578 m .48461 .34582 L .48327 .34606 L closepath p F P
0 g
s
0 0 0 r
.48199 .34667 m .48461 .34582 L .48327 .34606 L p F P
0 g
s
0 0 0 r
.48153 .34676 m .48199 .34667 L p .48327 .34606 L F P
0 g
s
0 0 0 r
.47228 .34834 m .48153 .34676 L p .48327 .34606 L F P
0 g
s
.162 .591 .936 r
.26488 .32369 m .26681 .32409 L .26196 .32176 L closepath p F P
0 g
s
.469 .348 .632 r
.69358 .34014 m .69079 .34229 L .68735 .33922 L p F P
0 g
s
.469 .348 .632 r
.68735 .33922 m .6927 .33507 L .69358 .34014 L p F P
0 g
s
.67 .708 .876 r
.64643 .30255 m .65636 .29905 L .65878 .30258 L p F P
0 g
s
.681 .733 .889 r
.65636 .29905 m .64643 .30255 L .64403 .29959 L p F P
0 g
s
.688 .752 .901 r
.63414 .30348 m .64403 .29959 L .64643 .30255 L p F P
0 g
s
.826 .383 .181 r
.17829 .40152 m .18296 .40404 L .18098 .40064 L p F P
0 g
s
.826 .383 .181 r
.18098 .40064 m .17628 .39813 L .17829 .40152 L p F P
0 g
s
0 0 0 r
.56348 .44741 m .56543 .44628 L .55564 .4494 L p F P
0 g
s
0 0 0 r
.55564 .4494 m .55359 .45059 L .56348 .44741 L p F P
0 g
s
.142 0 0 r
.44279 .3523 m .437 .35279 L .43528 .35331 L p F P
0 g
s
.421 0 0 r
.26685 .44884 m .27304 .45074 L .26774 .44838 L p F P
0 g
s
.421 0 0 r
.26421 .44766 m .26685 .44884 L p .26774 .44838 L F P
0 g
s
.421 0 0 r
.26774 .44838 m .26691 .44813 L .26421 .44766 L p F P
0 g
s
.299 0 0 r
.37383 .35123 m .37544 .35156 L .37303 .35129 L closepath p F P
0 g
s
.332 0 0 r
.37383 .35123 m .37544 .35156 L .38462 .35242 L p F P
0 g
s
.845 .429 .246 r
.17507 .39562 m .17628 .39813 L .17183 .3957 L closepath p F P
0 g
s
.697 .776 .913 r
.64403 .29959 m .63414 .30348 L .63173 .30101 L p F P
0 g
s
.753 .733 .834 r
.15851 .30488 m .15851 .30489 L .15851 .30489 L closepath p F P
0 g
s
.751 .734 .837 r
.15851 .30489 m .15851 .30488 L .15542 .30147 L p F P
0 g
s
.751 .734 .837 r
.15542 .30147 m .15482 .30188 L .15851 .30489 L p F P
0 g
s
.761 .726 .819 r
.14591 .30844 m .15482 .30188 L .15851 .30489 L p F P
0 g
s
.714 .735 .868 r
.16783 .29995 m .15851 .30488 L .15542 .30147 L p F P
0 g
s
.678 .135 0 r
.21909 .42821 m .21592 .42547 L .22114 .42774 L p F P
0 g
s
.678 .135 0 r
.22114 .42774 m .22231 .42872 L .21909 .42821 L p F P
0 g
s
.08 .584 .892 r
.28899 .33094 m .28486 .33005 L .29078 .33214 L p F P
0 g
s
.08 .584 .892 r
.29078 .33214 m .29201 .33236 L .28899 .33094 L p F P
0 g
s
.15 .687 .691 r
.49429 .34371 m .49535 .34343 L .48477 .34578 L p F P
0 g
s
.15 .687 .691 r
.48477 .34578 m .48461 .34582 L .49429 .34371 L p F P
0 g
s
.059 0 0 r
.60793 .42777 m .60945 .42605 L .59963 .43067 L p F P
0 g
s
.059 0 0 r
.59963 .43067 m .59865 .4318 L .60793 .42777 L p F P
0 g
s
.27 0 0 r
.3867 .35259 m .38607 .35266 L .38462 .35242 L closepath p F P
0 g
s
.891 .593 .475 r
.14566 .36744 m .14982 .3702 L .14963 .36621 L p F P
0 g
s
.891 .593 .475 r
.14963 .36621 m .14547 .36345 L .14566 .36744 L p F P
0 g
s
.302 .037 .335 r
.66914 .38133 m .66228 .38567 L .66674 .37986 L p F P
0 g
s
.302 .037 .335 r
.66674 .37986 m .66964 .37802 L .66914 .38133 L p F P
0 g
s
.474 0 0 r
.26691 .44813 m .26421 .44766 L .26171 .44643 L closepath p F P
0 g
s
.261 0 .269 r
.66068 .38666 m .66047 .38765 L .66228 .38567 L closepath p F P
0 g
s
.649 .661 .849 r
.67048 .3026 m .66788 .3047 L p .65878 .30258 L F P
0 g
s
.635 .649 .847 r
.66788 .3047 m .67048 .3026 L .67118 .30386 L closepath p F P
0 g
s
.891 .619 .52 r
.14136 .36066 m .14547 .36345 L .14566 .35933 L p F P
0 g
s
.891 .619 .52 r
.14566 .35933 m .14155 .35654 L .14136 .36066 L p F P
0 g
s
.703 .889 .966 r
.60719 .30601 m .6075 .30622 L .599 .31148 L p F P
0 g
s
.703 .889 .966 r
.599 .31148 m .59735 .31054 L .60719 .30601 L p F P
0 g
s
.888 .563 .429 r
.15035 .37408 m .14982 .3702 L .15403 .37293 L p F P
0 g
s
.888 .563 .429 r
.15389 .37637 m .15035 .37408 L p .15403 .37293 L F P
0 g
s
.888 .563 .429 r
.15403 .37293 m .15447 .37606 L .15389 .37637 L p F P
0 g
s
.295 0 0 r
.38282 .35306 m .37544 .35156 L .38462 .35242 L p F P
0 g
s
.295 0 0 r
.38333 .3531 m .38282 .35306 L p .38462 .35242 L F P
0 g
s
.295 0 0 r
.38462 .35242 m .38607 .35266 L .38333 .3531 L p F P
0 g
s
.407 .671 .968 r
.22463 .31014 m .22265 .31007 L .21959 .30737 L p F P
0 g
s
.649 .661 .849 r
.65878 .30258 m .66875 .29962 L .67048 .3026 L p F P
0 g
s
.66 .686 .863 r
.66875 .29962 m .65878 .30258 L .65636 .29905 L p F P
0 g
s
0 0 0 r
.48051 .46757 m .47381 .46848 L .47205 .46874 L p F P
0 g
s
.837 .716 .73 r
.13809 .32464 m .13909 .32314 L .13604 .31913 L p F P
0 g
s
.688 .917 .971 r
.59492 .30938 m .59735 .31054 L .58754 .31495 L p F P
0 g
s
.688 .917 .971 r
.58701 .31304 m .59492 .30938 L p .58754 .31495 L F P
0 g
s
.688 .917 .971 r
.58754 .31495 m .58532 .31403 L .58701 .31304 L p F P
0 g
s
.377 .691 .981 r
.24675 .31602 m .24352 .31577 L .24861 .3182 L p F P
0 g
s
.377 .691 .981 r
.24861 .3182 m .2498 .31826 L .24675 .31602 L p F P
0 g
s
.149 0 0 r
.44868 .3518 m .44761 .35214 L .44279 .3523 L closepath p F P
0 g
s
.142 0 0 r
.44591 .35283 m .44761 .35214 L .44279 .3523 L p F P
0 g
s
.142 0 0 r
.44018 .35328 m .44591 .35283 L p .44279 .3523 L F P
0 g
s
.142 0 0 r
.43528 .35331 m .44018 .35328 L p .44279 .3523 L F P
0 g
s
0 0 0 r
.49263 .34435 m .49429 .34371 L .48461 .34582 L p F P
0 g
s
0 0 0 r
.48461 .34582 m .48199 .34667 L .49263 .34435 L p F P
0 g
s
.888 .642 .562 r
.13751 .35372 m .14155 .35654 L .14216 .35227 L p F P
0 g
s
.888 .642 .562 r
.14216 .35227 m .13812 .34944 L .13751 .35372 L p F P
0 g
s
.241 0 0 r
.32718 .46458 m .32173 .46333 L .31872 .46298 L p F P
0 g
s
0 0 0 r
.57773 .44103 m .57766 .44109 L .58059 .43996 L closepath p F P
0 g
s
0 0 0 r
.54355 .45356 m .54337 .45364 L .5394 .45468 L closepath p F P
0 g
s
0 0 0 r
.54092 .45472 m .54337 .45364 L .5394 .45468 L p F P
0 g
s
0 0 0 r
.53949 .4551 m .54092 .45472 L p .5394 .45468 L F P
0 g
s
0 0 0 r
.53108 .45728 m .53949 .4551 L p .5394 .45468 L F P
0 g
s
.554 .706 .941 r
.19745 .30328 m .19538 .30357 L .1923 .30053 L p F P
0 g
s
.108 0 0 r
.36902 .47041 m .36128 .46953 L .35836 .46931 L p F P
0 g
s
.108 0 0 r
.35751 .46923 m .35836 .46931 L .35114 .46829 L p F P
0 g
s
.108 0 0 r
.35154 .46846 m .35751 .46923 L p .35114 .46829 L F P
0 g
s
.108 0 0 r
.34612 .46769 m .35154 .46846 L p .35114 .46829 L F P
0 g
s
.108 0 0 r
.35114 .46829 m .34796 .46789 L .34612 .46769 L p F P
0 g
s
.877 .519 .365 r
.15556 .38053 m .15993 .38319 L .15897 .37945 L p F P
0 g
s
.877 .519 .365 r
.15897 .37945 m .15459 .3768 L .15556 .38053 L p F P
0 g
s
.231 0 0 r
.31812 .46291 m .31872 .46298 L .31259 .46136 L p F P
0 g
s
.231 0 0 r
.31239 .46168 m .31812 .46291 L p .31259 .46136 L F P
0 g
s
.231 0 0 r
.30657 .46016 m .31239 .46168 L p .31259 .46136 L F P
0 g
s
.231 0 0 r
.31259 .46136 m .30744 .4603 L .30657 .46016 L p F P
0 g
s
.229 0 .146 r
.64106 .4047 m .63827 .40672 L .6408 .40538 L closepath p F P
0 g
s
.175 0 .06 r
.6396 .40791 m .6408 .40538 L .63827 .40672 L p F P
0 g
s
.175 0 .06 r
.63073 .41258 m .6396 .40791 L p .63827 .40672 L F P
0 g
s
0 0 0 r
.58059 .43996 m .57766 .44109 L .57558 .44263 L p F P
0 g
s
.35 0 0 r
.29857 .45819 m .29446 .45683 L .2914 .45643 L p F P
0 g
s
.699 .835 .948 r
.63019 .30166 m .62186 .3052 L .61945 .30321 L p F P
0 g
s
.707 .837 .944 r
.6096 .3076 m .61945 .30321 L .62186 .3052 L p F P
0 g
s
.527 0 0 r
.25575 .44445 m .25227 .44257 L .24912 .44206 L p F P
0 g
s
.755 .258 .043 r
.20746 .42006 m .20755 .42016 L .2073 .42005 L closepath p F P
0 g
s
.837 .716 .73 r
.13604 .31913 m .1343 .32168 L .13809 .32464 L p F P
0 g
s
.85 .709 .706 r
.13134 .32681 m .13517 .32975 L .13809 .32464 L p F P
0 g
s
.85 .709 .706 r
.13809 .32464 m .1343 .32168 L .13134 .32681 L p F P
0 g
s
.333 0 0 r
.29112 .45639 m .2914 .45643 L .28584 .45436 L p F P
0 g
s
.333 0 0 r
.28523 .45477 m .29112 .45639 L p .28584 .45436 L F P
0 g
s
.333 0 0 r
.27933 .45263 m .28523 .45477 L p .28584 .45436 L F P
0 g
s
.333 0 0 r
.28584 .45436 m .27938 .45264 L .27933 .45263 L p F P
0 g
s
.807 .343 .128 r
.18522 .40735 m .18296 .40404 L .18769 .40652 L p F P
0 g
s
.807 .343 .128 r
.18842 .40903 m .18522 .40735 L p .18769 .40652 L F P
0 g
s
.807 .343 .128 r
.18769 .40652 m .18949 .40914 L .18842 .40903 L p F P
0 g
s
.701 .167 0 r
.20562 .42085 m .21074 .42318 L .20755 .42016 L p F P
0 g
s
.701 .167 0 r
.20421 .41951 m .20562 .42085 L p .20755 .42016 L F P
0 g
s
.701 .167 0 r
.20755 .42016 m .2073 .42005 L .20421 .41951 L p F P
0 g
s
.882 .663 .602 r
.13414 .34659 m .13812 .34944 L .1392 .345 L p F P
0 g
s
.882 .663 .602 r
.1392 .345 m .13522 .34214 L .13414 .34659 L p F P
0 g
s
.084 0 0 r
.45947 .35048 m .44868 .3518 L .44761 .35214 L p F P
0 g
s
.158 0 0 r
.34796 .46789 m .34612 .46769 L .34289 .46714 L closepath p F P
0 g
s
.207 0 .136 r
.64846 .39897 m .64106 .4047 L .6408 .40538 L p F P
0 g
s
.576 .932 .939 r
.56302 .32205 m .55324 .32616 L .55074 .32599 L p F P
0 g
s
.732 .213 0 r
.2073 .42005 m .20421 .41951 L .20255 .4178 L closepath p F P
0 g
s
0 .41 .733 r
.29728 .33383 m .29201 .33236 L .28899 .33094 L p F P
0 g
s
.869 .485 .312 r
.1612 .38681 m .16562 .38945 L .16436 .38582 L p F P
0 g
s
.869 .485 .312 r
.16436 .38582 m .15993 .38319 L .1612 .38681 L p F P
0 g
s
.26 0 0 r
.33565 .34499 m .34306 .34651 L .33652 .34477 L p F P
0 g
s
.26 0 0 r
.33134 .3436 m .33565 .34499 L p .33652 .34477 L F P
0 g
s
.26 0 0 r
.33652 .34477 m .33268 .34384 L .33134 .3436 L p F P
0 g
s
.182 .602 .942 r
.2564 .31934 m .2498 .31826 L .24675 .31602 L p F P
0 g
s
.315 0 0 r
.37368 .35217 m .38282 .35306 L .37544 .35156 L p F P
0 g
s
.315 0 0 r
.3709 .35147 m .37368 .35217 L p .37544 .35156 L F P
0 g
s
.315 0 0 r
.37544 .35156 m .37303 .35129 L .3709 .35147 L p F P
0 g
s
0 0 0 r
.51734 .46084 m .51876 .46041 L .50903 .46244 L p F P
0 g
s
0 0 0 r
.50903 .46244 m .50674 .46311 L .51734 .46084 L p F P
0 g
s
.259 0 .267 r
.66847 .38443 m .66914 .38133 L .66228 .38567 L p F P
0 g
s
.259 0 .267 r
.66 .38977 m .66847 .38443 L p .66228 .38567 L F P
0 g
s
.259 0 .267 r
.66228 .38567 m .66047 .38765 L .66 .38977 L p F P
0 g
s
.352 .141 .448 r
.6816 .36655 m .67827 .3689 L .67839 .36512 L p F P
0 g
s
.352 .141 .448 r
.67839 .36512 m .68322 .36171 L .6816 .36655 L p F P
0 g
s
0 .431 .742 r
.30956 .33768 m .31614 .33952 L .30964 .3378 L p F P
0 g
s
0 .431 .742 r
.30409 .33593 m .30956 .33768 L p .30964 .3378 L F P
0 g
s
0 .431 .742 r
.30964 .3378 m .30461 .33612 L .30409 .33593 L p F P
0 g
s
0 0 0 r
.48498 .46693 m .48439 .46704 L .48051 .46757 L closepath p F P
0 g
s
0 0 0 r
.48172 .46747 m .48439 .46704 L .48051 .46757 L p F P
0 g
s
0 0 0 r
.47205 .46874 m .48172 .46747 L p .48051 .46757 L F P
0 g
s
.136 .578 .926 r
.27373 .32537 m .27389 .32546 L .26681 .32409 L p F P
0 g
s
.136 .578 .926 r
.26846 .32324 m .27373 .32537 L p .26681 .32409 L F P
0 g
s
.136 .578 .926 r
.26184 .32168 m .26846 .32324 L p .26681 .32409 L F P
0 g
s
.136 .578 .926 r
.26681 .32409 m .26196 .32176 L .26184 .32168 L p F P
0 g
s
.315 0 0 r
.38607 .35266 m .3924 .35378 L .38333 .3531 L closepath p F P
0 g
s
.324 .808 .778 r
.52849 .33375 m .52867 .33372 L .51893 .33701 L p F P
0 g
s
.324 .808 .778 r
.51893 .33701 m .51863 .33707 L .52849 .33375 L p F P
0 g
s
.593 .022 0 r
.23726 .43614 m .23969 .43774 L .23411 .43565 L closepath p F P
0 g
s
.278 0 .274 r
.66047 .38765 m .65621 .39203 L .66 .38977 L closepath p F P
0 g
s
.323 0 0 r
.37303 .35129 m .3709 .35147 L .36669 .35054 L closepath p F P
0 g
s
.662 .114 0 r
.22473 .43063 m .22231 .42872 L .21909 .42821 L p F P
0 g
s
.874 .682 .64 r
.1313 .33925 m .13522 .34214 L .13683 .33751 L p F P
0 g
s
.874 .682 .64 r
.13683 .33751 m .13293 .33461 L .1313 .33925 L p F P
0 g
s
.304 0 0 r
.34648 .34689 m .35052 .34802 L .3438 .34665 L closepath p F P
0 g
s
.619 .603 .812 r
.67118 .30386 m .68123 .30174 L .6837 .30696 L p F P
0 g
s
.622 .643 .85 r
.67048 .3026 m .67118 .30386 L .68123 .30174 L p F P
0 g
s
.407 .671 .968 r
.21959 .30737 m .22029 .30741 L .22463 .31014 L p F P
0 g
s
.426 .692 .975 r
.22858 .30777 m .22029 .30741 L .22463 .31014 L p F P
0 g
s
.426 .692 .975 r
.22463 .31014 m .23165 .31029 L .22858 .30777 L p F P
0 g
s
.255 0 .213 r
.6508 .39697 m .64846 .39897 L .65056 .39779 L closepath p F P
0 g
s
.207 0 .136 r
.64953 .40049 m .65056 .39779 L .64846 .39897 L p F P
0 g
s
.207 0 .136 r
.6408 .40538 m .64953 .40049 L p .64846 .39897 L F P
0 g
s
.052 0 0 r
.58747 .43727 m .58059 .43996 L .5873 .43743 L closepath p F P
0 g
s
0 0 0 r
.58517 .43903 m .5873 .43743 L .58059 .43996 L p F P
0 g
s
0 0 0 r
.57558 .44263 m .58517 .43903 L p .58059 .43996 L F P
0 g
s
.014 0 0 r
.47228 .34834 m .48153 .34676 L .47118 .34875 L closepath p F P
0 g
s
.554 .706 .941 r
.1923 .30053 m .19348 .30039 L .19745 .30328 L p F P
0 g
s
.565 .719 .945 r
.20136 .29935 m .19348 .30039 L .19745 .30328 L p F P
0 g
s
.565 .719 .945 r
.19745 .30328 m .20443 .30224 L .20136 .29935 L p F P
0 g
s
.107 0 0 r
.63892 .40907 m .6396 .40791 L .63073 .41258 L p F P
0 g
s
.107 0 0 r
.63185 .41363 m .63892 .40907 L p .63073 .41258 L F P
0 g
s
.107 0 0 r
.63073 .41258 m .62937 .41493 L .63185 .41363 L p F P
0 g
s
.09 0 0 r
.37353 .47074 m .37841 .47116 L .37139 .47064 L closepath p F P
0 g
s
0 0 0 r
.55316 .45079 m .55359 .45059 L .54355 .45356 L p F P
0 g
s
0 0 0 r
.54355 .45356 m .54337 .45364 L .55316 .45079 L p F P
0 g
s
.857 .448 .257 r
.16718 .39299 m .17165 .3956 L .17009 .39205 L p F P
0 g
s
.857 .448 .257 r
.17009 .39205 m .16562 .38945 L .16718 .39299 L p F P
0 g
s
.235 0 .206 r
.65621 .39203 m .6508 .39697 L .65056 .39779 L p F P
0 g
s
.069 0 0 r
.6291 .4153 m .62937 .41493 L .62036 .41937 L p F P
0 g
s
.069 0 0 r
.62036 .41937 m .61928 .4209 L .6291 .4153 L p F P
0 g
s
.235 0 .206 r
.65915 .39267 m .66 .38977 L .65621 .39203 L p F P
0 g
s
.235 0 .206 r
.65056 .39779 m .65915 .39267 L p .65621 .39203 L F P
0 g
s
.552 0 0 r
.24414 .44036 m .23969 .43774 L .24538 .43982 L p F P
0 g
s
.552 0 0 r
.24829 .44191 m .24414 .44036 L p .24538 .43982 L F P
0 g
s
.552 0 0 r
.24538 .43982 m .24912 .44206 L .24829 .44191 L p F P
0 g
s
.233 0 0 r
.3339 .46574 m .33484 .46593 L .34289 .46714 L p F P
0 g
s
.156 0 0 r
.34315 .46735 m .33484 .46593 L .34289 .46714 L p F P
0 g
s
.156 0 0 r
.34316 .46735 m .34315 .46735 L p .34289 .46714 L F P
0 g
s
.156 0 0 r
.34289 .46714 m .34612 .46769 L .34316 .46735 L p F P
0 g
s
.222 0 0 r
.3192 .34038 m .32257 .34141 L .31625 .33955 L closepath p F P
0 g
s
.286 0 0 r
.30744 .4603 m .30657 .46016 L .30543 .45983 L closepath p F P
0 g
s
.709 .873 .958 r
.61705 .30145 m .61945 .30321 L .6096 .3076 L p F P
0 g
s
.709 .873 .958 r
.60916 .3051 m .61705 .30145 L p .6096 .3076 L F P
0 g
s
.709 .873 .958 r
.6096 .3076 m .6075 .30622 L .60916 .3051 L p F P
0 g
s
.407 .244 .546 r
.69353 .34991 m .68647 .35526 L .68615 .35093 L p F P
0 g
s
.407 .244 .546 r
.68615 .35093 m .6928 .34588 L .69353 .34991 L p F P
0 g
s
.76 .728 .823 r
.15482 .30188 m .14591 .30844 L .14282 .30488 L p F P
0 g
s
.791 .731 .797 r
.14444 .30983 m .14591 .30844 L .14282 .30488 L p F P
0 g
s
.805 .729 .78 r
.1347 .31312 m .13852 .31608 L .14444 .30983 L p F P
0 g
s
.805 .729 .78 r
.14444 .30983 m .14073 .30682 L .1347 .31312 L p F P
0 g
s
.791 .731 .797 r
.14282 .30488 m .14073 .30682 L .14444 .30983 L p F P
0 g
s
.613 .046 0 r
.22866 .43342 m .23405 .43563 L .23015 .43282 L p F P
0 g
s
.613 .046 0 r
.23015 .43282 m .22473 .43063 L .22866 .43342 L p F P
0 g
s
.479 .699 .965 r
.21587 .3047 m .2075 .30512 L .20443 .30224 L p F P
0 g
s
.493 .707 .966 r
.21775 .30575 m .21959 .30737 L p .2075 .30512 L F P
0 g
s
.493 .707 .966 r
.2075 .30512 m .21587 .3047 L .21775 .30575 L p F P
0 g
s
.538 .476 .734 r
.68878 .3202 m .69297 .32075 L .68979 .32339 L closepath p F P
0 g
s
.534 .489 .752 r
.68748 .31639 m .68878 .3202 L .69297 .32075 L p F P
0 g
s
.472 0 0 r
.26073 .44692 m .25575 .44445 L .26171 .44643 L p F P
0 g
s
.472 0 0 r
.26149 .44717 m .26073 .44692 L p .26171 .44643 L F P
0 g
s
.472 0 0 r
.26171 .44643 m .26421 .44766 L .26149 .44717 L p F P
0 g
s
0 0 0 r
.49408 .46546 m .49595 .46514 L .48498 .46693 L p F P
0 g
s
0 0 0 r
.48498 .46693 m .48439 .46704 L .49408 .46546 L p F P
0 g
s
.318 .804 .773 r
.52611 .33425 m .52849 .33375 L .51863 .33707 L p F P
0 g
s
.318 .804 .773 r
.51863 .33707 m .51635 .33753 L .52611 .33425 L p F P
0 g
s
.501 .43 .709 r
.69911 .32236 m .69297 .32075 L .68979 .32339 L p F P
0 g
s
.501 .43 .709 r
.6993 .32308 m .69911 .32236 L p .68979 .32339 L F P
0 g
s
.501 .43 .709 r
.69156 .32951 m .6993 .32308 L p .68979 .32339 L F P
0 g
s
.501 .43 .709 r
.68979 .32339 m .69147 .32948 L .69156 .32951 L p F P
0 g
s
.794 .324 .116 r
.18949 .40914 m .18999 .40982 L .1949 .41224 L p F P
0 g
s
.76 .259 .021 r
.19273 .41298 m .19761 .4154 L .1949 .41224 L p F P
0 g
s
.76 .259 .021 r
.1949 .41224 m .18999 .40982 L .19273 .41298 L p F P
0 g
s
.137 0 .038 r
.64873 .40219 m .64953 .40049 L .6408 .40538 L p F P
0 g
s
.137 0 .038 r
.64515 .40482 m .64873 .40219 L p .6408 .40538 L F P
0 g
s
.137 0 .038 r
.6408 .40538 m .6396 .40791 L .64515 .40482 L p F P
0 g
s
.282 .021 .328 r
.67782 .37344 m .67797 .37245 L .66964 .37802 L p F P
0 g
s
.282 .021 .328 r
.67502 .37741 m .67782 .37344 L p .66964 .37802 L F P
0 g
s
.282 .021 .328 r
.66964 .37802 m .66914 .38133 L .67502 .37741 L p F P
0 g
s
.216 0 0 r
.33268 .34384 m .33134 .3436 L .32945 .34312 L closepath p F P
0 g
s
0 0 0 r
.55099 .45176 m .55316 .45079 L .54337 .45364 L p F P
0 g
s
0 0 0 r
.54337 .45364 m .54092 .45472 L .55099 .45176 L p F P
0 g
s
.664 .934 .969 r
.58509 .31393 m .57528 .31835 L .57282 .31772 L p F P
0 g
s
.026 0 0 r
.60967 .42579 m .60945 .42605 L .61265 .42442 L closepath p F P
0 g
s
0 0 0 r
.52853 .45811 m .53068 .45745 L .52028 .45995 L p F P
0 g
s
0 0 0 r
.52028 .45995 m .51876 .46041 L .52853 .45811 L p F P
0 g
s
.565 .525 .769 r
.68621 .31301 m .69152 .31298 L .68748 .31639 L closepath p F P
0 g
s
.534 .489 .752 r
.69643 .31329 m .69152 .31298 L .68748 .31639 L p F P
0 g
s
.534 .489 .752 r
.69757 .31686 m .69643 .31329 L p .68748 .31639 L F P
0 g
s
.534 .489 .752 r
.69297 .32075 m .69757 .31686 L p .68748 .31639 L F P
0 g
s
0 .507 .846 r
.27692 .32719 m .27929 .32783 L .28486 .33005 L p F P
0 g
s
.031 .548 .867 r
.28586 .32948 m .27929 .32783 L .28486 .33005 L p F P
0 g
s
.031 .548 .867 r
.28605 .32955 m .28586 .32948 L p .28486 .33005 L F P
0 g
s
.031 .548 .867 r
.28486 .33005 m .28899 .33094 L .28605 .32955 L p F P
0 g
s
.293 0 0 r
.36947 .35165 m .3709 .35147 L .36669 .35054 L p F P
0 g
s
.293 0 0 r
.36508 .35109 m .36947 .35165 L p .36669 .35054 L F P
0 g
s
.293 0 0 r
.35868 .34933 m .36508 .35109 L p .36669 .35054 L F P
0 g
s
.293 0 0 r
.36669 .35054 m .35875 .34933 L .35868 .34933 L p F P
0 g
s
.082 0 0 r
.46004 .35041 m .45995 .35044 L .45947 .35048 L closepath p F P
0 g
s
.084 0 0 r
.45734 .35149 m .45995 .35044 L .45947 .35048 L p F P
0 g
s
.084 0 0 r
.45655 .35158 m .45734 .35149 L p .45947 .35048 L F P
0 g
s
.084 0 0 r
.44761 .35214 m .45655 .35158 L p .45947 .35048 L F P
0 g
s
.278 0 0 r
.30353 .45966 m .29857 .45819 L .30543 .45983 L p F P
0 g
s
.278 0 0 r
.30543 .45983 m .30657 .46016 L .30353 .45966 L p F P
0 g
s
.638 .656 .852 r
.66875 .29962 m .67644 .29761 L .67048 .3026 L closepath p F P
0 g
s
.622 .643 .85 r
.67878 .29702 m .67644 .29761 L .67048 .3026 L p F P
0 g
s
.622 .643 .85 r
.68123 .30174 m .67878 .29702 L p .67048 .3026 L F P
0 g
s
0 0 0 r
.49672 .46493 m .50353 .46373 L .49595 .46514 L closepath p F P
0 g
s
.384 .197 .499 r
.68657 .3593 m .68322 .36171 L .6837 .35726 L p F P
0 g
s
.384 .197 .499 r
.6837 .35726 m .68647 .35526 L .68657 .3593 L p F P
0 g
s
.046 0 0 r
.46958 .34935 m .47118 .34875 L .46004 .35041 L p F P
0 g
s
.046 0 0 r
.46004 .35041 m .45995 .35044 L .46958 .34935 L p F P
0 g
s
.531 .917 .922 r
.54126 .32991 m .54096 .3299 L .54899 .32669 L closepath p F P
0 g
s
.309 0 0 r
.39834 .35362 m .40273 .35424 L .39669 .35402 L closepath p F P
0 g
s
.222 0 0 r
.3339 .46574 m .33484 .46593 L .33334 .46569 L closepath p F P
0 g
s
0 0 0 r
.57524 .44283 m .57558 .44263 L .56585 .44603 L p F P
0 g
s
0 0 0 r
.56585 .44603 m .56543 .44628 L .57524 .44283 L p F P
0 g
s
.821 .366 .149 r
.17366 .39898 m .17829 .40152 L .17628 .39813 L p F P
0 g
s
.821 .366 .149 r
.1717 .39568 m .17366 .39898 L p .17628 .39813 L F P
0 g
s
.821 .366 .149 r
.17628 .39813 m .17183 .3957 L .1717 .39568 L p F P
0 g
s
.682 .139 0 r
.21418 .42612 m .21074 .42318 L .21592 .42547 L p F P
0 g
s
.682 .139 0 r
.21869 .42814 m .21418 .42612 L p .21592 .42547 L F P
0 g
s
.682 .139 0 r
.21592 .42547 m .21909 .42821 L .21869 .42814 L p F P
0 g
s
0 0 0 r
.50401 .34124 m .50567 .34073 L .49535 .34343 L p F P
0 g
s
0 0 0 r
.49535 .34343 m .49429 .34371 L .50401 .34124 L p F P
0 g
s
.316 .654 .971 r
.23471 .31278 m .23869 .31324 L .24352 .31577 L p F P
0 g
s
.296 .638 .965 r
.23869 .31324 m .23471 .31278 L .23165 .31029 L p F P
0 g
s
.864 .698 .675 r
.12909 .33168 m .13293 .33461 L .13517 .32975 L p F P
0 g
s
.864 .698 .675 r
.13517 .32975 m .13134 .32681 L .12909 .33168 L p F P
0 g
s
.819 .719 .755 r
.13297 .31521 m .1347 .31312 L .13852 .31608 L p F P
0 g
s
.819 .719 .755 r
.13852 .31608 m .13604 .31913 L .13297 .31521 L p F P
0 g
s
0 .48 .835 r
.27929 .32783 m .27692 .32719 L .27389 .32546 L p F P
0 g
s
.116 0 0 r
.46854 .34986 m .46958 .34935 L .45995 .35044 L p F P
0 g
s
.116 0 0 r
.45995 .35044 m .45734 .35149 L .46854 .34986 L p F P
0 g
s
.668 .731 .897 r
.16783 .29995 m .17702 .29655 L .18011 .29973 L p F P
0 g
s
.664 .73 .899 r
.17702 .29655 m .16783 .29995 L .16473 .29666 L p F P
0 g
s
.714 .735 .868 r
.15542 .30147 m .16473 .29666 L .16783 .29995 L p F P
0 g
s
.563 .542 .789 r
.68416 .308 m .68621 .31301 L .69152 .31298 L p F P
0 g
s
.069 0 0 r
.3858 .47164 m .38818 .47178 L .38486 .47162 L closepath p F P
0 g
s
.079 0 0 r
.39797 .47222 m .39809 .47222 L p .3858 .47164 L F P
0 g
s
.079 0 0 r
.3858 .47164 m .38818 .47178 L .39797 .47222 L p F P
0 g
s
.387 0 0 r
.27938 .45264 m .27933 .45263 L .27927 .45261 L closepath p F P
0 g
s
.508 .423 .694 r
.69147 .32948 m .69156 .32951 L .69149 .32956 L closepath p F P
0 g
s
.487 .388 .668 r
.69631 .33212 m .6927 .33507 L .69149 .32956 L p F P
0 g
s
.487 .388 .668 r
.69149 .32956 m .69156 .32951 L .69631 .33212 L p F P
0 g
s
.378 0 0 r
.27624 .45203 m .27304 .45074 L .27927 .45261 L p F P
0 g
s
.378 0 0 r
.27927 .45261 m .27933 .45263 L .27624 .45203 L p F P
0 g
s
.884 .556 .424 r
.15447 .37606 m .15459 .3768 L .15389 .37637 L closepath p F P
0 g
s
.35 0 0 r
.28523 .45477 m .27933 .45263 L .27624 .45203 L p F P
0 g
s
.485 .388 .67 r
.70053 .32862 m .69631 .33212 L .69156 .32951 L p F P
0 g
s
.485 .388 .67 r
.69156 .32951 m .6993 .32308 L .70053 .32862 L p F P
0 g
s
.023 0 0 r
.61265 .42442 m .60945 .42605 L .60793 .42777 L p F P
0 g
s
.227 0 0 r
.32834 .3431 m .32257 .34141 L .32945 .34312 L p F P
0 g
s
.227 0 0 r
.32945 .34312 m .33134 .3436 L .32834 .3431 L p F P
0 g
s
.351 .677 .978 r
.24369 .31375 m .23869 .31324 L .24352 .31577 L p F P
0 g
s
.351 .677 .978 r
.24352 .31577 m .24675 .31602 L .24369 .31375 L p F P
0 g
s
.169 0 .113 r
.65851 .39438 m .65915 .39267 L .65056 .39779 L p F P
0 g
s
.169 0 .113 r
.65537 .39703 m .65851 .39438 L p .65056 .39779 L F P
0 g
s
.169 0 .113 r
.65056 .39779 m .64953 .40049 L .65537 .39703 L p F P
0 g
s
.618 .725 .923 r
.18011 .29973 m .18922 .29749 L .1923 .30053 L p F P
0 g
s
.611 .724 .926 r
.18922 .29749 m .18011 .29973 L .17702 .29655 L p F P
0 g
s
.471 .893 .872 r
.54899 .32669 m .54096 .3299 L .53843 .33009 L p F P
0 g
s
.438 .877 .864 r
.52867 .33372 m .53843 .33009 L .54096 .3299 L p F P
0 g
s
0 .504 .803 r
.30461 .33612 m .30409 .33593 L .30351 .3358 L closepath p F P
0 g
s
.895 .596 .473 r
.14155 .36466 m .14566 .36744 L .14547 .36345 L p F P
0 g
s
.895 .596 .473 r
.14547 .36345 m .14136 .36066 L .14155 .36466 L p F P
0 g
s
0 0 0 r
.60715 .4285 m .60793 .42777 L .59865 .4318 L p F P
0 g
s
0 0 0 r
.59865 .4318 m .5973 .43306 L .60715 .4285 L p F P
0 g
s
.749 .735 .839 r
.15482 .30188 m .15542 .30147 L .15232 .29807 L p F P
0 g
s
.749 .735 .839 r
.15232 .29807 m .15117 .29884 L .15482 .30188 L p F P
0 g
s
.76 .728 .823 r
.14282 .30488 m .15117 .29884 L .15482 .30188 L p F P
0 g
s
.838 .719 .733 r
.1343 .32168 m .13604 .31913 L .13297 .31521 L p F P
0 g
s
.894 .622 .518 r
.13731 .35784 m .14136 .36066 L .14155 .35654 L p F P
0 g
s
.894 .622 .518 r
.14155 .35654 m .13751 .35372 L .13731 .35784 L p F P
0 g
s
.114 0 0 r
.33528 .46606 m .34315 .46735 L .33484 .46593 L p F P
0 g
s
.114 0 0 r
.33092 .46532 m .33528 .46606 L p .33484 .46593 L F P
0 g
s
.114 0 0 r
.33484 .46593 m .33334 .46569 L .33092 .46532 L p F P
0 g
s
.893 .567 .425 r
.14619 .37132 m .15035 .37408 L .14982 .3702 L p F P
0 g
s
.893 .567 .425 r
.14982 .3702 m .14566 .36744 L .14619 .37132 L p F P
0 g
s
.291 0 0 r
.41064 .35406 m .41393 .35437 L .40957 .35438 L closepath p F P
0 g
s
.711 .735 .87 r
.16473 .29666 m .15542 .30147 L .15232 .29807 L p F P
0 g
s
.205 .721 .681 r
.51577 .33772 m .51635 .33753 L .50662 .34046 L p F P
0 g
s
.205 .721 .681 r
.50662 .34046 m .50567 .34073 L .51577 .33772 L p F P
0 g
s
.246 0 0 r
.31239 .46168 m .30657 .46016 L .30353 .45966 L p F P
0 g
s
.167 0 0 r
.44761 .35214 m .45655 .35158 L .44591 .35283 L closepath p F P
0 g
s
0 0 0 r
.49408 .46546 m .48439 .46704 L .48172 .46747 L p F P
0 g
s
.691 .757 .902 r
.65396 .29583 m .64403 .29959 L .64163 .2969 L p F P
0 g
s
.697 .776 .913 r
.63173 .30101 m .64163 .2969 L .64403 .29959 L p F P
0 g
s
.681 .733 .889 r
.64403 .29959 m .65396 .29583 L .65636 .29905 L p F P
0 g
s
.7 .818 .938 r
.63173 .30101 m .63019 .30166 L .63149 .30079 L closepath p F P
0 g
s
.699 .835 .948 r
.62933 .29882 m .63149 .30079 L .63019 .30166 L p F P
0 g
s
.699 .835 .948 r
.61945 .30321 m .62933 .29882 L p .63019 .30166 L F P
0 g
s
.706 .898 .966 r
.60719 .30601 m .59735 .31054 L .59492 .30938 L p F P
0 g
s
.631 .937 .962 r
.56341 .32213 m .56302 .32205 L .56782 .31993 L closepath p F P
0 g
s
0 .499 .794 r
.30107 .33484 m .29728 .33383 L .30351 .3358 L p F P
0 g
s
0 .499 .794 r
.30351 .3358 m .30409 .33593 L .30107 .33484 L p F P
0 g
s
.168 0 0 r
.33334 .46569 m .33092 .46532 L .32718 .46458 L closepath p F P
0 g
s
.881 .519 .357 r
.15124 .37784 m .15556 .38053 L .15459 .3768 L p F P
0 g
s
.881 .519 .357 r
.15098 .3768 m .15124 .37784 L p .15459 .3768 L F P
0 g
s
.881 .519 .357 r
.15459 .3768 m .15389 .37637 L .15098 .3768 L p F P
0 g
s
.891 .646 .562 r
.13352 .35086 m .13751 .35372 L .13812 .34944 L p F P
0 g
s
.891 .646 .562 r
.13812 .34944 m .13414 .34659 L .13352 .35086 L p F P
0 g
s
.66 .686 .863 r
.65636 .29905 m .66633 .29577 L .66875 .29962 L p F P
0 g
s
.672 .711 .877 r
.66633 .29577 m .65636 .29905 L .65396 .29583 L p F P
0 g
s
.731 .212 0 r
.20058 .41849 m .19761 .4154 L .20255 .4178 L p F P
0 g
s
.731 .212 0 r
.2017 .41904 m .20058 .41849 L p .20255 .4178 L F P
0 g
s
.731 .212 0 r
.20255 .4178 m .20421 .41951 L .2017 .41904 L p F P
0 g
s
.054 .62 .754 r
.4212 .47237 m .41072 .47245 L .4104 .47244 L p F P
0 g
s
.015 .589 .731 r
.41072 .47245 m .4104 .47244 L .40944 .47243 L closepath p F P
0 g
s
.063 0 0 r
.39809 .47222 m .39844 .47223 L .40944 .47243 L p F P
0 g
s
.028 .599 .746 r
.40757 .4723 m .39844 .47223 L .40944 .47243 L p F P
0 g
s
.028 .599 .746 r
.40944 .47243 m .4104 .47244 L .40757 .4723 L p F P
0 g
s
.048 0 0 r
.39809 .47222 m .39844 .47223 L .39797 .47222 L closepath p F P
0 g
s
.286 0 0 r
.35875 .34933 m .35868 .34933 L .35855 .3493 L closepath p F P
0 g
s
.807 .337 .109 r
.18056 .40483 m .18522 .40735 L .18296 .40404 L p F P
0 g
s
.807 .337 .109 r
.18296 .40404 m .17829 .40152 L .18056 .40483 L p F P
0 g
s
0 0 0 r
.57323 .44401 m .57524 .44283 L .56543 .44628 L p F P
0 g
s
0 0 0 r
.56543 .44628 m .56348 .44741 L .57323 .44401 L p F P
0 g
s
.261 0 0 r
.42295 .35396 m .42626 .35411 L .42204 .35428 L closepath p F P
0 g
s
.307 0 0 r
.35572 .34943 m .35052 .34802 L .35855 .3493 L p F P
0 g
s
.307 0 0 r
.35855 .3493 m .35868 .34933 L .35572 .34943 L p F P
0 g
s
.22 0 0 r
.43528 .35331 m .44018 .35328 L .43414 .35376 L closepath p F P
0 g
s
.037 .607 .734 r
.42318 .47234 m .42272 .47234 L .4212 .47237 L closepath p F P
0 g
s
.054 .62 .754 r
.41992 .47226 m .42272 .47234 L .4212 .47237 L p F P
0 g
s
.054 .62 .754 r
.4104 .47244 m .41992 .47226 L p .4212 .47237 L F P
0 g
s
.074 .636 .756 r
.43391 .47199 m .42318 .47234 L .42272 .47234 L p F P
0 g
s
.434 0 0 r
.36508 .35109 m .35868 .34933 L .35572 .34943 L p F P
0 g
s
.095 0 0 r
.61928 .4209 m .61265 .42442 L .61881 .42155 L closepath p F P
0 g
s
.023 0 0 r
.61709 .42352 m .61881 .42155 L .61265 .42442 L p F P
0 g
s
.023 0 0 r
.60793 .42777 m .61709 .42352 L p .61265 .42442 L F P
0 g
s
.438 .297 .592 r
.69417 .34482 m .6928 .34588 L .69079 .34229 L p F P
0 g
s
.438 .297 .592 r
.69079 .34229 m .69358 .34014 L .69417 .34482 L p F P
0 g
s
.049 .615 .769 r
.40642 .47223 m .40757 .4723 L .39844 .47223 L p F P
0 g
s
.049 .615 .769 r
.40001 .47207 m .40642 .47223 L p .39844 .47223 L F P
0 g
s
.049 .615 .769 r
.39524 .47202 m .40001 .47207 L p .39844 .47223 L F P
0 g
s
.049 .615 .769 r
.39844 .47223 m .39797 .47222 L .39524 .47202 L p F P
0 g
s
.008 .582 .744 r
.39797 .47222 m .39524 .47202 L .38818 .47178 L closepath p F P
0 g
s
.265 .655 .967 r
.26196 .32176 m .26184 .32168 L .26175 .32167 L closepath p F P
0 g
s
.705 .819 .936 r
.63955 .29479 m .64163 .2969 L .63173 .30101 L p F P
0 g
s
.705 .819 .936 r
.63173 .30101 m .63149 .30079 L .63955 .29479 L p F P
0 g
s
.563 .542 .789 r
.69386 .3062 m .6856 .30676 L .68416 .308 L p F P
0 g
s
.563 .542 .789 r
.69522 .30979 m .69386 .3062 L p .68416 .308 L F P
0 g
s
.563 .542 .789 r
.69152 .31298 m .69522 .30979 L p .68416 .308 L F P
0 g
s
.59 .57 .8 r
.6837 .30696 m .6856 .30676 L .68416 .308 L closepath p F P
0 g
s
.838 .719 .733 r
.13297 .31521 m .13057 .31869 L .1343 .32168 L p F P
0 g
s
.852 .712 .708 r
.12757 .32384 m .13134 .32681 L .1343 .32168 L p F P
0 g
s
.852 .712 .708 r
.1343 .32168 m .13057 .31869 L .12757 .32384 L p F P
0 g
s
.292 0 0 r
.30956 .33768 m .30409 .33593 L .30107 .33484 L p F P
0 g
s
.264 .655 .966 r
.25879 .3197 m .2564 .31934 L .26175 .32167 L p F P
0 g
s
.264 .655 .966 r
.26175 .32167 m .26184 .32168 L .25879 .3197 L p F P
0 g
s
.795 .322 .106 r
.18949 .40914 m .18999 .40982 L .18842 .40903 L closepath p F P
0 g
s
.887 .534 .372 r
.15389 .37637 m .15098 .3768 L .15035 .37408 L closepath p F P
0 g
s
.871 .484 .304 r
.15684 .38415 m .1612 .38681 L .15993 .38319 L p F P
0 g
s
.871 .484 .304 r
.15993 .38319 m .15556 .38053 L .15684 .38415 L p F P
0 g
s
.885 .667 .603 r
.13021 .3437 m .13414 .34659 L .13522 .34214 L p F P
0 g
s
.885 .667 .603 r
.13522 .34214 m .1313 .33925 L .13021 .3437 L p F P
0 g
s
.016 0 0 r
.59673 .4336 m .5973 .43306 L .58747 .43727 L p F P
0 g
s
.016 0 0 r
.58747 .43727 m .5873 .43743 L .59673 .4336 L p F P
0 g
s
.027 .523 .876 r
.26846 .32324 m .26184 .32168 L .25879 .3197 L p F P
0 g
s
0 0 0 r
.48162 .46748 m .48172 .46747 L .47205 .46874 L p F P
0 g
s
0 0 0 r
.47205 .46874 m .47038 .46898 L .48162 .46748 L p F P
0 g
s
0 0 0 r
.47038 .46898 m .47205 .46874 L p .45972 .47014 L F P
0 g
s
.544 .701 .942 r
.19348 .30039 m .1923 .30053 L .18922 .29749 L p F P
0 g
s
.412 .669 .966 r
.21959 .30737 m .22029 .30741 L .21775 .30575 L closepath p F P
0 g
s
.058 .624 .737 r
.43535 .47193 m .43505 .47194 L .43391 .47199 L closepath p F P
0 g
s
.074 .636 .756 r
.43227 .47192 m .43505 .47194 L .43391 .47199 L p F P
0 g
s
.074 .636 .756 r
.42272 .47234 m .43227 .47192 L p .43391 .47199 L F P
0 g
s
.14 .682 .707 r
.50353 .46373 m .49595 .46514 L .49408 .46546 L p F P
0 g
s
0 0 0 r
.53108 .45728 m .53949 .4551 L .53068 .45745 L closepath p F P
0 g
s
.501 0 0 r
.23855 .43823 m .24414 .44036 L .23969 .43774 L p F P
0 g
s
.501 0 0 r
.23407 .43564 m .23855 .43823 L p .23969 .43774 L F P
0 g
s
.501 0 0 r
.23969 .43774 m .23411 .43565 L .23407 .43564 L p F P
0 g
s
.094 .651 .758 r
.44463 .47126 m .44727 .47123 L .43535 .47193 L p F P
0 g
s
.094 .651 .758 r
.43535 .47193 m .43505 .47194 L .44463 .47126 L p F P
0 g
s
.052 .618 .756 r
.41992 .47226 m .4104 .47244 L .40757 .4723 L p F P
0 g
s
.119 0 0 r
.34612 .46769 m .35154 .46846 L .34316 .46735 L closepath p F P
0 g
s
.35 0 0 r
.2914 .45643 m .29173 .45654 L .29857 .45819 L p F P
0 g
s
.278 0 0 r
.2984 .45847 m .29173 .45654 L .29857 .45819 L p F P
0 g
s
.278 0 0 r
.3022 .45943 m .2984 .45847 L p .29857 .45819 L F P
0 g
s
.278 0 0 r
.29857 .45819 m .30353 .45966 L .3022 .45943 L p F P
0 g
s
.457 .34 .632 r
.69956 .33527 m .69358 .34014 L .6927 .33507 L p F P
0 g
s
.457 .34 .632 r
.6927 .33507 m .69631 .33212 L .69956 .33527 L p F P
0 g
s
.602 .578 .8 r
.6856 .30676 m .6837 .30696 L .68123 .30174 L p F P
0 g
s
.021 0 0 r
.48153 .34676 m .47118 .34875 L .46958 .34935 L p F P
0 g
s
.201 0 .188 r
.66823 .38524 m .66847 .38443 L .66 .38977 L p F P
0 g
s
.201 0 .188 r
.66344 .38997 m .66823 .38524 L p .66 .38977 L F P
0 g
s
.201 0 .188 r
.66 .38977 m .65915 .39267 L .66344 .38997 L p F P
0 g
s
.592 .938 .939 r
.56782 .31993 m .56302 .32205 L .56053 .32183 L p F P
0 g
s
.576 .932 .939 r
.55074 .32599 m .56053 .32183 L .56302 .32205 L p F P
0 g
s
.527 0 0 r
.24912 .44206 m .24984 .44245 L .25575 .44445 L p F P
0 g
s
.454 0 0 r
.25488 .44489 m .26073 .44692 L .25575 .44445 L p F P
0 g
s
.454 0 0 r
.25575 .44445 m .24984 .44245 L .25488 .44489 L p F P
0 g
s
.706 .82 .936 r
.63923 .29446 m .63955 .29479 L .63149 .30079 L p F P
0 g
s
.706 .82 .936 r
.63149 .30079 m .62933 .29882 L .63923 .29446 L p F P
0 g
s
.029 .598 .766 r
.3935 .47188 m .39524 .47202 L .38818 .47178 L p F P
0 g
s
.029 .598 .766 r
.38955 .47167 m .3935 .47188 L p .38818 .47178 L F P
0 g
s
.029 .598 .766 r
.38293 .47143 m .38955 .47167 L p .38818 .47178 L F P
0 g
s
.029 .598 .766 r
.38818 .47178 m .38486 .47162 L .38293 .47143 L p F P
0 g
s
.648 .663 .851 r
.67644 .29761 m .66875 .29962 L .66633 .29577 L p F P
0 g
s
.662 .114 0 r
.21909 .42821 m .21935 .42842 L .22473 .43063 L p F P
0 g
s
.599 .028 0 r
.22333 .43118 m .22866 .43342 L .22473 .43063 L p F P
0 g
s
.599 .028 0 r
.22473 .43063 m .21935 .42842 L .22333 .43118 L p F P
0 g
s
0 0 0 r
.45893 .47023 m .45972 .47014 L p .44738 .47122 L F P
0 g
s
0 0 0 r
.45972 .47014 m .46383 .46971 L .45893 .47023 L closepath p F P
0 g
s
0 0 0 r
.45972 .47014 m .46383 .46971 L .47038 .46898 L p F P
0 g
s
.392 0 0 r
.33565 .34499 m .33134 .3436 L .32834 .3431 L p F P
0 g
s
0 0 0 r
.59494 .43494 m .59673 .4336 L .5873 .43743 L p F P
0 g
s
0 0 0 r
.58725 .43819 m .59494 .43494 L p .5873 .43743 L F P
0 g
s
0 0 0 r
.5873 .43743 m .58517 .43903 L .58725 .43819 L p F P
0 g
s
0 .563 .739 r
.38486 .47162 m .38293 .47143 L .37841 .47116 L closepath p F P
0 g
s
.437 0 0 r
.26421 .44766 m .26685 .44884 L .26149 .44717 L closepath p F P
0 g
s
.397 .663 .966 r
.22608 .3057 m .22858 .30777 L .22029 .30741 L p F P
0 g
s
.397 .663 .966 r
.2252 .30522 m .22608 .3057 L p .22029 .30741 L F P
0 g
s
.397 .663 .966 r
.21652 .30467 m .2252 .30522 L p .22029 .30741 L F P
0 g
s
.397 .663 .966 r
.22029 .30741 m .21775 .30575 L .21652 .30467 L p F P
0 g
s
.07 .633 .756 r
.43227 .47192 m .42272 .47234 L .41992 .47226 L p F P
0 g
s
.369 .185 .496 r
.69311 .35435 m .68657 .3593 L .68647 .35526 L p F P
0 g
s
.369 .185 .496 r
.68647 .35526 m .69353 .34991 L .69311 .35435 L p F P
0 g
s
.859 .447 .248 r
.16277 .39035 m .16718 .39299 L .16562 .38945 L p F P
0 g
s
.859 .447 .248 r
.16562 .38945 m .1612 .38681 L .16277 .39035 L p F P
0 g
s
.309 .077 .39 r
.67894 .37176 m .67797 .37245 L .67827 .3689 L p F P
0 g
s
.309 .077 .39 r
.67827 .3689 m .6816 .36655 L .67894 .37176 L p F P
0 g
s
0 .48 .835 r
.27389 .32546 m .274 .32549 L .27929 .32783 L p F P
0 g
s
0 .483 .839 r
.28008 .32732 m .28586 .32948 L .27929 .32783 L p F P
0 g
s
0 .483 .839 r
.27929 .32783 m .274 .32549 L .28008 .32732 L p F P
0 g
s
.876 .686 .641 r
.12744 .33633 m .1313 .33925 L .13293 .33461 L p F P
0 g
s
.876 .686 .641 r
.13293 .33461 m .12909 .33168 L .12744 .33633 L p F P
0 g
s
.544 .701 .942 r
.18922 .29749 m .18963 .29744 L .19348 .30039 L p F P
0 g
s
.556 .714 .946 r
.19827 .29643 m .18963 .29744 L .19348 .30039 L p F P
0 g
s
.556 .714 .946 r
.19348 .30039 m .20136 .29935 L .19827 .29643 L p F P
0 g
s
0 0 0 r
.44738 .47122 m .44788 .47118 L .45893 .47023 L p F P
0 g
s
0 0 0 r
.44738 .47122 m .44788 .47118 L .44727 .47123 L closepath p F P
0 g
s
.241 0 0 r
.31872 .46298 m .31961 .46319 L .32718 .46458 L p F P
0 g
s
.165 0 0 r
.32746 .46475 m .31961 .46319 L .32718 .46458 L p F P
0 g
s
.165 0 0 r
.32825 .4649 m .32746 .46475 L p .32718 .46458 L F P
0 g
s
.165 0 0 r
.32718 .46458 m .33092 .46532 L .32825 .4649 L p F P
0 g
s
.088 .647 .755 r
.44463 .47126 m .43505 .47194 L .43227 .47192 L p F P
0 g
s
.25 0 0 r
.32799 .34305 m .32834 .3431 L .32257 .34141 L p F P
0 g
s
.25 0 0 r
.32188 .34154 m .32799 .34305 L p .32257 .34141 L F P
0 g
s
.25 0 0 r
.3162 .33954 m .32188 .34154 L p .32257 .34141 L F P
0 g
s
.25 0 0 r
.32257 .34141 m .31625 .33955 L .3162 .33954 L p F P
0 g
s
.75 .238 0 r
.18789 .41053 m .19273 .41298 L .18999 .40982 L p F P
0 g
s
.75 .238 0 r
.1862 .40856 m .18789 .41053 L p .18999 .40982 L F P
0 g
s
.75 .238 0 r
.18999 .40982 m .18842 .40903 L .1862 .40856 L p F P
0 g
s
.688 .918 .971 r
.58532 .31403 m .58509 .31393 L .58701 .31304 L closepath p F P
0 g
s
.517 .443 .712 r
.69297 .32075 m .69757 .31686 L .69911 .32236 L closepath p F P
0 g
s
.382 0 0 r
.27245 .45111 m .26685 .44884 L .27304 .45074 L p F P
0 g
s
.382 0 0 r
.27385 .45154 m .27245 .45111 L p .27304 .45074 L F P
0 g
s
.382 0 0 r
.27304 .45074 m .27624 .45203 L .27385 .45154 L p F P
0 g
s
.714 .843 .943 r
.62933 .29882 m .61945 .30321 L .61705 .30145 L p F P
0 g
s
.129 .678 .776 r
.44788 .47118 m .44727 .47123 L .44463 .47126 L p F P
0 g
s
.345 .135 .445 r
.68645 .36307 m .6816 .36655 L .68322 .36171 L p F P
0 g
s
.345 .135 .445 r
.68322 .36171 m .68657 .3593 L .68645 .36307 L p F P
0 g
s
.115 .667 .759 r
.45893 .47023 m .457 .4703 L .44788 .47118 L closepath p F P
0 g
s
.129 .678 .776 r
.45509 .47035 m .457 .4703 L .44788 .47118 L p F P
0 g
s
.129 .678 .776 r
.45046 .47073 m .45509 .47035 L p .44788 .47118 L F P
0 g
s
.129 .678 .776 r
.44463 .47126 m .45046 .47073 L p .44788 .47118 L F P
0 g
s
.325 0 0 r
.35496 .34948 m .35572 .34943 L .35052 .34802 L p F P
0 g
s
.325 0 0 r
.34907 .34848 m .35496 .34948 L p .35052 .34802 L F P
0 g
s
.325 0 0 r
.34351 .34663 m .34907 .34848 L p .35052 .34802 L F P
0 g
s
.325 0 0 r
.35052 .34802 m .3438 .34665 L .34351 .34663 L p F P
0 g
s
0 0 0 r
.50299 .34166 m .50401 .34124 L .49429 .34371 L p F P
0 g
s
0 0 0 r
.49429 .34371 m .49263 .34435 L .50299 .34166 L p F P
0 g
s
.009 .581 .762 r
.38025 .47116 m .38293 .47143 L .37841 .47116 L p F P
0 g
s
.009 .581 .762 r
.37958 .47111 m .38025 .47116 L p .37841 .47116 L F P
0 g
s
.009 .581 .762 r
.37063 .47055 m .37958 .47111 L p .37841 .47116 L F P
0 g
s
.009 .581 .762 r
.37841 .47116 m .37139 .47064 L .37063 .47055 L p F P
0 g
s
0 0 0 r
.53949 .4551 m .53068 .45745 L .52853 .45811 L p F P
0 g
s
0 0 0 r
.56297 .44765 m .56348 .44741 L .55359 .45059 L p F P
0 g
s
0 0 0 r
.55359 .45059 m .55316 .45079 L .56297 .44765 L p F P
0 g
s
.668 .118 0 r
.20909 .42378 m .21418 .42612 L .21074 .42318 L p F P
0 g
s
.668 .118 0 r
.21074 .42318 m .20562 .42085 L .20909 .42378 L p F P
0 g
s
.758 .73 .827 r
.15117 .29884 m .14282 .30488 L .13971 .30136 L p F P
0 g
s
.79 .733 .8 r
.14073 .30682 m .14282 .30488 L .13971 .30136 L p F P
0 g
s
.79 .733 .8 r
.13971 .30136 m .13706 .30379 L .14073 .30682 L p F P
0 g
s
.805 .731 .782 r
.13095 .31012 m .1347 .31312 L .14073 .30682 L p F P
0 g
s
.805 .731 .782 r
.14073 .30682 m .13706 .30379 L .13095 .31012 L p F P
0 g
s
.361 .83 .788 r
.53814 .33015 m .53843 .33009 L .52867 .33372 L p F P
0 g
s
.361 .83 .788 r
.52867 .33372 m .52849 .33375 L .53814 .33015 L p F P
0 g
s
.602 .578 .8 r
.69183 .3013 m .6856 .30676 L p .68123 .30174 L F P
0 g
s
.579 .553 .789 r
.6856 .30676 m .69183 .3013 L .69386 .3062 L closepath p F P
0 g
s
.836 .396 .182 r
.17183 .3957 m .1717 .39568 L .17165 .3956 L closepath p F P
0 g
s
.667 .934 .968 r
.58701 .31304 m .58509 .31393 L .58264 .3132 L p F P
0 g
s
.664 .934 .969 r
.57282 .31772 m .58264 .3132 L .58509 .31393 L p F P
0 g
s
.16 .581 .934 r
.25133 .31691 m .24675 .31602 L .24369 .31375 L p F P
0 g
s
.182 .602 .942 r
.24675 .31602 m .25133 .31691 L .2564 .31934 L p F P
0 g
s
.838 .396 .175 r
.16836 .39516 m .16718 .39299 L .17165 .3956 L p F P
0 g
s
.838 .396 .175 r
.17165 .3956 m .1717 .39568 L .16836 .39516 L p F P
0 g
s
.062 0 0 r
.62782 .41707 m .6291 .4153 L .61928 .4209 L p F P
0 g
s
.062 0 0 r
.61928 .4209 m .61881 .42155 L .62782 .41707 L p F P
0 g
s
.831 .384 .166 r
.17366 .39898 m .1717 .39568 L .16836 .39516 L p F P
0 g
s
0 0 0 r
.51376 .33837 m .51577 .33772 L .50567 .34073 L p F P
0 g
s
0 0 0 r
.50567 .34073 m .50401 .34124 L .51376 .33837 L p F P
0 g
s
.301 0 0 r
.41393 .35437 m .40957 .35438 L .40778 .35496 L p F P
0 g
s
.34 0 0 r
.40957 .35438 m .40778 .35496 L .40273 .35424 L closepath p F P
0 g
s
.317 0 0 r
.42204 .35428 m .42012 .35499 L .41393 .35437 L closepath p F P
0 g
s
.301 0 0 r
.41925 .35538 m .42012 .35499 L .41393 .35437 L p F P
0 g
s
.301 0 0 r
.41108 .35542 m .41925 .35538 L p .41393 .35437 L F P
0 g
s
.301 0 0 r
.40778 .35496 m .41108 .35542 L p .41393 .35437 L F P
0 g
s
0 .41 .733 r
.28899 .33094 m .29142 .33172 L .29728 .33383 L p F P
0 g
s
0 .456 .759 r
.29749 .33358 m .29142 .33172 L .29728 .33383 L p F P
0 g
s
0 .456 .759 r
.29856 .33393 m .29749 .33358 L p .29728 .33383 L F P
0 g
s
0 .456 .759 r
.29728 .33383 m .30107 .33484 L .29856 .33393 L p F P
0 g
s
.296 .638 .965 r
.23165 .31029 m .23405 .31063 L .23869 .31324 L p F P
0 g
s
.326 .662 .973 r
.24063 .31146 m .23405 .31063 L .23869 .31324 L p F P
0 g
s
.326 .662 .973 r
.23869 .31324 m .24369 .31375 L .24063 .31146 L p F P
0 g
s
.23 0 0 r
.31872 .46298 m .31961 .46319 L .31812 .46291 L closepath p F P
0 g
s
0 .544 .733 r
.37139 .47064 m .37063 .47055 L .36902 .47041 L closepath p F P
0 g
s
.359 .829 .785 r
.5359 .3306 m .53814 .33015 L .52849 .33375 L p F P
0 g
s
.359 .829 .785 r
.52849 .33375 m .52611 .33425 L .5359 .3306 L p F P
0 g
s
.271 0 0 r
.42626 .35411 m .42204 .35428 L .42012 .35499 L p F P
0 g
s
.776 .28 .031 r
.18842 .40903 m .1862 .40856 L .18522 .40735 L closepath p F P
0 g
s
.373 0 0 r
.3709 .35147 m .37368 .35217 L .36947 .35165 L closepath p F P
0 g
s
0 .439 .782 r
.28899 .33094 m .29142 .33172 L .28605 .32955 L closepath p F P
0 g
s
.479 .699 .965 r
.20443 .30224 m .21133 .30203 L .21587 .3047 L p F P
0 g
s
.468 .691 .964 r
.21133 .30203 m .20443 .30224 L .20136 .29935 L p F P
0 g
s
.321 0 0 r
.40667 .35539 m .40778 .35496 L .40273 .35424 L p F P
0 g
s
.321 0 0 r
.40007 .3552 m .40667 .35539 L p .40273 .35424 L F P
0 g
s
.321 0 0 r
.39546 .35433 m .40007 .3552 L p .40273 .35424 L F P
0 g
s
.321 0 0 r
.40273 .35424 m .39669 .35402 L .39546 .35433 L p F P
0 g
s
0 0 0 r
.50674 .46311 m .50643 .46318 L .50353 .46373 L closepath p F P
0 g
s
.14 .682 .707 r
.50381 .46365 m .50643 .46318 L .50353 .46373 L p F P
0 g
s
.14 .682 .707 r
.49408 .46546 m .50381 .46365 L p .50353 .46373 L F P
0 g
s
.108 0 0 r
.35836 .46931 m .36008 .4695 L .36902 .47041 L p F P
0 g
s
.098 0 0 r
.35836 .46931 m .36008 .4695 L .35751 .46923 L closepath p F P
0 g
s
0 0 0 r
.52777 .45834 m .52853 .45811 L .51876 .46041 L p F P
0 g
s
0 0 0 r
.51876 .46041 m .51734 .46084 L .52777 .45834 L p F P
0 g
s
.866 .702 .677 r
.1253 .32872 m .12909 .33168 L .13134 .32681 L p F P
0 g
s
.866 .702 .677 r
.13134 .32681 m .12757 .32384 L .1253 .32872 L p F P
0 g
s
.82 .723 .759 r
.12988 .31139 m .13095 .31012 L .1347 .31312 L p F P
0 g
s
.82 .723 .759 r
.1347 .31312 m .13297 .31521 L .12988 .31139 L p F P
0 g
s
.606 .938 .95 r
.57282 .31772 m .56782 .31993 L .57245 .31767 L closepath p F P
0 g
s
.592 .938 .939 r
.57035 .31739 m .57245 .31767 L .56782 .31993 L p F P
0 g
s
.592 .938 .939 r
.56053 .32183 m .57035 .31739 L p .56782 .31993 L F P
0 g
s
.709 .874 .959 r
.6075 .30622 m .60719 .30601 L .60916 .3051 L closepath p F P
0 g
s
.339 0 0 r
.2914 .45643 m .29173 .45654 L .29112 .45639 L closepath p F P
0 g
s
.52 0 0 r
.24912 .44206 m .24984 .44245 L .24829 .44191 L closepath p F P
0 g
s
.283 0 0 r
.43414 .35376 m .43248 .35443 L .42626 .35411 L closepath p F P
0 g
s
.271 0 0 r
.43146 .35493 m .43248 .35443 L .42626 .35411 L p F P
0 g
s
.271 0 0 r
.42317 .35525 m .43146 .35493 L p .42626 .35411 L F P
0 g
s
.271 0 0 r
.42012 .35499 m .42317 .35525 L p .42626 .35411 L F P
0 g
s
.679 .925 .972 r
.59492 .30938 m .58701 .31304 L .59404 .30905 L closepath p F P
0 g
s
.667 .934 .968 r
.59248 .30848 m .59404 .30905 L .58701 .31304 L p F P
0 g
s
.667 .934 .968 r
.58264 .3132 m .59248 .30848 L p .58701 .31304 L F P
0 g
s
.713 .183 0 r
.20421 .41951 m .20562 .42085 L .2017 .41904 L closepath p F P
0 g
s
.48 .898 .881 r
.55074 .32599 m .54899 .32669 L .55068 .326 L closepath p F P
0 g
s
.471 .893 .872 r
.54823 .32615 m .55068 .326 L .54899 .32669 L p F P
0 g
s
.471 .893 .872 r
.53843 .33009 m .54823 .32615 L p .54899 .32669 L F P
0 g
s
0 .552 .746 r
.36772 .47017 m .36008 .4695 L .36902 .47041 L p F P
0 g
s
0 .552 .746 r
.36902 .47041 m .37063 .47055 L .36772 .47017 L p F P
0 g
s
.55 .5 .753 r
.69152 .31298 m .69522 .30979 L .69643 .31329 L closepath p F P
0 g
s
.351 0 0 r
.39669 .35402 m .39546 .35433 L .3924 .35378 L closepath p F P
0 g
s
.233 0 .26 r
.66996 .38344 m .66847 .38443 L .66914 .38133 L p F P
0 g
s
.233 0 .26 r
.66914 .38133 m .67502 .37741 L .66996 .38344 L p F P
0 g
s
.664 .73 .899 r
.16473 .29666 m .17393 .29338 L .17702 .29655 L p F P
0 g
s
.659 .729 .901 r
.17393 .29338 m .16473 .29666 L .16163 .29338 L p F P
0 g
s
.711 .735 .87 r
.15232 .29807 m .16163 .29338 L .16473 .29666 L p F P
0 g
s
.149 .692 .776 r
.46383 .46971 m .45893 .47023 L .457 .4703 L p F P
0 g
s
.225 0 0 r
.29171 .45676 m .2984 .45847 L .29173 .45654 L p F P
0 g
s
.225 0 0 r
.28834 .45578 m .29171 .45676 L p .29173 .45654 L F P
0 g
s
.225 0 0 r
.29173 .45654 m .29112 .45639 L .28834 .45578 L p F P
0 g
s
.838 .722 .736 r
.13057 .31869 m .13297 .31521 L .12988 .31139 L p F P
0 g
s
.425 .288 .59 r
.70146 .3389 m .69417 .34482 L .69358 .34014 L p F P
0 g
s
.425 .288 .59 r
.69358 .34014 m .69956 .33527 L .70146 .3389 L p F P
0 g
s
.898 .599 .47 r
.1375 .36184 m .14155 .36466 L .14136 .36066 L p F P
0 g
s
.898 .599 .47 r
.14136 .36066 m .13731 .35784 L .1375 .36184 L p F P
0 g
s
0 0 0 r
.56091 .44857 m .56297 .44765 L .55316 .45079 L p F P
0 g
s
0 0 0 r
.55316 .45079 m .55099 .45176 L .56091 .44857 L p F P
0 g
s
.729 .205 0 r
.19572 .41606 m .20058 .41849 L .19761 .4154 L p F P
0 g
s
.729 .205 0 r
.19761 .4154 m .19273 .41298 L .19572 .41606 L p F P
0 g
s
.329 0 0 r
.39365 .3549 m .39546 .35433 L .3924 .35378 L p F P
0 g
s
.329 0 0 r
.38992 .35467 m .39365 .3549 L p .3924 .35378 L F P
0 g
s
.329 0 0 r
.38317 .35313 m .38992 .35467 L p .3924 .35378 L F P
0 g
s
.329 0 0 r
.3924 .35378 m .38333 .3531 L .38317 .35313 L p F P
0 g
s
.229 0 0 r
.44018 .35328 m .43414 .35376 L .43248 .35443 L p F P
0 g
s
.896 .569 .421 r
.14208 .36853 m .14619 .37132 L .14566 .36744 L p F P
0 g
s
.896 .569 .421 r
.14566 .36744 m .14155 .36466 L .14208 .36853 L p F P
0 g
s
.898 .625 .517 r
.13332 .35499 m .13731 .35784 L .13751 .35372 L p F P
0 g
s
.898 .625 .517 r
.13751 .35372 m .13352 .35086 L .13332 .35499 L p F P
0 g
s
.287 0 0 r
.29112 .45639 m .28834 .45578 L .28523 .45477 L closepath p F P
0 g
s
.602 .578 .8 r
.68123 .30174 m .69135 .30019 L .69183 .3013 L p F P
0 g
s
.616 .603 .814 r
.69135 .30019 m .68123 .30174 L .67878 .29702 L p F P
0 g
s
.501 .709 .964 r
.21775 .30575 m .21652 .30467 L .21587 .3047 L closepath p F P
0 g
s
0 .47 .707 r
.32007 .46329 m .32746 .46475 L .31961 .46319 L p F P
0 g
s
.177 0 0 r
.31812 .46291 m .31571 .46243 L .31239 .46168 L closepath p F P
0 g
s
0 .47 .707 r
.31961 .46319 m .31812 .46291 L .31571 .46243 L p F P
0 g
s
0 .47 .707 r
.31571 .46243 m .32007 .46329 L p .31961 .46319 L F P
0 g
s
0 0 0 r
.58508 .43908 m .58517 .43903 L .57558 .44263 L p F P
0 g
s
0 0 0 r
.57558 .44263 m .57524 .44283 L .58508 .43908 L p F P
0 g
s
.747 .736 .842 r
.15117 .29884 m .15232 .29807 L .14921 .29469 L p F P
0 g
s
.747 .736 .842 r
.14921 .29469 m .14757 .29577 L .15117 .29884 L p F P
0 g
s
.758 .73 .827 r
.13971 .30136 m .14757 .29577 L .15117 .29884 L p F P
0 g
s
.021 0 0 r
.47942 .34782 m .48194 .34669 L .48153 .34676 L p F P
0 g
s
.021 0 0 r
.47803 .34807 m .47942 .34782 L p .48153 .34676 L F P
0 g
s
.021 0 0 r
.46958 .34935 m .47803 .34807 L p .48153 .34676 L F P
0 g
s
0 0 0 r
.48199 .34667 m .48194 .34669 L .48153 .34676 L closepath p F P
0 g
s
.805 .332 .094 r
.17596 .40228 m .18056 .40483 L .17829 .40152 L p F P
0 g
s
.805 .332 .094 r
.17829 .40152 m .17366 .39898 L .17596 .40228 L p F P
0 g
s
.701 .897 .967 r
.60916 .3051 m .60719 .30601 L .60477 .30471 L p F P
0 g
s
.706 .898 .966 r
.59492 .30938 m .60477 .30471 L .60719 .30601 L p F P
0 g
s
.231 .634 .958 r
.25573 .31769 m .25133 .31691 L .2564 .31934 L p F P
0 g
s
.231 .634 .958 r
.2564 .31934 m .25879 .3197 L .25573 .31769 L p F P
0 g
s
.165 .699 .709 r
.51618 .46107 m .51734 .46084 L .50674 .46311 L p F P
0 g
s
.165 .699 .709 r
.50674 .46311 m .50643 .46318 L .51618 .46107 L p F P
0 g
s
.889 .536 .37 r
.14705 .37509 m .14619 .37132 L .15035 .37408 L p F P
0 g
s
.889 .536 .37 r
.14983 .37693 m .14705 .37509 L p .15035 .37408 L F P
0 g
s
.889 .536 .37 r
.15035 .37408 m .15098 .3768 L .14983 .37693 L p F P
0 g
s
0 0 0 r
.49164 .34473 m .49263 .34435 L .48199 .34667 L p F P
0 g
s
0 0 0 r
.48199 .34667 m .48194 .34669 L .49164 .34473 L p F P
0 g
s
.511 .913 .887 r
.55995 .32184 m .56053 .32183 L .55074 .32599 L p F P
0 g
s
.511 .913 .887 r
.55074 .32599 m .55068 .326 L .55995 .32184 L p F P
0 g
s
.611 .724 .926 r
.18738 .29566 m .18922 .29749 L p .17702 .29655 L F P
0 g
s
.611 .724 .926 r
.17702 .29655 m .18559 .29456 L .18738 .29566 L p F P
0 g
s
.605 .721 .927 r
.18559 .29456 m .17702 .29655 L .17393 .29338 L p F P
0 g
s
.3 0 0 r
.3438 .34665 m .34351 .34663 L .34306 .34651 L closepath p F P
0 g
s
.552 0 0 r
.23411 .43565 m .23407 .43564 L .23405 .43563 L closepath p F P
0 g
s
.278 .622 .96 r
.23405 .31063 m .23165 .31029 L .22858 .30777 L p F P
0 g
s
.545 0 0 r
.2309 .43483 m .22866 .43342 L .23405 .43563 L p F P
0 g
s
.545 0 0 r
.23405 .43563 m .23407 .43564 L .2309 .43483 L p F P
0 g
s
.522 0 0 r
.23855 .43823 m .23407 .43564 L .2309 .43483 L p F P
0 g
s
.415 0 0 r
.24908 .44283 m .25488 .44489 L .24984 .44245 L p F P
0 g
s
.415 0 0 r
.24598 .44133 m .24908 .44283 L p .24984 .44245 L F P
0 g
s
.415 0 0 r
.24984 .44245 m .24829 .44191 L .24598 .44133 L p F P
0 g
s
.894 .649 .561 r
.12958 .34798 m .13352 .35086 L .13414 .34659 L p F P
0 g
s
.894 .649 .561 r
.13414 .34659 m .13021 .3437 L .12958 .34798 L p F P
0 g
s
.708 .735 .873 r
.16163 .29338 m .15232 .29807 L .14921 .29469 L p F P
0 g
s
.033 0 0 r
.49009 .34551 m .49164 .34473 L .48194 .34669 L p F P
0 g
s
.033 0 0 r
.48194 .34669 m .47942 .34782 L .49009 .34551 L p F P
0 g
s
.516 .915 .886 r
.55804 .32188 m .55995 .32184 L .55068 .326 L p F P
0 g
s
.516 .915 .886 r
.55068 .326 m .54823 .32615 L .55804 .32188 L p F P
0 g
s
.659 .107 0 r
.21909 .42821 m .21935 .42842 L .21869 .42814 L closepath p F P
0 g
s
.316 0 0 r
.34052 .34651 m .33565 .34499 L .34306 .34651 L p F P
0 g
s
.316 0 0 r
.34306 .34651 m .34351 .34663 L .34052 .34651 L p F P
0 g
s
.135 .683 .76 r
.47038 .46898 m .46936 .46904 L .46383 .46971 L closepath p F P
0 g
s
.149 .692 .776 r
.46666 .46917 m .46936 .46904 L .46383 .46971 L p F P
0 g
s
.149 .692 .776 r
.457 .4703 m .46666 .46917 L p .46383 .46971 L F P
0 g
s
.028 0 0 r
.62937 .41493 m .6291 .4153 L .63185 .41363 L closepath p F P
0 g
s
.237 0 0 r
.44591 .35283 m .44485 .35327 L .44018 .35328 L closepath p F P
0 g
s
.229 0 0 r
.44331 .35407 m .44485 .35327 L .44018 .35328 L p F P
0 g
s
.229 0 0 r
.43676 .35455 m .44331 .35407 L p .44018 .35328 L F P
0 g
s
.229 0 0 r
.43248 .35443 m .43676 .35455 L p .44018 .35328 L F P
0 g
s
0 .411 .684 r
.31625 .33955 m .3162 .33954 L .31614 .33952 L closepath p F P
0 g
s
.193 0 0 r
.31318 .33879 m .30956 .33768 L .31614 .33952 L p F P
0 g
s
.393 0 0 r
.32188 .34154 m .3162 .33954 L .31318 .33879 L p F P
0 g
s
.874 .484 .295 r
.15254 .38145 m .15684 .38415 L .15556 .38053 L p F P
0 g
s
.874 .484 .295 r
.15556 .38053 m .15124 .37784 L .15254 .38145 L p F P
0 g
s
.069 0 0 r
.6396 .40791 m .63892 .40907 L .64515 .40482 L closepath p F P
0 g
s
.348 0 0 r
.38333 .3531 m .38317 .35313 L .38282 .35306 L closepath p F P
0 g
s
.683 .735 .89 r
.66393 .29226 m .65396 .29583 L .65156 .29289 L p F P
0 g
s
.691 .757 .902 r
.64163 .2969 m .65156 .29289 L .65396 .29583 L p F P
0 g
s
.672 .711 .877 r
.65396 .29583 m .66393 .29226 L .66633 .29577 L p F P
0 g
s
.574 0 0 r
.21805 .42892 m .22333 .43118 L .21935 .42842 L p F P
0 g
s
.574 0 0 r
.21589 .4274 m .21805 .42892 L p .21935 .42842 L F P
0 g
s
.574 0 0 r
.21935 .42842 m .21869 .42814 L .21589 .4274 L p F P
0 g
s
.004 .575 .775 r
.36656 .47 m .36772 .47017 L .36008 .4695 L p F P
0 g
s
.004 .575 .775 r
.36128 .46941 m .36656 .47 L p .36008 .4695 L F P
0 g
s
.004 .575 .775 r
.35543 .4689 m .36128 .46941 L p .36008 .4695 L F P
0 g
s
.004 .575 .775 r
.36008 .4695 m .35751 .46923 L .35543 .4689 L p F P
0 g
s
0 0 0 r
.62687 .41816 m .62782 .41707 L .61881 .42155 L p F P
0 g
s
0 0 0 r
.61806 .42305 m .62687 .41816 L p .61881 .42155 L F P
0 g
s
0 0 0 r
.61881 .42155 m .61709 .42352 L .61806 .42305 L p F P
0 g
s
.368 0 0 r
.38024 .35381 m .37368 .35217 L .38282 .35306 L p F P
0 g
s
.368 0 0 r
.38282 .35306 m .38317 .35313 L .38024 .35381 L p F P
0 g
s
.01 .581 .769 r
.37958 .47111 m .37063 .47055 L .36772 .47017 L p F P
0 g
s
.707 .88 .962 r
.61705 .30145 m .60916 .3051 L .61588 .30072 L closepath p F P
0 g
s
.701 .897 .967 r
.61464 .29994 m .61588 .30072 L .60916 .3051 L p F P
0 g
s
.701 .897 .967 r
.60477 .30471 m .61464 .29994 L p .60916 .3051 L F P
0 g
s
.454 0 0 r
.34907 .34848 m .34351 .34663 L .34052 .34651 L p F P
0 g
s
0 .487 .848 r
.27389 .32546 m .274 .32549 L .27373 .32537 L closepath p F P
0 g
s
.327 0 0 r
.26638 .44916 m .27245 .45111 L .26685 .44884 L p F P
0 g
s
.327 0 0 r
.26109 .44707 m .26638 .44916 L p .26685 .44884 L F P
0 g
s
.327 0 0 r
.26685 .44884 m .26149 .44717 L .26109 .44707 L p F P
0 g
s
.888 .671 .603 r
.12634 .34078 m .13021 .3437 L .1313 .33925 L p F P
0 g
s
.888 .671 .603 r
.1313 .33925 m .12744 .33633 L .12634 .34078 L p F P
0 g
s
0 0 0 r
.51618 .46107 m .50643 .46318 L .50381 .46365 L p F P
0 g
s
.838 .722 .736 r
.12988 .31139 m .12688 .31567 L .13057 .31869 L p F P
0 g
s
.854 .716 .71 r
.12386 .32083 m .12757 .32384 L .13057 .31869 L p F P
0 g
s
.854 .716 .71 r
.13057 .31869 m .12688 .31567 L .12386 .32083 L p F P
0 g
s
0 0 0 r
.60602 .42955 m .60715 .4285 L .5973 .43306 L p F P
0 g
s
0 0 0 r
.5973 .43306 m .59673 .4336 L .60602 .42955 L p F P
0 g
s
0 .466 .829 r
.27461 .32504 m .28008 .32732 L .274 .32549 L p F P
0 g
s
0 .466 .829 r
.27084 .32376 m .27461 .32504 L p .274 .32549 L F P
0 g
s
0 .466 .829 r
.274 .32549 m .27373 .32537 L .27084 .32376 L p F P
0 g
s
.473 0 0 r
.24829 .44191 m .24598 .44133 L .24414 .44036 L closepath p F P
0 g
s
.3 .068 .384 r
.68615 .3666 m .67894 .37176 L .6816 .36655 L p F P
0 g
s
.3 .068 .384 r
.6816 .36655 m .68645 .36307 L .68615 .3666 L p F P
0 g
s
.702 .799 .925 r
.64917 .29021 m .65156 .29289 L .64163 .2969 L p F P
0 g
s
.702 .799 .925 r
.64076 .29381 m .64917 .29021 L p .64163 .2969 L F P
0 g
s
.702 .799 .925 r
.64163 .2969 m .63955 .29479 L .64076 .29381 L p F P
0 g
s
.176 0 0 r
.45655 .35158 m .44591 .35283 L .44485 .35327 L p F P
0 g
s
0 0 0 r
.58284 .44039 m .58508 .43908 L .57524 .44283 L p F P
0 g
s
0 0 0 r
.57524 .44283 m .57323 .44401 L .58284 .44039 L p F P
0 g
s
.451 0 0 r
.38992 .35467 m .38317 .35313 L .38024 .35381 L p F P
0 g
s
.621 .055 0 r
.21869 .42814 m .21589 .4274 L .21418 .42612 L closepath p F P
0 g
s
0 .535 .744 r
.35751 .46923 m .35543 .4689 L .35154 .46846 L closepath p F P
0 g
s
.082 .565 .9 r
.27373 .32537 m .27084 .32376 L .26846 .32324 L closepath p F P
0 g
s
.402 .241 .546 r
.69451 .34916 m .69353 .34991 L .6928 .34588 L p F P
0 g
s
.402 .241 .546 r
.6928 .34588 m .69417 .34482 L .69451 .34916 L p F P
0 g
s
.238 .742 .685 r
.52565 .3344 m .52611 .33425 L .51635 .33753 L p F P
0 g
s
.238 .742 .685 r
.51635 .33753 m .51577 .33772 L .52565 .3344 L p F P
0 g
s
.648 .663 .851 r
.67824 .29606 m .67644 .29761 L p .66633 .29577 L F P
0 g
s
.648 .663 .851 r
.66633 .29577 m .67635 .29281 L .67824 .29606 L p F P
0 g
s
.661 .688 .865 r
.67635 .29281 m .66633 .29577 L .66393 .29226 L p F P
0 g
s
.628 .946 .949 r
.58133 .31293 m .58264 .3132 L .57282 .31772 L p F P
0 g
s
.628 .946 .949 r
.57282 .31772 m .57245 .31767 L .58133 .31293 L p F P
0 g
s
.455 .34 .633 r
.70144 .33372 m .69956 .33527 L .69631 .33212 L p F P
0 g
s
.455 .34 .633 r
.69631 .33212 m .70053 .32862 L .70144 .33372 L p F P
0 g
s
.502 .709 .963 r
.21345 .30195 m .21133 .30203 L .21587 .3047 L p F P
0 g
s
.502 .709 .963 r
.21587 .3047 m .21652 .30467 L .21345 .30195 L p F P
0 g
s
.861 .445 .238 r
.15842 .38768 m .16277 .39035 L .1612 .38681 L p F P
0 g
s
.861 .445 .238 r
.1612 .38681 m .15684 .38415 L .15842 .38768 L p F P
0 g
s
.776 .279 .025 r
.18292 .40781 m .18056 .40483 L .18522 .40735 L p F P
0 g
s
.776 .279 .025 r
.18522 .40735 m .1862 .40856 L .18292 .40781 L p F P
0 g
s
.106 0 .024 r
.64953 .40049 m .64873 .40219 L .65537 .39703 L closepath p F P
0 g
s
.168 .707 .777 r
.47905 .46763 m .48162 .46748 L .47038 .46898 L p F P
0 g
s
.168 .707 .777 r
.47038 .46898 m .46936 .46904 L .47905 .46763 L p F P
0 g
s
.024 0 0 r
.63185 .41363 m .6291 .4153 L .62782 .41707 L p F P
0 g
s
.545 .699 .941 r
.18922 .29749 m .18963 .29744 L .18738 .29566 L closepath p F P
0 g
s
.126 0 0 r
.33092 .46532 m .33528 .46606 L .32825 .4649 L closepath p F P
0 g
s
.327 .121 .44 r
.69163 .35916 m .68645 .36307 L .68657 .3593 L p F P
0 g
s
.327 .121 .44 r
.68657 .3593 m .69311 .35435 L .69163 .35916 L p F P
0 g
s
0 0 0 r
.617 .42361 m .61709 .42352 L .60793 .42777 L p F P
0 g
s
0 0 0 r
.60793 .42777 m .60715 .4285 L .617 .42361 L p F P
0 g
s
.634 .651 .849 r
.67644 .29761 m .67824 .29606 L .67878 .29702 L closepath p F P
0 g
s
.64 .079 0 r
.20405 .42141 m .20909 .42378 L .20562 .42085 L p F P
0 g
s
.64 .079 0 r
.20097 .41884 m .20405 .42141 L p .20562 .42085 L F P
0 g
s
.64 .079 0 r
.20562 .42085 m .2017 .41904 L .20097 .41884 L p F P
0 g
s
0 0 0 r
.54092 .45472 m .54086 .45474 L .53949 .4551 L closepath p F P
0 g
s
0 0 0 r
.53832 .45554 m .54086 .45474 L .53949 .4551 L p F P
0 g
s
0 0 0 r
.52853 .45811 m .53832 .45554 L p .53949 .4551 L F P
0 g
s
0 .415 .758 r
.29149 .33151 m .29749 .33358 L .29142 .33172 L p F P
0 g
s
0 .415 .758 r
.28595 .32951 m .29149 .33151 L p .29142 .33172 L F P
0 g
s
0 .415 .758 r
.29142 .33172 m .28605 .32955 L .28595 .32951 L p F P
0 g
s
.367 .663 .971 r
.2252 .30522 m .21652 .30467 L .21345 .30195 L p F P
0 g
s
.538 .697 .942 r
.19517 .29349 m .19827 .29643 L .18963 .29744 L p F P
0 g
s
.538 .697 .942 r
.18613 .29443 m .19517 .29349 L p .18963 .29744 L F P
0 g
s
.538 .697 .942 r
.18963 .29744 m .18738 .29566 L .18613 .29443 L p F P
0 g
s
.879 .69 .642 r
.12364 .33337 m .12744 .33633 L .12909 .33168 L p F P
0 g
s
.879 .69 .642 r
.12909 .33168 m .1253 .32872 L .12364 .33337 L p F P
0 g
s
.343 0 0 r
.27624 .45203 m .27879 .45296 L .27385 .45154 L closepath p F P
0 g
s
.35 0 0 r
.27624 .45203 m .27879 .45296 L .28523 .45477 L p F P
0 g
s
.388 0 0 r
.38013 .35385 m .38024 .35381 L .37368 .35217 L p F P
0 g
s
.388 0 0 r
.37146 .35294 m .38013 .35385 L p .37368 .35217 L F P
0 g
s
.388 0 0 r
.36796 .35186 m .37146 .35294 L p .37368 .35217 L F P
0 g
s
.388 0 0 r
.37368 .35217 m .36947 .35165 L .36796 .35186 L p F P
0 g
s
.105 0 0 r
.46958 .34935 m .47803 .34807 L .46854 .34986 L closepath p F P
0 g
s
.023 .593 .764 r
.38293 .47143 m .38955 .47167 L .38025 .47116 L closepath p F P
0 g
s
.714 .826 .934 r
.63923 .29446 m .62933 .29882 L .62693 .29687 L p F P
0 g
s
.714 .843 .943 r
.61705 .30145 m .62693 .29687 L .62933 .29882 L p F P
0 g
s
.246 0 0 r
.30353 .45966 m .30528 .46012 L .31239 .46168 L p F P
0 g
s
.174 0 0 r
.31269 .46182 m .30528 .46012 L .31239 .46168 L p F P
0 g
s
.174 0 0 r
.3127 .46182 m .31269 .46182 L p .31239 .46168 L F P
0 g
s
.174 0 0 r
.31239 .46168 m .31571 .46243 L .3127 .46182 L p F P
0 g
s
.284 0 0 r
.28506 .45502 m .27879 .45296 L .28523 .45477 L p F P
0 g
s
.284 0 0 r
.28546 .45513 m .28506 .45502 L p .28523 .45477 L F P
0 g
s
.284 0 0 r
.28523 .45477 m .28834 .45578 L .28546 .45513 L p F P
0 g
s
0 .557 .77 r
.35249 .46841 m .35543 .4689 L .35154 .46846 L p F P
0 g
s
0 .557 .77 r
.34316 .46735 m .35249 .46841 L p .35154 .46846 L F P
0 g
s
0 .557 .77 r
.35154 .46846 m .34316 .46735 L .34316 .46735 L p F P
0 g
s
.092 0 0 r
.63892 .40907 m .63185 .41363 L .63824 .41024 L closepath p F P
0 g
s
.024 0 0 r
.63673 .41235 m .63824 .41024 L .63185 .41363 L p F P
0 g
s
.024 0 0 r
.63649 .4125 m .63673 .41235 L p .63185 .41363 L F P
0 g
s
.024 0 0 r
.62782 .41707 m .63649 .4125 L p .63185 .41363 L F P
0 g
s
.144 .685 .712 r
.50348 .46371 m .50381 .46365 L .49408 .46546 L p F P
0 g
s
.144 .685 .712 r
.49408 .46546 m .49264 .4657 L .50348 .46371 L p F P
0 g
s
0 0 0 r
.49264 .4657 m .49408 .46546 L p .48172 .46747 L F P
0 g
s
0 0 0 r
.55066 .45186 m .55099 .45176 L .54092 .45472 L p F P
0 g
s
0 0 0 r
.54092 .45472 m .54086 .45474 L .55066 .45186 L p F P
0 g
s
.632 .947 .947 r
.58019 .31271 m .58133 .31293 L .57245 .31767 L p F P
0 g
s
.632 .947 .947 r
.57245 .31767 m .57035 .31739 L .58019 .31271 L p F P
0 g
s
.257 0 .319 r
.67797 .37245 m .67782 .37344 L .67894 .37176 L closepath p F P
0 g
s
.696 .929 .967 r
.60249 .30367 m .60477 .30471 L .59492 .30938 L p F P
0 g
s
.696 .929 .967 r
.59492 .30938 m .59404 .30905 L .60249 .30367 L p F P
0 g
s
.842 .401 .178 r
.16462 .39379 m .16277 .39035 L .16718 .39299 L p F P
0 g
s
.842 .401 .178 r
.16629 .39478 m .16462 .39379 L p .16718 .39299 L F P
0 g
s
.842 .401 .178 r
.16718 .39299 m .16836 .39516 L .16629 .39478 L p F P
0 g
s
.027 .523 .876 r
.25879 .3197 m .26319 .32088 L .26846 .32324 L p F P
0 g
s
.005 .499 .866 r
.26319 .32088 m .25879 .3197 L .25573 .31769 L p F P
0 g
s
.371 0 0 r
.33438 .34536 m .32878 .34326 L .33565 .34499 L p F P
0 g
s
.371 0 0 r
.3397 .3465 m .33438 .34536 L p .33565 .34499 L F P
0 g
s
.371 0 0 r
.33565 .34499 m .34052 .34651 L .3397 .3465 L p F P
0 g
s
.392 0 0 r
.32834 .3431 m .32878 .34326 L .33565 .34499 L p F P
0 g
s
0 0 0 r
.55066 .45186 m .54086 .45474 L .53832 .45554 L p F P
0 g
s
.79 .735 .802 r
.13706 .30379 m .13971 .30136 L .13659 .29788 L p F P
0 g
s
.79 .735 .802 r
.13659 .29788 m .13345 .30072 L .13706 .30379 L p F P
0 g
s
.805 .733 .785 r
.12725 .30709 m .13095 .31012 L .13706 .30379 L p F P
0 g
s
.805 .733 .785 r
.13706 .30379 m .13345 .30072 L .12725 .30709 L p F P
0 g
s
.756 .732 .83 r
.14757 .29577 m .13971 .30136 L .13659 .29788 L p F P
0 g
s
.278 .622 .96 r
.22858 .30777 m .2296 .30794 L .23405 .31063 L p F P
0 g
s
.303 .648 .969 r
.23729 .3091 m .2296 .30794 L .23405 .31063 L p F P
0 g
s
.303 .648 .969 r
.23801 .30948 m .23729 .3091 L p .23405 .31063 L F P
0 g
s
.303 .648 .969 r
.23405 .31063 m .24063 .31146 L .23801 .30948 L p F P
0 g
s
.237 0 0 r
.30353 .45966 m .30528 .46012 L .3022 .45943 L closepath p F P
0 g
s
.388 .23 .543 r
.70217 .34295 m .69451 .34916 L .69417 .34482 L p F P
0 g
s
.388 .23 .543 r
.69417 .34482 m .70146 .3389 L .70217 .34295 L p F P
0 g
s
.393 0 0 r
.36947 .35165 m .36796 .35186 L .36508 .35109 L closepath p F P
0 g
s
.38 0 0 r
.39546 .35433 m .40007 .3552 L .39365 .3549 L closepath p F P
0 g
s
.177 0 0 r
.45734 .35149 m .45722 .35154 L .45655 .35158 L closepath p F P
0 g
s
.176 0 0 r
.45482 .35279 m .45722 .35154 L .45655 .35158 L p F P
0 g
s
.176 0 0 r
.45266 .35303 m .45482 .35279 L p .45655 .35158 L F P
0 g
s
.176 0 0 r
.44485 .35327 m .45266 .35303 L p .45655 .35158 L F P
0 g
s
.14 0 .101 r
.65915 .39267 m .65851 .39438 L .66344 .38997 L closepath p F P
0 g
s
.141 0 0 r
.46687 .3507 m .46854 .34986 L .45734 .35149 L p F P
0 g
s
.141 0 0 r
.45734 .35149 m .45722 .35154 L .46687 .3507 L p F P
0 g
s
0 0 0 r
.57281 .44421 m .57323 .44401 L .56348 .44741 L p F P
0 g
s
0 0 0 r
.56348 .44741 m .56297 .44765 L .57281 .44421 L p F P
0 g
s
.616 .603 .814 r
.67878 .29702 m .68888 .29498 L .69135 .30019 L p F P
0 g
s
.618 .643 .853 r
.67824 .29606 m .67878 .29702 L .68888 .29498 L p F P
0 g
s
.232 .737 .679 r
.52354 .3351 m .52565 .3344 L .51577 .33772 L p F P
0 g
s
.232 .737 .679 r
.51577 .33772 m .51376 .33837 L .52354 .3351 L p F P
0 g
s
.292 0 0 r
.30107 .33484 m .3034 .33568 L .30956 .33768 L p F P
0 g
s
.247 0 0 r
.3091 .3377 m .3034 .33568 L .30956 .33768 L p F P
0 g
s
.247 0 0 r
.31107 .33828 m .3091 .3377 L p .30956 .33768 L F P
0 g
s
.247 0 0 r
.30956 .33768 m .31318 .33879 L .31107 .33828 L p F P
0 g
s
.243 0 0 r
.30107 .33484 m .3034 .33568 L .29856 .33393 L closepath p F P
0 g
s
0 0 0 r
.60481 .43045 m .60602 .42955 L .59673 .4336 L p F P
0 g
s
0 0 0 r
.59673 .4336 m .59494 .43494 L .60481 .43045 L p F P
0 g
s
.406 .857 .806 r
.54761 .32625 m .54823 .32615 L .53843 .33009 L p F P
0 g
s
.406 .857 .806 r
.53843 .33009 m .53814 .33015 L .54761 .32625 L p F P
0 g
s
.045 .611 .768 r
.39524 .47202 m .40001 .47207 L .3935 .47188 L closepath p F P
0 g
s
.723 .194 0 r
.19091 .41359 m .19572 .41606 L .19273 .41298 L p F P
0 g
s
.723 .194 0 r
.19273 .41298 m .18789 .41053 L .19091 .41359 L p F P
0 g
s
.885 .527 .361 r
.15098 .3768 m .15124 .37784 L .14983 .37693 L closepath p F P
0 g
s
.47 0 0 r
.24282 .44051 m .23855 .43823 L .24414 .44036 L p F P
0 g
s
.47 0 0 r
.24414 .44036 m .24598 .44133 L .24282 .44051 L p F P
0 g
s
.868 .706 .678 r
.12157 .32572 m .1253 .32872 L .12757 .32384 L p F P
0 g
s
.868 .706 .678 r
.12757 .32384 m .12386 .32083 L .12157 .32572 L p F P
0 g
s
.82 .727 .762 r
.12677 .30766 m .12725 .30709 L .13095 .31012 L p F P
0 g
s
.82 .727 .762 r
.13095 .31012 m .12988 .31139 L .12677 .30766 L p F P
0 g
s
.387 0 0 r
.26149 .44717 m .26109 .44707 L .26073 .44692 L closepath p F P
0 g
s
.199 0 0 r
.46607 .35119 m .46687 .3507 L .45722 .35154 L p F P
0 g
s
.199 0 0 r
.45722 .35154 m .45482 .35279 L .46607 .35119 L p F P
0 g
s
.255 0 .317 r
.68567 .3699 m .68615 .3666 L .67894 .37176 L p F P
0 g
s
.255 0 .317 r
.67747 .37575 m .68567 .3699 L p .67894 .37176 L F P
0 g
s
.255 0 .317 r
.67894 .37176 m .67782 .37344 L .67747 .37575 L p F P
0 g
s
0 0 0 r
.50138 .34235 m .50299 .34166 L .49263 .34435 L p F P
0 g
s
0 0 0 r
.49263 .34435 m .49164 .34473 L .50138 .34235 L p F P
0 g
s
.198 .723 .724 r
.52596 .4587 m .52777 .45834 L .51734 .46084 L p F P
0 g
s
.198 .723 .724 r
.51734 .46084 m .51618 .46107 L .52596 .4587 L p F P
0 g
s
.16 .581 .934 r
.24369 .31375 m .24648 .31438 L .25133 .31691 L p F P
0 g
s
.2 .614 .948 r
.25267 .31565 m .24648 .31438 L .25133 .31691 L p F P
0 g
s
.2 .614 .948 r
.25133 .31691 m .25573 .31769 L .25267 .31565 L p F P
0 g
s
.55 0 0 r
.22754 .43388 m .22333 .43118 L .22866 .43342 L p F P
0 g
s
.55 0 0 r
.22798 .43407 m .22754 .43388 L p .22866 .43342 L F P
0 g
s
.55 0 0 r
.22866 .43342 m .2309 .43483 L .22798 .43407 L p F P
0 g
s
0 0 0 r
.48172 .46747 m .48246 .46735 L .49264 .4657 L p F P
0 g
s
.121 .669 .711 r
.48172 .46747 m .48246 .46735 L .48162 .46748 L closepath p F P
0 g
s
.53 .473 .737 r
.69643 .31329 m .70078 .31399 L .69757 .31686 L closepath p F P
0 g
s
.525 .486 .755 r
.69522 .30979 m .69643 .31329 L .70078 .31399 L p F P
0 g
s
.765 .261 .008 r
.18789 .41053 m .1862 .40856 L .18292 .40781 L p F P
0 g
s
.49 .426 .712 r
.70683 .31583 m .70078 .31399 L .69757 .31686 L p F P
0 g
s
.49 .426 .712 r
.70695 .31628 m .70683 .31583 L p .69757 .31686 L F P
0 g
s
.49 .426 .712 r
.69981 .32263 m .70695 .31628 L p .69757 .31686 L F P
0 g
s
.49 .426 .712 r
.69757 .31686 m .69911 .32236 L .69981 .32263 L p F P
0 g
s
.434 0 0 r
.35572 .34943 m .35695 .34983 L .36508 .35109 L p F P
0 g
s
.406 0 0 r
.36302 .35179 m .35695 .34983 L .36508 .35109 L p F P
0 g
s
.406 0 0 r
.36607 .35221 m .36302 .35179 L p .36508 .35109 L F P
0 g
s
.406 0 0 r
.36508 .35109 m .36796 .35186 L .36607 .35221 L p F P
0 g
s
.839 .725 .738 r
.12688 .31567 m .12988 .31139 L .12677 .30766 L p F P
0 g
s
.831 .384 .166 r
.16836 .39516 m .16909 .39641 L .17366 .39898 L p F P
0 g
s
.803 .325 .077 r
.17141 .3997 m .17596 .40228 L .17366 .39898 L p F P
0 g
s
.803 .325 .077 r
.17366 .39898 m .16909 .39641 L .17141 .3997 L p F P
0 g
s
.902 .602 .467 r
.1335 .35898 m .1375 .36184 L .13731 .35784 L p F P
0 g
s
.902 .602 .467 r
.13731 .35784 m .13332 .35499 L .1335 .35898 L p F P
0 g
s
.203 .731 .793 r
.48246 .46735 m .48162 .46748 L .47905 .46763 L p F P
0 g
s
.378 0 0 r
.25797 .44624 m .25488 .44489 L .26073 .44692 L p F P
0 g
s
.378 0 0 r
.26073 .44692 m .26109 .44707 L .25797 .44624 L p F P
0 g
s
.9 .572 .417 r
.13803 .36571 m .14208 .36853 L .14155 .36466 L p F P
0 g
s
.9 .572 .417 r
.14155 .36466 m .1375 .36184 L .13803 .36571 L p F P
0 g
s
.559 .523 .772 r
.69386 .3062 m .69908 .30628 L .69522 .30979 L closepath p F P
0 g
s
.525 .486 .755 r
.70414 .30675 m .69908 .30628 L .69522 .30979 L p F P
0 g
s
.525 .486 .755 r
.70519 .31001 m .70414 .30675 L p .69522 .30979 L F P
0 g
s
.525 .486 .755 r
.70078 .31399 m .70519 .31001 L p .69522 .30979 L F P
0 g
s
.636 .657 .854 r
.67635 .29281 m .68392 .29088 L .67824 .29606 L closepath p F P
0 g
s
.618 .643 .853 r
.68643 .29027 m .68392 .29088 L .67824 .29606 L p F P
0 g
s
.618 .643 .853 r
.68888 .29498 m .68643 .29027 L p .67824 .29606 L F P
0 g
s
.901 .629 .515 r
.12938 .3521 m .13332 .35499 L .13352 .35086 L p F P
0 g
s
.901 .629 .515 r
.13352 .35086 m .12958 .34798 L .12938 .3521 L p F P
0 g
s
.468 .691 .964 r
.20136 .29935 m .20698 .29928 L .21133 .30203 L p F P
0 g
s
.458 .682 .962 r
.20698 .29928 m .20136 .29935 L .19827 .29643 L p F P
0 g
s
.139 .561 .926 r
.24648 .31438 m .24369 .31375 L .24063 .31146 L p F P
0 g
s
.411 0 0 r
.35572 .34943 m .35695 .34983 L .35496 .34948 L closepath p F P
0 g
s
.065 0 0 r
.64515 .40482 m .63892 .40907 L .63824 .41024 L p F P
0 g
s
.191 .722 .777 r
.49264 .4657 m .49143 .4658 L .48246 .46735 L closepath p F P
0 g
s
.203 .731 .793 r
.48904 .46596 m .49143 .4658 L .48246 .46735 L p F P
0 g
s
.203 .731 .793 r
.48688 .46631 m .48904 .46596 L p .48246 .46735 L F P
0 g
s
.203 .731 .793 r
.47905 .46763 m .48688 .46631 L p .48246 .46735 L F P
0 g
s
.717 .883 .957 r
.62453 .29513 m .62693 .29687 L .61705 .30145 L p F P
0 g
s
.717 .883 .957 r
.62154 .29658 m .62453 .29513 L p .61705 .30145 L F P
0 g
s
.717 .883 .957 r
.61705 .30145 m .61588 .30072 L .62154 .29658 L p F P
0 g
s
0 .515 .737 r
.34316 .46735 m .34316 .46735 L .34315 .46735 L closepath p F P
0 g
s
0 .526 .754 r
.3402 .46675 m .33528 .46606 L .34315 .46735 L p F P
0 g
s
0 .526 .754 r
.34315 .46735 m .34316 .46735 L .3402 .46675 L p F P
0 g
s
0 .557 .779 r
.35249 .46841 m .34316 .46735 L .3402 .46675 L p F P
0 g
s
.273 .012 .323 r
.67782 .37344 m .67502 .37741 L .67747 .37575 L closepath p F P
0 g
s
0 0 0 r
.51312 .33865 m .51376 .33837 L .50401 .34124 L p F P
0 g
s
0 0 0 r
.50401 .34124 m .50299 .34166 L .51312 .33865 L p F P
0 g
s
.362 0 0 r
.40778 .35496 m .41108 .35542 L .40667 .35539 L closepath p F P
0 g
s
.894 .539 .364 r
.14294 .3723 m .14705 .37509 L .14619 .37132 L p F P
0 g
s
.894 .539 .364 r
.14619 .37132 m .14208 .36853 L .14294 .3723 L p F P
0 g
s
.052 .618 .756 r
.41901 .47223 m .41992 .47226 L p .40757 .4723 L F P
0 g
s
.052 .618 .756 r
.40757 .4723 m .41112 .47224 L .41901 .47223 L p F P
0 g
s
.066 .629 .772 r
.40757 .4723 m .41112 .47224 L .40642 .47223 L closepath p F P
0 g
s
.659 .729 .901 r
.16163 .29338 m .17082 .29019 L .17393 .29338 L p F P
0 g
s
.656 .728 .902 r
.17082 .29019 m .16163 .29338 L .15852 .2901 L p F P
0 g
s
.708 .735 .873 r
.14921 .29469 m .15852 .2901 L .16163 .29338 L p F P
0 g
s
.407 .858 .804 r
.54571 .32659 m .54761 .32625 L .53814 .33015 L p F P
0 g
s
.407 .858 .804 r
.53814 .33015 m .5359 .3306 L .54571 .32659 L p F P
0 g
s
.619 .052 0 r
.21268 .42653 m .20909 .42378 L .21418 .42612 L p F P
0 g
s
.619 .052 0 r
.21418 .42612 m .21589 .4274 L .21268 .42653 L p F P
0 g
s
.087 .567 .903 r
.26778 .32204 m .26319 .32088 L .26846 .32324 L p F P
0 g
s
.087 .567 .903 r
.26846 .32324 m .27084 .32376 L .26778 .32204 L p F P
0 g
s
.346 0 0 r
.26638 .44916 m .26109 .44707 L .25797 .44624 L p F P
0 g
s
.157 .699 .767 r
.47905 .46763 m .46936 .46904 L .46666 .46917 L p F P
0 g
s
.746 .737 .844 r
.14757 .29577 m .14921 .29469 L .14609 .29133 L p F P
0 g
s
.746 .737 .844 r
.14609 .29133 m .14401 .29268 L .14757 .29577 L p F P
0 g
s
.756 .732 .83 r
.13659 .29788 m .14401 .29268 L .14757 .29577 L p F P
0 g
s
.498 .419 .697 r
.69911 .32236 m .69981 .32263 L .6993 .32308 L closepath p F P
0 g
s
.248 0 0 r
.44485 .35327 m .45266 .35303 L .44331 .35407 L closepath p F P
0 g
s
.897 .653 .561 r
.12571 .34506 m .12958 .34798 L .13021 .3437 L p F P
0 g
s
.897 .653 .561 r
.13021 .3437 m .12634 .34078 L .12571 .34506 L p F P
0 g
s
.613 .724 .925 r
.18738 .29566 m .18613 .29443 L .18559 .29456 L closepath p F P
0 g
s
.558 .932 .905 r
.56901 .31734 m .57035 .31739 L .56053 .32183 L p F P
0 g
s
.558 .932 .905 r
.56053 .32183 m .55995 .32184 L .56901 .31734 L p F P
0 g
s
.475 .381 .67 r
.70429 .32534 m .70053 .32862 L .6993 .32308 L p F P
0 g
s
.475 .381 .67 r
.6993 .32308 m .69981 .32263 L .70429 .32534 L p F P
0 g
s
.372 0 0 r
.32834 .3431 m .32878 .34326 L .32799 .34305 L closepath p F P
0 g
s
.68 .133 0 r
.2017 .41904 m .20097 .41884 L .20058 .41849 L closepath p F P
0 g
s
0 .462 .719 r
.30574 .46019 m .31269 .46182 L .30528 .46012 L p F P
0 g
s
0 .462 .719 r
.30049 .45901 m .30574 .46019 L p .30528 .46012 L F P
0 g
s
0 .462 .719 r
.30528 .46012 m .3022 .45943 L .30049 .45901 L p F P
0 g
s
.556 .54 .792 r
.69183 .3013 m .69386 .3062 L .69908 .30628 L p F P
0 g
s
.875 .479 .279 r
.14829 .37873 m .15254 .38145 L .15124 .37784 L p F P
0 g
s
.875 .479 .279 r
.14756 .37666 m .14829 .37873 L p .15124 .37784 L F P
0 g
s
.875 .479 .279 r
.15124 .37784 m .14983 .37693 L .14756 .37666 L p F P
0 g
s
.334 0 0 r
.42012 .35499 m .42317 .35525 L .41925 .35538 L closepath p F P
0 g
s
.07 .633 .756 r
.4313 .4719 m .43227 .47192 L p .41992 .47226 L F P
0 g
s
.07 .633 .756 r
.41992 .47226 m .42305 .47214 L .4313 .4719 L p F P
0 g
s
.088 .646 .775 r
.41992 .47226 m .42305 .47214 L .41901 .47223 L closepath p F P
0 g
s
.705 .735 .874 r
.15852 .2901 m .14921 .29469 L .14609 .29133 L p F P
0 g
s
0 0 0 r
.57068 .44516 m .57281 .44421 L .56297 .44765 L p F P
0 g
s
0 0 0 r
.56297 .44765 m .56091 .44857 L .57068 .44516 L p F P
0 g
s
.605 .721 .927 r
.17393 .29338 m .18134 .29174 L .18559 .29456 L p F P
0 g
s
.599 .717 .927 r
.18134 .29174 m .17393 .29338 L .17082 .29019 L p F P
0 g
s
.15 .693 .78 r
.46664 .46917 m .46666 .46917 L .457 .4703 L p F P
0 g
s
.15 .693 .78 r
.457 .4703 m .45509 .47035 L .46664 .46917 L p F P
0 g
s
.296 0 0 r
.43248 .35443 m .43676 .35455 L .43146 .35493 L closepath p F P
0 g
s
0 0 0 r
.61518 .42527 m .617 .42361 L .60715 .4285 L p F P
0 g
s
0 0 0 r
.60715 .4285 m .60602 .42955 L .61518 .42527 L p F P
0 g
s
.697 .93 .966 r
.60234 .30361 m .60249 .30367 L .59404 .30905 L p F P
0 g
s
.697 .93 .966 r
.59404 .30905 m .59248 .30848 L .60234 .30361 L p F P
0 g
s
0 0 0 r
.53804 .45562 m .53832 .45554 L .52853 .45811 L p F P
0 g
s
0 0 0 r
.52853 .45811 m .52777 .45834 L .53804 .45562 L p F P
0 g
s
.17 0 .171 r
.66847 .38443 m .66823 .38524 L .66996 .38344 L closepath p F P
0 g
s
0 .511 .835 r
.28605 .32955 m .28595 .32951 L .28586 .32948 L closepath p F P
0 g
s
.394 0 0 r
.32748 .34363 m .33438 .34536 L .32878 .34326 L p F P
0 g
s
.394 0 0 r
.32533 .34272 m .32748 .34363 L p .32878 .34326 L F P
0 g
s
.394 0 0 r
.32878 .34326 m .32799 .34305 L .32533 .34272 L p F P
0 g
s
.088 .647 .755 r
.44332 .47127 m .44463 .47126 L p .43227 .47192 L F P
0 g
s
.088 .647 .755 r
.43227 .47192 m .43605 .47167 L .44332 .47127 L p F P
0 g
s
.109 .662 .778 r
.43227 .47192 m .43605 .47167 L .4313 .4719 L closepath p F P
0 g
s
.228 0 0 r
.27876 .45315 m .28506 .45502 L .27879 .45296 L p F P
0 g
s
.228 0 0 r
.27315 .45136 m .27876 .45315 L p .27879 .45296 L F P
0 g
s
.228 0 0 r
.27879 .45296 m .27385 .45154 L .27315 .45136 L p F P
0 g
s
.129 .678 .779 r
.44463 .47126 m .45046 .47073 L .44332 .47127 L closepath p F P
0 g
s
.473 .382 .671 r
.70821 .32186 m .70429 .32534 L .69981 .32263 L p F P
0 g
s
.473 .382 .671 r
.69981 .32263 m .70695 .31628 L .70821 .32186 L p F P
0 g
s
0 .509 .832 r
.2829 .32813 m .28008 .32732 L .28586 .32948 L p F P
0 g
s
0 .509 .832 r
.28586 .32948 m .28595 .32951 L .2829 .32813 L p F P
0 g
s
.891 .675 .603 r
.12253 .33782 m .12634 .34078 L .12744 .33633 L p F P
0 g
s
.891 .675 .603 r
.12744 .33633 m .12364 .33337 L .12253 .33782 L p F P
0 g
s
.489 .702 .964 r
.21036 .2992 m .20698 .29928 L .21133 .30203 L p F P
0 g
s
.489 .702 .964 r
.21133 .30203 m .21345 .30195 L .21036 .2992 L p F P
0 g
s
.277 0 0 r
.29149 .33151 m .28595 .32951 L .2829 .32813 L p F P
0 g
s
.219 0 .247 r
.67679 .37882 m .66996 .38344 L .67502 .37741 L p F P
0 g
s
.219 0 .247 r
.67502 .37741 m .67747 .37575 L .67679 .37882 L p F P
0 g
s
.78 .284 .024 r
.17851 .40549 m .17596 .40228 L .18056 .40483 L p F P
0 g
s
.78 .284 .024 r
.18246 .4077 m .17851 .40549 L p .18056 .40483 L F P
0 g
s
.78 .284 .024 r
.18056 .40483 m .18292 .40781 L .18246 .4077 L p F P
0 g
s
.839 .725 .738 r
.12677 .30766 m .12326 .31262 L .12688 .31567 L p F P
0 g
s
.855 .719 .711 r
.12021 .31779 m .12386 .32083 L .12688 .31567 L p F P
0 g
s
.855 .719 .711 r
.12688 .31567 m .12326 .31262 L .12021 .31779 L p F P
0 g
s
.128 0 .031 r
.64873 .40219 m .64515 .40482 L .64834 .40301 L closepath p F P
0 g
s
.065 0 0 r
.64698 .40532 m .64834 .40301 L .64515 .40482 L p F P
0 g
s
.065 0 0 r
.63824 .41024 m .64698 .40532 L p .64515 .40482 L F P
0 g
s
.677 .129 0 r
.19773 .41789 m .19572 .41606 L .20058 .41849 L p F P
0 g
s
.677 .129 0 r
.20058 .41849 m .20097 .41884 L .19773 .41789 L p F P
0 g
s
.35 0 0 r
.32799 .34305 m .32533 .34272 L .32188 .34154 L closepath p F P
0 g
s
.363 .18 .494 r
.69461 .3532 m .69311 .35435 L .69353 .34991 L p F P
0 g
s
.363 .18 .494 r
.69353 .34991 m .69451 .34916 L .69461 .3532 L p F P
0 g
s
.665 .949 .955 r
.59004 .30781 m .59248 .30848 L .58264 .3132 L p F P
0 g
s
.665 .949 .955 r
.58929 .30818 m .59004 .30781 L p .58264 .3132 L F P
0 g
s
.665 .949 .955 r
.58264 .3132 m .58133 .31293 L .58929 .30818 L p F P
0 g
s
0 0 0 r
.58517 .43903 m .58508 .43908 L .58725 .43819 L closepath p F P
0 g
s
.112 0 0 r
.47803 .34807 m .46854 .34986 L .46687 .3507 L p F P
0 g
s
.862 .443 .227 r
.15413 .38497 m .15842 .38768 L .15684 .38415 L p F P
0 g
s
.862 .443 .227 r
.15684 .38415 m .15254 .38145 L .15413 .38497 L p F P
0 g
s
.289 .621 .96 r
.22858 .30777 m .2296 .30794 L .22608 .3057 L closepath p F P
0 g
s
.427 0 0 r
.35495 .3505 m .36302 .35179 L .35695 .34983 L p F P
0 g
s
.427 0 0 r
.35274 .34966 m .35495 .3505 L p .35695 .34983 L F P
0 g
s
.427 0 0 r
.35695 .34983 m .35496 .34948 L .35274 .34966 L p F P
0 g
s
.683 .735 .89 r
.65156 .29289 m .66153 .28905 L .66393 .29226 L p F P
0 g
s
.694 .759 .902 r
.66153 .28905 m .65156 .29289 L .64917 .29021 L p F P
0 g
s
.185 0 0 r
.3022 .45943 m .30049 .45901 L .2984 .45847 L closepath p F P
0 g
s
.673 .712 .878 r
.67394 .28897 m .66393 .29226 L .66153 .28905 L p F P
0 g
s
.661 .688 .865 r
.66393 .29226 m .67394 .28897 L .67635 .29281 L p F P
0 g
s
.833 .383 .157 r
.16836 .39516 m .16909 .39641 L .16629 .39478 L closepath p F P
0 g
s
.702 .799 .925 r
.63955 .29479 m .63923 .29446 L .64076 .29381 L closepath p F P
0 g
s
0 0 0 r
.58725 .43819 m .58508 .43908 L .58284 .44039 L p F P
0 g
s
0 .457 .698 r
.31571 .46243 m .32007 .46329 L .3127 .46182 L closepath p F P
0 g
s
.103 0 .02 r
.65537 .39703 m .64873 .40219 L .64834 .40301 L p F P
0 g
s
.439 0 0 r
.24908 .44283 m .24598 .44133 L .24282 .44051 L p F P
0 g
s
.243 0 0 r
.28834 .45578 m .29171 .45676 L .28546 .45513 L closepath p F P
0 g
s
.884 .499 .302 r
.14983 .37693 m .14756 .37666 L .14705 .37509 L closepath p F P
0 g
s
.418 0 0 r
.35496 .34948 m .35274 .34966 L .34907 .34848 L closepath p F P
0 g
s
0 .549 .781 r
.33781 .46626 m .3402 .46675 L .33528 .46606 L p F P
0 g
s
0 .549 .781 r
.33629 .466 m .33781 .46626 L p .33528 .46606 L F P
0 g
s
0 .549 .781 r
.32793 .46483 m .33629 .466 L p .33528 .46606 L F P
0 g
s
0 .549 .781 r
.33528 .46606 m .32825 .4649 L .32793 .46483 L p F P
0 g
s
0 .569 .774 r
.36128 .46941 m .35543 .4689 L .35249 .46841 L p F P
0 g
s
.659 .105 0 r
.20405 .42141 m .20097 .41884 L .19773 .41789 L p F P
0 g
s
.613 .724 .924 r
.18303 .29136 m .18134 .29174 L .18559 .29456 L p F P
0 g
s
.613 .724 .924 r
.18559 .29456 m .18613 .29443 L .18303 .29136 L p F P
0 g
s
.274 0 0 r
.30285 .33573 m .3091 .3377 L .3034 .33568 L p F P
0 g
s
.274 0 0 r
.29804 .33374 m .30285 .33573 L p .3034 .33568 L F P
0 g
s
.274 0 0 r
.3034 .33568 m .29856 .33393 L .29804 .33374 L p F P
0 g
s
.28 .052 .379 r
.68919 .3643 m .68615 .3666 L .68645 .36307 L p F P
0 g
s
.28 .052 .379 r
.68645 .36307 m .69163 .35916 L .68919 .3643 L p F P
0 g
s
.556 .54 .792 r
.70156 .29964 m .6932 .30003 L .69183 .3013 L p F P
0 g
s
.556 .54 .792 r
.70279 .30286 m .70156 .29964 L p .69183 .3013 L F P
0 g
s
.556 .54 .792 r
.69908 .30628 m .70279 .30286 L p .69183 .3013 L F P
0 g
s
.585 .569 .803 r
.69135 .30019 m .6932 .30003 L .69183 .3013 L closepath p F P
0 g
s
.882 .693 .643 r
.1199 .33037 m .12364 .33337 L .1253 .32872 L p F P
0 g
s
.882 .693 .643 r
.1253 .32872 m .12157 .32572 L .1199 .33037 L p F P
0 g
s
.561 .934 .904 r
.56788 .31731 m .56901 .31734 L .55995 .32184 L p F P
0 g
s
.561 .934 .904 r
.55995 .32184 m .55804 .32188 L .56788 .31731 L p F P
0 g
s
.443 .332 .632 r
.70735 .32856 m .70144 .33372 L .70053 .32862 L p F P
0 g
s
.443 .332 .632 r
.70053 .32862 m .70429 .32534 L .70735 .32856 L p F P
0 g
s
.845 .401 .167 r
.16028 .39111 m .16462 .39379 L .16277 .39035 L p F P
0 g
s
.845 .401 .167 r
.16277 .39035 m .15842 .38768 L .16028 .39111 L p F P
0 g
s
.711 .917 .964 r
.61222 .29866 m .61464 .29994 L .60477 .30471 L p F P
0 g
s
.711 .917 .964 r
.60326 .30314 m .61222 .29866 L p .60477 .30471 L F P
0 g
s
.711 .917 .964 r
.60477 .30471 m .60249 .30367 L .60326 .30314 L p F P
0 g
s
.532 .702 .948 r
.19517 .29349 m .18613 .29443 L .18303 .29136 L p F P
0 g
s
.346 .168 .491 r
.7018 .34738 m .69461 .3532 L .69451 .34916 L p F P
0 g
s
.346 .168 .491 r
.69451 .34916 m .70217 .34295 L .7018 .34738 L p F P
0 g
s
.701 .822 .94 r
.64076 .29381 m .63923 .29446 L .63684 .2923 L p F P
0 g
s
.714 .826 .934 r
.62693 .29687 m .63684 .2923 L .63923 .29446 L p F P
0 g
s
.281 .771 .701 r
.53532 .33078 m .5359 .3306 L .52611 .33425 L p F P
0 g
s
.281 .771 .701 r
.52611 .33425 m .52565 .3344 L .53532 .33078 L p F P
0 g
s
.167 0 .168 r
.676 .38157 m .67679 .37882 L .66996 .38344 L p F P
0 g
s
.167 0 .168 r
.67572 .38187 m .676 .38157 L p .66996 .38344 L F P
0 g
s
.167 0 .168 r
.66762 .38731 m .67572 .38187 L p .66996 .38344 L F P
0 g
s
.167 0 .168 r
.66996 .38344 m .66823 .38524 L .66762 .38731 L p F P
0 g
s
.267 .611 .956 r
.23256 .30649 m .23729 .3091 L .2296 .30794 L p F P
0 g
s
.267 .611 .956 r
.22551 .30523 m .23256 .30649 L p .2296 .30794 L F P
0 g
s
.267 .611 .956 r
.2296 .30794 m .22608 .3057 L .22551 .30523 L p F P
0 g
s
.223 .745 .792 r
.50118 .46388 m .50348 .46371 L .49264 .4657 L p F P
0 g
s
.223 .745 .792 r
.49264 .4657 m .49143 .4658 L .50118 .46388 L p F P
0 g
s
.522 0 0 r
.2309 .43483 m .23302 .43607 L .23855 .43823 L p F P
0 g
s
.469 0 0 r
.2378 .43859 m .23302 .43607 L .23855 .43823 L p F P
0 g
s
.469 0 0 r
.2422 .44034 m .2378 .43859 L p .23855 .43823 L F P
0 g
s
.469 0 0 r
.23855 .43823 m .24282 .44051 L .2422 .44034 L p F P
0 g
s
.008 0 0 r
.50049 .34284 m .50138 .34235 L .49164 .34473 L p F P
0 g
s
.008 0 0 r
.49164 .34473 m .49009 .34551 L .50049 .34284 L p F P
0 g
s
.189 0 .177 r
.66823 .38524 m .66344 .38997 L .66762 .38731 L closepath p F P
0 g
s
.16 0 .108 r
.65851 .39438 m .65537 .39703 L .65814 .39537 L closepath p F P
0 g
s
.103 0 .02 r
.65694 .39786 m .65814 .39537 L .65537 .39703 L p F P
0 g
s
.103 0 .02 r
.64834 .40301 m .65694 .39786 L p .65537 .39703 L F P
0 g
s
0 0 0 r
.59494 .43494 m .58725 .43819 L .59461 .43518 L closepath p F P
0 g
s
0 0 0 r
.59255 .43639 m .59461 .43518 L .58725 .43819 L p F P
0 g
s
0 0 0 r
.58669 .43883 m .59255 .43639 L p .58725 .43819 L F P
0 g
s
0 0 0 r
.58284 .44039 m .58669 .43883 L p .58725 .43819 L F P
0 g
s
.597 .576 .801 r
.6932 .30003 m .69135 .30019 L .68888 .29498 L p F P
0 g
s
.422 .287 .591 r
.70204 .33842 m .70146 .3389 L .69956 .33527 L p F P
0 g
s
.422 .287 .591 r
.69956 .33527 m .70144 .33372 L .70204 .33842 L p F P
0 g
s
.647 .663 .851 r
.68392 .29088 m .67635 .29281 L .67394 .28897 L p F P
0 g
s
.516 0 0 r
.2309 .43483 m .23302 .43607 L .22798 .43407 L closepath p F P
0 g
s
.137 0 .098 r
.66344 .38997 m .65851 .39438 L .65814 .39537 L p F P
0 g
s
.437 0 0 r
.36796 .35186 m .37146 .35294 L .36607 .35221 L closepath p F P
0 g
s
.537 0 0 r
.2223 .4316 m .22754 .43388 L .22333 .43118 L p F P
0 g
s
.537 0 0 r
.22333 .43118 m .21805 .42892 L .2223 .4316 L p F P
0 g
s
0 .397 .762 r
.27461 .32504 m .27084 .32376 L .26778 .32204 L p F P
0 g
s
0 0 0 r
.5605 .44871 m .56091 .44857 L .55099 .45176 L p F P
0 g
s
0 0 0 r
.55099 .45176 m .55066 .45186 L .5605 .44871 L p F P
0 g
s
.381 0 0 r
.25441 .44518 m .24908 .44283 L .25488 .44489 L p F P
0 g
s
.381 0 0 r
.25536 .44553 m .25441 .44518 L p .25488 .44489 L F P
0 g
s
.381 0 0 r
.25488 .44489 m .25797 .44624 L .25536 .44553 L p F P
0 g
s
.597 .024 0 r
.21805 .42892 m .21589 .4274 L .21268 .42653 L p F P
0 g
s
.137 0 .098 r
.6666 .38999 m .66762 .38731 L .66344 .38997 L p F P
0 g
s
.137 0 .098 r
.65814 .39537 m .6666 .38999 L p .66344 .38997 L F P
0 g
s
.203 .727 .731 r
.5246 .45896 m .52596 .4587 L .51618 .46107 L p F P
0 g
s
.203 .727 .731 r
.51618 .46107 m .51413 .46145 L .5246 .45896 L p F P
0 g
s
0 0 0 r
.51413 .46145 m .51618 .46107 L p .50381 .46365 L F P
0 g
s
.765 .261 .008 r
.18292 .40781 m .18312 .40805 L .18789 .41053 L p F P
0 g
s
.715 .182 0 r
.18616 .4111 m .19091 .41359 L .18789 .41053 L p F P
0 g
s
.715 .182 0 r
.18789 .41053 m .18312 .40805 L .18616 .4111 L p F P
0 g
s
.367 .663 .971 r
.21345 .30195 m .22062 .30255 L .2252 .30522 L p F P
0 g
s
.355 .652 .968 r
.22062 .30255 m .21345 .30195 L .21036 .2992 L p F P
0 g
s
.805 .735 .787 r
.12376 .30414 m .12725 .30709 L .13345 .30072 L p F P
0 g
s
.805 .735 .787 r
.12365 .304 m .12376 .30414 L p .13345 .30072 L F P
0 g
s
.805 .735 .787 r
.13345 .30072 m .1299 .29762 L .12365 .304 L p F P
0 g
s
.789 .737 .804 r
.13345 .30072 m .13659 .29788 L .13346 .29443 L p F P
0 g
s
.789 .737 .804 r
.13346 .29443 m .1299 .29762 L .13345 .30072 L p F P
0 g
s
.718 .884 .957 r
.61588 .30072 m .61464 .29994 L .62154 .29658 L closepath p F P
0 g
s
.137 .679 .83 r
.41901 .47223 m .41711 .47202 L .41112 .47224 L closepath p F P
0 g
s
.154 .689 .846 r
.41444 .47171 m .41711 .47202 L .41112 .47224 L p F P
0 g
s
.154 .689 .846 r
.41383 .4717 m .41444 .47171 L p .41112 .47224 L F P
0 g
s
.154 .689 .846 r
.40474 .47201 m .41383 .4717 L p .41112 .47224 L F P
0 g
s
.154 .689 .846 r
.41112 .47224 m .40642 .47223 L .40474 .47201 L p F P
0 g
s
.173 .704 .848 r
.42305 .47214 m .41901 .47223 L .41711 .47202 L p F P
0 g
s
.755 .734 .833 r
.14401 .29268 m .13659 .29788 L .13346 .29443 L p F P
0 g
s
.116 .662 .827 r
.40642 .47223 m .40474 .47201 L .40001 .47207 L closepath p F P
0 g
s
.701 .801 .927 r
.64917 .29021 m .64076 .29381 L .64746 .28848 L closepath p F P
0 g
s
.701 .822 .94 r
.64677 .28779 m .64746 .28848 L .64076 .29381 L p F P
0 g
s
.701 .822 .94 r
.63684 .2923 m .64677 .28779 L p .64076 .29381 L F P
0 g
s
.178 0 0 r
.29745 .45824 m .29171 .45676 L .2984 .45847 L p F P
0 g
s
.178 0 0 r
.2984 .45847 m .30049 .45901 L .29745 .45824 L p F P
0 g
s
.139 .561 .926 r
.24063 .31146 m .24183 .31176 L .24648 .31438 L p F P
0 g
s
.169 .593 .938 r
.24846 .31334 m .24183 .31176 L .24648 .31438 L p F P
0 g
s
.169 .593 .938 r
.25137 .31478 m .24846 .31334 L p .24648 .31438 L F P
0 g
s
.169 .593 .938 r
.24648 .31438 m .25267 .31565 L .25137 .31478 L p F P
0 g
s
.158 .695 .832 r
.4313 .4719 m .42949 .47174 L .42305 .47214 L closepath p F P
0 g
s
.173 .704 .848 r
.42687 .47148 m .42949 .47174 L .42305 .47214 L p F P
0 g
s
.173 .704 .848 r
.42609 .4715 m .42687 .47148 L p .42305 .47214 L F P
0 g
s
.173 .704 .848 r
.41711 .47202 m .42609 .4715 L p .42305 .47214 L F P
0 g
s
.292 0 0 r
.27385 .45154 m .27315 .45136 L .27245 .45111 L closepath p F P
0 g
s
.384 0 0 r
.41925 .35538 m .41727 .35631 L .41108 .35542 L closepath p F P
0 g
s
.371 0 0 r
.41661 .35667 m .41727 .35631 L .41108 .35542 L p F P
0 g
s
.371 0 0 r
.40772 .35665 m .41661 .35667 L p .41108 .35542 L F P
0 g
s
.371 0 0 r
.4049 .35612 m .40772 .35665 L p .41108 .35542 L F P
0 g
s
.371 0 0 r
.41108 .35542 m .40667 .35539 L .4049 .35612 L p F P
0 g
s
.134 .673 .843 r
.4019 .47162 m .40474 .47201 L .40001 .47207 L p F P
0 g
s
.134 .673 .843 r
.39238 .47171 m .4019 .47162 L p .40001 .47207 L F P
0 g
s
.134 .673 .843 r
.40001 .47207 m .3935 .47188 L .39238 .47171 L p F P
0 g
s
.232 .747 .74 r
.53578 .45607 m .53804 .45562 L .52777 .45834 L p F P
0 g
s
.232 .747 .74 r
.52777 .45834 m .52596 .4587 L .53578 .45607 L p F P
0 g
s
.406 0 0 r
.40667 .35539 m .4049 .35612 L .40007 .3552 L closepath p F P
0 g
s
0 0 0 r
.51115 .33954 m .51312 .33865 L .50299 .34166 L p F P
0 g
s
0 0 0 r
.50299 .34166 m .50138 .34235 L .51115 .33954 L p F P
0 g
s
.342 0 0 r
.42317 .35525 m .41925 .35538 L .41727 .35631 L p F P
0 g
s
0 0 0 r
.64659 .40586 m .64698 .40532 L .63824 .41024 L p F P
0 g
s
0 0 0 r
.63824 .41024 m .63673 .41235 L .64659 .40586 L p F P
0 g
s
.454 0 0 r
.34052 .34651 m .34166 .34695 L .34907 .34848 L p F P
0 g
s
.428 0 0 r
.34723 .34908 m .34166 .34695 L .34907 .34848 L p F P
0 g
s
.428 0 0 r
.35133 .34982 m .34723 .34908 L p .34907 .34848 L F P
0 g
s
.428 0 0 r
.34907 .34848 m .35274 .34966 L .35133 .34982 L p F P
0 g
s
0 0 0 r
.62782 .41707 m .62687 .41816 L .63649 .4125 L closepath p F P
0 g
s
.393 0 0 r
.31318 .33879 m .31537 .33967 L .32188 .34154 L p F P
0 g
s
.352 0 0 r
.31318 .33879 m .31537 .33967 L .31107 .33828 L closepath p F P
0 g
s
.354 0 0 r
.32082 .34181 m .31537 .33967 L .32188 .34154 L p F P
0 g
s
.354 0 0 r
.32349 .3425 m .32082 .34181 L p .32188 .34154 L F P
0 g
s
.354 0 0 r
.32188 .34154 m .32533 .34272 L .32349 .3425 L p F P
0 g
s
.354 0 0 r
.43146 .35493 m .42966 .35585 L .42317 .35525 L closepath p F P
0 g
s
.342 0 0 r
.42891 .3563 m .42966 .35585 L .42317 .35525 L p F P
0 g
s
.342 0 0 r
.4195 .3566 m .42891 .3563 L p .42317 .35525 L F P
0 g
s
.342 0 0 r
.41727 .35631 m .4195 .3566 L p .42317 .35525 L F P
0 g
s
.192 .718 .849 r
.43605 .47167 m .4313 .4719 L .42949 .47174 L p F P
0 g
s
.794 .304 .039 r
.16691 .39708 m .17141 .3997 L .16909 .39641 L p F P
0 g
s
.794 .304 .039 r
.16504 .39442 m .16691 .39708 L p .16909 .39641 L F P
0 g
s
.794 .304 .039 r
.16909 .39641 m .16629 .39478 L .16504 .39442 L p F P
0 g
s
.094 .644 .822 r
.3935 .47188 m .39238 .47171 L .38955 .47167 L closepath p F P
0 g
s
.391 0 0 r
.40392 .35659 m .4049 .35612 L .40007 .3552 L p F P
0 g
s
.391 0 0 r
.39695 .35633 m .40392 .35659 L p .40007 .3552 L F P
0 g
s
.391 0 0 r
.39256 .35527 m .39695 .35633 L p .40007 .3552 L F P
0 g
s
.391 0 0 r
.40007 .3552 m .39365 .3549 L .39256 .35527 L p F P
0 g
s
.005 .499 .866 r
.25573 .31769 m .25816 .31842 L .26319 .32088 L p F P
0 g
s
.049 .539 .886 r
.26437 .32019 m .25816 .31842 L .26319 .32088 L p F P
0 g
s
.049 .539 .886 r
.26517 .32054 m .26437 .32019 L p .26319 .32088 L F P
0 g
s
.049 .539 .886 r
.26319 .32088 m .26778 .32204 L .26517 .32054 L p F P
0 g
s
.507 .438 .713 r
.70078 .31399 m .70519 .31001 L .70683 .31583 L closepath p F P
0 g
s
.195 0 .239 r
.68563 .37006 m .68567 .3699 L .67747 .37575 L p F P
0 g
s
.195 0 .239 r
.68124 .37566 m .68563 .37006 L p .67747 .37575 L F P
0 g
s
.195 0 .239 r
.67747 .37575 m .67679 .37882 L .68124 .37566 L p F P
0 g
s
.621 .054 0 r
.2078 .42425 m .20405 .42141 L .20909 .42378 L p F P
0 g
s
.621 .054 0 r
.21244 .42646 m .2078 .42425 L p .20909 .42378 L F P
0 g
s
.621 .054 0 r
.20909 .42378 m .21268 .42653 L .21244 .42646 L p F P
0 g
s
.87 .709 .68 r
.1179 .32268 m .12157 .32572 L .12386 .32083 L p F P
0 g
s
.87 .709 .68 r
.12386 .32083 m .12021 .31779 L .1179 .32268 L p F P
0 g
s
.82 .73 .766 r
.12725 .30709 m .12376 .30414 L .12677 .30766 L closepath p F P
0 g
s
.01 .581 .769 r
.36772 .47017 m .37025 .47032 L .37958 .47111 L p F P
0 g
s
.018 .586 .777 r
.36772 .47017 m .37025 .47032 L .36656 .47 L closepath p F P
0 g
s
0 .505 .746 r
.32825 .4649 m .32793 .46483 L .32746 .46475 L closepath p F P
0 g
s
.458 .886 .83 r
.55686 .32204 m .55804 .32188 L .54823 .32615 L p F P
0 g
s
.458 .886 .83 r
.54823 .32615 m .54761 .32625 L .55686 .32204 L p F P
0 g
s
.841 .729 .741 r
.12326 .31262 m .12677 .30766 L .12376 .30414 L p F P
0 g
s
.282 0 0 r
.27005 .45048 m .26638 .44916 L .27245 .45111 L p F P
0 g
s
.282 0 0 r
.27245 .45111 m .27315 .45136 L .27005 .45048 L p F P
0 g
s
.114 .657 .839 r
.38952 .47124 m .39238 .47171 L .38955 .47167 L p F P
0 g
s
.114 .657 .839 r
.38004 .47113 m .38952 .47124 L p .38955 .47167 L F P
0 g
s
.114 .657 .839 r
.38955 .47167 m .38025 .47116 L .38004 .47113 L p F P
0 g
s
.177 .71 .834 r
.44332 .47127 m .44188 .47117 L .43605 .47167 L closepath p F P
0 g
s
.192 .718 .849 r
.43911 .47095 m .44188 .47117 L .43605 .47167 L p F P
0 g
s
.192 .718 .849 r
.42949 .47174 m .43911 .47095 L p .43605 .47167 L F P
0 g
s
0 0 0 r
.5581 .44948 m .5605 .44871 L .55066 .45186 L p F P
0 g
s
0 0 0 r
.55066 .45186 m .54815 .45267 L .5581 .44948 L p F P
0 g
s
0 0 0 r
.54815 .45267 m .55066 .45186 L p .53832 .45554 L F P
0 g
s
.906 .604 .464 r
.12957 .3561 m .1335 .35898 L .13332 .35499 L p F P
0 g
s
.906 .604 .464 r
.13332 .35499 m .12938 .3521 L .12957 .3561 L p F P
0 g
s
.279 .768 .697 r
.53335 .33142 m .53532 .33078 L .52565 .3344 L p F P
0 g
s
.279 .768 .697 r
.52565 .3344 m .52354 .3351 L .53335 .33142 L p F P
0 g
s
.903 .574 .413 r
.13404 .36286 m .13803 .36571 L .1375 .36184 L p F P
0 g
s
.903 .574 .413 r
.1375 .36184 m .1335 .35898 L .13404 .36286 L p F P
0 g
s
.024 0 0 r
.65643 .39873 m .65694 .39786 L .64834 .40301 L p F P
0 g
s
.024 0 0 r
.6497 .4037 m .65643 .39873 L p .64834 .40301 L F P
0 g
s
.024 0 0 r
.64834 .40301 m .64698 .40532 L .6497 .4037 L p F P
0 g
s
0 .514 .761 r
.32494 .46411 m .32007 .46329 L .32746 .46475 L p F P
0 g
s
0 .514 .761 r
.32746 .46475 m .32793 .46483 L .32494 .46411 L p F P
0 g
s
.096 0 0 r
.47942 .34782 m .47926 .34789 L .47803 .34807 L closepath p F P
0 g
s
.112 0 0 r
.47702 .3492 m .47926 .34789 L .47803 .34807 L p F P
0 g
s
.112 0 0 r
.47315 .34988 m .47702 .3492 L p .47803 .34807 L F P
0 g
s
.112 0 0 r
.46687 .3507 m .47315 .34988 L p .47803 .34807 L F P
0 g
s
.304 0 0 r
.43676 .35455 m .43146 .35493 L .42966 .35585 L p F P
0 g
s
.597 .576 .801 r
.69934 .29426 m .6932 .30003 L p .68888 .29498 L F P
0 g
s
.573 .55 .791 r
.6932 .30003 m .69934 .29426 L .70156 .29964 L closepath p F P
0 g
s
.721 .847 .941 r
.63684 .2923 m .62693 .29687 L .62453 .29513 L p F P
0 g
s
.417 0 0 r
.39365 .3549 m .39256 .35527 L .38992 .35467 L closepath p F P
0 g
s
0 0 0 r
.61709 .42352 m .617 .42361 L .61806 .42305 L closepath p F P
0 g
s
.905 .632 .513 r
.12551 .34919 m .12938 .3521 L .12958 .34798 L p F P
0 g
s
.905 .632 .513 r
.12958 .34798 m .12571 .34506 L .12551 .34919 L p F P
0 g
s
.897 .541 .359 r
.13889 .36947 m .14294 .3723 L .14208 .36853 L p F P
0 g
s
.897 .541 .359 r
.14208 .36853 m .13803 .36571 L .13889 .36947 L p F P
0 g
s
0 0 0 r
.58267 .44047 m .58284 .44039 L .57323 .44401 L p F P
0 g
s
0 0 0 r
.57323 .44401 m .57281 .44421 L .58267 .44047 L p F P
0 g
s
0 .474 .807 r
.27984 .32671 m .27461 .32504 L .28008 .32732 L p F P
0 g
s
0 .474 .807 r
.28008 .32732 m .2829 .32813 L .27984 .32671 L p F P
0 g
s
.432 0 0 r
.34052 .34651 m .34166 .34695 L .3397 .3465 L closepath p F P
0 g
s
0 .477 .856 r
.25816 .31842 m .25573 .31769 L .25267 .31565 L p F P
0 g
s
.048 0 0 r
.48898 .34609 m .49009 .34551 L .47942 .34782 L p F P
0 g
s
.048 0 0 r
.47942 .34782 m .47926 .34789 L .48898 .34609 L p F P
0 g
s
.451 0 0 r
.38024 .35381 m .38049 .35388 L .38992 .35467 L p F P
0 g
s
.432 0 0 r
.38699 .35572 m .38049 .35388 L .38992 .35467 L p F P
0 g
s
.432 0 0 r
.39077 .35599 m .38699 .35572 L p .38992 .35467 L F P
0 g
s
.432 0 0 r
.38992 .35467 m .39256 .35527 L .39077 .35599 L p F P
0 g
s
0 0 0 r
.61806 .42305 m .617 .42361 L .61518 .42527 L p F P
0 g
s
0 .547 .788 r
.33629 .466 m .32793 .46483 L .32494 .46411 L p F P
0 g
s
.21 .732 .849 r
.45046 .47073 m .44332 .47127 L .44188 .47117 L p F P
0 g
s
.312 0 0 r
.44331 .35407 m .44206 .35473 L .43676 .35455 L closepath p F P
0 g
s
.304 0 0 r
.44085 .3555 m .44206 .35473 L .43676 .35455 L p F P
0 g
s
.304 0 0 r
.43268 .35605 m .44085 .3555 L p .43676 .35455 L F P
0 g
s
.304 0 0 r
.42966 .35585 m .43268 .35605 L p .43676 .35455 L F P
0 g
s
.607 .948 .922 r
.57781 .31247 m .58019 .31271 L .57035 .31739 L p F P
0 g
s
.607 .948 .922 r
.57035 .31739 m .56901 .31734 L .57781 .31247 L p F P
0 g
s
0 .405 .711 r
.29856 .33393 m .29804 .33374 L .29749 .33358 L closepath p F P
0 g
s
.901 .657 .56 r
.12189 .3421 m .12571 .34506 L .12634 .34078 L p F P
0 g
s
.901 .657 .56 r
.12634 .34078 m .12253 .33782 L .12189 .3421 L p F P
0 g
s
0 0 0 r
.50381 .46365 m .50732 .46291 L .51413 .46145 L p F P
0 g
s
.179 .711 .73 r
.50381 .46365 m .50732 .46291 L .50348 .46371 L closepath p F P
0 g
s
.886 .5 .299 r
.1441 .37596 m .14294 .3723 L .14705 .37509 L p F P
0 g
s
.886 .5 .299 r
.14442 .37618 m .1441 .37596 L p .14705 .37509 L F P
0 g
s
.886 .5 .299 r
.14705 .37509 m .14756 .37666 L .14442 .37618 L p F P
0 g
s
.744 .738 .846 r
.14401 .29268 m .14609 .29133 L .14296 .28798 L p F P
0 g
s
.744 .738 .846 r
.14296 .28798 m .1405 .28956 L .14401 .29268 L p F P
0 g
s
.755 .734 .833 r
.13346 .29443 m .1405 .28956 L .14401 .29268 L p F P
0 g
s
.244 0 0 r
.27876 .45315 m .27315 .45136 L .27005 .45048 L p F P
0 g
s
.072 .626 .817 r
.38025 .47116 m .38004 .47113 L .37958 .47111 L closepath p F P
0 g
s
.656 .728 .902 r
.15852 .2901 m .16771 .28699 L .17082 .29019 L p F P
0 g
s
.652 .727 .904 r
.16771 .28699 m .15852 .2901 L .1554 .28681 L p F P
0 g
s
.705 .735 .874 r
.14609 .29133 m .1554 .28681 L .15852 .2901 L p F P
0 g
s
.087 .635 .832 r
.37715 .47058 m .37025 .47032 L .37958 .47111 L p F P
0 g
s
.087 .635 .832 r
.37958 .47111 m .38004 .47113 L .37715 .47058 L p F P
0 g
s
0 0 0 r
.62687 .41816 m .61806 .42305 L .6261 .41902 L closepath p F P
0 g
s
0 0 0 r
.62459 .42041 m .6261 .41902 L .61806 .42305 L p F P
0 g
s
0 0 0 r
.62022 .42277 m .62459 .42041 L p .61806 .42305 L F P
0 g
s
0 0 0 r
.61518 .42527 m .62022 .42277 L p .61806 .42305 L F P
0 g
s
.32 .114 .437 r
.6945 .35696 m .69163 .35916 L .69311 .35435 L p F P
0 g
s
.32 .114 .437 r
.69311 .35435 m .69461 .3532 L .6945 .35696 L p F P
0 g
s
.119 0 0 r
.48772 .34689 m .48898 .34609 L .47926 .34789 L p F P
0 g
s
.119 0 0 r
.47926 .34789 m .47702 .3492 L .48772 .34689 L p F P
0 g
s
.542 .497 .755 r
.69908 .30628 m .70279 .30286 L .70414 .30675 L closepath p F P
0 g
s
.458 .682 .962 r
.19827 .29643 m .20279 .29645 L .20698 .29928 L p F P
0 g
s
.448 .675 .96 r
.20279 .29645 m .19827 .29643 L .19517 .29349 L p F P
0 g
s
.407 .277 .589 r
.70916 .33223 m .70204 .33842 L .70144 .33372 L p F P
0 g
s
.407 .277 .589 r
.70144 .33372 m .70735 .32856 L .70916 .33223 L p F P
0 g
s
.681 .133 0 r
.19417 .41659 m .19091 .41359 L .19572 .41606 L p F P
0 g
s
.681 .133 0 r
.19514 .41709 m .19417 .41659 L p .19572 .41606 L F P
0 g
s
.681 .133 0 r
.19572 .41606 m .19773 .41789 L .19514 .41709 L p F P
0 g
s
.775 .273 0 r
.17397 .4029 m .17851 .40549 L .17596 .40228 L p F P
0 g
s
.775 .273 0 r
.17596 .40228 m .17141 .3997 L .17397 .4029 L p F P
0 g
s
.477 .694 .963 r
.20727 .29642 m .20279 .29645 L .20698 .29928 L p F P
0 g
s
.477 .694 .963 r
.20698 .29928 m .21036 .2992 L .20727 .29642 L p F P
0 g
s
.061 0 0 r
.66624 .39074 m .6666 .38999 L .65814 .39537 L p F P
0 g
s
.061 0 0 r
.66018 .39581 m .66624 .39074 L p .65814 .39537 L F P
0 g
s
.061 0 0 r
.65814 .39537 m .65694 .39786 L .66018 .39581 L p F P
0 g
s
0 .403 .706 r
.29499 .3327 m .29149 .33151 L .29749 .33358 L p F P
0 g
s
0 .403 .706 r
.29749 .33358 m .29804 .33374 L .29499 .3327 L p F P
0 g
s
.12 .659 .848 r
.38952 .47124 m .38004 .47113 L .37715 .47058 L p F P
0 g
s
.664 .95 .955 r
.58133 .31293 m .58019 .31271 L .58929 .30818 L closepath p F P
0 g
s
.699 .937 .963 r
.60234 .30361 m .59248 .30848 L .59004 .30781 L p F P
0 g
s
.703 .735 .876 r
.1554 .28681 m .14609 .29133 L .14296 .28798 L p F P
0 g
s
.439 0 0 r
.38024 .35381 m .38049 .35388 L .38013 .35385 L closepath p F P
0 g
s
.256 0 0 r
.45266 .35303 m .44331 .35407 L .44206 .35473 L p F P
0 g
s
0 0 0 r
.6147 .42563 m .61518 .42527 L .60602 .42955 L p F P
0 g
s
0 0 0 r
.60602 .42955 m .60481 .43045 L .6147 .42563 L p F P
0 g
s
.196 .724 .834 r
.45509 .47035 m .45427 .47031 L .45046 .47073 L closepath p F P
0 g
s
.21 .732 .849 r
.45152 .47013 m .45427 .47031 L .45046 .47073 L p F P
0 g
s
.21 .732 .849 r
.44188 .47117 m .45152 .47013 L p .45046 .47073 L F P
0 g
s
.863 .441 .216 r
.14989 .38224 m .15413 .38497 L .15254 .38145 L p F P
0 g
s
.863 .441 .216 r
.15254 .38145 m .14829 .37873 L .14989 .38224 L p F P
0 g
s
0 .45 .712 r
.30574 .46019 m .30049 .45901 L .29745 .45824 L p F P
0 g
s
.894 .678 .603 r
.11878 .33483 m .12253 .33782 L .12364 .33337 L p F P
0 g
s
.894 .678 .603 r
.12364 .33337 m .1199 .33037 L .11878 .33483 L p F P
0 g
s
.158 .564 .931 r
.24063 .31146 m .24183 .31176 L .23801 .30948 L closepath p F P
0 g
s
.597 .576 .801 r
.68888 .29498 m .69905 .29359 L .69934 .29426 L p F P
0 g
s
.612 .6 .815 r
.69905 .29359 m .68888 .29498 L .68643 .29027 L p F P
0 g
s
.599 .717 .927 r
.17082 .29019 m .1773 .28884 L .18134 .29174 L p F P
0 g
s
.594 .714 .927 r
.1773 .28884 m .17082 .29019 L .16771 .28699 L p F P
0 g
s
.45 0 0 r
.37773 .35486 m .38699 .35572 L .38049 .35388 L p F P
0 g
s
.45 0 0 r
.3773 .35471 m .37773 .35486 L p .38049 .35388 L F P
0 g
s
.45 0 0 r
.38049 .35388 m .38013 .35385 L .3773 .35471 L p F P
0 g
s
0 0 0 r
.52302 .33533 m .52354 .3351 L .51376 .33837 L p F P
0 g
s
0 0 0 r
.51376 .33837 m .51312 .33865 L .52302 .33533 L p F P
0 g
s
.464 0 0 r
.38013 .35385 m .3773 .35471 L .37146 .35294 L closepath p F P
0 g
s
.257 .768 .807 r
.50732 .46291 m .50348 .46371 L .50118 .46388 L p F P
0 g
s
.841 .729 .741 r
.11969 .30953 m .12326 .31262 L p .12376 .30414 L F P
0 g
s
.857 .722 .713 r
.11663 .31471 m .12021 .31779 L .12326 .31262 L p F P
0 g
s
.857 .722 .713 r
.12326 .31262 m .11969 .30953 L .11663 .31471 L p F P
0 g
s
.45 0 0 r
.33984 .34752 m .34723 .34908 L .34166 .34695 L p F P
0 g
s
.45 0 0 r
.33752 .3465 m .33984 .34752 L p .34166 .34695 L F P
0 g
s
.45 0 0 r
.34166 .34695 m .3397 .3465 L .33752 .3465 L p F P
0 g
s
0 0 0 r
.5803 .44153 m .58267 .44047 L .57281 .44421 L p F P
0 g
s
0 0 0 r
.57281 .44421 m .57068 .44516 L .5803 .44153 L p F P
0 g
s
.4 .68 .974 r
.22608 .3057 m .22551 .30523 L .2252 .30522 L closepath p F P
0 g
s
0 .454 .73 r
.29635 .45795 m .29745 .45824 L .29171 .45676 L p F P
0 g
s
0 .454 .73 r
.29214 .45681 m .29635 .45795 L p .29171 .45676 L F P
0 g
s
0 .454 .73 r
.28527 .45508 m .29214 .45681 L p .29171 .45676 L F P
0 g
s
0 .454 .73 r
.29171 .45676 m .28546 .45513 L .28527 .45508 L p F P
0 g
s
.394 0 0 r
.30285 .33573 m .29804 .33374 L .29499 .3327 L p F P
0 g
s
.46 .887 .828 r
.55554 .32222 m .55686 .32204 L .54761 .32625 L p F P
0 g
s
.46 .887 .828 r
.54761 .32625 m .54571 .32659 L .55554 .32222 L p F P
0 g
s
.405 0 0 r
.23237 .43638 m .2378 .43859 L .23302 .43607 L p F P
0 g
s
.405 0 0 r
.22772 .43398 m .23237 .43638 L p .23302 .43607 L F P
0 g
s
.405 0 0 r
.23302 .43607 m .22798 .43407 L .22772 .43398 L p F P
0 g
s
.229 .749 .798 r
.49992 .46397 m .50118 .46388 L .49143 .4658 L p F P
0 g
s
.229 .749 .798 r
.49143 .4658 m .48904 .46596 L .49992 .46397 L p F P
0 g
s
.229 .746 .849 r
.46394 .46902 m .46664 .46917 L .45509 .47035 L p F P
0 g
s
.229 .746 .849 r
.45509 .47035 m .45427 .47031 L .46394 .46902 L p F P
0 g
s
0 0 0 r
.60391 .43111 m .60481 .43045 L .59494 .43494 L p F P
0 g
s
0 0 0 r
.59494 .43494 m .59461 .43518 L .60391 .43111 L p F P
0 g
s
.816 .343 .084 r
.16629 .39478 m .16504 .39442 L .16462 .39379 L closepath p F P
0 g
s
.111 .65 .851 r
.37511 .47018 m .37715 .47058 L .37025 .47032 L p F P
0 g
s
.111 .65 .851 r
.37239 .46993 m .37511 .47018 L p .37025 .47032 L F P
0 g
s
.111 .65 .851 r
.36481 .46963 m .37239 .46993 L p .37025 .47032 L F P
0 g
s
.111 .65 .851 r
.37025 .47032 m .36656 .47 L .36481 .46963 L p F P
0 g
s
.439 0 0 r
.24282 .44051 m .24333 .44076 L .24908 .44283 L p F P
0 g
s
.356 0 0 r
.24873 .44308 m .25441 .44518 L .24908 .44283 L p F P
0 g
s
.356 0 0 r
.24908 .44283 m .24333 .44076 L .24873 .44308 L p F P
0 g
s
.607 .721 .925 r
.17992 .28827 m .1773 .28884 L .18134 .29174 L p F P
0 g
s
.607 .721 .925 r
.18134 .29174 m .18303 .29136 L .17992 .28827 L p F P
0 g
s
.379 0 0 r
.31427 .33994 m .32082 .34181 L .31537 .33967 L p F P
0 g
s
.379 0 0 r
.31015 .33807 m .31427 .33994 L p .31537 .33967 L F P
0 g
s
.379 0 0 r
.31537 .33967 m .31107 .33828 L .31015 .33807 L p F P
0 g
s
0 .54 .791 r
.32256 .46352 m .32494 .46411 L .32007 .46329 L p F P
0 g
s
0 .54 .791 r
.32106 .46321 m .32256 .46352 L p .32007 .46329 L F P
0 g
s
0 .54 .791 r
.31269 .46182 m .32106 .46321 L p .32007 .46329 L F P
0 g
s
0 .54 .791 r
.32007 .46329 m .3127 .46182 L .31269 .46182 L p F P
0 g
s
.711 .903 .964 r
.62154 .29658 m .61464 .29994 L .61222 .29866 L p F P
0 g
s
.764 .257 0 r
.18292 .40781 m .18312 .40805 L .18246 .4077 L closepath p F P
0 g
s
.597 .024 0 r
.21268 .42653 m .21282 .42663 L .21805 .42892 L p F P
0 g
s
.519 0 0 r
.21712 .42929 m .2223 .4316 L .21805 .42892 L p F P
0 g
s
.519 0 0 r
.21805 .42892 m .21282 .42663 L .21712 .42929 L p F P
0 g
s
.425 0 0 r
.3397 .3465 m .33752 .3465 L .33438 .34536 L closepath p F P
0 g
s
.141 .676 .852 r
.4019 .47162 m .39238 .47171 L .38952 .47124 L p F P
0 g
s
.845 .399 .154 r
.15599 .38841 m .16028 .39111 L .15842 .38768 L p F P
0 g
s
.845 .399 .154 r
.15842 .38768 m .15413 .38497 L .15599 .38841 L p F P
0 g
s
.673 .712 .878 r
.66153 .28905 m .67153 .28545 L .67394 .28897 L p F P
0 g
s
.684 .736 .89 r
.67153 .28545 m .66153 .28905 L .65913 .28612 L p F P
0 g
s
.694 .759 .902 r
.64917 .29021 m .65913 .28612 L .66153 .28905 L p F P
0 g
s
.402 .679 .973 r
.22242 .30268 m .22062 .30255 L .2252 .30522 L p F P
0 g
s
.402 .679 .973 r
.2252 .30522 m .22551 .30523 L .22242 .30268 L p F P
0 g
s
.066 .617 .827 r
.36656 .47 m .36481 .46963 L .36128 .46941 L closepath p F P
0 g
s
.3 .1 .432 r
.70044 .35215 m .6945 .35696 L .69461 .3532 L p F P
0 g
s
.3 .1 .432 r
.69461 .3532 m .7018 .34738 L .70044 .35215 L p F P
0 g
s
.885 .697 .644 r
.11622 .32734 m .1199 .33037 L .12157 .32572 L p F P
0 g
s
.885 .697 .644 r
.12157 .32572 m .1179 .32268 L .11622 .32734 L p F P
0 g
s
0 0 0 r
.53832 .45554 m .548 .45272 L .54815 .45267 L p F P
0 g
s
0 0 0 r
.53832 .45554 m .548 .45272 L .53804 .45562 L closepath p F P
0 g
s
.881 .489 .285 r
.14756 .37666 m .14829 .37873 L .14442 .37618 L closepath p F P
0 g
s
.697 .155 0 r
.18147 .40858 m .18616 .4111 L .18312 .40805 L p F P
0 g
s
.697 .155 0 r
.17965 .40673 m .18147 .40858 L p .18312 .40805 L F P
0 g
s
.697 .155 0 r
.18312 .40805 m .18246 .4077 L .17965 .40673 L p F P
0 g
s
.224 .599 .95 r
.23256 .30649 m .22551 .30523 L .22242 .30268 L p F P
0 g
s
.705 .802 .925 r
.65674 .28342 m .65913 .28612 L .64917 .29021 L p F P
0 g
s
.705 .802 .925 r
.64975 .28648 m .65674 .28342 L p .64917 .29021 L F P
0 g
s
.705 .802 .925 r
.64917 .29021 m .64746 .28848 L .64975 .28648 L p F P
0 g
s
0 .557 .779 r
.35246 .46841 m .35249 .46841 L p .3402 .46675 L F P
0 g
s
0 .557 .779 r
.3402 .46675 m .34437 .46723 L .35246 .46841 L p F P
0 g
s
0 .558 .781 r
.3402 .46675 m .34437 .46723 L .33781 .46626 L closepath p F P
0 g
s
.259 0 0 r
.45482 .35279 m .45447 .35299 L .45266 .35303 L closepath p F P
0 g
s
.256 0 0 r
.45245 .35429 m .45447 .35299 L .45266 .35303 L p F P
0 g
s
.256 0 0 r
.448 .35475 m .45245 .35429 L p .45266 .35303 L F P
0 g
s
.256 0 0 r
.44206 .35473 m .448 .35475 L p .45266 .35303 L F P
0 g
s
.186 0 0 r
.46687 .3507 m .47315 .34988 L .46607 .35119 L closepath p F P
0 g
s
.244 .759 .791 r
.51413 .46145 m .51358 .46151 L .50732 .46291 L closepath p F P
0 g
s
.257 .768 .807 r
.51097 .46173 m .51358 .46151 L .50732 .46291 L p F P
0 g
s
.257 .768 .807 r
.50118 .46388 m .51097 .46173 L p .50732 .46291 L F P
0 g
s
.282 0 0 r
.26633 .44934 m .26036 .44719 L .26638 .44916 L p F P
0 g
s
.282 0 0 r
.26761 .44977 m .26633 .44934 L p .26638 .44916 L F P
0 g
s
.282 0 0 r
.26638 .44916 m .27005 .45048 L .26761 .44977 L p F P
0 g
s
.346 0 0 r
.25797 .44624 m .26036 .44719 L .26638 .44916 L p F P
0 g
s
.129 .549 .921 r
.24362 .31079 m .24846 .31334 L .24183 .31176 L p F P
0 g
s
.129 .549 .921 r
.23755 .30914 m .24362 .31079 L p .24183 .31176 L F P
0 g
s
.129 .549 .921 r
.24183 .31176 m .23801 .30948 L .23755 .30914 L p F P
0 g
s
.339 0 0 r
.25797 .44624 m .26036 .44719 L .25536 .44553 L closepath p F P
0 g
s
.099 0 .078 r
.6687 .38859 m .6666 .38999 L .66762 .38731 L p F P
0 g
s
.099 0 .078 r
.66762 .38731 m .67572 .38187 L .6687 .38859 L p F P
0 g
s
.647 .663 .851 r
.6858 .28915 m .68392 .29088 L p .67394 .28897 L F P
0 g
s
.647 .663 .851 r
.67394 .28897 m .684 .28603 L .6858 .28915 L p F P
0 g
s
.66 .687 .865 r
.684 .28603 m .67394 .28897 L .67153 .28545 L p F P
0 g
s
.451 0 0 r
.37708 .35479 m .3773 .35471 L .37146 .35294 L p F P
0 g
s
.451 0 0 r
.36887 .35385 m .37708 .35479 L p .37146 .35294 L F P
0 g
s
.451 0 0 r
.365 .35243 m .36887 .35385 L p .37146 .35294 L F P
0 g
s
.451 0 0 r
.37146 .35294 m .36607 .35221 L .365 .35243 L p F P
0 g
s
.206 .733 .798 r
.47905 .46763 m .48688 .46631 L .47793 .46768 L closepath p F P
0 g
s
.157 .699 .767 r
.47793 .46768 m .47905 .46763 L p .46666 .46917 L F P
0 g
s
.23 0 .311 r
.68586 .36976 m .68567 .3699 L .68615 .3666 L p F P
0 g
s
.23 0 .311 r
.68615 .3666 m .68919 .3643 L .68586 .36976 L p F P
0 g
s
.441 .331 .633 r
.70913 .32698 m .70735 .32856 L .70429 .32534 L p F P
0 g
s
.441 .331 .633 r
.70429 .32534 m .70821 .32186 L .70913 .32698 L p F P
0 g
s
.224 0 0 r
.46414 .35239 m .46607 .35119 L .45482 .35279 L p F P
0 g
s
.224 0 0 r
.45482 .35279 m .45447 .35299 L .46414 .35239 L p F P
0 g
s
0 .477 .856 r
.25267 .31565 m .25334 .31588 L .25816 .31842 L p F P
0 g
s
0 .484 .862 r
.25918 .31778 m .26437 .32019 L .25816 .31842 L p F P
0 g
s
0 .484 .862 r
.25816 .31842 m .25334 .31588 L .25918 .31778 L p F P
0 g
s
.159 .691 .853 r
.41383 .4717 m .40474 .47201 L .4019 .47162 L p F P
0 g
s
0 0 0 r
.60245 .43196 m .60391 .43111 L .59461 .43518 L p F P
0 g
s
0 0 0 r
.59461 .43518 m .59255 .43639 L .60245 .43196 L p F P
0 g
s
.532 .702 .948 r
.18303 .29136 m .19207 .29052 L .19517 .29349 L p F P
0 g
s
.526 .698 .948 r
.19207 .29052 m .18303 .29136 L .17992 .28827 L p F P
0 g
s
.734 .209 0 r
.18246 .4077 m .17965 .40673 L .17851 .40549 L closepath p F P
0 g
s
.44 0 0 r
.39256 .35527 m .39695 .35633 L .39077 .35599 L closepath p F P
0 g
s
.599 .028 0 r
.20285 .42185 m .2078 .42425 L .20405 .42141 L p F P
0 g
s
.599 .028 0 r
.20405 .42141 m .19907 .41902 L .20285 .42185 L p F P
0 g
s
.659 .105 0 r
.19773 .41789 m .19907 .41902 L .20405 .42141 L p F P
0 g
s
.631 .65 .85 r
.68392 .29088 m .6858 .28915 L .68643 .29027 L closepath p F P
0 g
s
.333 .805 .725 r
.5448 .32685 m .54571 .32659 L .5359 .3306 L p F P
0 g
s
.333 .805 .725 r
.5359 .3306 m .53532 .33078 L .5448 .32685 L p F P
0 g
s
.383 .228 .543 r
.70239 .34277 m .70217 .34295 L .70146 .3389 L p F P
0 g
s
.383 .228 .543 r
.70146 .3389 m .70204 .33842 L .70239 .34277 L p F P
0 g
s
.072 .621 .834 r
.36189 .46899 m .35255 .46842 L .36128 .46941 L p F P
0 g
s
.072 .621 .834 r
.36128 .46941 m .36481 .46963 L .36189 .46899 L p F P
0 g
s
0 .569 .774 r
.35249 .46841 m .35255 .46842 L .36128 .46941 L p F P
0 g
s
.789 .739 .806 r
.1299 .29762 m .13346 .29443 L .13031 .29101 L p F P
0 g
s
.789 .739 .806 r
.13031 .29101 m .12641 .29448 L .1299 .29762 L p F P
0 g
s
.805 .735 .786 r
.1205 .30045 m .12641 .29448 L .1299 .29762 L p F P
0 g
s
.805 .735 .786 r
.1299 .29762 m .12365 .304 L .1205 .30045 L p F P
0 g
s
.816 .342 .076 r
.16173 .39336 m .16028 .39111 L .16462 .39379 L p F P
0 g
s
.816 .342 .076 r
.16462 .39379 m .16504 .39442 L .16173 .39336 L p F P
0 g
s
.267 .771 .754 r
.548 .45272 m .53804 .45562 L .53578 .45607 L p F P
0 g
s
.754 .736 .836 r
.1405 .28956 m .13346 .29443 L .13031 .29101 L p F P
0 g
s
0 .397 .762 r
.26778 .32204 m .26941 .32265 L .27461 .32504 L p F P
0 g
s
0 .437 .778 r
.27498 .32468 m .26941 .32265 L .27461 .32504 L p F P
0 g
s
0 .437 .778 r
.27898 .32631 m .27498 .32468 L p .27461 .32504 L F P
0 g
s
0 .437 .778 r
.27461 .32504 m .27984 .32671 L .27898 .32631 L p F P
0 g
s
.277 0 0 r
.2829 .32813 m .28582 .3293 L .29149 .33151 L p F P
0 g
s
.296 0 0 r
.28582 .3293 m .2829 .32813 L .27984 .32671 L p F P
0 g
s
0 0 0 r
.63649 .4125 m .62687 .41816 L .6261 .41902 L p F P
0 g
s
.434 0 0 r
.32533 .34272 m .32748 .34363 L .32349 .3425 L closepath p F P
0 g
s
.157 .699 .767 r
.46666 .46917 m .46679 .46915 L .47793 .46768 L p F P
0 g
s
.187 .72 .799 r
.46666 .46917 m .46679 .46915 L .46664 .46917 L closepath p F P
0 g
s
0 0 0 r
.52096 .33628 m .52302 .33533 L .51312 .33865 L p F P
0 g
s
0 0 0 r
.51312 .33865 m .51115 .33954 L .52096 .33628 L p F P
0 g
s
.023 0 0 r
.49874 .34382 m .50049 .34284 L .49009 .34551 L p F P
0 g
s
.023 0 0 r
.49009 .34551 m .48898 .34609 L .49874 .34382 L p F P
0 g
s
.246 .746 .683 r
.57036 .44527 m .57068 .44516 L .56091 .44857 L p F P
0 g
s
.246 .746 .683 r
.56091 .44857 m .5605 .44871 L .57036 .44527 L p F P
0 g
s
.471 0 0 r
.35274 .34966 m .35495 .3505 L .35133 .34982 L closepath p F P
0 g
s
.263 .768 .864 r
.46679 .46915 m .46664 .46917 L .46394 .46902 L p F P
0 g
s
.25 .761 .85 r
.47793 .46768 m .47636 .46763 L .46679 .46915 L closepath p F P
0 g
s
.263 .768 .864 r
.4739 .46753 m .47636 .46763 L .46679 .46915 L p F P
0 g
s
.263 .768 .864 r
.47224 .46774 m .4739 .46753 L p .46679 .46915 L F P
0 g
s
.263 .768 .864 r
.46394 .46902 m .47224 .46774 L p .46679 .46915 L F P
0 g
s
.171 .702 .849 r
.41711 .47202 m .42609 .4715 L .41444 .47171 L closepath p F P
0 g
s
.271 .043 .373 r
.69419 .36048 m .68919 .3643 L .69163 .35916 L p F P
0 g
s
.271 .043 .373 r
.69163 .35916 m .6945 .35696 L .69419 .36048 L p F P
0 g
s
.828 .733 .759 r
.12365 .304 m .12363 .30402 L .12376 .30414 L closepath p F P
0 g
s
.841 .729 .741 r
.12376 .30414 m .12363 .30402 L .11969 .30953 L p F P
0 g
s
.431 0 0 r
.33276 .34586 m .32748 .34363 L .33438 .34536 L p F P
0 g
s
.431 0 0 r
.33575 .34653 m .33276 .34586 L p .33438 .34536 L F P
0 g
s
.431 0 0 r
.33438 .34536 m .33752 .3465 L .33575 .34653 L p F P
0 g
s
.454 0 0 r
.36607 .35221 m .365 .35243 L .36302 .35179 L closepath p F P
0 g
s
.367 .216 .54 r
.70985 .33629 m .70239 .34277 L .70204 .33842 L p F P
0 g
s
.367 .216 .54 r
.70204 .33842 m .70916 .33223 L .70985 .33629 L p F P
0 g
s
.873 .713 .681 r
.1143 .31961 m .1179 .32268 L .12021 .31779 L p F P
0 g
s
.873 .713 .681 r
.12021 .31779 m .11663 .31471 L .1143 .31961 L p F P
0 g
s
.72 .828 .932 r
.64677 .28779 m .63684 .2923 L .63444 .29035 L p F P
0 g
s
.721 .847 .941 r
.62453 .29513 m .63444 .29035 L .63684 .2923 L p F P
0 g
s
.829 .735 .761 r
.12363 .30402 m .12365 .304 L .1205 .30045 L p F P
0 g
s
.829 .735 .761 r
.1205 .30045 m .12015 .30088 L .12363 .30402 L p F P
0 g
s
.842 .732 .743 r
.11619 .3064 m .11969 .30953 L .12363 .30402 L p F P
0 g
s
.842 .732 .743 r
.12363 .30402 m .12015 .30088 L .11619 .3064 L p F P
0 g
s
0 .361 .673 r
.29127 .3314 m .28582 .3293 L .29149 .33151 L p F P
0 g
s
0 .361 .673 r
.29262 .33188 m .29127 .3314 L p .29149 .33151 L F P
0 g
s
0 .361 .673 r
.29149 .33151 m .29499 .3327 L .29262 .33188 L p F P
0 g
s
.224 .743 .847 r
.46394 .46902 m .45427 .47031 L .45152 .47013 L p F P
0 g
s
.355 .652 .968 r
.21036 .2992 m .21623 .29981 L .22062 .30255 L p F P
0 g
s
.343 .64 .964 r
.21623 .29981 m .21036 .2992 L .20727 .29642 L p F P
0 g
s
.516 .916 .858 r
.56589 .31747 m .56788 .31731 L .55804 .32188 L p F P
0 g
s
.516 .916 .858 r
.55804 .32188 m .55686 .32204 L .56589 .31747 L p F P
0 g
s
.907 .576 .408 r
.13011 .35997 m .13404 .36286 L .1335 .35898 L p F P
0 g
s
.907 .576 .408 r
.1335 .35898 m .12957 .3561 L .13011 .35997 L p F P
0 g
s
.909 .607 .461 r
.12569 .35318 m .12957 .3561 L .12938 .3521 L p F P
0 g
s
.909 .607 .461 r
.12938 .3521 m .12551 .34919 L .12569 .35318 L p F P
0 g
s
.191 .717 .851 r
.43901 .47094 m .43911 .47095 L .42949 .47174 L p F P
0 g
s
.191 .717 .851 r
.42949 .47174 m .42687 .47148 L .43901 .47094 L p F P
0 g
s
0 .399 .682 r
.28546 .45513 m .28527 .45508 L .28506 .45502 L closepath p F P
0 g
s
.309 0 0 r
.31107 .33828 m .31015 .33807 L .3091 .3377 L closepath p F P
0 g
s
.21 .732 .85 r
.45152 .47013 m .44188 .47117 L .43911 .47095 L p F P
0 g
s
.268 0 0 r
.46373 .35269 m .46414 .35239 L .45447 .35299 L p F P
0 g
s
.268 0 0 r
.45447 .35299 m .45245 .35429 L .46373 .35269 L p F P
0 g
s
.9 .542 .353 r
.1349 .36662 m .13889 .36947 L .13803 .36571 L p F P
0 g
s
.9 .542 .353 r
.13803 .36571 m .13404 .36286 L .1349 .36662 L p F P
0 g
s
0 .408 .698 r
.2822 .45414 m .27876 .45315 L .28506 .45502 L p F P
0 g
s
0 .408 .698 r
.28506 .45502 m .28527 .45508 L .2822 .45414 L p F P
0 g
s
.909 .636 .511 r
.12169 .34623 m .12551 .34919 L .12571 .34506 L p F P
0 g
s
.909 .636 .511 r
.12571 .34506 m .12189 .3421 L .12169 .34623 L p F P
0 g
s
.806 .325 .06 r
.16691 .39708 m .16504 .39442 L .16173 .39336 L p F P
0 g
s
0 .493 .753 r
.3127 .46182 m .31269 .46182 L .31269 .46182 L closepath p F P
0 g
s
0 .503 .769 r
.30968 .46096 m .30574 .46019 L .31269 .46182 L p F P
0 g
s
0 .503 .769 r
.31269 .46182 m .31269 .46182 L .30968 .46096 L p F P
0 g
s
.429 0 0 r
.24282 .44051 m .24333 .44076 L .2422 .44034 L closepath p F P
0 g
s
0 .537 .797 r
.32106 .46321 m .31269 .46182 L .30968 .46096 L p F P
0 g
s
.635 .953 .937 r
.58929 .30818 m .58019 .31271 L .57781 .31247 L p F P
0 g
s
.655 .099 0 r
.19773 .41789 m .19907 .41902 L .19514 .41709 L closepath p F P
0 g
s
.464 0 0 r
.36058 .35263 m .35495 .3505 L .36302 .35179 L p F P
0 g
s
.464 0 0 r
.36282 .35296 m .36058 .35263 L p .36302 .35179 L F P
0 g
s
.464 0 0 r
.36302 .35179 m .365 .35243 L .36282 .35296 L p F P
0 g
s
.711 .918 .964 r
.60249 .30367 m .60234 .30361 L .60326 .30314 L closepath p F P
0 g
s
0 0 0 r
.51065 .33983 m .51115 .33954 L .50138 .34235 L p F P
0 g
s
0 0 0 r
.50138 .34235 m .50049 .34284 L .51065 .33983 L p F P
0 g
s
0 .444 .728 r
.29214 .45681 m .28527 .45508 L .2822 .45414 L p F P
0 g
s
.422 0 0 r
.4049 .35612 m .40772 .35665 L .40392 .35659 L closepath p F P
0 g
s
.674 .124 0 r
.18944 .41408 m .19417 .41659 L .19091 .41359 L p F P
0 g
s
.674 .124 0 r
.19091 .41359 m .18616 .4111 L .18944 .41408 L p F P
0 g
s
.606 .948 .921 r
.57773 .31247 m .57781 .31247 L .56901 .31734 L p F P
0 g
s
.606 .948 .921 r
.56901 .31734 m .56788 .31731 L .57773 .31247 L p F P
0 g
s
.612 .6 .815 r
.68643 .29027 m .69658 .28835 L .69905 .29359 L p F P
0 g
s
.614 .641 .854 r
.6858 .28915 m .68643 .29027 L .69658 .28835 L p F P
0 g
s
.89 .505 .295 r
.14006 .37314 m .1441 .37596 L .14294 .3723 L p F P
0 g
s
.89 .505 .295 r
.14294 .3723 m .13889 .36947 L .14006 .37314 L p F P
0 g
s
.238 .752 .746 r
.53491 .45624 m .53578 .45607 L .52596 .4587 L p F P
0 g
s
.238 .752 .746 r
.52596 .4587 m .5246 .45896 L .53491 .45624 L p F P
0 g
s
.013 .579 .789 r
.35249 .46841 m .35255 .46842 L .35246 .46841 L closepath p F P
0 g
s
.467 0 0 r
.22798 .43407 m .22772 .43398 L .22754 .43388 L closepath p F P
0 g
s
0 .416 .793 r
.26778 .32204 m .26941 .32265 L .26517 .32054 L closepath p F P
0 g
s
.771 .264 0 r
.1695 .40028 m .17397 .4029 L .17141 .3997 L p F P
0 g
s
.771 .264 0 r
.17141 .3997 m .16691 .39708 L .1695 .40028 L p F P
0 g
s
.905 .661 .559 r
.11815 .33912 m .12189 .3421 L .12253 .33782 L p F P
0 g
s
.905 .661 .559 r
.11815 .33907 m .11815 .33912 L p .12253 .33782 L F P
0 g
s
.905 .661 .559 r
.12253 .33782 m .11878 .33483 L .11815 .33907 L p F P
0 g
s
.109 .643 .862 r
.3612 .46883 m .36189 .46899 L .35255 .46842 L p F P
0 g
s
.109 .643 .862 r
.35467 .468 m .3612 .46883 L p .35255 .46842 L F P
0 g
s
.109 .643 .862 r
.34954 .46768 m .35467 .468 L p .35255 .46842 L F P
0 g
s
.109 .643 .862 r
.35255 .46842 m .35246 .46841 L .34954 .46768 L p F P
0 g
s
.716 .886 .959 r
.62453 .29513 m .62154 .29658 L .62401 .29481 L closepath p F P
0 g
s
.711 .903 .964 r
.62213 .29365 m .62401 .29481 L .62154 .29658 L p F P
0 g
s
.711 .903 .964 r
.61222 .29866 m .62213 .29365 L p .62154 .29658 L F P
0 g
s
.059 .607 .836 r
.35246 .46841 m .34954 .46768 L .34437 .46723 L closepath p F P
0 g
s
.696 .936 .964 r
.60326 .30314 m .60234 .30361 L .59992 .30278 L p F P
0 g
s
.699 .937 .963 r
.59004 .30781 m .59992 .30278 L .60234 .30361 L p F P
0 g
s
.277 .781 .805 r
.52338 .45908 m .5246 .45896 L .51413 .46145 L p F P
0 g
s
.277 .781 .805 r
.51413 .46145 m .51358 .46151 L .52338 .45908 L p F P
0 g
s
.251 .751 .689 r
.56789 .44606 m .57036 .44527 L .5605 .44871 L p F P
0 g
s
.251 .751 .689 r
.5605 .44871 m .5581 .44948 L .56789 .44606 L p F P
0 g
s
.312 0 0 r
.3071 .3374 m .30285 .33573 L .3091 .3377 L p F P
0 g
s
.312 0 0 r
.3091 .3377 m .31015 .33807 L .3071 .3374 L p F P
0 g
s
.466 .687 .962 r
.20417 .2936 m .19875 .29356 L .20279 .29645 L p F P
0 g
s
.466 .687 .962 r
.20279 .29645 m .20727 .29642 L .20417 .2936 L p F P
0 g
s
.448 .675 .96 r
.19517 .29349 m .19875 .29356 L .20279 .29645 L p F P
0 g
s
.743 .738 .847 r
.1405 .28956 m .14296 .28798 L .13981 .28463 L p F P
0 g
s
.743 .738 .847 r
.13981 .28463 m .13704 .2864 L .1405 .28956 L p F P
0 g
s
.754 .736 .836 r
.13031 .29101 m .13704 .2864 L .1405 .28956 L p F P
0 g
s
.333 .805 .722 r
.54318 .32734 m .5448 .32685 L .53532 .33078 L p F P
0 g
s
.333 .805 .722 r
.53532 .33078 m .53335 .33142 L .54318 .32734 L p F P
0 g
s
.458 0 0 r
.22454 .43287 m .2223 .4316 L .22754 .43388 L p F P
0 g
s
.458 0 0 r
.22754 .43388 m .22772 .43398 L .22454 .43287 L p F P
0 g
s
.308 0 0 r
.24309 .44094 m .24873 .44308 L .24333 .44076 L p F P
0 g
s
.308 0 0 r
.23967 .43947 m .24309 .44094 L p .24333 .44076 L F P
0 g
s
.308 0 0 r
.24333 .44076 m .2422 .44034 L .23967 .43947 L p F P
0 g
s
.317 0 0 r
.44206 .35473 m .448 .35475 L .44085 .3555 L closepath p F P
0 g
s
.137 0 .159 r
.67679 .37882 m .676 .38157 L .68124 .37566 L closepath p F P
0 g
s
.707 .922 .965 r
.61222 .29866 m .60326 .30314 L .61083 .29805 L closepath p F P
0 g
s
.696 .936 .964 r
.60981 .29762 m .61083 .29805 L .60326 .30314 L p F P
0 g
s
.696 .936 .964 r
.59992 .30278 m .60981 .29762 L p .60326 .30314 L F P
0 g
s
.52 .468 .739 r
.70414 .30675 m .70782 .30748 L .70519 .31001 L closepath p F P
0 g
s
.477 .419 .713 r
.71393 .30962 m .70782 .30748 L .70519 .31001 L p F P
0 g
s
.477 .419 .713 r
.70724 .31601 m .71393 .30962 L p .70519 .31001 L F P
0 g
s
.477 .419 .713 r
.70519 .31001 m .70683 .31583 L .70724 .31601 L p F P
0 g
s
.652 .727 .904 r
.1554 .28681 m .16458 .28378 L .16771 .28699 L p F P
0 g
s
.649 .725 .904 r
.16458 .28378 m .1554 .28681 L .15226 .28353 L p F P
0 g
s
.703 .735 .876 r
.14296 .28798 m .15226 .28353 L .1554 .28681 L p F P
0 g
s
.514 .48 .757 r
.70279 .30286 m .70414 .30675 L .70782 .30748 L p F P
0 g
s
.86 .428 .186 r
.14571 .37948 m .14989 .38224 L .14829 .37873 L p F P
0 g
s
.86 .428 .186 r
.14416 .3761 m .14571 .37948 L p .14829 .37873 L F P
0 g
s
.86 .428 .186 r
.14829 .37873 m .14442 .37618 L .14416 .3761 L p F P
0 g
s
.427 0 0 r
.23237 .43638 m .22772 .43398 L .22454 .43287 L p F P
0 g
s
.395 0 0 r
.41727 .35631 m .4195 .3566 L .41661 .35667 L closepath p F P
0 g
s
.193 0 0 r
.47315 .34988 m .46607 .35119 L .46414 .35239 L p F P
0 g
s
.59 .015 0 r
.21268 .42653 m .21282 .42663 L .21244 .42646 L closepath p F P
0 g
s
.36 0 0 r
.42966 .35585 m .43268 .35605 L .42891 .3563 L closepath p F P
0 g
s
.632 .656 .855 r
.684 .28603 m .69054 .28442 L .6858 .28915 L closepath p F P
0 g
s
.614 .641 .854 r
.69413 .28359 m .69054 .28442 L .6858 .28915 L p F P
0 g
s
.614 .641 .854 r
.69658 .28835 m .69413 .28359 L p .6858 .28915 L F P
0 g
s
0 0 0 r
.58284 .44039 m .58267 .44047 L .58669 .43883 L closepath p F P
0 g
s
.482 0 0 r
.21199 .42695 m .21712 .42929 L .21282 .42663 L p F P
0 g
s
.482 0 0 r
.20947 .42538 m .21199 .42695 L p .21282 .42663 L F P
0 g
s
.482 0 0 r
.21282 .42663 m .21244 .42646 L .20947 .42538 L p F P
0 g
s
.897 .683 .605 r
.1174 .3337 m .11878 .33483 L .1199 .33037 L p F P
0 g
s
.897 .683 .605 r
.11562 .32968 m .1174 .3337 L p .1199 .33037 L F P
0 g
s
.897 .683 .605 r
.1199 .33037 m .11622 .32734 L .11562 .32968 L p F P
0 g
s
.551 .519 .774 r
.70156 .29964 m .70588 .29983 L .70279 .30286 L closepath p F P
0 g
s
.514 .48 .757 r
.71192 .30061 m .70588 .29983 L .70279 .30286 L p F P
0 g
s
.514 .48 .757 r
.71263 .30282 m .71192 .30061 L p .70279 .30286 L F P
0 g
s
.514 .48 .757 r
.70782 .30748 m .71263 .30282 L p .70279 .30286 L F P
0 g
s
.378 0 0 r
.2422 .44034 m .23967 .43947 L .2378 .43859 L closepath p F P
0 g
s
.701 .735 .877 r
.15226 .28353 m .14296 .28798 L .13981 .28463 L p F P
0 g
s
.439 .667 .959 r
.19875 .29356 m .19517 .29349 L .19207 .29052 L p F P
0 g
s
0 .369 .676 r
.26043 .44731 m .26633 .44934 L .26036 .44719 L p F P
0 g
s
0 .369 .676 r
.26036 .44719 m .25536 .44553 L .25485 .44535 L p F P
0 g
s
0 .369 .676 r
.25485 .44535 m .26043 .44731 L p .26036 .44719 L F P
0 g
s
0 0 0 r
.61308 .42681 m .6147 .42563 L .60481 .43045 L p F P
0 g
s
0 0 0 r
.60481 .43045 m .60391 .43111 L .61308 .42681 L p F P
0 g
s
.005 .484 .868 r
.25267 .31565 m .25334 .31588 L .25137 .31478 L closepath p F P
0 g
s
.543 0 0 r
.21244 .42646 m .20947 .42538 L .2078 .42425 L closepath p F P
0 g
s
.279 .78 .861 r
.48688 .46631 m .47793 .46768 L .47636 .46763 L p F P
0 g
s
.859 .726 .715 r
.1131 .31159 m .11663 .31471 L .11969 .30953 L p F P
0 g
s
.859 .726 .715 r
.11969 .30953 m .11619 .3064 L .1131 .31159 L p F P
0 g
s
.726 .888 .955 r
.63205 .28861 m .63444 .29035 L .62453 .29513 L p F P
0 g
s
.726 .888 .955 r
.63149 .28889 m .63205 .28861 L p .62453 .29513 L F P
0 g
s
.726 .888 .955 r
.62453 .29513 m .62401 .29481 L .63149 .28889 L p F P
0 g
s
.284 .64 .966 r
.23801 .30948 m .23755 .30914 L .23729 .3091 L closepath p F P
0 g
s
.486 .412 .699 r
.70683 .31583 m .70724 .31601 L .70695 .31628 L closepath p F P
0 g
s
.594 .714 .927 r
.16771 .28699 m .17343 .28585 L .1773 .28884 L p F P
0 g
s
.602 .718 .926 r
.17681 .28516 m .17343 .28585 L .1773 .28884 L p F P
0 g
s
.602 .718 .926 r
.1773 .28884 m .17992 .28827 L .17681 .28516 L p F P
0 g
s
.59 .711 .927 r
.17343 .28585 m .16771 .28699 L .16458 .28378 L p F P
0 g
s
.386 .668 .971 r
.21933 .30008 m .21623 .29981 L .22062 .30255 L p F P
0 g
s
.386 .668 .971 r
.22062 .30255 m .22242 .30268 L .21933 .30008 L p F P
0 g
s
.461 .374 .671 r
.71146 .31882 m .70821 .32186 L .70695 .31628 L p F P
0 g
s
.461 .374 .671 r
.70695 .31628 m .70724 .31601 L .71146 .31882 L p F P
0 g
s
0 0 0 r
.58669 .43883 m .58267 .44047 L .5803 .44153 L p F P
0 g
s
.014 0 0 r
.63673 .41235 m .63649 .4125 L .63671 .41238 L closepath p F P
0 g
s
0 0 0 r
.63498 .4143 m .63671 .41238 L .63649 .4125 L p F P
0 g
s
0 0 0 r
.6261 .41902 m .63498 .4143 L p .63649 .4125 L F P
0 g
s
.845 .395 .141 r
.15176 .38567 m .15599 .38841 L .15413 .38497 L p F P
0 g
s
.845 .395 .141 r
.15413 .38497 m .14989 .38224 L .15176 .38567 L p F P
0 g
s
.481 0 0 r
.31427 .33994 m .31015 .33807 L .3071 .3374 L p F P
0 g
s
0 0 0 r
.64544 .40742 m .64659 .40586 L .63673 .41235 L p F P
0 g
s
0 0 0 r
.63673 .41235 m .63671 .41238 L .64544 .40742 L p F P
0 g
s
.218 0 .302 r
.69371 .36376 m .68586 .36976 L .68919 .3643 L p F P
0 g
s
.218 0 .302 r
.68919 .3643 m .69419 .36048 L .69371 .36376 L p F P
0 g
s
.547 .536 .794 r
.69934 .29426 m .70156 .29964 L .70588 .29983 L p F P
0 g
s
.456 0 0 r
.32587 .34412 m .33276 .34586 L .32748 .34363 L p F P
0 g
s
.456 0 0 r
.3223 .34239 m .32587 .34412 L p .32748 .34363 L F P
0 g
s
.456 0 0 r
.32748 .34363 m .32349 .3425 L .3223 .34239 L p F P
0 g
s
.486 0 0 r
.35261 .35129 m .36058 .35263 L .35495 .3505 L p F P
0 g
s
.486 0 0 r
.34974 .35003 m .35261 .35129 L p .35495 .3505 L F P
0 g
s
.486 0 0 r
.35495 .3505 m .35133 .34982 L .34974 .35003 L p F P
0 g
s
0 0 0 r
.64439 .40858 m .64544 .40742 L .63671 .41238 L p F P
0 g
s
0 0 0 r
.63872 .41218 m .64439 .40858 L p .63671 .41238 L F P
0 g
s
0 0 0 r
.63671 .41238 m .63498 .4143 L .63872 .41218 L p F P
0 g
s
.733 .206 0 r
.17638 .40555 m .17397 .4029 L .17851 .40549 L p F P
0 g
s
.733 .206 0 r
.17851 .40549 m .17965 .40673 L .17638 .40555 L p F P
0 g
s
.115 .651 .858 r
.37239 .46993 m .36481 .46963 L .36189 .46899 L p F P
0 g
s
.469 .389 .683 r
.71572 .31477 m .71146 .31882 L .70724 .31601 L p F P
0 g
s
.469 .389 .683 r
.71464 .31003 m .71572 .31477 L p .70724 .31601 L F P
0 g
s
.469 .389 .683 r
.70724 .31601 m .71393 .30962 L .71464 .31003 L p F P
0 g
s
.705 .802 .925 r
.64746 .28848 m .64677 .28779 L .64975 .28648 L closepath p F P
0 g
s
.255 .766 .785 r
.52338 .45908 m .51358 .46151 L .51097 .46173 L p F P
0 g
s
.288 .64 .966 r
.23447 .3068 m .23256 .30649 L .23729 .3091 L p F P
0 g
s
.288 .64 .966 r
.23729 .3091 m .23755 .30914 L .23447 .3068 L p F P
0 g
s
.086 .624 .855 r
.34681 .46699 m .34954 .46768 L .34437 .46723 L p F P
0 g
s
.086 .624 .855 r
.34621 .46689 m .34681 .46699 L p .34437 .46723 L F P
0 g
s
.086 .624 .855 r
.33723 .46611 m .34621 .46689 L p .34437 .46723 L F P
0 g
s
.086 .624 .855 r
.34437 .46723 m .33781 .46626 L .33723 .46611 L p F P
0 g
s
0 0 0 r
.64698 .40532 m .64659 .40586 L .6497 .4037 L closepath p F P
0 g
s
0 0 0 r
.53272 .3317 m .53335 .33142 L .52354 .3351 L p F P
0 g
s
0 0 0 r
.52354 .3351 m .52302 .33533 L .53272 .3317 L p F P
0 g
s
0 .462 .85 r
.25422 .31527 m .25918 .31778 L .25334 .31588 L p F P
0 g
s
0 .462 .85 r
.24959 .3136 m .25422 .31527 L p .25334 .31588 L F P
0 g
s
0 .462 .85 r
.25334 .31588 m .25137 .31478 L .24959 .3136 L p F P
0 g
s
0 0 0 r
.63449 .41474 m .63498 .4143 L .6261 .41902 L p F P
0 g
s
0 0 0 r
.6261 .41902 m .62459 .42041 L .63449 .41474 L p F P
0 g
s
.559 0 0 r
.19796 .41941 m .20285 .42185 L .19907 .41902 L p F P
0 g
s
.559 0 0 r
.19449 .41684 m .19796 .41941 L p .19907 .41902 L F P
0 g
s
.559 0 0 r
.19907 .41902 m .19514 .41709 L .19449 .41684 L p F P
0 g
s
.493 0 0 r
.365 .35243 m .36887 .35385 L .36282 .35296 L closepath p F P
0 g
s
.887 .701 .645 r
.11311 .32471 m .11622 .32734 L .1179 .32268 L p F P
0 g
s
.887 .701 .645 r
.11269 .32404 m .11311 .32471 L p .1179 .32268 L F P
0 g
s
.887 .701 .645 r
.1179 .32268 m .1143 .31961 L .11269 .32404 L p F P
0 g
s
.067 .519 .898 r
.24362 .31079 m .23755 .30914 L .23447 .3068 L p F P
0 g
s
0 .39 .768 r
.26966 .32232 m .27498 .32468 L .26941 .32265 L p F P
0 g
s
0 .39 .768 r
.26471 .32029 m .26966 .32232 L p .26941 .32265 L F P
0 g
s
0 .39 .768 r
.26941 .32265 m .26517 .32054 L .26471 .32029 L p F P
0 g
s
0 .45 .712 r
.29745 .45824 m .29881 .45855 L .30574 .46019 L p F P
0 g
s
0 .503 .771 r
.30664 .46009 m .29881 .45855 L .30574 .46019 L p F P
0 g
s
0 .503 .771 r
.30574 .46019 m .30968 .46096 L .30664 .46009 L p F P
0 g
s
.25 .026 .366 r
.69819 .35725 m .69419 .36048 L .6945 .35696 L p F P
0 g
s
.25 .026 .366 r
.6945 .35696 m .70044 .35215 L .69819 .35725 L p F P
0 g
s
0 .547 .788 r
.32494 .46411 m .32863 .46462 L .33629 .466 L p F P
0 g
s
0 .549 .791 r
.32494 .46411 m .32863 .46462 L .32256 .46352 L closepath p F P
0 g
s
.244 0 0 r
.27005 .45048 m .2725 .45127 L .27876 .45315 L p F P
0 g
s
0 .407 .699 r
.27911 .45318 m .2725 .45127 L .27876 .45315 L p F P
0 g
s
0 .407 .699 r
.27876 .45315 m .2822 .45414 L .27911 .45318 L p F P
0 g
s
.237 0 0 r
.27005 .45048 m .2725 .45127 L .26761 .44977 L closepath p F P
0 g
s
.684 .736 .89 r
.65913 .28612 m .66914 .28222 L .67153 .28545 L p F P
0 g
s
.695 .758 .9 r
.66914 .28222 m .65913 .28612 L .65674 .28342 L p F P
0 g
s
.296 0 0 r
.27984 .32671 m .28044 .32698 L .28582 .3293 L p F P
0 g
s
.296 0 0 r
.28551 .32922 m .29127 .3314 L .28582 .3293 L p F P
0 g
s
.296 0 0 r
.28582 .3293 m .28044 .32698 L .28551 .32922 L p F P
0 g
s
.66 .687 .865 r
.67153 .28545 m .68159 .28217 L .684 .28603 L p F P
0 g
s
.672 .711 .877 r
.68159 .28217 m .67153 .28545 L .66914 .28222 L p F P
0 g
s
.182 0 0 r
.47702 .3492 m .47657 .34946 L .47315 .34988 L closepath p F P
0 g
s
.193 0 0 r
.47476 .35076 m .47657 .34946 L .47315 .34988 L p F P
0 g
s
.193 0 0 r
.4672 .35207 m .47476 .35076 L p .47315 .34988 L F P
0 g
s
.193 0 0 r
.46414 .35239 m .4672 .35207 L p .47315 .34988 L F P
0 g
s
.092 0 0 r
.49815 .34422 m .49874 .34382 L .48898 .34609 L p F P
0 g
s
.092 0 0 r
.48898 .34609 m .48772 .34689 L .49815 .34422 L p F P
0 g
s
.726 .889 .955 r
.62401 .29481 m .62213 .29365 L .63149 .28889 L closepath p F P
0 g
s
.82 .346 .076 r
.15813 .39175 m .15599 .38841 L .16028 .39111 L p F P
0 g
s
.82 .346 .076 r
.15939 .39255 m .15813 .39175 L p .16028 .39111 L F P
0 g
s
.82 .346 .076 r
.16028 .39111 m .16173 .39336 L .15939 .39255 L p F P
0 g
s
.341 .163 .489 r
.7025 .3468 m .7018 .34738 L .70217 .34295 L p F P
0 g
s
.341 .163 .489 r
.70217 .34295 m .70239 .34277 L .7025 .3468 L p F P
0 g
s
.475 0 0 r
.35133 .34982 m .34974 .35003 L .34723 .34908 L closepath p F P
0 g
s
.403 0 0 r
.4195 .3566 m .41661 .35667 L .4144 .35793 L p F P
0 g
s
.441 0 0 r
.41661 .35667 m .4144 .35793 L .40772 .35665 L closepath p F P
0 g
s
.431 0 0 r
.4141 .35813 m .4144 .35793 L .40772 .35665 L p F P
0 g
s
.431 0 0 r
.40394 .35802 m .4141 .35813 L p .40772 .35665 L F P
0 g
s
.431 0 0 r
.402 .35755 m .40394 .35802 L p .40772 .35665 L F P
0 g
s
.431 0 0 r
.40772 .35665 m .40392 .35659 L .402 .35755 L p F P
0 g
s
.412 0 0 r
.42891 .3563 m .42682 .3576 L .4195 .3566 L closepath p F P
0 g
s
.403 0 0 r
.42649 .35783 m .42682 .3576 L .4195 .3566 L p F P
0 g
s
.403 0 0 r
.41538 .35811 m .42649 .35783 L p .4195 .3566 L F P
0 g
s
.403 0 0 r
.4144 .35793 m .41538 .35811 L p .4195 .3566 L F P
0 g
s
0 0 0 r
.50854 .34107 m .51065 .33983 L .50049 .34284 L p F P
0 g
s
0 0 0 r
.50049 .34284 m .49874 .34382 L .50854 .34107 L p F P
0 g
s
.461 0 0 r
.40392 .35659 m .402 .35755 L .39695 .35633 L closepath p F P
0 g
s
0 0 0 r
.65694 .39786 m .65643 .39873 L .66018 .39581 L closepath p F P
0 g
s
.322 .149 .485 r
.70952 .34071 m .7025 .3468 L .70239 .34277 L p F P
0 g
s
.322 .149 .485 r
.70239 .34277 m .70985 .33629 L .70952 .34071 L p F P
0 g
s
.489 0 0 r
.33752 .3465 m .33984 .34752 L .33575 .34653 L closepath p F P
0 g
s
0 0 0 r
.61518 .42527 m .6147 .42563 L .62022 .42277 L closepath p F P
0 g
s
.394 .845 .758 r
.55405 .3226 m .55554 .32222 L .54571 .32659 L p F P
0 g
s
.394 .845 .758 r
.54571 .32659 m .5448 .32685 L .55405 .3226 L p F P
0 g
s
.516 .916 .855 r
.5654 .31751 m .56589 .31747 L .55686 .32204 L p F P
0 g
s
.516 .916 .855 r
.55686 .32204 m .55554 .32222 L .5654 .31751 L p F P
0 g
s
.806 .738 .789 r
.11734 .29697 m .12297 .29131 L .12641 .29448 L p F P
0 g
s
.806 .738 .789 r
.12641 .29448 m .1205 .30045 L .11734 .29697 L p F P
0 g
s
.789 .741 .808 r
.12641 .29448 m .13031 .29101 L .12716 .28761 L p F P
0 g
s
.789 .741 .808 r
.12716 .28761 m .12297 .29131 L .12641 .29448 L p F P
0 g
s
.255 .762 .74 r
.54815 .45267 m .54815 .45267 L .548 .45272 L closepath p F P
0 g
s
.267 .771 .754 r
.54562 .45318 m .54815 .45267 L .548 .45272 L p F P
0 g
s
.267 .771 .754 r
.53578 .45607 m .54562 .45318 L p .548 .45272 L F P
0 g
s
.358 0 0 r
.30201 .33587 m .29696 .3336 L .30285 .33573 L p F P
0 g
s
.358 0 0 r
.306 .33716 m .30201 .33587 L p .30285 .33573 L F P
0 g
s
.358 0 0 r
.30285 .33573 m .3071 .3374 L .306 .33716 L p F P
0 g
s
.394 0 0 r
.29499 .3327 m .29696 .3336 L .30285 .33573 L p F P
0 g
s
.29 .785 .755 r
.55801 .4495 m .5581 .44948 L .54815 .45267 L p F P
0 g
s
.29 .785 .755 r
.54815 .45267 m .54815 .45267 L .55801 .4495 L p F P
0 g
s
.224 .599 .95 r
.22242 .30268 m .22802 .30381 L .23256 .30649 L p F P
0 g
s
.21 .584 .944 r
.22802 .30381 m .22242 .30268 L .21933 .30008 L p F P
0 g
s
.65 .951 .949 r
.59004 .30781 m .58929 .30818 L .58996 .3078 L closepath p F P
0 g
s
.635 .953 .937 r
.5876 .30743 m .58996 .3078 L .58929 .30818 L p F P
0 g
s
.635 .953 .937 r
.57839 .31213 m .5876 .30743 L p .58929 .30818 L F P
0 g
s
.635 .953 .937 r
.57781 .31247 m .57839 .31213 L p .58929 .30818 L F P
0 g
s
.3 .792 .767 r
.55801 .4495 m .54815 .45267 L .54562 .45318 L p F P
0 g
s
.12 .659 .848 r
.38859 .47108 m .38952 .47124 L p .37715 .47058 L F P
0 g
s
.12 .659 .848 r
.37715 .47058 m .38196 .47064 L .38859 .47108 L p F P
0 g
s
.127 .663 .855 r
.37715 .47058 m .38196 .47064 L .37511 .47018 L closepath p F P
0 g
s
.451 0 0 r
.4013 .35796 m .402 .35755 L .39695 .35633 L p F P
0 g
s
.451 0 0 r
.39344 .3576 m .4013 .35796 L p .39695 .35633 L F P
0 g
s
.451 0 0 r
.38963 .35647 m .39344 .3576 L p .39695 .35633 L F P
0 g
s
.451 0 0 r
.39695 .35633 m .39077 .35599 L .38963 .35647 L p F P
0 g
s
.753 .738 .838 r
.13704 .2864 m .13031 .29101 L .12716 .28761 L p F P
0 g
s
.526 .698 .948 r
.17992 .28827 m .18896 .28751 L .19207 .29052 L p F P
0 g
s
.521 .694 .947 r
.18896 .28751 m .17992 .28827 L .17681 .28516 L p F P
0 g
s
0 .458 .724 r
.29745 .45824 m .29881 .45855 L .29635 .45795 L closepath p F P
0 g
s
.368 0 0 r
.43268 .35605 m .42891 .3563 L .42682 .3576 L p F P
0 g
s
0 0 0 r
.59255 .43639 m .58669 .43883 L .5923 .43654 L closepath p F P
0 g
s
0 0 0 r
.59015 .43749 m .5923 .43654 L .58669 .43883 L p F P
0 g
s
0 0 0 r
.58162 .44099 m .59015 .43749 L p .58669 .43883 L F P
0 g
s
0 0 0 r
.5803 .44153 m .58162 .44099 L p .58669 .43883 L F P
0 g
s
.427 .322 .632 r
.71435 .3221 m .70913 .32698 L .70821 .32186 L p F P
0 g
s
.427 .322 .632 r
.70821 .32186 m .71146 .31882 L .71435 .3221 L p F P
0 g
s
.41 0 0 r
.32349 .3425 m .3223 .34239 L .32082 .34181 L closepath p F P
0 g
s
.572 .94 .884 r
.57527 .31252 m .57773 .31247 L .56788 .31731 L p F P
0 g
s
.572 .94 .884 r
.56996 .3152 m .57527 .31252 L p .56788 .31731 L F P
0 g
s
.572 .94 .884 r
.56788 .31731 m .56589 .31747 L .56996 .3152 L p F P
0 g
s
.266 .773 .847 r
.48904 .46596 m .48878 .46596 L .48688 .46631 L closepath p F P
0 g
s
.279 .78 .861 r
.48611 .46588 m .48878 .46596 L .48688 .46631 L p F P
0 g
s
.279 .78 .861 r
.47636 .46763 m .48611 .46588 L p .48688 .46631 L F P
0 g
s
.262 .771 .812 r
.51064 .46175 m .51097 .46173 L .50118 .46388 L p F P
0 g
s
.262 .771 .812 r
.50118 .46388 m .49992 .46397 L .51064 .46175 L p F P
0 g
s
.705 .824 .939 r
.64975 .28648 m .64677 .28779 L .64439 .28561 L p F P
0 g
s
.72 .828 .932 r
.63444 .29035 m .64439 .28561 L .64677 .28779 L p F P
0 g
s
.578 .566 .804 r
.69905 .29359 m .70008 .29352 L .69934 .29426 L closepath p F P
0 g
s
.547 .536 .794 r
.70934 .29334 m .70008 .29352 L .69934 .29426 L p F P
0 g
s
.547 .536 .794 r
.71018 .29558 m .70934 .29334 L p .69934 .29426 L F P
0 g
s
.547 .536 .794 r
.70588 .29983 m .71018 .29558 L p .69934 .29426 L F P
0 g
s
.034 .586 .827 r
.33781 .46626 m .33723 .46611 L .33629 .466 L closepath p F P
0 g
s
.67 .956 .946 r
.59845 .30242 m .59992 .30278 L .59004 .30781 L p F P
0 g
s
.67 .956 .946 r
.59004 .30781 m .58996 .3078 L .59845 .30242 L p F P
0 g
s
.163 0 .222 r
.68567 .3699 m .68563 .37006 L .68586 .36976 L closepath p F P
0 g
s
.91 .579 .404 r
.12623 .35705 m .13011 .35997 L .12957 .3561 L p F P
0 g
s
.91 .579 .404 r
.12957 .3561 m .12569 .35318 L .12623 .35705 L p F P
0 g
s
.405 .275 .59 r
.70976 .3317 m .70916 .33223 L .70735 .32856 L p F P
0 g
s
.405 .275 .59 r
.70735 .32856 m .70913 .32698 L .70976 .3317 L p F P
0 g
s
.135 0 0 r
.48631 .34782 m .48772 .34689 L .47702 .3492 L p F P
0 g
s
.135 0 0 r
.47702 .3492 m .47657 .34946 L .48631 .34782 L p F P
0 g
s
.287 0 0 r
.25536 .44553 m .25485 .44535 L .25441 .44518 L closepath p F P
0 g
s
.356 0 0 r
.29499 .3327 m .29696 .3336 L .29262 .33188 L closepath p F P
0 g
s
.913 .61 .458 r
.12188 .35023 m .12569 .35318 L .12551 .34919 L p F P
0 g
s
.913 .61 .458 r
.12551 .34919 m .12169 .34623 L .12188 .35023 L p F P
0 g
s
.137 .575 .926 r
.25137 .31478 m .24959 .3136 L .24846 .31334 L closepath p F P
0 g
s
.376 0 0 r
.44085 .3555 m .43926 .35654 L .43268 .35605 L closepath p F P
0 g
s
.368 0 0 r
.43852 .3571 m .43926 .35654 L .43268 .35605 L p F P
0 g
s
.368 0 0 r
.4281 .35774 m .43852 .3571 L p .43268 .35605 L F P
0 g
s
.368 0 0 r
.42682 .3576 m .4281 .35774 L p .43268 .35605 L F P
0 g
s
.664 .11 0 r
.18478 .41155 m .18944 .41408 L .18616 .4111 L p F P
0 g
s
.664 .11 0 r
.18616 .4111 m .18147 .40858 L .18478 .41155 L p F P
0 g
s
.372 0 0 r
.23652 .43836 m .23237 .43638 L .2378 .43859 L p F P
0 g
s
.372 0 0 r
.2378 .43859 m .23967 .43947 L .23652 .43836 L p F P
0 g
s
.83 .738 .763 r
.12015 .30088 m .1205 .30045 L .11734 .29697 L p F P
0 g
s
.16 0 .219 r
.69342 .36507 m .69371 .36376 L .68586 .36976 L p F P
0 g
s
.16 0 .219 r
.69102 .36836 m .69342 .36507 L p .68586 .36976 L F P
0 g
s
.16 0 .219 r
.68499 .37295 m .69102 .36836 L p .68586 .36976 L F P
0 g
s
.16 0 .219 r
.68586 .36976 m .68563 .37006 L .68499 .37295 L p F P
0 g
s
.591 .587 .817 r
.70008 .29352 m .69905 .29359 L .69658 .28835 L p F P
0 g
s
.875 .717 .682 r
.11076 .3165 m .1143 .31961 L .11663 .31471 L p F P
0 g
s
.875 .717 .682 r
.11663 .31471 m .1131 .31159 L .11076 .3165 L p F P
0 g
s
.644 .66 .851 r
.69054 .28442 m .684 .28603 L .68159 .28217 L p F P
0 g
s
.472 0 0 r
.39077 .35599 m .38963 .35647 L .38699 .35572 L closepath p F P
0 g
s
.904 .544 .347 r
.13097 .36373 m .1349 .36662 L .13404 .36286 L p F P
0 g
s
.904 .544 .347 r
.13404 .36286 m .13011 .35997 L .13097 .36373 L p F P
0 g
s
0 0 0 r
.53079 .33257 m .53272 .3317 L .52302 .33533 L p F P
0 g
s
0 0 0 r
.52302 .33533 m .52096 .33628 L .53079 .33257 L p F P
0 g
s
.674 .958 .945 r
.59749 .30219 m .59845 .30242 L .58996 .3078 L p F P
0 g
s
.674 .958 .945 r
.58996 .3078 m .5876 .30743 L .59749 .30219 L p F P
0 g
s
.482 0 0 r
.34505 .3498 m .33984 .34752 L .34723 .34908 L p F P
0 g
s
.482 0 0 r
.34782 .35033 m .34505 .3498 L p .34723 .34908 L F P
0 g
s
.482 0 0 r
.34723 .34908 m .34974 .35003 L .34782 .35033 L p F P
0 g
s
.181 0 .227 r
.68563 .37006 m .68124 .37566 L .68499 .37295 L closepath p F P
0 g
s
0 0 0 r
.6497 .4037 m .64659 .40586 L .64544 .40742 L p F P
0 g
s
.83 .738 .763 r
.11734 .29697 m .11673 .29771 L .12015 .30088 L p F P
0 g
s
.843 .735 .744 r
.11274 .30324 m .11619 .3064 L .12015 .30088 L p F P
0 g
s
.843 .735 .744 r
.12015 .30088 m .11673 .29771 L .11274 .30324 L p F P
0 g
s
.46 0 0 r
.22136 .43172 m .21712 .42929 L .2223 .4316 L p F P
0 g
s
.46 0 0 r
.2223 .4316 m .22454 .43287 L .22136 .43172 L p F P
0 g
s
.048 .594 .84 r
.33425 .46526 m .32863 .46462 L .33629 .466 L p F P
0 g
s
.048 .594 .84 r
.33629 .466 m .33723 .46611 L .33425 .46526 L p F P
0 g
s
.913 .638 .508 r
.11794 .34324 m .12169 .34623 L .12189 .3421 L p F P
0 g
s
.913 .638 .508 r
.11814 .33914 m .11794 .34324 L p .12189 .3421 L F P
0 g
s
.913 .638 .508 r
.12189 .3421 m .11815 .33912 L .11814 .33914 L p F P
0 g
s
.299 .793 .86 r
.49854 .46395 m .49992 .46397 L .48904 .46596 L p F P
0 g
s
.299 .793 .86 r
.48904 .46596 m .48878 .46596 L .49854 .46395 L p F P
0 g
s
.722 .925 .96 r
.61972 .29238 m .62213 .29365 L .61222 .29866 L p F P
0 g
s
.722 .925 .96 r
.61526 .29473 m .61972 .29238 L p .61222 .29866 L F P
0 g
s
.722 .925 .96 r
.61222 .29866 m .61083 .29805 L .61526 .29473 L p F P
0 g
s
.716 .182 0 r
.18147 .40858 m .17965 .40673 L .17638 .40555 L p F P
0 g
s
.806 .325 .06 r
.16173 .39336 m .16248 .39444 L .16691 .39708 L p F P
0 g
s
.766 .256 0 r
.16508 .39763 m .1695 .40028 L .16691 .39708 L p F P
0 g
s
.766 .256 0 r
.16691 .39708 m .16248 .39444 L .16508 .39763 L p F P
0 g
s
.309 .802 .818 r
.53321 .4564 m .53491 .45624 L .5246 .45896 L p F P
0 g
s
.309 .802 .818 r
.5246 .45896 m .52338 .45908 L .53321 .4564 L p F P
0 g
s
.483 0 0 r
.3837 .3569 m .37773 .35486 L .38699 .35572 L p F P
0 g
s
.483 0 0 r
.38802 .35725 m .3837 .3569 L p .38699 .35572 L F P
0 g
s
.483 0 0 r
.38699 .35572 m .38963 .35647 L .38802 .35725 L p F P
0 g
s
.276 0 0 r
.25172 .44425 m .24873 .44308 L .25441 .44518 L p F P
0 g
s
.276 0 0 r
.25441 .44518 m .25485 .44535 L .25172 .44425 L p F P
0 g
s
.893 .506 .288 r
.13607 .37028 m .14006 .37314 L .13889 .36947 L p F P
0 g
s
.893 .506 .288 r
.13889 .36947 m .1349 .36662 L .13607 .37028 L p F P
0 g
s
.281 .77 .698 r
.58024 .44155 m .5803 .44153 L .57068 .44516 L p F P
0 g
s
.281 .77 .698 r
.57068 .44516 m .57036 .44527 L .58024 .44155 L p F P
0 g
s
.496 .431 .714 r
.71443 .30914 m .71393 .30962 L .70782 .30748 L p F P
0 g
s
.496 .431 .714 r
.70782 .30748 m .71263 .30282 L .71443 .30914 L p F P
0 g
s
.021 0 0 r
.6666 .38999 m .66624 .39074 L .6687 .38859 L closepath p F P
0 g
s
.413 0 0 r
.31925 .34211 m .31427 .33994 L .32082 .34181 L p F P
0 g
s
.413 0 0 r
.32082 .34181 m .3223 .34239 L .31925 .34211 L p F P
0 g
s
.873 .455 .22 r
.14442 .37618 m .14416 .3761 L .1441 .37596 L closepath p F P
0 g
s
.006 0 0 r
.65643 .39873 m .6497 .4037 L .65558 .40014 L closepath p F P
0 g
s
0 0 0 r
.65428 .40191 m .65558 .40014 L .6497 .4037 L p F P
0 g
s
0 0 0 r
.65249 .40318 m .65428 .40191 L p .6497 .4037 L F P
0 g
s
0 0 0 r
.64544 .40742 m .65249 .40318 L p .6497 .4037 L F P
0 g
s
.343 .64 .964 r
.20727 .29642 m .21199 .29699 L .21623 .29981 L p F P
0 g
s
.332 .63 .96 r
.21199 .29699 m .20727 .29642 L .20417 .2936 L p F P
0 g
s
.141 .676 .852 r
.40169 .47158 m .4019 .47162 L p .38952 .47124 L F P
0 g
s
.141 .676 .852 r
.38952 .47124 m .39195 .47121 L .40169 .47158 L p F P
0 g
s
.15 .681 .86 r
.38952 .47124 m .39195 .47121 L .38859 .47108 L closepath p F P
0 g
s
.439 .667 .959 r
.19207 .29052 m .19482 .29061 L .19875 .29356 L p F P
0 g
s
.456 .68 .961 r
.20106 .29074 m .19482 .29061 L .19875 .29356 L p F P
0 g
s
.456 .68 .961 r
.19875 .29356 m .20417 .2936 L .20106 .29074 L p F P
0 g
s
.324 0 0 r
.448 .35475 m .44085 .3555 L .43926 .35654 L p F P
0 g
s
.908 .665 .558 r
.11878 .33483 m .1174 .3337 L .11815 .33907 L closepath p F P
0 g
s
.565 .544 .791 r
.70681 .28719 m .7063 .28723 L .70008 .29352 L p F P
0 g
s
.565 .544 .791 r
.70008 .29352 m .70934 .29334 L .70681 .28719 L p F P
0 g
s
.591 .587 .817 r
.69658 .28835 m .7063 .28723 L .70008 .29352 L p F P
0 g
s
.539 0 0 r
.20626 .42417 m .20285 .42185 L .2078 .42425 L p F P
0 g
s
.539 0 0 r
.2078 .42425 m .20947 .42538 L .20626 .42417 L p F P
0 g
s
0 0 0 r
.61236 .42722 m .61308 .42681 L .60391 .43111 L p F P
0 g
s
0 0 0 r
.60391 .43111 m .60245 .43196 L .61236 .42722 L p F P
0 g
s
.285 .785 .85 r
.49854 .46395 m .48878 .46596 L .48611 .46588 L p F P
0 g
s
.236 0 0 r
.26043 .44731 m .25485 .44535 L .25172 .44425 L p F P
0 g
s
.705 .801 .925 r
.65674 .28342 m .64975 .28648 L .65513 .28177 L closepath p F P
0 g
s
.705 .824 .939 r
.65436 .28097 m .65513 .28177 L .64975 .28648 L p F P
0 g
s
.705 .824 .939 r
.64439 .28561 m .65436 .28097 L p .64975 .28648 L F P
0 g
s
.875 .455 .213 r
.14081 .37494 m .14006 .37314 L .1441 .37596 L p F P
0 g
s
.875 .455 .213 r
.1441 .37596 m .14416 .3761 L .14081 .37494 L p F P
0 g
s
0 .54 .814 r
.30661 .46008 m .30664 .46009 L .29881 .45855 L p F P
0 g
s
0 .54 .814 r
.29995 .45838 m .30661 .46008 L p .29881 .45855 L F P
0 g
s
0 .54 .814 r
.2944 .45732 m .29995 .45838 L p .29881 .45855 L F P
0 g
s
0 .54 .814 r
.29881 .45855 m .29635 .45795 L .2944 .45732 L p F P
0 g
s
.093 .626 .865 r
.34621 .46689 m .33723 .46611 L .33425 .46526 L p F P
0 g
s
.743 .739 .849 r
.13704 .2864 m .13981 .28463 L .13666 .28129 L p F P
0 g
s
.743 .739 .849 r
.13666 .28129 m .13363 .28321 L .13704 .2864 L p F P
0 g
s
.753 .738 .838 r
.12716 .28761 m .13363 .28321 L .13704 .2864 L p F P
0 g
s
.492 0 0 r
.3773 .35471 m .37773 .35486 L .37708 .35479 L closepath p F P
0 g
s
0 0 0 r
.62022 .42277 m .6147 .42563 L .61308 .42681 L p F P
0 g
s
.869 .444 .201 r
.14571 .37948 m .14416 .3761 L .14081 .37494 L p F P
0 g
s
.613 .045 0 r
.19514 .41709 m .19449 .41684 L .19417 .41659 L closepath p F P
0 g
s
0 .306 .665 r
.27984 .32671 m .28044 .32698 L .27898 .32631 L closepath p F P
0 g
s
.193 0 0 r
.48549 .34846 m .48631 .34782 L .47657 .34946 L p F P
0 g
s
.193 0 0 r
.47657 .34946 m .47476 .35076 L .48549 .34846 L p F P
0 g
s
.133 0 .156 r
.68414 .3758 m .68499 .37295 L .68124 .37566 L p F P
0 g
s
.133 0 .156 r
.67596 .38171 m .68414 .3758 L p .68124 .37566 L F P
0 g
s
.133 0 .156 r
.68124 .37566 m .676 .38157 L .67596 .38171 L p F P
0 g
s
.728 .848 .938 r
.64439 .28561 m .63444 .29035 L .63205 .28861 L p F P
0 g
s
.287 .775 .704 r
.57779 .44232 m .58024 .44155 L .57036 .44527 L p F P
0 g
s
.287 .775 .704 r
.56804 .44601 m .57779 .44232 L p .57036 .44527 L F P
0 g
s
.287 .775 .704 r
.57036 .44527 m .56789 .44606 L .56804 .44601 L p F P
0 g
s
.003 .509 .862 r
.26517 .32054 m .26471 .32029 L .26437 .32019 L closepath p F P
0 g
s
.649 .725 .904 r
.15226 .28353 m .16145 .28055 L .16458 .28378 L p F P
0 g
s
.647 .724 .905 r
.16145 .28055 m .15226 .28353 L .14912 .28024 L p F P
0 g
s
.701 .735 .877 r
.13981 .28463 m .14912 .28024 L .15226 .28353 L p F P
0 g
s
.532 .49 .755 r
.70588 .29983 m .71018 .29558 L .71192 .30061 L closepath p F P
0 g
s
.372 .658 .968 r
.21623 .29744 m .21199 .29699 L .21623 .29981 L p F P
0 g
s
.372 .658 .968 r
.21623 .29981 m .21933 .30008 L .21623 .29744 L p F P
0 g
s
.9 .687 .605 r
.11622 .32734 m .11311 .32471 L .11562 .32968 L closepath p F P
0 g
s
0 .454 .754 r
.27907 .45317 m .27911 .45318 L .2725 .45127 L p F P
0 g
s
0 .454 .754 r
.27304 .45124 m .27907 .45317 L p .2725 .45127 L F P
0 g
s
0 .454 .754 r
.26695 .44953 m .27304 .45124 L p .2725 .45127 L F P
0 g
s
0 .454 .754 r
.2725 .45127 m .26761 .44977 L .26695 .44953 L p F P
0 g
s
.159 .691 .853 r
.4019 .47162 m .40249 .47159 L .41383 .4717 L p F P
0 g
s
.172 .698 .864 r
.4019 .47162 m .40249 .47159 L .40169 .47158 L closepath p F P
0 g
s
.502 0 0 r
.37464 .35596 m .3837 .3569 L .37773 .35486 L p F P
0 g
s
.502 0 0 r
.37433 .35583 m .37464 .35596 L p .37773 .35486 L F P
0 g
s
.502 0 0 r
.37773 .35486 m .37708 .35479 L .37433 .35583 L p F P
0 g
s
0 0 0 r
.66018 .39581 m .65643 .39873 L .65558 .40014 L p F P
0 g
s
0 0 0 r
.52058 .3365 m .52096 .33628 L .51115 .33954 L p F P
0 g
s
0 0 0 r
.51115 .33954 m .51065 .33983 L .52058 .3365 L p F P
0 g
s
.513 0 0 r
.37708 .35479 m .37433 .35583 L .36887 .35385 L closepath p F P
0 g
s
.285 .783 .867 r
.48506 .46583 m .48611 .46588 L .47636 .46763 L p F P
0 g
s
.285 .783 .867 r
.47636 .46763 m .4739 .46753 L .48506 .46583 L p F P
0 g
s
.329 0 0 r
.45245 .35429 m .4517 .35479 L .448 .35475 L closepath p F P
0 g
s
.324 0 0 r
.4502 .35595 m .4517 .35479 L .448 .35475 L p F P
0 g
s
.324 0 0 r
.44274 .35668 m .4502 .35595 L p .448 .35475 L F P
0 g
s
.324 0 0 r
.43926 .35654 m .44274 .35668 L p .448 .35475 L F P
0 g
s
.735 .209 0 r
.17233 .40341 m .1695 .40028 L .17397 .4029 L p F P
0 g
s
.735 .209 0 r
.17523 .40511 m .17233 .40341 L p .17397 .4029 L F P
0 g
s
.735 .209 0 r
.17397 .4029 m .17638 .40555 L .17523 .40511 L p F P
0 g
s
.59 .711 .927 r
.16458 .28378 m .1697 .28281 L .17343 .28585 L p F P
0 g
s
.597 .715 .927 r
.17369 .28202 m .1697 .28281 L .17343 .28585 L p F P
0 g
s
.597 .715 .927 r
.17343 .28585 m .17681 .28516 L .17369 .28202 L p F P
0 g
s
.845 .392 .127 r
.1476 .3829 m .15176 .38567 L .14989 .38224 L p F P
0 g
s
.845 .392 .127 r
.14989 .38224 m .14571 .37948 L .1476 .3829 L p F P
0 g
s
.267 .625 .961 r
.23137 .30442 m .22802 .30381 L .23256 .30649 L p F P
0 g
s
.267 .625 .961 r
.23256 .30649 m .23447 .3068 L .23137 .30442 L p F P
0 g
s
.699 .734 .878 r
.14912 .28024 m .13981 .28463 L .13666 .28129 L p F P
0 g
s
.273 .775 .761 r
.54505 .45328 m .54562 .45318 L .53578 .45607 L p F P
0 g
s
.273 .775 .761 r
.53578 .45607 m .53491 .45624 L .54505 .45328 L p F P
0 g
s
0 .489 .773 r
.29635 .45795 m .2944 .45732 L .29214 .45681 L closepath p F P
0 g
s
.246 .745 .902 r
.42609 .4715 m .41444 .47171 L .41429 .47168 L p F P
0 g
s
.213 .724 .889 r
.41444 .47171 m .41429 .47168 L .41383 .4717 L closepath p F P
0 g
s
.144 .577 .929 r
.2465 .31152 m .24362 .31079 L .24846 .31334 L p F P
0 g
s
.144 .577 .929 r
.24846 .31334 m .24959 .3136 L .2465 .31152 L p F P
0 g
s
.23 .732 .903 r
.41147 .47109 m .40249 .47159 L .41383 .4717 L p F P
0 g
s
.23 .732 .903 r
.41383 .4717 m .41429 .47168 L .41147 .47109 L p F P
0 g
s
.008 .511 .865 r
.26163 .31854 m .25918 .31778 L .26437 .32019 L p F P
0 g
s
.008 .511 .865 r
.26437 .32019 m .26471 .32029 L .26163 .31854 L p F P
0 g
s
.607 .039 0 r
.19125 .41554 m .18944 .41408 L .19417 .41659 L p F P
0 g
s
.607 .039 0 r
.19417 .41659 m .19449 .41684 L .19125 .41554 L p F P
0 g
s
.861 .729 .716 r
.10964 .30844 m .1131 .31159 L .11619 .3064 L p F P
0 g
s
.861 .729 .716 r
.11619 .3064 m .11274 .30324 L .10964 .30844 L p F P
0 g
s
.248 .74 .915 r
.40934 .47064 m .41147 .47109 L .40249 .47159 L p F P
0 g
s
.248 .74 .915 r
.40655 .47059 m .40934 .47064 L p .40249 .47159 L F P
0 g
s
.248 .74 .915 r
.39905 .47099 m .40655 .47059 L p .40249 .47159 L F P
0 g
s
.248 .74 .915 r
.40249 .47159 m .40169 .47158 L .39905 .47099 L p F P
0 g
s
.389 .264 .588 r
.71607 .3258 m .70976 .3317 L .70913 .32698 L p F P
0 g
s
.389 .264 .588 r
.70913 .32698 m .71435 .3221 L .71607 .3258 L p F P
0 g
s
.213 .718 .901 r
.40169 .47158 m .39905 .47099 L .39195 .47121 L closepath p F P
0 g
s
.305 0 0 r
.28005 .32691 m .28551 .32922 L .28044 .32698 L p F P
0 g
s
.305 0 0 r
.27677 .32531 m .28005 .32691 L p .28044 .32698 L F P
0 g
s
0 .393 .737 r
.27677 .32531 m .27498 .32468 L .27856 .32614 L p F P
0 g
s
0 .393 .737 r
.27856 .32614 m .27898 .32631 L .27677 .32531 L p F P
0 g
s
0 .398 .745 r
.27498 .32468 m .27677 .32531 L .27368 .32389 L p F P
0 g
s
.387 0 0 r
.27677 .32531 m .27368 .32389 L p .2742 .32413 L F P
0 g
s
.387 0 0 r
.28005 .32691 m .27677 .32531 L p .2742 .32413 L F P
0 g
s
.305 0 0 r
.28044 .32698 m .27898 .32631 L .27677 .32531 L p F P
0 g
s
0 0 0 r
.60161 .43244 m .60245 .43196 L .59255 .43639 L p F P
0 g
s
0 0 0 r
.59255 .43639 m .5923 .43654 L .60161 .43244 L p F P
0 g
s
.043 0 0 r
.66624 .39074 m .66018 .39581 L .66541 .39245 L closepath p F P
0 g
s
0 0 0 r
.66415 .39456 m .66541 .39245 L .66018 .39581 L p F P
0 g
s
0 0 0 r
.66345 .39512 m .66415 .39456 L p .66018 .39581 L F P
0 g
s
0 0 0 r
.65558 .40014 m .66345 .39512 L p .66018 .39581 L F P
0 g
s
.431 .66 .957 r
.19482 .29061 m .19207 .29052 L .18896 .28751 L p F P
0 g
s
.081 .615 .863 r
.33183 .46455 m .33425 .46526 L .32863 .46462 L p F P
0 g
s
.081 .615 .863 r
.33041 .46428 m .33183 .46455 L p .32863 .46462 L F P
0 g
s
.081 .615 .863 r
.32194 .46333 m .33041 .46428 L p .32863 .46462 L F P
0 g
s
.081 .615 .863 r
.32863 .46462 m .32256 .46352 L .32194 .46333 L p F P
0 g
s
.232 .738 .891 r
.42687 .47148 m .4267 .47145 L .42609 .4715 L closepath p F P
0 g
s
.246 .745 .902 r
.42389 .47092 m .4267 .47145 L .42609 .4715 L p F P
0 g
s
.246 .745 .902 r
.41429 .47168 m .42389 .47092 L p .42609 .4715 L F P
0 g
s
.266 .76 .904 r
.43633 .47048 m .43901 .47094 L .42687 .47148 L p F P
0 g
s
.266 .76 .904 r
.42687 .47148 m .4267 .47145 L .43633 .47048 L p F P
0 g
s
.507 0 0 r
.33773 .34821 m .34505 .3498 L .33984 .34752 L p F P
0 g
s
.507 0 0 r
.33449 .34658 m .33773 .34821 L p .33984 .34752 L F P
0 g
s
.507 0 0 r
.33984 .34752 m .33575 .34653 L .33449 .34658 L p F P
0 g
s
.253 .748 .909 r
.42389 .47092 m .41429 .47168 L .41147 .47109 L p F P
0 g
s
.395 .844 .755 r
.55304 .32286 m .55405 .3226 L .5448 .32685 L p F P
0 g
s
.395 .844 .755 r
.5448 .32685 m .54318 .32734 L .55304 .32286 L p F P
0 g
s
.911 .667 .556 r
.11814 .33912 m .11815 .33907 L .1174 .3337 L p F P
0 g
s
.911 .667 .556 r
.1145 .33607 m .11814 .33912 L p .1174 .3337 L F P
0 g
s
.911 .667 .556 r
.1174 .3337 m .11513 .33179 L .1145 .33607 L p F P
0 g
s
.902 .683 .595 r
.11562 .32968 m .11513 .33179 L .1174 .3337 L closepath p F P
0 g
s
.586 .708 .927 r
.1697 .28281 m .16458 .28378 L .16145 .28055 L p F P
0 g
s
.265 .769 .868 r
.46394 .46902 m .47224 .46774 L .46249 .46893 L closepath p F P
0 g
s
.224 .743 .847 r
.46249 .46893 m .46394 .46902 L p .45152 .47013 L F P
0 g
s
.156 0 .165 r
.676 .38157 m .67572 .38187 L .67596 .38171 L closepath p F P
0 g
s
0 .317 .69 r
.26966 .32232 m .26471 .32029 L .26163 .31854 L p F P
0 g
s
.078 0 .057 r
.67493 .38434 m .6687 .38859 L .67572 .38187 L p F P
0 g
s
.078 0 .057 r
.67572 .38187 m .67596 .38171 L .67493 .38434 L p F P
0 g
s
.333 0 0 r
.24309 .44094 m .23967 .43947 L .23652 .43836 L p F P
0 g
s
.54 0 0 r
.32587 .34412 m .3223 .34239 L .31925 .34211 L p F P
0 g
s
.806 .323 .048 r
.16173 .39336 m .16248 .39444 L .15939 .39255 L closepath p F P
0 g
s
.295 0 0 r
.46153 .35438 m .46373 .35269 L .45245 .35429 L p F P
0 g
s
.295 0 0 r
.46055 .35451 m .46153 .35438 L p .45245 .35429 L F P
0 g
s
.295 0 0 r
.45245 .35429 m .4517 .35479 L .46055 .35451 L p F P
0 g
s
.293 .093 .428 r
.70239 .35056 m .70044 .35215 L .7018 .34738 L p F P
0 g
s
.293 .093 .428 r
.7018 .34738 m .7025 .3468 L .70239 .35056 L p F P
0 g
s
.387 0 0 r
.29608 .33376 m .30201 .33587 L .29696 .3336 L p F P
0 g
s
.387 0 0 r
.29192 .33165 m .29608 .33376 L p .29696 .3336 L F P
0 g
s
.387 0 0 r
.29696 .3336 m .29262 .33188 L .29192 .33165 L p F P
0 g
s
.582 .008 0 r
.19796 .41941 m .19449 .41684 L .19125 .41554 L p F P
0 g
s
0 .537 .797 r
.30968 .46096 m .31388 .46165 L .32106 .46321 L p F P
0 g
s
0 .541 .801 r
.31388 .46165 m .30968 .46096 L .30664 .46009 L p F P
0 g
s
.017 0 0 r
.6687 .38859 m .66624 .39074 L .66541 .39245 L p F P
0 g
s
0 .444 .728 r
.2822 .45414 m .28564 .45501 L .29214 .45681 L p F P
0 g
s
0 .447 .733 r
.28564 .45501 m .2822 .45414 L .27911 .45318 L p F P
0 g
s
.048 0 .045 r
.68377 .37677 m .68414 .3758 L .67596 .38171 L p F P
0 g
s
.048 0 .045 r
.67974 .38089 m .68377 .37677 L p .67596 .38171 L F P
0 g
s
.048 0 .045 r
.67596 .38171 m .67493 .38434 L .67974 .38089 L p F P
0 g
s
.017 0 0 r
.67399 .38628 m .67493 .38434 L .6687 .38859 L p F P
0 g
s
.017 0 0 r
.67236 .38774 m .67399 .38628 L p .6687 .38859 L F P
0 g
s
.017 0 0 r
.66541 .39245 m .67236 .38774 L p .6687 .38859 L F P
0 g
s
.228 .726 .912 r
.39642 .47038 m .39905 .47099 L .39195 .47121 L p F P
0 g
s
.228 .726 .912 r
.39557 .47034 m .39642 .47038 L p .39195 .47121 L F P
0 g
s
.228 .726 .912 r
.38664 .47061 m .39557 .47034 L p .39195 .47121 L F P
0 g
s
.228 .726 .912 r
.39195 .47121 m .38859 .47108 L .38664 .47061 L p F P
0 g
s
.269 .76 .908 r
.43633 .47048 m .4267 .47145 L .42389 .47092 L p F P
0 g
s
.224 .743 .847 r
.45152 .47013 m .45471 .46972 L .46249 .46893 L p F P
0 g
s
.248 .757 .869 r
.45152 .47013 m .45471 .46972 L .45087 .47008 L closepath p F P
0 g
s
.21 .732 .85 r
.45087 .47008 m .45152 .47013 L p .43911 .47095 L F P
0 g
s
.607 .595 .814 r
.7063 .28723 m .69658 .28835 L .69413 .28359 L p F P
0 g
s
.89 .705 .645 r
.10962 .31959 m .11076 .3165 L .1143 .31961 L p F P
0 g
s
.89 .705 .645 r
.1143 .31961 m .11269 .32404 L .10962 .31959 L p F P
0 g
s
.21 .732 .85 r
.43911 .47095 m .43951 .47091 L .45087 .47008 L p F P
0 g
s
.231 .744 .87 r
.43911 .47095 m .43951 .47091 L .43901 .47094 L closepath p F P
0 g
s
.19 .701 .897 r
.38859 .47108 m .38664 .47061 L .38196 .47064 L closepath p F P
0 g
s
.82 .344 .062 r
.15391 .38901 m .15813 .39175 L .15599 .38841 L p F P
0 g
s
.82 .344 .062 r
.15599 .38841 m .15176 .38567 L .15391 .38901 L p F P
0 g
s
.099 .636 .858 r
.34954 .46768 m .35467 .468 L .34681 .46699 L closepath p F P
0 g
s
0 0 0 r
.62459 .42041 m .62022 .42277 L .6242 .42076 L closepath p F P
0 g
s
0 0 0 r
.62229 .42215 m .6242 .42076 L .62022 .42277 L p F P
0 g
s
0 0 0 r
.62034 .42317 m .62229 .42215 L p .62022 .42277 L F P
0 g
s
0 0 0 r
.61308 .42681 m .62034 .42317 L p .62022 .42277 L F P
0 g
s
.286 .762 .648 r
.60007 .43311 m .60161 .43244 L .5923 .43654 L p F P
0 g
s
.286 .762 .648 r
.5923 .43654 m .59015 .43749 L .60007 .43311 L p F P
0 g
s
.506 0 0 r
.37417 .3559 m .37433 .35583 L .36887 .35385 L p F P
0 g
s
.506 0 0 r
.36594 .35488 m .37417 .3559 L p .36887 .35385 L F P
0 g
s
.506 0 0 r
.36201 .35318 m .36594 .35488 L p .36887 .35385 L F P
0 g
s
.506 0 0 r
.36887 .35385 m .36282 .35296 L .36201 .35318 L p F P
0 g
s
.3 .78 .918 r
.43951 .47091 m .43901 .47094 L .43633 .47048 L p F P
0 g
s
0 0 0 r
.5422 .32775 m .54318 .32734 L .53335 .33142 L p F P
0 g
s
0 0 0 r
.53335 .33142 m .53272 .3317 L .5422 .32775 L p F P
0 g
s
.523 0 0 r
.34974 .35003 m .35261 .35129 L .34782 .35033 L closepath p F P
0 g
s
.287 .775 .907 r
.45087 .47008 m .44877 .46976 L .43951 .47091 L closepath p F P
0 g
s
.3 .78 .918 r
.44622 .46935 m .44877 .46976 L .43951 .47091 L p F P
0 g
s
.3 .78 .918 r
.44512 .46942 m .44622 .46935 L p .43951 .47091 L F P
0 g
s
.3 .78 .918 r
.43633 .47048 m .44512 .46942 L p .43951 .47091 L F P
0 g
s
.645 .956 .935 r
.57781 .31247 m .57773 .31247 L .57839 .31213 L closepath p F P
0 g
s
0 .415 .807 r
.25422 .31527 m .24959 .3136 L .2465 .31152 L p F P
0 g
s
.107 0 0 r
.49609 .34566 m .49815 .34422 L .48772 .34689 L p F P
0 g
s
.107 0 0 r
.48772 .34689 m .48631 .34782 L .49609 .34566 L p F P
0 g
s
.329 .812 .871 r
.50834 .46172 m .51064 .46175 L .49992 .46397 L p F P
0 g
s
.329 .812 .871 r
.49992 .46397 m .49854 .46395 L .50834 .46172 L p F P
0 g
s
.427 0 0 r
.22454 .43287 m .22699 .43414 L .23237 .43638 L p F P
0 g
s
.369 0 0 r
.23209 .43656 m .22699 .43414 L .23237 .43638 L p F P
0 g
s
.369 0 0 r
.2352 .43787 m .23209 .43656 L p .23237 .43638 L F P
0 g
s
.369 0 0 r
.23237 .43638 m .23652 .43836 L .2352 .43787 L p F P
0 g
s
.481 0 0 r
.3071 .3374 m .30813 .33792 L .31427 .33994 L p F P
0 g
s
.456 0 0 r
.31289 .34031 m .30813 .33792 L .31427 .33994 L p F P
0 g
s
.456 0 0 r
.31909 .3421 m .31289 .34031 L p .31427 .33994 L F P
0 g
s
.456 0 0 r
.31427 .33994 m .31925 .34211 L .31909 .3421 L p F P
0 g
s
.424 0 0 r
.22699 .43414 m .22454 .43287 L .22136 .43172 L p F P
0 g
s
.272 .077 .423 r
.70828 .34546 m .70239 .35056 L .7025 .3468 L p F P
0 g
s
.272 .077 .423 r
.7025 .3468 m .70952 .34071 L .70828 .34546 L p F P
0 g
s
.491 0 0 r
.38963 .35647 m .39344 .3576 L .38802 .35725 L closepath p F P
0 g
s
.508 0 0 r
.21199 .42695 m .20947 .42538 L .20626 .42417 L p F P
0 g
s
.703 .953 .953 r
.6074 .2968 m .60981 .29762 L .59992 .30278 L p F P
0 g
s
.703 .953 .953 r
.60315 .2991 m .6074 .2968 L p .59992 .30278 L F P
0 g
s
.703 .953 .953 r
.59992 .30278 m .59845 .30242 L .60315 .2991 L p F P
0 g
s
.256 0 0 r
.46414 .35239 m .4672 .35207 L .46373 .35269 L closepath p F P
0 g
s
.905 .687 .597 r
.11513 .33179 m .11562 .32968 L .11311 .32471 L p F P
0 g
s
.602 .95 .903 r
.57839 .31213 m .57773 .31247 L .57527 .31252 L p F P
0 g
s
0 0 0 r
.51837 .33782 m .52058 .3365 L .51065 .33983 L p F P
0 g
s
0 0 0 r
.51065 .33983 m .50854 .34107 L .51837 .33782 L p F P
0 g
s
.194 0 .295 r
.69511 .36263 m .69371 .36376 L .69419 .36048 L p F P
0 g
s
.194 0 .295 r
.69419 .36048 m .69819 .35725 L .69511 .36263 L p F P
0 g
s
.672 .711 .877 r
.66914 .28222 m .67919 .27861 L .68159 .28217 L p F P
0 g
s
.684 .734 .888 r
.67919 .27861 m .66914 .28222 L .66675 .27925 L p F P
0 g
s
.695 .758 .9 r
.65674 .28342 m .66675 .27925 L .66914 .28222 L p F P
0 g
s
.463 .885 .795 r
.56306 .31798 m .5654 .31751 L .55554 .32222 L p F P
0 g
s
.463 .885 .795 r
.55554 .32222 m .55405 .3226 L .56306 .31798 L p F P
0 g
s
.208 .71 .908 r
.38376 .46988 m .38664 .47061 L .38196 .47064 L p F P
0 g
s
.208 .71 .908 r
.37425 .46996 m .38376 .46988 L p .38196 .47064 L F P
0 g
s
.208 .71 .908 r
.38196 .47064 m .37511 .47018 L .37425 .46996 L p F P
0 g
s
.276 0 0 r
.24858 .44311 m .24309 .44094 L .24873 .44308 L p F P
0 g
s
.276 0 0 r
.24873 .44308 m .25172 .44425 L .24858 .44311 L p F P
0 g
s
.457 0 0 r
.21654 .42953 m .21199 .42695 L .21712 .42929 L p F P
0 g
s
.457 0 0 r
.22089 .43155 m .21654 .42953 L p .21712 .42929 L F P
0 g
s
.457 0 0 r
.21712 .42929 m .22136 .43172 L .22089 .43155 L p F P
0 g
s
0 .494 .782 r
.29134 .45629 m .28564 .45501 L .29214 .45681 L p F P
0 g
s
0 .494 .782 r
.29214 .45681 m .2944 .45732 L .29134 .45629 L p F P
0 g
s
.716 .182 0 r
.17638 .40555 m .17683 .40602 L .18147 .40858 L p F P
0 g
s
.652 .096 0 r
.18017 .40898 m .18478 .41155 L .18147 .40858 L p F P
0 g
s
.652 .096 0 r
.18147 .40858 m .17683 .40602 L .18017 .40898 L p F P
0 g
s
.629 .955 .926 r
.5876 .30743 m .57839 .31213 L .58649 .30736 L closepath p F P
0 g
s
.602 .95 .903 r
.58516 .30729 m .58649 .30736 L .57839 .31213 L p F P
0 g
s
.602 .95 .903 r
.57527 .31252 m .58516 .30729 L p .57839 .31213 L F P
0 g
s
.481 0 0 r
.33575 .34653 m .33449 .34658 L .33276 .34586 L closepath p F P
0 g
s
.72 .907 .961 r
.63149 .28889 m .62213 .29365 L .61972 .29238 L p F P
0 g
s
.644 .66 .851 r
.69316 .28186 m .69054 .28442 L p .68159 .28217 L F P
0 g
s
.627 .647 .85 r
.69054 .28442 m .69316 .28186 L .69413 .28359 L closepath p F P
0 g
s
.79 .743 .81 r
.12297 .29131 m .12716 .28761 L .12399 .28424 L p F P
0 g
s
.79 .743 .81 r
.12399 .28424 m .1196 .2881 L .12297 .29131 L p F P
0 g
s
.806 .741 .792 r
.11416 .29354 m .1196 .2881 L .12297 .29131 L p F P
0 g
s
.806 .741 .792 r
.12297 .29131 m .11734 .29697 L .11416 .29354 L p F P
0 g
s
0 .395 .704 r
.26761 .44977 m .26695 .44953 L .26633 .44934 L closepath p F P
0 g
s
.026 .574 .833 r
.32256 .46352 m .32194 .46333 L .32106 .46321 L closepath p F P
0 g
s
.067 .519 .898 r
.23447 .3068 m .23897 .30815 L .24362 .31079 L p F P
0 g
s
.053 .502 .891 r
.23897 .30815 m .23447 .3068 L .23137 .30442 L p F P
0 g
s
.315 .805 .824 r
.53149 .45655 m .53321 .4564 L .52338 .45908 L p F P
0 g
s
.315 .805 .824 r
.52338 .45908 m .52116 .45928 L .53149 .45655 L p F P
0 g
s
.255 .766 .785 r
.52116 .45928 m .52338 .45908 L p .51097 .46173 L F P
0 g
s
.426 .322 .633 r
.71666 .31991 m .71435 .3221 L .71146 .31882 L p F P
0 g
s
.426 .322 .633 r
.71146 .31882 m .71572 .31477 L .71666 .31991 L p F P
0 g
s
.708 .802 .923 r
.66436 .27652 m .66675 .27925 L .65674 .28342 L p F P
0 g
s
.708 .802 .923 r
.65747 .27958 m .66436 .27652 L p .65674 .28342 L F P
0 g
s
.708 .802 .923 r
.65674 .28342 m .65513 .28177 L .65747 .27958 L p F P
0 g
s
.753 .74 .841 r
.13363 .28321 m .12716 .28761 L .12399 .28424 L p F P
0 g
s
.644 .66 .851 r
.68159 .28217 m .6917 .2793 L .69316 .28186 L p F P
0 g
s
.657 .684 .863 r
.6917 .2793 m .68159 .28217 L .67919 .27861 L p F P
0 g
s
.914 .581 .399 r
.12242 .3541 m .12623 .35705 L .12569 .35318 L p F P
0 g
s
.914 .581 .399 r
.12569 .35318 m .12188 .35023 L .12242 .3541 L p F P
0 g
s
.722 .926 .96 r
.61083 .29805 m .60981 .29762 L .61526 .29473 L closepath p F P
0 g
s
.917 .614 .454 r
.11812 .34724 m .12188 .35023 L .12169 .34623 L p F P
0 g
s
.917 .614 .454 r
.12169 .34623 m .11794 .34324 L .11812 .34724 L p F P
0 g
s
.746 .225 0 r
.16072 .39495 m .16508 .39763 L .16248 .39444 L p F P
0 g
s
.746 .225 0 r
.15842 .39213 m .16072 .39495 L p .16248 .39444 L F P
0 g
s
.746 .225 0 r
.16248 .39444 m .15939 .39255 L .15842 .39213 L p F P
0 g
s
.907 .545 .341 r
.1271 .36081 m .13097 .36373 L .13011 .35997 L p F P
0 g
s
.907 .545 .341 r
.13011 .35997 m .12623 .35705 L .1271 .36081 L p F P
0 g
s
.167 .683 .891 r
.37511 .47018 m .37425 .46996 L .37239 .46993 L closepath p F P
0 g
s
.521 .694 .947 r
.17681 .28516 m .18585 .28448 L .18896 .28751 L p F P
0 g
s
.517 .691 .947 r
.18585 .28448 m .17681 .28516 L .17369 .28202 L p F P
0 g
s
.323 .806 .768 r
.56789 .44606 m .56789 .44606 L .5581 .44948 L p F P
0 g
s
.323 .806 .768 r
.5581 .44948 m .55801 .4495 L .56789 .44606 L p F P
0 g
s
.831 .741 .765 r
.11673 .29771 m .11734 .29697 L .11416 .29354 L p F P
0 g
s
.507 0 0 r
.36282 .35296 m .36201 .35318 L .36058 .35263 L closepath p F P
0 g
s
.039 .581 .845 r
.31894 .46236 m .31388 .46165 L .32106 .46321 L p F P
0 g
s
.039 .581 .845 r
.32106 .46321 m .32194 .46333 L .31894 .46236 L p F P
0 g
s
.538 0 0 r
.20199 .42215 m .19796 .41941 L .20285 .42185 L p F P
0 g
s
.538 0 0 r
.20509 .42371 m .20199 .42215 L p .20285 .42185 L F P
0 g
s
.538 0 0 r
.20285 .42185 m .20626 .42417 L .20509 .42371 L p F P
0 g
s
.315 .792 .917 r
.45471 .46972 m .45087 .47008 L .44877 .46976 L p F P
0 g
s
.878 .721 .683 r
.10728 .31336 m .11076 .3165 L .1131 .31159 L p F P
0 g
s
.878 .721 .683 r
.1131 .31159 m .10964 .30844 L .10728 .31336 L p F P
0 g
s
.908 .663 .555 r
.11815 .33907 m .11814 .33912 L .11815 .33912 L closepath p F P
0 g
s
0 0 0 r
.63308 .416 m .63449 .41474 L .62459 .42041 L p F P
0 g
s
0 0 0 r
.62459 .42041 m .6242 .42076 L .63308 .416 L p F P
0 g
s
.915 .643 .51 r
.11815 .33912 m .11814 .33914 L .11814 .33912 L closepath p F P
0 g
s
.363 .213 .54 r
.71011 .33606 m .70985 .33629 L .70916 .33223 L p F P
0 g
s
.363 .213 .54 r
.70916 .33223 m .70976 .3317 L .71011 .33606 L p F P
0 g
s
.918 .646 .509 r
.11427 .34021 m .1145 .33607 L .11814 .33912 L p F P
0 g
s
.918 .646 .509 r
.1161 .34174 m .11427 .34021 L p .11814 .33912 L F P
0 g
s
.918 .646 .509 r
.11814 .33912 m .11814 .33914 L .1161 .34174 L p F P
0 g
s
.917 .643 .508 r
.11814 .33914 m .11794 .34324 L .1161 .34174 L closepath p F P
0 g
s
.342 .821 .829 r
.54308 .45347 m .54505 .45328 L .53491 .45624 L p F P
0 g
s
.342 .821 .829 r
.53491 .45624 m .53321 .4564 L .54308 .45347 L p F P
0 g
s
0 .403 .717 r
.26385 .44839 m .26043 .44731 L .26633 .44934 L p F P
0 g
s
0 .403 .717 r
.26633 .44934 m .26695 .44953 L .26385 .44839 L p F P
0 g
s
.896 .506 .28 r
.13214 .36739 m .13607 .37028 L .1349 .36662 L p F P
0 g
s
.896 .506 .28 r
.1349 .36662 m .13097 .36373 L .13214 .36739 L p F P
0 g
s
.831 .741 .765 r
.11416 .29354 m .11337 .2945 L .11673 .29771 L p F P
0 g
s
.845 .738 .746 r
.10936 .30005 m .11274 .30324 L .11673 .29771 L p F P
0 g
s
.845 .738 .746 r
.11673 .29771 m .11337 .2945 L .10936 .30005 L p F P
0 g
s
.336 .815 .782 r
.56789 .44606 m .55801 .4495 L .5555 .45 L p F P
0 g
s
.3 .792 .767 r
.54562 .45318 m .5555 .45 L .55801 .4495 L p F P
0 g
s
.115 .651 .858 r
.36189 .46899 m .3633 .46904 L .37239 .46993 L p F P
0 g
s
.18 .689 .901 r
.37135 .46916 m .3633 .46904 L .37239 .46993 L p F P
0 g
s
.18 .689 .901 r
.37239 .46993 m .37425 .46996 L .37135 .46916 L p F P
0 g
s
.484 0 0 r
.33084 .34646 m .32587 .34412 L .33276 .34586 L p F P
0 g
s
.484 0 0 r
.33191 .34672 m .33084 .34646 L p .33276 .34586 L F P
0 g
s
.484 0 0 r
.33276 .34586 m .33449 .34658 L .33191 .34672 L p F P
0 g
s
.21 .584 .944 r
.21933 .30008 m .22365 .30105 L .22802 .30381 L p F P
0 g
s
.198 .571 .939 r
.22365 .30105 m .21933 .30008 L .21623 .29744 L p F P
0 g
s
.264 0 0 r
.4672 .35207 m .46373 .35269 L .46153 .35438 L p F P
0 g
s
.124 .656 .866 r
.36189 .46899 m .3633 .46904 L .3612 .46883 L closepath p F P
0 g
s
.458 0 0 r
.3071 .3374 m .30813 .33792 L .306 .33716 L closepath p F P
0 g
s
.431 .66 .957 r
.18896 .28751 m .191 .28761 L .19482 .29061 L p F P
0 g
s
.448 .674 .96 r
.19795 .28783 m .191 .28761 L .19482 .29061 L p F P
0 g
s
.448 .674 .96 r
.19482 .29061 m .20106 .29074 L .19795 .28783 L p F P
0 g
s
.513 0 0 r
.35783 .35359 m .35261 .35129 L .36058 .35263 L p F P
0 g
s
.513 0 0 r
.3597 .35388 m .35783 .35359 L p .36058 .35263 L F P
0 g
s
.513 0 0 r
.36058 .35263 m .36201 .35318 L .3597 .35388 L p F P
0 g
s
.327 0 0 r
.4517 .35479 m .46055 .35451 L .4502 .35595 L closepath p F P
0 g
s
.472 0 0 r
.402 .35755 m .40394 .35802 L .4013 .35796 L closepath p F P
0 g
s
.303 .787 .906 r
.46249 .46893 m .46122 .46876 L .45471 .46972 L closepath p F P
0 g
s
.315 .792 .917 r
.45848 .46836 m .46122 .46876 L .45471 .46972 L p F P
0 g
s
.315 .792 .917 r
.44877 .46976 m .45848 .46836 L p .45471 .46972 L F P
0 g
s
.287 0 0 r
.29262 .33188 m .29192 .33165 L .29127 .3314 L closepath p F P
0 g
s
.059 0 0 r
.50833 .34121 m .50854 .34107 L .49874 .34382 L p F P
0 g
s
.059 0 0 r
.49874 .34382 m .49815 .34422 L .50833 .34121 L p F P
0 g
s
.905 .687 .597 r
.11155 .32871 m .11513 .33179 L p .11311 .32471 L F P
0 g
s
.915 .671 .555 r
.11092 .33299 m .1145 .33607 L .11513 .33179 L p F P
0 g
s
.915 .671 .555 r
.11513 .33179 m .11155 .32871 L .11092 .33299 L p F P
0 g
s
.878 .46 .213 r
.13746 .37368 m .13607 .37028 L .14006 .37314 L p F P
0 g
s
.878 .46 .213 r
.14006 .37314 m .14081 .37494 L .13746 .37368 L p F P
0 g
s
0 0 0 r
.54065 .32842 m .5422 .32775 L .53272 .3317 L p F P
0 g
s
0 0 0 r
.53272 .3317 m .53079 .33257 L .54065 .32842 L p F P
0 g
s
.345 .2 .537 r
.71674 .32988 m .71011 .33606 L .70976 .3317 L p F P
0 g
s
.345 .2 .537 r
.70976 .3317 m .71607 .3258 L .71674 .32988 L p F P
0 g
s
0 .441 .749 r
.27304 .45124 m .26695 .44953 L .26385 .44839 L p F P
0 g
s
.086 .615 .871 r
.33041 .46428 m .32194 .46333 L .31894 .46236 L p F P
0 g
s
.725 .827 .929 r
.65436 .28097 m .64439 .28561 L .642 .28365 L p F P
0 g
s
.728 .848 .938 r
.63205 .28861 m .642 .28365 L .64439 .28561 L p F P
0 g
s
0 0 0 r
.64544 .40742 m .64439 .40858 L .65249 .40318 L closepath p F P
0 g
s
.895 .699 .631 r
.11269 .32404 m .11261 .32428 L .11311 .32471 L closepath p F P
0 g
s
.905 .687 .597 r
.11311 .32471 m .11261 .32428 L .11155 .32871 L p F P
0 g
s
.092 0 .133 r
.68595 .37443 m .68414 .3758 L .68499 .37295 L p F P
0 g
s
.092 0 .133 r
.68499 .37295 m .69102 .36836 L .68595 .37443 L p F P
0 g
s
0 0 0 r
.63498 .4143 m .63449 .41474 L .63872 .41218 L closepath p F P
0 g
s
0 .398 .745 r
.27368 .32389 m .26966 .32232 L .27498 .32468 L p F P
0 g
s
0 .484 .849 r
.25854 .31674 m .25422 .31527 L .25918 .31778 L p F P
0 g
s
0 .484 .849 r
.25918 .31778 m .26163 .31854 L .25854 .31674 L p F P
0 g
s
.24 .017 .361 r
.70209 .35406 m .69819 .35725 L .70044 .35215 L p F P
0 g
s
.24 .017 .361 r
.70044 .35215 m .70239 .35056 L .70209 .35406 L p F P
0 g
s
.119 .557 .919 r
.24341 .30938 m .23897 .30815 L .24362 .31079 L p F P
0 g
s
.119 .557 .919 r
.24362 .31079 m .2465 .31152 L .24341 .30938 L p F P
0 g
s
.742 .74 .85 r
.13363 .28321 m .13666 .28129 L .13349 .27796 L p F P
0 g
s
.742 .74 .85 r
.13349 .27796 m .13028 .27998 L .13363 .28321 L p F P
0 g
s
.753 .74 .841 r
.12399 .28424 m .13028 .27998 L .13363 .28321 L p F P
0 g
s
.332 .63 .96 r
.20417 .2936 m .20789 .29411 L .21199 .29699 L p F P
0 g
s
.359 .648 .965 r
.21313 .29475 m .20789 .29411 L .21199 .29699 L p F P
0 g
s
.359 .648 .965 r
.21199 .29699 m .21623 .29744 L .21313 .29475 L p F P
0 g
s
.285 0 0 r
.28885 .33063 m .28551 .32922 L .29127 .3314 L p F P
0 g
s
.285 0 0 r
.29127 .3314 m .29192 .33165 L .28885 .33063 L p F P
0 g
s
.255 .766 .785 r
.51097 .46173 m .51546 .46063 L .52116 .45928 L p F P
0 g
s
.296 .793 .827 r
.51097 .46173 m .51546 .46063 L .51064 .46175 L closepath p F P
0 g
s
.256 0 0 r
.47476 .35076 m .47386 .35142 L .4672 .35207 L closepath p F P
0 g
s
.264 0 0 r
.47261 .35249 m .47386 .35142 L .4672 .35207 L p F P
0 g
s
.264 0 0 r
.46153 .35438 m .47261 .35249 L p .4672 .35207 L F P
0 g
s
.249 .611 .955 r
.22827 .30199 m .22365 .30105 L .22802 .30381 L p F P
0 g
s
.249 .611 .955 r
.22802 .30381 m .23137 .30442 L .22827 .30199 L p F P
0 g
s
.608 .041 0 r
.18801 .41419 m .18478 .41155 L .18944 .41408 L p F P
0 g
s
.608 .041 0 r
.18944 .41408 m .19125 .41554 L .18801 .41419 L p F P
0 g
s
.323 .62 .957 r
.20789 .29411 m .20417 .2936 L .20106 .29074 L p F P
0 g
s
.727 .197 0 r
.16793 .40075 m .17233 .40341 L .1695 .40028 L p F P
0 g
s
.727 .197 0 r
.1695 .40028 m .16508 .39763 L .16793 .40075 L p F P
0 g
s
.897 .703 .632 r
.11261 .32428 m .11269 .32404 L .10962 .31959 L p F P
0 g
s
.57 .939 .881 r
.56589 .31747 m .5654 .31751 L .56996 .3152 L closepath p F P
0 g
s
.317 .794 .714 r
.5803 .44153 m .58024 .44155 L .58162 .44099 L closepath p F P
0 g
s
.374 0 0 r
.43926 .35654 m .44274 .35668 L .43852 .3571 L closepath p F P
0 g
s
.869 .444 .201 r
.14081 .37494 m .14159 .37668 L .14571 .37948 L p F P
0 g
s
.844 .388 .113 r
.14349 .38009 m .1476 .3829 L .14571 .37948 L p F P
0 g
s
.844 .388 .113 r
.14571 .37948 m .14159 .37668 L .14349 .38009 L p F P
0 g
s
.447 0 0 r
.4144 .35793 m .41538 .35811 L .4141 .35813 L closepath p F P
0 g
s
0 0 0 r
.65558 .40014 m .65428 .40191 L .66345 .39512 L closepath p F P
0 g
s
.897 .703 .632 r
.10962 .31959 m .10911 .32116 L .11261 .32428 L p F P
0 g
s
.908 .691 .597 r
.10804 .3256 m .11155 .32871 L .11261 .32428 L p F P
0 g
s
.908 .691 .597 r
.11261 .32428 m .10911 .32116 L .10804 .3256 L p F P
0 g
s
.207 .703 .917 r
.36938 .46859 m .37135 .46916 L .3633 .46904 L p F P
0 g
s
.207 .703 .917 r
.36648 .46828 m .36938 .46859 L p .3633 .46904 L F P
0 g
s
.207 .703 .917 r
.35896 .46817 m .36648 .46828 L p .3633 .46904 L F P
0 g
s
.207 .703 .917 r
.3633 .46904 m .3612 .46883 L .35896 .46817 L p F P
0 g
s
0 .532 .812 r
.29995 .45838 m .2944 .45732 L .29134 .45629 L p F P
0 g
s
.607 .595 .814 r
.70667 .28686 m .7063 .28723 L p .69413 .28359 L F P
0 g
s
.607 .595 .814 r
.69413 .28359 m .70434 .28186 L .70667 .28686 L p F P
0 g
s
.607 .637 .855 r
.69316 .28186 m .69413 .28359 L .70434 .28186 L p F P
0 g
s
0 0 0 r
.63222 .41661 m .63308 .416 L .6242 .42076 L p F P
0 g
s
0 0 0 r
.6242 .42076 m .62229 .42215 L .63222 .41661 L p F P
0 g
s
.326 .801 .723 r
.58162 .44099 m .58024 .44155 L .57779 .44232 L p F P
0 g
s
.647 .724 .905 r
.14912 .28024 m .15832 .27731 L .16145 .28055 L p F P
0 g
s
.645 .723 .905 r
.15832 .27731 m .14912 .28024 L .14597 .27694 L p F P
0 g
s
.699 .734 .878 r
.13666 .28129 m .14597 .27694 L .14912 .28024 L p F P
0 g
s
.586 .708 .927 r
.16145 .28055 m .16608 .27971 L .1697 .28281 L p F P
0 g
s
.593 .712 .927 r
.17056 .27885 m .16608 .27971 L .1697 .28281 L p F P
0 g
s
.593 .712 .927 r
.1697 .28281 m .17369 .28202 L .17056 .27885 L p F P
0 g
s
0 0 0 r
.61078 .42812 m .61236 .42722 L .60245 .43196 L p F P
0 g
s
0 0 0 r
.60245 .43196 m .60161 .43244 L .61078 .42812 L p F P
0 g
s
.329 .803 .915 r
.47224 .46774 m .46249 .46893 L .46122 .46876 L p F P
0 g
s
.483 0 0 r
.30674 .33828 m .31289 .34031 L .30813 .33792 L p F P
0 g
s
.483 0 0 r
.30404 .33677 m .30674 .33828 L p .30813 .33792 L F P
0 g
s
.483 0 0 r
.30813 .33792 m .306 .33716 L .30404 .33677 L p F P
0 g
s
.22 .714 .919 r
.38376 .46988 m .37425 .46996 L .37135 .46916 L p F P
0 g
s
.414 0 0 r
.42682 .3576 m .4281 .35774 L .42649 .35783 L closepath p F P
0 g
s
.163 .674 .899 r
.3612 .46883 m .35896 .46817 L .35467 .468 L closepath p F P
0 g
s
0 .447 .733 r
.27911 .45318 m .27916 .45319 L .28564 .45501 L p F P
0 g
s
0 .498 .79 r
.2867 .45484 m .27916 .45319 L .28564 .45501 L p F P
0 g
s
0 .498 .79 r
.28974 .45573 m .2867 .45484 L p .28564 .45501 L F P
0 g
s
0 .498 .79 r
.28564 .45501 m .29134 .45629 L .28974 .45573 L p F P
0 g
s
.698 .734 .879 r
.14597 .27694 m .13666 .28129 L .13349 .27796 L p F P
0 g
s
.478 0 0 r
.29608 .33376 m .29192 .33165 L .28885 .33063 L p F P
0 g
s
.863 .733 .717 r
.10624 .30525 m .10964 .30844 L .11274 .30324 L p F P
0 g
s
.863 .733 .717 r
.11274 .30324 m .10936 .30005 L .10624 .30525 L p F P
0 g
s
.712 .176 0 r
.17638 .40555 m .17683 .40602 L .17523 .40511 L closepath p F P
0 g
s
.36 .83 .882 r
.51546 .46063 m .51064 .46175 L .50834 .46172 L p F P
0 g
s
.541 0 0 r
.36201 .35318 m .36594 .35488 L .3597 .35388 L closepath p F P
0 g
s
.424 0 0 r
.22136 .43172 m .22166 .43188 L .22699 .43414 L p F P
0 g
s
.336 0 0 r
.22682 .43427 m .23209 .43656 L .22699 .43414 L p F P
0 g
s
.336 0 0 r
.22699 .43414 m .22166 .43188 L .22682 .43427 L p F P
0 g
s
0 0 0 r
.59015 .43749 m .58162 .44099 L .58977 .43765 L closepath p F P
0 g
s
.326 .801 .723 r
.58772 .43828 m .58977 .43765 L .58162 .44099 L p F P
0 g
s
.326 .801 .723 r
.57779 .44232 m .58772 .43828 L p .58162 .44099 L F P
0 g
s
.044 .584 .849 r
.31559 .46131 m .30669 .46009 L .31388 .46165 L p F P
0 g
s
.044 .584 .849 r
.31618 .46145 m .31559 .46131 L p .31388 .46165 L F P
0 g
s
.044 .584 .849 r
.31388 .46165 m .31894 .46236 L .31618 .46145 L p F P
0 g
s
0 .541 .801 r
.30664 .46009 m .30669 .46009 L .31388 .46165 L p F P
0 g
s
.333 0 0 r
.23652 .43836 m .2375 .43879 L .24309 .44094 L p F P
0 g
s
.268 0 0 r
.24324 .441 m .2375 .43879 L .24309 .44094 L p F P
0 g
s
.268 0 0 r
.24309 .44094 m .24858 .44311 L .24836 .44303 L p F P
0 g
s
.268 0 0 r
.24836 .44303 m .24324 .441 L p .24309 .44094 L F P
0 g
s
.537 0 0 r
.34998 .35219 m .35783 .35359 L .35261 .35129 L p F P
0 g
s
.537 0 0 r
.34672 .35053 m .34998 .35219 L p .35261 .35129 L F P
0 g
s
.537 0 0 r
.35261 .35129 m .34782 .35033 L .34672 .35053 L p F P
0 g
s
.709 .941 .959 r
.61526 .29473 m .60981 .29762 L .6074 .2968 L p F P
0 g
s
.456 0 0 r
.41538 .35811 m .4141 .35813 L .41171 .35975 L p F P
0 g
s
.489 0 0 r
.4109 .35975 m .41171 .35975 L .4141 .35813 L p F P
0 g
s
.489 0 0 r
.4141 .35813 m .40394 .35802 L .4109 .35975 L p F P
0 g
s
.539 0 0 r
.33449 .34658 m .33773 .34821 L .33191 .34672 L closepath p F P
0 g
s
.463 0 0 r
.42649 .35783 m .41538 .35811 L .42313 .35956 L p F P
0 g
s
.456 0 0 r
.41171 .35975 m .42313 .35956 L .41538 .35811 L p F P
0 g
s
0 0 0 r
.53029 .33286 m .53079 .33257 L .52096 .33628 L p F P
0 g
s
0 0 0 r
.52096 .33628 m .52058 .3365 L .53029 .33286 L p F P
0 g
s
.818 .34 .046 r
.14975 .38623 m .15391 .38901 L .15176 .38567 L p F P
0 g
s
.818 .34 .046 r
.15176 .38567 m .1476 .3829 L .14975 .38623 L p F P
0 g
s
.779 .275 0 r
.15939 .39255 m .15842 .39213 L .15813 .39175 L closepath p F P
0 g
s
.335 .815 .877 r
.50679 .46168 m .50834 .46172 L .49854 .46395 L p F P
0 g
s
.335 .815 .877 r
.49854 .46395 m .49604 .4639 L .50679 .46168 L p F P
0 g
s
.285 .785 .85 r
.49604 .4639 m .49854 .46395 L p .48611 .46588 L F P
0 g
s
.66 .964 .925 r
.59506 .30183 m .59749 .30219 L .5876 .30743 L p F P
0 g
s
.66 .964 .925 r
.59393 .30245 m .59506 .30183 L p .5876 .30743 L F P
0 g
s
.66 .964 .925 r
.5876 .30743 m .58649 .30736 L .59393 .30245 L p F P
0 g
s
.481 0 0 r
.39983 .35952 m .4109 .35975 L .40394 .35802 L p F P
0 g
s
.481 0 0 r
.39908 .35929 m .39983 .35952 L p .40394 .35802 L F P
0 g
s
.481 0 0 r
.40394 .35802 m .4013 .35796 L .39908 .35929 L p F P
0 g
s
.583 .705 .927 r
.16608 .27971 m .16145 .28055 L .15832 .27731 L p F P
0 g
s
.071 0 0 r
.50617 .34281 m .50833 .34121 L .49815 .34422 L p F P
0 g
s
.071 0 0 r
.49983 .34464 m .50617 .34281 L p .49815 .34422 L F P
0 g
s
.071 0 0 r
.49815 .34422 m .49609 .34566 L .49983 .34464 L p F P
0 g
s
.508 0 0 r
.20626 .42417 m .20691 .42458 L .21199 .42695 L p F P
0 g
s
.425 0 0 r
.21151 .42715 m .21654 .42953 L .21199 .42695 L p F P
0 g
s
.425 0 0 r
.21199 .42695 m .20691 .42458 L .21151 .42715 L p F P
0 g
s
.509 .461 .739 r
.71192 .30061 m .71423 .30117 L .71263 .30282 L closepath p F P
0 g
s
.484 .424 .714 r
.71995 .30344 m .71443 .30914 L .71263 .30282 L p F P
0 g
s
.484 .424 .714 r
.71263 .30282 m .71423 .30117 L .71995 .30344 L p F P
0 g
s
.501 .472 .757 r
.71018 .29558 m .71192 .30061 L .71423 .30117 L p F P
0 g
s
.424 .654 .955 r
.191 .28761 m .18896 .28751 L .18585 .28448 L p F P
0 g
s
0 0 0 r
.66541 .39245 m .66415 .39456 L .67236 .38774 L closepath p F P
0 g
s
.507 0 0 r
.4013 .35796 m .39908 .35929 L .39344 .3576 L closepath p F P
0 g
s
.54 0 0 r
.31925 .34211 m .31942 .3422 L .32587 .34412 L p F P
0 g
s
.55 0 0 r
.32398 .3447 m .33084 .34646 L .32587 .34412 L p F P
0 g
s
.55 0 0 r
.32587 .34412 m .31942 .3422 L .32398 .3447 L p F P
0 g
s
.468 .389 .684 r
.71393 .30962 m .71443 .30914 L .71464 .31003 L closepath p F P
0 g
s
.308 .798 .775 r
.55502 .45009 m .5555 .45 L .54562 .45318 L p F P
0 g
s
.308 .798 .775 r
.54562 .45318 m .54505 .45328 L .55502 .45009 L p F P
0 g
s
.893 .71 .647 r
.10651 .31542 m .10728 .31336 L .11076 .3165 L p F P
0 g
s
.893 .71 .647 r
.11076 .3165 m .10962 .31959 L .10651 .31542 L p F P
0 g
s
.236 0 0 r
.25172 .44425 m .25458 .44525 L .26043 .44731 L p F P
0 g
s
0 .356 .673 r
.25458 .44525 m .25172 .44425 L .24858 .44311 L p F P
0 g
s
.72 .907 .961 r
.62966 .28713 m .63194 .28854 L .63149 .28889 L p F P
0 g
s
.72 .907 .961 r
.61972 .29238 m .62966 .28713 L p .63149 .28889 L F P
0 g
s
.725 .889 .955 r
.63205 .28861 m .63149 .28889 L .63194 .28854 L closepath p F P
0 g
s
.414 0 0 r
.306 .33716 m .30404 .33677 L .30201 .33587 L closepath p F P
0 g
s
0 0 0 r
.61308 .42681 m .61236 .42722 L .62034 .42317 L closepath p F P
0 g
s
.423 0 0 r
.4281 .35774 m .42649 .35783 L .4242 .35953 L p F P
0 g
s
.463 0 0 r
.42313 .35956 m .4242 .35953 L .42649 .35783 L p F P
0 g
s
0 0 0 r
.63872 .41218 m .63449 .41474 L .63308 .416 L p F P
0 g
s
.24 .73 .922 r
.39557 .47034 m .38664 .47061 L .38376 .46988 L p F P
0 g
s
.512 .912 .829 r
.56996 .3152 m .5654 .31751 L .56306 .31798 L p F P
0 g
s
.62 .057 0 r
.17562 .40638 m .18017 .40898 L .17683 .40602 L p F P
0 g
s
.62 .057 0 r
.17311 .40415 m .17562 .40638 L p .17683 .40602 L F P
0 g
s
.62 .057 0 r
.17683 .40602 m .17523 .40511 L .17311 .40415 L p F P
0 g
s
.428 0 0 r
.43852 .3571 m .43643 .35872 L .4281 .35774 L closepath p F P
0 g
s
.423 0 0 r
.43629 .35884 m .43643 .35872 L .4281 .35774 L p F P
0 g
s
.423 0 0 r
.4242 .35953 m .43629 .35884 L p .4281 .35774 L F P
0 g
s
.628 .653 .855 r
.6917 .2793 m .69654 .27817 L .69316 .28186 L closepath p F P
0 g
s
.607 .637 .855 r
.70188 .27701 m .69654 .27817 L .69316 .28186 L p F P
0 g
s
.607 .637 .855 r
.70434 .28186 m .70188 .27701 L p .69316 .28186 L F P
0 g
s
.733 .891 .951 r
.63968 .28193 m .642 .28365 L .63205 .28861 L p F P
0 g
s
.733 .891 .951 r
.63205 .28861 m .63194 .28854 L .63968 .28193 L p F P
0 g
s
.093 .626 .865 r
.33425 .46526 m .33827 .4656 L .34621 .46689 L p F P
0 g
s
.094 .626 .866 r
.33425 .46526 m .33827 .4656 L .33183 .46455 L closepath p F P
0 g
s
.21 0 0 r
.48362 .34995 m .48549 .34846 L .47476 .35076 L p F P
0 g
s
.21 0 0 r
.47476 .35076 m .47386 .35142 L .48362 .34995 L p F P
0 g
s
.541 .513 .774 r
.70934 .29334 m .7121 .29356 L .71018 .29558 L closepath p F P
0 g
s
.501 .472 .757 r
.71979 .2949 m .7121 .29356 L .71018 .29558 L p F P
0 g
s
.501 .472 .757 r
.71991 .29527 m .71979 .2949 L p .71018 .29558 L F P
0 g
s
.501 .472 .757 r
.71423 .30117 m .71991 .29527 L p .71018 .29558 L F P
0 g
s
.322 .788 .671 r
.55146 .32346 m .55304 .32286 L .54318 .32734 L p F P
0 g
s
.322 .788 .671 r
.54318 .32734 m .5422 .32775 L .55146 .32346 L p F P
0 g
s
.872 .448 .199 r
.14159 .37668 m .14081 .37494 L .13746 .37368 L p F P
0 g
s
0 .404 .721 r
.26073 .44722 m .25458 .44525 L .26043 .44731 L p F P
0 g
s
0 .404 .721 r
.26043 .44731 m .26385 .44839 L .26073 .44722 L p F P
0 g
s
.184 .685 .911 r
.35602 .46727 m .35896 .46817 L .35467 .468 L p F P
0 g
s
.184 .685 .911 r
.34659 .46692 m .35602 .46727 L p .35467 .468 L F P
0 g
s
.184 .685 .911 r
.35467 .468 m .34681 .46699 L .34659 .46692 L p F P
0 g
s
.708 .803 .924 r
.65513 .28177 m .65436 .28097 L .65747 .27958 L closepath p F P
0 g
s
.501 0 0 r
.39879 .35948 m .39908 .35929 L .39344 .3576 L p F P
0 g
s
.501 0 0 r
.38961 .35898 m .39879 .35948 L p .39344 .3576 L F P
0 g
s
.501 0 0 r
.38668 .35793 m .38961 .35898 L p .39344 .3576 L F P
0 g
s
.501 0 0 r
.39344 .3576 m .38802 .35725 L .38668 .35793 L p F P
0 g
s
.702 .954 .952 r
.59845 .30242 m .59749 .30219 L .60315 .2991 L closepath p F P
0 g
s
.734 .892 .951 r
.63961 .28188 m .63968 .28193 L .63194 .28854 L p F P
0 g
s
.734 .892 .951 r
.63194 .28854 m .62966 .28713 L .63961 .28188 L p F P
0 g
s
.217 0 .354 r
.7062 .3505 m .70209 .35406 L .70239 .35056 L p F P
0 g
s
.217 0 .354 r
.70239 .35056 m .70828 .34546 L .7062 .3505 L p F P
0 g
s
.432 .365 .682 r
.72257 .30515 m .71995 .30344 L .71443 .30914 L p F P
0 g
s
.432 .365 .682 r
.72306 .30732 m .72257 .30515 L p .71443 .30914 L F P
0 g
s
.432 .365 .682 r
.71798 .31249 m .72306 .30732 L p .71443 .30914 L F P
0 g
s
.432 .365 .682 r
.71443 .30914 m .71464 .31003 L .71798 .31249 L p F P
0 g
s
.317 .798 .903 r
.4739 .46753 m .47366 .46751 L .47224 .46774 L closepath p F P
0 g
s
.329 .803 .915 r
.47096 .46713 m .47366 .46751 L .47224 .46774 L p F P
0 g
s
.329 .803 .915 r
.46122 .46876 m .47096 .46713 L p .47224 .46774 L F P
0 g
s
.164 0 0 r
.49594 .34579 m .49609 .34566 L .48631 .34782 L p F P
0 g
s
.164 0 0 r
.48631 .34782 m .48549 .34846 L .49594 .34579 L p F P
0 g
s
.557 .521 .771 r
.7121 .29356 m .70934 .29334 L .70681 .28719 L p F P
0 g
s
.582 .008 0 r
.19125 .41554 m .19312 .41694 L .19796 .41941 L p F P
0 g
s
.515 0 0 r
.19719 .41967 m .20199 .42215 L .19796 .41941 L p F P
0 g
s
.515 0 0 r
.19796 .41941 m .19312 .41694 L .19719 .41967 L p F P
0 g
s
.285 .785 .85 r
.48611 .46588 m .49459 .46416 L .49604 .4639 L p F P
0 g
s
.317 .803 .88 r
.48611 .46588 m .49459 .46416 L .48506 .46583 L closepath p F P
0 g
s
.777 .272 0 r
.15512 .39062 m .15391 .38901 L .15813 .39175 L p F P
0 g
s
.777 .272 0 r
.15813 .39175 m .15842 .39213 L .15512 .39062 L p F P
0 g
s
.446 .364 .67 r
.71464 .31003 m .71798 .31249 L .71572 .31477 L closepath p F P
0 g
s
.519 0 0 r
.38802 .35725 m .38668 .35793 L .3837 .3569 L closepath p F P
0 g
s
.183 0 .286 r
.7016 .35732 m .69511 .36263 L .69819 .35725 L p F P
0 g
s
.183 0 .286 r
.69819 .35725 m .70209 .35406 L .7016 .35732 L p F P
0 g
s
.525 0 0 r
.34782 .35033 m .34672 .35053 L .34505 .3498 L closepath p F P
0 g
s
0 0 0 r
.52822 .33409 m .53029 .33286 L .52058 .3365 L p F P
0 g
s
0 0 0 r
.52058 .3365 m .51837 .33782 L .52822 .33409 L p F P
0 g
s
.347 .815 .913 r
.48342 .46564 m .48506 .46583 L .4739 .46753 L p F P
0 g
s
.347 .815 .913 r
.4739 .46753 m .47366 .46751 L .48342 .46564 L p F P
0 g
s
.346 .823 .868 r
.52116 .45928 m .52079 .45928 L .51546 .46063 L closepath p F P
0 g
s
.36 .83 .882 r
.51818 .45924 m .52079 .45928 L .51546 .46063 L p F P
0 g
s
.36 .83 .882 r
.50834 .46172 m .51818 .45924 L p .51546 .46063 L F P
0 g
s
.918 .583 .394 r
.11866 .35111 m .12242 .3541 L .12188 .35023 L p F P
0 g
s
.918 .583 .394 r
.12188 .35023 m .11812 .34724 L .11866 .35111 L p F P
0 g
s
.245 .738 .916 r
.39905 .47099 m .40655 .47059 L .39642 .47038 L closepath p F P
0 g
s
0 .317 .69 r
.26163 .31854 m .26458 .31986 L .26966 .32232 L p F P
0 g
s
0 .297 .684 r
.26458 .31986 m .26163 .31854 L .25854 .31674 L p F P
0 g
s
.381 0 0 r
.44274 .35668 m .43852 .3571 L .43643 .35872 L p F P
0 g
s
.807 .744 .794 r
.11097 .29016 m .1163 .28486 L .1196 .2881 L p F P
0 g
s
.807 .744 .794 r
.1196 .2881 m .11416 .29354 L .11097 .29016 L p F P
0 g
s
.79 .745 .811 r
.1196 .2881 m .12399 .28424 L .1208 .2809 L p F P
0 g
s
.79 .745 .811 r
.1208 .2809 m .1163 .28486 L .1196 .2881 L p F P
0 g
s
.46 .883 .791 r
.56291 .31801 m .56306 .31798 L .55405 .3226 L p F P
0 g
s
.46 .883 .791 r
.55405 .3226 m .55304 .32286 L .56291 .31801 L p F P
0 g
s
.684 .734 .888 r
.66675 .27925 m .67679 .27533 L .67919 .27861 L p F P
0 g
s
.696 .756 .898 r
.67679 .27533 m .66675 .27925 L .66436 .27652 L p F P
0 g
s
.657 .684 .863 r
.67919 .27861 m .68929 .27537 L .6917 .2793 L p F P
0 g
s
.67 .707 .875 r
.68929 .27537 m .67919 .27861 L .67679 .27533 L p F P
0 g
s
.91 .547 .334 r
.12328 .35785 m .1271 .36081 L .12623 .35705 L p F P
0 g
s
.91 .547 .334 r
.12623 .35705 m .12242 .3541 L .12328 .35785 L p F P
0 g
s
.921 .616 .448 r
.11443 .34421 m .11812 .34724 L .11794 .34324 L p F P
0 g
s
.921 .616 .448 r
.11432 .34172 m .11443 .34421 L p .11794 .34324 L F P
0 g
s
.921 .616 .448 r
.11794 .34324 m .1161 .34174 L .11432 .34172 L p F P
0 g
s
.317 .145 .483 r
.71023 .34009 m .70952 .34071 L .70985 .33629 L p F P
0 g
s
.317 .145 .483 r
.70985 .33629 m .71011 .33606 L .71023 .34009 L p F P
0 g
s
0 0 0 r
.64439 .40858 m .63872 .41218 L .64372 .40932 L closepath p F P
0 g
s
0 0 0 r
.64215 .41071 m .64372 .40932 L .63872 .41218 L p F P
0 g
s
0 0 0 r
.63942 .41238 m .64215 .41071 L p .63872 .41218 L F P
0 g
s
0 0 0 r
.63308 .416 m .63942 .41238 L p .63872 .41218 L F P
0 g
s
.753 .742 .842 r
.13028 .27998 m .12399 .28424 L .1208 .2809 L p F P
0 g
s
.526 .007 0 r
.3801 .35819 m .37464 .35596 L .3837 .3569 L p F P
0 g
s
.526 .007 0 r
.38539 .35866 m .3801 .35819 L p .3837 .3569 L F P
0 g
s
.526 .007 0 r
.3837 .3569 m .38668 .35793 L .38539 .35866 L p F P
0 g
s
.126 0 .206 r
.69371 .36376 m .69342 .36507 L .69511 .36263 L closepath p F P
0 g
s
.58 .007 0 r
.19312 .41694 m .19125 .41554 L .18801 .41419 L p F P
0 g
s
.898 .507 .272 r
.12827 .36447 m .13214 .36739 L .13097 .36373 L p F P
0 g
s
.898 .507 .272 r
.13097 .36373 m .1271 .36081 L .12827 .36447 L p F P
0 g
s
.72 .926 .96 r
.61972 .29238 m .61526 .29473 L .61891 .29203 L closepath p F P
0 g
s
.709 .941 .959 r
.61732 .29135 m .61891 .29203 L .61526 .29473 L p F P
0 g
s
.709 .941 .959 r
.6074 .2968 m .61732 .29135 L p .61526 .29473 L F P
0 g
s
.321 0 0 r
.23652 .43836 m .2375 .43879 L .2352 .43787 L closepath p F P
0 g
s
.763 .249 0 r
.16072 .39495 m .15842 .39213 L .15512 .39062 L p F P
0 g
s
0 .366 .722 r
.26971 .32206 m .26458 .31986 L .26966 .32232 L p F P
0 g
s
0 .366 .722 r
.2718 .32299 m .26971 .32206 L p .26966 .32232 L F P
0 g
s
0 .366 .722 r
.26966 .32232 m .27368 .32389 L .2718 .32299 L p F P
0 g
s
.322 0 0 r
.28498 .32921 m .28005 .32691 L .28551 .32922 L p F P
0 g
s
.322 0 0 r
.28669 .32988 m .28498 .32921 L p .28551 .32922 L F P
0 g
s
.322 0 0 r
.28551 .32922 m .28885 .33063 L .28669 .32988 L p F P
0 g
s
.671 .122 0 r
.17523 .40511 m .17311 .40415 L .17233 .40341 L closepath p F P
0 g
s
.832 .743 .766 r
.11337 .2945 m .11416 .29354 L .11097 .29016 L p F P
0 g
s
.922 .651 .508 r
.11068 .33714 m .11427 .34021 L .1145 .33607 L p F P
0 g
s
.922 .651 .508 r
.1145 .33607 m .11092 .33299 L .11068 .33714 L p F P
0 g
s
.296 .13 .479 r
.71647 .33429 m .71023 .34009 L .71011 .33606 L p F P
0 g
s
.296 .13 .479 r
.71011 .33606 m .71674 .32988 L .71647 .33429 L p F P
0 g
s
0 .415 .807 r
.2465 .31152 m .24946 .31268 L .25422 .31527 L p F P
0 g
s
0 .396 .799 r
.24946 .31268 m .2465 .31152 L .24341 .30938 L p F P
0 g
s
.88 .725 .684 r
.10387 .31018 m .10728 .31336 L .10964 .30844 L p F P
0 g
s
.88 .725 .684 r
.10964 .30844 m .10624 .30525 L .10387 .31018 L p F P
0 g
s
0 0 0 r
.67493 .38434 m .67399 .38628 L .67974 .38089 L closepath p F P
0 g
s
.351 .816 .918 r
.48342 .46564 m .47366 .46751 L .47096 .46713 L p F P
0 g
s
.529 0 0 r
.34259 .35062 m .33773 .34821 L .34505 .3498 L p F P
0 g
s
.529 0 0 r
.34444 .351 m .34259 .35062 L p .34505 .3498 L F P
0 g
s
.529 0 0 r
.34505 .3498 m .34672 .35053 L .34444 .351 L p F P
0 g
s
.386 0 0 r
.4502 .35595 m .44891 .35698 L .44274 .35668 L closepath p F P
0 g
s
.381 0 0 r
.44806 .35776 m .44891 .35698 L .44274 .35668 L p F P
0 g
s
.381 0 0 r
.43704 .35877 m .44806 .35776 L p .44274 .35668 L F P
0 g
s
.381 0 0 r
.43643 .35872 m .43704 .35877 L p .44274 .35668 L F P
0 g
s
.373 .84 .84 r
.55297 .45028 m .55502 .45009 L .54505 .45328 L p F P
0 g
s
.373 .84 .84 r
.54505 .45328 m .54308 .45347 L .55297 .45028 L p F P
0 g
s
0 .459 .833 r
.25495 .31472 m .24946 .31268 L .25422 .31527 L p F P
0 g
s
0 .459 .833 r
.25624 .31536 m .25495 .31472 L p .25422 .31527 L F P
0 g
s
0 .459 .833 r
.25422 .31527 m .25854 .31674 L .25624 .31536 L p F P
0 g
s
.517 .691 .947 r
.17369 .28202 m .18272 .2814 L .18585 .28448 L p F P
0 g
s
.514 .687 .945 r
.18272 .2814 m .17369 .28202 L .17056 .27885 L p F P
0 g
s
.253 .748 .909 r
.42193 .47054 m .42389 .47092 L p .41147 .47109 L F P
0 g
s
.253 .748 .909 r
.41147 .47109 m .41829 .47058 L .42193 .47054 L p F P
0 g
s
.265 .753 .918 r
.41147 .47109 m .41829 .47058 L .40934 .47064 L closepath p F P
0 g
s
0 .457 .749 r
.27911 .45318 m .27916 .45319 L .27907 .45317 L closepath p F P
0 g
s
0 .549 .815 r
.30664 .46009 m .30669 .46009 L .30661 .46008 L closepath p F P
0 g
s
.424 .654 .955 r
.18585 .28448 m .18728 .28456 L .191 .28761 L p F P
0 g
s
.44 .667 .958 r
.19483 .28488 m .18728 .28456 L .191 .28761 L p F P
0 g
s
.44 .667 .958 r
.191 .28761 m .19795 .28783 L .19483 .28488 L p F P
0 g
s
.832 .743 .766 r
.11097 .29016 m .11006 .29126 L .11337 .2945 L p F P
0 g
s
.847 .741 .747 r
.10604 .29681 m .10936 .30005 L .11337 .2945 L p F P
0 g
s
.847 .741 .747 r
.11337 .2945 m .11006 .29126 L .10604 .29681 L p F P
0 g
s
.386 .263 .588 r
.7173 .32464 m .71607 .3258 L .71435 .3221 L p F P
0 g
s
.386 .263 .588 r
.71435 .3221 m .71666 .31991 L .7173 .32464 L p F P
0 g
s
.542 .928 .86 r
.57527 .31252 m .56996 .3152 L .57473 .31259 L closepath p F P
0 g
s
.512 .912 .829 r
.5728 .31286 m .57473 .31259 L .56996 .3152 L p F P
0 g
s
.512 .912 .829 r
.56427 .31729 m .5728 .31286 L p .56996 .3152 L F P
0 g
s
.512 .912 .829 r
.56306 .31798 m .56427 .31729 L p .56996 .3152 L F P
0 g
s
.094 .614 .882 r
.30864 .45966 m .31559 .46131 L .30669 .46009 L p F P
0 g
s
.094 .614 .882 r
.30361 .45898 m .30864 .45966 L p .30669 .46009 L F P
0 g
s
.094 .614 .882 r
.30669 .46009 m .30661 .46008 L .30361 .45898 L p F P
0 g
s
0 .538 .834 r
.28041 .45294 m .2867 .45484 L .27916 .45319 L p F P
0 g
s
0 .538 .834 r
.27603 .45199 m .28041 .45294 L p .27916 .45319 L F P
0 g
s
0 .538 .834 r
.27916 .45319 m .27907 .45317 L .27603 .45199 L p F P
0 g
s
.137 .654 .891 r
.34681 .46699 m .34659 .46692 L .34621 .46689 L closepath p F P
0 g
s
.411 0 0 r
.30093 .33611 m .29608 .33376 L .30201 .33587 L p F P
0 g
s
.411 0 0 r
.30099 .33613 m .30093 .33611 L p .30201 .33587 L F P
0 g
s
.411 0 0 r
.30201 .33587 m .30404 .33677 L .30099 .33613 L p F P
0 g
s
.032 .569 .85 r
.30661 .46008 m .30361 .45898 L .29995 .45838 L closepath p F P
0 g
s
0 .483 .791 r
.27907 .45317 m .27603 .45199 L .27304 .45124 L closepath p F P
0 g
s
.323 .787 .665 r
.61001 .42845 m .61078 .42812 L .60161 .43244 L p F P
0 g
s
.323 .787 .665 r
.60161 .43244 m .60007 .43311 L .61001 .42845 L p F P
0 g
s
.881 .464 .21 r
.13359 .37096 m .13214 .36739 L .13607 .37028 L p F P
0 g
s
.881 .464 .21 r
.13708 .37352 m .13359 .37096 L p .13607 .37028 L F P
0 g
s
.881 .464 .21 r
.13607 .37028 m .13746 .37368 L .13708 .37352 L p F P
0 g
s
.153 .66 .902 r
.34363 .46594 m .33827 .4656 L .34621 .46689 L p F P
0 g
s
.153 .66 .902 r
.34621 .46689 m .34659 .46692 L .34363 .46594 L p F P
0 g
s
.053 .502 .891 r
.23137 .30442 m .23449 .30543 L .23897 .30815 L p F P
0 g
s
.097 .538 .91 r
.2403 .30718 m .23449 .30543 L .23897 .30815 L p F P
0 g
s
.097 .538 .91 r
.23897 .30815 m .24341 .30938 L .2403 .30718 L p F P
0 g
s
.9 .707 .634 r
.10911 .32116 m .10962 .31959 L .10651 .31542 L p F P
0 g
s
.04 .486 .884 r
.23449 .30543 m .23137 .30442 L .22827 .30199 L p F P
0 g
s
.708 .823 .936 r
.65747 .27958 m .65436 .28097 L .65197 .27876 L p F P
0 g
s
.725 .827 .929 r
.642 .28365 m .65197 .27876 L .65436 .28097 L p F P
0 g
s
.33 .803 .915 r
.47096 .46713 m .46122 .46876 L .45848 .46836 L p F P
0 g
s
.484 .424 .714 r
.72172 .30162 m .71995 .30344 L .71423 .30117 L p F P
0 g
s
.484 .424 .714 r
.71423 .30117 m .71991 .29527 L .72172 .30162 L p F P
0 g
s
.356 .826 .78 r
.56789 .44606 m .56789 .44606 L .56804 .44601 L closepath p F P
0 g
s
.348 .825 .835 r
.54166 .45359 m .54308 .45347 L .53321 .4564 L p F P
0 g
s
.348 .825 .835 r
.53321 .4564 m .53149 .45655 L .54166 .45359 L p F P
0 g
s
.607 .041 0 r
.18373 .41187 m .18017 .40898 L .18478 .41155 L p F P
0 g
s
.607 .041 0 r
.18727 .41386 m .18373 .41187 L p .18478 .41155 L F P
0 g
s
.607 .041 0 r
.18478 .41155 m .18801 .41419 L .18727 .41386 L p F P
0 g
s
.368 .835 .793 r
.56804 .44601 m .56789 .44606 L .5654 .44655 L p F P
0 g
s
.336 .815 .782 r
.5555 .45 m .5654 .44655 L .56789 .44606 L p F P
0 g
s
.283 .767 .92 r
.42389 .47092 m .43104 .47022 L .42193 .47054 L closepath p F P
0 g
s
.269 .76 .908 r
.43421 .4701 m .43633 .47048 L p .42389 .47092 L F P
0 g
s
.269 .76 .908 r
.42389 .47092 m .43104 .47022 L .43421 .4701 L p F P
0 g
s
.918 .675 .554 r
.1074 .32988 m .11092 .33299 L .11155 .32871 L p F P
0 g
s
.918 .675 .554 r
.11155 .32871 m .10804 .3256 L .1074 .32988 L p F P
0 g
s
.302 .786 .719 r
.57779 .44232 m .56804 .44601 L .57752 .4424 L closepath p F P
0 g
s
.368 .835 .793 r
.57532 .44283 m .57752 .4424 L .56804 .44601 L p F P
0 g
s
.368 .835 .793 r
.5654 .44655 m .57532 .44283 L p .56804 .44601 L F P
0 g
s
.198 .571 .939 r
.21623 .29744 m .21943 .29822 L .22365 .30105 L p F P
0 g
s
.233 .597 .95 r
.22517 .2995 m .21943 .29822 L .22365 .30105 L p F P
0 g
s
.233 .597 .95 r
.22365 .30105 m .22827 .30199 L .22517 .2995 L p F P
0 g
s
.579 .57 .807 r
.7063 .28723 m .70667 .28686 L .70681 .28719 L closepath p F P
0 g
s
.196 .688 .922 r
.35602 .46727 m .34659 .46692 L .34363 .46594 L p F P
0 g
s
.413 0 0 r
.22136 .43172 m .22166 .43188 L .22089 .43155 L closepath p F P
0 g
s
.323 .62 .957 r
.20106 .29074 m .20391 .29118 L .20789 .29411 L p F P
0 g
s
.347 .639 .962 r
.21001 .29201 m .20391 .29118 L .20789 .29411 L p F P
0 g
s
.347 .639 .962 r
.20789 .29411 m .21313 .29475 L .21001 .29201 L p F P
0 g
s
.537 .002 0 r
.37433 .35583 m .37464 .35596 L .37417 .3559 L closepath p F P
0 g
s
.719 .186 0 r
.16358 .39805 m .16793 .40075 L .16508 .39763 L p F P
0 g
s
.719 .186 0 r
.16508 .39763 m .16072 .39495 L .16358 .39805 L p F P
0 g
s
.498 0 0 r
.20626 .42417 m .20691 .42458 L .20509 .42371 L closepath p F P
0 g
s
.319 .793 .92 r
.45795 .46827 m .45848 .46836 L .44877 .46976 L p F P
0 g
s
.319 .793 .92 r
.44877 .46976 m .44622 .46935 L .45795 .46827 L p F P
0 g
s
.411 .311 .631 r
.72072 .31584 m .71666 .31991 L .71572 .31477 L p F P
0 g
s
.411 .311 .631 r
.71572 .31477 m .71798 .31249 L .72072 .31584 L p F P
0 g
s
.301 .78 .92 r
.43633 .47048 m .44512 .46942 L .43421 .4701 L closepath p F P
0 g
s
.64 .656 .85 r
.69654 .27817 m .6917 .2793 L .68929 .27537 L p F P
0 g
s
.528 0 0 r
.31925 .34211 m .31942 .3422 L .31909 .3421 L closepath p F P
0 g
s
.187 .559 .934 r
.21943 .29822 m .21623 .29744 L .21313 .29475 L p F P
0 g
s
0 0 0 r
.62034 .42317 m .61236 .42722 L .61078 .42812 L p F P
0 g
s
0 0 0 r
.65249 .40318 m .64439 .40858 L .64372 .40932 L p F P
0 g
s
.548 0 0 r
.31757 .34276 m .32398 .3447 L .31942 .3422 L p F P
0 g
s
.548 0 0 r
.31619 .34193 m .31757 .34276 L p .31942 .3422 L F P
0 g
s
.548 0 0 r
.31942 .3422 m .31909 .3421 L .31619 .34193 L p F P
0 g
s
.557 .521 .771 r
.7174 .28794 m .7121 .29356 L p .70681 .28719 L F P
0 g
s
.557 .521 .771 r
.70681 .28719 m .71718 .28735 L .7174 .28794 L p F P
0 g
s
.551 .554 .81 r
.70667 .28686 m .70681 .28719 L .71718 .28735 L p F P
0 g
s
.872 .448 .199 r
.13746 .37368 m .13753 .37384 L .14159 .37668 L p F P
0 g
s
.843 .384 .097 r
.13944 .37726 m .14349 .38009 L .14159 .37668 L p F P
0 g
s
.843 .384 .097 r
.14159 .37668 m .13753 .37384 L .13944 .37726 L p F P
0 g
s
.546 .017 0 r
.37136 .35716 m .3801 .35819 L .37464 .35596 L p F P
0 g
s
.546 .017 0 r
.37464 .35596 m .37417 .3559 L .37136 .35716 L p F P
0 g
s
0 .379 .716 r
.23778 .43878 m .24324 .441 L .2375 .43879 L p F P
0 g
s
0 .379 .716 r
.23336 .43709 m .23778 .43878 L p .2375 .43879 L F P
0 g
s
0 .379 .716 r
.2375 .43879 m .2352 .43787 L .23336 .43709 L p F P
0 g
s
.284 0 0 r
.22161 .43195 m .22682 .43427 L .22166 .43188 L p F P
0 g
s
.284 0 0 r
.21817 .43036 m .22161 .43195 L p .22166 .43188 L F P
0 g
s
.284 0 0 r
.22166 .43188 m .22089 .43155 L .21817 .43036 L p F P
0 g
s
.333 0 0 r
.46055 .35451 m .4502 .35595 L .44891 .35698 L p F P
0 g
s
.742 .741 .851 r
.13028 .27998 m .13349 .27796 L .13032 .27464 L p F P
0 g
s
.742 .741 .851 r
.13032 .27464 m .127 .27672 L .13028 .27998 L p F P
0 g
s
.753 .742 .842 r
.1208 .2809 m .127 .27672 L .13028 .27998 L p F P
0 g
s
.504 0 0 r
.31909 .3421 m .31619 .34193 L .31289 .34031 L closepath p F P
0 g
s
.554 .027 0 r
.37128 .35715 m .37136 .35716 L .37417 .3559 L p F P
0 g
s
.554 .027 0 r
.37417 .3559 m .36594 .35488 L .37128 .35715 L p F P
0 g
s
.551 .554 .81 r
.71464 .28105 m .71176 .28118 L .70667 .28686 L p F P
0 g
s
.551 .554 .81 r
.71718 .28735 m .71464 .28105 L p .70667 .28686 L F P
0 g
s
.583 .583 .818 r
.70434 .28186 m .71176 .28118 L .70667 .28686 L closepath p F P
0 g
s
.733 .928 .955 r
.62726 .28583 m .62966 .28713 L .61972 .29238 L p F P
0 g
s
.733 .928 .955 r
.62494 .28711 m .62726 .28583 L p .61972 .29238 L F P
0 g
s
.733 .928 .955 r
.61972 .29238 m .61891 .29203 L .62494 .28711 L p F P
0 g
s
.376 .84 .878 r
.53064 .45656 m .53149 .45655 L .52116 .45928 L p F P
0 g
s
.376 .84 .878 r
.52116 .45928 m .52079 .45928 L .53064 .45656 L p F P
0 g
s
.123 0 .204 r
.70121 .3591 m .7016 .35732 L .69511 .36263 L p F P
0 g
s
.123 0 .204 r
.69961 .36144 m .70121 .3591 L p .69511 .36263 L F P
0 g
s
.123 0 .204 r
.69303 .3668 m .69961 .36144 L p .69511 .36263 L F P
0 g
s
.123 0 .204 r
.69511 .36263 m .69342 .36507 L .69303 .3668 L p F P
0 g
s
.52 .482 .754 r
.7121 .29356 m .7174 .28794 L .71979 .2949 L closepath p F P
0 g
s
.658 .964 .923 r
.58649 .30736 m .58516 .30729 L .59393 .30245 L closepath p F P
0 g
s
.9 .707 .634 r
.10651 .31542 m .10566 .318 L .10911 .32116 L p F P
0 g
s
.911 .695 .597 r
.10458 .32245 m .10804 .3256 L .10911 .32116 L p F P
0 g
s
.911 .695 .597 r
.10911 .32116 m .10566 .318 L .10458 .32245 L p F P
0 g
s
.293 .767 .655 r
.59908 .43353 m .60007 .43311 L .59015 .43749 L p F P
0 g
s
.293 .767 .655 r
.59015 .43749 m .58977 .43765 L .59908 .43353 L p F P
0 g
s
.68 .961 .941 r
.60315 .2991 m .59749 .30219 L .59506 .30183 L p F P
0 g
s
.583 .705 .927 r
.15832 .27731 m .16255 .27655 L .16608 .27971 L p F P
0 g
s
.589 .709 .927 r
.16742 .27565 m .16255 .27655 L .16608 .27971 L p F P
0 g
s
.589 .709 .927 r
.16608 .27971 m .17056 .27885 L .16742 .27565 L p F P
0 g
s
.361 0 0 r
.22089 .43155 m .21817 .43036 L .21654 .42953 L closepath p F P
0 g
s
.923 .623 .456 r
.1161 .34174 m .11432 .34172 L .11427 .34021 L closepath p F P
0 g
s
.372 0 0 r
.20654 .42473 m .21151 .42715 L .20691 .42458 L p F P
0 g
s
.372 0 0 r
.20305 .42279 m .20654 .42473 L p .20691 .42458 L F P
0 g
s
.372 0 0 r
.20691 .42458 m .20509 .42371 L .20305 .42279 L p F P
0 g
s
.254 0 0 r
.48337 .35018 m .48362 .34995 L .47386 .35142 L p F P
0 g
s
.254 0 0 r
.47386 .35142 m .47261 .35249 L .48337 .35018 L p F P
0 g
s
.708 .799 .922 r
.66436 .27652 m .65747 .27958 L .66258 .27464 L closepath p F P
0 g
s
.708 .823 .936 r
.66198 .27401 m .66258 .27464 L .65747 .27958 L p F P
0 g
s
.708 .823 .936 r
.65197 .27876 m .66198 .27401 L p .65747 .27958 L F P
0 g
s
.018 0 0 r
.51829 .33788 m .51837 .33782 L .50854 .34107 L p F P
0 g
s
.018 0 0 r
.50854 .34107 m .50833 .34121 L .51829 .33788 L p F P
0 g
s
0 .356 .673 r
.24858 .44311 m .24877 .44318 L .25458 .44525 L p F P
0 g
s
0 .41 .733 r
.2552 .44517 m .24877 .44318 L .25458 .44525 L p F P
0 g
s
0 .41 .733 r
.26051 .44713 m .2552 .44517 L p .25458 .44525 L F P
0 g
s
0 .41 .733 r
.25458 .44525 m .26073 .44722 L .26051 .44713 L p F P
0 g
s
.315 .612 .954 r
.20391 .29118 m .20106 .29074 L .19795 .28783 L p F P
0 g
s
.645 .723 .905 r
.14597 .27694 m .15517 .27404 L .15832 .27731 L p F P
0 g
s
.644 .722 .905 r
.15517 .27404 m .14597 .27694 L .14281 .27363 L p F P
0 g
s
.698 .734 .879 r
.13349 .27796 m .14281 .27363 L .14597 .27694 L p F P
0 g
s
.321 .786 .667 r
.55052 .32383 m .55146 .32346 L .5422 .32775 L p F P
0 g
s
.321 .786 .667 r
.5422 .32775 m .54065 .32842 L .55052 .32383 L p F P
0 g
s
.181 0 0 r
.49389 .34756 m .49594 .34579 L .48549 .34846 L p F P
0 g
s
.181 0 0 r
.48718 .34921 m .49389 .34756 L p .48549 .34846 L F P
0 g
s
.181 0 0 r
.48549 .34846 m .48362 .34995 L .48718 .34921 L p F P
0 g
s
.375 .831 .922 r
.49459 .46416 m .48506 .46583 L .48342 .46564 L p F P
0 g
s
.865 .736 .719 r
.10291 .30203 m .10624 .30525 L .10936 .30005 L p F P
0 g
s
.865 .736 .719 r
.10936 .30005 m .10604 .29681 L .10291 .30203 L p F P
0 g
s
.816 .334 .03 r
.14565 .38343 m .14975 .38623 L .1476 .3829 L p F P
0 g
s
.816 .334 .03 r
.1476 .3829 m .14349 .38009 L .14565 .38343 L p F P
0 g
s
.697 .734 .879 r
.14281 .27363 m .13349 .27796 L .13032 .27464 L p F P
0 g
s
.579 .944 .865 r
.58336 .30738 m .58516 .30729 L .57527 .31252 L p F P
0 g
s
.579 .944 .865 r
.57527 .31252 m .57473 .31259 L .58336 .30738 L p F P
0 g
s
.568 .015 0 r
.34672 .35053 m .34998 .35219 L .34444 .351 L closepath p F P
0 g
s
.146 0 .212 r
.69342 .36507 m .69102 .36836 L .69303 .3668 L closepath p F P
0 g
s
.732 .867 .944 r
.64959 .27675 m .65197 .27876 L .642 .28365 L p F P
0 g
s
.732 .867 .944 r
.6399 .28173 m .64959 .27675 L p .642 .28365 L F P
0 g
s
.732 .867 .944 r
.642 .28365 m .63968 .28193 L .6399 .28173 L p F P
0 g
s
.18 .675 .917 r
.34066 .46493 m .34363 .46594 L .33827 .4656 L p F P
0 g
s
.18 .675 .917 r
.33127 .46435 m .34066 .46493 L p .33827 .4656 L F P
0 g
s
.18 .675 .917 r
.33827 .4656 m .33183 .46455 L .33127 .46435 L p F P
0 g
s
.556 0 0 r
.33536 .34899 m .34259 .35062 L .33773 .34821 L p F P
0 g
s
.556 0 0 r
.33145 .34675 m .33536 .34899 L p .33773 .34821 L F P
0 g
s
.556 0 0 r
.33773 .34821 m .33191 .34672 L .33145 .34675 L p F P
0 g
s
.013 0 .028 r
.68414 .3758 m .68377 .37677 L .68595 .37443 L closepath p F P
0 g
s
.667 .117 0 r
.16985 .4026 m .16793 .40075 L .17233 .40341 L p F P
0 g
s
.667 .117 0 r
.17233 .40341 m .17311 .40415 L .16985 .4026 L p F P
0 g
s
.216 .705 .925 r
.36648 .46828 m .35896 .46817 L .35602 .46727 L p F P
0 g
s
.031 0 0 r
.51616 .33949 m .51829 .33788 L .50833 .34121 L p F P
0 g
s
.031 0 0 r
.50833 .34121 m .50617 .34281 L .51616 .33949 L p F P
0 g
s
.382 .843 .885 r
.53064 .45656 m .52079 .45928 L .51818 .45924 L p F P
0 g
s
0 .31 .655 r
.2352 .43787 m .23336 .43709 L .23209 .43656 L closepath p F P
0 g
s
0 .441 .749 r
.26385 .44839 m .26697 .44927 L .27304 .45124 L p F P
0 g
s
0 .445 .756 r
.26697 .44927 m .26385 .44839 L .26073 .44722 L p F P
0 g
s
.553 .011 0 r
.36275 .356 m .37128 .35715 L .36594 .35488 L p F P
0 g
s
.553 .011 0 r
.35901 .35411 m .36275 .356 L p .36594 .35488 L F P
0 g
s
.553 .011 0 r
.36594 .35488 m .3597 .35388 L .35901 .35411 L p F P
0 g
s
0 0 0 r
.65428 .40191 m .65249 .40318 L .65405 .40223 L closepath p F P
0 g
s
0 0 0 r
.65233 .40409 m .65405 .40223 L .65249 .40318 L p F P
0 g
s
0 0 0 r
.64372 .40932 m .65233 .40409 L p .65249 .40318 L F P
0 g
s
.086 .615 .871 r
.31894 .46236 m .32299 .4628 L .33041 .46428 L p F P
0 g
s
.087 .615 .871 r
.31894 .46236 m .32299 .4628 L .31618 .46145 L closepath p F P
0 g
s
.4 .84 .719 r
.56046 .3188 m .56291 .31801 L .55304 .32286 L p F P
0 g
s
.4 .84 .719 r
.55304 .32286 m .55146 .32346 L .56046 .3188 L p F P
0 g
s
.896 .714 .649 r
.10337 .31153 m .10387 .31018 L .10728 .31336 L p F P
0 g
s
.896 .714 .649 r
.10728 .31336 m .10651 .31542 L .10337 .31153 L p F P
0 g
s
.58 .703 .926 r
.16255 .27655 m .15832 .27731 L .15517 .27404 L p F P
0 g
s
0 0 0 r
.53979 .3289 m .54065 .32842 L .53079 .33257 L p F P
0 g
s
0 0 0 r
.53079 .33257 m .53029 .33286 L .53979 .3289 L p F P
0 g
s
.037 .572 .854 r
.30057 .45785 m .29323 .45665 L .29995 .45838 L p F P
0 g
s
.037 .572 .854 r
.29995 .45838 m .30361 .45898 L .30057 .45785 L p F P
0 g
s
0 .532 .812 r
.29134 .45629 m .29323 .45665 L .29995 .45838 L p F P
0 g
s
.58 .007 0 r
.18801 .41419 m .18834 .41444 L .19312 .41694 L p F P
0 g
s
.495 0 0 r
.19245 .41715 m .19719 .41967 L .19312 .41694 L p F P
0 g
s
.495 0 0 r
.19312 .41694 m .18834 .41444 L .19245 .41715 L p F P
0 g
s
.365 .826 .74 r
.59766 .43396 m .59908 .43353 L .58977 .43765 L p F P
0 g
s
.365 .826 .74 r
.58977 .43765 m .58772 .43828 L .59766 .43396 L p F P
0 g
s
.508 0 0 r
.30404 .33677 m .30674 .33828 L .30099 .33613 L closepath p F P
0 g
s
.447 0 0 r
.20509 .42371 m .20305 .42279 L .20199 .42215 L closepath p F P
0 g
s
.419 .648 .953 r
.18728 .28456 m .18585 .28448 L .18272 .2814 L p F P
0 g
s
0 0 0 r
.66345 .39512 m .65428 .40191 L .65405 .40223 L p F P
0 g
s
0 .487 .797 r
.27294 .45077 m .26697 .44927 L .27304 .45124 L p F P
0 g
s
0 .487 .797 r
.27304 .45124 m .27603 .45199 L .27294 .45077 L p F P
0 g
s
.074 0 .117 r
.69218 .36962 m .68595 .37443 L .69102 .36836 L p F P
0 g
s
.074 0 .117 r
.69102 .36836 m .69303 .3668 L .69218 .36962 L p F P
0 g
s
.387 0 0 r
.27368 .32389 m .27485 .3245 L .28005 .32691 L p F P
0 g
s
.385 0 0 r
.27946 .32692 m .28498 .32921 L .28005 .32691 L p F P
0 g
s
.385 0 0 r
.28005 .32691 m .27485 .3245 L .27946 .32692 L p F P
0 g
s
.265 .071 .419 r
.71013 .34384 m .70828 .34546 L .70952 .34071 L p F P
0 g
s
.265 .071 .419 r
.70952 .34071 m .71023 .34009 L .71013 .34384 L p F P
0 g
s
.335 0 0 r
.46153 .35438 m .46139 .35449 L .46055 .35451 L closepath p F P
0 g
s
.333 0 0 r
.45947 .35625 m .46139 .35449 L .46055 .35451 L p F P
0 g
s
.333 0 0 r
.45376 .357 m .45947 .35625 L p .46055 .35451 L F P
0 g
s
.333 0 0 r
.44891 .35698 m .45376 .357 L p .46055 .35451 L F P
0 g
s
.534 .017 0 r
.38668 .35793 m .38961 .35898 L .38539 .35866 L closepath p F P
0 g
s
.478 0 0 r
.28885 .33063 m .29046 .33152 L .29608 .33376 L p F P
0 g
s
.476 0 0 r
.29496 .33399 m .30093 .33611 L .29608 .33376 L p F P
0 g
s
.476 0 0 r
.29608 .33376 m .29046 .33152 L .29496 .33399 L p F P
0 g
s
.779 .274 0 r
.15182 .38903 m .14975 .38623 L .15391 .38901 L p F P
0 g
s
.779 .274 0 r
.15391 .38901 m .15512 .39062 L .15182 .38903 L p F P
0 g
s
.369 .251 .586 r
.72235 .31957 m .7173 .32464 L .71666 .31991 L p F P
0 g
s
.369 .251 .586 r
.71666 .31991 m .72072 .31584 L .72235 .31957 L p F P
0 g
s
0 .297 .684 r
.25854 .31674 m .25972 .31731 L .26458 .31986 L p F P
0 g
s
0 .303 .69 r
.26456 .31961 m .26971 .32206 L .26458 .31986 L p F P
0 g
s
0 .303 .69 r
.26458 .31986 m .25972 .31731 L .26456 .31961 L p F P
0 g
s
.298 0 0 r
.47112 .35379 m .47261 .35249 L .46153 .35438 L p F P
0 g
s
.298 0 0 r
.46153 .35438 m .46139 .35449 L .47112 .35379 L p F P
0 g
s
.698 .954 .951 r
.6074 .2968 m .60315 .2991 L .6067 .29664 L closepath p F P
0 g
s
.68 .961 .941 r
.60498 .29624 m .6067 .29664 L .60315 .2991 L p F P
0 g
s
.68 .961 .941 r
.59506 .30183 m .60498 .29624 L p .60315 .2991 L F P
0 g
s
.343 .82 .788 r
.56483 .44666 m .5654 .44655 L .5555 .45 L p F P
0 g
s
.343 .82 .788 r
.5555 .45 m .55502 .45009 L .56483 .44666 L p F P
0 g
s
0 .536 .82 r
.29134 .45629 m .29323 .45665 L .28974 .45573 L closepath p F P
0 g
s
.733 .93 .955 r
.61891 .29203 m .61732 .29135 L .62494 .28711 L closepath p F P
0 g
s
.64 .656 .85 r
.70034 .27419 m .69654 .27817 L p .68929 .27537 L F P
0 g
s
.622 .641 .848 r
.69654 .27817 m .70034 .27419 L .70188 .27701 L closepath p F P
0 g
s
.921 .586 .388 r
.11497 .34808 m .11866 .35111 L .11812 .34724 L p F P
0 g
s
.921 .586 .388 r
.11812 .34724 m .11443 .34421 L .11497 .34808 L p F P
0 g
s
.503 0 0 r
.31127 .34078 m .30674 .33828 L .31289 .34031 L p F P
0 g
s
.503 0 0 r
.31481 .34185 m .31127 .34078 L p .31289 .34031 L F P
0 g
s
.503 0 0 r
.31289 .34031 m .31619 .34193 L .31481 .34185 L p F P
0 g
s
0 .396 .799 r
.24341 .30938 m .24489 .31 L .24946 .31268 L p F P
0 g
s
0 .407 .809 r
.2501 .31214 m .25495 .31472 L .24946 .31268 L p F P
0 g
s
0 .407 .809 r
.24946 .31268 m .24489 .31 L .2501 .31214 L p F P
0 g
s
.599 .589 .813 r
.71176 .28118 m .70434 .28186 L .70188 .27701 L p F P
0 g
s
.913 .548 .327 r
.11953 .35486 m .12328 .35785 L .12242 .3541 L p F P
0 g
s
.913 .548 .327 r
.12242 .3541 m .11866 .35111 L .11953 .35486 L p F P
0 g
s
0 0 0 r
.62229 .42215 m .62034 .42317 L .62211 .42228 L closepath p F P
0 g
s
0 0 0 r
.61996 .42348 m .62211 .42228 L .62034 .42317 L p F P
0 g
s
0 0 0 r
.6184 .42428 m .61996 .42348 L p .62034 .42317 L F P
0 g
s
0 0 0 r
.61078 .42812 m .6184 .42428 L p .62034 .42317 L F P
0 g
s
.643 .086 0 r
.17562 .40638 m .17311 .40415 L .16985 .4026 L p F P
0 g
s
.156 0 .277 r
.70335 .35582 m .7016 .35732 L .70209 .35406 L p F P
0 g
s
.156 0 .277 r
.70209 .35406 m .7062 .3505 L .70335 .35582 L p F P
0 g
s
0 0 0 r
.65208 .4043 m .65233 .40409 L .64372 .40932 L p F P
0 g
s
0 0 0 r
.64372 .40932 m .64215 .41071 L .65208 .4043 L p F P
0 g
s
.581 .944 .863 r
.5827 .30741 m .58336 .30738 L .57473 .31259 L p F P
0 g
s
.581 .944 .863 r
.57473 .31259 m .5728 .31286 L .5827 .30741 L p F P
0 g
s
.22 .714 .919 r
.38311 .4697 m .38376 .46988 L p .37135 .46916 L F P
0 g
s
.22 .714 .919 r
.37135 .46916 m .37575 .46911 L .38311 .4697 L p F P
0 g
s
.224 .715 .922 r
.37135 .46916 m .37575 .46911 L .36938 .46859 L closepath p F P
0 g
s
.333 0 0 r
.47057 .35435 m .47112 .35379 L .46139 .35449 L p F P
0 g
s
.333 0 0 r
.46139 .35449 m .45947 .35625 L .47057 .35435 L p F P
0 g
s
.926 .626 .454 r
.1108 .34115 m .11068 .33714 L .11427 .34021 L p F P
0 g
s
.926 .626 .454 r
.11101 .34133 m .1108 .34115 L p .11427 .34021 L F P
0 g
s
.926 .626 .454 r
.11427 .34021 m .11432 .34172 L .11101 .34133 L p F P
0 g
s
.129 .642 .895 r
.33183 .46455 m .33127 .46435 L .33041 .46428 L closepath p F P
0 g
s
.366 .833 .887 r
.51736 .45922 m .51818 .45924 L .50834 .46172 L p F P
0 g
s
.366 .833 .887 r
.50834 .46172 m .50679 .46168 L .51736 .45922 L p F P
0 g
s
.409 .311 .632 r
.72402 .31249 m .72072 .31584 L .71798 .31249 L p F P
0 g
s
.409 .311 .632 r
.71798 .31249 m .72306 .30732 L .72402 .31249 L p F P
0 g
s
.808 .747 .796 r
.10776 .28684 m .11306 .28157 L .1163 .28486 L p F P
0 g
s
.808 .747 .796 r
.1163 .28486 m .11097 .29016 L .10776 .28684 L p F P
0 g
s
.791 .747 .813 r
.1163 .28486 m .1208 .2809 L .11761 .27758 L p F P
0 g
s
.791 .747 .813 r
.11761 .27758 m .11306 .28157 L .1163 .28486 L p F P
0 g
s
.242 .053 .413 r
.71533 .33901 m .71013 .34384 L .71023 .34009 L p F P
0 g
s
.242 .053 .413 r
.71023 .34009 m .71647 .33429 L .71533 .33901 L p F P
0 g
s
.9 .507 .263 r
.12445 .36151 m .12827 .36447 L .1271 .36081 L p F P
0 g
s
.9 .507 .263 r
.1271 .36081 m .12328 .35785 L .12445 .36151 L p F P
0 g
s
.552 .009 0 r
.3597 .35388 m .35901 .35411 L .35783 .35359 L closepath p F P
0 g
s
0 0 0 r
.65405 .40223 m .6625 .39676 L p .66345 .39512 L F P
0 g
s
0 0 0 r
.662 .39729 m .6625 .39676 L .65405 .40223 L p F P
0 g
s
0 0 0 r
.65373 .40318 m .662 .39729 L p .65405 .40223 L F P
0 g
s
0 0 0 r
.65405 .40223 m .65233 .40409 L .65373 .40318 L p F P
0 g
s
.67 .707 .875 r
.67679 .27533 m .68689 .27175 L .68929 .27537 L p F P
0 g
s
.683 .73 .886 r
.68689 .27175 m .67679 .27533 L .67441 .2723 L p F P
0 g
s
.696 .756 .898 r
.66436 .27652 m .67441 .2723 L .67679 .27533 L p F P
0 g
s
.902 .712 .635 r
.10566 .318 m .10651 .31542 L .10337 .31153 L p F P
0 g
s
.449 0 0 r
.28885 .33063 m .29046 .33152 L .28669 .32988 L closepath p F P
0 g
s
.753 .744 .844 r
.127 .27672 m .1208 .2809 L .11761 .27758 L p F P
0 g
s
0 0 0 r
.63308 .416 m .63222 .41661 L .63942 .41238 L closepath p F P
0 g
s
.04 .486 .884 r
.22827 .30199 m .23017 .30265 L .23449 .30543 L p F P
0 g
s
.075 .52 .901 r
.23593 .30455 m .23017 .30265 L .23449 .30543 L p F P
0 g
s
.075 .52 .901 r
.23986 .30686 m .23593 .30455 L p .23449 .30543 L F P
0 g
s
.075 .52 .901 r
.23449 .30543 m .2403 .30718 L .23986 .30686 L p F P
0 g
s
.143 .647 .905 r
.32828 .46326 m .32299 .4628 L .33041 .46428 L p F P
0 g
s
.143 .647 .905 r
.33041 .46428 m .33127 .46435 L .32828 .46326 L p F P
0 g
s
.926 .655 .506 r
.10716 .33403 m .11068 .33714 L .11092 .33299 L p F P
0 g
s
.926 .655 .506 r
.11092 .33299 m .1074 .32988 L .10716 .33403 L p F P
0 g
s
.588 .02 0 r
.1792 .40926 m .18373 .41187 L .18017 .40898 L p F P
0 g
s
.588 .02 0 r
.18017 .40898 m .17562 .40638 L .1792 .40926 L p F P
0 g
s
.009 0 .024 r
.69155 .37122 m .69218 .36962 L .68595 .37443 L p F P
0 g
s
.009 0 .024 r
.68931 .37366 m .69155 .37122 L p .68595 .37443 L F P
0 g
s
.009 0 .024 r
.68311 .37843 m .68931 .37366 L p .68595 .37443 L F P
0 g
s
.009 0 .024 r
.68595 .37443 m .68377 .37677 L .68311 .37843 L p F P
0 g
s
0 0 0 r
.66415 .39456 m .66345 .39512 L .66405 .39473 L closepath p F P
0 g
s
0 0 0 r
.6625 .39676 m .66405 .39473 L .66345 .39512 L p F P
0 g
s
.419 .648 .953 r
.18272 .2814 m .18365 .28146 L .18728 .28456 L p F P
0 g
s
.434 .661 .956 r
.1917 .28188 m .18365 .28146 L .18728 .28456 L p F P
0 g
s
.434 .661 .956 r
.18728 .28456 m .19483 .28488 L .1917 .28188 L p F P
0 g
s
.834 .746 .767 r
.11006 .29126 m .11097 .29016 L .10776 .28684 L p F P
0 g
s
0 .317 .667 r
.2302 .4357 m .22682 .43427 L .23209 .43656 L p F P
0 g
s
0 .317 .667 r
.23209 .43656 m .23336 .43709 L .2302 .4357 L p F P
0 g
s
0 0 0 r
.63098 .41748 m .63222 .41661 L .62229 .42215 L p F P
0 g
s
0 0 0 r
.62229 .42215 m .62211 .42228 L .63098 .41748 L p F P
0 g
s
.53 0 0 r
.33191 .34672 m .33145 .34675 L .33084 .34646 L closepath p F P
0 g
s
.883 .729 .685 r
.10053 .30696 m .10387 .31018 L .10624 .30525 L p F P
0 g
s
.883 .729 .685 r
.10624 .30525 m .10291 .30203 L .10053 .30696 L p F P
0 g
s
0 0 0 r
.67236 .38774 m .66415 .39456 L .66405 .39473 L p F P
0 g
s
.363 .826 .911 r
.49604 .4639 m .49589 .46388 L .49459 .46416 L closepath p F P
0 g
s
.375 .831 .922 r
.49322 .46356 m .49589 .46388 L .49459 .46416 L p F P
0 g
s
.375 .831 .922 r
.48342 .46564 m .49322 .46356 L p .49459 .46416 L F P
0 g
s
0 0 0 r
.5381 .32986 m .53979 .3289 L .53029 .33286 L p F P
0 g
s
0 0 0 r
.53029 .33286 m .52822 .33409 L .5381 .32986 L p F P
0 g
s
.556 .018 0 r
.3548 .35464 m .34998 .35219 L .35783 .35359 L p F P
0 g
s
.556 .018 0 r
.35669 .35496 m .3548 .35464 L p .35783 .35359 L F P
0 g
s
.556 .018 0 r
.35783 .35359 m .35901 .35411 L .35669 .35496 L p F P
0 g
s
.883 .463 .197 r
.12972 .36803 m .13359 .37096 L .13214 .36739 L p F P
0 g
s
.883 .463 .197 r
.13214 .36739 m .12827 .36447 L .12972 .36803 L p F P
0 g
s
.709 .799 .921 r
.67202 .2695 m .67441 .2723 L .66436 .27652 L p F P
0 g
s
.709 .799 .921 r
.6642 .27302 m .67202 .2695 L p .66436 .27652 L F P
0 g
s
.709 .799 .921 r
.66436 .27652 m .66258 .27464 L .6642 .27302 L p F P
0 g
s
.353 0 0 r
.21498 .42892 m .21151 .42715 L .21654 .42953 L p F P
0 g
s
.353 0 0 r
.21654 .42953 m .21817 .43036 L .21498 .42892 L p F P
0 g
s
.187 .559 .934 r
.21313 .29475 m .21534 .29533 L .21943 .29822 L p F P
0 g
s
.219 .584 .945 r
.22189 .29691 m .21534 .29533 L .21943 .29822 L p F P
0 g
s
.219 .584 .945 r
.22248 .2973 m .22189 .29691 L p .21943 .29822 L F P
0 g
s
.219 .584 .945 r
.21943 .29822 m .22517 .2995 L .22248 .2973 L p F P
0 g
s
.035 0 .035 r
.68377 .37677 m .67974 .38089 L .68311 .37843 L closepath p F P
0 g
s
0 .366 .689 r
.24858 .44311 m .24877 .44318 L .24836 .44303 L closepath p F P
0 g
s
.763 .249 0 r
.15512 .39062 m .15642 .39223 L .16072 .39495 L p F P
0 g
s
.711 .175 0 r
.1593 .39533 m .16358 .39805 L .16072 .39495 L p F P
0 g
s
.711 .175 0 r
.16072 .39495 m .15642 .39223 L .1593 .39533 L p F P
0 g
s
.834 .746 .767 r
.10776 .28684 m .10682 .28798 L .11006 .29126 L p F P
0 g
s
.848 .744 .748 r
.10278 .29354 m .10604 .29681 L .11006 .29126 L p F P
0 g
s
.848 .744 .748 r
.11006 .29126 m .10682 .28798 L .10278 .29354 L p F P
0 g
s
.342 .198 .536 r
.71767 .32901 m .71674 .32988 L .71607 .3258 L p F P
0 g
s
.342 .198 .536 r
.71607 .3258 m .7173 .32464 L .71767 .32901 L p F P
0 g
s
.64 .656 .85 r
.68929 .27537 m .69945 .27261 L .70034 .27419 L p F P
0 g
s
.653 .678 .861 r
.69945 .27261 m .68929 .27537 L .68689 .27175 L p F P
0 g
s
.743 .892 .946 r
.63961 .28188 m .62966 .28713 L .62726 .28583 L p F P
0 g
s
.717 .958 .946 r
.61491 .29051 m .61732 .29135 L .6074 .2968 L p F P
0 g
s
.717 .958 .946 r
.61388 .29111 m .61491 .29051 L p .6074 .2968 L F P
0 g
s
.717 .958 .946 r
.6074 .2968 m .6067 .29664 L .61388 .29111 L p F P
0 g
s
.532 0 0 r
.32838 .34703 m .32398 .3447 L .33084 .34646 L p F P
0 g
s
.532 0 0 r
.33084 .34646 m .33145 .34675 L .32838 .34703 L p F P
0 g
s
.315 .612 .954 r
.19795 .28783 m .20005 .28818 L .20391 .29118 L p F P
0 g
s
.338 .63 .959 r
.2069 .28921 m .20005 .28818 L .20391 .29118 L p F P
0 g
s
.338 .63 .959 r
.20391 .29118 m .21001 .29201 L .2069 .28921 L p F P
0 g
s
.514 .687 .945 r
.17056 .27885 m .17959 .27828 L .18272 .2814 L p F P
0 g
s
.512 .683 .944 r
.17959 .27828 m .17056 .27885 L .16742 .27565 L p F P
0 g
s
.404 .858 .85 r
.56289 .44683 m .56483 .44666 L .55502 .45009 L p F P
0 g
s
.404 .858 .85 r
.55502 .45009 m .55297 .45028 L .56289 .44683 L p F P
0 g
s
0 .461 .79 r
.24954 .44303 m .2552 .44517 L .24877 .44318 L p F P
0 g
s
0 .461 .79 r
.24545 .44176 m .24954 .44303 L p .24877 .44318 L F P
0 g
s
0 .461 .79 r
.24877 .44318 m .24836 .44303 L .24545 .44176 L p F P
0 g
s
.391 .842 .919 r
.50571 .46157 m .50679 .46168 L .49604 .4639 L p F P
0 g
s
.391 .842 .919 r
.49604 .4639 m .49589 .46388 L .50571 .46157 L p F P
0 g
s
.357 0 0 r
.27368 .32389 m .27485 .3245 L .2718 .32299 L closepath p F P
0 g
s
.874 .448 .189 r
.13746 .37368 m .13753 .37384 L .13708 .37352 L closepath p F P
0 g
s
0 0 0 r
.66405 .39473 m .67237 .38902 L p .67236 .38774 L F P
0 g
s
0 0 0 r
.6719 .38962 m .67237 .38902 L .66405 .39473 L p F P
0 g
s
0 0 0 r
.66514 .39496 m .6719 .38962 L p .66405 .39473 L F P
0 g
s
0 0 0 r
.66405 .39473 m .6625 .39676 L .66514 .39496 L p F P
0 g
s
0 0 0 r
.68192 .38085 m .68311 .37843 L .67974 .38089 L p F P
0 g
s
0 0 0 r
.67374 .38679 m .68192 .38085 L p .67974 .38089 L F P
0 g
s
0 0 0 r
.67974 .38089 m .67399 .38628 L .67374 .38679 L p F P
0 g
s
.922 .679 .553 r
.10394 .32673 m .1074 .32988 L .10804 .3256 L p F P
0 g
s
.922 .679 .553 r
.10804 .3256 m .10458 .32245 L .10394 .32673 L p F P
0 g
s
.515 .007 0 r
.39908 .35929 m .39983 .35952 L .39879 .35948 L closepath p F P
0 g
s
0 0 0 r
.67399 .38628 m .67236 .38774 L .67374 .38679 L closepath p F P
0 g
s
0 0 0 r
.67237 .38902 m .67374 .38679 L .67236 .38774 L p F P
0 g
s
.24 .73 .922 r
.38376 .46988 m .38538 .46983 L .39557 .47034 L p F P
0 g
s
.247 .732 .927 r
.38376 .46988 m .38538 .46983 L .38311 .4697 L closepath p F P
0 g
s
.192 .677 .927 r
.34066 .46493 m .33127 .46435 L .32828 .46326 L p F P
0 g
s
0 .397 .736 r
.24836 .44303 m .24545 .44176 L .24324 .441 L closepath p F P
0 g
s
0 0 0 r
.62992 .41806 m .63098 .41748 L .62211 .42228 L p F P
0 g
s
0 0 0 r
.62211 .42228 m .61996 .42348 L .62992 .41806 L p F P
0 g
s
.327 .78 .952 r
.41829 .47058 m .40934 .47064 L .40863 .47044 L p F P
0 g
s
.297 .763 .943 r
.40934 .47064 m .40863 .47044 L .40655 .47059 L closepath p F P
0 g
s
.337 .809 .733 r
.587 .4385 m .58772 .43828 L .57779 .44232 L p F P
0 g
s
.337 .809 .733 r
.57779 .44232 m .57752 .4424 L .587 .4385 L p F P
0 g
s
.836 .367 .063 r
.13545 .37438 m .13944 .37726 L .13753 .37384 L p F P
0 g
s
.836 .367 .063 r
.13413 .372 m .13545 .37438 L p .13753 .37384 L F P
0 g
s
.836 .367 .063 r
.13753 .37384 m .13708 .37352 L .13413 .372 L p F P
0 g
s
.309 .767 .951 r
.40579 .4696 m .40863 .47044 L .40655 .47059 L p F P
0 g
s
.309 .767 .951 r
.39619 .47031 m .40579 .4696 L p .40655 .47059 L F P
0 g
s
.309 .767 .951 r
.40655 .47059 m .39642 .47038 L .39619 .47031 L p F P
0 g
s
.315 .777 .945 r
.42193 .47054 m .42108 .47032 L .41829 .47058 L closepath p F P
0 g
s
.327 .78 .952 r
.41826 .46953 m .42108 .47032 L .41829 .47058 L p F P
0 g
s
.327 .78 .952 r
.40863 .47044 m .41826 .46953 L p .41829 .47058 L F P
0 g
s
.131 0 0 r
.49609 .34566 m .49983 .34464 L .49594 .34579 L closepath p F P
0 g
s
.399 .844 .926 r
.50571 .46157 m .49589 .46388 L .49322 .46356 L p F P
0 g
s
.343 .792 .953 r
.43104 .47022 m .42193 .47054 L .42108 .47032 L p F P
0 g
s
.438 0 0 r
.19983 .42128 m .19719 .41967 L .20199 .42215 L p F P
0 g
s
.438 0 0 r
.20199 .42215 m .20305 .42279 L .19983 .42128 L p F P
0 g
s
0 .315 .715 r
.25854 .31674 m .25972 .31731 L .25624 .31536 L closepath p F P
0 g
s
.044 0 .105 r
.69491 .36739 m .69218 .36962 L .69303 .3668 L p F P
0 g
s
.044 0 .105 r
.69303 .3668 m .69961 .36144 L .69491 .36739 L p F P
0 g
s
.086 .601 .885 r
.29969 .45751 m .30057 .45785 L .29323 .45665 L p F P
0 g
s
.086 .601 .885 r
.29505 .45622 m .29969 .45751 L p .29323 .45665 L F P
0 g
s
.086 .601 .885 r
.28828 .45514 m .29505 .45622 L p .29323 .45665 L F P
0 g
s
.086 .601 .885 r
.29323 .45665 m .28974 .45573 L .28828 .45514 L p F P
0 g
s
.925 .622 .449 r
.11432 .34172 m .11443 .34421 L .11101 .34133 L closepath p F P
0 g
s
.379 0 0 r
.44891 .35698 m .45376 .357 L .44806 .35776 L closepath p F P
0 g
s
.277 .749 .94 r
.39642 .47038 m .39619 .47031 L .39557 .47034 L closepath p F P
0 g
s
.405 .856 .886 r
.54052 .45359 m .54166 .45359 L .53149 .45655 L p F P
0 g
s
.405 .856 .886 r
.53149 .45655 m .53064 .45656 L .54052 .45359 L p F P
0 g
s
.621 .958 .895 r
.59393 .30245 m .58516 .30729 L .58336 .30738 L p F P
0 g
s
0 .379 .792 r
.24489 .31 m .24341 .30938 L .2403 .30718 L p F P
0 g
s
.33 .792 .672 r
.60826 .42918 m .61001 .42845 L .60007 .43311 L p F P
0 g
s
.33 .792 .672 r
.60007 .43311 m .59908 .43353 L .60826 .42918 L p F P
0 g
s
.467 0 0 r
.42313 .35956 m .41171 .35975 L .4115 .3599 L p F P
0 g
s
.499 0 0 r
.41171 .35975 m .4115 .3599 L .4109 .35975 L closepath p F P
0 g
s
.294 .753 .951 r
.39332 .46941 m .38538 .46983 L .39557 .47034 L p F P
0 g
s
.294 .753 .951 r
.39557 .47034 m .39619 .47031 L .39332 .46941 L p F P
0 g
s
.507 .014 .019 r
.40612 .36149 m .39983 .35952 L .4109 .35975 L p F P
0 g
s
.507 .014 .019 r
.40946 .36155 m .40612 .36149 L p .4109 .35975 L F P
0 g
s
.507 .014 .019 r
.4109 .35975 m .4115 .3599 L .40946 .36155 L p F P
0 g
s
.617 .073 0 r
.33536 .34899 m .33145 .34675 L .32838 .34703 L p F P
0 g
s
.856 .405 .113 r
.13708 .37352 m .13413 .372 L .13359 .37096 L closepath p F P
0 g
s
.742 .742 .852 r
.127 .27672 m .13032 .27464 L .12713 .27131 L p F P
0 g
s
.742 .742 .852 r
.12713 .27131 m .12377 .27342 L .127 .27672 L p F P
0 g
s
.753 .744 .844 r
.11761 .27758 m .12377 .27342 L .127 .27672 L p F P
0 g
s
.028 .472 .878 r
.23017 .30265 m .22827 .30199 L .22517 .2995 L p F P
0 g
s
.332 .789 .946 r
.43421 .4701 m .43355 .46994 L .43104 .47022 L closepath p F P
0 g
s
.343 .792 .953 r
.43075 .46919 m .43355 .46994 L .43104 .47022 L p F P
0 g
s
.343 .792 .953 r
.42108 .47032 m .43075 .46919 L p .43104 .47022 L F P
0 g
s
.144 0 0 r
.49983 .34464 m .49594 .34579 L .49389 .34756 L p F P
0 g
s
.379 .844 .846 r
.55166 .45039 m .55297 .45028 L .54308 .45347 L p F P
0 g
s
.379 .844 .846 r
.54308 .45347 m .54166 .45359 L .55166 .45039 L p F P
0 g
s
.473 0 0 r
.4242 .35953 m .42396 .35972 L .42313 .35956 L closepath p F P
0 g
s
.467 0 0 r
.42204 .3614 m .42396 .35972 L .42313 .35956 L p F P
0 g
s
.467 0 0 r
.41789 .36148 m .42204 .3614 L p .42313 .35956 L F P
0 g
s
.467 0 0 r
.4115 .3599 m .41789 .36148 L p .42313 .35956 L F P
0 g
s
.763 .25 0 r
.15642 .39223 m .15512 .39062 L .15182 .38903 L p F P
0 g
s
.458 0 0 r
.43421 .36077 m .43629 .35884 L .4242 .35953 L p F P
0 g
s
.458 0 0 r
.43112 .36094 m .43421 .36077 L p .4242 .35953 L F P
0 g
s
.458 0 0 r
.4242 .35953 m .42396 .35972 L .43112 .36094 L p F P
0 g
s
.524 .022 .004 r
.39641 .36116 m .40612 .36149 L .39983 .35952 L p F P
0 g
s
.524 .022 .004 r
.39983 .35952 m .39879 .35948 L .39641 .36116 L p F P
0 g
s
.58 .703 .926 r
.15517 .27404 m .15911 .27336 L .16255 .27655 L p F P
0 g
s
.586 .707 .926 r
.16427 .27242 m .15911 .27336 L .16255 .27655 L p F P
0 g
s
.586 .707 .926 r
.16255 .27655 m .16742 .27565 L .16427 .27242 L p F P
0 g
s
.571 0 0 r
.18801 .41419 m .18834 .41444 L .18727 .41386 L closepath p F P
0 g
s
.358 .804 .953 r
.44512 .46942 m .43421 .4701 L .43355 .46994 L p F P
0 g
s
.902 .712 .635 r
.10337 .31153 m .10226 .31482 L .10566 .318 L p F P
0 g
s
.915 .699 .597 r
.10118 .31926 m .10458 .32245 L .10566 .318 L p F P
0 g
s
.915 .699 .597 r
.10566 .318 m .10226 .31482 L .10118 .31926 L p F P
0 g
s
.547 .048 .023 r
.39544 .36111 m .39641 .36116 L .39879 .35948 L p F P
0 g
s
.547 .048 .023 r
.39879 .35948 m .38961 .35898 L .39544 .36111 L p F P
0 g
s
.524 .918 .828 r
.56306 .31798 m .56291 .31801 L .56427 .31729 L closepath p F P
0 g
s
.582 .051 0 r
.35901 .35411 m .36275 .356 L .35669 .35496 L closepath p F P
0 g
s
.728 .825 .925 r
.66198 .27401 m .65197 .27876 L .64959 .27675 L p F P
0 g
s
.402 .855 .804 r
.58527 .43883 m .587 .4385 L .57752 .4424 L p F P
0 g
s
.402 .855 .804 r
.57752 .4424 m .57532 .44283 L .58527 .43883 L p F P
0 g
s
0 .358 .703 r
.23778 .43878 m .23336 .43709 L .2302 .4357 L p F P
0 g
s
.323 .771 .959 r
.40579 .4696 m .39619 .47031 L .39332 .46941 L p F P
0 g
s
.274 0 0 r
.48139 .35209 m .48337 .35018 L .47261 .35249 L p F P
0 g
s
.274 0 0 r
.47646 .3531 m .48139 .35209 L p .47261 .35249 L F P
0 g
s
.274 0 0 r
.47261 .35249 m .47112 .35379 L .47646 .3531 L p F P
0 g
s
0 .445 .756 r
.26073 .44722 m .26093 .44728 L .26697 .44927 L p F P
0 g
s
0 .492 .806 r
.2681 .44903 m .26093 .44728 L .26697 .44927 L p F P
0 g
s
0 .492 .806 r
.27175 .45029 m .2681 .44903 L p .26697 .44927 L F P
0 g
s
0 .492 .806 r
.26697 .44927 m .27294 .45077 L .27175 .45029 L p F P
0 g
s
.178 .547 .929 r
.21534 .29533 m .21313 .29475 L .21001 .29201 L p F P
0 g
s
.813 .329 .013 r
.14161 .38058 m .14565 .38343 L .14349 .38009 L p F P
0 g
s
.813 .329 .013 r
.14349 .38009 m .13944 .37726 L .14161 .38058 L p F P
0 g
s
.371 .829 .919 r
.49322 .46356 m .48342 .46564 L .48073 .4653 L p F P
0 g
s
.351 .816 .918 r
.47096 .46713 m .48073 .4653 L .48342 .46564 L p F P
0 g
s
.501 .006 .014 r
.4115 .3599 m .41789 .36148 L .40946 .36155 L closepath p F P
0 g
s
.208 0 .348 r
.70983 .34733 m .7062 .3505 L .70828 .34546 L p F P
0 g
s
.208 0 .348 r
.70828 .34546 m .71013 .34384 L .70983 .34733 L p F P
0 g
s
.667 .118 0 r
.16657 .40097 m .16358 .39805 L .16793 .40075 L p F P
0 g
s
.667 .118 0 r
.16793 .40075 m .16985 .4026 L .16657 .40097 L p F P
0 g
s
.322 .184 .533 r
.72301 .32366 m .71767 .32901 L .7173 .32464 L p F P
0 g
s
.322 .184 .533 r
.7173 .32464 m .72235 .31957 L .72301 .32366 L p F P
0 g
s
0 .526 .829 r
.28041 .45294 m .27603 .45199 L .27294 .45077 L p F P
0 g
s
.312 .761 .959 r
.39049 .46849 m .39332 .46941 L .38538 .46983 L p F P
0 g
s
.312 .761 .959 r
.39034 .46849 m .39049 .46849 L p .38538 .46983 L F P
0 g
s
.312 .761 .959 r
.38087 .46897 m .39034 .46849 L p .38538 .46983 L F P
0 g
s
.312 .761 .959 r
.38538 .46983 m .38311 .4697 L .38087 .46897 L p F P
0 g
s
.644 .722 .905 r
.14281 .27363 m .15201 .27076 L .15517 .27404 L p F P
0 g
s
.643 .721 .905 r
.15201 .27076 m .14281 .27363 L .13964 .27031 L p F P
0 g
s
.697 .734 .879 r
.13032 .27464 m .13964 .27031 L .14281 .27363 L p F P
0 g
s
.48 0 0 r
.28932 .33175 m .29496 .33399 L .29046 .33152 L p F P
0 g
s
.48 0 0 r
.28576 .32958 m .28932 .33175 L p .29046 .33152 L F P
0 g
s
.48 0 0 r
.29046 .33152 m .28669 .32988 L .28576 .32958 L p F P
0 g
s
.422 0 0 r
.43643 .35872 m .43704 .35877 L .43629 .35884 L closepath p F P
0 g
s
.089 .608 .882 r
.30864 .45966 m .30361 .45898 L .30057 .45785 L p F P
0 g
s
0 0 0 r
.68176 .3811 m .68192 .38085 L .67374 .38679 L p F P
0 g
s
0 0 0 r
.67463 .38737 m .68176 .3811 L p .67374 .38679 L F P
0 g
s
0 0 0 r
.67374 .38679 m .67237 .38902 L .67463 .38737 L p F P
0 g
s
.448 0 0 r
.18777 .4146 m .19245 .41715 L .18834 .41444 L p F P
0 g
s
.448 0 0 r
.18477 .41262 m .18777 .4146 L p .18834 .41444 L F P
0 g
s
.448 0 0 r
.18834 .41444 m .18727 .41386 L .18477 .41262 L p F P
0 g
s
.455 .877 .761 r
.56427 .31729 m .56291 .31801 L .56046 .3188 L p F P
0 g
s
.582 .036 0 r
.3471 .35318 m .3548 .35464 L .34998 .35219 L p F P
0 g
s
.582 .036 0 r
.34369 .35118 m .3471 .35318 L p .34998 .35219 L F P
0 g
s
.582 .036 0 r
.34998 .35219 m .34444 .351 L .34369 .35118 L p F P
0 g
s
.174 .664 .921 r
.32528 .46214 m .32828 .46326 L .32299 .4628 L p F P
0 g
s
.174 .664 .921 r
.31593 .46135 m .32528 .46214 L p .32299 .4628 L F P
0 g
s
.174 .664 .921 r
.32299 .4628 m .31618 .46145 L .31593 .46135 L p F P
0 g
s
.277 .741 .948 r
.38311 .4697 m .38087 .46897 L .37575 .46911 L closepath p F P
0 g
s
.393 0 0 r
.27422 .32451 m .27946 .32692 L .27485 .3245 L p F P
0 g
s
0 .32 .676 r
.2718 .32299 m .27059 .32243 L .26971 .32206 L closepath p F P
0 g
s
.393 0 0 r
.27059 .32243 m .27422 .32451 L p .27485 .3245 L F P
0 g
s
.393 0 0 r
.27485 .3245 m .2718 .32299 L .27059 .32243 L p F P
0 g
s
.867 .74 .72 r
.09964 .29876 m .10291 .30203 L .10604 .29681 L p F P
0 g
s
.867 .74 .72 r
.10604 .29681 m .10278 .29354 L .09964 .29876 L p F P
0 g
s
.533 0 0 r
.30513 .33873 m .31127 .34078 L .30674 .33828 L p F P
0 g
s
.533 0 0 r
.30096 .33613 m .30513 .33873 L p .30674 .33828 L F P
0 g
s
.533 0 0 r
.30674 .33828 m .30099 .33613 L .30096 .33613 L p F P
0 g
s
.697 .734 .879 r
.13964 .27031 m .13032 .27464 L .12713 .27131 L p F P
0 g
s
.543 .031 0 r
.38554 .36045 m .39544 .36111 L .38961 .35898 L p F P
0 g
s
.543 .031 0 r
.38371 .35967 m .38554 .36045 L p .38961 .35898 L F P
0 g
s
.543 .031 0 r
.38961 .35898 m .38539 .35866 L .38371 .35967 L p F P
0 g
s
.471 0 .01 r
.42396 .35972 m .43112 .36094 L .42204 .3614 L closepath p F P
0 g
s
.359 .81 .682 r
.61078 .42812 m .61001 .42845 L .6184 .42428 L closepath p F P
0 g
s
.308 .604 .95 r
.20005 .28818 m .19795 .28783 L .19483 .28488 L p F P
0 g
s
.021 .555 .852 r
.28974 .45573 m .28828 .45514 L .2867 .45484 L closepath p F P
0 g
s
.34 .784 .96 r
.41826 .46953 m .40863 .47044 L .40579 .4696 L p F P
0 g
s
.31 0 0 r
.22161 .43195 m .21817 .43036 L .21498 .42892 L p F P
0 g
s
.399 0 0 r
.20654 .42473 m .20305 .42279 L .19983 .42128 L p F P
0 g
s
.717 .959 .945 r
.6067 .29664 m .60498 .29624 L .61388 .29111 L closepath p F P
0 g
s
.434 0 0 r
.43704 .35877 m .43629 .35884 L .43421 .36077 L p F P
0 g
s
.366 .822 .93 r
.48071 .46529 m .48073 .4653 L .47096 .46713 L p F P
0 g
s
.366 .822 .93 r
.47096 .46713 m .46943 .46691 L .48071 .46529 L p F P
0 g
s
.33 .803 .915 r
.46943 .46691 m .47096 .46713 L p .45848 .46836 L F P
0 g
s
0 0 0 r
.52802 .33423 m .52822 .33409 L .51837 .33782 L p F P
0 g
s
0 0 0 r
.51837 .33782 m .51829 .33788 L .52802 .33423 L p F P
0 g
s
0 .283 .681 r
.25963 .31707 m .26456 .31961 L .25972 .31731 L p F P
0 g
s
0 .283 .681 r
.25544 .3149 m .25963 .31707 L p .25972 .31731 L F P
0 g
s
0 .283 .681 r
.25972 .31731 m .25624 .31536 L .25544 .3149 L p F P
0 g
s
.599 .589 .813 r
.71375 .279 m .71176 .28118 L p .70188 .27701 L F P
0 g
s
.599 .589 .813 r
.70188 .27701 m .71216 .27552 L .71375 .279 L p F P
0 g
s
.598 .63 .854 r
.70034 .27419 m .70188 .27701 L .71216 .27552 L p F P
0 g
s
.494 .902 .803 r
.5728 .31286 m .56427 .31729 L .57191 .31308 L closepath p F P
0 g
s
.455 .877 .761 r
.57032 .31349 m .57191 .31308 L .56427 .31729 L p F P
0 g
s
.455 .877 .761 r
.56083 .31859 m .57032 .31349 L p .56427 .31729 L F P
0 g
s
.455 .877 .761 r
.56046 .3188 m .56083 .31859 L p .56427 .31729 L F P
0 g
s
.347 .801 .945 r
.44622 .46935 m .44601 .4693 L .44512 .46942 L closepath p F P
0 g
s
.358 .804 .953 r
.44324 .4686 m .44601 .4693 L .44512 .46942 L p F P
0 g
s
.358 .804 .953 r
.43355 .46994 m .44324 .4686 L p .44512 .46942 L F P
0 g
s
.434 0 0 r
.44806 .35776 m .44609 .3596 L .43704 .35877 L closepath p F P
0 g
s
.434 0 0 r
.446 .35969 m .44609 .3596 L .43704 .35877 L p F P
0 g
s
.434 0 0 r
.43421 .36077 m .446 .35969 L p .43704 .35877 L F P
0 g
s
.452 .377 .681 r
.71995 .30344 m .72172 .30162 L .72257 .30515 L closepath p F P
0 g
s
.196 .688 .922 r
.35519 .467 m .35602 .46727 L p .34363 .46594 L F P
0 g
s
.196 .688 .922 r
.34363 .46594 m .34927 .46614 L .35519 .467 L p F P
0 g
s
.209 .694 .928 r
.34927 .46614 m .34363 .46594 L .34066 .46493 L p F P
0 g
s
.376 .817 .953 r
.45574 .46775 m .45795 .46827 L .44622 .46935 L p F P
0 g
s
.376 .817 .953 r
.44622 .46935 m .44601 .4693 L .45574 .46775 L p F P
0 g
s
.558 .049 .001 r
.38539 .35866 m .38371 .35967 L .3801 .35819 L closepath p F P
0 g
s
0 0 0 r
.54905 .32459 m .55052 .32383 L .54065 .32842 L p F P
0 g
s
0 0 0 r
.54065 .32842 m .53979 .3289 L .54905 .32459 L p F P
0 g
s
0 0 0 r
.5259 .33581 m .52802 .33423 L .51829 .33788 L p F P
0 g
s
0 0 0 r
.51829 .33788 m .51616 .33949 L .5259 .33581 L p F P
0 g
s
.899 .719 .65 r
.10018 .30788 m .10053 .30696 L .10387 .31018 L p F P
0 g
s
.899 .719 .65 r
.10387 .31018 m .10337 .31153 L .10018 .30788 L p F P
0 g
s
.354 .795 .96 r
.43075 .46919 m .42108 .47032 L .41826 .46953 L p F P
0 g
s
.781 .276 0 r
.14806 .38668 m .14565 .38343 L .14975 .38623 L p F P
0 g
s
.781 .276 0 r
.15045 .38832 m .14806 .38668 L p .14975 .38623 L F P
0 g
s
.781 .276 0 r
.14975 .38623 m .15182 .38903 L .15045 .38832 L p F P
0 g
s
.52 0 0 r
.18727 .41386 m .18477 .41262 L .18373 .41187 L closepath p F P
0 g
s
.562 0 0 r
.32186 .34536 m .31757 .34276 L .32398 .3447 L p F P
0 g
s
.562 0 0 r
.32817 .34705 m .32186 .34536 L p .32398 .3447 L F P
0 g
s
.562 0 0 r
.32398 .3447 m .32838 .34703 L .32817 .34705 L p F P
0 g
s
.33 .803 .915 r
.45848 .46836 m .46142 .46788 L .46943 .46691 L p F P
0 g
s
.353 .812 .933 r
.45848 .46836 m .46142 .46788 L .45795 .46827 L closepath p F P
0 g
s
.579 .701 .926 r
.15911 .27336 m .15517 .27404 L .15201 .27076 L p F P
0 g
s
.1 0 0 r
.50617 .34281 m .50591 .343 L .49983 .34464 L closepath p F P
0 g
s
.144 0 0 r
.50415 .34459 m .50591 .343 L .49983 .34464 L p F P
0 g
s
.144 0 0 r
.49389 .34756 m .50415 .34459 L p .49983 .34464 L F P
0 g
s
.291 .746 .955 r
.37797 .46797 m .38087 .46897 L .37575 .46911 L p F P
0 g
s
.291 .746 .955 r
.36843 .46827 m .37797 .46797 L p .37575 .46911 L F P
0 g
s
.291 .746 .955 r
.37575 .46911 m .36938 .46859 L .36843 .46827 L p F P
0 g
s
0 0 0 r
.63942 .41238 m .63222 .41661 L .63098 .41748 L p F P
0 g
s
0 .379 .792 r
.2403 .30718 m .24048 .30726 L .24489 .31 L p F P
0 g
s
0 .379 .792 r
.24544 .30949 m .2501 .31214 L .24489 .31 L p F P
0 g
s
0 .379 .792 r
.24489 .31 m .24048 .30726 L .24544 .30949 L p F P
0 g
s
.367 .806 .958 r
.44324 .4686 m .43355 .46994 L .43075 .46919 L p F P
0 g
s
.383 .818 .958 r
.45574 .46775 m .44601 .4693 L .44324 .4686 L p F P
0 g
s
.414 .643 .951 r
.18365 .28146 m .18272 .2814 L .17959 .27828 L p F P
0 g
s
.558 .036 0 r
.38286 .36022 m .38371 .35967 L .3801 .35819 L p F P
0 g
s
.558 .036 0 r
.37627 .35957 m .38286 .36022 L p .3801 .35819 L F P
0 g
s
.558 .036 0 r
.37133 .35718 m .37627 .35957 L p .3801 .35819 L F P
0 g
s
.558 .036 0 r
.3801 .35819 m .37136 .35716 L .37133 .35718 L p F P
0 g
s
0 .318 .672 r
.22702 .43426 m .22161 .43195 L .22682 .43427 L p F P
0 g
s
0 .318 .672 r
.22704 .43427 m .22702 .43426 L p .22682 .43427 L F P
0 g
s
0 .318 .672 r
.22682 .43427 m .2302 .4357 L .22704 .43427 L p F P
0 g
s
.386 .847 .87 r
.54052 .45359 m .53064 .45656 L .52805 .45653 L p F P
0 g
s
.382 .843 .885 r
.51818 .45924 m .52805 .45653 L .53064 .45656 L p F P
0 g
s
.395 .837 .713 r
.56041 .31882 m .56046 .3188 L .55146 .32346 L p F P
0 g
s
.395 .837 .713 r
.55146 .32346 m .55052 .32383 L .56041 .31882 L p F P
0 g
s
.924 .584 .374 r
.11134 .34502 m .11497 .34808 L .11443 .34421 L p F P
0 g
s
.924 .584 .374 r
.11081 .34124 m .11134 .34502 L p .11443 .34421 L F P
0 g
s
.924 .584 .374 r
.11443 .34421 m .11101 .34133 L .11081 .34124 L p F P
0 g
s
.723 .943 .955 r
.62494 .28711 m .61732 .29135 L .61491 .29051 L p F P
0 g
s
.916 .55 .32 r
.11584 .35184 m .11953 .35486 L .11866 .35111 L p F P
0 g
s
.916 .55 .32 r
.11866 .35111 m .11497 .34808 L .11584 .35184 L p F P
0 g
s
.733 .868 .944 r
.63968 .28193 m .63961 .28188 L .6399 .28173 L closepath p F P
0 g
s
.032 .56 .86 r
.28521 .45386 m .28041 .45294 L .2867 .45484 L p F P
0 g
s
.032 .56 .86 r
.2867 .45484 m .28828 .45514 L .28521 .45386 L p F P
0 g
s
.028 .472 .878 r
.22517 .2995 m .22599 .2998 L .23017 .30265 L p F P
0 g
s
.04 .479 .883 r
.23151 .30179 m .23593 .30455 L .23017 .30265 L p F P
0 g
s
.04 .479 .883 r
.23017 .30265 m .22599 .2998 L .23151 .30179 L p F P
0 g
s
.573 0 0 r
.31619 .34193 m .31757 .34276 L .31481 .34185 L closepath p F P
0 g
s
0 .402 .744 r
.24231 .44036 m .23778 .43878 L .24324 .441 L p F P
0 g
s
0 .402 .744 r
.24324 .441 m .24545 .44176 L .24231 .44036 L p F P
0 g
s
.349 0 0 r
.21139 .42722 m .20654 .42473 L .21151 .42715 L p F P
0 g
s
.349 0 0 r
.21251 .42777 m .21139 .42722 L p .21151 .42715 L F P
0 g
s
.349 0 0 r
.21151 .42715 m .21498 .42892 L .21251 .42777 L p F P
0 g
s
.905 .716 .635 r
.10226 .31482 m .10337 .31153 L .10018 .30788 L p F P
0 g
s
.643 .086 0 r
.16985 .4026 m .17113 .40375 L .17562 .40638 L p F P
0 g
s
.572 .004 0 r
.17474 .40662 m .1792 .40926 L .17562 .40638 L p F P
0 g
s
.572 .004 0 r
.17562 .40638 m .17113 .40375 L .17474 .40662 L p F P
0 g
s
.569 .019 0 r
.34444 .351 m .34369 .35118 L .34259 .35062 L closepath p F P
0 g
s
.418 .856 .927 r
.51556 .45903 m .51736 .45922 L .50679 .46168 L p F P
0 g
s
.418 .856 .927 r
.50679 .46168 m .50571 .46157 L .51556 .45903 L p F P
0 g
s
.254 .724 .943 r
.36938 .46859 m .36843 .46827 L .36648 .46828 L closepath p F P
0 g
s
.729 .889 .953 r
.6399 .28173 m .63961 .28188 L .63722 .28036 L p F P
0 g
s
.743 .892 .946 r
.62726 .28583 m .63722 .28036 L .63961 .28188 L p F P
0 g
s
.93 .631 .453 r
.10727 .33804 m .1108 .34115 L .11068 .33714 L p F P
0 g
s
.93 .631 .453 r
.11068 .33714 m .10716 .33403 L .10727 .33804 L p F P
0 g
s
.376 .84 .8 r
.57448 .44298 m .57532 .44283 L .5654 .44655 L p F P
0 g
s
.376 .84 .8 r
.5654 .44655 m .56483 .44666 L .57448 .44298 L p F P
0 g
s
.903 .508 .254 r
.1207 .35852 m .12445 .36151 L .12328 .35785 L p F P
0 g
s
.903 .508 .254 r
.12328 .35785 m .11953 .35486 L .1207 .35852 L p F P
0 g
s
.729 .889 .953 r
.63722 .28036 m .64715 .27495 L .6399 .28173 L p F P
0 g
s
.741 .889 .947 r
.6399 .28173 m .64959 .27675 L .64721 .27492 L p F P
0 g
s
.741 .889 .947 r
.64721 .27492 m .64715 .27495 L .6399 .28173 L p F P
0 g
s
.649 .963 .919 r
.59506 .30183 m .59393 .30245 L .59489 .30182 L closepath p F P
0 g
s
.621 .958 .895 r
.59262 .30175 m .59489 .30182 L .59393 .30245 L p F P
0 g
s
.621 .958 .895 r
.58689 .30501 m .59262 .30175 L p .59393 .30245 L F P
0 g
s
.621 .958 .895 r
.58336 .30738 m .58689 .30501 L p .59393 .30245 L F P
0 g
s
.385 0 0 r
.45376 .357 m .44806 .35776 L .44609 .3596 L p F P
0 g
s
.228 0 0 r
.48362 .34995 m .48718 .34921 L .48337 .35018 L closepath p F P
0 g
s
.182 0 .34 r
.7134 .34401 m .70983 .34733 L .71013 .34384 L p F P
0 g
s
.182 0 .34 r
.71013 .34384 m .71533 .33901 L .7134 .34401 L p F P
0 g
s
0 0 0 r
.68265 .38029 m .68192 .38085 L .68311 .37843 L p F P
0 g
s
0 0 0 r
.68311 .37843 m .68931 .37366 L .68265 .38029 L p F P
0 g
s
.12 .628 .898 r
.31618 .46145 m .31593 .46135 L .31559 .46131 L closepath p F P
0 g
s
.709 .8 .921 r
.66258 .27464 m .66198 .27401 L .6642 .27302 L closepath p F P
0 g
s
.763 .25 0 r
.15182 .38903 m .15219 .38948 L .15642 .39223 L p F P
0 g
s
.701 .163 0 r
.15509 .39257 m .1593 .39533 L .15642 .39223 L p F P
0 g
s
.701 .163 0 r
.15642 .39223 m .15219 .38948 L .15509 .39257 L p F P
0 g
s
.178 .547 .929 r
.21001 .29201 m .21137 .29238 L .21534 .29533 L p F P
0 g
s
.197 .557 .934 r
.21769 .29405 m .22189 .29691 L .21534 .29533 L p F P
0 g
s
.197 .557 .934 r
.21534 .29533 m .21137 .29238 L .21769 .29405 L p F P
0 g
s
.216 .705 .925 r
.35602 .46727 m .35766 .46729 L .36648 .46828 L p F P
0 g
s
.266 .728 .951 r
.36551 .46721 m .35766 .46729 L .36648 .46828 L p F P
0 g
s
.266 .728 .951 r
.36648 .46828 m .36843 .46827 L .36551 .46721 L p F P
0 g
s
.429 .655 .954 r
.18857 .27883 m .1801 .27832 L .18365 .28146 L p F P
0 g
s
.429 .655 .954 r
.18365 .28146 m .1917 .28188 L .18857 .27883 L p F P
0 g
s
.414 .643 .951 r
.17959 .27828 m .1801 .27832 L .18365 .28146 L p F P
0 g
s
.404 .83 .961 r
.46142 .46788 m .45795 .46827 L .45574 .46775 L p F P
0 g
s
.379 0 0 r
.28669 .32988 m .28576 .32958 L .28498 .32921 L closepath p F P
0 g
s
.93 .659 .505 r
.10369 .33088 m .10716 .33403 L .1074 .32988 L p F P
0 g
s
.93 .659 .505 r
.1074 .32988 m .10394 .32673 L .10369 .33088 L p F P
0 g
s
.292 .126 .477 r
.71779 .33305 m .71647 .33429 L .71674 .32988 L p F P
0 g
s
.292 .126 .477 r
.71674 .32988 m .71767 .32901 L .71779 .33305 L p F P
0 g
s
.884 .462 .186 r
.12591 .36507 m .12972 .36803 L .12827 .36447 L p F P
0 g
s
.884 .462 .186 r
.12827 .36447 m .12445 .36151 L .12591 .36507 L p F P
0 g
s
.571 .024 0 r
.33988 .35154 m .33536 .34899 L .34259 .35062 L p F P
0 g
s
.571 .024 0 r
.34116 .35182 m .33988 .35154 L p .34259 .35062 L F P
0 g
s
.571 .024 0 r
.34259 .35062 m .34369 .35118 L .34116 .35182 L p F P
0 g
s
.495 .452 .738 r
.71979 .2949 m .72014 .295 L .71991 .29527 L closepath p F P
0 g
s
.486 .461 .755 r
.7174 .28794 m .71979 .2949 L .72014 .295 L p F P
0 g
s
.47 .416 .714 r
.7255 .29741 m .72172 .30162 L .71991 .29527 L p F P
0 g
s
.47 .416 .714 r
.71991 .29527 m .72014 .295 L .7255 .29741 L p F P
0 g
s
.673 .97 .916 r
.60312 .29597 m .60498 .29624 L .59506 .30183 L p F P
0 g
s
.673 .97 .916 r
.59506 .30183 m .59489 .30182 L .60312 .29597 L p F P
0 g
s
.134 .634 .908 r
.31291 .46013 m .30864 .45966 L .31559 .46131 L p F P
0 g
s
.134 .634 .908 r
.31559 .46131 m .31593 .46135 L .31291 .46013 L p F P
0 g
s
.222 .707 .929 r
.35602 .46727 m .35766 .46729 L .35519 .467 L closepath p F P
0 g
s
0 .454 .77 r
.26073 .44722 m .26093 .44728 L .26051 .44713 L closepath p F P
0 g
s
.145 0 .269 r
.70934 .35058 m .70335 .35582 L .7062 .3505 L p F P
0 g
s
.145 0 .269 r
.7062 .3505 m .70983 .34733 L .70934 .35058 L p F P
0 g
s
.398 .846 .753 r
.60763 .42937 m .60826 .42918 L .59908 .43353 L p F P
0 g
s
.398 .846 .753 r
.59908 .43353 m .59766 .43396 L .60763 .42937 L p F P
0 g
s
.436 0 0 r
.19661 .41971 m .19245 .41715 L .19719 .41967 L p F P
0 g
s
.436 0 0 r
.19719 .41967 m .19983 .42128 L .19661 .41971 L p F P
0 g
s
.683 .73 .886 r
.67441 .2723 m .6845 .26839 L .68689 .27175 L p F P
0 g
s
.695 .751 .895 r
.6845 .26839 m .67441 .2723 L .67202 .2695 L p F P
0 g
s
.886 .733 .686 r
.09726 .3037 m .10053 .30696 L .10291 .30203 L p F P
0 g
s
.886 .733 .686 r
.10291 .30203 m .09964 .29876 L .09726 .3037 L p F P
0 g
s
.308 .604 .95 r
.19483 .28488 m .19629 .28514 L .20005 .28818 L p F P
0 g
s
.33 .621 .956 r
.20374 .28634 m .19629 .28514 L .20005 .28818 L p F P
0 g
s
.33 .621 .956 r
.20389 .28645 m .20374 .28634 L p .20005 .28818 L F P
0 g
s
.33 .621 .956 r
.20005 .28818 m .2069 .28921 L .20389 .28645 L p F P
0 g
s
.367 .25 .586 r
.72467 .31723 m .72235 .31957 L .72072 .31584 L p F P
0 g
s
.367 .25 .586 r
.72072 .31584 m .72402 .31249 L .72467 .31723 L p F P
0 g
s
.085 0 .187 r
.7016 .35732 m .70121 .3591 L .70335 .35582 L closepath p F P
0 g
s
.005 .534 .85 r
.26224 .44696 m .2681 .44903 L .26093 .44728 L p F P
0 g
s
.005 .534 .85 r
.25762 .44584 m .26224 .44696 L p .26093 .44728 L F P
0 g
s
.005 .534 .85 r
.26093 .44728 m .26051 .44713 L .25762 .44584 L p F P
0 g
s
.185 .665 .93 r
.32528 .46214 m .31593 .46135 L .31291 .46013 L p F P
0 g
s
.653 .678 .861 r
.68689 .27175 m .69704 .2686 L .69945 .27261 L p F P
0 g
s
.667 .701 .872 r
.69704 .2686 m .68689 .27175 L .6845 .26839 L p F P
0 g
s
.57 .562 .805 r
.71176 .28118 m .71375 .279 L .71464 .28105 L closepath p F P
0 g
s
.486 .461 .755 r
.72014 .295 m .72537 .28906 L p .7174 .28794 L F P
0 g
s
.48 .433 .727 r
.72882 .29372 m .7255 .29741 L .72014 .295 L p F P
0 g
s
.48 .433 .727 r
.72776 .28995 m .72882 .29372 L p .72014 .295 L F P
0 g
s
.48 .433 .727 r
.72014 .295 m .72537 .28906 L .72776 .28995 L p F P
0 g
s
.621 .647 .854 r
.69945 .27261 m .70214 .27204 L .70034 .27419 L closepath p F P
0 g
s
.598 .63 .854 r
.7097 .27056 m .70214 .27204 L .70034 .27419 L p F P
0 g
s
.598 .63 .854 r
.71216 .27552 m .7097 .27056 L p .70034 .27419 L F P
0 g
s
.676 .971 .914 r
.60256 .29589 m .60312 .29597 L .59489 .30182 L p F P
0 g
s
.676 .971 .914 r
.59489 .30182 m .59262 .30175 L .60256 .29589 L p F P
0 g
s
0 .476 .806 r
.26051 .44713 m .25762 .44584 L .2552 .44517 L closepath p F P
0 g
s
.565 .044 0 r
.37136 .35716 m .37133 .35718 L .37128 .35715 L closepath p F P
0 g
s
.569 .055 0 r
.36764 .35845 m .36275 .356 L .37128 .35715 L p F P
0 g
s
.569 .055 0 r
.36869 .35859 m .36764 .35845 L p .37128 .35715 L F P
0 g
s
.569 .055 0 r
.37128 .35715 m .37133 .35718 L .36869 .35859 L p F P
0 g
s
.393 .828 .953 r
.46943 .46691 m .46824 .46665 L .46142 .46788 L closepath p F P
0 g
s
.404 .83 .961 r
.46551 .46601 m .46824 .46665 L .46142 .46788 L p F P
0 g
s
.404 .83 .961 r
.45574 .46775 m .46551 .46601 L p .46142 .46788 L F P
0 g
s
.529 .505 .773 r
.71718 .28735 m .71785 .28742 L .7174 .28794 L closepath p F P
0 g
s
.486 .461 .755 r
.72537 .28906 m .71785 .28742 L .7174 .28794 L p F P
0 g
s
.856 .404 .104 r
.13081 .37016 m .12972 .36803 L .13359 .37096 L p F P
0 g
s
.856 .404 .104 r
.13359 .37096 m .13413 .372 L .13081 .37016 L p F P
0 g
s
.364 .814 .687 r
.6184 .42428 m .61001 .42845 L .60826 .42918 L p F P
0 g
s
.586 .076 .007 r
.37133 .35718 m .37627 .35957 L .36869 .35859 L closepath p F P
0 g
s
.239 0 0 r
.48718 .34921 m .48337 .35018 L .48139 .35209 L p F P
0 g
s
.543 .527 .788 r
.71785 .28742 m .71718 .28735 L .71464 .28105 L p F P
0 g
s
.925 .683 .552 r
.10054 .32355 m .10394 .32673 L .10458 .32245 L p F P
0 g
s
.925 .683 .552 r
.10458 .32245 m .10118 .31926 L .10054 .32355 L p F P
0 g
s
.371 .83 .746 r
.59633 .43436 m .59766 .43396 L .58772 .43828 L p F P
0 g
s
.371 .83 .746 r
.58772 .43828 m .587 .4385 L .59633 .43436 L p F P
0 g
s
0 0 0 r
.64215 .41071 m .63942 .41238 L .64182 .411 L closepath p F P
0 g
s
0 0 0 r
.63988 .41234 m .64182 .411 L .63942 .41238 L p F P
0 g
s
0 0 0 r
.63861 .41309 m .63988 .41234 L p .63942 .41238 L F P
0 g
s
0 0 0 r
.63098 .41748 m .63861 .41309 L p .63942 .41238 L F P
0 g
s
.512 .683 .944 r
.16742 .27565 m .17645 .27513 L .17959 .27828 L p F P
0 g
s
.509 .681 .943 r
.17645 .27513 m .16742 .27565 L .16427 .27242 L p F P
0 g
s
.389 0 0 r
.45947 .35625 m .45861 .35706 L .45376 .357 L closepath p F P
0 g
s
.385 0 0 r
.4575 .35826 m .45861 .35706 L .45376 .357 L p F P
0 g
s
.385 0 0 r
.44659 .35962 m .4575 .35826 L p .45376 .357 L F P
0 g
s
.385 0 0 r
.44609 .3596 m .44659 .35962 L p .45376 .357 L F P
0 g
s
.412 .35 .679 r
.72944 .30033 m .7255 .29741 L .72172 .30162 L p F P
0 g
s
.412 .35 .679 r
.72398 .30633 m .72944 .30033 L p .72172 .30162 L F P
0 g
s
.412 .35 .679 r
.72172 .30162 m .72257 .30515 L .72398 .30633 L p F P
0 g
s
.373 0 0 r
.28266 .32853 m .27946 .32692 L .28498 .32921 L p F P
0 g
s
.373 0 0 r
.28498 .32921 m .28576 .32958 L .28266 .32853 L p F P
0 g
s
.397 .85 .897 r
.52776 .45652 m .52805 .45653 L .51818 .45924 L p F P
0 g
s
.397 .85 .897 r
.51818 .45924 m .51736 .45922 L .52776 .45652 L p F P
0 g
s
.465 0 0 r
.30099 .33613 m .30096 .33613 L .30093 .33611 L closepath p F P
0 g
s
0 .427 .805 r
.25624 .31536 m .25544 .3149 L .25495 .31472 L closepath p F P
0 g
s
.464 0 0 r
.29786 .33555 m .29496 .33399 L .30093 .33611 L p F P
0 g
s
.464 0 0 r
.30093 .33611 m .30096 .33613 L .29786 .33555 L p F P
0 g
s
.085 .596 .888 r
.29505 .45622 m .28828 .45514 L .28521 .45386 L p F P
0 g
s
.599 .03 0 r
.30513 .33873 m .30096 .33613 L .29786 .33555 L p F P
0 g
s
.641 .085 0 r
.17113 .40375 m .16985 .4026 L .16657 .40097 L p F P
0 g
s
.709 .82 .934 r
.6642 .27302 m .66198 .27401 L .6596 .27174 L p F P
0 g
s
.728 .825 .925 r
.64959 .27675 m .6596 .27174 L .66198 .27401 L p F P
0 g
s
.269 .11 .472 r
.72278 .32807 m .71779 .33305 L .71767 .32901 L p F P
0 g
s
.269 .11 .472 r
.71767 .32901 m .72301 .32366 L .72278 .32807 L p F P
0 g
s
.433 .872 .894 r
.55043 .45039 m .55166 .45039 L .54166 .45359 L p F P
0 g
s
.433 .872 .894 r
.54166 .45359 m .54052 .45359 L .55043 .45039 L p F P
0 g
s
.542 .925 .813 r
.58049 .30777 m .5827 .30741 L .5728 .31286 L p F P
0 g
s
.542 .925 .813 r
.5728 .31286 m .57191 .31308 L .58049 .30777 L p F P
0 g
s
.434 .874 .858 r
.57284 .44312 m .57448 .44298 L .56483 .44666 L p F P
0 g
s
.434 .874 .858 r
.56483 .44666 m .56289 .44683 L .57284 .44312 L p F P
0 g
s
0 .327 .687 r
.26748 .32095 m .26456 .31961 L .26971 .32206 L p F P
0 g
s
0 .327 .687 r
.26971 .32206 m .27059 .32243 L .26748 .32095 L p F P
0 g
s
.042 0 0 r
.51576 .3398 m .51616 .33949 L .50617 .34281 L p F P
0 g
s
.042 0 0 r
.50617 .34281 m .50591 .343 L .51576 .3398 L p F P
0 g
s
.543 .527 .788 r
.71464 .28105 m .72293 .28151 L .71785 .28742 L p F P
0 g
s
.522 .496 .769 r
.72695 .28727 m .72537 .28906 L .71785 .28742 L p F P
0 g
s
.522 .496 .769 r
.7251 .28183 m .72695 .28727 L p .71785 .28742 L F P
0 g
s
.522 .496 .769 r
.71785 .28742 m .72293 .28151 L .7251 .28183 L p F P
0 g
s
.592 .024 0 r
.3155 .3434 m .32186 .34536 L .31757 .34276 L p F P
0 g
s
.592 .024 0 r
.31311 .34179 m .3155 .3434 L p .31757 .34276 L F P
0 g
s
.592 .024 0 r
.31757 .34276 m .31481 .34185 L .31311 .34179 L p F P
0 g
s
0 0 0 r
.548 .32514 m .54905 .32459 L .53979 .3289 L p F P
0 g
s
0 0 0 r
.53979 .3289 m .5381 .32986 L .548 .32514 L p F P
0 g
s
.29 .738 .961 r
.3629 .46624 m .36551 .46721 L .35766 .46729 L p F P
0 g
s
.29 .738 .961 r
.36198 .46612 m .3629 .46624 L p .35766 .46729 L F P
0 g
s
.29 .738 .961 r
.35308 .4662 m .36198 .46612 L p .35766 .46729 L F P
0 g
s
.29 .738 .961 r
.35766 .46729 m .35519 .467 L .35308 .4662 L p F P
0 g
s
0 0 0 r
.65041 .40572 m .65208 .4043 L .64215 .41071 L p F P
0 g
s
0 0 0 r
.64215 .41071 m .64182 .411 L .65041 .40572 L p F P
0 g
s
.607 .071 0 r
.34369 .35118 m .3471 .35318 L .34116 .35182 L closepath p F P
0 g
s
.666 .118 0 r
.16242 .39836 m .1593 .39533 L .16358 .39805 L p F P
0 g
s
.666 .118 0 r
.1662 .40078 m .16242 .39836 L p .16358 .39805 L F P
0 g
s
.666 .118 0 r
.16358 .39805 m .16657 .40097 L .1662 .40078 L p F P
0 g
s
.512 0 0 r
.18153 .41095 m .1792 .40926 L .18373 .41187 L p F P
0 g
s
.512 0 0 r
.18373 .41187 m .18477 .41262 L .18153 .41095 L p F P
0 g
s
.81 .323 0 r
.13763 .37771 m .14161 .38058 L .13944 .37726 L p F P
0 g
s
.81 .323 0 r
.13944 .37726 m .13545 .37438 L .13763 .37771 L p F P
0 g
s
.308 .75 .965 r
.37797 .46797 m .36843 .46827 L .36551 .46721 L p F P
0 g
s
.579 .701 .926 r
.15201 .27076 m .15576 .27012 L .15911 .27336 L p F P
0 g
s
.584 .704 .925 r
.16112 .26916 m .15576 .27012 L .15911 .27336 L p F P
0 g
s
.584 .704 .925 r
.15911 .27336 m .16427 .27242 L .16112 .26916 L p F P
0 g
s
.905 .716 .635 r
.10018 .30788 m .09893 .31159 L .10226 .31482 L p F P
0 g
s
.918 .703 .596 r
.09784 .31604 m .10118 .31926 L .10226 .31482 L p F P
0 g
s
.918 .703 .596 r
.10226 .31482 m .09893 .31159 L .09784 .31604 L p F P
0 g
s
.733 .928 .955 r
.62726 .28583 m .62494 .28711 L .62678 .28562 L closepath p F P
0 g
s
.723 .943 .955 r
.62486 .28477 m .62678 .28562 L .62494 .28711 L p F P
0 g
s
.723 .943 .955 r
.61491 .29051 m .62486 .28477 L p .62494 .28711 L F P
0 g
s
.633 .649 .848 r
.70214 .27204 m .69945 .27261 L .69704 .2686 L p F P
0 g
s
.428 .351 .667 r
.72257 .30515 m .72398 .30633 L .72306 .30732 L closepath p F P
0 g
s
0 .432 .813 r
.25233 .31303 m .2501 .31214 L .25495 .31472 L p F P
0 g
s
0 .432 .813 r
.25495 .31472 m .25544 .3149 L .25233 .31303 L p F P
0 g
s
.353 0 0 r
.46864 .35637 m .47057 .35435 L .45947 .35625 L p F P
0 g
s
.353 0 0 r
.46651 .35672 m .46864 .35637 L p .45947 .35625 L F P
0 g
s
.353 0 0 r
.45947 .35625 m .45861 .35706 L .46651 .35672 L p F P
0 g
s
.249 .713 .948 r
.35519 .467 m .35308 .4662 L .34927 .46614 L closepath p F P
0 g
s
.546 0 0 r
.28932 .33175 m .28576 .32958 L .28266 .32853 L p F P
0 g
s
0 .443 .779 r
.24954 .44303 m .24545 .44176 L .24231 .44036 L p F P
0 g
s
.215 0 0 r
.49389 .34756 m .49342 .34797 L .48718 .34921 L closepath p F P
0 g
s
.239 0 0 r
.49195 .34949 m .49342 .34797 L .48718 .34921 L p F P
0 g
s
.239 0 0 r
.48139 .35209 m .49195 .34949 L p .48718 .34921 L F P
0 g
s
.417 .841 .959 r
.47803 .46469 m .48071 .46529 L .46943 .46691 L p F P
0 g
s
.417 .841 .959 r
.46943 .46691 m .46824 .46665 L .47803 .46469 L p F P
0 g
s
.709 .794 .918 r
.67202 .2695 m .6642 .27302 L .66975 .26703 L closepath p F P
0 g
s
.709 .82 .934 r
.66965 .26691 m .66975 .26703 L .6642 .27302 L p F P
0 g
s
.709 .82 .934 r
.6596 .27174 m .66965 .26691 L p .6642 .27302 L F P
0 g
s
.847 .387 .082 r
.13545 .37438 m .13413 .372 L .13081 .37016 L p F P
0 g
s
.41 .861 .855 r
.5615 .44695 m .56289 .44683 L .55297 .45028 L p F P
0 g
s
.41 .861 .855 r
.55297 .45028 m .55166 .45039 L .5615 .44695 L p F P
0 g
s
.039 .563 .865 r
.28209 .45254 m .27414 .45103 L .28041 .45294 L p F P
0 g
s
.039 .563 .865 r
.28218 .45257 m .28209 .45254 L p .28041 .45294 L F P
0 g
s
.039 .563 .865 r
.28041 .45294 m .28521 .45386 L .28218 .45257 L p F P
0 g
s
0 .526 .829 r
.27294 .45077 m .27414 .45103 L .28041 .45294 L p F P
0 g
s
.108 0 0 r
.51416 .34127 m .51576 .3398 L .50591 .343 L p F P
0 g
s
.108 0 0 r
.50591 .343 m .50415 .34459 L .51416 .34127 L p F P
0 g
s
.643 .721 .905 r
.13964 .27031 m .14885 .26745 L .15201 .27076 L p F P
0 g
s
.643 .72 .904 r
.14885 .26745 m .13964 .27031 L .13647 .26699 L p F P
0 g
s
.697 .734 .879 r
.12713 .27131 m .13647 .26699 L .13964 .27031 L p F P
0 g
s
.593 .069 0 r
.35934 .3572 m .36764 .35845 L .36275 .356 L p F P
0 g
s
.593 .069 0 r
.35598 .35524 m .35934 .3572 L p .36275 .356 L F P
0 g
s
.593 .069 0 r
.36275 .356 m .35669 .35496 L .35598 .35524 L p F P
0 g
s
.046 .476 .885 r
.22517 .2995 m .22599 .2998 L .22248 .2973 L closepath p F P
0 g
s
.617 .073 0 r
.32838 .34703 m .32862 .34718 L .33536 .34899 L p F P
0 g
s
.627 .089 0 r
.33276 .34986 m .33988 .35154 L .33536 .34899 L p F P
0 g
s
.627 .089 0 r
.33536 .34899 m .32862 .34718 L .33276 .34986 L p F P
0 g
s
.408 .852 .919 r
.51556 .45903 m .50571 .46157 L .50306 .46126 L p F P
0 g
s
.399 .844 .926 r
.49322 .46356 m .50306 .46126 L .50571 .46157 L p F P
0 g
s
0 .387 .805 r
.2403 .30718 m .24048 .30726 L .23986 .30686 L closepath p F P
0 g
s
.461 0 0 r
.27422 .32451 m .27059 .32243 L .26748 .32095 L p F P
0 g
s
.329 .781 .63 r
.55806 .31989 m .56041 .31882 L .55052 .32383 L p F P
0 g
s
.329 .781 .63 r
.55052 .32383 m .54905 .32459 L .55806 .31989 L p F P
0 g
s
.171 .537 .925 r
.21137 .29238 m .21001 .29201 L .2069 .28921 L p F P
0 g
s
.635 .963 .892 r
.58336 .30738 m .5827 .30741 L .58689 .30501 L closepath p F P
0 g
s
0 .229 .623 r
.25963 .31707 m .25544 .3149 L .25233 .31303 L p F P
0 g
s
.744 .929 .95 r
.63484 .27901 m .63722 .28036 L .62726 .28583 L p F P
0 g
s
.744 .929 .95 r
.63309 .28001 m .63484 .27901 L p .62726 .28583 L F P
0 g
s
.744 .929 .95 r
.62726 .28583 m .62678 .28562 L .63309 .28001 L p F P
0 g
s
.082 0 .184 r
.70898 .35213 m .70934 .35058 L .70335 .35582 L p F P
0 g
s
.082 0 .184 r
.70725 .35482 m .70898 .35213 L p .70335 .35582 L F P
0 g
s
.082 0 .184 r
.70093 .36035 m .70725 .35482 L p .70335 .35582 L F P
0 g
s
.082 0 .184 r
.70335 .35582 m .70121 .3591 L .70093 .36035 L p F P
0 g
s
.392 .299 .63 r
.72656 .30973 m .72402 .31249 L .72306 .30732 L p F P
0 g
s
.392 .299 .63 r
.72306 .30732 m .72398 .30633 L .72656 .30973 L p F P
0 g
s
.089 .608 .882 r
.30057 .45785 m .30169 .458 L .30864 .45966 L p F P
0 g
s
.142 .638 .912 r
.30989 .45888 m .30169 .458 L .30864 .45966 L p F P
0 g
s
.142 .638 .912 r
.30864 .45966 m .31291 .46013 L .30989 .45888 L p F P
0 g
s
0 .336 .696 r
.22192 .43189 m .22702 .43426 L .22161 .43195 L p F P
0 g
s
.31 0 0 r
.21498 .42892 m .21645 .4296 L .22161 .43195 L p F P
0 g
s
0 .336 .696 r
.22161 .43195 m .21645 .4296 L .22192 .43189 L p F P
0 g
s
.538 .544 .809 r
.71375 .279 m .71464 .28105 L .72293 .28151 L p F P
0 g
s
0 0 .002 r
.69218 .36962 m .69155 .37122 L .69491 .36739 L closepath p F P
0 g
s
.308 0 0 r
.47112 .35379 m .47646 .3531 L .47057 .35435 L closepath p F P
0 g
s
0 .357 .779 r
.24096 .30675 m .24544 .30949 L .24048 .30726 L p F P
0 g
s
0 .357 .779 r
.23719 .30496 m .24096 .30675 L p .24048 .30726 L F P
0 g
s
0 .357 .779 r
.24048 .30726 m .23986 .30686 L .23719 .30496 L p F P
0 g
s
.775 .269 0 r
.14403 .38383 m .14806 .38668 L .14565 .38343 L p F P
0 g
s
.775 .269 0 r
.14565 .38343 m .14161 .38058 L .14403 .38383 L p F P
0 g
s
.192 .677 .927 r
.34045 .46485 m .34066 .46493 L p .32828 .46326 L F P
0 g
s
.192 .677 .927 r
.32828 .46326 m .33332 .46355 L .34045 .46485 L p F P
0 g
s
.202 .683 .932 r
.33332 .46355 m .32828 .46326 L .32528 .46214 L p F P
0 g
s
.548 0 0 r
.31481 .34185 m .31311 .34179 L .31127 .34078 L closepath p F P
0 g
s
0 .358 .703 r
.2302 .4357 m .23237 .43653 L .23778 .43878 L p F P
0 g
s
0 .405 .751 r
.23844 .43864 m .23237 .43653 L .23778 .43878 L p F P
0 g
s
0 .405 .751 r
.24019 .43938 m .23844 .43864 L p .23778 .43878 L F P
0 g
s
0 .405 .751 r
.23778 .43878 m .24231 .44036 L .24019 .43938 L p F P
0 g
s
.33 .765 .968 r
.39034 .46849 m .38087 .46897 L .37797 .46797 L p F P
0 g
s
0 0 0 r
.65233 .40409 m .65208 .4043 L .65373 .40318 L closepath p F P
0 g
s
0 0 0 r
.64985 .4061 m .65041 .40572 L .64182 .411 L p F P
0 g
s
0 0 0 r
.64182 .411 m .63988 .41234 L .64985 .4061 L p F P
0 g
s
.303 .597 .947 r
.19629 .28514 m .19483 .28488 L .1917 .28188 L p F P
0 g
s
0 0 0 r
.53753 .33026 m .5381 .32986 L .52822 .33409 L p F P
0 g
s
0 0 0 r
.52822 .33409 m .52802 .33423 L .53753 .33026 L p F P
0 g
s
.399 0 0 r
.19983 .42128 m .20163 .42228 L .20654 .42473 L p F P
0 g
s
.324 0 0 r
.20652 .42475 m .21139 .42722 L .20654 .42473 L p F P
0 g
s
.324 0 0 r
.20654 .42473 m .20163 .42228 L .20652 .42475 L p F P
0 g
s
.902 .724 .651 r
.09696 .30448 m .09726 .3037 L .10053 .30696 L p F P
0 g
s
.902 .724 .651 r
.10053 .30696 m .10018 .30788 L .09696 .30448 L p F P
0 g
s
.738 .843 .929 r
.6596 .27174 m .64959 .27675 L .64721 .27492 L p F P
0 g
s
.433 .872 .814 r
.59524 .43456 m .59633 .43436 L .587 .4385 L p F P
0 g
s
.433 .872 .814 r
.587 .4385 m .58527 .43883 L .59524 .43456 L p F P
0 g
s
.76 .245 0 r
.15182 .38903 m .15219 .38948 L .15045 .38832 L closepath p F P
0 g
s
.698 .967 .935 r
.61388 .29111 m .60498 .29624 L .60312 .29597 L p F P
0 g
s
.476 0 0 r
.18777 .4146 m .18477 .41262 L .18153 .41095 L p F P
0 g
s
.045 .502 .888 r
.23986 .30686 m .23719 .30496 L .23593 .30455 L closepath p F P
0 g
s
.445 .87 .933 r
.52545 .45627 m .52776 .45652 L .51736 .45922 L p F P
0 g
s
.445 .87 .933 r
.51736 .45922 m .51556 .45903 L .52545 .45627 L p F P
0 g
s
.209 .694 .928 r
.34066 .46493 m .34103 .46494 L .34927 .46614 L p F P
0 g
s
.257 .716 .952 r
.35013 .46504 m .34103 .46494 L .34927 .46614 L p F P
0 g
s
.257 .716 .952 r
.34927 .46614 m .35308 .4662 L .35013 .46504 L p F P
0 g
s
.578 .7 .925 r
.15576 .27012 m .15201 .27076 L .14885 .26745 L p F P
0 g
s
.555 0 0 r
.17033 .40394 m .17474 .40662 L .17113 .40375 L p F P
0 g
s
.555 0 0 r
.17113 .40375 m .1667 .40109 L .17033 .40394 L p F P
0 g
s
.641 .085 0 r
.16657 .40097 m .1667 .40109 L .17113 .40375 L p F P
0 g
s
.009 .453 .868 r
.22725 .29896 m .23151 .30179 L .22599 .2998 L p F P
0 g
s
.009 .453 .868 r
.22205 .29695 m .22725 .29896 L p .22599 .2998 L F P
0 g
s
.009 .453 .868 r
.22599 .2998 m .22248 .2973 L .22205 .29695 L p F P
0 g
s
0 .364 .713 r
.2302 .4357 m .23237 .43653 L .22704 .43427 L closepath p F P
0 g
s
0 0 0 r
.6625 .39676 m .662 .39729 L .66514 .39496 L closepath p F P
0 g
s
.573 .575 .817 r
.71216 .27552 m .71685 .27524 L .71375 .279 L closepath p F P
0 g
s
.538 .544 .809 r
.72255 .2752 m .71685 .27524 L .71375 .279 L p F P
0 g
s
.538 .544 .809 r
.72438 .27983 m .72255 .2752 L p .71375 .279 L F P
0 g
s
.538 .544 .809 r
.72293 .28151 m .72438 .27983 L p .71375 .279 L F P
0 g
s
.927 .596 .391 r
.11101 .34133 m .11081 .34124 L .1108 .34115 L closepath p F P
0 g
s
.633 .649 .848 r
.70735 .26617 m .70214 .27204 L p .69704 .2686 L F P
0 g
s
.615 .633 .846 r
.70214 .27204 m .70735 .26617 L .7097 .27056 L closepath p F P
0 g
s
.367 .801 .632 r
.63098 .41748 m .62992 .41806 L .63861 .41309 L closepath p F P
0 g
s
0 .48 .813 r
.2545 .44441 m .24954 .44303 L .2552 .44517 L p F P
0 g
s
0 .48 .813 r
.2552 .44517 m .25762 .44584 L .2545 .44441 L p F P
0 g
s
.411 .849 .936 r
.50256 .46119 m .50306 .46126 L .49322 .46356 L p F P
0 g
s
.411 .849 .936 r
.49322 .46356 m .49172 .46336 L .50256 .46119 L p F P
0 g
s
.371 .829 .919 r
.49172 .46336 m .49322 .46356 L p .48073 .4653 L F P
0 g
s
.571 .072 .032 r
.38371 .35967 m .38554 .36045 L .38286 .36022 L closepath p F P
0 g
s
.235 .048 .41 r
.7177 .33679 m .71533 .33901 L .71647 .33429 L p F P
0 g
s
.235 .048 .41 r
.71647 .33429 m .71779 .33305 L .7177 .33679 L p F P
0 g
s
.106 0 .193 r
.70121 .3591 m .69961 .36144 L .70093 .36035 L closepath p F P
0 g
s
0 0 0 r
.53554 .33167 m .53753 .33026 L .52802 .33423 L p F P
0 g
s
0 0 0 r
.53177 .33332 m .53554 .33167 L p .52802 .33423 L F P
0 g
s
0 0 0 r
.52802 .33423 m .5259 .33581 L .53177 .33332 L p F P
0 g
s
.919 .552 .312 r
.11221 .34878 m .11584 .35184 L .11497 .34808 L p F P
0 g
s
.919 .552 .312 r
.11497 .34808 m .11134 .34502 L .11221 .34878 L p F P
0 g
s
.908 .72 .636 r
.09893 .31159 m .10018 .30788 L .09696 .30448 L p F P
0 g
s
0 0 0 r
.61996 .42348 m .6184 .42428 L .61981 .42356 L closepath p F P
0 g
s
.364 .814 .687 r
.6176 .42446 m .61981 .42356 L .6184 .42428 L p F P
0 g
s
.364 .814 .687 r
.61437 .42608 m .6176 .42446 L p .6184 .42428 L F P
0 g
s
.364 .814 .687 r
.60826 .42918 m .61437 .42608 L p .6184 .42428 L F P
0 g
s
.93 .598 .387 r
.10744 .33942 m .10727 .33804 L .1108 .34115 L p F P
0 g
s
.93 .598 .387 r
.1108 .34115 m .11081 .34124 L .10744 .33942 L p F P
0 g
s
.59 .065 0 r
.35669 .35496 m .35598 .35524 L .3548 .35464 L closepath p F P
0 g
s
.929 .593 .38 r
.11134 .34502 m .11081 .34124 L .10744 .33942 L p F P
0 g
s
.329 .772 .962 r
.39332 .46941 m .40104 .46885 L .39049 .46849 L closepath p F P
0 g
s
.323 .771 .959 r
.40361 .46892 m .40579 .4696 L p .39332 .46941 L F P
0 g
s
.323 .771 .959 r
.39332 .46941 m .40104 .46885 L .40361 .46892 L p F P
0 g
s
0 0 0 r
.65373 .40318 m .65208 .4043 L .65041 .40572 L p F P
0 g
s
.744 .931 .95 r
.62678 .28562 m .62486 .28477 L .63309 .28001 L closepath p F P
0 g
s
.411 .639 .949 r
.1801 .27832 m .17959 .27828 L .17645 .27513 L p F P
0 g
s
0 .532 .837 r
.27294 .45077 m .27414 .45103 L .27175 .45029 L closepath p F P
0 g
s
.905 .508 .245 r
.11702 .35549 m .1207 .35852 L .11953 .35486 L p F P
0 g
s
.905 .508 .245 r
.11953 .35486 m .11584 .35184 L .11702 .35549 L p F P
0 g
s
.669 .125 0 r
.15093 .38978 m .15509 .39257 L .15219 .38948 L p F P
0 g
s
.669 .125 0 r
.14853 .38722 m .15093 .38978 L p .15219 .38948 L F P
0 g
s
.669 .125 0 r
.15219 .38948 m .15045 .38832 L .14853 .38722 L p F P
0 g
s
.397 .308 .638 r
.73119 .30469 m .72656 .30973 L .72398 .30633 L p F P
0 g
s
.397 .308 .638 r
.73066 .3018 m .73119 .30469 L p .72398 .30633 L F P
0 g
s
.397 .308 .638 r
.72398 .30633 m .72944 .30033 L .73066 .3018 L p F P
0 g
s
.934 .634 .45 r
.1038 .3349 m .10727 .33804 L .10716 .33403 L p F P
0 g
s
.934 .634 .45 r
.10716 .33403 m .10369 .33088 L .1038 .3349 L p F P
0 g
s
.43 0 0 r
.19211 .41724 m .18777 .4146 L .19245 .41715 L p F P
0 g
s
.43 0 0 r
.19628 .41954 m .19211 .41724 L p .19245 .41715 L F P
0 g
s
.43 0 0 r
.19245 .41715 m .19661 .41971 L .19628 .41954 L p F P
0 g
s
.098 .612 .889 r
.30057 .45785 m .30169 .458 L .29969 .45751 L closepath p F P
0 g
s
.493 0 0 r
.29365 .3343 m .28932 .33175 L .29496 .33399 L p F P
0 g
s
.493 0 0 r
.29601 .33518 m .29365 .3343 L p .29496 .33399 L F P
0 g
s
.493 0 0 r
.29496 .33399 m .29786 .33555 L .29601 .33518 L p F P
0 g
s
.171 .537 .925 r
.2069 .28921 m .20751 .28939 L .21137 .29238 L p F P
0 g
s
.183 .544 .928 r
.21363 .29112 m .21769 .29405 L .21137 .29238 L p F P
0 g
s
.183 .544 .928 r
.21137 .29238 m .20751 .28939 L .21363 .29112 L p F P
0 g
s
.393 0 0 r
.20163 .42228 m .19983 .42128 L .19661 .41971 L p F P
0 g
s
0 .28 .641 r
.21498 .42892 m .21645 .4296 L .21251 .42777 L closepath p F P
0 g
s
0 0 0 r
.662 .39729 m .65373 .40318 L .66077 .39858 L closepath p F P
0 g
s
0 0 0 r
.65981 .39939 m .66077 .39858 L .65373 .40318 L p F P
0 g
s
0 0 0 r
.65358 .40366 m .65981 .39939 L p .65373 .40318 L F P
0 g
s
0 0 0 r
.65041 .40572 m .65358 .40366 L p .65373 .40318 L F P
0 g
s
.408 .859 .81 r
.58398 .43906 m .58527 .43883 L .57532 .44283 L p F P
0 g
s
.408 .859 .81 r
.57532 .44283 m .57448 .44298 L .58398 .43906 L p F P
0 g
s
.541 .924 .81 r
.58025 .30781 m .58049 .30777 L .57191 .31308 L p F P
0 g
s
.541 .924 .81 r
.57191 .31308 m .57032 .31349 L .58025 .30781 L p F P
0 g
s
.592 .072 0 r
.35156 .35577 m .3471 .35318 L .3548 .35464 L p F P
0 g
s
.592 .072 0 r
.3538 .35617 m .35156 .35577 L p .3548 .35464 L F P
0 g
s
.592 .072 0 r
.3548 .35464 m .35598 .35524 L .3538 .35617 L p F P
0 g
s
0 0 0 r
.62868 .41872 m .62992 .41806 L .61996 .42348 L p F P
0 g
s
0 0 0 r
.61996 .42348 m .61981 .42356 L .62868 .41872 L p F P
0 g
s
.547 0 0 r
.30942 .34132 m .30513 .33873 L .31127 .34078 L p F P
0 g
s
.547 0 0 r
.31058 .34168 m .30942 .34132 L p .31127 .34078 L F P
0 g
s
.547 0 0 r
.31127 .34078 m .31311 .34179 L .31058 .34168 L p F P
0 g
s
.402 0 0 r
.2787 .32698 m .27422 .32451 L .27946 .32692 L p F P
0 g
s
.402 0 0 r
.28067 .32783 m .2787 .32698 L p .27946 .32692 L F P
0 g
s
.402 0 0 r
.27946 .32692 m .28266 .32853 L .28067 .32783 L p F P
0 g
s
.508 .019 .028 r
.41789 .36148 m .40946 .36155 L .40858 .36228 L p F P
0 g
s
.537 .051 .05 r
.40946 .36155 m .40858 .36228 L .40612 .36149 L closepath p F P
0 g
s
.885 .461 .176 r
.12217 .36208 m .12591 .36507 L .12445 .36151 L p F P
0 g
s
.885 .461 .176 r
.12445 .36151 m .1207 .35852 L .12217 .36208 L p F P
0 g
s
.534 .039 .025 r
.4073 .36347 m .40858 .36228 L .40612 .36149 L p F P
0 g
s
.534 .039 .025 r
.40114 .36331 m .4073 .36347 L p .40612 .36149 L F P
0 g
s
.534 .039 .025 r
.39613 .36137 m .40114 .36331 L p .40612 .36149 L F P
0 g
s
.534 .039 .025 r
.40612 .36149 m .39641 .36116 L .39613 .36137 L p F P
0 g
s
.512 .031 .049 r
.42204 .3614 m .42107 .36229 L .41789 .36148 L closepath p F P
0 g
s
.508 .019 .028 r
.41997 .3634 m .42107 .36229 L .41789 .36148 L p F P
0 g
s
.508 .019 .028 r
.41243 .36347 m .41997 .3634 L p .41789 .36148 L F P
0 g
s
.508 .019 .028 r
.40858 .36228 m .41243 .36347 L p .41789 .36148 L F P
0 g
s
.411 .639 .949 r
.17645 .27513 m .17663 .27514 L .1801 .27832 L p F P
0 g
s
.425 .65 .952 r
.18544 .27572 m .17663 .27514 L .1801 .27832 L p F P
0 g
s
.425 .65 .952 r
.1801 .27832 m .18857 .27883 L .18544 .27572 L p F P
0 g
s
.026 0 .09 r
.70006 .36313 m .69491 .36739 L .69961 .36144 L p F P
0 g
s
.026 0 .09 r
.69961 .36144 m .70093 .36035 L .70006 .36313 L p F P
0 g
s
.162 0 0 r
.50327 .3454 m .50415 .34459 L .49389 .34756 L p F P
0 g
s
.162 0 0 r
.49389 .34756 m .49342 .34797 L .50327 .3454 L p F P
0 g
s
.371 .829 .919 r
.48073 .4653 m .48094 .46525 L .49172 .46336 L p F P
0 g
s
.4 .839 .941 r
.48073 .4653 m .48094 .46525 L .48071 .46529 L closepath p F P
0 g
s
.477 0 .023 r
.43112 .36094 m .42204 .3614 L .42107 .36229 L p F P
0 g
s
.933 .663 .503 r
.10028 .3277 m .10369 .33088 L .10394 .32673 L p F P
0 g
s
.933 .663 .503 r
.10394 .32673 m .10054 .32355 L .10028 .3277 L p F P
0 g
s
.438 .874 .898 r
.548 .45036 m .55043 .45039 L .54052 .45359 L p F P
0 g
s
.438 .874 .898 r
.54052 .45359 m .53797 .45357 L .548 .45036 L p F P
0 g
s
.386 .847 .87 r
.53797 .45357 m .54052 .45359 L p .52805 .45653 L F P
0 g
s
.444 .853 .965 r
.48094 .46525 m .48071 .46529 L .47803 .46469 L p F P
0 g
s
.303 .597 .947 r
.1917 .28188 m .19262 .28205 L .19629 .28514 L p F P
0 g
s
.319 .604 .949 r
.19988 .28332 m .20374 .28634 L .19629 .28514 L p F P
0 g
s
.319 .604 .949 r
.19629 .28514 m .19262 .28205 L .19988 .28332 L p F P
0 g
s
.589 .947 .853 r
.58689 .30501 m .5827 .30741 L .58049 .30777 L p F P
0 g
s
.34 .784 .96 r
.41639 .46897 m .41826 .46953 L p .40579 .4696 L F P
0 g
s
.34 .784 .96 r
.40579 .4696 m .41243 .46897 L .41639 .46897 L p F P
0 g
s
.348 .786 .965 r
.40579 .4696 m .41243 .46897 L .40361 .46892 L closepath p F P
0 g
s
.433 .851 .957 r
.49172 .46336 m .49055 .46312 L .48094 .46525 L closepath p F P
0 g
s
.444 .853 .965 r
.48786 .46253 m .49055 .46312 L .48094 .46525 L p F P
0 g
s
.444 .853 .965 r
.47803 .46469 m .48786 .46253 L p .48094 .46525 L F P
0 g
s
0 0 0 r
.67237 .38902 m .6719 .38962 L .67463 .38737 L closepath p F P
0 g
s
.317 0 0 r
.47646 .3531 m .47057 .35435 L .46864 .35637 L p F P
0 g
s
.611 .06 0 r
.32838 .34703 m .32862 .34718 L .32817 .34705 L closepath p F P
0 g
s
.218 .697 .935 r
.34066 .46493 m .34103 .46494 L .34045 .46485 L closepath p F P
0 g
s
.41 .843 .708 r
.62759 .41915 m .62868 .41872 L .61981 .42356 L p F P
0 g
s
.41 .843 .708 r
.61981 .42356 m .6176 .42446 L .62759 .41915 L p F P
0 g
s
0 .301 .671 r
.26437 .3194 m .25963 .31707 L .26456 .31961 L p F P
0 g
s
0 .301 .671 r
.26456 .31961 m .26748 .32095 L .26437 .3194 L p F P
0 g
s
.116 0 .26 r
.71075 .34927 m .70934 .35058 L .70983 .34733 L p F P
0 g
s
.116 0 .26 r
.70983 .34733 m .7134 .34401 L .71075 .34927 L p F P
0 g
s
.556 .064 .043 r
.39641 .36116 m .39613 .36137 L .39544 .36111 L closepath p F P
0 g
s
.319 .182 .532 r
.72505 .3216 m .72301 .32366 L .72235 .31957 L p F P
0 g
s
.319 .182 .532 r
.72235 .31957 m .72467 .31723 L .72505 .3216 L p F P
0 g
s
.559 .078 .068 r
.39081 .36279 m .38554 .36045 L .39544 .36111 L p F P
0 g
s
.559 .078 .068 r
.39414 .363 m .39081 .36279 L p .39544 .36111 L F P
0 g
s
.559 .078 .068 r
.39544 .36111 m .39613 .36137 L .39414 .363 L p F P
0 g
s
.858 .407 .099 r
.12748 .3682 m .12591 .36507 L .12972 .36803 L p F P
0 g
s
.858 .407 .099 r
.12972 .36803 m .13081 .37016 L .12748 .3682 L p F P
0 g
s
.405 .85 .758 r
.60552 .42998 m .60763 .42937 L .59766 .43396 L p F P
0 g
s
.405 .85 .758 r
.59766 .43396 m .59633 .43436 L .60552 .42998 L p F P
0 g
s
.377 0 0 r
.45861 .35706 m .46651 .35672 L .4575 .35826 L closepath p F P
0 g
s
.667 .701 .872 r
.6845 .26839 m .69464 .26488 L .69704 .2686 L p F P
0 g
s
.68 .723 .882 r
.69464 .26488 m .6845 .26839 L .68211 .26528 L p F P
0 g
s
.695 .751 .895 r
.67202 .2695 m .68211 .26528 L .6845 .26839 L p F P
0 g
s
.625 .081 0 r
.32612 .34799 m .33276 .34986 L .32862 .34718 L p F P
0 g
s
.625 .081 0 r
.3253 .34741 m .32612 .34799 L p .32862 .34718 L F P
0 g
s
.625 .081 0 r
.32862 .34718 m .32817 .34705 L .3253 .34741 L p F P
0 g
s
.418 .84 .959 r
.47803 .46469 m .46824 .46665 L .46551 .46601 L p F P
0 g
s
.348 .236 .583 r
.72812 .3135 m .72467 .31723 L .72402 .31249 L p F P
0 g
s
.348 .236 .583 r
.72402 .31249 m .72656 .30973 L .72812 .3135 L p F P
0 g
s
.288 .728 .964 r
.34833 .46431 m .35013 .46504 L .34103 .46494 L p F P
0 g
s
.288 .728 .964 r
.3452 .46379 m .34833 .46431 L p .34103 .46494 L F P
0 g
s
.288 .728 .964 r
.33769 .46371 m .3452 .46379 L p .34103 .46494 L F P
0 g
s
.288 .728 .964 r
.34103 .46494 m .34045 .46485 L .33769 .46371 L p F P
0 g
s
.186 .66 .934 r
.30887 .45844 m .30989 .45888 L .30169 .458 L p F P
0 g
s
.186 .66 .934 r
.3044 .45728 m .30887 .45844 L p .30169 .458 L F P
0 g
s
.186 .66 .934 r
.29753 .45656 m .3044 .45728 L p .30169 .458 L F P
0 g
s
.186 .66 .934 r
.30169 .458 m .29969 .45751 L .29753 .45656 L p F P
0 g
s
.354 .795 .96 r
.42884 .46866 m .43075 .46919 L p .41826 .46953 L F P
0 g
s
.354 .795 .96 r
.41826 .46953 m .42475 .46878 L .42884 .46866 L p F P
0 g
s
.365 .798 .966 r
.41826 .46953 m .42475 .46878 L .41639 .46897 L closepath p F P
0 g
s
.483 .003 .039 r
.43421 .36077 m .43358 .36139 L .43112 .36094 L closepath p F P
0 g
s
.477 0 .023 r
.43223 .36284 m .43358 .36139 L .43112 .36094 L p F P
0 g
s
.477 0 .023 r
.42501 .36318 m .43223 .36284 L p .43112 .36094 L F P
0 g
s
.477 0 .023 r
.42107 .36229 m .42501 .36318 L p .43112 .36094 L F P
0 g
s
.095 .595 .898 r
.27602 .45054 m .28209 .45254 L .27414 .45103 L p F P
0 g
s
.095 .595 .898 r
.26985 .44941 m .27602 .45054 L p .27414 .45103 L F P
0 g
s
.095 .595 .898 r
.27414 .45103 m .27175 .45029 L .26985 .44941 L p F P
0 g
s
.589 .58 .811 r
.71685 .27524 m .71216 .27552 L .7097 .27056 L p F P
0 g
s
.599 .048 0 r
.32817 .34705 m .3253 .34741 L .32186 .34536 L closepath p F P
0 g
s
.242 .701 .95 r
.34045 .46485 m .33769 .46371 L .33332 .46355 L closepath p F P
0 g
s
.929 .687 .551 r
.09719 .32033 m .10054 .32355 L .10118 .31926 L p F P
0 g
s
.929 .687 .551 r
.10118 .31926 m .09784 .31604 L .09719 .32033 L p F P
0 g
s
.708 .794 .918 r
.67973 .26239 m .68211 .26528 L .67202 .2695 L p F P
0 g
s
.708 .794 .918 r
.67 .26676 m .67973 .26239 L p .67202 .2695 L F P
0 g
s
.708 .794 .918 r
.67202 .2695 m .66975 .26703 L .67 .26676 L p F P
0 g
s
.463 0 .025 r
.4441 .36182 m .446 .35969 L .43421 .36077 L p F P
0 g
s
.463 0 .025 r
.43949 .36221 m .4441 .36182 L p .43421 .36077 L F P
0 g
s
.463 0 .025 r
.43421 .36077 m .43358 .36139 L .43949 .36221 L p F P
0 g
s
.21 .029 .403 r
.72173 .33277 m .7177 .33679 L .71779 .33305 L p F P
0 g
s
.21 .029 .403 r
.71779 .33305 m .72278 .32807 L .72173 .33277 L p F P
0 g
s
.411 .832 .964 r
.46551 .46601 m .45574 .46775 L .45298 .46708 L p F P
0 g
s
.383 .818 .958 r
.44324 .4686 m .45298 .46708 L .45574 .46775 L p F P
0 g
s
.509 0 0 r
.17829 .40921 m .17474 .40662 L .1792 .40926 L p F P
0 g
s
.509 0 0 r
.1792 .40926 m .18153 .41095 L .17829 .40921 L p F P
0 g
s
.367 .806 .958 r
.44099 .46801 m .44324 .4686 L p .43075 .46919 L F P
0 g
s
.367 .806 .958 r
.43075 .46919 m .4383 .46817 L .44099 .46801 L p F P
0 g
s
.38 .809 .966 r
.43075 .46919 m .4383 .46817 L .42884 .46866 L closepath p F P
0 g
s
.509 .681 .943 r
.17439 .27303 m .17645 .27513 L p .16427 .27242 L F P
0 g
s
.509 .681 .943 r
.16427 .27242 m .17318 .27194 L .17439 .27303 L p F P
0 g
s
.508 .678 .941 r
.17318 .27194 m .16427 .27242 L .16112 .26916 L p F P
0 g
s
.65 .1 0 r
.15821 .39559 m .16242 .39836 L .1593 .39533 L p F P
0 g
s
.65 .1 0 r
.1593 .39533 m .15509 .39257 L .15821 .39559 L p F P
0 g
s
.394 .82 .965 r
.45286 .46705 m .45298 .46708 L .44324 .4686 L p F P
0 g
s
.394 .82 .965 r
.44324 .4686 m .44099 .46801 L .45286 .46705 L p F P
0 g
s
0 .41 .801 r
.24922 .31108 m .24544 .30949 L .2501 .31214 L p F P
0 g
s
0 .41 .801 r
.2501 .31214 m .25233 .31303 L .24922 .31108 L p F P
0 g
s
0 0 0 r
.66514 .39496 m .662 .39729 L .66077 .39858 L p F P
0 g
s
.719 .19 0 r
.15045 .38832 m .14853 .38722 L .14806 .38668 L closepath p F P
0 g
s
.561 .08 .07 r
.39613 .36137 m .40114 .36331 L .39414 .363 L closepath p F P
0 g
s
.847 .387 .082 r
.13081 .37016 m .13153 .37148 L .13545 .37438 L p F P
0 g
s
.806 .316 0 r
.13371 .37479 m .13763 .37771 L .13545 .37438 L p F P
0 g
s
.806 .316 0 r
.13545 .37438 m .13153 .37148 L .13371 .37479 L p F P
0 g
s
.738 .906 .952 r
.64715 .27495 m .63722 .28036 L .63484 .27901 L p F P
0 g
s
.633 .649 .848 r
.69704 .2686 m .70726 .26601 L .70735 .26617 L p F P
0 g
s
.647 .67 .858 r
.70726 .26601 m .69704 .2686 L .69464 .26488 L p F P
0 g
s
.617 .104 .005 r
.35598 .35524 m .35934 .3572 L .3538 .35617 L closepath p F P
0 g
s
.626 .961 .887 r
.59262 .30175 m .58689 .30501 L .59176 .3018 L closepath p F P
0 g
s
.589 .947 .853 r
.59018 .30192 m .59176 .3018 L .58689 .30501 L p F P
0 g
s
.589 .947 .853 r
.5818 .30689 m .59018 .30192 L p .58689 .30501 L F P
0 g
s
.589 .947 .853 r
.58049 .30777 m .5818 .30689 L p .58689 .30501 L F P
0 g
s
.125 .62 .909 r
.29969 .45751 m .29753 .45656 L .29505 .45622 L closepath p F P
0 g
s
0 0 0 r
.69934 .36493 m .70006 .36313 L .69491 .36739 L p F P
0 g
s
0 0 0 r
.69772 .3668 m .69934 .36493 L p .69491 .36739 L F P
0 g
s
0 0 0 r
.69115 .37222 m .69772 .3668 L p .69491 .36739 L F P
0 g
s
0 0 0 r
.69491 .36739 m .69155 .37122 L .69115 .37222 L p F P
0 g
s
.578 .086 .048 r
.38127 .362 m .39081 .36279 L .38554 .36045 L p F P
0 g
s
.578 .086 .048 r
.38071 .36171 m .38127 .362 L p .38554 .36045 L F P
0 g
s
.578 .086 .048 r
.38554 .36045 m .38286 .36022 L .38071 .36171 L p F P
0 g
s
.716 .958 .946 r
.61491 .29051 m .61388 .29111 L .61471 .29046 L closepath p F P
0 g
s
.698 .967 .935 r
.6125 .28994 m .61471 .29046 L .61388 .29111 L p F P
0 g
s
.698 .967 .935 r
.60543 .29417 m .6125 .28994 L p .61388 .29111 L F P
0 g
s
.698 .967 .935 r
.60312 .29597 m .60543 .29417 L p .61388 .29111 L F P
0 g
s
.469 .883 .761 r
.56046 .3188 m .56041 .31882 L .56083 .31859 L closepath p F P
0 g
s
0 0 .077 r
.70288 .36067 m .70006 .36313 L .70093 .36035 L p F P
0 g
s
0 0 .077 r
.70093 .36035 m .70725 .35482 L .70288 .36067 L p F P
0 g
s
0 0 0 r
.6719 .38962 m .66514 .39496 L .67081 .39102 L closepath p F P
0 g
s
0 0 0 r
.66975 .39211 m .67081 .39102 L .66514 .39496 L p F P
0 g
s
0 0 0 r
.66567 .39519 m .66975 .39211 L p .66514 .39496 L F P
0 g
s
0 0 0 r
.66077 .39858 m .66567 .39519 L p .66514 .39496 L F P
0 g
s
0 .386 .752 r
.21688 .42949 m .22192 .43189 L .21645 .4296 L p F P
0 g
s
0 .386 .752 r
.21179 .4274 m .21688 .42949 L p .21645 .4296 L F P
0 g
s
0 .386 .752 r
.21645 .4296 m .21251 .42777 L .21179 .4274 L p F P
0 g
s
0 0 0 r
.52564 .33601 m .5259 .33581 L .51616 .33949 L p F P
0 g
s
0 0 0 r
.51616 .33949 m .51576 .3398 L .52564 .33601 L p F P
0 g
s
0 .457 .807 r
.23316 .43633 m .23844 .43864 L .23237 .43653 L p F P
0 g
s
0 .457 .807 r
.22702 .43427 m .23316 .43633 L p .23237 .43653 L F P
0 g
s
0 .457 .807 r
.23237 .43653 m .22704 .43427 L .22702 .43427 L p F P
0 g
s
.392 .827 .681 r
.56083 .31859 m .56041 .31882 L .55806 .31989 L p F P
0 g
s
.46 .886 .9 r
.56037 .44694 m .5615 .44695 L .55166 .45039 L p F P
0 g
s
.46 .886 .9 r
.55166 .45039 m .55043 .45039 L .56037 .44694 L p F P
0 g
s
.214 0 0 r
.50223 .34651 m .50327 .3454 L .49342 .34797 L p F P
0 g
s
.214 0 0 r
.49342 .34797 m .49195 .34949 L .50223 .34651 L p F P
0 g
s
.578 .7 .925 r
.14885 .26745 m .15247 .26683 L .15576 .27012 L p F P
0 g
s
.583 .702 .924 r
.15796 .26586 m .15247 .26683 L .15576 .27012 L p F P
0 g
s
.583 .702 .924 r
.15576 .27012 m .16112 .26916 L .15796 .26586 L p F P
0 g
s
.591 .101 .059 r
.38286 .36022 m .38071 .36171 L .37627 .35957 L closepath p F P
0 g
s
.733 .961 .941 r
.62251 .28391 m .62486 .28477 L .61491 .29051 L p F P
0 g
s
.733 .961 .941 r
.61491 .29051 m .61471 .29046 L .62251 .28391 L p F P
0 g
s
.439 .863 .734 r
.57032 .31349 m .56083 .31859 L .56931 .31386 L closepath p F P
0 g
s
.392 .827 .681 r
.56784 .31442 m .56931 .31386 L .56083 .31859 L p F P
0 g
s
.392 .827 .681 r
.55917 .31925 m .56784 .31442 L p .56083 .31859 L F P
0 g
s
.392 .827 .681 r
.55806 .31989 m .55917 .31925 L p .56083 .31859 L F P
0 g
s
0 .521 .844 r
.26224 .44696 m .25762 .44584 L .2545 .44441 L p F P
0 g
s
.025 .546 .863 r
.27175 .45029 m .26985 .44941 L .2681 .44903 L closepath p F P
0 g
s
.908 .72 .636 r
.09696 .30448 m .09566 .30834 L .09893 .31159 L p F P
0 g
s
.921 .707 .596 r
.09456 .31279 m .09784 .31604 L .09893 .31159 L p F P
0 g
s
.921 .707 .596 r
.09893 .31159 m .09566 .30834 L .09456 .31279 L p F P
0 g
s
.62 .091 0 r
.34402 .35424 m .35156 .35577 L .3471 .35318 L p F P
0 g
s
.62 .091 0 r
.34062 .35197 m .34402 .35424 L p .3471 .35318 L F P
0 g
s
.62 .091 0 r
.3471 .35318 m .34116 .35182 L .34062 .35197 L p F P
0 g
s
0 0 0 r
.68192 .38085 m .68176 .3811 L .68265 .38029 L closepath p F P
0 g
s
.308 0 0 r
.48139 .35209 m .48091 .35257 L .47646 .3531 L closepath p F P
0 g
s
.317 0 0 r
.47952 .35416 m .48091 .35257 L .47646 .3531 L p F P
0 g
s
.317 0 0 r
.46864 .35637 m .47952 .35416 L p .47646 .3531 L F P
0 g
s
.307 .74 .969 r
.36198 .46612 m .35308 .4662 L .35013 .46504 L p F P
0 g
s
0 0 .009 r
.69155 .37122 m .68931 .37366 L .69115 .37222 L closepath p F P
0 g
s
.058 .505 .893 r
.23408 .30267 m .23151 .30179 L .23593 .30455 L p F P
0 g
s
.058 .505 .893 r
.23593 .30455 m .23719 .30496 L .23408 .30267 L p F P
0 g
s
.386 .847 .87 r
.52805 .45653 m .53725 .45378 L .53797 .45357 L p F P
0 g
s
.426 .866 .906 r
.52805 .45653 m .53725 .45378 L .52776 .45652 L closepath p F P
0 g
s
.423 0 .022 r
.44609 .3596 m .44659 .35962 L .446 .35969 L closepath p F P
0 g
s
.185 .665 .93 r
.32506 .46205 m .32528 .46214 L p .31291 .46013 L F P
0 g
s
.185 .665 .93 r
.31291 .46013 m .31843 .46058 L .32506 .46205 L p F P
0 g
s
.196 .67 .935 r
.31843 .46058 m .31291 .46013 L .30989 .45888 L p F P
0 g
s
.393 0 0 r
.19661 .41971 m .19678 .4198 L .20163 .42228 L p F P
0 g
s
0 .271 .651 r
.20172 .42225 m .20652 .42475 L .20163 .42228 L p F P
0 g
s
0 .271 .651 r
.20163 .42228 m .19678 .4198 L .20172 .42225 L p F P
0 g
s
.431 .865 .765 r
.60826 .42918 m .60763 .42937 L .61437 .42608 L closepath p F P
0 g
s
0 .443 .779 r
.24231 .44036 m .24393 .44086 L .24954 .44303 L p F P
0 g
s
0 .484 .82 r
.2507 .44274 m .24393 .44086 L .24954 .44303 L p F P
0 g
s
0 .484 .82 r
.25223 .44335 m .2507 .44274 L p .24954 .44303 L F P
0 g
s
0 .484 .82 r
.24954 .44303 m .2545 .44441 L .25223 .44335 L p F P
0 g
s
.173 0 .335 r
.7174 .34027 m .7134 .34401 L .71533 .33901 L p F P
0 g
s
.173 0 .335 r
.71533 .33901 m .7177 .33679 L .7174 .34027 L p F P
0 g
s
.434 .363 .678 r
.7302 .29948 m .72944 .30033 L .7255 .29741 L p F P
0 g
s
.434 .363 .678 r
.7255 .29741 m .72882 .29372 L .7302 .29948 L p F P
0 g
s
.733 .962 .94 r
.62247 .28389 m .62251 .28391 L .61471 .29046 L p F P
0 g
s
.733 .962 .94 r
.61471 .29046 m .6125 .28994 L .62247 .28389 L p F P
0 g
s
.73 .82 .92 r
.66965 .26691 m .6596 .27174 L .65723 .26966 L p F P
0 g
s
.738 .843 .929 r
.64721 .27492 m .65723 .26966 L .6596 .27174 L p F P
0 g
s
0 0 0 r
.68994 .37459 m .68265 .38029 L .68931 .37366 L p F P
0 g
s
0 0 0 r
.68931 .37366 m .69115 .37222 L .68994 .37459 L p F P
0 g
s
0 0 0 r
.67463 .38737 m .6719 .38962 L .67081 .39102 L p F P
0 g
s
.612 .051 0 r
.31311 .34179 m .3155 .3434 L .31058 .34168 L closepath p F P
0 g
s
.77 .262 0 r
.14006 .38095 m .14403 .38383 L .14161 .38058 L p F P
0 g
s
.77 .262 0 r
.14161 .38058 m .13763 .37771 L .14006 .38095 L p F P
0 g
s
.462 .889 .865 r
.58281 .43916 m .58398 .43906 L .57448 .44298 L p F P
0 g
s
.462 .889 .865 r
.57448 .44298 m .57284 .44312 L .58281 .43916 L p F P
0 g
s
.643 .72 .904 r
.13647 .26699 m .14568 .26412 L .14885 .26745 L p F P
0 g
s
.203 .578 .941 r
.22248 .2973 m .22205 .29695 L .22189 .29691 L closepath p F P
0 g
s
.435 0 .045 r
.44659 .35962 m .446 .35969 L .4441 .36182 L p F P
0 g
s
0 0 0 r
.68176 .3811 m .67463 .38737 L .68053 .38302 L closepath p F P
0 g
s
0 0 0 r
.67967 .38412 m .68053 .38302 L .67463 .38737 L p F P
0 g
s
0 0 0 r
.67574 .3874 m .67967 .38412 L p .67463 .38737 L F P
0 g
s
0 0 0 r
.67081 .39102 m .67574 .3874 L p .67463 .38737 L F P
0 g
s
.632 .076 0 r
.16657 .40097 m .1667 .40109 L .1662 .40078 L closepath p F P
0 g
s
.432 0 .035 r
.4575 .35826 m .45582 .36011 L .44659 .35962 L closepath p F P
0 g
s
.435 0 .045 r
.45561 .36036 m .45582 .36011 L .44659 .35962 L p F P
0 g
s
.435 0 .045 r
.4441 .36182 m .45561 .36036 L p .44659 .35962 L F P
0 g
s
.439 .877 .863 r
.57117 .44326 m .57284 .44312 L .56289 .44683 L p F P
0 g
s
.439 .877 .863 r
.56289 .44683 m .5615 .44695 L .57117 .44326 L p F P
0 g
s
.595 .092 .028 r
.38044 .36191 m .38071 .36171 L .37627 .35957 L p F P
0 g
s
.595 .092 .028 r
.37223 .36102 m .38044 .36191 L p .37627 .35957 L F P
0 g
s
.595 .092 .028 r
.36832 .3588 m .37223 .36102 L p .37627 .35957 L F P
0 g
s
.595 .092 .028 r
.37627 .35957 m .36869 .35859 L .36832 .3588 L p F P
0 g
s
.537 .062 .076 r
.40858 .36228 m .41243 .36347 L .4073 .36347 L closepath p F P
0 g
s
.202 .683 .932 r
.32528 .46214 m .32563 .46215 L .33332 .46355 L p F P
0 g
s
.249 .703 .954 r
.33471 .46245 m .32563 .46215 L .33332 .46355 L p F P
0 g
s
.249 .703 .954 r
.33332 .46355 m .33769 .46371 L .33471 .46245 L p F P
0 g
s
.599 .03 0 r
.29786 .33555 m .29933 .33654 L .30513 .33873 L p F P
0 g
s
.603 .034 0 r
.30332 .33924 m .30942 .34132 L .30513 .33873 L p F P
0 g
s
.603 .034 0 r
.30513 .33873 m .29933 .33654 L .30332 .33924 L p F P
0 g
s
.085 .596 .888 r
.28521 .45386 m .28856 .45439 L .29505 .45622 L p F P
0 g
s
.087 .597 .89 r
.28521 .45386 m .28856 .45439 L .28218 .45257 L closepath p F P
0 g
s
.546 0 0 r
.28266 .32853 m .28397 .32939 L .28932 .33175 L p F P
0 g
s
.549 0 0 r
.28801 .33204 m .29365 .3343 L .28932 .33175 L p F P
0 g
s
.549 0 0 r
.28932 .33175 m .28397 .32939 L .28801 .33204 L p F P
0 g
s
0 0 0 r
.68954 .37521 m .68994 .37459 L .68265 .38029 L p F P
0 g
s
0 0 0 r
.68425 .38013 m .68954 .37521 L p .68265 .38029 L F P
0 g
s
0 0 0 r
.68053 .38302 m .68425 .38013 L p .68265 .38029 L F P
0 g
s
0 0 0 r
.68265 .38029 m .68176 .3811 L .68053 .38302 L p F P
0 g
s
.51 0 0 r
.16599 .40123 m .17033 .40394 L .1667 .40109 L p F P
0 g
s
.51 0 0 r
.16331 .39911 m .16599 .40123 L p .1667 .40109 L F P
0 g
s
.51 0 0 r
.1667 .40109 m .1662 .40078 L .16331 .39911 L p F P
0 g
s
0 0 0 r
.5468 .32593 m .548 .32514 L .5381 .32986 L p F P
0 g
s
0 0 0 r
.5381 .32986 m .53753 .33026 L .5468 .32593 L p F P
0 g
s
.471 .882 .938 r
.53725 .45378 m .52776 .45652 L .52545 .45627 L p F P
0 g
s
.372 .805 .637 r
.63861 .41309 m .62992 .41806 L .62868 .41872 L p F P
0 g
s
.456 .863 .961 r
.5004 .46074 m .50256 .46119 L .49172 .46336 L p F P
0 g
s
.456 .863 .961 r
.49172 .46336 m .49055 .46312 L .5004 .46074 L p F P
0 g
s
.212 .578 .942 r
.21893 .29436 m .21769 .29405 L .22189 .29691 L p F P
0 g
s
.212 .578 .942 r
.22189 .29691 m .22205 .29695 L .21893 .29436 L p F P
0 g
s
.055 0 0 r
.52392 .33759 m .52564 .33601 L .51576 .3398 L p F P
0 g
s
.055 0 0 r
.51576 .3398 m .51416 .34127 L .52392 .33759 L p F P
0 g
s
.182 .538 .926 r
.2069 .28921 m .20751 .28939 L .20389 .28645 L closepath p F P
0 g
s
0 0 0 r
.55791 .31996 m .55806 .31989 L .54905 .32459 L p F P
0 g
s
0 0 0 r
.54905 .32459 m .548 .32514 L .55791 .31996 L p F P
0 g
s
.474 .007 .064 r
.43358 .36139 m .43949 .36221 L .43223 .36284 L closepath p F P
0 g
s
.599 .048 0 r
.31953 .3461 m .3155 .3434 L .32186 .34536 L p F P
0 g
s
.599 .048 0 r
.32453 .34751 m .31953 .3461 L p .32186 .34536 L F P
0 g
s
.599 .048 0 r
.32186 .34536 m .3253 .34741 L .32453 .34751 L p F P
0 g
s
.66 .971 .887 r
.60013 .2958 m .60256 .29589 L .59262 .30175 L p F P
0 g
s
.66 .971 .887 r
.59892 .29654 m .60013 .2958 L p .59262 .30175 L F P
0 g
s
.66 .971 .887 r
.59262 .30175 m .59176 .3018 L .59892 .29654 L p F P
0 g
s
0 .44 .857 r
.22725 .29896 m .22205 .29695 L .21893 .29436 L p F P
0 g
s
.461 0 0 r
.26748 .32095 m .26921 .32201 L .27422 .32451 L p F P
0 g
s
.456 0 0 r
.27343 .32457 m .2787 .32698 L .27422 .32451 L p F P
0 g
s
.456 0 0 r
.27422 .32451 m .26921 .32201 L .27343 .32457 L p F P
0 g
s
.581 .021 0 r
.1662 .40078 m .16331 .39911 L .16242 .39836 L closepath p F P
0 g
s
.134 .624 .914 r
.29448 .45518 m .28856 .45439 L .29505 .45622 L p F P
0 g
s
.134 .624 .914 r
.29505 .45622 m .29753 .45656 L .29448 .45518 L p F P
0 g
s
.476 0 0 r
.18153 .41095 m .18315 .41202 L .18777 .4146 L p F P
0 g
s
.398 0 0 r
.18753 .41465 m .19211 .41724 L .18777 .4146 L p F P
0 g
s
.398 0 0 r
.18777 .4146 m .18315 .41202 L .18753 .41465 L p F P
0 g
s
.508 .038 .074 r
.42107 .36229 m .42501 .36318 L .41997 .3634 L closepath p F P
0 g
s
.299 .591 .945 r
.19262 .28205 m .1917 .28188 L .18857 .27883 L p F P
0 g
s
.262 0 0 r
.49074 .35076 m .49195 .34949 L .48139 .35209 L p F P
0 g
s
.262 0 0 r
.48139 .35209 m .48091 .35257 L .49074 .35076 L p F P
0 g
s
.578 .698 .924 r
.15247 .26683 m .14885 .26745 L .14568 .26412 L p F P
0 g
s
.308 .75 .965 r
.3769 .46759 m .37797 .46797 L p .36551 .46721 L F P
0 g
s
.308 .75 .965 r
.36551 .46721 m .3711 .46703 L .3769 .46759 L p F P
0 g
s
.308 .75 .965 r
.36551 .46721 m .3711 .46703 L .3629 .46624 L closepath p F P
0 g
s
0 .33 .754 r
.24096 .30675 m .23719 .30496 L .23408 .30267 L p F P
0 g
s
.848 .388 .075 r
.13153 .37148 m .13081 .37016 L .12748 .3682 L p F P
0 g
s
.714 .185 0 r
.14525 .38523 m .14403 .38383 L .14806 .38668 L p F P
0 g
s
.714 .185 0 r
.14806 .38668 m .14853 .38722 L .14525 .38523 L p F P
0 g
s
.582 .006 0 r
.29786 .33555 m .29933 .33654 L .29601 .33518 L closepath p F P
0 g
s
.451 .872 .937 r
.52362 .45604 m .52545 .45627 L .51556 .45903 L p F P
0 g
s
.451 .872 .937 r
.51556 .45903 m .51319 .45876 L .52362 .45604 L p F P
0 g
s
.408 .852 .919 r
.51319 .45876 m .51556 .45903 L p .50306 .46126 L F P
0 g
s
.929 .593 .38 r
.10744 .33942 m .10778 .34192 L .11134 .34502 L p F P
0 g
s
.922 .553 .304 r
.10865 .34568 m .11221 .34878 L .11134 .34502 L p F P
0 g
s
.922 .553 .304 r
.11134 .34502 m .10778 .34192 L .10865 .34568 L p F P
0 g
s
0 .449 .788 r
.24231 .44036 m .24393 .44086 L .24019 .43938 L closepath p F P
0 g
s
.035 .55 .87 r
.26675 .44794 m .26224 .44696 L .2681 .44903 L p F P
0 g
s
.035 .55 .87 r
.2681 .44903 m .26985 .44941 L .26675 .44794 L p F P
0 g
s
.934 .602 .385 r
.10408 .3373 m .1038 .3349 L .10727 .33804 L p F P
0 g
s
.934 .602 .385 r
.10727 .33804 m .10744 .33942 L .10408 .3373 L p F P
0 g
s
.297 .166 .528 r
.72876 .3176 m .72505 .3216 L .72467 .31723 L p F P
0 g
s
.297 .166 .528 r
.72467 .31723 m .72812 .3135 L .72876 .3176 L p F P
0 g
s
.589 .58 .811 r
.72065 .27076 m .71685 .27524 L p .7097 .27056 L F P
0 g
s
.589 .58 .811 r
.7097 .27056 m .72004 .2694 L .72065 .27076 L p F P
0 g
s
.586 .619 .852 r
.70735 .26617 m .7097 .27056 L .72004 .2694 L p F P
0 g
s
.907 .508 .235 r
.11339 .35243 m .11702 .35549 L .11584 .35184 L p F P
0 g
s
.907 .508 .235 r
.11584 .35184 m .11221 .34878 L .11339 .35243 L p F P
0 g
s
.15 .52 .917 r
.2097 .28813 m .21363 .29112 L .20751 .28939 L p F P
0 g
s
.15 .52 .917 r
.20377 .28635 m .2097 .28813 L p .20751 .28939 L F P
0 g
s
.15 .52 .917 r
.20751 .28939 m .20389 .28645 L .20377 .28635 L p F P
0 g
s
.606 .073 0 r
.34116 .35182 m .34062 .35197 L .33988 .35154 L closepath p F P
0 g
s
0 .229 .623 r
.25233 .31303 m .25491 .31445 L .25963 .31707 L p F P
0 g
s
0 .274 .653 r
.25943 .31688 m .25491 .31445 L .25963 .31707 L p F P
0 g
s
0 .274 .653 r
.26431 .31937 m .25943 .31688 L p .25963 .31707 L F P
0 g
s
0 .274 .653 r
.25963 .31707 m .26437 .3194 L .26431 .31937 L p F P
0 g
s
0 .214 .621 r
.25491 .31445 m .25233 .31303 L .24922 .31108 L p F P
0 g
s
.938 .638 .447 r
.10039 .33172 m .1038 .3349 L .10369 .33088 L p F P
0 g
s
.938 .638 .447 r
.10369 .33088 m .10028 .3277 L .10039 .33172 L p F P
0 g
s
.6 .098 .032 r
.36869 .35859 m .36832 .3588 L .36764 .35845 L closepath p F P
0 g
s
.439 .876 .819 r
.59332 .4349 m .59524 .43456 L .58527 .43883 L p F P
0 g
s
.439 .876 .819 r
.58527 .43883 m .58398 .43906 L .59332 .4349 L p F P
0 g
s
.523 0 0 r
.28266 .32853 m .28397 .32939 L .28067 .32783 L closepath p F P
0 g
s
.886 .46 .164 r
.11848 .35905 m .12217 .36208 L .1207 .35852 L p F P
0 g
s
.886 .46 .164 r
.1207 .35852 m .11702 .35549 L .11848 .35905 L p F P
0 g
s
.414 .637 .948 r
.17645 .27513 m .17663 .27514 L .17439 .27303 L closepath p F P
0 g
s
.559 .551 .802 r
.71685 .27524 m .72065 .27076 L .72255 .2752 L closepath p F P
0 g
s
.471 0 0 r
.26921 .32201 m .26748 .32095 L .26437 .3194 L p F P
0 g
s
.607 .076 0 r
.33696 .35253 m .33276 .34986 L .33988 .35154 L p F P
0 g
s
.607 .076 0 r
.33798 .35276 m .33696 .35253 L p .33988 .35154 L F P
0 g
s
.607 .076 0 r
.33988 .35154 m .34062 .35197 L .33798 .35276 L p F P
0 g
s
.116 0 0 r
.51315 .34222 m .51416 .34127 L .50415 .34459 L p F P
0 g
s
.116 0 0 r
.50415 .34459 m .50327 .3454 L .51315 .34222 L p F P
0 g
s
.601 .106 .048 r
.3638 .35981 m .35934 .3572 L .36764 .35845 L p F P
0 g
s
.601 .106 .048 r
.36611 .36015 m .3638 .35981 L p .36764 .35845 L F P
0 g
s
.601 .106 .048 r
.36764 .35845 m .36832 .3588 L .36611 .36015 L p F P
0 g
s
.48 .432 .727 r
.72537 .28906 m .72695 .28727 L .72776 .28995 L closepath p F P
0 g
s
.71 .97 .931 r
.60312 .29597 m .60256 .29589 L .60543 .29417 L closepath p F P
0 g
s
.397 .63 .948 r
.18423 .2745 m .18544 .27572 L .17663 .27514 L p F P
0 g
s
.397 .63 .948 r
.18205 .27254 m .18423 .2745 L p .17663 .27514 L F P
0 g
s
.397 .63 .948 r
.17331 .27193 m .18205 .27254 L p .17663 .27514 L F P
0 g
s
.397 .63 .948 r
.17663 .27514 m .17439 .27303 L .17331 .27193 L p F P
0 g
s
0 .315 .69 r
.21251 .42777 m .21179 .4274 L .21139 .42722 L closepath p F P
0 g
s
.435 .868 .769 r
.61437 .42608 m .60763 .42937 L .60552 .42998 L p F P
0 g
s
.299 .591 .945 r
.18857 .27883 m .18904 .27892 L .19262 .28205 L p F P
0 g
s
.312 .597 .946 r
.19615 .28024 m .19988 .28332 L .19262 .28205 L p F P
0 g
s
.312 .597 .946 r
.19262 .28205 m .18904 .27892 L .19615 .28024 L p F P
0 g
s
.265 .106 .471 r
.72518 .32564 m .72278 .32807 L .72301 .32366 L p F P
0 g
s
.265 .106 .471 r
.72301 .32366 m .72505 .3216 L .72518 .32564 L p F P
0 g
s
0 0 0 r
.69154 .37327 m .68994 .37459 L .69115 .37222 L p F P
0 g
s
0 0 0 r
.69115 .37222 m .69772 .3668 L .69154 .37327 L p F P
0 g
s
.346 .236 .583 r
.73185 .30944 m .72812 .3135 L .72656 .30973 L p F P
0 g
s
.346 .236 .583 r
.72656 .30973 m .73119 .30469 L .73185 .30944 L p F P
0 g
s
.212 .686 .938 r
.32528 .46214 m .32563 .46215 L .32506 .46205 L closepath p F P
0 g
s
.69 .154 0 r
.15093 .38978 m .14853 .38722 L .14525 .38523 L p F P
0 g
s
.383 0 .003 r
.46651 .35672 m .4575 .35826 L .45582 .36011 L p F P
0 g
s
.937 .666 .501 r
.09693 .32449 m .10028 .3277 L .10054 .32355 L p F P
0 g
s
.937 .666 .501 r
.10054 .32355 m .09719 .32033 L .09693 .32449 L p F P
0 g
s
.742 .886 .945 r
.64721 .27492 m .64715 .27495 L .6472 .27491 L closepath p F P
0 g
s
.738 .906 .952 r
.64483 .27333 m .6472 .27491 L .64715 .27495 L p F P
0 g
s
.738 .906 .952 r
.63484 .27901 m .64483 .27333 L p .64715 .27495 L F P
0 g
s
.747 .886 .943 r
.65485 .26775 m .65723 .26966 L .64721 .27492 L p F P
0 g
s
.747 .886 .943 r
.65361 .26844 m .65485 .26775 L p .64721 .27492 L F P
0 g
s
.747 .886 .943 r
.64721 .27492 m .6472 .27491 L .65361 .26844 L p F P
0 g
s
.469 0 0 r
.18315 .41202 m .18153 .41095 L .17829 .40921 L p F P
0 g
s
.747 .888 .943 r
.6472 .27491 m .64483 .27333 L .65361 .26844 L closepath p F P
0 g
s
.86 .409 .093 r
.1239 .36555 m .12217 .36208 L .12591 .36507 L p F P
0 g
s
.86 .409 .093 r
.1262 .36739 m .1239 .36555 L p .12591 .36507 L F P
0 g
s
.86 .409 .093 r
.12591 .36507 m .12748 .3682 L .1262 .36739 L p F P
0 g
s
.736 .943 .951 r
.63309 .28001 m .62486 .28477 L .62251 .28391 L p F P
0 g
s
.33 .765 .968 r
.37797 .46797 m .3805 .46783 L .39034 .46849 L p F P
0 g
s
.332 .765 .97 r
.37797 .46797 m .3805 .46783 L .3769 .46759 L closepath p F P
0 g
s
.282 .717 .966 r
.33314 .46176 m .33471 .46245 L .32563 .46215 L p F P
0 g
s
.282 .717 .966 r
.32962 .46104 m .33314 .46176 L p .32563 .46215 L F P
0 g
s
.282 .717 .966 r
.32228 .46081 m .32962 .46104 L p .32563 .46215 L F P
0 g
s
.282 .717 .966 r
.32563 .46215 m .32506 .46205 L .32228 .46081 L p F P
0 g
s
0 .39 .791 r
.24594 .30899 m .24096 .30675 L .24544 .30949 L p F P
0 g
s
0 .39 .791 r
.24641 .30926 m .24594 .30899 L p .24544 .30949 L F P
0 g
s
0 .39 .791 r
.24544 .30949 m .24922 .31108 L .24641 .30926 L p F P
0 g
s
.504 0 0 r
.17418 .40674 m .17033 .40394 L .17474 .40662 L p F P
0 g
s
.504 0 0 r
.17749 .40876 m .17418 .40674 L p .17474 .40662 L F P
0 g
s
.504 0 0 r
.17474 .40662 m .17829 .40921 L .17749 .40876 L p F P
0 g
s
.462 .888 .823 r
.60523 .43003 m .60552 .42998 L .59633 .43436 L p F P
0 g
s
.462 .888 .823 r
.59633 .43436 m .59524 .43456 L .60523 .43003 L p F P
0 g
s
0 0 0 r
.54547 .32683 m .5468 .32593 L .53753 .33026 L p F P
0 g
s
0 0 0 r
.53753 .33026 m .53554 .33167 L .54547 .32683 L p F P
0 g
s
.408 .852 .919 r
.50306 .46126 m .50939 .45964 L .51319 .45876 L p F P
0 g
s
.44 .863 .943 r
.50306 .46126 m .50939 .45964 L .50256 .46119 L closepath p F P
0 g
s
.232 .688 .951 r
.32506 .46205 m .32228 .46081 L .31843 .46058 L closepath p F P
0 g
s
.496 .894 .75 r
.57786 .30849 m .58025 .30781 L .57032 .31349 L p F P
0 g
s
.496 .894 .75 r
.57032 .31349 m .56931 .31386 L .57786 .30849 L p F P
0 g
s
.411 .811 .983 r
.42475 .46878 m .41639 .46897 L .41544 .46864 L p F P
0 g
s
.387 .799 .979 r
.41639 .46897 m .41544 .46864 L .41243 .46897 L closepath p F P
0 g
s
0 .393 .753 r
.22704 .43427 m .22702 .43427 L .22702 .43426 L closepath p F P
0 g
s
.396 .8 .983 r
.4126 .46757 m .41544 .46864 L .41243 .46897 L p F P
0 g
s
.396 .8 .983 r
.40293 .46868 m .4126 .46757 L p .41243 .46897 L F P
0 g
s
.396 .8 .983 r
.41243 .46897 m .40361 .46892 L .40293 .46868 L p F P
0 g
s
0 .4 .766 r
.22386 .43262 m .22192 .43189 L .22702 .43426 L p F P
0 g
s
0 .4 .766 r
.22702 .43426 m .22702 .43427 L .22386 .43262 L p F P
0 g
s
0 .44 .799 r
.23316 .43633 m .22702 .43427 L .22386 .43262 L p F P
0 g
s
.105 0 .252 r
.71691 .3435 m .71075 .34927 L .7134 .34401 L p F P
0 g
s
.105 0 .252 r
.7134 .34401 m .7174 .34027 L .71691 .3435 L p F P
0 g
s
.37 .787 .978 r
.40361 .46892 m .40293 .46868 L .40104 .46885 L closepath p F P
0 g
s
.637 .088 0 r
.15407 .39279 m .15821 .39559 L .15509 .39257 L p F P
0 g
s
.637 .088 0 r
.15509 .39257 m .15093 .38978 L .15407 .39279 L p F P
0 g
s
.522 .496 .768 r
.72293 .28151 m .72438 .27983 L .7251 .28183 L closepath p F P
0 g
s
.465 .888 .904 r
.55786 .4469 m .56037 .44694 L .55043 .45039 L p F P
0 g
s
.465 .888 .904 r
.55043 .45039 m .548 .45036 L .55786 .4469 L p F P
0 g
s
.618 .126 .064 r
.36832 .3588 m .37223 .36102 L .36611 .36015 L closepath p F P
0 g
s
0 .323 .703 r
.2086 .42569 m .20652 .42475 L .21139 .42722 L p F P
0 g
s
0 .323 .703 r
.21139 .42722 m .21179 .4274 L .2086 .42569 L p F P
0 g
s
.38 .789 .981 r
.40008 .46756 m .40293 .46868 L .40104 .46885 L p F P
0 g
s
.38 .789 .981 r
.39044 .46848 m .40008 .46756 L p .40104 .46885 L F P
0 g
s
.38 .789 .981 r
.40104 .46885 m .39049 .46849 L .39044 .46848 L p F P
0 g
s
.3 0 0 r
.4901 .35154 m .49074 .35076 L .48091 .35257 L p F P
0 g
s
.3 0 0 r
.48091 .35257 m .47952 .35416 L .4901 .35154 L p F P
0 g
s
.932 .597 .377 r
.10778 .34192 m .10744 .33942 L .10408 .3373 L p F P
0 g
s
.642 .122 0 r
.34062 .35197 m .34402 .35424 L .33798 .35276 L closepath p F P
0 g
s
.402 .81 .979 r
.42884 .46866 m .42795 .46836 L .42475 .46878 L closepath p F P
0 g
s
.411 .811 .983 r
.42513 .46734 m .42795 .46836 L .42475 .46878 L p F P
0 g
s
.411 .811 .983 r
.41544 .46864 m .42513 .46734 L p .42475 .46878 L F P
0 g
s
.68 .723 .882 r
.68211 .26528 m .69224 .26142 L .69464 .26488 L p F P
0 g
s
.692 .744 .891 r
.69224 .26142 m .68211 .26528 L .67973 .26239 L p F P
0 g
s
.932 .691 .55 r
.09391 .31708 m .09719 .32033 L .09784 .31604 L p F P
0 g
s
.932 .691 .55 r
.09784 .31604 m .09456 .31279 L .09391 .31708 L p F P
0 g
s
.424 .821 .983 r
.4383 .46817 m .42884 .46866 L .42795 .46836 L p F P
0 g
s
.145 0 .326 r
.71995 .33772 m .7174 .34027 L .7177 .33679 L p F P
0 g
s
.145 0 .326 r
.7177 .33679 m .72173 .33277 L .71995 .33772 L p F P
0 g
s
.848 .388 .075 r
.12748 .3682 m .12767 .36854 L .13153 .37148 L p F P
0 g
s
.801 .31 0 r
.12986 .37185 m .13371 .37479 L .13153 .37148 L p F P
0 g
s
.801 .31 0 r
.13153 .37148 m .12767 .36854 L .12986 .37185 L p F P
0 g
s
.09 .587 .898 r
.27602 .45054 m .26985 .44941 L .26675 .44794 L p F P
0 g
s
.013 .527 .863 r
.24524 .4405 m .2507 .44274 L .24393 .44086 L p F P
0 g
s
.013 .527 .863 r
.23916 .43886 m .24524 .4405 L p .24393 .44086 L F P
0 g
s
.013 .527 .863 r
.24393 .44086 m .24019 .43938 L .23916 .43886 L p F P
0 g
s
0 0 0 r
.63988 .41234 m .63861 .41309 L .63973 .41245 L closepath p F P
0 g
s
.372 .805 .637 r
.63759 .41356 m .63973 .41245 L .63861 .41309 L p F P
0 g
s
.372 .805 .637 r
.63627 .41432 m .63759 .41356 L p .63861 .41309 L F P
0 g
s
.372 .805 .637 r
.62868 .41872 m .63627 .41432 L p .63861 .41309 L F P
0 g
s
.647 .67 .858 r
.69464 .26488 m .70484 .26187 L .70726 .26601 L p F P
0 g
s
.661 .693 .869 r
.70484 .26187 m .69464 .26488 L .69224 .26142 L p F P
0 g
s
.039 0 .163 r
.70934 .35058 m .70898 .35213 L .71075 .34927 L closepath p F P
0 g
s
.379 0 0 r
.19661 .41971 m .19678 .4198 L .19628 .41954 L closepath p F P
0 g
s
0 .364 .739 r
.21688 .42949 m .21179 .4274 L .2086 .42569 L p F P
0 g
s
.189 .657 .937 r
.3044 .45728 m .29753 .45656 L .29448 .45518 L p F P
0 g
s
.508 .678 .941 r
.16112 .26916 m .16975 .26871 L .17318 .27194 L p F P
0 g
s
.508 .675 .939 r
.16975 .26871 m .16112 .26916 L .15796 .26586 L p F P
0 g
s
.351 .774 .975 r
.39049 .46849 m .39044 .46848 L .39034 .46849 L closepath p F P
0 g
s
.367 .776 .982 r
.38756 .46731 m .3805 .46783 L .39034 .46849 L p F P
0 g
s
.367 .776 .982 r
.39034 .46849 m .39044 .46848 L .38756 .46731 L p F P
0 g
s
.395 .791 .987 r
.40008 .46756 m .39044 .46848 L .38756 .46731 L p F P
0 g
s
.605 .036 0 r
.29755 .33703 m .30332 .33924 L .29933 .33654 L p F P
0 g
s
.605 .036 0 r
.29476 .33496 m .29755 .33703 L p .29933 .33654 L F P
0 g
s
.605 .036 0 r
.29933 .33654 m .29601 .33518 L .29476 .33496 L p F P
0 g
s
.658 .971 .885 r
.59176 .3018 m .59018 .30192 L .59892 .29654 L closepath p F P
0 g
s
0 .316 .703 r
.19697 .41971 m .20172 .42225 L .19678 .4198 L p F P
0 g
s
0 .316 .703 r
.1934 .41794 m .19697 .41971 L p .19678 .4198 L F P
0 g
s
0 .316 .703 r
.19678 .4198 m .19628 .41954 L .1934 .41794 L p F P
0 g
s
0 0 0 r
.6483 .40712 m .64985 .4061 L .63988 .41234 L p F P
0 g
s
0 0 0 r
.63988 .41234 m .63973 .41245 L .6483 .40712 L p F P
0 g
s
.044 .49 .886 r
.23095 .3003 m .22725 .29896 L .23151 .30179 L p F P
0 g
s
.044 .49 .886 r
.23151 .30179 m .23408 .30267 L .23095 .3003 L p F P
0 g
s
.631 .077 0 r
.31324 .3441 m .31953 .3461 L .3155 .3434 L p F P
0 g
s
.631 .077 0 r
.31001 .34168 m .31324 .3441 L p .3155 .3434 L F P
0 g
s
.631 .077 0 r
.3155 .3434 m .31058 .34168 L .31001 .34168 L p F P
0 g
s
.709 .795 .918 r
.66975 .26703 m .66965 .26691 L .67 .26676 L closepath p F P
0 g
s
.451 .861 .959 r
.5004 .46074 m .49055 .46312 L .48786 .46253 L p F P
0 g
s
.684 .973 .914 r
.60543 .29417 m .60256 .29589 L .60013 .2958 L p F P
0 g
s
.175 .645 .933 r
.29173 .4539 m .29448 .45518 L .28856 .45439 L p F P
0 g
s
.175 .645 .933 r
.29108 .45371 m .29173 .4539 L p .28856 .45439 L F P
0 g
s
.175 .645 .933 r
.28214 .45255 m .29108 .45371 L p .28856 .45439 L F P
0 g
s
.175 .645 .933 r
.28856 .45439 m .28218 .45257 L .28214 .45255 L p F P
0 g
s
.627 .122 .028 r
.35574 .35847 m .3638 .35981 L .35934 .3572 L p F P
0 g
s
.627 .122 .028 r
.35292 .35658 m .35574 .35847 L p .35934 .3572 L F P
0 g
s
.627 .122 .028 r
.35934 .3572 m .3538 .35617 L .35292 .35658 L p F P
0 g
s
.554 0 0 r
.28266 .32967 m .28801 .33204 L .28397 .32939 L p F P
0 g
s
.554 0 0 r
.27955 .32745 m .28266 .32967 L p .28397 .32939 L F P
0 g
s
.554 0 0 r
.28397 .32939 m .28067 .32783 L .27955 .32745 L p F P
0 g
s
0 0 0 r
.65041 .40572 m .64985 .4061 L .65358 .40366 L closepath p F P
0 g
s
.709 .814 .93 r
.67 .26676 m .66965 .26691 L .66727 .26456 L p F P
0 g
s
.73 .82 .92 r
.65723 .26966 m .66727 .26456 L .66965 .26691 L p F P
0 g
s
.416 .821 .979 r
.44099 .46801 m .44046 .46784 L .4383 .46817 L closepath p F P
0 g
s
.424 .821 .983 r
.43767 .46687 m .44046 .46784 L .4383 .46817 L p F P
0 g
s
.424 .821 .983 r
.42795 .46836 m .43767 .46687 L p .4383 .46817 L F P
0 g
s
.578 .698 .924 r
.14568 .26412 m .14926 .26351 L .15247 .26683 L p F P
0 g
s
.582 .7 .923 r
.1548 .26253 m .14926 .26351 L .15247 .26683 L p F P
0 g
s
.582 .7 .923 r
.15247 .26683 m .15796 .26586 L .1548 .26253 L p F P
0 g
s
0 .238 .631 r
.19628 .41954 m .1934 .41794 L .19211 .41724 L closepath p F P
0 g
s
.479 .873 .966 r
.50939 .45964 m .50256 .46119 L .5004 .46074 L p F P
0 g
s
.721 .816 .924 r
.67 .26676 m .67973 .26239 L .67735 .2597 L p F P
0 g
s
.721 .816 .924 r
.67735 .2597 m .6756 .26054 L .67 .26676 L p F P
0 g
s
.709 .814 .93 r
.66727 .26456 m .6756 .26054 L .67 .26676 L p F P
0 g
s
.441 .833 .983 r
.45022 .46616 m .45286 .46705 L .44099 .46801 L p F P
0 g
s
.441 .833 .983 r
.44099 .46801 m .44046 .46784 L .45022 .46616 L p F P
0 g
s
0 0 0 r
.66077 .39858 m .65981 .39939 L .66567 .39519 L closepath p F P
0 g
s
.419 .835 .66 r
.64758 .40749 m .6483 .40712 L .63973 .41245 L p F P
0 g
s
.419 .835 .66 r
.63973 .41245 m .63759 .41356 L .64758 .40749 L p F P
0 g
s
.3 .729 .97 r
.3452 .46379 m .33769 .46371 L .33471 .46245 L p F P
0 g
s
.764 .254 0 r
.13615 .37803 m .14006 .38095 L .13763 .37771 L p F P
0 g
s
.764 .254 0 r
.13763 .37771 m .13371 .37479 L .13615 .37803 L p F P
0 g
s
.413 .802 .988 r
.4126 .46757 m .40293 .46868 L .40008 .46756 L p F P
0 g
s
.658 .136 0 r
.32997 .35079 m .33696 .35253 L .33276 .34986 L p F P
0 g
s
.658 .136 0 r
.33276 .34986 m .32612 .34799 L .32997 .35079 L p F P
0 g
s
.383 .781 .986 r
.38467 .4661 m .38756 .46731 L .3805 .46783 L p F P
0 g
s
.383 .781 .986 r
.37507 .46683 m .38467 .4661 L p .3805 .46783 L F P
0 g
s
.383 .781 .986 r
.3805 .46783 m .3769 .46759 L .37507 .46683 L p F P
0 g
s
.45 .854 .968 r
.48692 .46229 m .48786 .46253 L .47803 .46469 L p F P
0 g
s
.45 .854 .968 r
.47803 .46469 m .47581 .46417 L .48692 .46229 L p F P
0 g
s
.418 .84 .959 r
.47581 .46417 m .47803 .46469 L p .46551 .46601 L F P
0 g
s
.471 0 0 r
.26437 .3194 m .2644 .31942 L .26921 .32201 L p F P
0 g
s
.484 0 0 r
.2684 .32206 m .27343 .32457 L .26921 .32201 L p F P
0 g
s
.484 0 0 r
.26921 .32201 m .2644 .31942 L .2684 .32206 L p F P
0 g
s
0 0 0 r
.55582 .32121 m .55791 .31996 L .548 .32514 L p F P
0 g
s
0 0 0 r
.548 .32514 m .5468 .32593 L .55582 .32121 L p F P
0 g
s
.384 0 0 r
.46864 .35637 m .46837 .35666 L .46651 .35672 L closepath p F P
0 g
s
.383 0 .003 r
.46684 .35856 m .46837 .35666 L .46651 .35672 L p F P
0 g
s
.383 0 .003 r
.45724 .36009 m .46684 .35856 L p .46651 .35672 L F P
0 g
s
.383 0 .003 r
.45582 .36011 m .45724 .36009 L p .46651 .35672 L F P
0 g
s
.043 .553 .875 r
.26364 .44644 m .25641 .44487 L .26224 .44696 L p F P
0 g
s
.043 .553 .875 r
.26224 .44696 m .26675 .44794 L .26364 .44644 L p F P
0 g
s
0 .521 .844 r
.2545 .44441 m .25641 .44487 L .26224 .44696 L p F P
0 g
s
.493 .463 .752 r
.7251 .28183 m .73022 .28322 L .72695 .28727 L closepath p F P
0 g
s
.44 .407 .726 r
.73553 .28565 m .73022 .28322 L .72695 .28727 L p F P
0 g
s
.44 .407 .726 r
.73067 .29149 m .73553 .28565 L p .72695 .28727 L F P
0 g
s
.44 .407 .726 r
.72695 .28727 m .72776 .28995 L .73067 .29149 L p F P
0 g
s
.573 .014 0 r
.16005 .39716 m .15821 .39559 L .16242 .39836 L p F P
0 g
s
.573 .014 0 r
.16242 .39836 m .16331 .39911 L .16005 .39716 L p F P
0 g
s
.486 .898 .905 r
.57034 .44325 m .57117 .44326 L .5615 .44695 L p F P
0 g
s
.486 .898 .905 r
.5615 .44695 m .56037 .44694 L .57034 .44325 L p F P
0 g
s
.711 .969 .933 r
.6125 .28994 m .60543 .29417 L .61112 .28972 L closepath p F P
0 g
s
.684 .973 .914 r
.61009 .28957 m .61112 .28972 L .60543 .29417 L p F P
0 g
s
.684 .973 .914 r
.60013 .2958 m .61009 .28957 L p .60543 .29417 L F P
0 g
s
.384 .829 .704 r
.6176 .42446 m .61437 .42608 L .61729 .42458 L closepath p F P
0 g
s
.435 .868 .769 r
.61523 .42515 m .61729 .42458 L .61437 .42608 L p F P
0 g
s
.435 .868 .769 r
.60821 .42861 m .61523 .42515 L p .61437 .42608 L F P
0 g
s
.435 .868 .769 r
.60552 .42998 m .60821 .42861 L p .61437 .42608 L F P
0 g
s
0 0 0 r
.5259 .33581 m .52564 .33601 L .53177 .33332 L closepath p F P
0 g
s
.453 .402 .711 r
.72776 .28995 m .73067 .29149 L .72882 .29372 L closepath p F P
0 g
s
.471 .882 .938 r
.53537 .45327 m .53795 .45357 L .53725 .45378 L p F P
0 g
s
.471 .882 .938 r
.52545 .45627 m .53537 .45327 L p .53725 .45378 L F P
0 g
s
.457 .878 .927 r
.53797 .45357 m .53795 .45357 L .53725 .45378 L closepath p F P
0 g
s
.202 .567 .938 r
.21581 .29169 m .21363 .29112 L .21769 .29405 L p F P
0 g
s
.202 .567 .938 r
.21769 .29405 m .21893 .29436 L .21581 .29169 L p F P
0 g
s
.545 .083 .108 r
.41997 .3634 m .41815 .3653 L .41243 .36347 L closepath p F P
0 g
s
.543 .073 .09 r
.41798 .3655 m .41815 .3653 L .41243 .36347 L p F P
0 g
s
.543 .073 .09 r
.40682 .36552 m .41798 .3655 L p .41243 .36347 L F P
0 g
s
.543 .073 .09 r
.40563 .36507 m .40682 .36552 L p .41243 .36347 L F P
0 g
s
.543 .073 .09 r
.41243 .36347 m .4073 .36347 L .40563 .36507 L p F P
0 g
s
.568 .102 .108 r
.4073 .36347 m .40563 .36507 L .40114 .36331 L closepath p F P
0 g
s
.351 .765 .98 r
.3769 .46759 m .37507 .46683 L .3711 .46703 L closepath p F P
0 g
s
.469 0 0 r
.17829 .40921 m .17859 .40941 L .18315 .41202 L p F P
0 g
s
.375 0 0 r
.183 .41202 m .18753 .41465 L .18315 .41202 L p F P
0 g
s
.375 0 0 r
.18315 .41202 m .17859 .40941 L .183 .41202 L p F P
0 g
s
.514 .048 .086 r
.42501 .36318 m .41997 .3634 L .41815 .3653 L p F P
0 g
s
.484 .473 .77 r
.72438 .27983 m .7251 .28183 L .73022 .28322 L p F P
0 g
s
.613 .639 .853 r
.70726 .26601 m .70751 .26596 L .70735 .26617 L closepath p F P
0 g
s
.586 .619 .852 r
.71757 .26427 m .70751 .26596 L .70735 .26617 L p F P
0 g
s
.586 .619 .852 r
.72004 .2694 m .71757 .26427 L p .70735 .26617 L F P
0 g
s
.426 .813 .989 r
.42513 .46734 m .41544 .46864 L .4126 .46757 L p F P
0 g
s
.224 0 0 r
.50061 .34828 m .50223 .34651 L .49195 .34949 L p F P
0 g
s
.224 0 0 r
.49195 .34949 m .49074 .35076 L .50061 .34828 L p F P
0 g
s
.196 .67 .935 r
.30989 .45888 m .31126 .45899 L .31843 .46058 L p F P
0 g
s
.239 .689 .954 r
.31927 .45943 m .31126 .45899 L .31843 .46058 L p F P
0 g
s
.239 .689 .954 r
.31843 .46058 m .32228 .46081 L .31927 .45943 L p F P
0 g
s
.746 .926 .95 r
.63484 .27901 m .63309 .28001 L .63442 .27881 L closepath p F P
0 g
s
.736 .943 .951 r
.63245 .27789 m .63442 .27881 L .63309 .28001 L p F P
0 g
s
.736 .943 .951 r
.62266 .28378 m .63245 .27789 L p .63309 .28001 L F P
0 g
s
.736 .943 .951 r
.62251 .28391 m .62266 .28378 L p .63309 .28001 L F P
0 g
s
.605 .953 .851 r
.58049 .30777 m .58025 .30781 L .5818 .30689 L closepath p F P
0 g
s
.346 0 0 r
.47818 .35572 m .47952 .35416 L .46864 .35637 L p F P
0 g
s
.346 0 0 r
.46864 .35637 m .46837 .35666 L .47818 .35572 L p F P
0 g
s
.568 .093 .086 r
.40522 .36551 m .40563 .36507 L .40114 .36331 L p F P
0 g
s
.568 .093 .086 r
.396 .36518 m .40522 .36551 L p .40114 .36331 L F P
0 g
s
.568 .093 .086 r
.39315 .36386 m .396 .36518 L p .40114 .36331 L F P
0 g
s
.568 .093 .086 r
.40114 .36331 m .39414 .363 L .39315 .36386 L p F P
0 g
s
.517 .684 .942 r
.17439 .27303 m .17331 .27193 L .17318 .27194 L closepath p F P
0 g
s
.481 .89 .932 r
.54788 .45035 m .548 .45036 L .53797 .45357 L p F P
0 g
s
.481 .89 .932 r
.53797 .45357 m .53795 .45357 L .54788 .45035 L p F P
0 g
s
.627 .66 .863 r
.70751 .26596 m .70726 .26601 L .70484 .26187 L p F P
0 g
s
.418 .84 .959 r
.46551 .46601 m .47211 .4647 L .47581 .46417 L p F P
0 g
s
.439 .844 .972 r
.46551 .46601 m .47211 .4647 L .46444 .46574 L closepath p F P
0 g
s
.411 .832 .964 r
.46444 .46574 m .46551 .46601 L p .45298 .46708 L F P
0 g
s
.467 .892 .87 r
.58068 .43932 m .58281 .43916 L .57284 .44312 L p F P
0 g
s
.467 .892 .87 r
.57284 .44312 m .57117 .44326 L .58068 .43932 L p F P
0 g
s
.24 .088 .465 r
.72857 .322 m .72518 .32564 L .72505 .3216 L p F P
0 g
s
.24 .088 .465 r
.72505 .3216 m .72876 .3176 L .72857 .322 L p F P
0 g
s
.495 .894 .942 r
.54788 .45035 m .53795 .45357 L .53537 .45327 L p F P
0 g
s
0 0 0 r
.67081 .39102 m .66975 .39211 L .67574 .3874 L closepath p F P
0 g
s
.627 .66 .863 r
.70484 .26187 m .71169 .26029 L .70751 .26596 L p F P
0 g
s
.605 .622 .842 r
.71513 .25955 m .71169 .26029 L .70751 .26596 L p F P
0 g
s
.605 .622 .842 r
.70751 .26596 m .71757 .26427 L .71513 .25955 L p F P
0 g
s
.517 .058 .101 r
.43223 .36284 m .4307 .36454 L .42501 .36318 L closepath p F P
0 g
s
.514 .048 .086 r
.43032 .365 m .4307 .36454 L .42501 .36318 L p F P
0 g
s
.514 .048 .086 r
.41876 .36547 m .43032 .365 L p .42501 .36318 L F P
0 g
s
.514 .048 .086 r
.41815 .3653 m .41876 .36547 L p .42501 .36318 L F P
0 g
s
.529 .517 .786 r
.72255 .2752 m .72761 .27571 L .72438 .27983 L closepath p F P
0 g
s
.484 .473 .77 r
.73312 .27686 m .72761 .27571 L .72438 .27983 L p F P
0 g
s
.484 .473 .77 r
.73379 .27886 m .73312 .27686 L p .72438 .27983 L F P
0 g
s
.484 .473 .77 r
.73022 .28322 m .73379 .27886 L p .72438 .27983 L F P
0 g
s
.417 .352 .677 r
.73437 .2945 m .7302 .29948 L .72882 .29372 L p F P
0 g
s
.417 .352 .677 r
.72882 .29372 m .73067 .29149 L .73437 .2945 L p F P
0 g
s
.442 .862 .723 r
.62868 .41872 m .62759 .41915 L .63627 .41432 L closepath p F P
0 g
s
.035 0 .16 r
.71675 .34417 m .71691 .3435 L .71075 .34927 L p F P
0 g
s
.035 0 .16 r
.71413 .34844 m .71675 .34417 L p .71075 .34927 L F P
0 g
s
.035 0 .16 r
.70866 .35357 m .71413 .34844 L p .71075 .34927 L F P
0 g
s
.035 0 .16 r
.71075 .34927 m .70898 .35213 L .70866 .35357 L p F P
0 g
s
.171 0 0 r
.51226 .34318 m .51315 .34222 L .50327 .3454 L p F P
0 g
s
.171 0 0 r
.50327 .3454 m .50223 .34651 L .51226 .34318 L p F P
0 g
s
0 0 0 r
.70006 .36313 m .69934 .36493 L .70288 .36067 L closepath p F P
0 g
s
.438 .823 .988 r
.43767 .46687 m .42795 .46836 L .42513 .46734 L p F P
0 g
s
.623 .116 .024 r
.3538 .35617 m .35292 .35658 L .35156 .35577 L closepath p F P
0 g
s
.429 .835 .975 r
.45298 .46708 m .45362 .46697 L .45286 .46705 L closepath p F P
0 g
s
.411 .832 .964 r
.45298 .46708 m .45362 .46697 L .46444 .46574 L p F P
0 g
s
0 .216 .623 r
.25467 .31425 m .25943 .31688 L .25491 .31445 L p F P
0 g
s
0 .216 .623 r
.25491 .31445 m .25036 .31175 L .25467 .31425 L p F P
0 g
s
0 .214 .621 r
.24922 .31108 m .25036 .31175 L .25491 .31445 L p F P
0 g
s
.452 .833 .988 r
.45022 .46616 m .44046 .46784 L .43767 .46687 L p F P
0 g
s
.587 .115 .101 r
.39414 .363 m .39315 .36386 L .39081 .36279 L closepath p F P
0 g
s
.712 .184 0 r
.14196 .38316 m .14006 .38095 L .14403 .38383 L p F P
0 g
s
.712 .184 0 r
.14403 .38383 m .14525 .38523 L .14196 .38316 L p F P
0 g
s
0 .468 .818 r
.24019 .43938 m .23916 .43886 L .23844 .43864 L closepath p F P
0 g
s
.754 .927 .946 r
.64245 .2719 m .64483 .27333 L .63484 .27901 L p F P
0 g
s
.754 .927 .946 r
.64014 .27328 m .64245 .2719 L p .63484 .27901 L F P
0 g
s
.754 .927 .946 r
.63484 .27901 m .63442 .27881 L .64014 .27328 L p F P
0 g
s
.54 0 0 r
.29601 .33518 m .29476 .33496 L .29365 .3343 L closepath p F P
0 g
s
0 0 0 r
.53177 .33332 m .52564 .33601 L .52392 .33759 L p F P
0 g
s
0 .524 .851 r
.2545 .44441 m .25641 .44487 L .25223 .44335 L closepath p F P
0 g
s
.466 .842 .988 r
.45362 .46697 m .45286 .46705 L .45022 .46616 L p F P
0 g
s
.328 .622 .957 r
.20389 .28645 m .20377 .28635 L .20374 .28634 L closepath p F P
0 g
s
.395 .308 .639 r
.72944 .30033 m .7302 .29948 L .73066 .3018 L closepath p F P
0 g
s
.362 .768 .983 r
.37215 .46556 m .37507 .46683 L .3711 .46703 L p F P
0 g
s
.362 .768 .983 r
.36258 .4661 m .37215 .46556 L p .3711 .46703 L F P
0 g
s
.362 .768 .983 r
.3711 .46703 m .3629 .46624 L .36258 .4661 L p F P
0 g
s
.48 .017 .076 r
.43949 .36221 m .43223 .36284 L .4307 .36454 L p F P
0 g
s
.204 .024 .4 r
.72509 .32938 m .72173 .33277 L .72278 .32807 L p F P
0 g
s
.204 .024 .4 r
.72278 .32807 m .72518 .32564 L .72509 .32938 L p F P
0 g
s
.417 .848 .715 r
.62616 .41971 m .62759 .41915 L .6176 .42446 L p F P
0 g
s
.417 .848 .715 r
.6176 .42446 m .61729 .42458 L .62616 .41971 L p F P
0 g
s
.588 .125 .121 r
.38602 .36453 m .38127 .362 L .39081 .36279 L p F P
0 g
s
.588 .125 .121 r
.39197 .36496 m .38602 .36453 L p .39081 .36279 L F P
0 g
s
.588 .125 .121 r
.39081 .36279 m .39315 .36386 L .39197 .36496 L p F P
0 g
s
.466 .842 .988 r
.46002 .46428 m .46277 .46521 L .45362 .46697 L p F P
0 g
s
.466 .842 .988 r
.45022 .46616 m .46002 .46428 L p .45362 .46697 L F P
0 g
s
.457 .843 .984 r
.46444 .46574 m .46277 .46521 L .45362 .46697 L closepath p F P
0 g
s
.55 .926 .799 r
.5818 .30689 m .58025 .30781 L .57786 .30849 L p F P
0 g
s
.645 .109 0 r
.3253 .34741 m .32612 .34799 L .32453 .34751 L closepath p F P
0 g
s
.932 .597 .377 r
.10408 .3373 m .10428 .33879 L .10778 .34192 L p F P
0 g
s
.925 .555 .296 r
.10515 .34255 m .10865 .34568 L .10778 .34192 L p F P
0 g
s
.925 .555 .296 r
.10778 .34192 m .10428 .33879 L .10515 .34255 L p F P
0 g
s
.333 .62 .955 r
.20064 .28344 m .19988 .28332 L .20374 .28634 L p F P
0 g
s
.333 .62 .955 r
.20374 .28634 m .20377 .28635 L .20064 .28344 L p F P
0 g
s
.74 .837 .924 r
.66727 .26456 m .65723 .26966 L .65485 .26775 L p F P
0 g
s
.153 .523 .918 r
.2097 .28813 m .20377 .28635 L .20064 .28344 L p F P
0 g
s
.624 .12 .034 r
.34812 .35697 m .34402 .35424 L .35156 .35577 L p F P
0 g
s
.624 .12 .034 r
.351 .35753 m .34812 .35697 L p .35156 .35577 L F P
0 g
s
.624 .12 .034 r
.35156 .35577 m .35292 .35658 L .351 .35753 L p F P
0 g
s
.937 .606 .382 r
.10075 .33487 m .10039 .33172 L .1038 .3349 L p F P
0 g
s
.937 .606 .382 r
.1038 .3349 m .10408 .3373 L .10075 .33487 L p F P
0 g
s
.908 .509 .225 r
.10983 .34933 m .11339 .35243 L .11221 .34878 L p F P
0 g
s
.908 .509 .225 r
.11221 .34878 m .10865 .34568 L .10983 .34933 L p F P
0 g
s
.489 .903 .871 r
.5928 .43494 m .59332 .4349 L .58398 .43906 L p F P
0 g
s
.489 .903 .871 r
.58398 .43906 m .58281 .43916 L .5928 .43494 L p F P
0 g
s
.297 .585 .942 r
.18904 .27892 m .18857 .27883 L .18544 .27572 L p F P
0 g
s
.372 0 .029 r
.47773 .35632 m .47818 .35572 L .46837 .35666 L p F P
0 g
s
.372 0 .029 r
.46837 .35666 m .46684 .35856 L .47773 .35632 L p F P
0 g
s
.307 .74 .969 r
.35013 .46504 m .3535 .46499 L .36198 .46612 L p F P
0 g
s
.306 .74 .969 r
.35013 .46504 m .3535 .46499 L .34833 .46431 L closepath p F P
0 g
s
.538 0 0 r
.16599 .40123 m .16331 .39911 L .16005 .39716 L p F P
0 g
s
.468 .891 .827 r
.60281 .43044 m .60523 .43003 L .59524 .43456 L p F P
0 g
s
.468 .891 .827 r
.59921 .43208 m .60281 .43044 L p .59524 .43456 L F P
0 g
s
.468 .891 .827 r
.59524 .43456 m .59332 .4349 L .59921 .43208 L p F P
0 g
s
.202 .672 .939 r
.30989 .45888 m .31126 .45899 L .30887 .45844 L closepath p F P
0 g
s
.454 0 0 r
.28067 .32783 m .27955 .32745 L .2787 .32698 L closepath p F P
0 g
s
0 0 0 r
.65358 .40366 m .64985 .4061 L .6483 .40712 L p F P
0 g
s
.588 .022 0 r
.31058 .34168 m .31001 .34168 L .30942 .34132 L closepath p F P
0 g
s
.602 .121 .086 r
.38071 .36171 m .38127 .362 L .38044 .36191 L closepath p F P
0 g
s
.493 .891 .745 r
.57778 .30851 m .57786 .30849 L .56931 .31386 L p F P
0 g
s
.493 .891 .745 r
.56931 .31386 m .56784 .31442 L .57778 .30851 L p F P
0 g
s
0 .44 .857 r
.21893 .29436 m .22313 .29606 L .22725 .29896 L p F P
0 g
s
0 .43 .855 r
.22313 .29606 m .21893 .29436 L .21581 .29169 L p F P
0 g
s
.597 .95 .847 r
.59018 .30192 m .5818 .30689 L .58889 .30215 L closepath p F P
0 g
s
.55 .926 .799 r
.58774 .30236 m .58889 .30215 L .5818 .30689 L p F P
0 g
s
.55 .926 .799 r
.57828 .3082 m .58774 .30236 L p .5818 .30689 L F P
0 g
s
.55 .926 .799 r
.57786 .30849 m .57828 .3082 L p .5818 .30689 L F P
0 g
s
.886 .459 .153 r
.11485 .35598 m .11848 .35905 L .11702 .35549 L p F P
0 g
s
.886 .459 .153 r
.11702 .35549 m .11339 .35243 L .11485 .35598 L p F P
0 g
s
.941 .641 .443 r
.09704 .32851 m .10039 .33172 L .10028 .3277 L p F P
0 g
s
.941 .641 .443 r
.10028 .3277 m .09693 .32449 L .09704 .32851 L p F P
0 g
s
0 .403 .772 r
.22068 .43093 m .21688 .42949 L .22192 .43189 L p F P
0 g
s
0 .403 .772 r
.22192 .43189 m .22386 .43262 L .22068 .43093 L p F P
0 g
s
.061 0 .169 r
.70898 .35213 m .70725 .35482 L .70866 .35357 L closepath p F P
0 g
s
.467 .871 .957 r
.51319 .45876 m .51293 .45871 L .50939 .45964 L closepath p F P
0 g
s
.479 .873 .966 r
.51029 .45814 m .51293 .45871 L .50939 .45964 L p F P
0 g
s
.479 .873 .966 r
.5004 .46074 m .51029 .45814 L p .50939 .45964 L F P
0 g
s
0 .33 .754 r
.23408 .30267 m .23664 .30395 L .24096 .30675 L p F P
0 g
s
0 .348 .771 r
.24141 .30626 m .24594 .30899 L .24096 .30675 L p F P
0 g
s
0 .348 .771 r
.24096 .30675 m .23664 .30395 L .24141 .30626 L p F P
0 g
s
.523 .532 .806 r
.72065 .27076 m .72255 .2752 L .72761 .27571 L p F P
0 g
s
.297 .585 .942 r
.18544 .27572 m .18554 .27574 L .18904 .27892 L p F P
0 g
s
.308 .591 .944 r
.19253 .2771 m .19615 .28024 L .18904 .27892 L p F P
0 g
s
.308 .591 .944 r
.18904 .27892 m .18554 .27574 L .19253 .2771 L p F P
0 g
s
.48 0 0 r
.16986 .40401 m .17418 .40674 L .17033 .40394 L p F P
0 g
s
.48 0 0 r
.17033 .40394 m .16599 .40123 L .16986 .40401 L p F P
0 g
s
.518 .681 .94 r
.17016 .26869 m .16975 .26871 L .17318 .27194 L p F P
0 g
s
.518 .681 .94 r
.17318 .27194 m .17331 .27193 L .17016 .26869 L p F P
0 g
s
.113 .604 .907 r
.28218 .45257 m .28214 .45255 L .28209 .45254 L closepath p F P
0 g
s
.127 .609 .915 r
.27906 .45103 m .27602 .45054 L .28209 .45254 L p F P
0 g
s
.127 .609 .915 r
.28209 .45254 m .28214 .45255 L .27906 .45103 L p F P
0 g
s
0 .325 .71 r
.20539 .42393 m .20172 .42225 L .20652 .42475 L p F P
0 g
s
0 .325 .71 r
.20652 .42475 m .2086 .42569 L .20539 .42393 L p F P
0 g
s
.485 .025 .086 r
.4441 .36182 m .44325 .36279 L .43949 .36221 L closepath p F P
0 g
s
.48 .017 .076 r
.44227 .36405 m .44325 .36279 L .43949 .36221 L p F P
0 g
s
.48 .017 .076 r
.4323 .36485 m .44227 .36405 L p .43949 .36221 L F P
0 g
s
.48 .017 .076 r
.4307 .36454 m .4323 .36485 L p .43949 .36221 L F P
0 g
s
0 .474 .827 r
.23601 .43721 m .23316 .43633 L .23844 .43864 L p F P
0 g
s
0 .474 .827 r
.23844 .43864 m .23916 .43886 L .23601 .43721 L p F P
0 g
s
.73 .973 .928 r
.62006 .28327 m .62247 .28389 L .6125 .28994 L p F P
0 g
s
.73 .973 .928 r
.61469 .28666 m .62006 .28327 L p .6125 .28994 L F P
0 g
s
.73 .973 .928 r
.6125 .28994 m .61112 .28972 L .61469 .28666 L p F P
0 g
s
.18 .641 .938 r
.29108 .45371 m .28214 .45255 L .27906 .45103 L p F P
0 g
s
.754 .928 .946 r
.63442 .27881 m .63245 .27789 L .64014 .27328 L closepath p F P
0 g
s
0 0 0 r
.68053 .38302 m .67967 .38412 L .68425 .38013 L closepath p F P
0 g
s
.418 .64 .948 r
.18205 .27254 m .17331 .27193 L .17016 .26869 L p F P
0 g
s
.587 .02 0 r
.30689 .34161 m .30332 .33924 L .30942 .34132 L p F P
0 g
s
.587 .02 0 r
.30942 .34132 m .31001 .34168 L .30689 .34161 L p F P
0 g
s
.294 .164 .527 r
.73224 .31382 m .72876 .3176 L .72812 .3135 L p F P
0 g
s
.294 .164 .527 r
.72812 .3135 m .73185 .30944 L .73224 .31382 L p F P
0 g
s
.061 0 0 r
.52305 .3384 m .52392 .33759 L .51416 .34127 L p F P
0 g
s
.061 0 0 r
.51416 .34127 m .51315 .34222 L .52305 .3384 L p F P
0 g
s
.535 0 0 r
.29164 .33435 m .28801 .33204 L .29365 .3343 L p F P
0 g
s
.535 0 0 r
.29365 .3343 m .29476 .33496 L .29164 .33435 L p F P
0 g
s
.859 .407 .078 r
.12022 .36252 m .1239 .36555 L .12217 .36208 L p F P
0 g
s
.859 .407 .078 r
.12217 .36208 m .11848 .35905 L .12022 .36252 L p F P
0 g
s
0 .318 .751 r
.23664 .30395 m .23408 .30267 L .23095 .3003 L p F P
0 g
s
.477 .891 .787 r
.62524 .41995 m .62616 .41971 L .61729 .42458 L p F P
0 g
s
.477 .891 .787 r
.61729 .42458 m .61523 .42515 L .62524 .41995 L p F P
0 g
s
.477 .884 .942 r
.53386 .45308 m .53537 .45327 L .52545 .45627 L p F P
0 g
s
.477 .884 .942 r
.52545 .45627 m .52362 .45604 L .53386 .45308 L p F P
0 g
s
.94 .67 .498 r
.09364 .32123 m .09693 .32449 L .09719 .32033 L p F P
0 g
s
.94 .67 .498 r
.09719 .32033 m .09391 .31708 L .09364 .32123 L p F P
0 g
s
.347 .275 .633 r
.73692 .29792 m .73437 .2945 L .7302 .29948 L p F P
0 g
s
.347 .275 .633 r
.732 .30375 m .73692 .29792 L p .7302 .29948 L F P
0 g
s
.347 .275 .633 r
.7302 .29948 m .73066 .3018 L .732 .30375 L p F P
0 g
s
.328 .75 .975 r
.3629 .46624 m .36258 .4661 L .36198 .46612 L closepath p F P
0 g
s
.61 .138 .107 r
.37813 .36376 m .38602 .36453 L .38127 .362 L p F P
0 g
s
.61 .138 .107 r
.38127 .362 m .38044 .36191 L .37813 .36376 L p F P
0 g
s
.69 .154 0 r
.14525 .38523 m .14684 .38695 L .15093 .38978 L p F P
0 g
s
.624 .075 0 r
.14999 .38995 m .15407 .39279 L .15093 .38978 L p F P
0 g
s
.624 .075 0 r
.15093 .38978 m .14684 .38695 L .14999 .38995 L p F P
0 g
s
0 0 0 r
.65981 .39939 m .65358 .40366 L .65885 .40018 L closepath p F P
0 g
s
0 0 0 r
.65758 .401 m .65885 .40018 L .65358 .40366 L p F P
0 g
s
0 0 0 r
.65222 .40455 m .65758 .401 L p .65358 .40366 L F P
0 g
s
0 0 0 r
.6483 .40712 m .65222 .40455 L p .65358 .40366 L F P
0 g
s
.848 .386 .062 r
.12748 .3682 m .12767 .36854 L .1262 .36739 L closepath p F P
0 g
s
.62 .15 .116 r
.37679 .36361 m .37813 .36376 L .38044 .36191 L p F P
0 g
s
.62 .15 .116 r
.38044 .36191 m .37223 .36102 L .37679 .36361 L p F P
0 g
s
.659 .13 0 r
.32344 .34887 m .32997 .35079 L .32612 .34799 L p F P
0 g
s
.659 .13 0 r
.3222 .34789 m .32344 .34887 L p .32612 .34799 L F P
0 g
s
.659 .13 0 r
.32612 .34799 m .32453 .34751 L .3222 .34789 L p F P
0 g
s
.342 .751 .981 r
.35965 .46479 m .3535 .46499 L .36198 .46612 L p F P
0 g
s
.342 .751 .981 r
.36198 .46612 m .36258 .4661 L .35965 .46479 L p F P
0 g
s
.46 0 .07 r
.45385 .36266 m .45561 .36036 L .4441 .36182 L p F P
0 g
s
.46 0 .07 r
.44846 .3633 m .45385 .36266 L p .4441 .36182 L F P
0 g
s
.46 0 .07 r
.4441 .36182 m .44325 .36279 L .44846 .3633 L p F P
0 g
s
0 0 .062 r
.70779 .35633 m .70288 .36067 L .70725 .35482 L p F P
0 g
s
0 0 .062 r
.70725 .35482 m .70866 .35357 L .70779 .35633 L p F P
0 g
s
.445 0 0 r
.27642 .32634 m .27343 .32457 L .2787 .32698 L p F P
0 g
s
.445 0 0 r
.2787 .32698 m .27955 .32745 L .27642 .32634 L p F P
0 g
s
.274 .704 .966 r
.31721 .45845 m .31927 .45943 L .31126 .45899 L p F P
0 g
s
.274 .704 .966 r
.31502 .45792 m .31721 .45845 L p .31126 .45899 L F P
0 g
s
.274 .704 .966 r
.30686 .45748 m .31502 .45792 L p .31126 .45899 L F P
0 g
s
.274 .704 .966 r
.31126 .45899 m .30887 .45844 L .30686 .45748 L p F P
0 g
s
0 .245 .643 r
.19017 .41609 m .18753 .41465 L .19211 .41724 L p F P
0 g
s
0 .245 .643 r
.19211 .41724 m .1934 .41794 L .19017 .41609 L p F P
0 g
s
0 .513 .858 r
.24524 .4405 m .23916 .43886 L .23601 .43721 L p F P
0 g
s
.407 .835 .68 r
.55806 .31989 m .55791 .31996 L .55917 .31925 L closepath p F P
0 g
s
.781 .281 0 r
.12607 .36886 m .12986 .37185 L .12767 .36854 L p F P
0 g
s
.781 .281 0 r
.12417 .36599 m .12607 .36886 L p .12767 .36854 L F P
0 g
s
.781 .281 0 r
.12767 .36854 m .1262 .36739 L .12417 .36599 L p F P
0 g
s
0 .232 .653 r
.24922 .31108 m .25036 .31175 L .24641 .30926 L closepath p F P
0 g
s
.673 .138 0 r
.31324 .3441 m .31001 .34168 L .30689 .34161 L p F P
0 g
s
.38 .769 .989 r
.37215 .46556 m .36258 .4661 L .35965 .46479 L p F P
0 g
s
.034 .477 .881 r
.22783 .29784 m .22313 .29606 L .22725 .29896 L p F P
0 g
s
.034 .477 .881 r
.22725 .29896 m .23095 .3003 L .22783 .29784 L p F P
0 g
s
.475 .851 .986 r
.47211 .4647 m .46444 .46574 L .46277 .46521 L p F P
0 g
s
.101 .587 .907 r
.26326 .44625 m .26364 .44644 L .25641 .44487 L p F P
0 g
s
.101 .587 .907 r
.2583 .44434 m .26326 .44625 L p .25641 .44487 L F P
0 g
s
.101 .587 .907 r
.25137 .4429 m .2583 .44434 L p .25641 .44487 L F P
0 g
s
.101 .587 .907 r
.25641 .44487 m .25223 .44335 L .25137 .4429 L p F P
0 g
s
.49 .882 .961 r
.52283 .4559 m .52362 .45604 L .51319 .45876 L p F P
0 g
s
.49 .882 .961 r
.51319 .45876 m .51293 .45871 L .52283 .4559 L p F P
0 g
s
.633 .095 0 r
.32453 .34751 m .3222 .34789 L .31953 .3461 L closepath p F P
0 g
s
.648 .152 .058 r
.35292 .35658 m .35574 .35847 L .351 .35753 L closepath p F P
0 g
s
.491 .9 .909 r
.56783 .44319 m .57034 .44325 L .56037 .44694 L p F P
0 g
s
.491 .9 .909 r
.55855 .44664 m .56783 .44319 L p .56037 .44694 L F P
0 g
s
.491 .9 .909 r
.56037 .44694 m .55786 .4469 L .55855 .44664 L p F P
0 g
s
.661 .693 .869 r
.69224 .26142 m .70244 .25803 L .70484 .26187 L p F P
0 g
s
.675 .715 .879 r
.70244 .25803 m .69224 .26142 L .68986 .2582 L p F P
0 g
s
.692 .744 .891 r
.67973 .26239 m .68986 .2582 L .69224 .26142 L p F P
0 g
s
.37 .283 .626 r
.73066 .3018 m .732 .30375 L .73119 .30469 L closepath p F P
0 g
s
.687 .151 0 r
.14684 .38695 m .14525 .38523 L .14196 .38316 L p F P
0 g
s
0 0 0 r
.55917 .31925 m .55791 .31996 L .55582 .32121 L p F P
0 g
s
.653 .142 .015 r
.34077 .35536 m .34812 .35697 L .34402 .35424 L p F P
0 g
s
.653 .142 .015 r
.33754 .35291 m .34077 .35536 L p .34402 .35424 L F P
0 g
s
.653 .142 .015 r
.34402 .35424 m .33798 .35276 L .33754 .35291 L p F P
0 g
s
.508 .675 .939 r
.15796 .26586 m .16643 .26544 L .16975 .26871 L p F P
0 g
s
.509 .672 .937 r
.16643 .26544 m .15796 .26586 L .1548 .26253 L p F P
0 g
s
.704 .764 .898 r
.68986 .2582 m .67973 .26239 L .67735 .2597 L p F P
0 g
s
.453 0 0 r
.26437 .3194 m .2644 .31942 L .26431 .31937 L closepath p F P
0 g
s
.22 .673 .95 r
.30887 .45844 m .30686 .45748 L .3044 .45728 L closepath p F P
0 g
s
.49 0 0 r
.26358 .31947 m .2684 .32206 L .2644 .31942 L p F P
0 g
s
.49 0 0 r
.26125 .31784 m .26358 .31947 L p .2644 .31942 L F P
0 g
s
.49 0 0 r
.2644 .31942 m .26431 .31937 L .26125 .31784 L p F P
0 g
s
0 0 0 r
.53342 .33355 m .5354 .3318 L .53177 .33332 L p F P
0 g
s
0 0 0 r
.52392 .33759 m .53342 .33355 L p .53177 .33332 L F P
0 g
s
0 0 0 r
.53554 .33167 m .53177 .33332 L .5354 .3318 L closepath p F P
0 g
s
0 0 0 r
.66567 .39519 m .65981 .39939 L .65885 .40018 L p F P
0 g
s
.523 .532 .806 r
.73053 .26971 m .7217 .26936 L .72065 .27076 L p F P
0 g
s
.523 .532 .806 r
.73114 .2713 m .73053 .26971 L p .72065 .27076 L F P
0 g
s
.523 .532 .806 r
.72761 .27571 m .73114 .2713 L p .72065 .27076 L F P
0 g
s
.561 .565 .815 r
.72004 .2694 m .7217 .26936 L .72065 .27076 L closepath p F P
0 g
s
.074 0 .241 r
.71748 .34292 m .71691 .3435 L .7174 .34027 L p F P
0 g
s
.074 0 .241 r
.7174 .34027 m .71995 .33772 L .71748 .34292 L p F P
0 g
s
.313 0 0 r
.48834 .35372 m .4901 .35154 L .47952 .35416 L p F P
0 g
s
.313 0 0 r
.48425 .35471 m .48834 .35372 L p .47952 .35416 L F P
0 g
s
.313 0 0 r
.47952 .35416 m .47818 .35572 L .48425 .35471 L p F P
0 g
s
.346 0 0 r
.26431 .31937 m .26125 .31784 L .25943 .31688 L closepath p F P
0 g
s
.456 0 0 r
.17829 .40921 m .17859 .40941 L .17749 .40876 L closepath p F P
0 g
s
.626 .142 .084 r
.36804 .36252 m .37679 .36361 L .37223 .36102 L p F P
0 g
s
.626 .142 .084 r
.36527 .3607 m .36804 .36252 L p .37223 .36102 L F P
0 g
s
.626 .142 .084 r
.37223 .36102 m .36611 .36015 L .36527 .3607 L p F P
0 g
s
.429 .369 .689 r
.73713 .2912 m .73437 .2945 L .73067 .29149 L p F P
0 g
s
.429 .369 .689 r
.73585 .28588 m .73713 .2912 L p .73067 .29149 L F P
0 g
s
.429 .369 .689 r
.73067 .29149 m .73553 .28565 L .73585 .28588 L p F P
0 g
s
.649 .094 0 r
.29755 .33703 m .29476 .33496 L .29164 .33435 L p F P
0 g
s
.501 .883 .968 r
.52283 .4559 m .51293 .45871 L .51029 .45814 L p F P
0 g
s
.293 .717 .971 r
.32962 .46104 m .32228 .46081 L .31927 .45943 L p F P
0 g
s
.378 .813 .655 r
.56784 .31442 m .55917 .31925 L .56689 .3149 L closepath p F P
0 g
s
0 0 0 r
.56535 .31569 m .56689 .3149 L .55917 .31925 L p F P
0 g
s
0 0 0 r
.5589 .31943 m .56535 .31569 L p .55917 .31925 L F P
0 g
s
0 0 0 r
.55582 .32121 m .5589 .31943 L p .55917 .31925 L F P
0 g
s
.417 0 .06 r
.45582 .36011 m .45724 .36009 L .45561 .36036 L closepath p F P
0 g
s
.601 .03 0 r
.28266 .32967 m .27955 .32745 L .27642 .32634 L p F P
0 g
s
.757 .246 0 r
.13231 .37508 m .13615 .37803 L .13371 .37479 L p F P
0 g
s
.757 .246 0 r
.13371 .37479 m .12986 .37185 L .13231 .37508 L p F P
0 g
s
.745 .902 .948 r
.65361 .26844 m .64483 .27333 L .64245 .2719 L p F P
0 g
s
.569 .012 0 r
.15677 .39512 m .15407 .39279 L .15821 .39559 L p F P
0 g
s
.569 .012 0 r
.15821 .39559 m .16005 .39716 L .15677 .39512 L p F P
0 g
s
.936 .601 .373 r
.10428 .33879 m .10408 .3373 L .10075 .33487 L p F P
0 g
s
.616 .957 .848 r
.59892 .29654 m .59018 .30192 L .58889 .30215 L p F P
0 g
s
0 .445 .807 r
.22795 .434 m .22386 .43262 L .22068 .43093 L p F P
0 g
s
0 .44 .799 r
.22386 .43262 m .22795 .434 L .23316 .43633 L p F P
0 g
s
0 .241 .649 r
.17854 .40936 m .183 .41202 L .17859 .40941 L p F P
0 g
s
0 .241 .649 r
.17504 .40729 m .17854 .40936 L p .17859 .40941 L F P
0 g
s
0 .241 .649 r
.17859 .40941 m .17749 .40876 L .17504 .40729 L p F P
0 g
s
.591 .128 .123 r
.39315 .36386 m .396 .36518 L .39197 .36496 L closepath p F P
0 g
s
.361 .759 .985 r
.35671 .46343 m .35965 .46479 L .3535 .46499 L p F P
0 g
s
.361 .759 .985 r
.34717 .46378 m .35671 .46343 L p .3535 .46499 L F P
0 g
s
.361 .759 .985 r
.3535 .46499 m .34833 .46431 L .34717 .46378 L p F P
0 g
s
.403 .783 .992 r
.38467 .4661 m .37507 .46683 L .37215 .46556 L p F P
0 g
s
0 0 0 r
.5554 .32147 m .55582 .32121 L .5468 .32593 L p F P
0 g
s
0 0 0 r
.5468 .32593 m .54547 .32683 L .5554 .32147 L p F P
0 g
s
0 0 0 r
.68994 .37459 m .68954 .37521 L .69154 .37327 L closepath p F P
0 g
s
.575 .585 .826 r
.7217 .26936 m .72004 .2694 L .71757 .26427 L p F P
0 g
s
0 0 0 r
.70714 .35788 m .70779 .35633 L .70288 .36067 L p F P
0 g
s
0 0 0 r
.70521 .36023 m .70714 .35788 L p .70288 .36067 L F P
0 g
s
0 0 0 r
.69903 .3657 m .70521 .36023 L p .70288 .36067 L F P
0 g
s
0 0 0 r
.70288 .36067 m .69934 .36493 L .69903 .3657 L p F P
0 g
s
.195 .557 .934 r
.21268 .28895 m .2097 .28813 L .21363 .29112 L p F P
0 g
s
.195 .557 .934 r
.21363 .29112 m .21581 .29169 L .21268 .28895 L p F P
0 g
s
.64 .661 .855 r
.71169 .26029 m .70484 .26187 L .70244 .25803 L p F P
0 g
s
.137 0 .321 r
.72479 .33285 m .71995 .33772 L .72173 .33277 L p F P
0 g
s
.137 0 .321 r
.72173 .33277 m .72509 .32938 L .72479 .33285 L p F P
0 g
s
0 0 .048 r
.71006 .3542 m .70779 .35633 L .70866 .35357 L p F P
0 g
s
0 0 .048 r
.70866 .35357 m .71413 .34844 L .71006 .3542 L p F P
0 g
s
.447 .866 .727 r
.63627 .41432 m .62759 .41915 L .62616 .41971 L p F P
0 g
s
.491 .903 .831 r
.60552 .42998 m .60523 .43003 L .60821 .42861 L closepath p F P
0 g
s
.816 .333 0 r
.1262 .36739 m .12417 .36599 L .1239 .36555 L closepath p F P
0 g
s
0 0 0 r
.66975 .39211 m .66567 .39519 L .66908 .3928 L closepath p F P
0 g
s
0 0 0 r
.66756 .39402 m .66908 .3928 L .66567 .39519 L p F P
0 g
s
0 0 0 r
.66512 .39579 m .66756 .39402 L p .66567 .39519 L F P
0 g
s
0 0 0 r
.65885 .40018 m .66512 .39579 L p .66567 .39519 L F P
0 g
s
0 .194 .613 r
.2501 .31155 m .25467 .31425 L .25036 .31175 L p F P
0 g
s
0 .194 .613 r
.24609 .30906 m .2501 .31155 L p .25036 .31175 L F P
0 g
s
0 .194 .613 r
.25036 .31175 m .24641 .30926 L .24609 .30906 L p F P
0 g
s
.179 0 0 r
.51051 .34511 m .51226 .34318 L .50223 .34651 L p F P
0 g
s
.179 0 0 r
.50223 .34651 m .50061 .34828 L .51051 .34511 L p F P
0 g
s
.176 .003 .393 r
.72762 .32667 m .72509 .32938 L .72518 .32564 L p F P
0 g
s
.176 .003 .393 r
.72518 .32564 m .72857 .322 L .72762 .32667 L p F P
0 g
s
0 .289 .683 r
.19697 .41971 m .1934 .41794 L .19017 .41609 L p F P
0 g
s
.465 .852 .981 r
.47581 .46417 m .47532 .46403 L .47211 .4647 L closepath p F P
0 g
s
.475 .851 .986 r
.47259 .46314 m .47532 .46403 L .47211 .4647 L p F P
0 g
s
.475 .851 .986 r
.46277 .46521 m .47259 .46314 L p .47211 .4647 L F P
0 g
s
.747 .946 .945 r
.62251 .28391 m .62247 .28389 L .62266 .28378 L closepath p F P
0 g
s
.429 0 .083 r
.45724 .36009 m .45561 .36036 L .45385 .36266 L p F P
0 g
s
0 .364 .739 r
.2086 .42569 m .21191 .42706 L .21688 .42949 L p F P
0 g
s
0 .369 .748 r
.21191 .42706 m .2086 .42569 L .20539 .42393 L p F P
0 g
s
.1 .592 .904 r
.26999 .44853 m .26675 .44794 L .26364 .44644 L p F P
0 g
s
.09 .587 .898 r
.26675 .44794 m .26999 .44853 L .27602 .45054 L p F P
0 g
s
.325 .221 .579 r
.73348 .30755 m .73185 .30944 L .73119 .30469 L p F P
0 g
s
.325 .221 .579 r
.73119 .30469 m .732 .30375 L .73348 .30755 L p F P
0 g
s
.734 .96 .942 r
.62266 .28378 m .62247 .28389 L .62006 .28327 L p F P
0 g
s
.75 .941 .946 r
.63245 .27789 m .62266 .28378 L .63007 .27694 L closepath p F P
0 g
s
.734 .96 .942 r
.63005 .27693 m .63007 .27694 L .62266 .28378 L p F P
0 g
s
.734 .96 .942 r
.62006 .28327 m .63005 .27693 L p .62266 .28378 L F P
0 g
s
.264 0 0 r
.50039 .34855 m .50061 .34828 L .49074 .35076 L p F P
0 g
s
.264 0 0 r
.49074 .35076 m .4901 .35154 L .50039 .34855 L p F P
0 g
s
.721 .833 .934 r
.6756 .26054 m .66727 .26456 L .6649 .26238 L p F P
0 g
s
.74 .837 .924 r
.65485 .26775 m .6649 .26238 L .66727 .26456 L p F P
0 g
s
.494 .905 .875 r
.59034 .43511 m .5928 .43494 L .58281 .43916 L p F P
0 g
s
.494 .905 .875 r
.58575 .43706 m .59034 .43511 L p .58281 .43916 L F P
0 g
s
.494 .905 .875 r
.58281 .43916 m .58068 .43932 L .58575 .43706 L p F P
0 g
s
.486 .875 .969 r
.50851 .45773 m .51029 .45814 L .5004 .46074 L p F P
0 g
s
.486 .875 .969 r
.5004 .46074 m .49784 .46017 L .50851 .45773 L p F P
0 g
s
.451 .861 .959 r
.49784 .46017 m .5004 .46074 L p .48786 .46253 L F P
0 g
s
.189 .657 .937 r
.29448 .45518 m .29772 .4555 L .3044 .45728 L p F P
0 g
s
.19 .657 .938 r
.29448 .45518 m .29772 .4555 L .29173 .4539 L closepath p F P
0 g
s
.629 .146 .086 r
.36611 .36015 m .36527 .3607 L .3638 .35981 L closepath p F P
0 g
s
.135 .612 .92 r
.27597 .44947 m .26999 .44853 L .27602 .45054 L p F P
0 g
s
.135 .612 .92 r
.27602 .45054 m .27906 .45103 L .27597 .44947 L p F P
0 g
s
.609 .047 0 r
.30134 .33982 m .29755 .33703 L .30332 .33924 L p F P
0 g
s
.609 .047 0 r
.30639 .3416 m .30134 .33982 L p .30332 .33924 L F P
0 g
s
.609 .047 0 r
.30332 .33924 m .30689 .34161 L .30639 .3416 L p F P
0 g
s
.425 0 .068 r
.46684 .35856 m .4656 .36013 L .45724 .36009 L closepath p F P
0 g
s
.429 0 .083 r
.4651 .36084 m .4656 .36013 L .45724 .36009 L p F P
0 g
s
.429 0 .083 r
.45385 .36266 m .4651 .36084 L p .45724 .36009 L F P
0 g
s
.71 .183 0 r
.13866 .38099 m .13615 .37803 L .14006 .38095 L p F P
0 g
s
.71 .183 0 r
.14006 .38095 m .14196 .38316 L .13866 .38099 L p F P
0 g
s
.403 0 0 r
.17749 .40876 m .17504 .40729 L .17418 .40674 L closepath p F P
0 g
s
0 0 0 r
.69934 .36493 m .69772 .3668 L .69903 .3657 L closepath p F P
0 g
s
0 0 0 r
.67574 .3874 m .66975 .39211 L .66908 .3928 L p F P
0 g
s
.633 .094 0 r
.31702 .34691 m .31324 .3441 L .31953 .3461 L p F P
0 g
s
.633 .094 0 r
.32097 .34808 m .31702 .34691 L p .31953 .3461 L F P
0 g
s
.633 .094 0 r
.31953 .3461 m .3222 .34789 L .32097 .34808 L p F P
0 g
s
0 0 0 r
.54469 .32746 m .54547 .32683 L .53554 .33167 L p F P
0 g
s
0 0 0 r
.53554 .33167 m .5354 .3318 L .54469 .32746 L p F P
0 g
s
.322 .739 .977 r
.34833 .46431 m .34717 .46378 L .3452 .46379 L closepath p F P
0 g
s
.395 .791 .987 r
.38756 .46731 m .39721 .4664 L .40008 .46756 L p F P
0 g
s
.422 .795 .994 r
.39721 .4664 m .38756 .46731 L .38467 .4661 L p F P
0 g
s
.505 .901 .935 r
.55784 .4469 m .55786 .4469 L .548 .45036 L p F P
0 g
s
.505 .901 .935 r
.548 .45036 m .54788 .45035 L .55784 .4469 L p F P
0 g
s
0 .405 .778 r
.21749 .42918 m .21191 .42706 L .21688 .42949 L p F P
0 g
s
0 .405 .778 r
.21688 .42949 m .22068 .43093 L .21749 .42918 L p F P
0 g
s
.229 .675 .954 r
.30382 .45599 m .29772 .4555 L .3044 .45728 L p F P
0 g
s
.229 .675 .954 r
.3044 .45728 m .30686 .45748 L .30382 .45599 L p F P
0 g
s
.028 .536 .871 r
.25223 .44335 m .25137 .4429 L .2507 .44274 L closepath p F P
0 g
s
.558 0 0 r
.28655 .33239 m .28266 .32967 L .28801 .33204 L p F P
0 g
s
.558 0 0 r
.291 .33421 m .28655 .33239 L p .28801 .33204 L F P
0 g
s
.558 0 0 r
.28801 .33204 m .29164 .33435 L .291 .33421 L p F P
0 g
s
.487 .861 .983 r
.48516 .46176 m .48692 .46229 L .47581 .46417 L p F P
0 g
s
.487 .861 .983 r
.47581 .46417 m .47532 .46403 L .48516 .46176 L p F P
0 g
s
0 0 0 r
.69781 .36804 m .69154 .37327 L .69772 .3668 L p F P
0 g
s
0 0 0 r
.69772 .3668 m .69903 .3657 L .69781 .36804 L p F P
0 g
s
0 .477 .833 r
.23285 .43551 m .22795 .434 L .23316 .43633 L p F P
0 g
s
0 .477 .833 r
.23316 .43633 m .23601 .43721 L .23285 .43551 L p F P
0 g
s
.329 .613 .952 r
.19751 .28047 m .19615 .28024 L .19988 .28332 L p F P
0 g
s
.329 .613 .952 r
.19988 .28332 m .20064 .28344 L .19751 .28047 L p F P
0 g
s
.629 .151 .099 r
.3598 .36124 m .35574 .35847 L .3638 .35981 L p F P
0 g
s
.629 .151 .099 r
.36363 .36184 m .3598 .36124 L p .3638 .35981 L F P
0 g
s
.629 .151 .099 r
.3638 .35981 m .36527 .3607 L .36363 .36184 L p F P
0 g
s
.499 .907 .838 r
.60821 .42861 m .60523 .43003 L .60281 .43044 L p F P
0 g
s
.51 .91 .909 r
.58033 .43932 m .58068 .43932 L .57117 .44326 L p F P
0 g
s
.51 .91 .909 r
.57117 .44326 m .57034 .44325 L .58033 .43932 L p F P
0 g
s
.575 .585 .826 r
.71757 .26427 m .72604 .26365 L .7217 .26936 L p F P
0 g
s
.545 .537 .797 r
.728 .2636 m .72604 .26365 L .7217 .26936 L p F P
0 g
s
.545 .537 .797 r
.7217 .26936 m .73053 .26971 L .728 .2636 L p F P
0 g
s
.461 .416 .721 r
.73573 .28541 m .73553 .28565 L .73022 .28322 L p F P
0 g
s
.461 .416 .721 r
.73022 .28322 m .73379 .27886 L .73573 .28541 L p F P
0 g
s
.495 .894 .942 r
.53537 .45327 m .54531 .45005 L .54788 .45035 L p F P
0 g
s
.519 .904 .945 r
.55784 .4469 m .54788 .45035 L .54531 .45005 L p F P
0 g
s
.639 .122 0 r
.33798 .35276 m .33754 .35291 L .33696 .35253 L closepath p F P
0 g
s
.471 .025 .107 r
.44325 .36279 m .44846 .3633 L .44227 .36405 L closepath p F P
0 g
s
.936 .601 .373 r
.10075 .33487 m .10085 .33562 L .10428 .33879 L p F P
0 g
s
.927 .556 .288 r
.10172 .33937 m .10515 .34255 L .10428 .33879 L p F P
0 g
s
.927 .556 .288 r
.10428 .33879 m .10085 .33562 L .10172 .33937 L p F P
0 g
s
0 .328 .717 r
.20214 .42209 m .19697 .41971 L .20172 .42225 L p F P
0 g
s
0 .328 .717 r
.20229 .42218 m .20214 .42209 L p .20172 .42225 L F P
0 g
s
0 .328 .717 r
.20172 .42225 m .20539 .42393 L .20229 .42218 L p F P
0 g
s
0 0 0 r
.54293 .32892 m .54469 .32746 L .5354 .3318 L p F P
0 g
s
0 0 0 r
.5393 .33074 m .54293 .32892 L p .5354 .3318 L F P
0 g
s
0 0 0 r
.5354 .3318 m .53342 .33355 L .5393 .33074 L p F P
0 g
s
0 .318 .751 r
.23095 .3003 m .23246 .30108 L .23664 .30395 L p F P
0 g
s
0 .326 .759 r
.23705 .30345 m .24141 .30626 L .23664 .30395 L p F P
0 g
s
0 .326 .759 r
.23664 .30395 m .23246 .30108 L .23705 .30345 L p F P
0 g
s
.91 .509 .215 r
.10633 .34619 m .10983 .34933 L .10865 .34568 L p F P
0 g
s
.91 .509 .215 r
.10865 .34568 m .10515 .34255 L .10633 .34619 L p F P
0 g
s
0 0 0 r
.67967 .38412 m .67574 .3874 L .67897 .38499 L closepath p F P
0 g
s
0 0 0 r
.67753 .38643 m .67897 .38499 L .67574 .3874 L p F P
0 g
s
0 0 0 r
.67586 .38776 m .67753 .38643 L p .67574 .3874 L F P
0 g
s
0 0 0 r
.66908 .3928 m .67586 .38776 L p .67574 .3874 L F P
0 g
s
.3 .729 .97 r
.33471 .46245 m .33729 .46246 L .3452 .46379 L p F P
0 g
s
.301 .729 .971 r
.33471 .46245 m .33729 .46246 L .33314 .46176 L closepath p F P
0 g
s
.566 .11 .129 r
.40563 .36507 m .40682 .36552 L .40522 .36551 L closepath p F P
0 g
s
.94 .61 .378 r
.09744 .33211 m .09704 .32851 L .10039 .33172 L p F P
0 g
s
.94 .61 .378 r
.10039 .33172 m .10075 .33487 L .09744 .33211 L p F P
0 g
s
.451 .861 .959 r
.48786 .46253 m .49659 .46042 L .49784 .46017 L p F P
0 g
s
.476 .865 .974 r
.48786 .46253 m .49659 .46042 L .48692 .46229 L closepath p F P
0 g
s
.538 0 0 r
.16005 .39716 m .16172 .39849 L .16599 .40123 L p F P
0 g
s
.46 0 0 r
.16561 .40126 m .16986 .40401 L .16599 .40123 L p F P
0 g
s
.46 0 0 r
.16599 .40123 m .16172 .39849 L .16561 .40126 L p F P
0 g
s
.121 0 0 r
.52204 .3395 m .52305 .3384 L .51315 .34222 L p F P
0 g
s
.121 0 0 r
.51315 .34222 m .51226 .34318 L .52204 .3395 L p F P
0 g
s
.639 .124 .003 r
.33386 .35358 m .32997 .35079 L .33696 .35253 L p F P
0 g
s
.639 .124 .003 r
.33489 .35383 m .33386 .35358 L p .33696 .35253 L F P
0 g
s
.639 .124 .003 r
.33696 .35253 m .33754 .35291 L .33489 .35383 L p F P
0 g
s
.334 .739 .981 r
.3442 .46236 m .33729 .46246 L .3452 .46379 L p F P
0 g
s
.334 .739 .981 r
.3452 .46379 m .34717 .46378 L .3442 .46236 L p F P
0 g
s
.413 .802 .988 r
.41006 .46657 m .4126 .46757 L p .40008 .46756 L F P
0 g
s
.413 .802 .988 r
.40008 .46756 m .40885 .46655 L .41006 .46657 L p F P
0 g
s
.437 .806 .994 r
.40885 .46655 m .40008 .46756 L .39721 .4664 L p F P
0 g
s
.324 .222 .582 r
.73846 .30171 m .73348 .30755 L .732 .30375 L p F P
0 g
s
.324 .222 .582 r
.732 .30375 m .73692 .29792 L .73846 .30171 L p F P
0 g
s
0 0 0 r
.68425 .38013 m .67967 .38412 L .67897 .38499 L p F P
0 g
s
.887 .458 .141 r
.11129 .35288 m .11485 .35598 L .11339 .35243 L p F P
0 g
s
.887 .458 .141 r
.11339 .35243 m .10983 .34933 L .11129 .35288 L p F P
0 g
s
0 0 0 r
.69735 .36872 m .69781 .36804 L .69154 .37327 L p F P
0 g
s
0 0 0 r
.69272 .37325 m .69735 .36872 L p .69154 .37327 L F P
0 g
s
0 0 0 r
.68855 .37674 m .69272 .37325 L p .69154 .37327 L F P
0 g
s
0 0 0 r
.69154 .37327 m .68954 .37521 L .68855 .37674 L p F P
0 g
s
.466 0 0 r
.27252 .32468 m .2684 .32206 L .27343 .32457 L p F P
0 g
s
.466 0 0 r
.27446 .3256 m .27252 .32468 L p .27343 .32457 L F P
0 g
s
.466 0 0 r
.27343 .32457 m .27642 .32634 L .27446 .3256 L p F P
0 g
s
.236 .085 .463 r
.73238 .31787 m .72857 .322 L .72876 .3176 L p F P
0 g
s
.236 .085 .463 r
.72876 .3176 m .73224 .31382 L .73238 .31787 L p F P
0 g
s
.303 .584 .941 r
.18544 .27572 m .18554 .27574 L .18423 .2745 L closepath p F P
0 g
s
0 0 0 r
.68954 .37521 m .68425 .38013 L .68855 .37674 L closepath p F P
0 g
s
.73 .974 .927 r
.61112 .28972 m .61009 .28957 L .61469 .28666 L closepath p F P
0 g
s
.945 .645 .44 r
.09374 .32526 m .09704 .32851 L .09693 .32449 L p F P
0 g
s
.945 .645 .44 r
.09693 .32449 m .09364 .32123 L .09374 .32526 L p F P
0 g
s
.153 .523 .918 r
.20064 .28344 m .2059 .28508 L .2097 .28813 L p F P
0 g
s
.153 .517 .916 r
.2059 .28508 m .20064 .28344 L .19751 .28047 L p F P
0 g
s
0 0 0 r
.68746 .37806 m .68855 .37674 L .68425 .38013 L p F P
0 g
s
0 0 0 r
.68494 .38029 m .68746 .37806 L p .68425 .38013 L F P
0 g
s
0 0 0 r
.67897 .38499 m .68494 .38029 L p .68425 .38013 L F P
0 g
s
.04 .54 .879 r
.24824 .44123 m .24524 .4405 L .2507 .44274 L p F P
0 g
s
.04 .54 .879 r
.2507 .44274 m .25137 .4429 L .24824 .44123 L p F P
0 g
s
.278 .571 .937 r
.18902 .27391 m .19253 .2771 L .18554 .27574 L p F P
0 g
s
.278 .571 .937 r
.18229 .27256 m .18902 .27391 L p .18554 .27574 L F P
0 g
s
.278 .571 .937 r
.18554 .27574 m .18423 .2745 L .18229 .27256 L p F P
0 g
s
.506 .481 .764 r
.72761 .27571 m .73114 .2713 L .73312 .27686 L closepath p F P
0 g
s
.517 .678 .938 r
.16701 .2654 m .16643 .26544 L .16975 .26871 L p F P
0 g
s
.517 .678 .938 r
.16975 .26871 m .17016 .26869 L .16701 .2654 L p F P
0 g
s
.657 .971 .886 r
.60013 .2958 m .59892 .29654 L .59991 .29581 L closepath p F P
0 g
s
.616 .957 .848 r
.5977 .29597 m .59991 .29581 L .59892 .29654 L p F P
0 g
s
.616 .957 .848 r
.59397 .29835 m .5977 .29597 L p .59892 .29654 L F P
0 g
s
.616 .957 .848 r
.58889 .30215 m .59397 .29835 L p .59892 .29654 L F P
0 g
s
.687 .151 0 r
.14196 .38316 m .14281 .38409 L .14684 .38695 L p F P
0 g
s
.609 .061 0 r
.14598 .38708 m .14999 .38995 L .14684 .38695 L p F P
0 g
s
.609 .061 0 r
.14684 .38695 m .14281 .38409 L .14598 .38708 L p F P
0 g
s
.858 .404 .065 r
.11659 .35945 m .12022 .36252 L .11848 .35905 L p F P
0 g
s
.858 .404 .065 r
.11848 .35905 m .11485 .35598 L .11659 .35945 L p F P
0 g
s
.455 .88 .785 r
.61523 .42515 m .60821 .42861 L .61453 .42533 L closepath p F P
0 g
s
.499 .907 .838 r
.61283 .4256 m .61453 .42533 L .60821 .42861 L p F P
0 g
s
.499 .907 .838 r
.60281 .43044 m .61283 .4256 L p .60821 .42861 L F P
0 g
s
.442 .851 .677 r
.57543 .30947 m .57778 .30851 L .56784 .31442 L p F P
0 g
s
.442 .851 .677 r
.56784 .31442 m .56689 .3149 L .57543 .30947 L p F P
0 g
s
.499 .861 .988 r
.48516 .46176 m .47532 .46403 L .47259 .46314 L p F P
0 g
s
.507 .059 .121 r
.4307 .36454 m .4323 .36485 L .43032 .365 L closepath p F P
0 g
s
0 .248 .651 r
.18695 .41419 m .183 .41202 L .18753 .41465 L p F P
0 g
s
0 .248 .651 r
.18753 .41465 m .19017 .41609 L .18695 .41419 L p F P
0 g
s
.426 .813 .989 r
.4227 .46642 m .42513 .46734 L p .4126 .46757 L F P
0 g
s
.426 .813 .989 r
.4126 .46757 m .42098 .46645 L .4227 .46642 L p F P
0 g
s
.433 .813 .991 r
.4126 .46757 m .42098 .46645 L .41006 .46657 L closepath p F P
0 g
s
.538 .087 .128 r
.41815 .3653 m .41876 .36547 L .41798 .3655 L closepath p F P
0 g
s
.685 .979 .885 r
.60784 .28944 m .61009 .28957 L .60013 .2958 L p F P
0 g
s
.685 .979 .885 r
.60013 .2958 m .59991 .29581 L .60784 .28944 L p F P
0 g
s
.418 .64 .948 r
.17016 .26869 m .17863 .26931 L .18205 .27254 L p F P
0 g
s
.419 .636 .945 r
.17863 .26931 m .17016 .26869 L .16701 .2654 L p F P
0 g
s
.748 .879 .94 r
.65485 .26775 m .65361 .26844 L .6545 .2675 L closepath p F P
0 g
s
.745 .902 .948 r
.65247 .26606 m .6545 .2675 L .65361 .26844 L p F P
0 g
s
.745 .902 .948 r
.64245 .2719 m .65247 .26606 L p .65361 .26844 L F P
0 g
s
.671 .168 .04 r
.33754 .35291 m .34077 .35536 L .33489 .35383 L closepath p F P
0 g
s
0 .43 .855 r
.21581 .29169 m .21914 .2931 L .22313 .29606 L p F P
0 g
s
0 .422 .852 r
.21914 .2931 m .21581 .29169 L .21268 .28895 L p F P
0 g
s
.094 .577 .905 r
.2583 .44434 m .25137 .4429 L .24824 .44123 L p F P
0 g
s
0 0 0 r
.69946 .36657 m .69781 .36804 L .69903 .3657 L p F P
0 g
s
0 0 0 r
.69903 .3657 m .70521 .36023 L .69946 .36657 L p F P
0 g
s
.482 .852 .988 r
.47259 .46314 m .46277 .46521 L .46002 .46428 L p F P
0 g
s
.438 .823 .988 r
.43503 .4659 m .43767 .46687 L p .42513 .46734 L F P
0 g
s
.438 .823 .988 r
.42513 .46734 m .43427 .46594 L .43503 .4659 L p F P
0 g
s
.447 .823 .991 r
.42513 .46734 m .43427 .46594 L .4227 .46642 L closepath p F P
0 g
s
.026 .465 .876 r
.2244 .2952 m .21914 .2931 L .22313 .29606 L p F P
0 g
s
.026 .465 .876 r
.2256 .29603 m .2244 .2952 L p .22313 .29606 L F P
0 g
s
.026 .465 .876 r
.22313 .29606 m .22783 .29784 L .2256 .29603 L p F P
0 g
s
.394 .822 .655 r
.63759 .41356 m .63627 .41432 L .63742 .41365 L closepath p F P
0 g
s
.447 .866 .727 r
.63526 .41445 m .63742 .41365 L .63627 .41432 L p F P
0 g
s
.447 .866 .727 r
.63237 .41608 m .63526 .41445 L p .63627 .41432 L F P
0 g
s
.447 .866 .727 r
.62616 .41971 m .63237 .41608 L p .63627 .41432 L F P
0 g
s
.53 0 0 r
.16172 .39849 m .16005 .39716 L .15677 .39512 L p F P
0 g
s
0 .242 .626 r
.25811 .31618 m .25467 .31425 L .25943 .31688 L p F P
0 g
s
0 .242 .626 r
.25943 .31688 m .26125 .31784 L .25811 .31618 L p F P
0 g
s
.512 .892 .964 r
.53277 .45287 m .53386 .45308 L .52362 .45604 L p F P
0 g
s
.512 .892 .964 r
.52362 .45604 m .52283 .4559 L .53277 .45287 L p F P
0 g
s
.593 .591 .819 r
.72604 .26365 m .71757 .26427 L .71513 .25955 L p F P
0 g
s
.751 .88 .938 r
.66252 .26037 m .6649 .26238 L .65485 .26775 L p F P
0 g
s
.751 .88 .938 r
.65938 .26214 m .66252 .26037 L p .65485 .26775 L F P
0 g
s
.751 .88 .938 r
.65485 .26775 m .6545 .2675 L .65938 .26214 L p F P
0 g
s
.059 0 .228 r
.72358 .33678 m .71748 .34292 L .71995 .33772 L p F P
0 g
s
.059 0 .228 r
.72448 .33489 m .72358 .33678 L p .71995 .33772 L F P
0 g
s
.059 0 .228 r
.71995 .33772 m .72479 .33285 L .72448 .33489 L p F P
0 g
s
.813 .33 0 r
.12087 .36359 m .12022 .36252 L .1239 .36555 L p F P
0 g
s
.813 .33 0 r
.1239 .36555 m .12417 .36599 L .12087 .36359 L p F P
0 g
s
.477 .843 .991 r
.46002 .46428 m .45022 .46616 L .44745 .46519 L p F P
0 g
s
.452 .833 .988 r
.43767 .46687 m .44745 .46519 L .45022 .46616 L p F P
0 g
s
.576 .138 .17 r
.41798 .3655 m .40682 .36552 L .41244 .36778 L p F P
0 g
s
.575 .127 .149 r
.40325 .36769 m .41244 .36778 L .40682 .36552 L p F P
0 g
s
.575 .127 .149 r
.40682 .36552 m .40522 .36551 L .40325 .36769 L p F P
0 g
s
.461 .833 .991 r
.44703 .46503 m .44745 .46519 L .43767 .46687 L p F P
0 g
s
.461 .833 .991 r
.43767 .46687 m .43503 .4659 L .44703 .46503 L p F P
0 g
s
.388 0 .046 r
.47605 .35864 m .47773 .35632 L .46684 .35856 L p F P
0 g
s
.388 0 .046 r
.47008 .35982 m .47605 .35864 L p .46684 .35856 L F P
0 g
s
.388 0 .046 r
.46684 .35856 m .4656 .36013 L .47008 .35982 L p F P
0 g
s
.597 .152 .165 r
.40109 .36762 m .40325 .36769 L .40522 .36551 L p F P
0 g
s
.597 .152 .165 r
.40522 .36551 m .396 .36518 L .40109 .36762 L p F P
0 g
s
.549 .106 .151 r
.41876 .36547 m .41798 .3655 L .41612 .36778 L p F P
0 g
s
.576 .138 .17 r
.41244 .36778 m .41612 .36778 L .41798 .3655 L p F P
0 g
s
.55 .113 .163 r
.43032 .365 m .41876 .36547 L .42515 .36746 L p F P
0 g
s
.549 .106 .151 r
.41612 .36778 m .42515 .36746 L .41876 .36547 L p F P
0 g
s
.28 0 0 r
.49869 .35078 m .50039 .34855 L .4901 .35154 L p F P
0 g
s
.28 0 0 r
.4901 .35154 m .48834 .35372 L .49869 .35078 L p F P
0 g
s
.657 .169 .081 r
.35199 .3598 m .3598 .36124 L .35574 .35847 L p F P
0 g
s
.657 .169 .081 r
.34984 .35815 m .35199 .3598 L p .35574 .35847 L F P
0 g
s
.657 .169 .081 r
.35574 .35847 m .351 .35753 L .34984 .35815 L p F P
0 g
s
0 0 0 r
.53298 .33395 m .53342 .33355 L .52392 .33759 L p F P
0 g
s
0 0 0 r
.52392 .33759 m .52305 .3384 L .53298 .33395 L p F P
0 g
s
.684 .979 .882 r
.60767 .28943 m .60784 .28944 L .59991 .29581 L p F P
0 g
s
.684 .979 .882 r
.59991 .29581 m .5977 .29597 L .60767 .28943 L p F P
0 g
s
.428 .825 .61 r
.65885 .40018 m .65758 .401 L .66512 .39579 L closepath p F P
0 g
s
.456 .858 .678 r
.6483 .40712 m .64758 .40749 L .65222 .40455 L closepath p F P
0 g
s
.427 .841 .666 r
.64599 .40828 m .64758 .40749 L .63759 .41356 L p F P
0 g
s
.427 .841 .666 r
.63759 .41356 m .63742 .41365 L .64599 .40828 L p F P
0 g
s
.645 .172 .114 r
.36527 .3607 m .36804 .36252 L .36363 .36184 L closepath p F P
0 g
s
.748 .941 .947 r
.64014 .27328 m .63245 .27789 L .63007 .27694 L p F P
0 g
s
.502 .895 .946 r
.54392 .44987 m .54531 .45005 L .53537 .45327 L p F P
0 g
s
.502 .895 .946 r
.53537 .45327 m .53386 .45308 L .54392 .44987 L p F P
0 g
s
.514 .915 .876 r
.59332 .4349 m .5928 .43494 L .59921 .43208 L closepath p F P
0 g
s
.284 .703 .971 r
.31502 .45792 m .30686 .45748 L .30382 .45599 L p F P
0 g
s
.38 .759 .99 r
.35671 .46343 m .34717 .46378 L .3442 .46236 L p F P
0 g
s
0 .307 .75 r
.23246 .30108 m .23095 .3003 L .22783 .29784 L p F P
0 g
s
.597 .14 .138 r
.39075 .36709 m .40109 .36762 L .396 .36518 L p F P
0 g
s
.597 .14 .138 r
.39014 .36675 m .39075 .36709 L p .396 .36518 L F P
0 g
s
.597 .14 .138 r
.396 .36518 m .39197 .36496 L .39014 .36675 L p F P
0 g
s
.27 .147 .522 r
.73411 .31166 m .73224 .31382 L .73185 .30944 L p F P
0 g
s
.27 .147 .522 r
.73185 .30944 m .73348 .30755 L .73411 .31166 L p F P
0 g
s
.522 .914 .917 r
.58033 .43932 m .57034 .44325 L .56783 .44319 L p F P
0 g
s
.796 .304 0 r
.12607 .36886 m .12417 .36599 L .12087 .36359 L p F P
0 g
s
.263 .69 .965 r
.30077 .45445 m .30382 .45599 L .29772 .4555 L p F P
0 g
s
.263 .69 .965 r
.29142 .45374 m .30077 .45445 L p .29772 .4555 L F P
0 g
s
.263 .69 .965 r
.29772 .4555 m .29173 .4539 L .29142 .45374 L p F P
0 g
s
.356 .748 .986 r
.34123 .4609 m .3442 .46236 L .33729 .46246 L p F P
0 g
s
.356 .748 .986 r
.33172 .46106 m .34123 .4609 L p .33729 .46246 L F P
0 g
s
.356 .748 .986 r
.33729 .46246 m .33314 .46176 L .33172 .46106 L p F P
0 g
s
.688 .735 .887 r
.70004 .25445 m .68986 .2582 L .68748 .2552 L p F P
0 g
s
.704 .764 .898 r
.67735 .2597 m .68748 .2552 L .68986 .2582 L p F P
0 g
s
.675 .715 .879 r
.68986 .2582 m .70004 .25445 L .70244 .25803 L p F P
0 g
s
.516 .076 .142 r
.4323 .36485 m .43032 .365 L .42853 .36733 L p F P
0 g
s
.55 .113 .163 r
.42515 .36746 m .42853 .36733 L .43032 .365 L p F P
0 g
s
.1 .592 .904 r
.26364 .44644 m .26398 .4465 L .26999 .44853 L p F P
0 g
s
.146 .616 .926 r
.27251 .44781 m .26398 .4465 L .26999 .44853 L p F P
0 g
s
.146 .616 .926 r
.27329 .44808 m .27251 .44781 L p .26999 .44853 L F P
0 g
s
.146 .616 .926 r
.26999 .44853 m .27597 .44947 L .27329 .44808 L p F P
0 g
s
.18 .641 .938 r
.27906 .45103 m .28486 .45176 L .29108 .45371 L p F P
0 g
s
.192 .646 .943 r
.28486 .45176 m .27906 .45103 L .27597 .44947 L p F P
0 g
s
.43 .649 .95 r
.18423 .2745 m .18229 .27256 L .18205 .27254 L closepath p F P
0 g
s
.673 .138 0 r
.30689 .34161 m .30732 .34195 L .31324 .3441 L p F P
0 g
s
.683 .154 0 r
.31082 .34486 m .31702 .34691 L .31324 .3441 L p F P
0 g
s
.683 .154 0 r
.31324 .3441 m .30732 .34195 L .31082 .34486 L p F P
0 g
s
.391 0 0 r
.1718 .40526 m .16986 .40401 L .17418 .40674 L p F P
0 g
s
.391 0 0 r
.17418 .40674 m .17504 .40729 L .1718 .40526 L p F P
0 g
s
.613 .159 .151 r
.39197 .36496 m .39014 .36675 L .38602 .36453 L closepath p F P
0 g
s
0 0 0 r
.66908 .3928 m .66756 .39402 L .67586 .38776 L closepath p F P
0 g
s
.721 .808 .919 r
.67735 .2597 m .6756 .26054 L .67678 .2591 L closepath p F P
0 g
s
.721 .833 .934 r
.67498 .25722 m .67678 .2591 L .6756 .26054 L p F P
0 g
s
.721 .833 .934 r
.6649 .26238 m .67498 .25722 L p .6756 .26054 L F P
0 g
s
.751 .881 .938 r
.6545 .2675 m .65247 .26606 L .65938 .26214 L closepath p F P
0 g
s
0 .359 .762 r
.24641 .30926 m .24609 .30906 L .24594 .30899 L closepath p F P
0 g
s
.564 .009 0 r
.15338 .39289 m .14999 .38995 L .15407 .39279 L p F P
0 g
s
.564 .009 0 r
.15401 .39333 m .15338 .39289 L p .15407 .39279 L F P
0 g
s
.564 .009 0 r
.15407 .39279 m .15677 .39512 L .15401 .39333 L p F P
0 g
s
.491 .891 .746 r
.64529 .40853 m .64599 .40828 L .63742 .41365 L p F P
0 g
s
.491 .891 .746 r
.63742 .41365 m .63526 .41445 L .64529 .40853 L p F P
0 g
s
.509 .672 .937 r
.1548 .26253 m .16321 .2621 L .16643 .26544 L p F P
0 g
s
.749 .238 0 r
.12852 .37209 m .13231 .37508 L .12986 .37185 L p F P
0 g
s
.749 .238 0 r
.12986 .37185 m .12607 .36886 L .12852 .37209 L p F P
0 g
s
.649 .094 0 r
.29164 .33435 m .29208 .3347 L .29755 .33703 L p F P
0 g
s
.66 .109 0 r
.29562 .33758 m .30134 .33982 L .29755 .33703 L p F P
0 g
s
.66 .109 0 r
.29755 .33703 m .29208 .3347 L .29562 .33758 L p F P
0 g
s
.517 .078 .144 r
.44227 .36405 m .4323 .36485 L .43985 .36644 L p F P
0 g
s
.516 .076 .142 r
.42853 .36733 m .43985 .36644 L .4323 .36485 L p F P
0 g
s
.508 .868 .986 r
.49659 .46042 m .48692 .46229 L .48516 .46176 L p F P
0 g
s
.633 .963 .846 r
.58889 .30215 m .58774 .30236 L .59397 .29835 L closepath p F P
0 g
s
.685 .179 .033 r
.32701 .35178 m .33386 .35358 L .32997 .35079 L p F P
0 g
s
.685 .179 .033 r
.32997 .35079 m .32344 .34887 L .32701 .35178 L p F P
0 g
s
.64 .661 .855 r
.71398 .25749 m .71169 .26029 L p .70244 .25803 L F P
0 g
s
.62 .646 .854 r
.71169 .26029 m .71398 .25749 L .71513 .25955 L closepath p F P
0 g
s
.19 .548 .93 r
.20954 .28613 m .2059 .28508 L .2097 .28813 L p F P
0 g
s
.19 .548 .93 r
.2097 .28813 m .21268 .28895 L .20954 .28613 L p F P
0 g
s
0 .366 .774 r
.24296 .30699 m .24141 .30626 L .24594 .30899 L p F P
0 g
s
0 .366 .774 r
.24594 .30899 m .24609 .30906 L .24296 .30699 L p F P
0 g
s
.64 .661 .855 r
.70244 .25803 m .7127 .25523 L .71398 .25749 L p F P
0 g
s
.654 .682 .865 r
.7127 .25523 m .70244 .25803 L .70004 .25445 L p F P
0 g
s
.401 0 0 r
.2501 .31155 m .24609 .30906 L .24296 .30699 L p F P
0 g
s
.619 .155 .129 r
.38987 .36703 m .39014 .36675 L .38602 .36453 L p F P
0 g
s
.619 .155 .129 r
.38111 .36631 m .38987 .36703 L p .38602 .36453 L F P
0 g
s
.619 .155 .129 r
.37768 .36414 m .38111 .36631 L p .38602 .36453 L F P
0 g
s
.619 .155 .129 r
.38602 .36453 m .37813 .36376 L .37768 .36414 L p F P
0 g
s
.341 0 .028 r
.47818 .35572 m .48425 .35471 L .47773 .35632 L closepath p F P
0 g
s
0 .513 .858 r
.23601 .43721 m .23984 .43824 L .24524 .4405 L p F P
0 g
s
.011 .518 .865 r
.23984 .43824 m .23601 .43721 L .23285 .43551 L p F P
0 g
s
.719 .808 .92 r
.6851 .25239 m .68748 .2552 L .67735 .2597 L p F P
0 g
s
.719 .808 .92 r
.68071 .25449 m .6851 .25239 L p .67735 .2597 L F P
0 g
s
.719 .808 .92 r
.67735 .2597 m .67678 .2591 L .68071 .25449 L p F P
0 g
s
.651 .161 .075 r
.351 .35753 m .34984 .35815 L .34812 .35697 L closepath p F P
0 g
s
.601 .03 0 r
.27642 .32634 m .27755 .32719 L .28266 .32967 L p F P
0 g
s
.608 .038 0 r
.28121 .33 m .28655 .33239 L .28266 .32967 L p F P
0 g
s
.608 .038 0 r
.28266 .32967 m .27755 .32719 L .28121 .33 L p F P
0 g
s
0 .369 .748 r
.20539 .42393 m .20699 .42459 L .21191 .42706 L p F P
0 g
s
0 .41 .788 r
.2128 .42676 m .20699 .42459 L .21191 .42706 L p F P
0 g
s
0 .41 .788 r
.21717 .429 m .2128 .42676 L p .21191 .42706 L F P
0 g
s
0 .41 .788 r
.21191 .42706 m .21749 .42918 L .21717 .429 L p F P
0 g
s
0 0 .133 r
.71691 .3435 m .71675 .34417 L .71748 .34292 L closepath p F P
0 g
s
0 .445 .807 r
.22068 .43093 m .22279 .43164 L .22795 .434 L p F P
0 g
s
0 .48 .84 r
.22923 .43361 m .22279 .43164 L .22795 .434 L p F P
0 g
s
0 .48 .84 r
.23043 .43417 m .22923 .43361 L p .22795 .434 L F P
0 g
s
0 .48 .84 r
.22795 .434 m .23285 .43551 L .23043 .43417 L p F P
0 g
s
.682 .148 0 r
.14281 .38409 m .14196 .38316 L .13866 .38099 L p F P
0 g
s
0 0 0 r
.55372 .32273 m .5554 .32147 L .54547 .32683 L p F P
0 g
s
0 0 0 r
.54547 .32683 m .54469 .32746 L .55372 .32273 L p F P
0 g
s
.314 .726 .977 r
.33314 .46176 m .33172 .46106 L .32962 .46104 L closepath p F P
0 g
s
.38 .769 .989 r
.36973 .46447 m .37215 .46556 L p .35965 .46479 L F P
0 g
s
.38 .769 .989 r
.35965 .46479 m .36821 .4643 L .36973 .46447 L p F P
0 g
s
.403 .773 .993 r
.36821 .4643 m .35965 .46479 L .35671 .46343 L p F P
0 g
s
.483 .895 .792 r
.6234 .42043 m .62524 .41995 L .61523 .42515 L p F P
0 g
s
.483 .895 .792 r
.61523 .42515 m .61453 .42533 L .6234 .42043 L p F P
0 g
s
.676 .154 0 r
.3222 .34789 m .32344 .34887 L .32097 .34808 L closepath p F P
0 g
s
.106 0 .311 r
.72597 .3316 m .72479 .33285 L .72509 .32938 L p F P
0 g
s
.106 0 .311 r
.72509 .32938 m .72762 .32667 L .72597 .3316 L p F P
0 g
s
.567 .933 .798 r
.57786 .30849 m .57778 .30851 L .57828 .3082 L closepath p F P
0 g
s
.521 .918 .882 r
.59921 .43208 m .5928 .43494 L .59034 .43511 L p F P
0 g
s
.521 .892 .969 r
.53277 .45287 m .52283 .4559 L .52021 .45533 L p F P
0 g
s
.501 .883 .968 r
.51029 .45814 m .52021 .45533 L .52283 .4559 L p F P
0 g
s
.373 .291 .634 r
.73815 .29646 m .73692 .29792 L .73437 .2945 L p F P
0 g
s
.373 .291 .634 r
.73437 .2945 m .73713 .2912 L .73815 .29646 L p F P
0 g
s
.707 .181 0 r
.13499 .37824 m .13231 .37508 L .13615 .37803 L p F P
0 g
s
.707 .181 0 r
.13765 .38028 m .13499 .37824 L p .13615 .37803 L F P
0 g
s
.707 .181 0 r
.13615 .37803 m .13866 .38099 L .13765 .38028 L p F P
0 g
s
0 0 0 r
.67897 .38499 m .67753 .38643 L .68494 .38029 L closepath p F P
0 g
s
.709 .978 .913 r
.61469 .28666 m .61009 .28957 L .60784 .28944 L p F P
0 g
s
.126 0 0 r
.52045 .34126 m .52204 .3395 L .51226 .34318 L p F P
0 g
s
.126 0 0 r
.51226 .34318 m .51051 .34511 L .52045 .34126 L p F P
0 g
s
0 .212 .625 r
.17854 .40936 m .17504 .40729 L .1718 .40526 L p F P
0 g
s
.939 .604 .368 r
.10085 .33562 m .10075 .33487 L .09744 .33211 L p F P
0 g
s
.477 .036 .12 r
.44846 .3633 m .44227 .36405 L .44051 .36639 L p F P
0 g
s
.517 .078 .144 r
.43985 .36644 m .44051 .36639 L .44227 .36405 L p F P
0 g
s
.503 .894 .735 r
.57828 .3082 m .57778 .30851 L .57543 .30947 L p F P
0 g
s
0 .343 .738 r
.1975 .41951 m .20214 .42209 L .19697 .41971 L p F P
0 g
s
0 .343 .738 r
.19697 .41971 m .19229 .41715 L .1975 .41951 L p F P
0 g
s
0 .289 .683 r
.19017 .41609 m .19229 .41715 L .19697 .41971 L p F P
0 g
s
.506 .906 .796 r
.62616 .41971 m .62524 .41995 L .63237 .41608 L closepath p F P
0 g
s
.651 .164 .082 r
.34452 .35823 m .34077 .35536 L .34812 .35697 L p F P
0 g
s
.651 .164 .082 r
.3483 .35901 m .34452 .35823 L p .34812 .35697 L F P
0 g
s
.651 .164 .082 r
.34812 .35697 m .34984 .35815 L .3483 .35901 L p F P
0 g
s
.561 .93 .796 r
.58774 .30236 m .57828 .3082 L .58624 .3028 L closepath p F P
0 g
s
.503 .894 .735 r
.58529 .30309 m .58624 .3028 L .57828 .3082 L p F P
0 g
s
.503 .894 .735 r
.576 .30907 m .58529 .30309 L p .57828 .3082 L F P
0 g
s
.503 .894 .735 r
.57543 .30947 m .576 .30907 L p .57828 .3082 L F P
0 g
s
.048 .543 .884 r
.2451 .43951 m .23984 .43824 L .24524 .4405 L p F P
0 g
s
.048 .543 .884 r
.24524 .4405 m .24824 .44123 L .2451 .43951 L p F P
0 g
s
.512 0 0 r
.26748 .32216 m .27252 .32468 L .2684 .32206 L p F P
0 g
s
.512 0 0 r
.2684 .32206 m .26358 .31947 L .26748 .32216 L p F P
0 g
s
.526 0 0 r
.26358 .31947 m .26125 .31784 L .25811 .31618 L p F P
0 g
s
.757 .921 .944 r
.64245 .2719 m .64014 .27328 L .64183 .27159 L closepath p F P
0 g
s
.748 .941 .947 r
.64006 .27069 m .64183 .27159 L .64014 .27328 L p F P
0 g
s
.748 .941 .947 r
.63012 .27689 m .64006 .27069 L p .64014 .27328 L F P
0 g
s
.748 .941 .947 r
.63007 .27694 m .63012 .27689 L p .64014 .27328 L F P
0 g
s
0 0 .13 r
.72039 .34224 m .72358 .33678 L .71748 .34292 L p F P
0 g
s
0 0 .13 r
.71621 .34645 m .72039 .34224 L p .71748 .34292 L F P
0 g
s
0 0 .13 r
.71748 .34292 m .71675 .34417 L .71621 .34645 L p F P
0 g
s
.326 .606 .949 r
.19437 .27742 m .19253 .2771 L .19615 .28024 L p F P
0 g
s
.326 .606 .949 r
.19615 .28024 m .19751 .28047 L .19437 .27742 L p F P
0 g
s
.171 0 .39 r
.7323 .3216 m .72762 .32667 L .72857 .322 L p F P
0 g
s
.171 0 .39 r
.72857 .322 m .73238 .31787 L .7323 .3216 L p F P
0 g
s
0 .307 .75 r
.22783 .29784 m .2284 .29816 L .23246 .30108 L p F P
0 g
s
0 .307 .749 r
.23285 .30058 m .23705 .30345 L .23246 .30108 L p F P
0 g
s
0 .307 .749 r
.23246 .30108 m .2284 .29816 L .23285 .30058 L p F P
0 g
s
.628 .166 .136 r
.37813 .36376 m .37768 .36414 L .37679 .36361 L closepath p F P
0 g
s
.293 .717 .971 r
.31927 .45943 m .32226 .4595 L .32962 .46104 L p F P
0 g
s
.293 .717 .971 r
.31927 .45943 m .32226 .4595 L .31721 .45845 L closepath p F P
0 g
s
0 .45 .815 r
.22279 .43164 m .22068 .43093 L .21749 .42918 L p F P
0 g
s
.53 0 0 r
.15677 .39512 m .15751 .39571 L .16172 .39849 L p F P
0 g
s
.44 0 0 r
.16142 .39847 m .16561 .40126 L .16172 .39849 L p F P
0 g
s
.44 0 0 r
.16172 .39849 m .15751 .39571 L .16142 .39847 L p F P
0 g
s
.437 .847 .67 r
.57532 .30952 m .57543 .30947 L .56689 .3149 L p F P
0 g
s
.437 .847 .67 r
.56689 .3149 m .56535 .31569 L .57532 .30952 L p F P
0 g
s
.628 .172 .151 r
.37215 .36529 m .36804 .36252 L .37679 .36361 L p F P
0 g
s
.628 .172 .151 r
.37592 .36574 m .37215 .36529 L p .37679 .36361 L F P
0 g
s
.628 .172 .151 r
.37679 .36361 m .37768 .36414 L .37592 .36574 L p F P
0 g
s
.719 .809 .921 r
.67678 .2591 m .67498 .25722 L .68071 .25449 L closepath p F P
0 g
s
.324 .727 .98 r
.32873 .45955 m .32226 .4595 L .32962 .46104 L p F P
0 g
s
.324 .727 .98 r
.32962 .46104 m .33172 .46106 L .32873 .45955 L p F P
0 g
s
.46 .861 .683 r
.65222 .40455 m .64758 .40749 L .64599 .40828 L p F P
0 g
s
.939 .604 .368 r
.09744 .33211 m .09748 .33241 L .10085 .33562 L p F P
0 g
s
.93 .558 .28 r
.09835 .33617 m .10172 .33937 L .10085 .33562 L p F P
0 g
s
.93 .558 .28 r
.10085 .33562 m .09748 .33241 L .09835 .33617 L p F P
0 g
s
.01 0 .141 r
.71675 .34417 m .71413 .34844 L .71621 .34645 L closepath p F P
0 g
s
.911 .509 .205 r
.10289 .34302 m .10633 .34619 L .10515 .34255 L p F P
0 g
s
.911 .509 .205 r
.10515 .34255 m .10172 .33937 L .10289 .34302 L p F P
0 g
s
0 .294 .694 r
.19229 .41715 m .19017 .41609 L .18695 .41419 L p F P
0 g
s
.762 .921 .941 r
.65009 .26453 m .65247 .26606 L .64245 .2719 L p F P
0 g
s
.762 .921 .941 r
.64634 .26683 m .65009 .26453 L p .64245 .2719 L F P
0 g
s
.762 .921 .941 r
.64245 .2719 m .64183 .27159 L .64634 .26683 L p F P
0 g
s
.403 .783 .992 r
.3836 .46562 m .38467 .4661 L p .37215 .46556 L F P
0 g
s
.403 .783 .992 r
.37215 .46556 m .37762 .46513 L .3836 .46562 L p F P
0 g
s
.402 .783 .992 r
.37215 .46556 m .37762 .46513 L .36973 .46447 L closepath p F P
0 g
s
.206 .657 .947 r
.29173 .4539 m .29142 .45374 L .29108 .45371 L closepath p F P
0 g
s
.944 .613 .374 r
.09416 .32902 m .09374 .32526 L .09704 .32851 L p F P
0 g
s
.944 .613 .374 r
.09704 .32851 m .09744 .33211 L .09416 .32902 L p F P
0 g
s
.668 .126 0 r
.30689 .34161 m .30732 .34195 L .30639 .3416 L closepath p F P
0 g
s
.527 .911 .938 r
.55786 .4469 m .55784 .4469 L .55855 .44664 L closepath p F P
0 g
s
.583 .01 0 r
.27642 .32634 m .27755 .32719 L .27446 .3256 L closepath p F P
0 g
s
.481 .04 .124 r
.45385 .36266 m .453 .36382 L .44846 .3633 L closepath p F P
0 g
s
.477 .036 .12 r
.45217 .36505 m .453 .36382 L .44846 .3633 L p F P
0 g
s
.477 .036 .12 r
.44051 .36639 m .45217 .36505 L p .44846 .3633 L F P
0 g
s
0 0 0 r
.70779 .35633 m .70714 .35788 L .71006 .3542 L closepath p F P
0 g
s
.353 0 .047 r
.48425 .35471 m .47773 .35632 L .47605 .35864 L p F P
0 g
s
.734 .971 .931 r
.62006 .28327 m .61469 .28666 L .61886 .28305 L closepath p F P
0 g
s
.709 .978 .913 r
.61766 .28284 m .61886 .28305 L .61469 .28666 L p F P
0 g
s
.709 .978 .913 r
.60842 .28893 m .61766 .28284 L p .61469 .28666 L F P
0 g
s
.709 .978 .913 r
.60784 .28944 m .60842 .28893 L p .61469 .28666 L F P
0 g
s
.268 .146 .522 r
.7391 .30582 m .73411 .31166 L .73348 .30755 L p F P
0 g
s
.268 .146 .522 r
.73348 .30755 m .73846 .30171 L .7391 .30582 L p F P
0 g
s
.541 .914 .947 r
.55855 .44664 m .55784 .4469 L .55529 .44659 L p F P
0 g
s
.519 .904 .945 r
.54531 .45005 m .55529 .44659 L .55784 .4469 L p F P
0 g
s
.886 .457 .128 r
.10779 .34975 m .11129 .35288 L .10983 .34933 L p F P
0 g
s
.886 .457 .128 r
.10983 .34933 m .10633 .34619 L .10779 .34975 L p F P
0 g
s
0 .376 .759 r
.20539 .42393 m .20699 .42459 L .20229 .42218 L closepath p F P
0 g
s
0 .252 .661 r
.18318 .4119 m .17854 .40936 L .183 .41202 L p F P
0 g
s
0 .252 .661 r
.18515 .41309 m .18318 .4119 L p .183 .41202 L F P
0 g
s
0 .252 .661 r
.183 .41202 m .18695 .41419 L .18515 .41309 L p F P
0 g
s
.593 .591 .819 r
.72729 .26202 m .72604 .26365 L p .71513 .25955 L F P
0 g
s
.593 .591 .819 r
.71513 .25955 m .72551 .2582 L .72729 .26202 L p F P
0 g
s
.591 .632 .861 r
.71398 .25749 m .71513 .25955 L .72551 .2582 L p F P
0 g
s
.741 .83 .919 r
.67498 .25722 m .6649 .26238 L .66252 .26037 L p F P
0 g
s
.51 .884 .972 r
.519 .45504 m .52021 .45533 L .51029 .45814 L p F P
0 g
s
.51 .884 .972 r
.51029 .45814 m .50851 .45773 L .519 .45504 L p F P
0 g
s
.682 .148 0 r
.13866 .38099 m .13885 .38119 L .14281 .38409 L p F P
0 g
s
.594 .048 0 r
.14203 .38418 m .14598 .38708 L .14281 .38409 L p F P
0 g
s
.594 .048 0 r
.14281 .38409 m .13885 .38119 L .14203 .38418 L p F P
0 g
s
.06 0 0 r
.53156 .33546 m .53298 .33395 L .52305 .3384 L p F P
0 g
s
.06 0 0 r
.52305 .3384 m .52204 .3395 L .53156 .33546 L p F P
0 g
s
.218 .659 .952 r
.28835 .45213 m .28486 .45176 L .29108 .45371 L p F P
0 g
s
.218 .659 .952 r
.29108 .45371 m .29142 .45374 L .28835 .45213 L p F P
0 g
s
.111 .596 .91 r
.26364 .44644 m .26398 .4465 L .26326 .44625 L closepath p F P
0 g
s
.434 .647 .948 r
.17914 .26934 m .17863 .26931 L .18205 .27254 L p F P
0 g
s
.434 .647 .948 r
.18205 .27254 m .18229 .27256 L .17914 .26934 L p F P
0 g
s
.224 0 0 r
.51043 .34521 m .51051 .34511 L .50061 .34828 L p F P
0 g
s
.224 0 0 r
.50061 .34828 m .50039 .34855 L .51043 .34521 L p F P
0 g
s
.64 .08 0 r
.29164 .33435 m .29208 .3347 L .291 .33421 L closepath p F P
0 g
s
.507 .906 .921 r
.56783 .44319 m .55855 .44664 L .56754 .44318 L closepath p F P
0 g
s
.541 .914 .947 r
.56529 .4429 m .56754 .44318 L .55855 .44664 L p F P
0 g
s
.541 .914 .947 r
.55529 .44659 m .56529 .4429 L p .55855 .44664 L F P
0 g
s
0 .223 .618 r
.25437 .31408 m .2501 .31155 L .25467 .31425 L p F P
0 g
s
0 .223 .618 r
.25618 .31509 m .25437 .31408 L p .25467 .31425 L F P
0 g
s
0 .223 .618 r
.25467 .31425 m .25811 .31618 L .25618 .31509 L p F P
0 g
s
0 0 0 r
.55582 .32121 m .5554 .32147 L .5589 .31943 L closepath p F P
0 g
s
.517 .675 .936 r
.16385 .26206 m .16321 .2621 L .16643 .26544 L p F P
0 g
s
.517 .675 .936 r
.16643 .26544 m .16701 .2654 L .16385 .26206 L p F P
0 g
s
.856 .401 .051 r
.11303 .35635 m .11659 .35945 L .11485 .35598 L p F P
0 g
s
.856 .401 .051 r
.11485 .35598 m .11129 .35288 L .11303 .35635 L p F P
0 g
s
.304 .583 .94 r
.18902 .27391 m .18229 .27256 L .17914 .26934 L p F P
0 g
s
.272 .687 .969 r
.30077 .45445 m .29142 .45374 L .28835 .45213 L p F P
0 g
s
.198 .642 .947 r
.26674 .44568 m .27251 .44781 L .26398 .4465 L p F P
0 g
s
.198 .642 .947 r
.26053 .44475 m .26674 .44568 L p .26398 .4465 L F P
0 g
s
.198 .642 .947 r
.26398 .4465 m .26326 .44625 L .26053 .44475 L p F P
0 g
s
.497 .87 .981 r
.49784 .46017 m .49773 .46014 L .49659 .46042 L closepath p F P
0 g
s
.508 .868 .986 r
.49505 .45929 m .49773 .46014 L .49659 .46042 L p F P
0 g
s
.508 .868 .986 r
.48516 .46176 m .49505 .45929 L p .49659 .46042 L F P
0 g
s
.684 .151 0 r
.30497 .34268 m .31082 .34486 L .30732 .34195 L p F P
0 g
s
.684 .151 0 r
.30376 .3416 m .30497 .34268 L p .30732 .34195 L F P
0 g
s
.684 .151 0 r
.30732 .34195 m .30639 .3416 L .30376 .3416 L p F P
0 g
s
.688 .175 .01 r
.32061 .34981 m .32701 .35178 L .32344 .34887 L p F P
0 g
s
.688 .175 .01 r
.31907 .34845 m .32061 .34981 L p .32344 .34887 L F P
0 g
s
.688 .175 .01 r
.32344 .34887 m .32097 .34808 L .31907 .34845 L p F P
0 g
s
0 0 0 r
.68855 .37674 m .68746 .37806 L .69272 .37325 L closepath p F P
0 g
s
.153 .517 .916 r
.19751 .28047 m .2022 .28198 L .2059 .28508 L p F P
0 g
s
.155 .512 .914 r
.2022 .28198 m .19751 .28047 L .19437 .27742 L p F P
0 g
s
0 .422 .852 r
.21268 .28895 m .21527 .29009 L .21914 .2931 L p F P
0 g
s
.008 .439 .865 r
.22039 .29223 m .2244 .2952 L .21914 .2931 L p F P
0 g
s
.008 .439 .865 r
.21914 .2931 m .21527 .29009 L .22039 .29223 L p F P
0 g
s
.637 .184 .158 r
.37768 .36414 m .38111 .36631 L .37592 .36574 L closepath p F P
0 g
s
.407 .813 .606 r
.65758 .401 m .65222 .40455 L .65673 .40153 L closepath p F P
0 g
s
.46 .861 .683 r
.65532 .40221 m .65673 .40153 L .65222 .40455 L p F P
0 g
s
.46 .861 .683 r
.64964 .40585 m .65532 .40221 L p .65222 .40455 L F P
0 g
s
.46 .861 .683 r
.64599 .40828 m .64964 .40585 L p .65222 .40455 L F P
0 g
s
.533 .92 .912 r
.58068 .43932 m .58033 .43932 L .58575 .43706 L closepath p F P
0 g
s
.452 .01 .106 r
.46347 .36327 m .4651 .36084 L .45385 .36266 L p F P
0 g
s
.452 .01 .106 r
.45843 .36405 m .46347 .36327 L p .45385 .36266 L F P
0 g
s
.452 .01 .106 r
.45385 .36266 m .453 .36382 L .45843 .36405 L p F P
0 g
s
.128 .597 .92 r
.26326 .44625 m .26053 .44475 L .2583 .44434 L closepath p F P
0 g
s
.419 .636 .945 r
.16701 .2654 m .17531 .26602 L .17863 .26931 L p F P
0 g
s
.422 .633 .943 r
.17531 .26602 m .16701 .2654 L .16385 .26206 L p F P
0 g
s
.517 .878 .982 r
.50763 .45748 m .50851 .45773 L .49784 .46017 L p F P
0 g
s
.517 .878 .982 r
.49784 .46017 m .49773 .46014 L .50763 .45748 L p F P
0 g
s
.532 .923 .848 r
.62287 .42051 m .6234 .42043 L .61453 .42533 L p F P
0 g
s
.532 .923 .848 r
.61453 .42533 m .61283 .4256 L .62287 .42051 L p F P
0 g
s
.423 .795 .994 r
.38467 .4661 m .38738 .46583 L .3836 .46562 L closepath p F P
0 g
s
.422 .795 .994 r
.39705 .46633 m .39721 .4664 L p .38467 .4661 L F P
0 g
s
.422 .795 .994 r
.38467 .4661 m .38738 .46583 L .39705 .46633 L p F P
0 g
s
.209 .066 .456 r
.73395 .31606 m .73238 .31787 L .73224 .31382 L p F P
0 g
s
.209 .066 .456 r
.73224 .31382 m .73411 .31166 L .73395 .31606 L p F P
0 g
s
.662 .11 0 r
.29019 .33522 m .29562 .33758 L .29208 .3347 L p F P
0 g
s
.662 .11 0 r
.2885 .33375 m .29019 .33522 L p .29208 .3347 L F P
0 g
s
.662 .11 0 r
.29208 .3347 m .291 .33421 L .2885 .33375 L p F P
0 g
s
.653 .186 .133 r
.36373 .36407 m .37215 .36529 L .36804 .36252 L p F P
0 g
s
.653 .186 .133 r
.3622 .3629 m .36373 .36407 L p .36804 .36252 L F P
0 g
s
.653 .186 .133 r
.36804 .36252 m .36363 .36184 L .3622 .3629 L p F P
0 g
s
.812 .329 0 r
.11757 .36106 m .11659 .35945 L .12022 .36252 L p F P
0 g
s
.812 .329 0 r
.12022 .36252 m .12087 .36359 L .11757 .36106 L p F P
0 g
s
.644 .095 0 r
.30639 .3416 m .30376 .3416 L .30134 .33982 L closepath p F P
0 g
s
.533 .9 .966 r
.54273 .44963 m .54392 .44987 L .53386 .45308 L p F P
0 g
s
.533 .9 .966 r
.53386 .45308 m .53277 .45287 L .54273 .44963 L p F P
0 g
s
.241 0 0 r
.50876 .34745 m .51043 .34521 L .50039 .34855 L p F P
0 g
s
.241 0 0 r
.50039 .34855 m .49869 .35078 L .50876 .34745 L p F P
0 g
s
.475 .447 .747 r
.73312 .27686 m .73484 .27745 L .73379 .27886 L closepath p F P
0 g
s
.444 .406 .721 r
.73977 .28002 m .73573 .28541 L .73379 .27886 L p F P
0 g
s
.444 .406 .721 r
.73379 .27886 m .73484 .27745 L .73977 .28002 L p F P
0 g
s
.464 .456 .764 r
.73114 .2713 m .73312 .27686 L .73484 .27745 L p F P
0 g
s
.53 .877 .987 r
.50763 .45748 m .49773 .46014 L .49505 .45929 L p F P
0 g
s
.485 .9 .841 r
.60281 .43044 m .59921 .43208 L .60251 .43048 L closepath p F P
0 g
s
.521 .918 .882 r
.60037 .4306 m .60251 .43048 L .59921 .43208 L p F P
0 g
s
.521 .918 .882 r
.59034 .43511 m .60037 .4306 L p .59921 .43208 L F P
0 g
s
0 0 .035 r
.71534 .34918 m .71006 .3542 L .71413 .34844 L p F P
0 g
s
0 0 .035 r
.71413 .34844 m .71621 .34645 L .71534 .34918 L p F P
0 g
s
.749 .973 .925 r
.62766 .27622 m .63005 .27693 L .62006 .28327 L p F P
0 g
s
.749 .973 .925 r
.62246 .27966 m .62766 .27622 L p .62006 .28327 L F P
0 g
s
.749 .973 .925 r
.62006 .28327 m .61886 .28305 L .62246 .27966 L p F P
0 g
s
.682 .188 .066 r
.33736 .35654 m .34452 .35823 L .34077 .35536 L p F P
0 g
s
.682 .188 .066 r
.33444 .35401 m .33736 .35654 L p .34077 .35536 L F P
0 g
s
.682 .188 .066 r
.34077 .35536 m .33489 .35383 L .33444 .35401 L p F P
0 g
s
.428 .369 .69 r
.73553 .28565 m .73573 .28541 L .73585 .28588 L closepath p F P
0 g
s
0 0 0 r
.55289 .32337 m .55372 .32273 L .54469 .32746 L p F P
0 g
s
0 0 0 r
.54469 .32746 m .54293 .32892 L .55289 .32337 L p F P
0 g
s
.374 .747 .99 r
.34123 .4609 m .33172 .46106 L .32873 .45955 L p F P
0 g
s
0 .415 .851 r
.21527 .29009 m .21268 .28895 L .20954 .28613 L p F P
0 g
s
.407 0 .091 r
.4656 .36013 m .47008 .35982 L .4651 .36084 L closepath p F P
0 g
s
.384 0 0 r
.16855 .40317 m .16561 .40126 L .16986 .40401 L p F P
0 g
s
.384 0 0 r
.16986 .40401 m .1718 .40526 L .16855 .40317 L p F P
0 g
s
.763 .923 .941 r
.64183 .27159 m .64006 .27069 L .64634 .26683 L closepath p F P
0 g
s
.583 .94 .8 r
.59397 .29835 m .58774 .30236 L .58624 .3028 L p F P
0 g
s
.674 .195 .105 r
.34984 .35815 m .35199 .3598 L .3483 .35901 L closepath p F P
0 g
s
.599 .027 0 r
.291 .33421 m .2885 .33375 L .28655 .33239 L closepath p F P
0 g
s
.378 .337 .686 r
.74341 .28305 m .73977 .28002 L .73573 .28541 L p F P
0 g
s
.378 .337 .686 r
.73903 .28874 m .74341 .28305 L p .73573 .28541 L F P
0 g
s
.378 .337 .686 r
.73573 .28541 m .73585 .28588 L .73903 .28874 L p F P
0 g
s
.549 0 0 r
.14937 .39001 m .15338 .39289 L .14999 .38995 L p F P
0 g
s
.549 0 0 r
.14999 .38995 m .14598 .38708 L .14937 .39001 L p F P
0 g
s
.613 .046 0 r
.27612 .3275 m .28121 .33 L .27755 .32719 L p F P
0 g
s
.613 .046 0 r
.27329 .32518 m .27612 .3275 L p .27755 .32719 L F P
0 g
s
.613 .046 0 r
.27755 .32719 m .27446 .3256 L .27329 .32518 L p F P
0 g
s
.617 .65 .861 r
.7127 .25523 m .71591 .25458 L .71398 .25749 L closepath p F P
0 g
s
.591 .632 .861 r
.72306 .25328 m .71591 .25458 L .71398 .25749 L p F P
0 g
s
.591 .632 .861 r
.72551 .2582 m .72306 .25328 L p .71398 .25749 L F P
0 g
s
.663 .14 0 r
.32097 .34808 m .31907 .34845 L .31702 .34691 L closepath p F P
0 g
s
.467 .818 .997 r
.42098 .46645 m .41006 .46657 L .40975 .46644 L p F P
0 g
s
.447 .809 .996 r
.41006 .46657 m .40975 .46644 L .40885 .46655 L closepath p F P
0 g
s
0 .351 .768 r
.23983 .30483 m .23705 .30345 L .24141 .30626 L p F P
0 g
s
0 .351 .768 r
.24141 .30626 m .24296 .30699 L .23983 .30483 L p F P
0 g
s
.398 .339 .675 r
.73585 .28588 m .73903 .28874 L .73713 .2912 L closepath p F P
0 g
s
.437 .806 .994 r
.39721 .4664 m .39766 .46635 L .40885 .46655 L p F P
0 g
s
.442 .805 .996 r
.39721 .4664 m .39766 .46635 L .39705 .46633 L closepath p F P
0 g
s
.461 .807 .998 r
.4069 .46508 m .39766 .46635 L .40885 .46655 L p F P
0 g
s
.461 .807 .998 r
.40885 .46655 m .40975 .46644 L .4069 .46508 L p F P
0 g
s
0 0 0 r
.5589 .31943 m .5554 .32147 L .55372 .32273 L p F P
0 g
s
.543 .923 .92 r
.58575 .43706 m .58033 .43932 L .57783 .43923 L p F P
0 g
s
.522 .914 .917 r
.56783 .44319 m .57783 .43923 L .58033 .43932 L p F P
0 g
s
.433 .829 .615 r
.66512 .39579 m .65758 .401 L .65673 .40153 L p F P
0 g
s
0 .45 .815 r
.21749 .42918 m .21768 .42925 L .22279 .43164 L p F P
0 g
s
0 .498 .858 r
.22421 .43118 m .22923 .43361 L .22279 .43164 L p F P
0 g
s
0 .498 .858 r
.22279 .43164 m .21768 .42925 L .22421 .43118 L p F P
0 g
s
.349 .737 .986 r
.32573 .45798 m .32873 .45955 L .32226 .4595 L p F P
0 g
s
.349 .737 .986 r
.31626 .45796 m .32573 .45798 L p .32226 .4595 L F P
0 g
s
.349 .737 .986 r
.32226 .4595 m .31721 .45845 L .31626 .45796 L p F P
0 g
s
.513 .503 .783 r
.73053 .26971 m .73211 .26996 L .73114 .2713 L closepath p F P
0 g
s
.464 .456 .764 r
.73901 .27182 m .73211 .26996 L .73114 .2713 L p F P
0 g
s
.464 .456 .764 r
.73484 .27745 m .73901 .27182 L p .73114 .2713 L F P
0 g
s
.796 .304 0 r
.12087 .36359 m .12235 .36585 L .12607 .36886 L p F P
0 g
s
.741 .229 0 r
.12481 .36907 m .12852 .37209 L .12607 .36886 L p F P
0 g
s
.741 .229 0 r
.12607 .36886 m .12235 .36585 L .12481 .36907 L p F P
0 g
s
.467 .818 .997 r
.41948 .46493 m .42231 .46625 L .42098 .46645 L p F P
0 g
s
.467 .818 .997 r
.40975 .46644 m .41948 .46493 L p .42098 .46645 L F P
0 g
s
.461 .819 .996 r
.4227 .46642 m .42231 .46625 L .42098 .46645 L closepath p F P
0 g
s
.51 .869 .986 r
.49505 .45929 m .48516 .46176 L .48245 .46087 L p F P
0 g
s
.499 .861 .988 r
.47259 .46314 m .48245 .46087 L .48516 .46176 L p F P
0 g
s
.479 .827 .997 r
.43427 .46594 m .4227 .46642 L .42231 .46625 L p F P
0 g
s
0 .464 .841 r
.20801 .42424 m .2128 .42676 L .20699 .42459 L p F P
0 g
s
0 .464 .841 r
.20219 .42211 m .20801 .42424 L p .20699 .42459 L F P
0 g
s
0 .464 .841 r
.20699 .42459 m .20229 .42218 L .20219 .42211 L p F P
0 g
s
.51 .909 .8 r
.63237 .41608 m .62524 .41995 L .6234 .42043 L p F P
0 g
s
.654 .188 .134 r
.36363 .36184 m .3622 .3629 L .3598 .36124 L closepath p F P
0 g
s
.474 .809 .999 r
.40404 .46366 m .4069 .46508 L .39766 .46635 L p F P
0 g
s
.474 .809 .999 r
.39433 .46501 m .40404 .46366 L p .39766 .46635 L F P
0 g
s
.474 .809 .999 r
.39766 .46635 m .39705 .46633 L .39433 .46501 L p F P
0 g
s
.525 .905 .949 r
.55381 .44639 m .55529 .44659 L .54531 .45005 L p F P
0 g
s
.525 .905 .949 r
.54531 .45005 m .54392 .44987 L .55381 .44639 L p F P
0 g
s
.453 .8 .998 r
.39705 .46633 m .39433 .46501 L .38738 .46583 L closepath p F P
0 g
s
.188 .54 .927 r
.20641 .28323 m .2022 .28198 L .2059 .28508 L p F P
0 g
s
.188 .54 .927 r
.2059 .28508 m .20954 .28613 L .20641 .28323 L p F P
0 g
s
.518 0 0 r
.15677 .39512 m .15751 .39571 L .15401 .39333 L closepath p F P
0 g
s
.341 0 .02 r
.48834 .35372 m .48804 .35411 L .48425 .35471 L closepath p F P
0 g
s
.353 0 .047 r
.4867 .35608 m .48804 .35411 L .48425 .35471 L p F P
0 g
s
.353 0 .047 r
.47605 .35864 m .4867 .35608 L p .48425 .35471 L F P
0 g
s
.528 .525 .795 r
.73211 .26996 m .73053 .26971 L .728 .2636 L p F P
0 g
s
.094 .577 .905 r
.24824 .44123 m .25271 .44215 L .2583 .44434 L p F P
0 g
s
.106 .581 .911 r
.25271 .44215 m .24824 .44123 L .2451 .43951 L p F P
0 g
s
.654 .682 .865 r
.70004 .25445 m .71029 .25124 L .7127 .25523 L p F P
0 g
s
.668 .704 .874 r
.71029 .25124 m .70004 .25445 L .69765 .2511 L p F P
0 g
s
.688 .735 .887 r
.68748 .2552 m .69765 .2511 L .70004 .25445 L p F P
0 g
s
.7 .754 .894 r
.69765 .2511 m .68748 .2552 L .6851 .25239 L p F P
0 g
s
.49 .818 1 r
.41948 .46493 m .40975 .46644 L .4069 .46508 L p F P
0 g
s
.058 .547 .89 r
.24168 .43768 m .23448 .43595 L .23984 .43824 L p F P
0 g
s
.058 .547 .89 r
.24236 .43798 m .24168 .43768 L p .23984 .43824 L F P
0 g
s
.058 .547 .89 r
.23984 .43824 m .2451 .43951 L .24236 .43798 L p F P
0 g
s
.011 .518 .865 r
.23285 .43551 m .23448 .43595 L .23984 .43824 L p F P
0 g
s
.095 0 .303 r
.73148 .32562 m .72597 .3316 L .72762 .32667 L p F P
0 g
s
.095 0 .303 r
.73211 .32373 m .73148 .32562 L p .72762 .32667 L F P
0 g
s
.095 0 .303 r
.72762 .32667 m .7323 .3216 L .73211 .32373 L p F P
0 g
s
0 .317 .765 r
.22783 .29784 m .2284 .29816 L .2256 .29603 L closepath p F P
0 g
s
.508 .86 .991 r
.48145 .4605 m .48245 .46087 L .47259 .46314 L p F P
0 g
s
.508 .86 .991 r
.47259 .46314 m .47024 .46233 L .48145 .4605 L p F P
0 g
s
.482 .852 .988 r
.47024 .46233 m .47259 .46314 L p .46002 .46428 L F P
0 g
s
0 0 0 r
.53342 .33355 m .53298 .33395 L .5393 .33074 L closepath p F P
0 g
s
.512 .914 .847 r
.61152 .42579 m .61283 .4256 L .60281 .43044 L p F P
0 g
s
.512 .914 .847 r
.60281 .43044 m .60251 .43048 L .61152 .42579 L p F P
0 g
s
0 .359 .758 r
.19293 .41689 m .1975 .41951 L .19229 .41715 L p F P
0 g
s
0 .359 .758 r
.19229 .41715 m .18768 .41455 L .19293 .41689 L p F P
0 g
s
0 .294 .694 r
.18695 .41419 m .18768 .41455 L .19229 .41715 L p F P
0 g
s
.793 .302 0 r
.12235 .36585 m .12087 .36359 L .11757 .36106 L p F P
0 g
s
.473 .828 .996 r
.43503 .4659 m .43488 .46584 L .43427 .46594 L closepath p F P
0 g
s
.479 .827 .997 r
.43207 .46457 m .43488 .46584 L .43427 .46594 L p F P
0 g
s
.479 .827 .997 r
.42231 .46625 m .43207 .46457 L p .43427 .46594 L F P
0 g
s
.496 .838 .997 r
.44466 .46399 m .44703 .46503 L .43503 .4659 L p F P
0 g
s
.496 .838 .997 r
.43503 .4659 m .43488 .46584 L .44466 .46399 L p F P
0 g
s
.749 .895 .944 r
.65938 .26214 m .65247 .26606 L .65009 .26453 L p F P
0 g
s
.526 0 0 r
.25811 .31618 m .25895 .31679 L .26358 .31947 L p F P
0 g
s
.534 0 0 r
.26266 .31955 m .26748 .32216 L .26358 .31947 L p F P
0 g
s
.534 0 0 r
.26358 .31947 m .25895 .31679 L .26266 .31955 L p F P
0 g
s
.561 .563 .813 r
.72604 .26365 m .72729 .26202 L .728 .2636 L closepath p F P
0 g
s
0 0 0 r
.56535 .31569 m .5589 .31943 L .56463 .31616 L closepath p F P
0 g
s
0 0 0 r
.56286 .31732 m .56463 .31616 L .5589 .31943 L p F P
0 g
s
0 0 0 r
.55971 .31921 m .56286 .31732 L p .5589 .31943 L F P
0 g
s
0 0 0 r
.55372 .32273 m .55971 .31921 L p .5589 .31943 L F P
0 g
s
.502 .826 1 r
.43207 .46457 m .42231 .46625 L .41948 .46493 L p F P
0 g
s
.459 .8 .999 r
.39145 .46355 m .39433 .46501 L .38738 .46583 L p F P
0 g
s
.459 .8 .999 r
.38178 .46473 m .39145 .46355 L p .38738 .46583 L F P
0 g
s
.459 .8 .999 r
.38738 .46583 m .3836 .46562 L .38178 .46473 L p F P
0 g
s
.654 .192 .144 r
.35567 .36271 m .35199 .3598 L .3598 .36124 L p F P
0 g
s
.654 .192 .144 r
.36124 .36365 m .35567 .36271 L p .3598 .36124 L F P
0 g
s
.654 .192 .144 r
.3598 .36124 m .3622 .3629 L .36124 .36365 L p F P
0 g
s
.482 .852 .988 r
.46002 .46428 m .46747 .46271 L .47024 .46233 L p F P
0 g
s
.498 .851 .993 r
.46002 .46428 m .46747 .46271 L .45875 .46382 L closepath p F P
0 g
s
.477 .843 .991 r
.45875 .46382 m .46002 .46428 L p .44745 .46519 L F P
0 g
s
0 0 0 r
.71495 .35009 m .71534 .34918 L .71006 .3542 L p F P
0 g
s
0 0 0 r
.71196 .35389 m .71495 .35009 L p .71006 .3542 L F P
0 g
s
0 0 0 r
.70674 .35886 m .71196 .35389 L p .71006 .3542 L F P
0 g
s
0 0 0 r
.71006 .3542 m .70714 .35788 L .70674 .35886 L p F P
0 g
s
.284 .703 .971 r
.30382 .45599 m .30818 .45619 L .31502 .45792 L p F P
0 g
s
.296 .708 .974 r
.30818 .45619 m .30382 .45599 L .30077 .45445 L p F P
0 g
s
.695 .17 0 r
.13121 .37525 m .13499 .37824 L .13231 .37508 L p F P
0 g
s
.695 .17 0 r
.13231 .37508 m .12852 .37209 L .13121 .37525 L p F P
0 g
s
.456 .423 .733 r
.74237 .2766 m .73977 .28002 L .73484 .27745 L p F P
0 g
s
.456 .423 .733 r
.74127 .27282 m .74237 .2766 L p .73484 .27745 L F P
0 g
s
.456 .423 .733 r
.73484 .27745 m .73901 .27182 L .74127 .27282 L p F P
0 g
s
.192 .646 .943 r
.27597 .44947 m .27865 .4498 L .28486 .45176 L p F P
0 g
s
.229 .663 .956 r
.28528 .45046 m .27865 .4498 L .28486 .45176 L p F P
0 g
s
.229 .663 .956 r
.28486 .45176 m .28835 .45213 L .28528 .45046 L p F P
0 g
s
.635 .964 .85 r
.5977 .29597 m .59397 .29835 L .59702 .29609 L closepath p F P
0 g
s
.583 .94 .8 r
.59526 .2964 m .59702 .29609 L .59397 .29835 L p F P
0 g
s
.583 .94 .8 r
.59031 .29971 m .59526 .2964 L p .59397 .29835 L F P
0 g
s
.583 .94 .8 r
.58624 .3028 m .59031 .29971 L p .59397 .29835 L F P
0 g
s
.512 .834 .999 r
.44466 .46399 m .43488 .46584 L .43207 .46457 L p F P
0 g
s
.38 .759 .99 r
.35531 .46275 m .35671 .46343 L p .3442 .46236 L F P
0 g
s
.38 .759 .99 r
.3442 .46236 m .35102 .46209 L .35531 .46275 L p F P
0 g
s
.397 .764 .993 r
.35102 .46209 m .3442 .46236 L .34123 .4609 L p F P
0 g
s
0 0 0 r
.69781 .36804 m .69735 .36872 L .69946 .36657 L closepath p F P
0 g
s
.477 .843 .991 r
.44745 .46519 m .44948 .46479 L .45875 .46382 L p F P
0 g
s
.491 .842 .995 r
.44745 .46519 m .44948 .46479 L .44703 .46503 L closepath p F P
0 g
s
.434 .789 .997 r
.3836 .46562 m .38178 .46473 L .37762 .46513 L closepath p F P
0 g
s
.351 .276 .631 r
.74144 .29221 m .73815 .29646 L .73713 .2912 L p F P
0 g
s
.351 .276 .631 r
.73713 .2912 m .73903 .28874 L .74144 .29221 L p F P
0 g
s
0 0 0 r
.66756 .39402 m .66512 .39579 L .66715 .39435 L closepath p F P
0 g
s
.433 .829 .615 r
.66534 .39546 m .66715 .39435 L .66512 .39579 L p F P
0 g
s
.433 .829 .615 r
.66346 .39677 m .66534 .39546 L p .66512 .39579 L F P
0 g
s
.433 .829 .615 r
.65673 .40153 m .66346 .39677 L p .66512 .39579 L F P
0 g
s
0 .281 .733 r
.22878 .29764 m .23285 .30058 L .2284 .29816 L p F P
0 g
s
0 .281 .733 r
.22469 .29531 m .22878 .29764 L p .2284 .29816 L F P
0 g
s
0 .281 .733 r
.2284 .29816 m .2256 .29603 L .22469 .29531 L p F P
0 g
s
.195 .647 .944 r
.27597 .44947 m .27865 .4498 L .27329 .44808 L closepath p F P
0 g
s
.663 .138 0 r
.31436 .34777 m .31082 .34486 L .31702 .34691 L p F P
0 g
s
.663 .138 0 r
.31747 .34874 m .31436 .34777 L p .31702 .34691 L F P
0 g
s
.663 .138 0 r
.31702 .34691 m .31907 .34845 L .31747 .34874 L p F P
0 g
s
0 .173 .606 r
.1573 .39565 m .16142 .39847 L .15751 .39571 L p F P
0 g
s
0 .173 .606 r
.15751 .39571 m .15401 .39333 L .1535 .39299 L p F P
0 g
s
0 .173 .606 r
.1535 .39299 m .1573 .39565 L p .15751 .39571 L F P
0 g
s
.418 0 .111 r
.47008 .35982 m .4651 .36084 L .46347 .36327 L p F P
0 g
s
.303 .712 .976 r
.31721 .45845 m .31626 .45796 L .31502 .45792 L closepath p F P
0 g
s
.582 .15 .184 r
.41612 .36778 m .4152 .36895 L .41244 .36778 L closepath p F P
0 g
s
.583 .143 .169 r
.41434 .37016 m .4152 .36895 L .41244 .36778 L p F P
0 g
s
.583 .143 .169 r
.40608 .37011 m .41434 .37016 L p .41244 .36778 L F P
0 g
s
.583 .143 .169 r
.40265 .36841 m .40608 .37011 L p .41244 .36778 L F P
0 g
s
.583 .143 .169 r
.41244 .36778 m .40325 .36769 L .40265 .36841 L p F P
0 g
s
.667 .167 .049 r
.33489 .35383 m .33444 .35401 L .33386 .35358 L closepath p F P
0 g
s
.555 .119 .167 r
.42515 .36746 m .41612 .36778 L .4152 .36895 L p F P
0 g
s
.326 .601 .946 r
.19123 .27431 m .18902 .27391 L .19253 .2771 L p F P
0 g
s
.326 .601 .946 r
.19253 .2771 m .19437 .27742 L .19123 .27431 L p F P
0 g
s
.026 0 .216 r
.72479 .33285 m .72448 .33489 L .72597 .3316 L closepath p F P
0 g
s
.553 .932 .89 r
.61042 .42584 m .61152 .42579 L .60251 .43048 L p F P
0 g
s
.553 .932 .89 r
.60251 .43048 m .60037 .4306 L .61042 .42584 L p F P
0 g
s
.641 .091 0 r
.29921 .34045 m .29562 .33758 L .30134 .33982 L p F P
0 g
s
.641 .091 0 r
.30223 .34157 m .29921 .34045 L p .30134 .33982 L F P
0 g
s
.641 .091 0 r
.30134 .33982 m .30376 .3416 L .30223 .34157 L p F P
0 g
s
.604 .167 .184 r
.40325 .36769 m .40265 .36841 L .40109 .36762 L closepath p F P
0 g
s
.72 .824 .93 r
.68071 .25449 m .67498 .25722 L .6726 .25493 L p F P
0 g
s
.741 .83 .919 r
.66252 .26037 m .6726 .25493 L .67498 .25722 L p F P
0 g
s
.295 0 0 r
.49793 .35179 m .49869 .35078 L .48834 .35372 L p F P
0 g
s
.295 0 0 r
.48834 .35372 m .48804 .35411 L .49793 .35179 L p F P
0 g
s
.616 .17 .17 r
.39014 .36675 m .39075 .36709 L .38987 .36703 L closepath p F P
0 g
s
.322 .221 .582 r
.73884 .30126 m .73846 .30171 L .73692 .29792 L p F P
0 g
s
.322 .221 .582 r
.73692 .29792 m .73815 .29646 L .73884 .30126 L p F P
0 g
s
.137 .6 .924 r
.25741 .44301 m .25271 .44215 L .2583 .44434 L p F P
0 g
s
.137 .6 .924 r
.2583 .44434 m .26053 .44475 L .25741 .44301 L p F P
0 g
s
.63 .665 .865 r
.71591 .25458 m .7127 .25523 L .71029 .25124 L p F P
0 g
s
0 0 0 r
.67586 .38776 m .66756 .39402 L .66715 .39435 L p F P
0 g
s
.604 .176 .202 r
.39527 .36975 m .39075 .36709 L .40109 .36762 L p F P
0 g
s
.604 .176 .202 r
.40139 .37002 m .39527 .36975 L p .40109 .36762 L F P
0 g
s
.604 .176 .202 r
.40109 .36762 m .40265 .36841 L .40139 .37002 L p F P
0 g
s
.759 .943 .941 r
.63007 .27694 m .63005 .27693 L .63012 .27689 L closepath p F P
0 g
s
.528 .525 .795 r
.728 .2636 m .73612 .26436 L .73211 .26996 L p F P
0 g
s
.503 .49 .775 r
.74038 .26996 m .73901 .27182 L .73211 .26996 L p F P
0 g
s
.503 .49 .775 r
.73861 .26485 m .74038 .26996 L p .73211 .26996 L F P
0 g
s
.503 .49 .775 r
.73211 .26996 m .73612 .26436 L .73861 .26485 L p F P
0 g
s
.749 .958 .939 r
.63012 .27689 m .63005 .27693 L .62766 .27622 L p F P
0 g
s
.764 .959 .933 r
.63012 .27689 m .64006 .27069 L .63768 .26963 L p F P
0 g
s
.764 .959 .933 r
.63768 .26963 m .63662 .27033 L .63012 .27689 L p F P
0 g
s
.749 .958 .939 r
.62766 .27622 m .63662 .27033 L .63012 .27689 L p F P
0 g
s
0 0 0 r
.70714 .35788 m .70521 .36023 L .70674 .35886 L closepath p F P
0 g
s
.667 .168 .051 r
.33061 .3547 m .32701 .35178 L .33386 .35358 L p F P
0 g
s
.667 .168 .051 r
.33189 .35503 m .33061 .3547 L p .33386 .35358 L F P
0 g
s
.667 .168 .051 r
.33386 .35358 m .33444 .35401 L .33189 .35503 L p F P
0 g
s
.401 0 0 r
.24296 .30699 m .24569 .30877 L .2501 .31155 L p F P
0 g
s
.402 0 0 r
.24569 .30877 m .24296 .30699 L .23983 .30483 L p F P
0 g
s
.943 .608 .363 r
.09748 .33241 m .09744 .33211 L .09416 .32902 L p F P
0 g
s
0 .212 .625 r
.1718 .40526 m .17415 .40666 L .17854 .40936 L p F P
0 g
s
0 .27 .685 r
.17882 .40919 m .18318 .4119 L .17854 .40936 L p F P
0 g
s
0 .27 .685 r
.17854 .40936 m .17415 .40666 L .17882 .40919 L p F P
0 g
s
.674 .14 0 r
.13866 .38099 m .13885 .38119 L .13765 .38028 L closepath p F P
0 g
s
.44 .79 .997 r
.37887 .46323 m .38178 .46473 L .37762 .46513 L p F P
0 g
s
.44 .79 .997 r
.36923 .46423 m .37887 .46323 L p .37762 .46513 L F P
0 g
s
.44 .79 .997 r
.37762 .46513 m .36973 .46447 L .36923 .46423 L p F P
0 g
s
.557 .127 .18 r
.42853 .36733 m .42779 .36834 L .42515 .36746 L closepath p F P
0 g
s
.555 .119 .167 r
.42682 .36977 m .42779 .36834 L .42515 .36746 L p F P
0 g
s
.555 .119 .167 r
.41805 .37006 m .42682 .36977 L p .42515 .36746 L F P
0 g
s
.555 .119 .167 r
.4152 .36895 m .41805 .37006 L p .42515 .36746 L F P
0 g
s
.541 .901 .97 r
.54273 .44963 m .53277 .45287 L .53016 .4523 L p F P
0 g
s
.521 .892 .969 r
.52021 .45533 m .53016 .4523 L .53277 .45287 L p F P
0 g
s
.204 .061 .453 r
.73893 .31023 m .73395 .31606 L .73411 .31166 L p F P
0 g
s
.204 .061 .453 r
.73411 .31166 m .7391 .30582 L .73893 .31023 L p F P
0 g
s
.514 0 0 r
.27446 .3256 m .27329 .32518 L .27252 .32468 L closepath p F P
0 g
s
.669 .975 .851 r
.60525 .28955 m .60767 .28943 L .5977 .29597 L p F P
0 g
s
.669 .975 .851 r
.60355 .29071 m .60525 .28955 L p .5977 .29597 L F P
0 g
s
.669 .975 .851 r
.5977 .29597 m .59702 .29609 L .60355 .29071 L p F P
0 g
s
.02 .522 .871 r
.23285 .43551 m .23448 .43595 L .23043 .43417 L closepath p F P
0 g
s
.063 0 0 r
.5304 .33672 m .53156 .33546 L .52204 .3395 L p F P
0 g
s
.063 0 0 r
.52204 .3395 m .52045 .34126 L .5304 .33672 L p F P
0 g
s
0 0 .02 r
.71659 .34792 m .71534 .34918 L .71621 .34645 L p F P
0 g
s
0 0 .02 r
.71621 .34645 m .72039 .34224 L .71659 .34792 L p F P
0 g
s
.517 .842 .998 r
.44948 .46479 m .44703 .46503 L .44466 .46399 L p F P
0 g
s
.382 0 0 r
.24978 .31136 m .25437 .31408 L .2501 .31155 L p F P
0 g
s
.382 0 0 r
.2501 .31155 m .24569 .30877 L .24978 .31136 L p F P
0 g
s
.524 .091 .159 r
.43985 .36644 m .42853 .36733 L .42779 .36834 L p F P
0 g
s
.463 .036 .142 r
.453 .36382 m .45843 .36405 L .45217 .36505 L closepath p F P
0 g
s
.51 .912 .888 r
.59034 .43511 m .58575 .43706 L .59003 .43512 L closepath p F P
0 g
s
.543 .923 .92 r
.58786 .43503 m .59003 .43512 L .58575 .43706 L p F P
0 g
s
.543 .923 .92 r
.57783 .43923 m .58786 .43503 L p .58575 .43706 L F P
0 g
s
.943 .608 .363 r
.09416 .32902 m .09418 .32916 L .09748 .33241 L p F P
0 g
s
.932 .56 .272 r
.09504 .33292 m .09835 .33617 L .09748 .33241 L p F P
0 g
s
.932 .56 .272 r
.09748 .33241 m .09418 .32916 L .09504 .33292 L p F P
0 g
s
.912 .51 .195 r
.09952 .33981 m .10289 .34302 L .10172 .33937 L p F P
0 g
s
.912 .51 .195 r
.10172 .33937 m .09835 .33617 L .09952 .33981 L p F P
0 g
s
.592 .019 0 r
.28496 .33279 m .28121 .33 L .28655 .33239 L p F P
0 g
s
.592 .019 0 r
.2859 .33319 m .28496 .33279 L p .28655 .33239 L F P
0 g
s
.592 .019 0 r
.28655 .33239 m .2885 .33375 L .2859 .33319 L p F P
0 g
s
.469 .88 .744 r
.63526 .41445 m .63237 .41608 L .63488 .41459 L closepath p F P
0 g
s
.51 .909 .8 r
.63292 .41505 m .63488 .41459 L .63237 .41608 L p F P
0 g
s
.51 .909 .8 r
.6269 .41836 m .63292 .41505 L p .63237 .41608 L F P
0 g
s
.51 .909 .8 r
.6234 .42043 m .6269 .41836 L p .63237 .41608 L F P
0 g
s
0 0 0 r
.5393 .33074 m .53298 .33395 L .53156 .33546 L p F P
0 g
s
.313 .713 .979 r
.31324 .45634 m .30818 .45619 L .31502 .45792 L p F P
0 g
s
.313 .713 .979 r
.31502 .45792 m .31626 .45796 L .31324 .45634 L p F P
0 g
s
.545 0 0 r
.13815 .38124 m .14203 .38418 L .13885 .38119 L p F P
0 g
s
.545 0 0 r
.13538 .37863 m .13815 .38124 L p .13885 .38119 L F P
0 g
s
.545 0 0 r
.13885 .38119 m .13765 .38028 L .13538 .37863 L p F P
0 g
s
0 0 0 r
.7055 .36115 m .69946 .36657 L .70521 .36023 L p F P
0 g
s
0 0 0 r
.70521 .36023 m .70674 .35886 L .7055 .36115 L p F P
0 g
s
.522 .541 .817 r
.72729 .26202 m .728 .2636 L .73612 .26436 L p F P
0 g
s
0 .217 .637 r
.17415 .40666 m .1718 .40526 L .16855 .40317 L p F P
0 g
s
.51 .845 .997 r
.45875 .46382 m .45726 .46319 L .44948 .46479 L closepath p F P
0 g
s
.517 .842 .998 r
.45449 .46195 m .45726 .46319 L .44948 .46479 L p F P
0 g
s
.517 .842 .998 r
.44466 .46399 m .45449 .46195 L p .44948 .46479 L F P
0 g
s
.886 .456 .116 r
.10436 .34658 m .10779 .34975 L .10633 .34619 L p F P
0 g
s
.886 .456 .116 r
.10633 .34619 m .10289 .34302 L .10436 .34658 L p F P
0 g
s
.625 .189 .192 r
.38791 .36927 m .39527 .36975 L .39075 .36709 L p F P
0 g
s
.625 .189 .192 r
.39075 .36709 m .38987 .36703 L .38791 .36927 L p F P
0 g
s
.538 .885 .984 r
.51757 .45462 m .519 .45504 L .50851 .45773 L p F P
0 g
s
.538 .885 .984 r
.50851 .45773 m .50763 .45748 L .51757 .45462 L p F P
0 g
s
.638 .205 .202 r
.38535 .36906 m .38791 .36927 L .38987 .36703 L p F P
0 g
s
.638 .205 .202 r
.38987 .36703 m .38111 .36631 L .38535 .36906 L p F P
0 g
s
.531 .917 .924 r
.57705 .4392 m .57783 .43923 L .56783 .44319 L p F P
0 g
s
.531 .917 .924 r
.56783 .44319 m .56754 .44318 L .57705 .4392 L p F P
0 g
s
.403 .773 .993 r
.35671 .46343 m .35947 .46325 L .36821 .4643 L p F P
0 g
s
.402 .773 .993 r
.35671 .46343 m .35947 .46325 L .35531 .46275 L closepath p F P
0 g
s
.434 .643 .945 r
.17599 .26606 m .17531 .26602 L .17863 .26931 L p F P
0 g
s
.434 .643 .945 r
.17863 .26931 m .17914 .26934 L .17599 .26606 L p F P
0 g
s
.697 .21 .086 r
.33444 .35401 m .33736 .35654 L .33189 .35503 L closepath p F P
0 g
s
0 0 0 r
.57316 .31069 m .57532 .30952 L .56535 .31569 L p F P
0 g
s
0 0 0 r
.56535 .31569 m .56463 .31616 L .57316 .31069 L p F P
0 g
s
.327 0 .05 r
.49707 .35311 m .49793 .35179 L .48804 .35411 L p F P
0 g
s
.327 0 .05 r
.48804 .35411 m .4867 .35608 L .49707 .35311 L p F P
0 g
s
.854 .398 .037 r
.10953 .35321 m .11303 .35635 L .11129 .35288 L p F P
0 g
s
.854 .398 .037 r
.11129 .35288 m .10779 .34975 L .10953 .35321 L p F P
0 g
s
0 .415 .851 r
.20954 .28613 m .2115 .28702 L .21527 .29009 L p F P
0 g
s
.001 .428 .86 r
.21651 .28921 m .22039 .29223 L .21527 .29009 L p F P
0 g
s
.001 .428 .86 r
.21527 .29009 m .2115 .28702 L .21651 .28921 L p F P
0 g
s
0 0 0 r
.67535 .38818 m .67722 .38673 L .67586 .38776 L p F P
0 g
s
0 0 0 r
.67498 .38847 m .67535 .38818 L p .67586 .38776 L F P
0 g
s
0 0 0 r
.66715 .39435 m .67498 .38847 L p .67586 .38776 L F P
0 g
s
0 0 0 r
.67753 .38643 m .67586 .38776 L .67722 .38673 L closepath p F P
0 g
s
.414 0 .095 r
.47605 .35864 m .47543 .35953 L .47008 .35982 L closepath p F P
0 g
s
.418 0 .111 r
.47446 .3611 m .47543 .35953 L .47008 .35982 L p F P
0 g
s
.418 0 .111 r
.46347 .36327 m .47446 .3611 L p .47008 .35982 L F P
0 g
s
.749 .895 .944 r
.66015 .25854 m .66153 .2596 L .65938 .26214 L p F P
0 g
s
.749 .895 .944 r
.65009 .26453 m .66015 .25854 L p .65938 .26214 L F P
0 g
s
.752 .871 .934 r
.66252 .26037 m .65938 .26214 L .66153 .2596 L closepath p F P
0 g
s
.412 .777 .995 r
.36973 .46447 m .36923 .46423 L .36821 .4643 L closepath p F P
0 g
s
.682 .211 .128 r
.34811 .36117 m .35567 .36271 L .35199 .3598 L p F P
0 g
s
.682 .211 .128 r
.34673 .35995 m .34811 .36117 L p .35199 .3598 L F P
0 g
s
.682 .211 .128 r
.35199 .3598 m .3483 .35901 L .34673 .35995 L p F P
0 g
s
.749 .974 .924 r
.61886 .28305 m .61766 .28284 L .62246 .27966 L closepath p F P
0 g
s
0 0 0 r
.68494 .38029 m .67753 .38643 L .67722 .38673 L p F P
0 g
s
.14 0 .381 r
.73308 .32071 m .7323 .3216 L .73238 .31787 L p F P
0 g
s
.14 0 .381 r
.73238 .31787 m .73395 .31606 L .73308 .32071 L p F P
0 g
s
.561 .574 .824 r
.72551 .2582 m .72994 .25806 L .72729 .26202 L closepath p F P
0 g
s
.522 .541 .817 r
.73605 .25826 m .72994 .25806 L .72729 .26202 L p F P
0 g
s
.522 .541 .817 r
.73764 .26225 m .73605 .25826 L p .72729 .26202 L F P
0 g
s
.522 .541 .817 r
.73612 .26436 m .73764 .26225 L p .72729 .26202 L F P
0 g
s
.503 .886 .703 r
.65673 .40153 m .65532 .40221 L .66346 .39677 L closepath p F P
0 g
s
.498 .895 .752 r
.64344 .40917 m .64529 .40853 L .63526 .41445 L p F P
0 g
s
.498 .895 .752 r
.63526 .41445 m .63488 .41459 L .64344 .40917 L p F P
0 g
s
.304 .583 .94 r
.17914 .26934 m .18561 .27066 L .18902 .27391 L p F P
0 g
s
.307 .581 .938 r
.18561 .27066 m .17914 .26934 L .17599 .26606 L p F P
0 g
s
.425 .775 .996 r
.36631 .46269 m .35947 .46325 L .36821 .4643 L p F P
0 g
s
.425 .775 .996 r
.36821 .4643 m .36923 .46423 L .36631 .46269 L p F P
0 g
s
0 .457 .826 r
.21749 .42918 m .21768 .42925 L .21717 .429 L closepath p F P
0 g
s
.503 0 0 r
.25811 .31618 m .25895 .31679 L .25618 .31509 L closepath p F P
0 g
s
0 0 0 r
.70517 .36163 m .7055 .36115 L .69946 .36657 L p F P
0 g
s
0 0 0 r
.70025 .36667 m .70517 .36163 L p .69946 .36657 L F P
0 g
s
0 0 0 r
.6964 .37013 m .70025 .36667 L p .69946 .36657 L F P
0 g
s
0 0 0 r
.69946 .36657 m .69735 .36872 L .6964 .37013 L p F P
0 g
s
.504 0 0 r
.27015 .32397 m .26748 .32216 L .27252 .32468 L p F P
0 g
s
.504 0 0 r
.27252 .32468 m .27329 .32518 L .27015 .32397 L p F P
0 g
s
.365 .735 .989 r
.32573 .45798 m .31626 .45796 L .31324 .45634 L p F P
0 g
s
.022 0 .214 r
.72911 .3308 m .73148 .32562 L .72597 .3316 L p F P
0 g
s
.022 0 .214 r
.72429 .33605 m .72911 .3308 L p .72597 .3316 L F P
0 g
s
.022 0 .214 r
.72597 .3316 m .72448 .33489 L .72429 .33605 L p F P
0 g
s
0 0 0 r
.69735 .36872 m .69272 .37325 L .6964 .37013 L closepath p F P
0 g
s
.05 .53 .889 r
.21926 .42872 m .22421 .43118 L .21768 .42925 L p F P
0 g
s
.05 .53 .889 r
.21431 .42727 m .21926 .42872 L p .21768 .42925 L F P
0 g
s
.05 .53 .889 r
.21768 .42925 m .21717 .429 L .21431 .42727 L p F P
0 g
s
.479 .857 .638 r
.66715 .39435 m .66534 .39546 L .67498 .38847 L closepath p F P
0 g
s
.528 .099 .169 r
.44051 .36639 m .44039 .36656 L .43985 .36644 L closepath p F P
0 g
s
.524 .091 .159 r
.4389 .3689 m .44039 .36656 L .43985 .36644 L p F P
0 g
s
.524 .091 .159 r
.43167 .36943 m .4389 .3689 L p .43985 .36644 L F P
0 g
s
.524 .091 .159 r
.42779 .36834 m .43167 .36943 L p .43985 .36644 L F P
0 g
s
.81 .328 0 r
.11427 .35841 m .11303 .35635 L .11659 .35945 L p F P
0 g
s
.81 .328 0 r
.11659 .35945 m .11757 .36106 L .11427 .35841 L p F P
0 g
s
.562 .922 .948 r
.57532 .43897 m .57705 .4392 L .56754 .44318 L p F P
0 g
s
.562 .922 .948 r
.56754 .44318 m .56529 .4429 L .57532 .43897 L p F P
0 g
s
.522 .907 .759 r
.64599 .40828 m .64529 .40853 L .64964 .40585 L closepath p F P
0 g
s
.532 .893 .975 r
.52929 .45209 m .53016 .4523 L .52021 .45533 L p F P
0 g
s
.532 .893 .975 r
.52021 .45533 m .519 .45504 L .52929 .45209 L p F P
0 g
s
.507 .076 .156 r
.45058 .36756 m .45217 .36505 L .44051 .36639 L p F P
0 g
s
.507 .076 .156 r
.44796 .36785 m .45058 .36756 L p .44051 .36639 L F P
0 g
s
.507 .076 .156 r
.44051 .36639 m .44039 .36656 L .44796 .36785 L p F P
0 g
s
0 .302 .707 r
.18695 .41419 m .18768 .41455 L .18515 .41309 L closepath p F P
0 g
s
.422 .633 .943 r
.16385 .26206 m .1721 .26268 L .17531 .26602 L p F P
0 g
s
.155 .512 .914 r
.19437 .27742 m .19862 .27883 L .2022 .28198 L p F P
0 g
s
.159 .508 .912 r
.19862 .27883 m .19437 .27742 L .19123 .27431 L p F P
0 g
s
.177 0 0 r
.52023 .34153 m .52045 .34126 L .51051 .34511 L p F P
0 g
s
.177 0 0 r
.51051 .34511 m .51043 .34521 L .52023 .34153 L p F P
0 g
s
0 .175 .603 r
.16529 .401 m .16142 .39847 L .16561 .40126 L p F P
0 g
s
0 .175 .603 r
.16561 .40126 m .16855 .40317 L .16529 .401 L p F P
0 g
s
0 .398 .788 r
.20229 .42218 m .20219 .42211 L .20214 .42209 L closepath p F P
0 g
s
0 0 0 r
.68746 .37806 m .68494 .38029 L .68697 .37866 L closepath p F P
0 g
s
0 0 0 r
.68533 .38023 m .68697 .37866 L .68494 .38029 L p F P
0 g
s
0 0 0 r
.6847 .38076 m .68533 .38023 L p .68494 .38029 L F P
0 g
s
0 0 0 r
.67722 .38673 m .6847 .38076 L p .68494 .38029 L F P
0 g
s
.619 .081 0 r
.13765 .38028 m .13538 .37863 L .13499 .37824 L closepath p F P
0 g
s
.644 .197 .176 r
.37613 .36812 m .38535 .36906 L .38111 .36631 L p F P
0 g
s
.644 .197 .176 r
.37462 .36701 m .37613 .36812 L p .38111 .36631 L F P
0 g
s
.644 .197 .176 r
.38111 .36631 m .37592 .36574 L .37462 .36701 L p F P
0 g
s
0 0 0 r
.69272 .37325 m .68746 .37806 L .68697 .37866 L p F P
0 g
s
0 0 0 r
.69528 .37145 m .6964 .37013 L .69272 .37325 L p F P
0 g
s
0 0 0 r
.69303 .37353 m .69528 .37145 L p .69272 .37325 L F P
0 g
s
0 0 0 r
.68697 .37866 m .69303 .37353 L p .69272 .37325 L F P
0 g
s
0 .404 .798 r
.19898 .42011 m .1975 .41951 L .20214 .42209 L p F P
0 g
s
0 .404 .798 r
.20214 .42209 m .20219 .42211 L .19898 .42011 L p F P
0 g
s
0 .338 .764 r
.23669 .30257 m .23285 .30058 L .23705 .30345 L p F P
0 g
s
0 .338 .764 r
.23705 .30345 m .23983 .30483 L .23669 .30257 L p F P
0 g
s
.297 .204 .578 r
.74291 .29603 m .73884 .30126 L .73815 .29646 L p F P
0 g
s
.297 .204 .578 r
.73815 .29646 m .74144 .29221 L .74291 .29603 L p F P
0 g
s
.63 .665 .865 r
.71029 .25124 m .72019 .24883 L .71591 .25458 L p F P
0 g
s
.609 .633 .85 r
.72062 .24873 m .72019 .24883 L .71591 .25458 L p F P
0 g
s
.609 .633 .85 r
.71591 .25458 m .72306 .25328 L .72062 .24873 L p F P
0 g
s
0 .444 .83 r
.20801 .42424 m .20219 .42211 L .19898 .42011 L p F P
0 g
s
.723 .982 .908 r
.60784 .28944 m .60767 .28943 L .60842 .28893 L closepath p F P
0 g
s
.601 .173 .2 r
.40265 .36841 m .40608 .37011 L .40139 .37002 L closepath p F P
0 g
s
0 .469 .844 r
.21717 .429 m .21431 .42727 L .2128 .42676 L closepath p F P
0 g
s
.121 .581 .919 r
.23649 .43531 m .24168 .43768 L .23448 .43595 L p F P
0 g
s
.121 .581 .919 r
.22969 .43373 m .23649 .43531 L p .23448 .43595 L F P
0 g
s
.121 .581 .919 r
.23448 .43595 m .23043 .43417 L .22969 .43373 L p F P
0 g
s
.193 0 0 r
.51857 .34375 m .52023 .34153 L .51043 .34521 L p F P
0 g
s
.193 0 0 r
.51043 .34521 m .50876 .34745 L .51857 .34375 L p F P
0 g
s
.718 .798 .914 r
.6851 .25239 m .68071 .25449 L .68348 .2506 L closepath p F P
0 g
s
.72 .824 .93 r
.68272 .24977 m .68348 .2506 L .68071 .25449 L p F P
0 g
s
.72 .824 .93 r
.6726 .25493 m .68272 .24977 L p .68071 .25449 L F P
0 g
s
.533 0 0 r
.14544 .3871 m .14937 .39001 L .14598 .38708 L p F P
0 g
s
.533 0 0 r
.14598 .38708 m .14203 .38418 L .14544 .3871 L p F P
0 g
s
.752 .871 .934 r
.67023 .25279 m .6726 .25493 L .66252 .26037 L p F P
0 g
s
.752 .871 .934 r
.6645 .25606 m .67023 .25279 L p .66252 .26037 L F P
0 g
s
.752 .871 .934 r
.66252 .26037 m .66153 .2596 L .6645 .25606 L p F P
0 g
s
.553 .908 .967 r
.55273 .44617 m .55381 .44639 L .54392 .44987 L p F P
0 g
s
.553 .908 .967 r
.54392 .44987 m .54273 .44963 L .55273 .44617 L p F P
0 g
s
.524 .85 .997 r
.46747 .46271 m .45875 .46382 L .45726 .46319 L p F P
0 g
s
.461 .79 .999 r
.37887 .46323 m .36923 .46423 L .36631 .46269 L p F P
0 g
s
.513 .095 .185 r
.44039 .36656 m .44796 .36785 L .4389 .3689 L closepath p F P
0 g
s
.267 .68 .968 r
.28227 .4488 m .28528 .45046 L .27865 .4498 L p F P
0 g
s
.267 .68 .968 r
.28214 .44875 m .28227 .4488 L p .27865 .4498 L F P
0 g
s
.267 .68 .968 r
.27288 .44785 m .28214 .44875 L p .27865 .4498 L F P
0 g
s
.267 .68 .968 r
.27865 .4498 m .27329 .44808 L .27288 .44785 L p F P
0 g
s
.194 .634 .946 r
.26674 .44568 m .26053 .44475 L .25741 .44301 L p F P
0 g
s
.675 .202 .121 r
.3483 .35901 m .34673 .35995 L .34452 .35823 L closepath p F P
0 g
s
.535 .924 .891 r
.5992 .43065 m .60037 .4306 L .59034 .43511 L p F P
0 g
s
.535 .924 .891 r
.59034 .43511 m .59003 .43512 L .5992 .43065 L p F P
0 g
s
.666 .974 .847 r
.59702 .29609 m .59526 .2964 L .60355 .29071 L closepath p F P
0 g
s
.793 .302 0 r
.11757 .36106 m .1187 .36279 L .12235 .36585 L p F P
0 g
s
.732 .221 0 r
.12116 .36601 m .12481 .36907 L .12235 .36585 L p F P
0 g
s
.732 .221 0 r
.12235 .36585 m .1187 .36279 L .12116 .36601 L p F P
0 g
s
0 0 0 r
.70659 .36011 m .7055 .36115 L .70674 .35886 L p F P
0 g
s
0 0 0 r
.70674 .35886 m .71196 .35389 L .70659 .36011 L p F P
0 g
s
.695 .981 .886 r
.60842 .28893 m .60767 .28943 L .60525 .28955 L p F P
0 g
s
.001 .451 .865 r
.2256 .29603 m .22469 .29531 L .2244 .2952 L closepath p F P
0 g
s
.708 .193 0 r
.30825 .34568 m .31436 .34777 L .31082 .34486 L p F P
0 g
s
.708 .193 0 r
.31082 .34486 m .30497 .34268 L .30825 .34568 L p F P
0 g
s
.537 .925 .852 r
.62048 .42084 m .62287 .42051 L .61283 .4256 L p F P
0 g
s
.537 .925 .852 r
.61972 .42122 m .62048 .42084 L p .61283 .4256 L F P
0 g
s
.537 .925 .852 r
.61283 .4256 m .61152 .42579 L .61972 .42122 L p F P
0 g
s
.272 .687 .969 r
.30035 .45423 m .30077 .45445 L p .28835 .45213 L F P
0 g
s
.272 .687 .969 r
.28835 .45213 m .29486 .45259 L .30035 .45423 L p F P
0 g
s
.286 .692 .973 r
.29486 .45259 m .28835 .45213 L .28528 .45046 L p F P
0 g
s
.451 .821 .566 r
.67722 .38673 m .67535 .38818 L .6847 .38076 L closepath p F P
0 g
s
.758 .935 .943 r
.64634 .26683 m .64006 .27069 L .63768 .26963 L p F P
0 g
s
.188 .534 .924 r
.20326 .28025 m .19862 .27883 L .2022 .28198 L p F P
0 g
s
.188 .534 .924 r
.2022 .28198 m .20641 .28323 L .20326 .28025 L p F P
0 g
s
.709 .218 .077 r
.32391 .35283 m .33061 .3547 L .32701 .35178 L p F P
0 g
s
.709 .218 .077 r
.32701 .35178 m .32061 .34981 L .32391 .35283 L p F P
0 g
s
.646 .088 0 r
.27612 .3275 m .27329 .32518 L .27015 .32397 L p F P
0 g
s
.651 .206 .181 r
.37592 .36574 m .37462 .36701 L .37215 .36529 L closepath p F P
0 g
s
.548 .927 .814 r
.64297 .40928 m .64344 .40917 L .63488 .41459 L p F P
0 g
s
.548 .927 .814 r
.63488 .41459 m .63292 .41505 L .64297 .40928 L p F P
0 g
s
.669 .212 .158 r
.3622 .3629 m .36373 .36407 L .36124 .36365 L closepath p F P
0 g
s
.731 .98 .914 r
.61766 .28284 m .60842 .28893 L .61552 .28264 L closepath p F P
0 g
s
.695 .981 .886 r
.61525 .28262 m .61552 .28264 L .60842 .28893 L p F P
0 g
s
.695 .981 .886 r
.60525 .28955 m .61525 .28262 L p .60842 .28893 L F P
0 g
s
0 .41 .85 r
.2115 .28702 m .20954 .28613 L .20641 .28323 L p F P
0 g
s
0 .404 .803 r
.18843 .41424 m .19293 .41689 L .18768 .41455 L p F P
0 g
s
0 .404 .803 r
.18371 .41216 m .18843 .41424 L p .18768 .41455 L F P
0 g
s
0 .404 .803 r
.18768 .41455 m .18515 .41309 L .18371 .41216 L p F P
0 g
s
.543 0 0 r
.25804 .31685 m .26266 .31955 L .25895 .31679 L p F P
0 g
s
.543 0 0 r
.25498 .31444 m .25804 .31685 L p .25895 .31679 L F P
0 g
s
.543 0 0 r
.25895 .31679 m .25618 .31509 L .25498 .31444 L p F P
0 g
s
0 0 0 r
.54293 .32892 m .5393 .33074 L .54269 .32915 L closepath p F P
0 g
s
0 0 0 r
.54083 .33103 m .54269 .32915 L .5393 .33074 L p F P
0 g
s
0 0 0 r
.53156 .33546 m .54083 .33103 L p .5393 .33074 L F P
0 g
s
.374 0 .072 r
.48531 .35817 m .4867 .35608 L .47605 .35864 L p F P
0 g
s
.374 0 .072 r
.47605 .35864 m .47543 .35953 L .48531 .35817 L p F P
0 g
s
.602 .947 .797 r
.58624 .3028 m .58529 .30309 L .59031 .29971 L closepath p F P
0 g
s
.703 .196 .026 r
.31907 .34845 m .32061 .34981 L .31747 .34874 L closepath p F P
0 g
s
.359 .288 .639 r
.74488 .28778 m .74144 .29221 L .73903 .28874 L p F P
0 g
s
.359 .288 .639 r
.74415 .28403 m .74488 .28778 L p .73903 .28874 L F P
0 g
s
.359 .288 .639 r
.73903 .28874 m .74341 .28305 L .74415 .28403 L p F P
0 g
s
.548 .884 .988 r
.51757 .45462 m .50763 .45748 L .50496 .45662 L p F P
0 g
s
.53 .877 .987 r
.49505 .45929 m .50496 .45662 L .50763 .45748 L p F P
0 g
s
.441 .781 .998 r
.36337 .46109 m .36631 .46269 L .35947 .46325 L p F P
0 g
s
.441 .781 .998 r
.35376 .46193 m .36337 .46109 L p .35947 .46325 L F P
0 g
s
.441 .781 .998 r
.35947 .46325 m .35531 .46275 L .35376 .46193 L p F P
0 g
s
.686 .147 0 r
.29355 .33818 m .29921 .34045 L .29562 .33758 L p F P
0 g
s
.686 .147 0 r
.29562 .33758 m .29019 .33522 L .29355 .33818 L p F P
0 g
s
.296 .708 .974 r
.30077 .45445 m .3013 .45447 L .30818 .45619 L p F P
0 g
s
.326 .716 .982 r
.31021 .45467 m .3013 .45447 L .30818 .45619 L p F P
0 g
s
.326 .716 .982 r
.30818 .45619 m .31324 .45634 L .31021 .45467 L p F P
0 g
s
.574 .151 .2 r
.4152 .36895 m .41805 .37006 L .41434 .37016 L closepath p F P
0 g
s
.463 0 0 r
.15401 .39333 m .1535 .39299 L .15338 .39289 L closepath p F P
0 g
s
.545 .125 .195 r
.42779 .36834 m .43167 .36943 L .42682 .36977 L closepath p F P
0 g
s
.7 .754 .894 r
.6851 .25239 m .69527 .24795 L .69765 .2511 L p F P
0 g
s
.668 .704 .874 r
.69765 .2511 m .70789 .2475 L .71029 .25124 L p F P
0 g
s
.681 .724 .882 r
.70789 .2475 m .69765 .2511 L .69527 .24795 L p F P
0 g
s
.48 .798 1 r
.39145 .46355 m .38178 .46473 L .37887 .46323 L p F P
0 g
s
.106 .581 .911 r
.2451 .43951 m .24715 .43993 L .25271 .44215 L p F P
0 g
s
.147 .603 .929 r
.25429 .44122 m .24715 .43993 L .25271 .44215 L p F P
0 g
s
.147 .603 .929 r
.25271 .44215 m .25741 .44301 L .25429 .44122 L p F P
0 g
s
.546 .914 .951 r
.56351 .44265 m .56529 .4429 L .55529 .44659 L p F P
0 g
s
.546 .914 .951 r
.55529 .44659 m .55381 .44639 L .56351 .44265 L p F P
0 g
s
.049 0 .223 r
.72448 .33489 m .72358 .33678 L .72429 .33605 L closepath p F P
0 g
s
.522 .902 .734 r
.57543 .30947 m .57532 .30952 L .576 .30907 L closepath p F P
0 g
s
.569 .933 .923 r
.59792 .43059 m .5992 .43065 L .59003 .43512 L p F P
0 g
s
.569 .933 .923 r
.59003 .43512 m .58786 .43503 L .59792 .43059 L p F P
0 g
s
.65 .21 .192 r
.36741 .367 m .36373 .36407 L .37215 .36529 L p F P
0 g
s
.65 .21 .192 r
.3738 .36784 m .36741 .367 L p .37215 .36529 L F P
0 g
s
.65 .21 .192 r
.37215 .36529 m .37462 .36701 L .3738 .36784 L p F P
0 g
s
.578 .577 .816 r
.72994 .25806 m .72551 .2582 L .72306 .25328 L p F P
0 g
s
.675 .204 .125 r
.34079 .35953 m .33736 .35654 L .34452 .35823 L p F P
0 g
s
.675 .204 .125 r
.34568 .36061 m .34079 .35953 L p .34452 .35823 L F P
0 g
s
.675 .204 .125 r
.34452 .35823 m .34673 .35995 L .34568 .36061 L p F P
0 g
s
.671 .122 0 r
.2885 .33375 m .29019 .33522 L .2859 .33319 L closepath p F P
0 g
s
.685 .161 0 r
.1275 .37222 m .13121 .37525 L .12852 .37209 L p F P
0 g
s
.685 .161 0 r
.12852 .37209 m .12481 .36907 L .1275 .37222 L p F P
0 g
s
.374 .747 .99 r
.34029 .46041 m .34123 .4609 L p .32873 .45955 L F P
0 g
s
.374 .747 .99 r
.32873 .45955 m .33513 .4594 L .34029 .46041 L p F P
0 g
s
.39 .752 .993 r
.33513 .4594 m .32873 .45955 L .32573 .45798 L p F P
0 g
s
.697 .168 0 r
.30376 .3416 m .30497 .34268 L .30223 .34157 L closepath p F P
0 g
s
.471 .05 .158 r
.45843 .36405 m .45217 .36505 L .45058 .36756 L p F P
0 g
s
.451 .851 .661 r
.576 .30907 m .57532 .30952 L .57316 .31069 L p F P
0 g
s
0 0 0 r
.57284 .31087 m .57316 .31069 L .57216 .31133 L p F P
0 g
s
0 0 0 r
.57284 .31087 m .57103 .31212 L p .5736 .31036 L F P
0 g
s
.472 .861 .661 r
.57316 .31069 m .57284 .31087 L .57471 .3096 L closepath p F P
0 g
s
0 0 0 r
.57471 .3096 m .57284 .31087 L p .5736 .31036 L F P
0 g
s
0 0 0 r
.57216 .31133 m .56463 .31616 L p .57284 .31087 L F P
0 g
s
0 0 0 r
.56463 .31616 m .56286 .31732 L .57284 .31087 L p F P
0 g
s
.018 .455 .871 r
.22155 .29271 m .22039 .29223 L .2244 .2952 L p F P
0 g
s
.018 .455 .871 r
.2244 .2952 m .22469 .29531 L .22155 .29271 L p F P
0 g
s
.409 .766 .995 r
.35531 .46275 m .35376 .46193 L .35102 .46209 L closepath p F P
0 g
s
.714 .797 .916 r
.69289 .245 m .69527 .24795 L .6851 .25239 L p F P
0 g
s
.714 .797 .916 r
.68501 .24869 m .69289 .245 L p .6851 .25239 L F P
0 g
s
.714 .797 .916 r
.6851 .25239 m .68348 .2506 L .68501 .24869 L p F P
0 g
s
.449 0 0 r
.15023 .39067 m .14937 .39001 L .15338 .39289 L p F P
0 g
s
.449 0 0 r
.15338 .39289 m .1535 .39299 L .15023 .39067 L p F P
0 g
s
.516 .853 .996 r
.47024 .46233 m .46986 .46218 L .46747 .46271 L closepath p F P
0 g
s
.524 .85 .997 r
.46711 .46098 m .46986 .46218 L .46747 .46271 L p F P
0 g
s
.524 .85 .997 r
.45726 .46319 m .46711 .46098 L p .46747 .46271 L F P
0 g
s
.52 .901 .736 r
.58529 .30309 m .576 .30907 L .58378 .30371 L closepath p F P
0 g
s
.451 .851 .661 r
.58283 .30412 m .58378 .30371 L .576 .30907 L p F P
0 g
s
.451 .851 .661 r
.57471 .3096 m .58283 .30412 L p .576 .30907 L F P
0 g
s
.451 .851 .661 r
.57316 .31069 m .57471 .3096 L p .576 .30907 L F P
0 g
s
.13 0 .374 r
.73803 .3149 m .73308 .32071 L .73395 .31606 L p F P
0 g
s
.13 0 .374 r
.73395 .31606 m .73893 .31023 L .73803 .3149 L p F P
0 g
s
.634 .072 0 r
.27965 .33037 m .28496 .33279 L .28121 .33 L p F P
0 g
s
.634 .072 0 r
.28121 .33 m .27612 .3275 L .27965 .33037 L p F P
0 g
s
.537 .877 .989 r
.5032 .45602 m .50496 .45662 L .49505 .45929 L p F P
0 g
s
.537 .877 .989 r
.49505 .45929 m .49246 .45843 L .5032 .45602 L p F P
0 g
s
.51 .869 .986 r
.49246 .45843 m .49505 .45929 L p .48245 .46087 L F P
0 g
s
0 .141 .58 r
.1573 .39565 m .1535 .39299 L .15023 .39067 L p F P
0 g
s
.644 .67 .86 r
.72019 .24883 m .71029 .25124 L .70789 .2475 L p F P
0 g
s
0 .276 .729 r
.22878 .29764 m .22469 .29531 L .22155 .29271 L p F P
0 g
s
0 .217 .637 r
.16855 .40317 m .16982 .40393 L .17415 .40666 L p F P
0 g
s
0 .285 .706 r
.17452 .40644 m .17882 .40919 L .17415 .40666 L p F P
0 g
s
0 .285 .706 r
.17415 .40666 m .16982 .40393 L .17452 .40644 L p F P
0 g
s
.496 .807 1 r
.40404 .46366 m .39433 .46501 L .39145 .46355 L p F P
0 g
s
.251 0 0 r
.50787 .34867 m .50876 .34745 L .49869 .35078 L p F P
0 g
s
.251 0 0 r
.49869 .35078 m .49793 .35179 L .50787 .34867 L p F P
0 g
s
0 0 .112 r
.72359 .33897 m .72039 .34224 L .72358 .33678 L p F P
0 g
s
0 0 .112 r
.72358 .33678 m .72429 .33605 L .72359 .33897 L p F P
0 g
s
.526 .91 .762 r
.64964 .40585 m .64529 .40853 L .64344 .40917 L p F P
0 g
s
0 0 0 r
.55174 .32441 m .55289 .32337 L .54293 .32892 L p F P
0 g
s
0 0 0 r
.54293 .32892 m .54269 .32915 L .55174 .32441 L p F P
0 g
s
.326 .596 .944 r
.18808 .27112 m .18561 .27066 L .18902 .27391 L p F P
0 g
s
.326 .596 .944 r
.18902 .27391 m .19123 .27431 L .18808 .27112 L p F P
0 g
s
.79 .299 0 r
.1187 .36279 m .11757 .36106 L .11427 .35841 L p F P
0 g
s
0 0 0 r
.68697 .37866 m .68533 .38023 L .69303 .37353 L closepath p F P
0 g
s
.402 0 0 r
.23983 .30483 m .24144 .30592 L .24569 .30877 L p F P
0 g
s
.398 0 0 r
.24537 .30857 m .24978 .31136 L .24569 .30877 L p F P
0 g
s
.398 0 0 r
.24569 .30877 m .24144 .30592 L .24537 .30857 L p F P
0 g
s
0 0 0 r
.55372 .32273 m .55289 .32337 L .55971 .31921 L closepath p F P
0 g
s
.765 .913 .939 r
.65009 .26453 m .64634 .26683 L .64897 .26389 L closepath p F P
0 g
s
.758 .935 .943 r
.64771 .26318 m .64897 .26389 L .64634 .26683 L p F P
0 g
s
.758 .935 .943 r
.63768 .26963 m .64771 .26318 L p .64634 .26683 L F P
0 g
s
.263 .142 .522 r
.73925 .30565 m .7391 .30582 L .73846 .30171 L p F P
0 g
s
.263 .142 .522 r
.73846 .30171 m .73884 .30126 L .73925 .30565 L p F P
0 g
s
.557 .934 .853 r
.6234 .42043 m .62287 .42051 L .6269 .41836 L closepath p F P
0 g
s
.534 .86 .996 r
.47973 .4598 m .48145 .4605 L .47024 .46233 L p F P
0 g
s
.534 .86 .996 r
.47024 .46233 m .46986 .46218 L .47973 .4598 L p F P
0 g
s
.113 .583 .914 r
.2451 .43951 m .24715 .43993 L .24236 .43798 L closepath p F P
0 g
s
.753 .872 .934 r
.66153 .2596 m .66015 .25854 L .6645 .25606 L closepath p F P
0 g
s
.042 .528 .884 r
.23043 .43417 m .22969 .43373 L .22923 .43361 L closepath p F P
0 g
s
.53 .867 .993 r
.48245 .46087 m .49131 .45866 L .48145 .4605 L closepath p F P
0 g
s
.51 .869 .986 r
.48245 .46087 m .49131 .45866 L .49246 .45843 L p F P
0 g
s
.397 .764 .993 r
.34123 .4609 m .34286 .46082 L .35102 .46209 L p F P
0 g
s
.419 .765 .996 r
.3508 .4603 m .34286 .46082 L .35102 .46209 L p F P
0 g
s
.419 .765 .996 r
.35102 .46209 m .35376 .46193 L .3508 .4603 L p F P
0 g
s
.49 .818 1 r
.4069 .46508 m .41665 .46355 L .41948 .46493 L p F P
0 g
s
.509 .816 1 r
.41665 .46355 m .4069 .46508 L .40404 .46366 L p F P
0 g
s
.609 .073 0 r
.13209 .37614 m .13121 .37525 L .13499 .37824 L p F P
0 g
s
.609 .073 0 r
.13499 .37824 m .13538 .37863 L .13209 .37614 L p F P
0 g
s
.206 .644 .949 r
.27329 .44808 m .27288 .44785 L .27251 .44781 L closepath p F P
0 g
s
.732 .98 .914 r
.62246 .27966 m .61766 .28284 L .61552 .28264 L p F P
0 g
s
.557 .892 .984 r
.52754 .45155 m .52929 .45209 L .519 .45504 L p F P
0 g
s
.557 .892 .984 r
.519 .45504 m .51757 .45462 L .52754 .45155 L p F P
0 g
s
0 .33 .742 r
.18515 .41309 m .18371 .41216 L .18318 .4119 L closepath p F P
0 g
s
.235 .123 .515 r
.74353 .30016 m .73925 .30565 L .73884 .30126 L p F P
0 g
s
.235 .123 .515 r
.73884 .30126 m .74291 .29603 L .74353 .30016 L p F P
0 g
s
.913 .51 .184 r
.09622 .33657 m .09952 .33981 L .09835 .33617 L p F P
0 g
s
.913 .51 .184 r
.09835 .33617 m .09504 .33292 L .09622 .33657 L p F P
0 g
s
0 0 0 r
.55036 .32569 m .55174 .32441 L .54269 .32915 L p F P
0 g
s
0 0 0 r
.54491 .32884 m .55036 .32569 L p .54269 .32915 L F P
0 g
s
0 0 0 r
.54269 .32915 m .54083 .33103 L .54491 .32884 L p F P
0 g
s
.517 0 0 r
.26648 .32229 m .26266 .31955 L .26748 .32216 L p F P
0 g
s
.517 0 0 r
.26791 .32303 m .26648 .32229 L p .26748 .32216 L F P
0 g
s
.517 0 0 r
.26748 .32216 m .27015 .32397 L .26791 .32303 L p F P
0 g
s
.676 .226 .177 r
.35932 .36565 m .36741 .367 L .36373 .36407 L p F P
0 g
s
.676 .226 .177 r
.35909 .36545 m .35932 .36565 L p .36373 .36407 L F P
0 g
s
.676 .226 .177 r
.36373 .36407 m .36124 .36365 L .35909 .36545 L p F P
0 g
s
.473 .05 .155 r
.46347 .36327 m .4628 .36432 L .45843 .36405 L closepath p F P
0 g
s
.471 .05 .158 r
.46193 .36582 m .4628 .36432 L .45843 .36405 L p F P
0 g
s
.471 .05 .158 r
.45058 .36756 m .46193 .36582 L p .45843 .36405 L F P
0 g
s
.393 0 0 r
.25618 .31509 m .25498 .31444 L .25437 .31408 L closepath p F P
0 g
s
0 0 .098 r
.72614 .3362 m .72359 .33897 L .72429 .33605 L p F P
0 g
s
0 0 .098 r
.72429 .33605 m .72911 .3308 L .72614 .3362 L p F P
0 g
s
.885 .454 .104 r
.10098 .34337 m .10436 .34658 L .10289 .34302 L p F P
0 g
s
.885 .454 .104 r
.10289 .34302 m .09952 .33981 L .10098 .34337 L p F P
0 g
s
.217 .646 .954 r
.26978 .44607 m .26674 .44568 L .27251 .44781 L p F P
0 g
s
.217 .646 .954 r
.27251 .44781 m .27288 .44785 L .26978 .44607 L p F P
0 g
s
.302 .709 .976 r
.30077 .45445 m .3013 .45447 L .30035 .45423 L closepath p F P
0 g
s
.502 .826 1 r
.41948 .46493 m .42926 .46323 L .43207 .46457 L p F P
0 g
s
.518 .824 1 r
.42926 .46323 m .41948 .46493 L .41665 .46355 L p F P
0 g
s
.549 .856 .997 r
.47973 .4598 m .46986 .46218 L .46711 .46098 L p F P
0 g
s
.483 .877 .701 r
.65532 .40221 m .64964 .40585 L .6544 .40264 L closepath p F P
0 g
s
.526 .91 .762 r
.65303 .40308 m .6544 .40264 L .64964 .40585 L p F P
0 g
s
.526 .91 .762 r
.64584 .40756 m .65303 .40308 L p .64964 .40585 L F P
0 g
s
.526 .91 .762 r
.64344 .40917 m .64584 .40756 L p .64964 .40585 L F P
0 g
s
.561 .908 .971 r
.55273 .44617 m .54273 .44963 L .54014 .44906 L p F P
0 g
s
.541 .901 .97 r
.53016 .4523 m .54014 .44906 L .54273 .44963 L p F P
0 g
s
.394 0 .117 r
.48512 .3585 m .48531 .35817 L .47543 .35953 L p F P
0 g
s
.394 0 .117 r
.47543 .35953 m .47446 .3611 L .48512 .3585 L p F P
0 g
s
.768 .913 .937 r
.65777 .25689 m .66015 .25854 L .65009 .26453 L p F P
0 g
s
.768 .913 .937 r
.65181 .26062 m .65777 .25689 L p .65009 .26453 L F P
0 g
s
.768 .913 .937 r
.65009 .26453 m .64897 .26389 L .65181 .26062 L p F P
0 g
s
0 .473 .851 r
.21112 .42528 m .20801 .42424 L .2128 .42676 L p F P
0 g
s
0 .473 .851 r
.2128 .42676 m .21431 .42727 L .21112 .42528 L p F P
0 g
s
.553 .926 .926 r
.5864 .43495 m .58786 .43503 L .57783 .43923 L p F P
0 g
s
.553 .926 .926 r
.57783 .43923 m .57705 .4392 L .5864 .43495 L p F P
0 g
s
0 .41 .85 r
.20641 .28323 m .20785 .2839 L .2115 .28702 L p F P
0 g
s
0 .419 .856 r
.21275 .28612 m .21651 .28921 L .2115 .28702 L p F P
0 g
s
0 .419 .856 r
.2115 .28702 m .20785 .2839 L .21275 .28612 L p F P
0 g
s
.399 .763 .993 r
.34123 .4609 m .34286 .46082 L .34029 .46041 L closepath p F P
0 g
s
.402 .347 .682 r
.74384 .28249 m .74341 .28305 L .73977 .28002 L p F P
0 g
s
.402 .347 .682 r
.73977 .28002 m .74237 .2766 L .74384 .28249 L p F P
0 g
s
.435 .64 .943 r
.17284 .26273 m .1721 .26268 L .17531 .26602 L p F P
0 g
s
.435 .64 .943 r
.17531 .26602 m .17599 .26606 L .17284 .26273 L p F P
0 g
s
.74 .82 .914 r
.68272 .24977 m .6726 .25493 L .67023 .25279 L p F P
0 g
s
.715 .217 .056 r
.31764 .35079 m .32391 .35283 L .32061 .34981 L p F P
0 g
s
.715 .217 .056 r
.31593 .34909 m .31764 .35079 L p .32061 .34981 L F P
0 g
s
.715 .217 .056 r
.32061 .34981 m .31747 .34874 L .31593 .34909 L p F P
0 g
s
.572 .032 0 r
.13815 .38124 m .13538 .37863 L .13209 .37614 L p F P
0 g
s
.512 .834 .999 r
.43207 .46457 m .44187 .4627 L .44466 .46399 L p F P
0 g
s
.526 .832 1 r
.44187 .4627 m .43207 .46457 L .42926 .46323 L p F P
0 g
s
.54 .848 .998 r
.46711 .46098 m .45726 .46319 L .45449 .46195 L p F P
0 g
s
.054 .532 .891 r
.22652 .4318 m .22421 .43118 L .22923 .43361 L p F P
0 g
s
.054 .532 .891 r
.22923 .43361 m .22969 .43373 L .22652 .4318 L p F P
0 g
s
.273 .674 .97 r
.28214 .44875 m .27288 .44785 L .26978 .44607 L p F P
0 g
s
.852 .395 .023 r
.10609 .35004 m .10953 .35321 L .10779 .34975 L p F P
0 g
s
.852 .395 .023 r
.10779 .34975 m .10436 .34658 L .10609 .35004 L p F P
0 g
s
.531 .841 .999 r
.45449 .46195 m .44466 .46399 L .44187 .4627 L p F P
0 g
s
.676 .226 .176 r
.36124 .36365 m .35909 .36545 L .35567 .36271 L closepath p F P
0 g
s
.357 .728 .987 r
.30784 .45332 m .31021 .45467 L .3013 .45447 L p F P
0 g
s
.357 .728 .987 r
.30639 .45291 m .30784 .45332 L p .3013 .45447 L F P
0 g
s
.357 .728 .987 r
.29773 .45274 m .30639 .45291 L p .3013 .45447 L F P
0 g
s
.357 .728 .987 r
.3013 .45447 m .30035 .45423 L .29773 .45274 L p F P
0 g
s
.712 .194 0 r
.30249 .34345 m .30825 .34568 L .30497 .34268 L p F P
0 g
s
.712 .194 0 r
.30061 .34159 m .30249 .34345 L p .30497 .34268 L F P
0 g
s
.712 .194 0 r
.30497 .34268 m .30223 .34157 L .30061 .34159 L p F P
0 g
s
0 .407 .805 r
.19577 .41805 m .19293 .41689 L .1975 .41951 L p F P
0 g
s
0 .407 .805 r
.1975 .41951 m .19898 .42011 L .19577 .41805 L p F P
0 g
s
0 .144 .583 r
.24144 .30592 m .23983 .30483 L .23669 .30257 L p F P
0 g
s
0 .18 .614 r
.16144 .39834 m .1573 .39565 L .16142 .39847 L p F P
0 g
s
0 .18 .614 r
.16432 .40033 m .16144 .39834 L p .16142 .39847 L F P
0 g
s
0 .18 .614 r
.16142 .39847 m .16529 .401 L .16432 .40033 L p F P
0 g
s
.062 0 .292 r
.7323 .3216 m .73211 .32373 L .73308 .32071 L closepath p F P
0 g
s
.707 .229 .112 r
.33383 .35776 m .34079 .35953 L .33736 .35654 L p F P
0 g
s
.707 .229 .112 r
.33131 .35529 m .33383 .35776 L p .33736 .35654 L F P
0 g
s
.707 .229 .112 r
.33736 .35654 m .33189 .35503 L .33131 .35529 L p F P
0 g
s
.755 .969 .928 r
.62766 .27622 m .62246 .27966 L .62633 .27592 L closepath p F P
0 g
s
.732 .98 .914 r
.62526 .27569 m .62633 .27592 L .62246 .27966 L p F P
0 g
s
.732 .98 .914 r
.61632 .28188 m .62526 .27569 L p .62246 .27966 L F P
0 g
s
.732 .98 .914 r
.61552 .28264 m .61632 .28188 L p .62246 .27966 L F P
0 g
s
0 .327 .762 r
.23327 .30006 m .22878 .29764 L .23285 .30058 L p F P
0 g
s
0 .327 .762 r
.23438 .30083 m .23327 .30006 L p .23285 .30058 L F P
0 g
s
0 .327 .762 r
.23285 .30058 m .23669 .30257 L .23438 .30083 L p F P
0 g
s
0 0 0 r
.54037 .3315 m .54083 .33103 L .53156 .33546 L p F P
0 g
s
0 0 0 r
.53156 .33546 m .5304 .33672 L .54037 .3315 L p F P
0 g
s
.109 .568 .915 r
.23649 .43531 m .22969 .43373 L .22652 .4318 L p F P
0 g
s
.305 .7 .977 r
.30035 .45423 m .29773 .45274 L .29486 .45259 L closepath p F P
0 g
s
.545 .914 .742 r
.59031 .29971 m .58529 .30309 L .58378 .30371 L p F P
0 g
s
.307 .581 .938 r
.17599 .26606 m .18231 .26737 L .18561 .27066 L p F P
0 g
s
.313 .578 .936 r
.18231 .26737 m .17599 .26606 L .17284 .26273 L p F P
0 g
s
.562 .936 .857 r
.6269 .41836 m .62287 .42051 L .62048 .42084 L p F P
0 g
s
.807 .326 0 r
.11098 .35563 m .10953 .35321 L .11303 .35635 L p F P
0 g
s
.807 .326 0 r
.11303 .35635 m .11427 .35841 L .11098 .35563 L p F P
0 g
s
0 .223 .649 r
.16982 .40393 m .16855 .40317 L .16529 .401 L p F P
0 g
s
.44 .016 .136 r
.47294 .36364 m .47446 .3611 L .46347 .36327 L p F P
0 g
s
.44 .016 .136 r
.47031 .36415 m .47294 .36364 L p .46347 .36327 L F P
0 g
s
.44 .016 .136 r
.46347 .36327 m .4628 .36432 L .47031 .36415 L p F P
0 g
s
.516 0 0 r
.14157 .38415 m .14544 .3871 L .14203 .38418 L p F P
0 g
s
.516 0 0 r
.14203 .38418 m .13815 .38124 L .14157 .38415 L p F P
0 g
s
0 0 .006 r
.72257 .34181 m .71659 .34792 L .72039 .34224 L p F P
0 g
s
0 0 .006 r
.72275 .34154 m .72257 .34181 L p .72039 .34224 L F P
0 g
s
0 0 .006 r
.72039 .34224 m .72359 .33897 L .72275 .34154 L p F P
0 g
s
.693 .153 0 r
.28818 .33579 m .29355 .33818 L .29019 .33522 L p F P
0 g
s
.693 .153 0 r
.28536 .33309 m .28818 .33579 L p .29019 .33522 L F P
0 g
s
.693 .153 0 r
.29019 .33522 m .2859 .33319 L .28536 .33309 L p F P
0 g
s
.557 .933 .894 r
.60822 .42593 m .61042 .42584 L .60037 .4306 L p F P
0 g
s
.557 .933 .894 r
.60037 .4306 m .5992 .43065 L .60822 .42593 L p F P
0 g
s
.581 .165 .217 r
.41805 .37006 m .41434 .37016 L .41264 .37266 L p F P
0 g
s
.606 .192 .232 r
.41099 .37265 m .41264 .37266 L .41434 .37016 L p F P
0 g
s
.606 .192 .232 r
.41434 .37016 m .40608 .37011 L .41099 .37265 L p F P
0 g
s
0 0 0 r
.71534 .34918 m .71495 .35009 L .71659 .34792 L closepath p F P
0 g
s
0 0 0 r
.6964 .37013 m .69528 .37145 L .70025 .36667 L closepath p F P
0 g
s
.607 .184 .214 r
.39973 .37243 m .41099 .37265 L .40608 .37011 L p F P
0 g
s
.607 .184 .214 r
.39963 .37237 m .39973 .37243 L p .40608 .37011 L F P
0 g
s
.607 .184 .214 r
.40608 .37011 m .40139 .37002 L .39963 .37237 L p F P
0 g
s
.121 0 0 r
.52978 .33749 m .5304 .33672 L .52045 .34126 L p F P
0 g
s
.121 0 0 r
.52045 .34126 m .52023 .34153 L .52978 .33749 L p F P
0 g
s
.582 .171 .228 r
.42682 .36977 m .41805 .37006 L .42362 .37238 L p F P
0 g
s
.581 .165 .217 r
.41264 .37266 m .42362 .37238 L .41805 .37006 L p F P
0 g
s
.337 0 .062 r
.49551 .35555 m .49707 .35311 L .4867 .35608 L p F P
0 g
s
.337 0 .062 r
.48964 .35721 m .49551 .35555 L p .4867 .35608 L F P
0 g
s
.337 0 .062 r
.4867 .35608 m .48531 .35817 L .48964 .35721 L p F P
0 g
s
.198 .628 .948 r
.25303 .44047 m .25429 .44122 L .24715 .43993 L p F P
0 g
s
.198 .628 .948 r
.24982 .4391 m .25303 .44047 L p .24715 .43993 L F P
0 g
s
.198 .628 .948 r
.24195 .43774 m .24982 .4391 L p .24715 .43993 L F P
0 g
s
.198 .628 .948 r
.24715 .43993 m .24236 .43798 L .24195 .43774 L p F P
0 g
s
.578 .577 .816 r
.73369 .25279 m .72994 .25806 L p .72306 .25328 L F P
0 g
s
.578 .577 .816 r
.72306 .25328 m .73353 .25243 L .73369 .25279 L p F P
0 g
s
.596 .6 .826 r
.73353 .25243 m .72306 .25328 L .72062 .24873 L p F P
0 g
s
.625 .205 .226 r
.40139 .37002 m .39963 .37237 L .39527 .36975 L closepath p F P
0 g
s
.159 .508 .912 r
.19123 .27431 m .19513 .27562 L .19862 .27883 L p F P
0 g
s
.164 .505 .911 r
.19513 .27562 m .19123 .27431 L .18808 .27112 L p F P
0 g
s
.507 .889 .707 r
.66346 .39677 m .65532 .40221 L .6544 .40264 L p F P
0 g
s
.376 0 0 r
.25183 .31264 m .24978 .31136 L .25437 .31408 L p F P
0 g
s
.376 0 0 r
.25437 .31408 m .25498 .31444 L .25183 .31264 L p F P
0 g
s
0 .337 .753 r
.18048 .41 m .17882 .40919 L .18318 .4119 L p F P
0 g
s
0 .337 .753 r
.18318 .4119 m .18371 .41216 L .18048 .41 L p F P
0 g
s
.438 .771 .997 r
.34784 .4586 m .3508 .4603 L .34286 .46082 L p F P
0 g
s
.438 .771 .997 r
.33825 .45928 m .34784 .4586 L p .34286 .46082 L F P
0 g
s
.438 .771 .997 r
.34286 .46082 m .34029 .46041 L .33825 .45928 L p F P
0 g
s
.544 .546 .807 r
.72994 .25806 m .73369 .25279 L .73605 .25826 L closepath p F P
0 g
s
.574 .94 .892 r
.61152 .42579 m .61042 .42584 L .61972 .42122 L closepath p F P
0 g
s
.462 .778 .998 r
.36337 .46109 m .35376 .46193 L .3508 .4603 L p F P
0 g
s
.79 .299 0 r
.11427 .35841 m .11511 .3597 L .1187 .36279 L p F P
0 g
s
.723 .212 0 r
.11757 .36292 m .12116 .36601 L .1187 .36279 L p F P
0 g
s
.723 .212 0 r
.1187 .36279 m .11511 .3597 L .11757 .36292 L p F P
0 g
s
.552 .138 .211 r
.43167 .36943 m .42682 .36977 L .4252 .37232 L p F P
0 g
s
.582 .171 .228 r
.42362 .37238 m .4252 .37232 L .42682 .36977 L p F P
0 g
s
.697 .234 .148 r
.34673 .35995 m .34811 .36117 L .34568 .36061 L closepath p F P
0 g
s
.632 .204 .211 r
.39959 .37243 m .39963 .37237 L .39527 .36975 L p F P
0 g
s
.632 .204 .211 r
.38942 .37188 m .39959 .37243 L p .39527 .36975 L F P
0 g
s
.632 .204 .211 r
.38709 .37025 m .38942 .37188 L p .39527 .36975 L F P
0 g
s
.632 .204 .211 r
.39527 .36975 m .38791 .36927 L .38709 .37025 L p F P
0 g
s
.659 .222 .2 r
.37462 .36701 m .37613 .36812 L .3738 .36784 L closepath p F P
0 g
s
.69 .181 .023 r
.31747 .34874 m .31593 .34909 L .31436 .34777 L closepath p F P
0 g
s
.553 .901 .976 r
.53939 .44887 m .54014 .44906 L .53016 .4523 L p F P
0 g
s
.553 .901 .976 r
.53016 .4523 m .52929 .45209 L .53939 .44887 L p F P
0 g
s
.675 .228 .183 r
.35143 .36422 m .34811 .36117 L .35567 .36271 L p F P
0 g
s
.675 .228 .183 r
.35894 .36558 m .35143 .36422 L p .35567 .36271 L F P
0 g
s
.675 .228 .183 r
.35567 .36271 m .35909 .36545 L .35894 .36558 L p F P
0 g
s
.19 .528 .922 r
.20012 .27718 m .19513 .27562 L .19862 .27883 L p F P
0 g
s
.19 .528 .922 r
.19862 .27883 m .20326 .28025 L .20012 .27718 L p F P
0 g
s
.754 .969 .929 r
.63662 .27033 m .62766 .27622 L .62633 .27592 L p F P
0 g
s
.456 .423 .732 r
.73901 .27182 m .74038 .26996 L .74127 .27282 L closepath p F P
0 g
s
.058 0 .29 r
.73645 .31981 m .73803 .3149 L .73308 .32071 L p F P
0 g
s
.058 0 .29 r
.732 .32505 m .73645 .31981 L p .73308 .32071 L F P
0 g
s
.058 0 .29 r
.73308 .32071 m .73211 .32373 L .732 .32505 L p F P
0 g
s
.551 .864 .996 r
.49131 .45866 m .48145 .4605 L .47973 .4598 L p F P
0 g
s
.031 .512 .88 r
.21926 .42872 m .21431 .42727 L .21112 .42528 L p F P
0 g
s
.287 0 .035 r
.50715 .34978 m .50787 .34867 L .49793 .35179 L p F P
0 g
s
.287 0 .035 r
.49793 .35179 m .49707 .35311 L .50715 .34978 L p F P
0 g
s
.545 .914 .742 r
.59283 .2971 m .59434 .29666 L .59031 .29971 L p F P
0 g
s
.545 .914 .742 r
.58769 .30069 m .59283 .2971 L p .59031 .29971 L F P
0 g
s
.545 .914 .742 r
.58378 .30371 m .58769 .30069 L p .59031 .29971 L F P
0 g
s
.608 .95 .806 r
.59526 .2964 m .59031 .29971 L .59434 .29666 L closepath p F P
0 g
s
.402 .755 .994 r
.34029 .46041 m .33825 .45928 L .33513 .4594 L closepath p F P
0 g
s
.673 .137 0 r
.30223 .34157 m .30061 .34159 L .29921 .34045 L closepath p F P
0 g
s
.571 .915 .967 r
.56275 .44249 m .56351 .44265 L .55381 .44639 L p F P
0 g
s
.571 .915 .967 r
.55381 .44639 m .55273 .44617 L .56275 .44249 L p F P
0 g
s
.13 0 0 r
.5281 .33966 m .52978 .33749 L .52023 .34153 L p F P
0 g
s
.13 0 0 r
.52023 .34153 m .51857 .34375 L .5281 .33966 L p F P
0 g
s
0 0 0 r
.55971 .31921 m .55289 .32337 L .55174 .32441 L p F P
0 g
s
0 .379 .788 r
.18843 .41424 m .18371 .41216 L .18048 .41 L p F P
0 g
s
.646 .088 0 r
.27015 .32397 m .27125 .32492 L .27612 .3275 L p F P
0 g
s
.654 .098 0 r
.27459 .32785 m .27965 .33037 L .27612 .3275 L p F P
0 g
s
.654 .098 0 r
.27612 .3275 m .27125 .32492 L .27459 .32785 L p F P
0 g
s
.715 .798 .916 r
.68348 .2506 m .68272 .24977 L .68501 .24869 L closepath p F P
0 g
s
.53 .919 .815 r
.63292 .41505 m .6269 .41836 L .63211 .41524 L closepath p F P
0 g
s
.562 .936 .857 r
.63055 .41543 m .63211 .41524 L .6269 .41836 L p F P
0 g
s
.562 .936 .857 r
.62048 .42084 m .63055 .41543 L p .6269 .41836 L F P
0 g
s
.553 .142 .216 r
.4389 .3689 m .43749 .37119 L .43167 .36943 L closepath p F P
0 g
s
.552 .138 .211 r
.43732 .37148 m .43749 .37119 L .43167 .36943 L p F P
0 g
s
.552 .138 .211 r
.4252 .37232 m .43732 .37148 L p .43167 .36943 L F P
0 g
s
.365 .735 .989 r
.32452 .45732 m .32573 .45798 L p .31324 .45634 L F P
0 g
s
.365 .735 .989 r
.31324 .45634 m .32033 .45632 L .32452 .45732 L p F P
0 g
s
.381 .739 .991 r
.32033 .45632 m .31324 .45634 L .31021 .45467 L p F P
0 g
s
.57 .006 0 r
.25804 .31685 m .25498 .31444 L .25183 .31264 L p F P
0 g
s
0 .444 .83 r
.19898 .42011 m .20329 .42168 L .20801 .42424 L p F P
0 g
s
0 .449 .837 r
.20329 .42168 m .19898 .42011 L .19577 .41805 L p F P
0 g
s
.581 .93 .948 r
.58537 .43482 m .5864 .43495 L .57705 .4392 L p F P
0 g
s
.581 .93 .948 r
.57705 .4392 m .57532 .43897 L .58537 .43482 L p F P
0 g
s
.644 .219 .22 r
.38791 .36927 m .38709 .37025 L .38535 .36906 L closepath p F P
0 g
s
.503 .489 .774 r
.73612 .26436 m .73764 .26225 L .73861 .26485 L closepath p F P
0 g
s
0 .406 .85 r
.20785 .2839 m .20641 .28323 L .20326 .28025 L p F P
0 g
s
.016 .446 .869 r
.21841 .29001 m .21651 .28921 L .22039 .29223 L p F P
0 g
s
.016 .446 .869 r
.22039 .29223 m .22155 .29271 L .21841 .29001 L p F P
0 g
s
.297 .204 .578 r
.74558 .29259 m .74291 .29603 L .74144 .29221 L p F P
0 g
s
.297 .204 .578 r
.74144 .29221 m .74488 .28778 L .74558 .29259 L p F P
0 g
s
.674 .152 0 r
.12386 .36916 m .1275 .37222 L .12481 .36907 L p F P
0 g
s
.674 .152 0 r
.12481 .36907 m .12116 .36601 L .12386 .36916 L p F P
0 g
s
.643 .223 .233 r
.37987 .37105 m .37613 .36812 L .38535 .36906 L p F P
0 g
s
.643 .223 .233 r
.38603 .37162 m .37987 .37105 L p .38535 .36906 L F P
0 g
s
.643 .223 .233 r
.38535 .36906 m .38709 .37025 L .38603 .37162 L p F P
0 g
s
.566 .922 .951 r
.57305 .43866 m .57532 .43897 L .56529 .4429 L p F P
0 g
s
.566 .922 .951 r
.56529 .4429 m .56351 .44265 L .57305 .43866 L p F P
0 g
s
.441 0 0 r
.14696 .38827 m .14544 .3871 L .14937 .39001 L p F P
0 g
s
.441 0 0 r
.14937 .39001 m .15023 .39067 L .14696 .38827 L p F P
0 g
s
.692 .208 .095 r
.33189 .35503 m .33131 .35529 L .33061 .3547 L closepath p F P
0 g
s
.194 .634 .946 r
.25741 .44301 m .261 .44353 L .26674 .44568 L p F P
0 g
s
.206 .638 .95 r
.261 .44353 m .25741 .44301 L .25429 .44122 L p F P
0 g
s
.681 .724 .882 r
.69527 .24795 m .7055 .244 L .70789 .2475 L p F P
0 g
s
.694 .743 .889 r
.7055 .244 m .69527 .24795 L .69289 .245 L p F P
0 g
s
0 .223 .649 r
.16529 .401 m .16556 .40116 L .16982 .40393 L p F P
0 g
s
0 .299 .725 r
.17029 .40366 m .17452 .40644 L .16982 .40393 L p F P
0 g
s
0 .299 .725 r
.16982 .40393 m .16556 .40116 L .17029 .40366 L p F P
0 g
s
.461 .79 .999 r
.36631 .46269 m .37596 .46166 L .37887 .46323 L p F P
0 g
s
.485 .788 .998 r
.37596 .46166 m .36631 .46269 L .36337 .46109 L p F P
0 g
s
.752 .887 .94 r
.6645 .25606 m .66015 .25854 L .65777 .25689 L p F P
0 g
s
.518 .105 .196 r
.44796 .36785 m .4389 .3689 L .43749 .37119 L p F P
0 g
s
0 0 0 r
.71809 .34773 m .72257 .34181 L .71659 .34792 L p F P
0 g
s
0 0 0 r
.71427 .35166 m .71809 .34773 L p .71659 .34792 L F P
0 g
s
0 0 0 r
.71659 .34792 m .71495 .35009 L .71427 .35166 L p F P
0 g
s
.426 0 0 r
.23702 .30278 m .23731 .30298 L p .23732 .30301 L F P
0 g
s
0 .144 .583 r
.23732 .30301 m .24144 .30592 L p .23732 .30301 L F P
0 g
s
.41 0 0 r
.24144 .30592 m .23732 .30301 L .24113 .30571 L p F P
0 g
s
.426 0 0 r
.23731 .30298 m .24113 .30571 L .23732 .30301 L p F P
0 g
s
0 .144 .583 r
.23669 .30257 m .23732 .30301 L p .23732 .30301 L F P
0 g
s
.41 0 0 r
.24113 .30571 m .24537 .30857 L .24144 .30592 L p F P
0 g
s
.623 .956 .808 r
.60355 .29071 m .59526 .2964 L .59434 .29666 L p F P
0 g
s
.644 .67 .86 r
.72047 .24846 m .72019 .24883 L p .70789 .2475 L F P
0 g
s
.644 .67 .86 r
.70789 .2475 m .7182 .24455 L .72047 .24846 L p F P
0 g
s
.658 .691 .869 r
.7182 .24455 m .70789 .2475 L .7055 .244 L p F P
0 g
s
.459 .847 .636 r
.66534 .39546 m .66346 .39677 L .66501 .39566 L closepath p F P
0 g
s
.507 .889 .707 r
.66309 .39651 m .66501 .39566 L .66346 .39677 L p F P
0 g
s
.507 .889 .707 r
.66069 .39813 m .66309 .39651 L p .66346 .39677 L F P
0 g
s
.507 .889 .707 r
.6544 .40264 m .66069 .39813 L p .66346 .39677 L F P
0 g
s
.769 .915 .937 r
.64897 .26389 m .64771 .26318 L .65181 .26062 L closepath p F P
0 g
s
.227 .649 .957 r
.26668 .44423 m .261 .44353 L .26674 .44568 L p F P
0 g
s
.227 .649 .957 r
.26674 .44568 m .26978 .44607 L .26668 .44423 L p F P
0 g
s
.196 .055 .451 r
.73939 .30968 m .73893 .31023 L .7391 .30582 L p F P
0 g
s
.196 .055 .451 r
.7391 .30582 m .73925 .30565 L .73939 .30968 L p F P
0 g
s
.69 .179 .017 r
.31156 .34868 m .30825 .34568 L .31436 .34777 L p F P
0 g
s
.69 .179 .017 r
.31402 .34949 m .31156 .34868 L p .31436 .34777 L F P
0 g
s
.69 .179 .017 r
.31436 .34777 m .31593 .34909 L .31402 .34949 L p F P
0 g
s
.564 .89 .987 r
.52754 .45155 m .51757 .45462 L .51492 .45376 L p F P
0 g
s
.548 .884 .988 r
.50496 .45662 m .51492 .45376 L .51757 .45462 L p F P
0 g
s
.286 .692 .973 r
.28528 .45046 m .2885 .45067 L .29486 .45259 L p F P
0 g
s
.286 .692 .973 r
.28528 .45046 m .2885 .45067 L .28227 .4488 L closepath p F P
0 g
s
.692 .208 .095 r
.32722 .35586 m .32391 .35283 L .33061 .3547 L p F P
0 g
s
.692 .208 .095 r
.32897 .35633 m .32722 .35586 L p .33061 .3547 L F P
0 g
s
.692 .208 .095 r
.33061 .3547 m .33131 .35529 L .32897 .35633 L p F P
0 g
s
.313 .7 .979 r
.29467 .45096 m .2885 .45067 L .29486 .45259 L p F P
0 g
s
.313 .7 .979 r
.29486 .45259 m .29773 .45274 L .29467 .45096 L p F P
0 g
s
.164 .032 .442 r
.7434 .30455 m .73939 .30968 L .73925 .30565 L p F P
0 g
s
.164 .032 .442 r
.73925 .30565 m .74353 .30016 L .7434 .30455 L p F P
0 g
s
.328 .592 .941 r
.18493 .26785 m .18231 .26737 L .18561 .27066 L p F P
0 g
s
.328 .592 .941 r
.18561 .27066 m .18808 .27112 L .18493 .26785 L p F P
0 g
s
.484 .861 .643 r
.67498 .38847 m .66534 .39546 L .66501 .39566 L p F P
0 g
s
0 0 0 r
.71495 .35009 m .71196 .35389 L .71427 .35166 L closepath p F P
0 g
s
.554 0 0 r
.26168 .31966 m .26648 .32229 L .26266 .31955 L p F P
0 g
s
.554 0 0 r
.26266 .31955 m .25804 .31685 L .26168 .31966 L p F P
0 g
s
.39 .752 .993 r
.32573 .45798 m .32756 .45792 L .33513 .4594 L p F P
0 g
s
.41 .753 .994 r
.33527 .45755 m .32756 .45792 L .33513 .4594 L p F P
0 g
s
.41 .753 .994 r
.33513 .4594 m .33825 .45928 L .33527 .45755 L p F P
0 g
s
.2 0 0 r
.51783 .34476 m .51857 .34375 L .50876 .34745 L p F P
0 g
s
.2 0 0 r
.50876 .34745 m .50787 .34867 L .51783 .34476 L p F P
0 g
s
.671 .132 0 r
.29695 .34113 m .29355 .33818 L .29921 .34045 L p F P
0 g
s
.671 .132 0 r
.29807 .34156 m .29695 .34113 L p .29921 .34045 L F P
0 g
s
.671 .132 0 r
.29921 .34045 m .30061 .34159 L .29807 .34156 L p F P
0 g
s
.085 0 .299 r
.73211 .32373 m .73148 .32562 L .732 .32505 L closepath p F P
0 g
s
.452 .043 .171 r
.4628 .36432 m .47031 .36415 L .46193 .36582 L closepath p F P
0 g
s
0 .476 .857 r
.20792 .42324 m .20329 .42168 L .20801 .42424 L p F P
0 g
s
0 .476 .857 r
.20801 .42424 m .21112 .42528 L .20792 .42324 L p F P
0 g
s
.716 .814 .926 r
.68501 .24869 m .68272 .24977 L .68035 .24734 L p F P
0 g
s
.74 .82 .914 r
.67023 .25279 m .68035 .24734 L .68272 .24977 L p F P
0 g
s
.601 .068 0 r
.1288 .37355 m .1275 .37222 L .13121 .37525 L p F P
0 g
s
.601 .068 0 r
.13121 .37525 m .13209 .37614 L .1288 .37355 L p F P
0 g
s
.769 .951 .935 r
.63768 .26963 m .63662 .27033 L .63738 .26953 L closepath p F P
0 g
s
.754 .969 .929 r
.63529 .26879 m .63738 .26953 L .63662 .27033 L p F P
0 g
s
.754 .969 .929 r
.62913 .27302 m .63529 .26879 L p .63662 .27033 L F P
0 g
s
.754 .969 .929 r
.62633 .27592 m .62913 .27302 L p .63662 .27033 L F P
0 g
s
.063 .535 .895 r
.22335 .42982 m .21926 .42872 L .22421 .43118 L p F P
0 g
s
.063 .535 .895 r
.22421 .43118 m .22652 .4318 L .22335 .42982 L p F P
0 g
s
.631 .07 0 r
.27015 .32397 m .27125 .32492 L .26791 .32303 L closepath p F P
0 g
s
0 0 0 r
.56049 .31923 m .56249 .31761 L .55971 .31921 L p F P
0 g
s
0 0 0 r
.55174 .32441 m .56049 .31923 L p .55971 .31921 L F P
0 g
s
0 0 0 r
.56286 .31732 m .55971 .31921 L .56249 .31761 L closepath p F P
0 g
s
.48 .798 1 r
.38912 .46231 m .39145 .46355 L p .37887 .46323 L F P
0 g
s
.48 .798 1 r
.37887 .46323 m .38721 .46218 L .38912 .46231 L p F P
0 g
s
.502 .798 .998 r
.38721 .46218 m .37887 .46323 L .37596 .46166 L p F P
0 g
s
.631 .069 0 r
.2859 .33319 m .28536 .33309 L .28496 .33279 L closepath p F P
0 g
s
.704 .25 .169 r
.34414 .36257 m .35143 .36422 L .34811 .36117 L p F P
0 g
s
.704 .25 .169 r
.3436 .36203 m .34414 .36257 L p .34811 .36117 L F P
0 g
s
.704 .25 .169 r
.34811 .36117 m .34568 .36061 L .3436 .36203 L p F P
0 g
s
.574 .898 .984 r
.53754 .44829 m .53939 .44887 L .52929 .45209 L p F P
0 g
s
.574 .898 .984 r
.52929 .45209 m .52754 .45155 L .53754 .44829 L p F P
0 g
s
0 0 0 r
.7055 .36115 m .70517 .36163 L .70659 .36011 L closepath p F P
0 g
s
.666 .237 .219 r
.37178 .37006 m .37987 .37105 L .37613 .36812 L p F P
0 g
s
.666 .237 .219 r
.37613 .36812 m .3738 .36784 L .37178 .37006 L p F P
0 g
s
.554 .93 .819 r
.64066 .40979 m .64297 .40928 L .63292 .41505 L p F P
0 g
s
.554 .93 .819 r
.63292 .41505 m .63211 .41524 L .64066 .40979 L p F P
0 g
s
.786 .296 0 r
.11511 .3597 m .11427 .35841 L .11098 .35563 L p F P
0 g
s
.409 0 .135 r
.48367 .36111 m .48512 .3585 L .47446 .3611 L p F P
0 g
s
.409 0 .135 r
.47446 .3611 m .47294 .36364 L .48367 .36111 L p F P
0 g
s
0 .276 .729 r
.22155 .29271 m .22484 .29464 L .22878 .29764 L p F P
0 g
s
0 .272 .732 r
.22484 .29464 m .22155 .29271 L .21841 .29001 L p F P
0 g
s
.776 .952 .931 r
.64533 .262 m .64771 .26318 L .63768 .26963 L p F P
0 g
s
.776 .952 .931 r
.64236 .26401 m .64533 .262 L p .63768 .26963 L F P
0 g
s
.776 .952 .931 r
.63768 .26963 m .63738 .26953 L .64236 .26401 L p F P
0 g
s
0 .141 .58 r
.15023 .39067 m .15325 .39278 L .1573 .39565 L p F P
0 g
s
0 .148 .593 r
.15325 .39278 m .15023 .39067 L .14696 .38827 L p F P
0 g
s
.126 .583 .922 r
.24236 .43798 m .24195 .43774 L .24168 .43768 L closepath p F P
0 g
s
.753 .859 .928 r
.67023 .25279 m .6645 .25606 L .66822 .25111 L closepath p F P
0 g
s
.752 .887 .94 r
.66786 .25081 m .66822 .25111 L .6645 .25606 L p F P
0 g
s
.752 .887 .94 r
.65777 .25689 m .66786 .25081 L p .6645 .25606 L F P
0 g
s
.391 .752 .993 r
.32573 .45798 m .32756 .45792 L .32452 .45732 L closepath p F P
0 g
s
.557 .882 .99 r
.51375 .45334 m .51492 .45376 L .50496 .45662 L p F P
0 g
s
.557 .882 .99 r
.50496 .45662 m .5032 .45602 L .51375 .45334 L p F P
0 g
s
0 .41 .811 r
.19255 .41593 m .18843 .41424 L .19293 .41689 L p F P
0 g
s
0 .41 .811 r
.19293 .41689 m .19577 .41805 L .19255 .41593 L p F P
0 g
s
.468 .453 .758 r
.73861 .26485 m .74283 .26628 L .74038 .26996 L closepath p F P
0 g
s
.406 .391 .73 r
.74767 .26889 m .74283 .26628 L .74038 .26996 L p F P
0 g
s
.406 .391 .73 r
.74388 .27441 m .74767 .26889 L p .74038 .26996 L F P
0 g
s
.406 .391 .73 r
.74038 .26996 m .74127 .27282 L .74388 .27441 L p F P
0 g
s
.573 .934 .926 r
.59559 .43046 m .59792 .43059 L .58786 .43503 L p F P
0 g
s
.573 .934 .926 r
.58786 .43503 m .5864 .43495 L .59559 .43046 L p F P
0 g
s
.721 .249 .128 r
.33131 .35529 m .33383 .35776 L .32897 .35633 L closepath p F P
0 g
s
0 0 0 r
.71302 .35391 m .70659 .36011 L .71196 .35389 L p F P
0 g
s
0 0 0 r
.71196 .35389 m .71427 .35166 L .71302 .35391 L p F P
0 g
s
.522 .112 .204 r
.45058 .36756 m .45015 .36828 L .44796 .36785 L closepath p F P
0 g
s
.518 .105 .196 r
.44909 .37022 m .45015 .36828 L .44796 .36785 L p F P
0 g
s
.518 .105 .196 r
.43829 .37138 m .44909 .37022 L p .44796 .36785 L F P
0 g
s
.518 .105 .196 r
.43749 .37119 m .43829 .37138 L p .44796 .36785 L F P
0 g
s
0 .406 .85 r
.20326 .28025 m .20429 .28073 L .20785 .2839 L p F P
0 g
s
0 .412 .854 r
.20911 .28298 m .21275 .28612 L .20785 .2839 L p F P
0 g
s
0 .412 .854 r
.20785 .2839 m .20429 .28073 L .20911 .28298 L p F P
0 g
s
.671 .244 .223 r
.37105 .36996 m .37178 .37006 L .3738 .36784 L p F P
0 g
s
.671 .244 .223 r
.3738 .36784 m .36741 .367 L .37105 .36996 L p F P
0 g
s
.422 .388 .716 r
.74127 .27282 m .74388 .27441 L .74237 .2766 L closepath p F P
0 g
s
.884 .453 .091 r
.09767 .34012 m .10098 .34337 L .09952 .33981 L p F P
0 g
s
.884 .453 .091 r
.09952 .33981 m .09622 .33657 L .09767 .34012 L p F P
0 g
s
.627 .062 0 r
.2822 .33243 m .27965 .33037 L .28496 .33279 L p F P
0 g
s
.627 .062 0 r
.28496 .33279 m .28536 .33309 L .2822 .33243 L p F P
0 g
s
.624 .656 .861 r
.72019 .24883 m .72047 .24846 L .72062 .24873 L closepath p F P
0 g
s
.138 .586 .926 r
.23881 .43579 m .23649 .43531 L .24168 .43768 L p F P
0 g
s
.138 .586 .926 r
.24168 .43768 m .24195 .43774 L .23881 .43579 L p F P
0 g
s
.542 .868 .994 r
.49246 .45843 m .49235 .45839 L .49131 .45866 L closepath p F P
0 g
s
.551 .864 .996 r
.48965 .45723 m .49235 .45839 L .49131 .45866 L p F P
0 g
s
.551 .864 .996 r
.47973 .4598 m .48965 .45723 L p .49131 .45866 L F P
0 g
s
.588 .941 .924 r
.60799 .42592 m .60822 .42593 L .5992 .43065 L p F P
0 g
s
.588 .941 .924 r
.5992 .43065 m .59792 .43059 L .60799 .42592 L p F P
0 g
s
.484 .861 .643 r
.66501 .39566 m .67307 .38952 L p .67498 .38847 L F P
0 g
s
.549 .912 .726 r
.66501 .39566 m .66309 .39651 L .67307 .38952 L closepath p F P
0 g
s
.676 .977 .858 r
.60525 .28955 m .60355 .29071 L .60489 .2896 L closepath p F P
0 g
s
.623 .956 .808 r
.60283 .28992 m .60489 .2896 L .60355 .29071 L p F P
0 g
s
.623 .956 .808 r
.59978 .2921 m .60283 .28992 L p .60355 .29071 L F P
0 g
s
.623 .956 .808 r
.59434 .29666 m .59978 .2921 L p .60355 .29071 L F P
0 g
s
0 .197 .639 r
.1574 .39547 m .16144 .39834 L .1573 .39565 L p F P
0 g
s
0 .197 .639 r
.1573 .39565 m .15325 .39278 L .1574 .39547 L p F P
0 g
s
.564 .929 .778 r
.6544 .40264 m .65303 .40308 L .66069 .39813 L closepath p F P
0 g
s
.728 .811 .916 r
.68501 .24869 m .69289 .245 L .69052 .24223 L p F P
0 g
s
.728 .811 .916 r
.69052 .24223 m .68894 .24302 L .68501 .24869 L p F P
0 g
s
.716 .814 .926 r
.68035 .24734 m .68894 .24302 L .68501 .24869 L p F P
0 g
s
0 .3 .75 r
.22921 .29711 m .23327 .30006 L .22878 .29764 L p F P
0 g
s
0 .3 .75 r
.22878 .29764 m .22484 .29464 L .22921 .29711 L p F P
0 g
s
.697 .239 .162 r
.34568 .36061 m .3436 .36203 L .34079 .35953 L closepath p F P
0 g
s
0 0 .194 r
.73148 .3282 m .72911 .3308 L .73148 .32562 L p F P
0 g
s
0 0 .194 r
.73148 .32562 m .732 .32505 L .73148 .3282 L p F P
0 g
s
.593 .641 .867 r
.72047 .24846 m .72062 .24873 L .73106 .24727 L p F P
0 g
s
.596 .6 .826 r
.72062 .24873 m .73106 .24727 L .73353 .25243 L p F P
0 g
s
.848 .392 .008 r
.10272 .34683 m .10609 .35004 L .10436 .34658 L p F P
0 g
s
.848 .392 .008 r
.10436 .34658 m .10098 .34337 L .10272 .34683 L p F P
0 g
s
0 0 0 r
.57036 .31259 m .57103 .31212 L .56249 .31761 L p F P
0 g
s
.418 .811 .582 r
.57103 .31212 m .57036 .31259 L .57053 .31246 L p F P
0 g
s
0 0 0 r
.57237 .31118 m .56286 .31732 L p .57103 .31212 L F P
0 g
s
.418 .811 .582 r
.57053 .31246 m .57419 .30984 L .57103 .31212 L p F P
0 g
s
0 0 0 r
.57103 .31212 m .57284 .31087 L .57237 .31118 L p F P
0 g
s
0 0 0 r
.56286 .31732 m .56249 .31761 L .57103 .31212 L p F P
0 g
s
.497 .085 .189 r
.46047 .36848 m .46193 .36582 L .45058 .36756 L p F P
0 g
s
.497 .085 .189 r
.45683 .36902 m .46047 .36848 L p .45058 .36756 L F P
0 g
s
.497 .085 .189 r
.45058 .36756 m .45015 .36828 L .45683 .36902 L p F P
0 g
s
.496 .807 1 r
.40243 .4628 m .40404 .46366 L p .39145 .46355 L F P
0 g
s
.496 .807 1 r
.39145 .46355 m .39775 .46263 L .40243 .4628 L p F P
0 g
s
.497 .807 1 r
.39145 .46355 m .39775 .46263 L .38912 .46231 L closepath p F P
0 g
s
.457 .461 .775 r
.73764 .26225 m .73861 .26485 L .74283 .26628 L p F P
0 g
s
.38 .333 .68 r
.74727 .27753 m .74384 .28249 L .74237 .2766 L p F P
0 g
s
.38 .333 .68 r
.74237 .2766 m .74388 .27441 L .74727 .27753 L p F P
0 g
s
.578 .942 .895 r
.61972 .42122 m .61042 .42584 L .60822 .42593 L p F P
0 g
s
.193 .618 .946 r
.24982 .4391 m .24195 .43774 L .23881 .43579 L p F P
0 g
s
.58 .915 .971 r
.56275 .44249 m .55273 .44617 L .55015 .44559 L p F P
0 g
s
.561 .908 .971 r
.54014 .44906 m .55015 .44559 L .55273 .44617 L p F P
0 g
s
.776 .954 .93 r
.63738 .26953 m .63529 .26879 L .64236 .26401 L closepath p F P
0 g
s
.559 .874 .994 r
.50229 .45565 m .5032 .45602 L .49246 .45843 L p F P
0 g
s
.559 .874 .994 r
.49246 .45843 m .49235 .45839 L .50229 .45565 L p F P
0 g
s
.43 .81 .563 r
.67535 .38818 m .67498 .38847 L .67528 .38823 L closepath p F P
0 g
s
.484 .861 .643 r
.67313 .38947 m .67528 .38823 L .67498 .38847 L p F P
0 g
s
.484 .861 .643 r
.67307 .38952 m .67313 .38947 L p .67498 .38847 L F P
0 g
s
.456 .825 .571 r
.6847 .38076 m .67535 .38818 L .67528 .38823 L p F P
0 g
s
.703 .985 .856 r
.61284 .28264 m .61525 .28262 L .60525 .28955 L p F P
0 g
s
.703 .985 .856 r
.61145 .28365 m .61284 .28264 L p .60525 .28955 L F P
0 g
s
.703 .985 .856 r
.60525 .28955 m .60489 .2896 L .61145 .28365 L p F P
0 g
s
.618 .658 .866 r
.7182 .24455 m .72327 .24348 L .72047 .24846 L closepath p F P
0 g
s
.593 .641 .867 r
.72861 .24248 m .72327 .24348 L .72047 .24846 L p F P
0 g
s
.593 .641 .867 r
.73106 .24727 m .72861 .24248 L p .72047 .24846 L F P
0 g
s
.383 0 0 r
.24868 .31072 m .24537 .30857 L .24978 .31136 L p F P
0 g
s
.383 0 0 r
.24978 .31136 m .25183 .31264 L .24868 .31072 L p F P
0 g
s
.719 .191 0 r
.28818 .33579 m .28536 .33309 L .2822 .33243 L p F P
0 g
s
.572 .869 .995 r
.50229 .45565 m .49235 .45839 L .48965 .45723 L p F P
0 g
s
.647 .228 .235 r
.38709 .37025 m .38942 .37188 L .38603 .37162 L closepath p F P
0 g
s
.051 0 0 r
.53907 .33307 m .54037 .3315 L .5304 .33672 L p F P
0 g
s
.051 0 0 r
.5304 .33672 m .52978 .33749 L .53907 .33307 L p F P
0 g
s
.499 0 0 r
.13776 .38117 m .14157 .38415 L .13815 .38124 L p F P
0 g
s
.499 0 0 r
.13815 .38124 m .13434 .37826 L .13776 .38117 L p F P
0 g
s
.572 .032 0 r
.13209 .37614 m .13434 .37826 L .13815 .38124 L p F P
0 g
s
.456 .825 .571 r
.67528 .38823 m .68323 .38178 L p .6847 .38076 L F P
0 g
s
.53 .887 .665 r
.68316 .38182 m .68323 .38178 L .67528 .38823 L p F P
0 g
s
.53 .887 .665 r
.67528 .38823 m .67313 .38947 L .68316 .38182 L p F P
0 g
s
.509 .509 .792 r
.73605 .25826 m .73982 .25885 L .73764 .26225 L closepath p F P
0 g
s
.457 .461 .775 r
.7466 .26075 m .73982 .25885 L .73764 .26225 L p F P
0 g
s
.457 .461 .775 r
.74283 .26628 m .7466 .26075 L p .73764 .26225 L F P
0 g
s
.803 .324 0 r
.10769 .35271 m .10609 .35004 L .10953 .35321 L p F P
0 g
s
.803 .324 0 r
.10953 .35321 m .11098 .35563 L .10769 .35271 L p F P
0 g
s
0 .34 .76 r
.17724 .40778 m .17452 .40644 L .17882 .40919 L p F P
0 g
s
0 .34 .76 r
.17882 .40919 m .18048 .41 L .17724 .40778 L p F P
0 g
s
.575 .94 .822 r
.64344 .40917 m .64297 .40928 L .64584 .40756 L closepath p F P
0 g
s
.313 .578 .936 r
.17284 .26273 m .1791 .26402 L .18231 .26737 L p F P
0 g
s
.298 0 .051 r
.50563 .35223 m .50715 .34978 L .49707 .35311 L p F P
0 g
s
.298 0 .051 r
.49707 .35311 m .49551 .35555 L .50563 .35223 L p F P
0 g
s
0 0 0 r
.713 .35394 m .71302 .35391 L .70659 .36011 L p F P
0 g
s
0 0 0 r
.70705 .36031 m .713 .35394 L p .70659 .36011 L F P
0 g
s
0 0 0 r
.70407 .36319 m .70705 .36031 L p .70659 .36011 L F P
0 g
s
0 0 0 r
.70659 .36011 m .70517 .36163 L .70407 .36319 L p F P
0 g
s
.562 .026 0 r
.13434 .37826 m .13209 .37614 L .1288 .37355 L p F P
0 g
s
.509 .816 1 r
.41534 .46287 m .41665 .46355 L p .40404 .46366 L F P
0 g
s
.509 .816 1 r
.40404 .46366 m .40898 .46285 L .41534 .46287 L p F P
0 g
s
.511 .814 1 r
.40404 .46366 m .40898 .46285 L .40243 .4628 L closepath p F P
0 g
s
0 0 .18 r
.73425 .32494 m .73148 .3282 L .732 .32505 L p F P
0 g
s
0 0 .18 r
.732 .32505 m .73645 .31981 L .73425 .32494 L p F P
0 g
s
.357 .287 .64 r
.74341 .28305 m .74384 .28249 L .74415 .28403 L closepath p F P
0 g
s
.695 .271 .237 r
.36259 .36874 m .37105 .36996 L .36741 .367 L p F P
0 g
s
.695 .271 .237 r
.36741 .367 m .35932 .36565 L .36259 .36874 L p F P
0 g
s
0 0 0 r
.70517 .36163 m .70025 .36667 L .70407 .36319 L closepath p F P
0 g
s
0 0 0 r
.72359 .33897 m .72275 .34154 L .72614 .3362 L closepath p F P
0 g
s
.728 .235 .067 r
.31593 .34909 m .31764 .35079 L .31402 .34949 L closepath p F P
0 g
s
.431 .761 .996 r
.33228 .45576 m .33527 .45755 L .32756 .45792 L p F P
0 g
s
.431 .761 .996 r
.32272 .45628 m .33228 .45576 L p .32756 .45792 L F P
0 g
s
.431 .761 .996 r
.32756 .45792 m .32452 .45732 L .32272 .45628 L p F P
0 g
s
.661 .107 0 r
.26975 .32524 m .27459 .32785 L .27125 .32492 L p F P
0 g
s
.661 .107 0 r
.267 .32267 m .26975 .32524 L p .27125 .32492 L F P
0 g
s
.661 .107 0 r
.27125 .32492 m .26791 .32303 L .267 .32267 L p F P
0 g
s
.369 .724 .988 r
.30639 .45291 m .29773 .45274 L .29467 .45096 L p F P
0 g
s
.766 .972 .923 r
.62633 .27592 m .62526 .27569 L .62913 .27302 L closepath p F P
0 g
s
.564 .861 .997 r
.48965 .45723 m .47973 .4598 L .477 .45858 L p F P
0 g
s
.549 .856 .997 r
.46711 .46098 m .477 .45858 L .47973 .4598 L p F P
0 g
s
.731 .255 .117 r
.32068 .35392 m .32722 .35586 L .32391 .35283 L p F P
0 g
s
.731 .255 .117 r
.32391 .35283 m .31764 .35079 L .32068 .35392 L p F P
0 g
s
.724 .208 0 r
.30061 .34159 m .30249 .34345 L .29807 .34156 L closepath p F P
0 g
s
.751 .859 .929 r
.67798 .24506 m .68035 .24734 L .67023 .25279 L p F P
0 g
s
.751 .859 .929 r
.66892 .25021 m .67798 .24506 L p .67023 .25279 L F P
0 g
s
.751 .859 .929 r
.67023 .25279 m .66822 .25111 L .66892 .25021 L p F P
0 g
s
0 0 0 r
.68533 .38023 m .6847 .38076 L .68521 .38035 L closepath p F P
0 g
s
.456 .825 .571 r
.68323 .38178 m .68521 .38035 L .6847 .38076 L p F P
0 g
s
.458 .768 .996 r
.34784 .4586 m .33825 .45928 L .33527 .45755 L p F P
0 g
s
0 0 0 r
.69303 .37353 m .68533 .38023 L .68521 .38035 L p F P
0 g
s
0 .158 .609 r
.23669 .30257 m .23732 .30301 L .23438 .30083 L closepath p F P
0 g
s
.518 .824 1 r
.42788 .46253 m .42926 .46323 L p .41665 .46355 L F P
0 g
s
.518 .824 1 r
.41665 .46355 m .42119 .46273 L .42788 .46253 L p F P
0 g
s
.523 .822 .999 r
.41665 .46355 m .42119 .46273 L .41534 .46287 L closepath p F P
0 g
s
.273 .674 .97 r
.26978 .44607 m .27624 .44666 L .28214 .44875 L p F P
0 g
s
.285 .678 .972 r
.27624 .44666 m .26978 .44607 L .26668 .44423 L p F P
0 g
s
.566 .922 .74 r
.58378 .30371 m .58283 .30412 L .58769 .30069 L closepath p F P
0 g
s
.786 .296 0 r
.11098 .35563 m .11159 .35657 L .11511 .3597 L p F P
0 g
s
.713 .204 0 r
.11405 .35978 m .11757 .36292 L .11511 .3597 L p F P
0 g
s
.713 .204 0 r
.11511 .3597 m .11159 .35657 L .11405 .35978 L p F P
0 g
s
.164 .505 .911 r
.18808 .27112 m .19174 .27237 L .19513 .27562 L p F P
0 g
s
.171 .504 .91 r
.19174 .27237 m .18808 .27112 L .18493 .26785 L p F P
0 g
s
.343 .713 .985 r
.29161 .44913 m .29467 .45096 L .2885 .45067 L p F P
0 g
s
.343 .713 .985 r
.2822 .44876 m .29161 .44913 L p .2885 .45067 L F P
0 g
s
.343 .713 .985 r
.2885 .45067 m .28227 .4488 L .2822 .44876 L p F P
0 g
s
.73 .229 .041 r
.30556 .34654 m .31156 .34868 L .30825 .34568 L p F P
0 g
s
.73 .229 .041 r
.30825 .34568 m .30249 .34345 L .30556 .34654 L p F P
0 g
s
0 0 0 r
.70311 .36426 m .70407 .36319 L .70025 .36667 L p F P
0 g
s
0 0 0 r
.70024 .36704 m .70311 .36426 L p .70025 .36667 L F P
0 g
s
0 0 0 r
.6948 .372 m .70024 .36704 L p .70025 .36667 L F P
0 g
s
0 0 0 r
.70025 .36667 m .69528 .37145 L .6948 .372 L p F P
0 g
s
.643 .963 .804 r
.59434 .29666 m .59283 .2971 L .59978 .2921 L closepath p F P
0 g
s
.747 .983 .908 r
.61552 .28264 m .61525 .28262 L .61632 .28188 L closepath p F P
0 g
s
.194 .524 .92 r
.19697 .27402 m .19174 .27237 L .19513 .27562 L p F P
0 g
s
.194 .524 .92 r
.19513 .27562 m .20012 .27718 L .19697 .27402 L p F P
0 g
s
0 0 0 r
.56121 .31876 m .57036 .31259 L p .56249 .31761 L F P
0 g
s
0 0 0 r
.56249 .31761 m .56049 .31923 L .56121 .31876 L p F P
0 g
s
.701 .984 .853 r
.60489 .2896 m .60283 .28992 L .61145 .28365 L closepath p F P
0 g
s
.556 .854 .997 r
.477 .45858 m .46711 .46098 L .46436 .45972 L p F P
0 g
s
.54 .848 .998 r
.45449 .46195 m .46436 .45972 L .46711 .46098 L p F P
0 g
s
0 0 0 r
.69528 .37145 m .69303 .37353 L .6948 .372 L closepath p F P
0 g
s
.696 .24 .165 r
.33695 .36088 m .33383 .35776 L .34079 .35953 L p F P
0 g
s
.696 .24 .165 r
.34316 .36233 m .33695 .36088 L p .34079 .35953 L F P
0 g
s
.696 .24 .165 r
.34079 .35953 m .3436 .36203 L .34316 .36233 L p F P
0 g
s
.206 .638 .95 r
.25429 .44122 m .25529 .44136 L .261 .44353 L p F P
0 g
s
.239 .652 .96 r
.26357 .44235 m .25529 .44136 L .261 .44353 L p F P
0 g
s
.239 .652 .96 r
.261 .44353 m .26668 .44423 L .26357 .44235 L p F P
0 g
s
0 0 0 r
.69316 .3735 m .6948 .372 L .69303 .37353 L p F P
0 g
s
0 0 0 r
.69248 .37409 m .69316 .3735 L p .69303 .37353 L F P
0 g
s
0 0 0 r
.68521 .38035 m .69248 .37409 L p .69303 .37353 L F P
0 g
s
.297 .247 .631 r
.74964 .28103 m .74727 .27753 L .74384 .28249 L p F P
0 g
s
.297 .247 .631 r
.74575 .28656 m .74964 .28103 L p .74384 .28249 L F P
0 g
s
.297 .247 .631 r
.74384 .28249 m .74415 .28403 L .74575 .28656 L p F P
0 g
s
.526 .832 1 r
.4401 .46181 m .44187 .4627 L p .42926 .46323 L F P
0 g
s
.526 .832 1 r
.42926 .46323 m .43475 .46215 L .4401 .46181 L p F P
0 g
s
.532 .829 .999 r
.42926 .46323 m .43475 .46215 L .42788 .46253 L closepath p F P
0 g
s
0 .232 .664 r
.16529 .401 m .16556 .40116 L .16432 .40033 L closepath p F P
0 g
s
.109 .568 .915 r
.22652 .4318 m .23137 .43292 L .23649 .43531 L p F P
0 g
s
.121 .572 .92 r
.23137 .43292 m .22652 .4318 L .22335 .42982 L p F P
0 g
s
0 0 0 r
.56036 .31934 m .56049 .31923 L .55174 .32441 L p F P
0 g
s
0 0 0 r
.55174 .32441 m .55036 .32569 L .56036 .31934 L p F P
0 g
s
.548 .846 .998 r
.46362 .45934 m .46436 .45972 L .45449 .46195 L p F P
0 g
s
.548 .846 .998 r
.45449 .46195 m .45202 .46077 L .46362 .45934 L p F P
0 g
s
.531 .841 .999 r
.45202 .46077 m .45449 .46195 L p .44187 .4627 L F P
0 g
s
.501 .522 .81 r
.73369 .25279 m .73605 .25826 L .73982 .25885 L p F P
0 g
s
.766 .928 .94 r
.65181 .26062 m .64771 .26318 L .64533 .262 L p F P
0 g
s
.539 .837 .999 r
.44187 .4627 m .45018 .46095 L .4401 .46181 L closepath p F P
0 g
s
.531 .841 .999 r
.44187 .4627 m .45018 .46095 L .45202 .46077 L p F P
0 g
s
.506 .856 .599 r
.68349 .38156 m .68323 .38178 L .68521 .38035 L p F P
0 g
s
.506 .856 .599 r
.68521 .38035 m .69248 .37409 L .68349 .38156 L p F P
0 g
s
.503 .104 .217 r
.45015 .36828 m .45683 .36902 L .44909 .37022 L closepath p F P
0 g
s
.391 .742 .992 r
.32452 .45732 m .32272 .45628 L .32033 .45632 L closepath p F P
0 g
s
.593 .949 .866 r
.64064 .40979 m .64066 .40979 L .63211 .41524 L p F P
0 g
s
.593 .949 .866 r
.63211 .41524 m .63055 .41543 L .64064 .40979 L p F P
0 g
s
.121 0 .369 r
.73929 .31339 m .73803 .3149 L .73893 .31023 L p F P
0 g
s
.121 0 .369 r
.73893 .31023 m .73939 .30968 L .73929 .31339 L p F P
0 g
s
.017 .44 .868 r
.21527 .28721 m .21275 .28612 L .21651 .28921 L p F P
0 g
s
.017 .44 .868 r
.21651 .28921 m .21841 .29001 L .21527 .28721 L p F P
0 g
s
.709 .181 0 r
.29136 .33881 m .29695 .34113 L .29355 .33818 L p F P
0 g
s
.709 .181 0 r
.29355 .33818 m .28818 .33579 L .29136 .33881 L p F P
0 g
s
.572 .908 .976 r
.5493 .44537 m .55015 .44559 L .54014 .44906 L p F P
0 g
s
.572 .908 .976 r
.54014 .44906 m .53939 .44887 L .5493 .44537 L p F P
0 g
s
0 .345 .771 r
.16613 .40085 m .17029 .40366 L .16556 .40116 L p F P
0 g
s
0 .345 .771 r
.16203 .39868 m .16613 .40085 L p .16556 .40116 L F P
0 g
s
0 .345 .771 r
.16556 .40116 m .16432 .40033 L .16203 .39868 L p F P
0 g
s
.431 0 0 r
.14369 .38578 m .14157 .38415 L .14544 .3871 L p F P
0 g
s
.431 0 0 r
.14544 .3871 m .14696 .38827 L .14369 .38578 L p F P
0 g
s
.361 0 .109 r
.48531 .35817 m .48964 .35721 L .48512 .3585 L closepath p F P
0 g
s
.579 .941 .825 r
.64584 .40756 m .64297 .40928 L .64066 .40979 L p F P
0 g
s
.725 .986 .891 r
.61632 .28188 m .61525 .28262 L .61284 .28264 L p F P
0 g
s
.234 .122 .515 r
.746 .29699 m .74353 .30016 L .74291 .29603 L p F P
0 g
s
.234 .122 .515 r
.74291 .29603 m .74558 .29259 L .746 .29699 L p F P
0 g
s
.326 .258 .625 r
.74415 .28403 m .74575 .28656 L .74488 .28778 L closepath p F P
0 g
s
0 0 0 r
.54083 .33103 m .54037 .3315 L .54491 .32884 L closepath p F P
0 g
s
.426 0 0 r
.23732 .30301 m .23438 .30083 L .23355 .30021 L p F P
0 g
s
.426 0 0 r
.23355 .30021 m .23702 .30278 L p .23732 .30301 L F P
0 g
s
.662 .142 0 r
.12027 .36606 m .12386 .36916 L .12116 .36601 L p F P
0 g
s
.662 .142 0 r
.12116 .36601 m .11757 .36292 L .12027 .36606 L p F P
0 g
s
.69 .248 .197 r
.35909 .36545 m .35932 .36565 L .35894 .36558 L closepath p F P
0 g
s
.584 .93 .951 r
.58287 .43445 m .58537 .43482 L .57532 .43897 L p F P
0 g
s
.584 .93 .951 r
.57641 .43713 m .58287 .43445 L p .57532 .43897 L F P
0 g
s
.584 .93 .951 r
.57532 .43897 m .57305 .43866 L .57641 .43713 L p F P
0 g
s
.756 .979 .915 r
.62526 .27569 m .61632 .28188 L .62291 .27535 L closepath p F P
0 g
s
.725 .986 .891 r
.62286 .27534 m .62291 .27535 L .61632 .28188 L p F P
0 g
s
.725 .986 .891 r
.61284 .28264 m .62286 .27534 L p .61632 .28188 L F P
0 g
s
.241 0 .013 r
.51698 .34608 m .51783 .34476 L .50787 .34867 L p F P
0 g
s
.241 0 .013 r
.50787 .34867 m .50715 .34978 L .51698 .34608 L p F P
0 g
s
.57 .006 0 r
.25183 .31264 m .25359 .31408 L .25804 .31685 L p F P
0 g
s
.57 .006 0 r
.25707 .31694 m .26168 .31966 L .25804 .31685 L p F P
0 g
s
.57 .006 0 r
.25804 .31685 m .25359 .31408 L .25707 .31694 L p F P
0 g
s
.46 .058 .188 r
.47031 .36415 m .46193 .36582 L .46047 .36848 L p F P
0 g
s
0 0 .089 r
.73077 .3311 m .72614 .3362 L .72911 .3308 L p F P
0 g
s
0 0 .089 r
.72911 .3308 m .73148 .3282 L .73077 .3311 L p F P
0 g
s
0 .404 .851 r
.20429 .28073 m .20326 .28025 L .20012 .27718 L p F P
0 g
s
.043 .517 .886 r
.21436 .42623 m .21112 .42528 L .20792 .42324 L p F P
0 g
s
.031 .512 .88 r
.21112 .42528 m .21436 .42623 L .21926 .42872 L p F P
0 g
s
.483 .779 .997 r
.35936 .45951 m .3508 .4603 L .34784 .4586 L p F P
0 g
s
.462 .778 .998 r
.36101 .45975 m .36337 .46109 L p .3508 .4603 L F P
0 g
s
.462 .778 .998 r
.3508 .4603 m .35936 .45951 L .36101 .45975 L p F P
0 g
s
.086 0 .358 r
.74258 .3092 m .73929 .31339 L .73939 .30968 L p F P
0 g
s
.086 0 .358 r
.73939 .30968 m .7434 .30455 L .74258 .3092 L p F P
0 g
s
.073 .538 .9 r
.22017 .42779 m .21436 .42623 L .21926 .42872 L p F P
0 g
s
.073 .538 .9 r
.21926 .42872 m .22335 .42982 L .22017 .42779 L p F P
0 g
s
.658 .691 .869 r
.7055 .244 m .71579 .24064 L .7182 .24455 L p F P
0 g
s
.672 .711 .877 r
.71579 .24064 m .7055 .244 L .70311 .2407 L p F P
0 g
s
.694 .743 .889 r
.69289 .245 m .70311 .2407 L .7055 .244 L p F P
0 g
s
0 0 0 r
.71308 .35385 m .71302 .35391 L .71427 .35166 L p F P
0 g
s
0 0 0 r
.71427 .35166 m .71809 .34773 L .71308 .35385 L p F P
0 g
s
0 .449 .837 r
.19577 .41805 m .19862 .41909 L .20329 .42168 L p F P
0 g
s
0 .479 .862 r
.20472 .42114 m .19862 .41909 L .20329 .42168 L p F P
0 g
s
0 .479 .862 r
.20329 .42168 m .20792 .42324 L .20472 .42114 L p F P
0 g
s
.771 .902 .933 r
.65777 .25689 m .65181 .26062 L .65579 .25563 L closepath p F P
0 g
s
.766 .928 .94 r
.65539 .25538 m .65579 .25563 L .65181 .26062 L p F P
0 g
s
.766 .928 .94 r
.64533 .262 m .65539 .25538 L p .65181 .26062 L F P
0 g
s
.591 .185 .241 r
.42362 .37238 m .41264 .37266 L .41222 .37334 L p F P
0 g
s
.614 .211 .255 r
.41264 .37266 m .41222 .37334 L .41099 .37265 L closepath p F P
0 g
s
.698 .267 .222 r
.35676 .36767 m .36259 .36874 L .35932 .36565 L p F P
0 g
s
.698 .267 .222 r
.35932 .36565 m .35894 .36558 L .35676 .36767 L p F P
0 g
s
.612 .217 .27 r
.40399 .37521 m .39973 .37243 L .41099 .37265 L p F P
0 g
s
.612 .217 .27 r
.41107 .37531 m .40399 .37521 L p .41099 .37265 L F P
0 g
s
.612 .217 .27 r
.41099 .37265 m .41222 .37334 L .41107 .37531 L p F P
0 g
s
0 .379 .788 r
.18048 .41 m .18399 .41155 L .18843 .41424 L p F P
0 g
s
0 .384 .796 r
.18399 .41155 m .18048 .41 L .17724 .40778 L p F P
0 g
s
.589 .922 .966 r
.5728 .4386 m .57305 .43866 L .56351 .44265 L p F P
0 g
s
.589 .922 .966 r
.56351 .44265 m .56275 .44249 L .5728 .4386 L p F P
0 g
s
.474 .864 .668 r
.58283 .30412 m .57471 .3096 L .58147 .30486 L closepath p F P
0 g
s
0 0 0 r
.58037 .30547 m .58147 .30486 L .57471 .3096 L p F P
0 g
s
0 0 0 r
.57419 .30984 m .58037 .30547 L p .57471 .3096 L F P
0 g
s
0 0 0 r
.57103 .31212 m .57419 .30984 L p .57471 .3096 L F P
0 g
s
.697 .266 .221 r
.35472 .3673 m .35676 .36767 L .35894 .36558 L p F P
0 g
s
.697 .266 .221 r
.35894 .36558 m .35143 .36422 L .35472 .3673 L p F P
0 g
s
.547 .922 .778 r
.65303 .40308 m .64584 .40756 L .65183 .40346 L closepath p F P
0 g
s
.579 .941 .825 r
.65072 .40368 m .65183 .40346 L .64584 .40756 L p F P
0 g
s
.579 .941 .825 r
.64079 .4097 m .65072 .40368 L p .64584 .40756 L F P
0 g
s
.579 .941 .825 r
.64066 .40979 m .64079 .4097 L p .64584 .40756 L F P
0 g
s
.622 .209 .239 r
.39963 .37237 m .39973 .37243 L .39959 .37243 L closepath p F P
0 g
s
.376 0 .135 r
.48964 .35721 m .48512 .3585 L .48367 .36111 L p F P
0 g
s
.053 0 0 r
.53781 .33461 m .53907 .33307 L .52978 .33749 L p F P
0 g
s
.053 0 0 r
.53165 .33794 m .53781 .33461 L p .52978 .33749 L F P
0 g
s
.053 0 0 r
.52978 .33749 m .5281 .33966 L .53165 .33794 L p F P
0 g
s
.706 .761 .894 r
.70311 .2407 m .69289 .245 L .69052 .24223 L p F P
0 g
s
.39 .346 .689 r
.75028 .27324 m .74727 .27753 L .74388 .27441 L p F P
0 g
s
.39 .346 .689 r
.7496 .2705 m .75028 .27324 L p .74388 .27441 L F P
0 g
s
.39 .346 .689 r
.74388 .27441 m .74767 .26889 L .7496 .2705 L p F P
0 g
s
0 .453 .845 r
.19862 .41909 m .19577 .41805 L .19255 .41593 L p F P
0 g
s
.632 .231 .266 r
.39794 .37503 m .40399 .37521 L .39973 .37243 L p F P
0 g
s
.632 .231 .266 r
.39973 .37243 m .39959 .37243 L .39794 .37503 L p F P
0 g
s
.648 .249 .276 r
.39331 .37478 m .39794 .37503 L .39959 .37243 L p F P
0 g
s
.648 .249 .276 r
.39959 .37243 m .38942 .37188 L .39331 .37478 L p F P
0 g
s
.332 .589 .938 r
.18177 .26451 m .1791 .26402 L .18231 .26737 L p F P
0 g
s
.332 .589 .938 r
.18231 .26737 m .18493 .26785 L .18177 .26451 L p F P
0 g
s
.639 .078 0 r
.27799 .33078 m .27459 .32785 L .27965 .33037 L p F P
0 g
s
.639 .078 0 r
.28066 .33204 m .27799 .33078 L p .27965 .33037 L F P
0 g
s
.639 .078 0 r
.27965 .33037 m .2822 .33243 L .28066 .33204 L p F P
0 g
s
.591 .19 .252 r
.4252 .37232 m .42484 .37293 L .42362 .37238 L closepath p F P
0 g
s
.591 .185 .241 r
.4237 .37504 m .42484 .37293 L .42362 .37238 L p F P
0 g
s
.591 .185 .241 r
.41581 .37523 m .4237 .37504 L p .42362 .37238 L F P
0 g
s
.591 .185 .241 r
.41222 .37334 m .41581 .37523 L p .42362 .37238 L F P
0 g
s
.578 .176 .244 r
.43589 .37425 m .43732 .37148 L .4252 .37232 L p F P
0 g
s
.578 .176 .244 r
.42924 .37469 m .43589 .37425 L p .4252 .37232 L F P
0 g
s
.578 .176 .244 r
.4252 .37232 m .42484 .37293 L .42924 .37469 L p F P
0 g
s
0 .265 .702 r
.16432 .40033 m .16203 .39868 L .16144 .39834 L closepath p F P
0 g
s
.381 .739 .991 r
.31021 .45467 m .31333 .45463 L .32033 .45632 L p F P
0 g
s
.379 .739 .991 r
.31021 .45467 m .31333 .45463 L .30784 .45332 L closepath p F P
0 g
s
.147 .588 .93 r
.23565 .4338 m .23137 .43292 L .23649 .43531 L p F P
0 g
s
.147 .588 .93 r
.23649 .43531 m .23881 .43579 L .23565 .4338 L p F P
0 g
s
.399 .741 .992 r
.31971 .45446 m .31333 .45463 L .32033 .45632 L p F P
0 g
s
.399 .741 .992 r
.32033 .45632 m .32272 .45628 L .31971 .45446 L p F P
0 g
s
.593 .063 0 r
.12552 .37086 m .12386 .36916 L .1275 .37222 L p F P
0 g
s
.593 .063 0 r
.1275 .37222 m .1288 .37355 L .12552 .37086 L p F P
0 g
s
.57 .012 0 r
.25359 .31408 m .25183 .31264 L .24868 .31072 L p F P
0 g
s
0 .413 .818 r
.18932 .41374 m .18399 .41155 L .18843 .41424 L p F P
0 g
s
0 .413 .818 r
.18843 .41424 m .19255 .41593 L .18932 .41374 L p F P
0 g
s
.553 .933 .864 r
.62048 .42084 m .61972 .42122 L .62039 .42085 L closepath p F P
0 g
s
.578 .942 .895 r
.61807 .42089 m .62039 .42085 L .61972 .42122 L p F P
0 g
s
.578 .942 .895 r
.60995 .42496 m .61807 .42089 L p .61972 .42122 L F P
0 g
s
.578 .942 .895 r
.60822 .42593 m .60995 .42496 L p .61972 .42122 L F P
0 g
s
.581 .896 .986 r
.53754 .44829 m .52754 .45155 L .5249 .45069 L p F P
0 g
s
.564 .89 .987 r
.51492 .45376 m .5249 .45069 L .52754 .45155 L p F P
0 g
s
.562 0 0 r
.26791 .32303 m .267 .32267 L .26648 .32229 L closepath p F P
0 g
s
.593 .942 .927 r
.60554 .42574 m .60799 .42592 L .59792 .43059 L p F P
0 g
s
.593 .942 .927 r
.59678 .42984 m .60554 .42574 L p .59792 .43059 L F P
0 g
s
.593 .942 .927 r
.59792 .43059 m .59559 .43046 L .59678 .42984 L p F P
0 g
s
.577 .943 .867 r
.62907 .41559 m .63055 .41543 L .62048 .42084 L p F P
0 g
s
.577 .943 .867 r
.62048 .42084 m .62039 .42085 L .62907 .41559 L p F P
0 g
s
.477 .816 .523 r
.6948 .372 m .69316 .3735 L .70024 .36704 L closepath p F P
0 g
s
.213 .639 .952 r
.25429 .44122 m .25529 .44136 L .25303 .44047 L closepath p F P
0 g
s
.536 .135 .229 r
.43749 .37119 m .43829 .37138 L .43732 .37148 L closepath p F P
0 g
s
.576 .878 .993 r
.51225 .45273 m .51375 .45334 L .5032 .45602 L p F P
0 g
s
.576 .878 .993 r
.5032 .45602 m .50229 .45565 L .51225 .45273 L p F P
0 g
s
.598 .936 .948 r
.59545 .43044 m .59559 .43046 L .5864 .43495 L p F P
0 g
s
.598 .936 .948 r
.5864 .43495 m .58537 .43482 L .59545 .43044 L p F P
0 g
s
.652 .242 .253 r
.38423 .37409 m .39331 .37478 L .38942 .37188 L p F P
0 g
s
.652 .242 .253 r
.38942 .37188 m .38603 .37162 L .38423 .37409 L p F P
0 g
s
.501 .522 .81 r
.74345 .25334 m .7339 .25244 L .73369 .25279 L p F P
0 g
s
.501 .522 .81 r
.73982 .25885 m .74345 .25334 L p .73369 .25279 L F P
0 g
s
.545 .559 .82 r
.73353 .25243 m .7339 .25244 L .73369 .25279 L closepath p F P
0 g
s
.632 .656 .855 r
.72327 .24348 m .7182 .24455 L .71579 .24064 L p F P
0 g
s
.269 .185 .572 r
.74715 .29041 m .74558 .29259 L .74488 .28778 L p F P
0 g
s
.269 .185 .572 r
.74488 .28778 m .74575 .28656 L .74715 .29041 L p F P
0 g
s
.485 .788 .998 r
.37533 .4613 m .37596 .46166 L p .36337 .46109 L F P
0 g
s
.485 .788 .998 r
.36337 .46109 m .36831 .46051 L .37533 .4613 L p F P
0 g
s
.481 .79 .999 r
.36337 .46109 m .36831 .46051 L .36101 .45975 L closepath p F P
0 g
s
0 0 0 r
.54491 .32884 m .54037 .3315 L .53907 .33307 L p F P
0 g
s
.609 .953 .902 r
.62817 .4156 m .62907 .41559 L .62039 .42085 L p F P
0 g
s
.609 .953 .902 r
.62039 .42085 m .61807 .42089 L .62817 .4156 L p F P
0 g
s
.739 .256 .098 r
.31456 .35182 m .32068 .35392 L .31764 .35079 L p F P
0 g
s
.739 .256 .098 r
.31277 .34982 m .31456 .35182 L p .31764 .35079 L F P
0 g
s
.739 .256 .098 r
.31764 .35079 m .31402 .34949 L .31277 .34982 L p F P
0 g
s
.59 .904 .983 r
.54756 .44482 m .5493 .44537 L .53939 .44887 L p F P
0 g
s
.59 .904 .983 r
.53939 .44887 m .53754 .44829 L .54756 .44482 L p F P
0 g
s
0 .404 .851 r
.20012 .27718 m .20082 .27751 L .20429 .28073 L p F P
0 g
s
0 .407 .853 r
.20559 .27978 m .20911 .28298 L .20429 .28073 L p F P
0 g
s
0 .407 .853 r
.20429 .28073 m .20082 .27751 L .20559 .27978 L p F P
0 g
s
.542 .819 .997 r
.42119 .46273 m .41534 .46287 L .4138 .462 L p F P
0 g
s
.529 .814 .998 r
.41534 .46287 m .4138 .462 L .40898 .46285 L closepath p F P
0 g
s
.532 .813 .998 r
.41095 .46027 m .4138 .462 L .40898 .46285 L p F P
0 g
s
.532 .813 .998 r
.40117 .46209 m .41095 .46027 L p .40898 .46285 L F P
0 g
s
.532 .813 .998 r
.40898 .46285 m .40243 .4628 L .40117 .46209 L p F P
0 g
s
.729 .268 .154 r
.3302 .35902 m .33695 .36088 L .33383 .35776 L p F P
0 g
s
.729 .268 .154 r
.32815 .35674 m .3302 .35902 L p .33383 .35776 L F P
0 g
s
.729 .268 .154 r
.33383 .35776 m .32897 .35633 L .32815 .35674 L p F P
0 g
s
0 .148 .593 r
.14696 .38827 m .14926 .38989 L .15325 .39278 L p F P
0 g
s
0 .21 .657 r
.15343 .39256 m .1574 .39547 L .15325 .39278 L p F P
0 g
s
0 .21 .657 r
.15325 .39278 m .14926 .38989 L .15343 .39256 L p F P
0 g
s
.141 0 0 r
.52781 .34004 m .5281 .33966 L .51857 .34375 L p F P
0 g
s
.141 0 0 r
.51857 .34375 m .51783 .34476 L .52781 .34004 L p F P
0 g
s
.559 .58 .831 r
.7339 .25244 m .73353 .25243 L .73106 .24727 L p F P
0 g
s
.288 .684 .973 r
.28227 .4488 m .2822 .44876 L .28214 .44875 L closepath p F P
0 g
s
.516 .807 .998 r
.40243 .4628 m .40117 .46209 L .39775 .46263 L closepath p F P
0 g
s
0 .289 .747 r
.22529 .29409 m .22921 .29711 L .22484 .29464 L p F P
0 g
s
0 .289 .747 r
.22484 .29464 m .22103 .29159 L .22529 .29409 L p F P
0 g
s
0 .272 .732 r
.21841 .29001 m .22103 .29159 L .22484 .29464 L p F P
0 g
s
.298 .684 .975 r
.27912 .44687 m .27624 .44666 L .28214 .44875 L p F P
0 g
s
.298 .684 .975 r
.28214 .44875 m .2822 .44876 L .27912 .44687 L p F P
0 g
s
.754 .979 .916 r
.62913 .27302 m .62526 .27569 L .62291 .27535 L p F P
0 g
s
.539 .822 .998 r
.42788 .46253 m .42643 .46172 L .42119 .46273 L closepath p F P
0 g
s
.542 .819 .997 r
.4236 .46003 m .42643 .46172 L .42119 .46273 L p F P
0 g
s
.542 .819 .997 r
.4138 .462 m .4236 .46003 L p .42119 .46273 L F P
0 g
s
.351 .708 .985 r
.29161 .44913 m .2822 .44876 L .27912 .44687 L p F P
0 g
s
.388 0 0 r
.24505 .30838 m .24113 .30571 L .24537 .30857 L p F P
0 g
s
.388 0 0 r
.24677 .30949 m .24505 .30838 L p .24537 .30857 L F P
0 g
s
.388 0 0 r
.24537 .30857 m .24868 .31072 L .24677 .30949 L p F P
0 g
s
.78 .292 0 r
.11159 .35657 m .11098 .35563 L .10769 .35271 L p F P
0 g
s
.663 .254 .26 r
.38355 .37402 m .38423 .37409 L .38603 .37162 L p F P
0 g
s
.663 .254 .26 r
.38603 .37162 m .37987 .37105 L .38355 .37402 L p F P
0 g
s
.772 .902 .933 r
.66549 .24901 m .66786 .25081 L .65777 .25689 L p F P
0 g
s
.772 .902 .933 r
.65658 .25463 m .66549 .24901 L p .65777 .25689 L F P
0 g
s
.772 .902 .933 r
.65777 .25689 m .65579 .25563 L .65658 .25463 L p F P
0 g
s
.519 .806 .998 r
.3983 .46034 m .40117 .46209 L .39775 .46263 L p F P
0 g
s
.519 .806 .998 r
.38856 .46199 m .3983 .46034 L p .39775 .46263 L F P
0 g
s
.519 .806 .998 r
.39775 .46263 m .38912 .46231 L .38856 .46199 L p F P
0 g
s
.559 .58 .831 r
.73106 .24727 m .73707 .24708 L .7339 .25244 L p F P
0 g
s
.54 .555 .819 r
.74388 .25268 m .74345 .25334 L .7339 .25244 L p F P
0 g
s
.54 .555 .819 r
.74165 .24723 m .74388 .25268 L p .7339 .25244 L F P
0 g
s
.54 .555 .819 r
.7339 .25244 m .73707 .24708 L .74165 .24723 L p F P
0 g
s
.606 .21 .266 r
.41222 .37334 m .41581 .37523 L .41107 .37531 L closepath p F P
0 g
s
.547 .158 .254 r
.43829 .37138 m .43732 .37148 L .43589 .37425 L p F P
0 g
s
.738 .234 .024 r
.2999 .34426 m .30556 .34654 L .30249 .34345 L p F P
0 g
s
.738 .234 .024 r
.29745 .34158 m .2999 .34426 L p .30249 .34345 L F P
0 g
s
.738 .234 .024 r
.30249 .34345 m .29807 .34156 L .29745 .34158 L p F P
0 g
s
0 .27 .737 r
.22103 .29159 m .21841 .29001 L .21527 .28721 L p F P
0 g
s
.55 .826 .997 r
.43475 .46215 m .42788 .46253 L .42643 .46172 L p F P
0 g
s
.729 .83 .928 r
.68894 .24302 m .68035 .24734 L .67798 .24506 L p F P
0 g
s
0 .344 .768 r
.174 .40549 m .17029 .40366 L .17452 .40644 L p F P
0 g
s
0 .344 .768 r
.17452 .40644 m .17724 .40778 L .174 .40549 L p F P
0 g
s
.502 .878 .676 r
.58769 .30069 m .58283 .30412 L .58147 .30486 L p F P
0 g
s
.845 .389 0 r
.09941 .34358 m .10272 .34683 L .10098 .34337 L p F P
0 g
s
.845 .389 0 r
.10098 .34337 m .09767 .34012 L .09941 .34358 L p F P
0 g
s
.45 .425 .74 r
.74876 .26728 m .74767 .26889 L .74283 .26628 L p F P
0 g
s
.45 .425 .74 r
.74682 .26085 m .74876 .26728 L p .74283 .26628 L F P
0 g
s
.45 .425 .74 r
.74283 .26628 m .7466 .26075 L .74682 .26085 L p F P
0 g
s
.547 .155 .251 r
.44909 .37022 m .43829 .37138 L .44525 .37323 L p F P
0 g
s
.547 .158 .254 r
.43589 .37425 m .44525 .37323 L .43829 .37138 L p F P
0 g
s
0 .154 .606 r
.14926 .38989 m .14696 .38827 L .14369 .38578 L p F P
0 g
s
.551 0 0 r
.26384 .32131 m .26168 .31966 L .26648 .32229 L p F P
0 g
s
.551 0 0 r
.26648 .32229 m .267 .32267 L .26384 .32131 L p F P
0 g
s
.578 .186 .263 r
.42484 .37293 m .42924 .37469 L .4237 .37504 L closepath p F P
0 g
s
.568 .931 .782 r
.66069 .39813 m .65303 .40308 L .65183 .40346 L p F P
0 g
s
.283 .671 .971 r
.26246 .44166 m .26357 .44235 L .25529 .44136 L p F P
0 g
s
.283 .671 .971 r
.25894 .44019 m .26246 .44166 L p .25529 .44136 L F P
0 g
s
.283 .671 .971 r
.25116 .4393 m .25894 .44019 L p .25529 .44136 L F P
0 g
s
.283 .671 .971 r
.25529 .44136 m .25303 .44047 L .25116 .4393 L p F P
0 g
s
.562 .026 0 r
.1288 .37355 m .13059 .37524 L .13434 .37826 L p F P
0 g
s
.481 0 0 r
.13402 .37815 m .13776 .38117 L .13434 .37826 L p F P
0 g
s
.481 0 0 r
.13434 .37826 m .13059 .37524 L .13402 .37815 L p F P
0 g
s
0 0 0 r
.73051 .33184 m .73077 .3311 L .72614 .3362 L p F P
0 g
s
0 0 0 r
.72792 .33589 m .73051 .33184 L p .72614 .3362 L F P
0 g
s
0 0 0 r
.72271 .34167 m .72792 .33589 L p .72614 .3362 L F P
0 g
s
0 0 0 r
.72614 .3362 m .72275 .34154 L .72271 .34167 L p F P
0 g
s
.721 .291 .228 r
.34711 .36576 m .35472 .3673 L .35143 .36422 L p F P
0 g
s
.721 .291 .228 r
.35143 .36422 m .34414 .36257 L .34711 .36576 L p F P
0 g
s
.361 0 .103 r
.49551 .35555 m .49524 .35601 L .48964 .35721 L closepath p F P
0 g
s
.376 0 .135 r
.49409 .35817 m .49524 .35601 L .48964 .35721 L p F P
0 g
s
.376 0 .135 r
.48367 .36111 m .49409 .35817 L p .48964 .35721 L F P
0 g
s
.501 .799 .999 r
.38912 .46231 m .38856 .46199 L .38721 .46218 L closepath p F P
0 g
s
.599 .921 .971 r
.5728 .4386 m .56275 .44249 L .56019 .4419 L p F P
0 g
s
.58 .915 .971 r
.55015 .44559 m .56019 .4419 L .56275 .44249 L p F P
0 g
s
.575 .888 .99 r
.52409 .45039 m .5249 .45069 L .51492 .45376 L p F P
0 g
s
.575 .888 .99 r
.51492 .45376 m .51375 .45334 L .52409 .45039 L p F P
0 g
s
.461 .055 .181 r
.47294 .36364 m .47266 .36414 L .47031 .36415 L closepath p F P
0 g
s
.46 .058 .188 r
.47154 .36635 m .47266 .36414 L .47031 .36415 L p F P
0 g
s
.46 .058 .188 r
.46047 .36848 m .47154 .36635 L p .47031 .36415 L F P
0 g
s
.774 .964 .926 r
.63529 .26879 m .62913 .27302 L .63351 .26829 L closepath p F P
0 g
s
.754 .979 .916 r
.6329 .26812 m .63351 .26829 L .62913 .27302 L p F P
0 g
s
.754 .979 .916 r
.62302 .27522 m .6329 .26812 L p .62913 .27302 L F P
0 g
s
.754 .979 .916 r
.62291 .27535 m .62302 .27522 L p .62913 .27302 L F P
0 g
s
.511 .793 .996 r
.38566 .46021 m .37743 .46146 L .38721 .46218 L p F P
0 g
s
.511 .793 .996 r
.38721 .46218 m .38856 .46199 L .38566 .46021 L p F P
0 g
s
.502 .798 .998 r
.37596 .46166 m .37743 .46146 L .38721 .46218 L p F P
0 g
s
.799 .32 0 r
.1044 .34965 m .10272 .34683 L .10609 .35004 L p F P
0 g
s
.799 .32 0 r
.10609 .35004 m .10769 .35271 L .1044 .34965 L p F P
0 g
s
.675 .258 .246 r
.37437 .37306 m .38355 .37402 L .37987 .37105 L p F P
0 g
s
.675 .258 .246 r
.37152 .37037 m .37437 .37306 L p .37987 .37105 L F P
0 g
s
.675 .258 .246 r
.37987 .37105 m .37178 .37006 L .37152 .37037 L p F P
0 g
s
.546 .829 .998 r
.4401 .46181 m .43907 .46126 L .43475 .46215 L closepath p F P
0 g
s
.55 .826 .997 r
.43626 .45962 m .43907 .46126 L .43475 .46215 L p F P
0 g
s
.55 .826 .997 r
.42643 .46172 m .43626 .45962 L p .43475 .46215 L F P
0 g
s
.502 .798 .998 r
.37596 .46166 m .37743 .46146 L .37533 .4613 L closepath p F P
0 g
s
.499 .493 .781 r
.74672 .26056 m .7466 .26075 L .73982 .25885 L p F P
0 g
s
.499 .493 .781 r
.74419 .25349 m .74672 .26056 L p .73982 .25885 L F P
0 g
s
.499 .493 .781 r
.73982 .25885 m .74345 .25334 L .74419 .25349 L p F P
0 g
s
.038 0 .277 r
.73898 .31681 m .73645 .31981 L .73803 .3149 L p F P
0 g
s
.038 0 .277 r
.73803 .3149 m .73929 .31339 L .73898 .31681 L p F P
0 g
s
.449 .756 .995 r
.33228 .45576 m .32272 .45628 L .31971 .45446 L p F P
0 g
s
0 .301 .737 r
.23438 .30083 m .23355 .30021 L .23327 .30006 L closepath p F P
0 g
s
0 0 0 r
.55036 .32569 m .54491 .32884 L .54985 .32624 L closepath p F P
0 g
s
0 0 0 r
.54807 .32822 m .54985 .32624 L .54491 .32884 L p F P
0 g
s
0 0 0 r
.53907 .33307 m .54807 .32822 L p .54491 .32884 L F P
0 g
s
.719 .191 0 r
.2822 .33243 m .28306 .33329 L .28818 .33579 L p F P
0 g
s
.728 .205 0 r
.28606 .33639 m .29136 .33881 L .28818 .33579 L p F P
0 g
s
.728 .205 0 r
.28818 .33579 m .28306 .33329 L .28606 .33639 L p F P
0 g
s
.251 0 .03 r
.51546 .34851 m .51698 .34608 L .50715 .34978 L p F P
0 g
s
.251 0 .03 r
.50715 .34978 m .50563 .35223 L .51546 .34851 L p F P
0 g
s
.576 .929 .754 r
.59283 .2971 m .58769 .30069 L .59183 .29749 L closepath p F P
0 g
s
.502 .878 .676 r
.59038 .29809 m .59183 .29749 L .58769 .30069 L p F P
0 g
s
.502 .878 .676 r
.5859 .30138 m .59038 .29809 L p .58769 .30069 L F P
0 g
s
.502 .878 .676 r
.58147 .30486 m .5859 .30138 L p .58769 .30069 L F P
0 g
s
.683 .137 0 r
.26975 .32524 m .267 .32267 L .26384 .32131 L p F P
0 g
s
.557 .833 .997 r
.45018 .46095 m .4401 .46181 L .43907 .46126 L p F P
0 g
s
.268 .187 .575 r
.75108 .28487 m .74715 .29041 L .74575 .28656 L p F P
0 g
s
.268 .187 .575 r
.74575 .28656 m .74964 .28103 L .75108 .28487 L p F P
0 g
s
.426 .019 .163 r
.48257 .36316 m .48367 .36111 L .47294 .36364 L p F P
0 g
s
.426 .019 .163 r
.47294 .36364 m .47266 .36414 L .48257 .36316 L p F P
0 g
s
.78 .292 0 r
.10769 .35271 m .10813 .3534 L .11159 .35657 L p F P
0 g
s
.702 .195 0 r
.1106 .35661 m .11405 .35978 L .11159 .35657 L p F P
0 g
s
.702 .195 0 r
.11159 .35657 m .10813 .3534 L .1106 .35661 L p F P
0 g
s
.193 .618 .946 r
.23881 .43579 m .24452 .43676 L .24982 .4391 L p F P
0 g
s
.205 .622 .95 r
.24452 .43676 m .23881 .43579 L .23565 .4338 L p F P
0 g
s
.714 .22 .065 r
.31402 .34949 m .31277 .34982 L .31156 .34868 L closepath p F P
0 g
s
.421 .75 .994 r
.31669 .45258 m .31971 .45446 L .31333 .45463 L p F P
0 g
s
.421 .75 .994 r
.30717 .45292 m .31669 .45258 L p .31333 .45463 L F P
0 g
s
.421 .75 .994 r
.31333 .45463 m .30784 .45332 L .30717 .45292 L p F P
0 g
s
.551 .019 0 r
.13059 .37524 m .1288 .37355 L .12552 .37086 L p F P
0 g
s
.171 .504 .91 r
.18493 .26785 m .18844 .26906 L .19174 .27237 L p F P
0 g
s
.199 .521 .918 r
.19382 .27077 m .18844 .26906 L .19174 .27237 L p F P
0 g
s
.199 .521 .918 r
.19174 .27237 m .19697 .27402 L .19382 .27077 L p F P
0 g
s
.587 .873 .994 r
.51225 .45273 m .50229 .45565 L .4996 .45448 L p F P
0 g
s
.572 .869 .995 r
.48965 .45723 m .4996 .45448 L .50229 .45565 L p F P
0 g
s
.547 .8 .992 r
.3983 .46034 m .38856 .46199 L .38566 .46021 L p F P
0 g
s
.18 .503 .909 r
.18844 .26906 m .18493 .26785 L .18177 .26451 L p F P
0 g
s
.215 .632 .953 r
.25303 .44047 m .25116 .4393 L .24982 .4391 L closepath p F P
0 g
s
.714 .245 .137 r
.32897 .35633 m .32815 .35674 L .32722 .35586 L closepath p F P
0 g
s
.524 .797 .995 r
.38276 .45834 m .38566 .46021 L .37743 .46146 L p F P
0 g
s
.524 .797 .995 r
.37304 .4599 m .38276 .45834 L p .37743 .46146 L F P
0 g
s
.524 .797 .995 r
.37743 .46146 m .37533 .4613 L .37304 .4599 L p F P
0 g
s
0 .272 .714 r
.15878 .39626 m .1574 .39547 L .16144 .39834 L p F P
0 g
s
0 .272 .714 r
.16144 .39834 m .16203 .39868 L .15878 .39626 L p F P
0 g
s
.752 .861 .929 r
.66822 .25111 m .66786 .25081 L .66892 .25021 L closepath p F P
0 g
s
0 0 .074 r
.73147 .33028 m .73077 .3311 L .73148 .3282 L p F P
0 g
s
0 0 .074 r
.73148 .3282 m .73425 .32494 L .73147 .33028 L p F P
0 g
s
.717 .269 .186 r
.3436 .36203 m .34414 .36257 L .34316 .36233 L closepath p F P
0 g
s
.769 .963 .929 r
.64236 .26401 m .63529 .26879 L .63351 .26829 L p F P
0 g
s
.163 .031 .442 r
.74615 .30103 m .7434 .30455 L .74353 .30016 L p F P
0 g
s
.163 .031 .442 r
.74353 .30016 m .746 .29699 L .74615 .30103 L p F P
0 g
s
.021 .435 .867 r
.21212 .28431 m .20911 .28298 L .21275 .28612 L p F P
0 g
s
.021 .435 .867 r
.21275 .28612 m .21527 .28721 L .21212 .28431 L p F P
0 g
s
.51 .118 .233 r
.45683 .36902 m .44909 .37022 L .44767 .37297 L p F P
0 g
s
.547 .155 .251 r
.44525 .37323 m .44767 .37297 L .44909 .37022 L p F P
0 g
s
0 0 0 r
.70407 .36319 m .70311 .36426 L .70705 .36031 L closepath p F P
0 g
s
.503 .789 .997 r
.37533 .4613 m .37304 .4599 L .36831 .46051 L closepath p F P
0 g
s
.57 .012 0 r
.24868 .31072 m .2493 .31124 L .25359 .31408 L p F P
0 g
s
.583 .025 0 r
.25264 .31415 m .25707 .31694 L .25359 .31408 L p F P
0 g
s
.583 .025 0 r
.25359 .31408 m .2493 .31124 L .25264 .31415 L p F P
0 g
s
0 .31 .752 r
.2304 .29777 m .22921 .29711 L .23327 .30006 L p F P
0 g
s
0 .31 .752 r
.23327 .30006 m .23355 .30021 L .2304 .29777 L p F P
0 g
s
.043 .517 .886 r
.20792 .42324 m .20953 .42371 L .21436 .42623 L p F P
0 g
s
.084 .541 .905 r
.2164 .42552 m .20953 .42371 L .21436 .42623 L p F P
0 g
s
.084 .541 .905 r
.21815 .42646 m .2164 .42552 L p .21436 .42623 L F P
0 g
s
.084 .541 .905 r
.21436 .42623 m .22017 .42779 L .21815 .42646 L p F P
0 g
s
0 .113 .572 r
.14041 .38321 m .13776 .38117 L .14157 .38415 L p F P
0 g
s
0 .113 .572 r
.14157 .38415 m .14369 .38578 L .14041 .38321 L p F P
0 g
s
.593 .937 .757 r
.59978 .2921 m .59283 .2971 L .59183 .29749 L p F P
0 g
s
.531 .904 .725 r
.66309 .39651 m .66069 .39813 L .66265 .3967 L closepath p F P
0 g
s
.568 .931 .782 r
.66081 .39724 m .66265 .3967 L .66069 .39813 L p F P
0 g
s
.568 .931 .782 r
.65679 .39987 m .66081 .39724 L p .66069 .39813 L F P
0 g
s
.568 .931 .782 r
.65183 .40346 m .65679 .39987 L p .66069 .39813 L F P
0 g
s
.679 .263 .249 r
.37178 .37006 m .37152 .37037 L .37105 .36996 L closepath p F P
0 g
s
0 .453 .845 r
.19255 .41593 m .19403 .41647 L .19862 .41909 L p F P
0 g
s
.006 .483 .869 r
.20022 .4185 m .19403 .41647 L .19862 .41909 L p F P
0 g
s
.006 .483 .869 r
.20464 .42108 m .20022 .4185 L p .19862 .41909 L F P
0 g
s
.006 .483 .869 r
.19862 .41909 m .20472 .42114 L .20464 .42108 L p F P
0 g
s
.677 .265 .257 r
.3658 .37187 m .36259 .36874 L .37105 .36996 L p F P
0 g
s
.677 .265 .257 r
.36988 .37244 m .3658 .37187 L p .37105 .36996 L F P
0 g
s
.677 .265 .257 r
.37105 .36996 m .37152 .37037 L .36988 .37244 L p F P
0 g
s
.558 .806 .991 r
.41095 .46027 m .40117 .46209 L .3983 .46034 L p F P
0 g
s
.65 .133 0 r
.11676 .36293 m .12027 .36606 L .11757 .36292 L p F P
0 g
s
.65 .133 0 r
.11757 .36292 m .11405 .35978 L .11676 .36293 L p F P
0 g
s
.676 .126 0 r
.27297 .32823 m .27799 .33078 L .27459 .32785 L p F P
0 g
s
.676 .126 0 r
.27459 .32785 m .26975 .32524 L .27297 .32823 L p F P
0 g
s
0 0 0 r
.72275 .34154 m .72257 .34181 L .72271 .34167 L closepath p F P
0 g
s
.575 .868 .995 r
.4996 .45448 m .48965 .45723 L .48693 .456 L p F P
0 g
s
.564 .861 .997 r
.477 .45858 m .48693 .456 L .48965 .45723 L p F P
0 g
s
.609 .937 .953 r
.59545 .43044 m .58537 .43482 L .58287 .43445 L p F P
0 g
s
.431 0 0 r
.23702 .30278 m .23355 .30021 L .2304 .29777 L p F P
0 g
s
.369 .724 .988 r
.29467 .45096 m .29994 .45102 L .30639 .45291 L p F P
0 g
s
.382 .728 .99 r
.29994 .45102 m .29467 .45096 L .29161 .44913 L p F P
0 g
s
.714 .245 .135 r
.32372 .35706 m .32068 .35392 L .32722 .35586 L p F P
0 g
s
.714 .245 .135 r
.32613 .35775 m .32372 .35706 L p .32722 .35586 L F P
0 g
s
.714 .245 .135 r
.32722 .35586 m .32815 .35674 L .32613 .35775 L p F P
0 g
s
0 0 0 r
.72161 .34409 m .71809 .34773 L .72257 .34181 L p F P
0 g
s
0 0 0 r
.72257 .34181 m .72271 .34167 L .72161 .34409 L p F P
0 g
s
.608 .948 .924 r
.60822 .42593 m .60799 .42592 L .60995 .42496 L closepath p F P
0 g
s
.44 .047 .197 r
.48227 .36379 m .48257 .36316 L .47266 .36414 L p F P
0 g
s
.44 .047 .197 r
.47266 .36414 m .47154 .36635 L .48227 .36379 L p F P
0 g
s
.121 .572 .92 r
.22335 .42982 m .2263 .43049 L .23137 .43292 L p F P
0 g
s
.157 .591 .934 r
.23249 .43176 m .2263 .43049 L .23137 .43292 L p F P
0 g
s
.157 .591 .934 r
.23137 .43292 m .23565 .4338 L .23249 .43176 L p F P
0 g
s
.552 .837 .998 r
.45202 .46077 m .45171 .46061 L .45018 .46095 L closepath p F P
0 g
s
.557 .833 .997 r
.44893 .45902 m .45171 .46061 L .45018 .46095 L p F P
0 g
s
.557 .833 .997 r
.43907 .46126 m .44893 .45902 L p .45018 .46095 L F P
0 g
s
.599 .951 .869 r
.63828 .41 m .64064 .40979 L .63055 .41543 L p F P
0 g
s
.599 .951 .869 r
.63395 .41244 m .63828 .41 L p .63055 .41543 L F P
0 g
s
.599 .951 .869 r
.63055 .41543 m .62907 .41559 L .63395 .41244 L p F P
0 g
s
.589 .914 .975 r
.55902 .4416 m .56019 .4419 L .55015 .44559 L p F P
0 g
s
.589 .914 .975 r
.55015 .44559 m .5493 .44537 L .55902 .4416 L p F P
0 g
s
0 0 0 r
.55862 .32106 m .56036 .31934 L .55036 .32569 L p F P
0 g
s
0 0 0 r
.55036 .32569 m .54985 .32624 L .55862 .32106 L p F P
0 g
s
.553 .914 .73 r
.67307 .38952 m .66309 .39651 L .66265 .3967 L p F P
0 g
s
.714 .217 .058 r
.30864 .34964 m .30556 .34654 L .31156 .34868 L p F P
0 g
s
.714 .217 .058 r
.31062 .35033 m .30864 .34964 L p .31156 .34868 L F P
0 g
s
.714 .217 .058 r
.31156 .34868 m .31277 .34982 L .31062 .35033 L p F P
0 g
s
.458 .768 .996 r
.34605 .45753 m .34784 .4586 L p .33527 .45755 L F P
0 g
s
.458 .768 .996 r
.33527 .45755 m .343 .45695 L .34605 .45753 L p F P
0 g
s
.477 .769 .995 r
.343 .45695 m .33527 .45755 L .33228 .45576 L p F P
0 g
s
.285 .678 .972 r
.26668 .44423 m .27037 .44455 L .27624 .44666 L p F P
0 g
s
.297 .683 .975 r
.27037 .44455 m .26668 .44423 L .26357 .44235 L p F P
0 g
s
0 0 0 r
.72374 .34172 m .72161 .34409 L .72271 .34167 L p F P
0 g
s
0 0 0 r
.72271 .34167 m .72792 .33589 L .72374 .34172 L p F P
0 g
s
.203 .101 .508 r
.74776 .29454 m .746 .29699 L .74558 .29259 L p F P
0 g
s
.203 .101 .508 r
.74558 .29259 m .74715 .29041 L .74776 .29454 L p F P
0 g
s
0 .316 .751 r
.16613 .40085 m .16203 .39868 L .15878 .39626 L p F P
0 g
s
.632 .656 .855 r
.72656 .23872 m .72327 .24348 L p .71579 .24064 L F P
0 g
s
.611 .64 .855 r
.72327 .24348 m .72656 .23872 L .72861 .24248 L closepath p F P
0 g
s
.577 .582 .821 r
.73707 .24708 m .73106 .24727 L .72861 .24248 L p F P
0 g
s
.187 0 0 r
.52654 .342 m .52781 .34004 L .51783 .34476 L p F P
0 g
s
.187 0 0 r
.51783 .34476 m .51698 .34608 L .52654 .342 L p F P
0 g
s
.752 .876 .936 r
.66892 .25021 m .66786 .25081 L .66549 .24901 L p F P
0 g
s
.568 .843 .996 r
.4616 .45823 m .46362 .45934 L .45202 .46077 L p F P
0 g
s
.568 .843 .996 r
.45202 .46077 m .45171 .46061 L .4616 .45823 L p F P
0 g
s
.7 .177 0 r
.29807 .34156 m .29745 .34158 L .29695 .34113 L closepath p F P
0 g
s
.725 .287 .21 r
.34074 .36419 m .34711 .36576 L .34414 .36257 L p F P
0 g
s
.725 .287 .21 r
.34414 .36257 m .34316 .36233 L .34074 .36419 L p F P
0 g
s
.315 0 .079 r
.5052 .35296 m .50563 .35223 L .49551 .35555 L p F P
0 g
s
.315 0 .079 r
.49551 .35555 m .49524 .35601 L .5052 .35296 L p F P
0 g
s
.567 .812 .991 r
.4236 .46003 m .4138 .462 L .41095 .46027 L p F P
0 g
s
.133 .576 .925 r
.2263 .43049 m .22335 .42982 L .22017 .42779 L p F P
0 g
s
.31 .686 .977 r
.27603 .44493 m .27037 .44455 L .27624 .44666 L p F P
0 g
s
.31 .686 .977 r
.27624 .44666 m .27912 .44687 L .27603 .44493 L p F P
0 g
s
.573 .857 .996 r
.48605 .45556 m .48693 .456 L .477 .45858 L p F P
0 g
s
.573 .857 .996 r
.477 .45858 m .47497 .45761 L .48605 .45556 L p F P
0 g
s
.556 .854 .997 r
.47497 .45761 m .477 .45858 L p .46436 .45972 L F P
0 g
s
0 0 .264 r
.74112 .31408 m .73898 .31681 L .73929 .31339 L p F P
0 g
s
0 0 .264 r
.73929 .31339 m .74258 .3092 L .74112 .31408 L p F P
0 g
s
.713 .179 0 r
.2822 .33243 m .28306 .33329 L .28066 .33204 L closepath p F P
0 g
s
0 .384 .796 r
.17724 .40778 m .17962 .40883 L .18399 .41155 L p F P
0 g
s
0 .418 .825 r
.18515 .41107 m .17962 .40883 L .18399 .41155 L p F P
0 g
s
0 .418 .825 r
.18886 .41342 m .18515 .41107 L p .18399 .41155 L F P
0 g
s
0 .418 .825 r
.18399 .41155 m .18932 .41374 L .18886 .41342 L p F P
0 g
s
.687 .277 .263 r
.37152 .37037 m .37437 .37306 L .36988 .37244 L closepath p F P
0 g
s
.752 .876 .936 r
.66549 .24901 m .67313 .24441 L .66892 .25021 L p F P
0 g
s
.765 .876 .928 r
.66892 .25021 m .67798 .24506 L .67561 .24291 L p F P
0 g
s
.765 .876 .928 r
.67561 .24291 m .67313 .24441 L .66892 .25021 L p F P
0 g
s
.672 .711 .877 r
.70311 .2407 m .7134 .23696 L .71579 .24064 L p F P
0 g
s
.685 .729 .884 r
.7134 .23696 m .70311 .2407 L .70073 .23759 L p F P
0 g
s
.706 .761 .894 r
.69052 .24223 m .70073 .23759 L .70311 .2407 L p F P
0 g
s
.004 .403 .852 r
.20082 .27751 m .20012 .27718 L .19697 .27402 L p F P
0 g
s
.506 .791 .997 r
.37011 .45802 m .37304 .4599 L .36831 .46051 L p F P
0 g
s
.506 .791 .997 r
.36043 .4594 m .37011 .45802 L p .36831 .46051 L F P
0 g
s
.506 .791 .997 r
.36831 .46051 m .36101 .45975 L .36043 .4594 L p F P
0 g
s
.716 .275 .202 r
.34003 .36402 m .34074 .36419 L .34316 .36233 L p F P
0 g
s
.716 .275 .202 r
.34316 .36233 m .33695 .36088 L .34003 .36402 L p F P
0 g
s
.617 .949 .93 r
.60995 .42496 m .60799 .42592 L .60554 .42574 L p F P
0 g
s
.574 .818 .991 r
.43626 .45962 m .42643 .46172 L .4236 .46003 L p F P
0 g
s
.556 .854 .997 r
.46436 .45972 m .46924 .45852 L .47497 .45761 L p F P
0 g
s
.568 .847 .997 r
.46436 .45972 m .46924 .45852 L .46362 .45934 L closepath p F P
0 g
s
.727 .804 .912 r
.69052 .24223 m .68894 .24302 L .68986 .24151 L closepath p F P
0 g
s
.729 .83 .928 r
.68814 .23963 m .68986 .24151 L .68894 .24302 L p F P
0 g
s
.729 .83 .928 r
.67798 .24506 m .68814 .23963 L p .68894 .24302 L F P
0 g
s
.593 .937 .757 r
.6004 .29054 m .60216 .29008 L .59978 .2921 L p F P
0 g
s
.593 .937 .757 r
.59691 .29316 m .6004 .29054 L p .59978 .2921 L F P
0 g
s
.593 .937 .757 r
.59183 .29749 m .59691 .29316 L p .59978 .2921 L F P
0 g
s
.657 .97 .821 r
.60283 .28992 m .59978 .2921 L .60216 .29008 L closepath p F P
0 g
s
.781 .942 .93 r
.64533 .262 m .64236 .26401 L .6444 .2616 L closepath p F P
0 g
s
.769 .963 .929 r
.64295 .261 m .6444 .2616 L .64236 .26401 L p F P
0 g
s
.769 .963 .929 r
.63492 .26668 m .64295 .261 L p .64236 .26401 L F P
0 g
s
.769 .963 .929 r
.63351 .26829 m .63492 .26668 L p .64236 .26401 L F P
0 g
s
.699 .173 0 r
.29428 .34157 m .29136 .33881 L .29695 .34113 L p F P
0 g
s
.699 .173 0 r
.29695 .34113 m .29745 .34158 L .29428 .34157 L p F P
0 g
s
.591 .882 .992 r
.52225 .44962 m .52409 .45039 L .51375 .45334 L p F P
0 g
s
.591 .882 .992 r
.51375 .45334 m .51225 .45273 L .52225 .44962 L p F P
0 g
s
.58 .825 .991 r
.44893 .45902 m .43907 .46126 L .43626 .45962 L p F P
0 g
s
.583 .058 0 r
.12223 .36807 m .12027 .36606 L .12386 .36916 L p F P
0 g
s
.583 .058 0 r
.12386 .36916 m .12552 .37086 L .12223 .36807 L p F P
0 g
s
.376 .728 .99 r
.30784 .45332 m .30717 .45292 L .30639 .45291 L closepath p F P
0 g
s
.585 .832 .992 r
.4616 .45823 m .45171 .46061 L .44893 .45902 L p F P
0 g
s
.513 .12 .232 r
.46047 .36848 m .45997 .36946 L .45683 .36902 L closepath p F P
0 g
s
.51 .118 .233 r
.45912 .37129 m .45997 .36946 L .45683 .36902 L p F P
0 g
s
.51 .118 .233 r
.44767 .37297 m .45912 .37129 L p .45683 .36902 L F P
0 g
s
.632 .656 .855 r
.71579 .24064 m .72618 .23803 L .72656 .23872 L p F P
0 g
s
.646 .675 .863 r
.72618 .23803 m .71579 .24064 L .7134 .23696 L p F P
0 g
s
.224 .633 .956 r
.24802 .43729 m .24452 .43676 L .24982 .4391 L p F P
0 g
s
.224 .633 .956 r
.24982 .4391 m .25116 .4393 L .24802 .43729 L p F P
0 g
s
0 0 .174 r
.73846 .31995 m .73425 .32494 L .73645 .31981 L p F P
0 g
s
0 0 .174 r
.73645 .31981 m .73898 .31681 L .73846 .31995 L p F P
0 g
s
.666 .972 .821 r
.61145 .28365 m .60283 .28992 L .60216 .29008 L p F P
0 g
s
.721 .803 .915 r
.69835 .23465 m .70073 .23759 L .69052 .24223 L p F P
0 g
s
.721 .803 .915 r
.6929 .23731 m .69835 .23465 L p .69052 .24223 L F P
0 g
s
.721 .803 .915 r
.69052 .24223 m .68986 .24151 L .6929 .23731 L p F P
0 g
s
0 .389 .805 r
.17962 .40883 m .17724 .40778 L .174 .40549 L p F P
0 g
s
0 .154 .606 r
.14369 .38578 m .14534 .38695 L .14926 .38989 L p F P
0 g
s
0 .223 .675 r
.14953 .38962 m .15343 .39256 L .14926 .38989 L p F P
0 g
s
0 .223 .675 r
.14926 .38989 m .14534 .38695 L .14953 .38962 L p F P
0 g
s
.594 .947 .905 r
.61807 .42089 m .60995 .42496 L .61706 .4209 L closepath p F P
0 g
s
.617 .949 .93 r
.61564 .42078 m .61706 .4209 L .60995 .42496 L p F P
0 g
s
.617 .949 .93 r
.60554 .42574 m .61564 .42078 L p .60995 .42496 L F P
0 g
s
0 .135 .576 r
.24082 .30549 m .24505 .30838 L .24113 .30571 L p F P
0 g
s
0 .135 .576 r
.24113 .30571 m .23702 .30278 L .24082 .30549 L p F P
0 g
s
.055 .521 .892 r
.20953 .42371 m .20792 .42324 L .20472 .42114 L p F P
0 g
s
0 0 0 r
.71888 .34779 m .71308 .35385 L .71809 .34773 L p F P
0 g
s
0 0 0 r
.72082 .34542 m .71888 .34779 L p .71809 .34773 L F P
0 g
s
0 0 0 r
.71809 .34773 m .72161 .34409 L .72082 .34542 L p F P
0 g
s
.785 .943 .928 r
.65302 .25406 m .65539 .25538 L .64533 .262 L p F P
0 g
s
.785 .943 .928 r
.64743 .25791 m .65302 .25406 L p .64533 .262 L F P
0 g
s
.785 .943 .928 r
.64533 .262 m .6444 .2616 L .64743 .25791 L p F P
0 g
s
.342 0 .126 r
.50422 .35483 m .5052 .35296 L .49524 .35601 L p F P
0 g
s
.342 0 .126 r
.49524 .35601 m .49409 .35817 L .50422 .35483 L p F P
0 g
s
.557 0 0 r
.26064 .31978 m .25707 .31694 L .26168 .31966 L p F P
0 g
s
.557 0 0 r
.26075 .31985 m .26064 .31978 L p .26168 .31966 L F P
0 g
s
.557 0 0 r
.26168 .31966 m .26384 .32131 L .26075 .31985 L p F P
0 g
s
0 .281 .747 r
.22151 .29101 m .22529 .29409 L .22103 .29159 L p F P
0 g
s
0 .281 .747 r
.22103 .29159 m .21733 .28848 L .22151 .29101 L p F P
0 g
s
0 .27 .737 r
.21527 .28721 m .21733 .28848 L .22103 .29159 L p F P
0 g
s
.741 .284 .166 r
.32815 .35674 m .3302 .35902 L .32613 .35775 L closepath p F P
0 g
s
.705 .284 .244 r
.35774 .37049 m .3658 .37187 L .36259 .36874 L p F P
0 g
s
.705 .284 .244 r
.35595 .36852 m .35774 .37049 L p .36259 .36874 L F P
0 g
s
.705 .284 .244 r
.36259 .36874 m .35676 .36767 L .35595 .36852 L p F P
0 g
s
.386 .727 .99 r
.30413 .451 m .29994 .45102 L .30639 .45291 L p F P
0 g
s
.386 .727 .99 r
.30639 .45291 m .30717 .45292 L .30413 .451 L p F P
0 g
s
.329 .265 .632 r
.75135 .27858 m .74964 .28103 L .74727 .27753 L p F P
0 g
s
.329 .265 .632 r
.74727 .27753 m .75028 .27324 L .75135 .27858 L p F P
0 g
s
.004 .403 .852 r
.19697 .27402 m .19745 .27425 L .20082 .27751 L p F P
0 g
s
.006 .405 .854 r
.20217 .27652 m .20559 .27978 L .20082 .27751 L p F P
0 g
s
.006 .405 .854 r
.20082 .27751 m .19745 .27425 L .20217 .27652 L p F P
0 g
s
.483 .779 .997 r
.34784 .4586 m .35111 .45826 L .35936 .45951 L p F P
0 g
s
.48 .78 .997 r
.34784 .4586 m .35111 .45826 L .34605 .45753 L closepath p F P
0 g
s
.553 .914 .73 r
.66265 .3967 m .67013 .39092 L p .67307 .38952 L F P
0 g
s
.604 .948 .795 r
.66265 .3967 m .66081 .39724 L .67013 .39092 L closepath p F P
0 g
s
0 .458 .852 r
.19403 .41647 m .19255 .41593 L .18932 .41374 L p F P
0 g
s
0 .348 .775 r
.17075 .40312 m .16613 .40085 L .17029 .40366 L p F P
0 g
s
0 .348 .775 r
.17029 .40366 m .174 .40549 L .17075 .40312 L p F P
0 g
s
.758 .265 .057 r
.2999 .34426 m .29745 .34158 L .29428 .34157 L p F P
0 g
s
.481 .78 .997 r
.36101 .45975 m .36043 .4594 L .35936 .45951 L closepath p F P
0 g
s
.597 .902 .985 r
.54756 .44482 m .53754 .44829 L .53492 .44742 L p F P
0 g
s
.581 .896 .986 r
.5249 .45069 m .53492 .44742 L .53754 .44829 L p F P
0 g
s
.605 .928 .965 r
.57305 .43866 m .5728 .4386 L .57641 .43713 L closepath p F P
0 g
s
.483 .09 .218 r
.4702 .36915 m .47154 .36635 L .46047 .36848 L p F P
0 g
s
.483 .09 .218 r
.46706 .36974 m .4702 .36915 L p .46047 .36848 L F P
0 g
s
.483 .09 .218 r
.46047 .36848 m .45997 .36946 L .46706 .36974 L p F P
0 g
s
.51 .879 .664 r
.67313 .38947 m .67307 .38952 L .67312 .38948 L closepath p F P
0 g
s
.553 .914 .73 r
.67089 .39038 m .67312 .38948 L .67307 .38952 L p F P
0 g
s
.553 .914 .73 r
.67013 .39092 m .67089 .39038 L p .67307 .38952 L F P
0 g
s
.539 .893 .671 r
.68105 .38296 m .68316 .38182 L .67313 .38947 L p F P
0 g
s
.539 .893 .671 r
.67313 .38947 m .67312 .38948 L .68105 .38296 L p F P
0 g
s
.593 .934 .747 r
.68095 .38299 m .68105 .38296 L .67312 .38948 L p F P
0 g
s
.593 .934 .747 r
.67312 .38948 m .67089 .39038 L .68095 .38299 L p F P
0 g
s
.612 .955 .836 r
.65183 .40346 m .65072 .40368 L .65679 .39987 L closepath p F P
0 g
s
.733 .21 0 r
.28101 .33386 m .28606 .33639 L .28306 .33329 L p F P
0 g
s
.733 .21 0 r
.27903 .33169 m .28101 .33386 L p .28306 .33329 L F P
0 g
s
.733 .21 0 r
.28306 .33329 m .28066 .33204 L .27903 .33169 L p F P
0 g
s
0 0 0 r
.56049 .31923 m .56036 .31934 L .56121 .31876 L closepath p F P
0 g
s
0 0 0 r
.55785 .32185 m .55862 .32106 L .54985 .32624 L p F P
0 g
s
0 0 0 r
.54973 .32722 m .55785 .32185 L p .54985 .32624 L F P
0 g
s
0 0 0 r
.54985 .32624 m .54807 .32822 L .54973 .32722 L p F P
0 g
s
.612 .223 .283 r
.41581 .37523 m .41107 .37531 L .40957 .37807 L p F P
0 g
s
.633 .246 .294 r
.40813 .37805 m .40957 .37807 L .41107 .37531 L p F P
0 g
s
.633 .246 .294 r
.41107 .37531 m .40399 .37521 L .40813 .37805 L p F P
0 g
s
.491 .775 .995 r
.35748 .45751 m .35111 .45826 L .35936 .45951 L p F P
0 g
s
.491 .775 .995 r
.35936 .45951 m .36043 .4594 L .35748 .45751 L p F P
0 g
s
.436 .744 .993 r
.31669 .45258 m .30717 .45292 L .30413 .451 L p F P
0 g
s
.75 .271 .106 r
.31277 .34982 m .31456 .35182 L .31062 .35033 L closepath p F P
0 g
s
.463 0 0 r
.13035 .37509 m .13402 .37815 L .13059 .37524 L p F P
0 g
s
.463 0 0 r
.13059 .37524 m .12691 .37219 L .13035 .37509 L p F P
0 g
s
.551 .019 0 r
.12552 .37086 m .12691 .37219 L .13059 .37524 L p F P
0 g
s
.61 .227 .292 r
.4237 .37504 m .41581 .37523 L .42049 .37789 L p F P
0 g
s
.612 .223 .283 r
.40957 .37807 m .42049 .37789 L .41581 .37523 L p F P
0 g
s
.774 .287 0 r
.10813 .3534 m .10769 .35271 L .1044 .34965 L p F P
0 g
s
.637 .243 .28 r
.39709 .37774 m .40813 .37805 L .40399 .37521 L p F P
0 g
s
.637 .243 .28 r
.39656 .37733 m .39709 .37774 L p .40399 .37521 L F P
0 g
s
.637 .243 .28 r
.40399 .37521 m .39794 .37503 L .39656 .37733 L p F P
0 g
s
.606 .909 .982 r
.55762 .44115 m .55902 .4416 L .5493 .44537 L p F P
0 g
s
.606 .909 .982 r
.5493 .44537 m .54756 .44482 L .55762 .44115 L p F P
0 g
s
0 0 0 r
.54783 .3285 m .54807 .32822 L .53907 .33307 L p F P
0 g
s
0 0 0 r
.53907 .33307 m .53781 .33461 L .54783 .3285 L p F P
0 g
s
.55 0 0 r
.24868 .31072 m .2493 .31124 L .24677 .30949 L closepath p F P
0 g
s
.389 0 .151 r
.4927 .36084 m .49409 .35817 L .48367 .36111 L p F P
0 g
s
.389 0 .151 r
.489 .36187 m .4927 .36084 L p .48367 .36111 L F P
0 g
s
.389 0 .151 r
.48367 .36111 m .48257 .36316 L .489 .36187 L p F P
0 g
s
.582 .842 .994 r
.46924 .45852 m .46362 .45934 L .4616 .45823 L p F P
0 g
s
.281 .662 .97 r
.25894 .44019 m .25116 .4393 L .24802 .43729 L p F P
0 g
s
.615 .927 .97 r
.57641 .43713 m .5728 .4386 L .57026 .43799 L p F P
0 g
s
.599 .921 .971 r
.56019 .4419 m .57026 .43799 L .5728 .4386 L p F P
0 g
s
.584 .199 .279 r
.42924 .37469 m .4237 .37504 L .42227 .37784 L p F P
0 g
s
.61 .227 .292 r
.42049 .37789 m .42227 .37784 L .4237 .37504 L p F P
0 g
s
.652 .26 .289 r
.39794 .37503 m .39656 .37733 L .39331 .37478 L closepath p F P
0 g
s
.524 .888 .675 r
.58147 .30486 m .58037 .30547 L .5859 .30138 L closepath p F P
0 g
s
0 0 0 r
.56121 .31876 m .56036 .31934 L .55862 .32106 L p F P
0 g
s
.751 .289 .154 r
.31735 .35504 m .32372 .35706 L .32068 .35392 L p F P
0 g
s
.751 .289 .154 r
.32068 .35392 m .31456 .35182 L .31735 .35504 L p F P
0 g
s
0 0 0 r
.71302 .35391 m .713 .35394 L .71308 .35385 L closepath p F P
0 g
s
0 .27 .742 r
.21733 .28848 m .21527 .28721 L .21212 .28431 L p F P
0 g
s
.773 .904 .933 r
.65579 .25563 m .65539 .25538 L .65658 .25463 L closepath p F P
0 g
s
.739 .301 .211 r
.33301 .36226 m .34003 .36402 L .33695 .36088 L p F P
0 g
s
.739 .301 .211 r
.33695 .36088 m .3302 .35902 L .33301 .36226 L p F P
0 g
s
.793 .316 0 r
.10111 .34645 m .09941 .34358 L .10272 .34683 L p F P
0 g
s
.793 .316 0 r
.10272 .34683 m .1044 .34965 L .10111 .34645 L p F P
0 g
s
0 0 0 r
.71324 .35414 m .71888 .34779 L .71308 .35385 L p F P
0 g
s
0 0 0 r
.71156 .35589 m .71324 .35414 L p .71308 .35385 L F P
0 g
s
0 0 0 r
.71308 .35385 m .713 .35394 L .71156 .35589 L p F P
0 g
s
0 0 0 r
.57036 .31259 m .56121 .31876 L .56902 .31371 L closepath p F P
0 g
s
0 0 0 r
.56787 .3147 m .56902 .31371 L .56121 .31876 L p F P
0 g
s
0 0 0 r
.56285 .31825 m .56787 .3147 L p .56121 .31876 L F P
0 g
s
0 0 0 r
.55862 .32106 m .56285 .31825 L p .56121 .31876 L F P
0 g
s
0 0 0 r
.713 .35394 m .70705 .36031 L .71156 .35589 L closepath p F P
0 g
s
.717 .987 .868 r
.61284 .28264 m .61145 .28365 L .6125 .28267 L closepath p F P
0 g
s
.666 .972 .821 r
.61042 .28289 m .6125 .28267 L .61145 .28365 L p F P
0 g
s
.666 .972 .821 r
.60758 .28505 m .61042 .28289 L p .61145 .28365 L F P
0 g
s
.666 .972 .821 r
.60216 .29008 m .60758 .28505 L p .61145 .28365 L F P
0 g
s
.722 .804 .916 r
.68986 .24151 m .68814 .23963 L .6929 .23731 L closepath p F P
0 g
s
.661 .263 .28 r
.39635 .37771 m .39656 .37733 L .39331 .37478 L p F P
0 g
s
.661 .263 .28 r
.38694 .37712 m .39635 .37771 L p .39331 .37478 L F P
0 g
s
.661 .263 .28 r
.38401 .37443 m .38694 .37712 L p .39331 .37478 L F P
0 g
s
.661 .263 .28 r
.39331 .37478 m .38423 .37409 L .38401 .37443 L p F P
0 g
s
.533 .785 .99 r
.37011 .45802 m .36043 .4594 L .35748 .45751 L p F P
0 g
s
.568 .91 .687 r
.68323 .38178 m .68316 .38182 L .68349 .38156 L closepath p F P
0 g
s
.072 0 0 r
.5281 .33966 m .52781 .34004 L .53165 .33794 L closepath p F P
0 g
s
.083 0 .357 r
.74606 .30473 m .74258 .3092 L .7434 .30455 L p F P
0 g
s
.083 0 .357 r
.7434 .30455 m .74615 .30103 L .74606 .30473 L p F P
0 g
s
0 .161 .619 r
.14534 .38695 m .14369 .38578 L .14041 .38321 L p F P
0 g
s
.737 .991 .864 r
.62046 .27523 m .62286 .27534 L .61284 .28264 L p F P
0 g
s
.737 .991 .864 r
.61817 .27697 m .62046 .27523 L p .61284 .28264 L F P
0 g
s
.737 .991 .864 r
.61284 .28264 m .6125 .28267 L .61817 .27697 L p F P
0 g
s
.351 .708 .985 r
.28995 .44812 m .29161 .44913 L p .27912 .44687 L F P
0 g
s
.351 .708 .985 r
.27912 .44687 m .28717 .44717 L .28995 .44812 L p F P
0 g
s
.367 .711 .986 r
.28717 .44717 m .27912 .44687 L .27603 .44493 L p F P
0 g
s
.617 .958 .869 r
.64066 .40979 m .64064 .40979 L .64079 .4097 L closepath p F P
0 g
s
.615 .944 .754 r
.59183 .29749 m .59038 .29809 L .59691 .29316 L closepath p F P
0 g
s
.584 .202 .283 r
.43589 .37425 m .43455 .37698 L .42924 .37469 L closepath p F P
0 g
s
.584 .199 .279 r
.4345 .37708 m .43455 .37698 L .42924 .37469 L p F P
0 g
s
.584 .199 .279 r
.42227 .37784 m .4345 .37708 L p .42924 .37469 L F P
0 g
s
.703 .281 .242 r
.35676 .36767 m .35595 .36852 L .35472 .3673 L closepath p F P
0 g
s
.625 .961 .876 r
.64079 .4097 m .64064 .40979 L .63828 .41 L p F P
0 g
s
.201 .099 .508 r
.75171 .289 m .74776 .29454 L .74715 .29041 L p F P
0 g
s
.201 .099 .508 r
.74715 .29041 m .75108 .28487 L .75171 .289 L p F P
0 g
s
.75 .262 .079 r
.30276 .34744 m .30864 .34964 L .30556 .34654 L p F P
0 g
s
.75 .262 .079 r
.30556 .34654 m .2999 .34426 L .30276 .34744 L p F P
0 g
s
.597 .95 .837 r
.65072 .40368 m .64079 .4097 L .64902 .404 L closepath p F P
0 g
s
.625 .961 .876 r
.64839 .40405 m .64902 .404 L .64079 .4097 L p F P
0 g
s
.625 .961 .876 r
.63828 .41 m .64839 .40405 L p .64079 .4097 L F P
0 g
s
.11 .553 .916 r
.21172 .42293 m .2164 .42552 L .20953 .42371 L p F P
0 g
s
.11 .553 .916 r
.20953 .42371 m .20476 .42115 L .21172 .42293 L p F P
0 g
s
.055 .521 .892 r
.20472 .42114 m .20476 .42115 L .20953 .42371 L p F P
0 g
s
.572 .912 .69 r
.68349 .38156 m .68316 .38182 L .68105 .38296 L p F P
0 g
s
.528 .873 .621 r
.69101 .375 m .68349 .38156 L .69248 .37409 L p F P
0 g
s
.572 .912 .69 r
.691 .375 m .69101 .375 L .68349 .38156 L p F P
0 g
s
.572 .912 .69 r
.68136 .38268 m .691 .375 L p .68349 .38156 L F P
0 g
s
.572 .912 .69 r
.68105 .38296 m .68136 .38268 L p .68349 .38156 L F P
0 g
s
.592 .893 .989 r
.53423 .44716 m .53492 .44742 L .5249 .45069 L p F P
0 g
s
.592 .893 .989 r
.5249 .45069 m .52409 .45039 L .53423 .44716 L p F P
0 g
s
.748 .823 .91 r
.68814 .23963 m .67798 .24506 L .67561 .24291 L p F P
0 g
s
.774 .287 0 r
.1044 .34965 m .10475 .35019 L .10813 .3534 L p F P
0 g
s
.691 .187 0 r
.10721 .35341 m .1106 .35661 L .10813 .3534 L p F P
0 g
s
.691 .187 0 r
.10813 .3534 m .10475 .35019 L .10721 .35341 L p F P
0 g
s
.592 .04 0 r
.24838 .31128 m .25264 .31415 L .2493 .31124 L p F P
0 g
s
.592 .04 0 r
.24553 .3087 m .24838 .31128 L p .2493 .31124 L F P
0 g
s
.592 .04 0 r
.2493 .31124 m .24677 .30949 L .24553 .3087 L p F P
0 g
s
0 .277 .722 r
.15551 .39377 m .15343 .39256 L .1574 .39547 L p F P
0 g
s
0 .277 .722 r
.1574 .39547 m .15878 .39626 L .15551 .39377 L p F P
0 g
s
.683 .137 0 r
.26384 .32131 m .26511 .32255 L .26975 .32524 L p F P
0 g
s
.691 .147 0 r
.26818 .32559 m .27297 .32823 L .26975 .32524 L p F P
0 g
s
.691 .147 0 r
.26975 .32524 m .26511 .32255 L .26818 .32559 L p F P
0 g
s
.577 .582 .821 r
.73974 .2429 m .73707 .24708 L p .72861 .24248 L F P
0 g
s
.577 .582 .821 r
.72861 .24248 m .73914 .2416 L .73974 .2429 L p F P
0 g
s
.572 .621 .862 r
.72656 .23872 m .72861 .24248 L .73914 .2416 L p F P
0 g
s
.297 .683 .975 r
.26357 .44235 m .26452 .44242 L .27037 .44455 L p F P
0 g
s
.322 .689 .979 r
.27293 .44294 m .26452 .44242 L .27037 .44455 L p F P
0 g
s
.322 .689 .979 r
.27037 .44455 m .27603 .44493 L .27293 .44294 L p F P
0 g
s
0 .458 .852 r
.18932 .41374 m .1895 .41381 L .19403 .41647 L p F P
0 g
s
.038 .5 .884 r
.19575 .41582 m .20022 .4185 L .19403 .41647 L p F P
0 g
s
.038 .5 .884 r
.19403 .41647 m .1895 .41381 L .19575 .41582 L p F P
0 g
s
.18 .503 .909 r
.18177 .26451 m .18524 .26571 L .18844 .26906 L p F P
0 g
s
.207 .519 .916 r
.19067 .26743 m .18524 .26571 L .18844 .26906 L p F P
0 g
s
.207 .519 .916 r
.18844 .26906 m .19382 .27077 L .19067 .26743 L p F P
0 g
s
0 0 0 r
.71096 .35652 m .71156 .35589 L .70705 .36031 L p F P
0 g
s
0 0 0 r
.70674 .36077 m .71096 .35652 L p .70705 .36031 L F P
0 g
s
0 0 0 r
.70245 .365 m .70674 .36077 L p .70705 .36031 L F P
0 g
s
0 0 0 r
.70705 .36031 m .70311 .36426 L .70245 .365 L p F P
0 g
s
.133 .576 .925 r
.22017 .42779 m .22128 .42804 L .2263 .43049 L p F P
0 g
s
.168 .594 .938 r
.22899 .42959 m .22128 .42804 L .2263 .43049 L p F P
0 g
s
.168 .594 .938 r
.22992 .43006 m .22899 .42959 L p .2263 .43049 L F P
0 g
s
.168 .594 .938 r
.2263 .43049 m .23249 .43176 L .22992 .43006 L p F P
0 g
s
0 .305 .754 r
.22725 .29521 m .22529 .29409 L .22921 .29711 L p F P
0 g
s
0 .305 .754 r
.22921 .29711 m .2304 .29777 L .22725 .29521 L p F P
0 g
s
.701 .282 .247 r
.35002 .36899 m .34711 .36576 L .35472 .3673 L p F P
0 g
s
.701 .282 .247 r
.35468 .36989 m .35002 .36899 L p .35472 .3673 L F P
0 g
s
.701 .282 .247 r
.35472 .3673 m .35595 .36852 L .35468 .36989 L p F P
0 g
s
.685 .978 .816 r
.60216 .29008 m .6004 .29054 L .60758 .28505 L closepath p F P
0 g
s
.615 .943 .947 r
.59559 .43046 m .59545 .43044 L .59678 .42984 L closepath p F P
0 g
s
.576 .848 .996 r
.47497 .45761 m .47427 .45724 L .46924 .45852 L closepath p F P
0 g
s
.582 .842 .994 r
.47152 .45567 m .47427 .45724 L .46924 .45852 L p F P
0 g
s
.582 .842 .994 r
.4616 .45823 m .47152 .45567 L p .46924 .45852 L F P
0 g
s
.553 .169 .268 r
.44525 .37323 m .43589 .37425 L .43455 .37698 L p F P
0 g
s
.027 .431 .867 r
.20897 .2813 m .20559 .27978 L .20911 .28298 L p F P
0 g
s
.027 .431 .867 r
.20911 .28298 m .21212 .28431 L .20897 .2813 L p F P
0 g
s
.128 .006 .432 r
.74766 .29893 m .74615 .30103 L .746 .29699 L p F P
0 g
s
.128 .006 .432 r
.746 .29699 m .74776 .29454 L .74766 .29893 L p F P
0 g
s
.77 .918 .937 r
.65658 .25463 m .65539 .25538 L .65302 .25406 L p F P
0 g
s
.389 .346 .689 r
.74767 .26889 m .74876 .26728 L .7496 .2705 L closepath p F P
0 g
s
.674 .125 0 r
.28066 .33204 m .27903 .33169 L .27799 .33078 L closepath p F P
0 g
s
.191 0 0 r
.52521 .34408 m .52654 .342 L .51698 .34608 L p F P
0 g
s
.191 0 0 r
.52084 .34619 m .52521 .34408 L p .51698 .34608 L F P
0 g
s
.191 0 0 r
.51698 .34608 m .51546 .34851 L .52084 .34619 L p F P
0 g
s
0 .119 .584 r
.13713 .38055 m .13402 .37815 L .13776 .38117 L p F P
0 g
s
0 .119 .584 r
.13776 .38117 m .14041 .38321 L .13713 .38055 L p F P
0 g
s
0 0 0 r
.70311 .36426 m .70024 .36704 L .70245 .365 L closepath p F P
0 g
s
0 0 0 r
.69316 .3735 m .69248 .37409 L .69301 .37363 L closepath p F P
0 g
s
.528 .873 .621 r
.69248 .37409 m .69301 .37363 L .69101 .375 L p F P
0 g
s
.671 .275 .286 r
.38423 .37409 m .38401 .37443 L .38355 .37402 L closepath p F P
0 g
s
0 0 .049 r
.73631 .32451 m .73147 .33028 L .73425 .32494 L p F P
0 g
s
0 0 .049 r
.73823 .32085 m .73631 .32451 L p .73425 .32494 L F P
0 g
s
0 0 .049 r
.73425 .32494 m .73846 .31995 L .73823 .32085 L p F P
0 g
s
.482 .82 .528 r
.70024 .36704 m .69316 .3735 L .69301 .37363 L p F P
0 g
s
.482 .82 .528 r
.70101 .36623 m .70245 .365 L .70024 .36704 L p F P
0 g
s
.482 .82 .528 r
.69942 .36769 m .70101 .36623 L p .70024 .36704 L F P
0 g
s
.482 .82 .528 r
.69301 .37363 m .69942 .36769 L p .70024 .36704 L F P
0 g
s
.548 .79 .988 r
.38276 .45834 m .37304 .4599 L .37011 .45802 L p F P
0 g
s
.625 .943 .953 r
.59678 .42984 m .59545 .43044 L .59296 .43004 L p F P
0 g
s
.609 .937 .953 r
.58287 .43445 m .59296 .43004 L .59545 .43044 L p F P
0 g
s
.668 .277 .295 r
.37756 .37621 m .37437 .37306 L .38355 .37402 L p F P
0 g
s
.668 .277 .295 r
.38258 .37673 m .37756 .37621 L p .38355 .37402 L F P
0 g
s
.668 .277 .295 r
.38355 .37402 m .38401 .37443 L .38258 .37673 L p F P
0 g
s
.505 .782 .995 r
.35453 .45553 m .35748 .45751 L .35111 .45826 L p F P
0 g
s
.505 .782 .995 r
.34487 .45678 m .35453 .45553 L p .35111 .45826 L F P
0 g
s
.505 .782 .995 r
.35111 .45826 m .34605 .45753 L .34487 .45678 L p F P
0 g
s
.784 .917 .928 r
.65658 .25463 m .66549 .24901 L .66311 .24734 L p F P
0 g
s
.784 .917 .928 r
.66311 .24734 m .66098 .24876 L .65658 .25463 L p F P
0 g
s
.77 .918 .937 r
.65302 .25406 m .66098 .24876 L .65658 .25463 L p F P
0 g
s
.538 .012 0 r
.12691 .37219 m .12552 .37086 L .12223 .36807 L p F P
0 g
s
.49 .109 .244 r
.45997 .36946 m .46706 .36974 L .45912 .37129 L closepath p F P
0 g
s
.598 .931 .958 r
.58287 .43445 m .57641 .43713 L .58239 .43437 L closepath p F P
0 g
s
.615 .927 .97 r
.58035 .43386 m .58239 .43437 L .57641 .43713 L p F P
0 g
s
.615 .927 .97 r
.57026 .43799 m .58035 .43386 L p .57641 .43713 L F P
0 g
s
.449 .756 .995 r
.33035 .45457 m .33228 .45576 L p .31971 .45446 L F P
0 g
s
.449 .756 .995 r
.31971 .45446 m .32781 .45397 L .33035 .45457 L p F P
0 g
s
.468 .758 .993 r
.32781 .45397 m .31971 .45446 L .31669 .45258 L p F P
0 g
s
.735 .991 .861 r
.6125 .28267 m .61042 .28289 L .61817 .27697 L closepath p F P
0 g
s
.785 .944 .928 r
.6444 .2616 m .64295 .261 L .64743 .25791 L closepath p F P
0 g
s
.129 0 0 r
.53165 .33794 m .52781 .34004 L .52654 .342 L p F P
0 g
s
.711 .187 0 r
.28908 .33949 m .28606 .33639 L .29136 .33881 L p F P
0 g
s
.711 .187 0 r
.29388 .34156 m .28908 .33949 L p .29136 .33881 L F P
0 g
s
.711 .187 0 r
.29136 .33881 m .29428 .34157 L .29388 .34156 L p F P
0 g
s
.613 .954 .905 r
.62577 .41561 m .62817 .4156 L .61807 .42089 L p F P
0 g
s
.613 .954 .905 r
.62563 .41568 m .62577 .41561 L p .61807 .42089 L F P
0 g
s
.613 .954 .905 r
.61807 .42089 m .61706 .4209 L .62563 .41568 L p F P
0 g
s
.638 .124 0 r
.1133 .35975 m .11676 .36293 L .11405 .35978 L p F P
0 g
s
.638 .124 0 r
.11405 .35978 m .1106 .35661 L .1133 .35975 L p F P
0 g
s
.382 .728 .99 r
.29161 .44913 m .29344 .44914 L .29994 .45102 L p F P
0 g
s
.399 .729 .99 r
.30108 .44904 m .29344 .44914 L .29994 .45102 L p F P
0 g
s
.399 .729 .99 r
.29994 .45102 m .30413 .451 L .30108 .44904 L p F P
0 g
s
0 .389 .805 r
.174 .40549 m .17532 .40607 L .17962 .40883 L p F P
0 g
s
0 .434 .842 r
.18089 .40829 m .18515 .41107 L .17962 .40883 L p F P
0 g
s
0 .434 .842 r
.17962 .40883 m .17532 .40607 L .18089 .40829 L p F P
0 g
s
.6 .877 .992 r
.52225 .44962 m .51225 .45273 L .50958 .45154 L p F P
0 g
s
.587 .873 .994 r
.4996 .45448 m .50958 .45154 L .51225 .45273 L p F P
0 g
s
.205 .622 .95 r
.23565 .4338 m .23928 .4344 L .24452 .43676 L p F P
0 g
s
.216 .626 .953 r
.23928 .4344 m .23565 .4338 L .23249 .43176 L p F P
0 g
s
.606 .945 .934 r
.60554 .42574 m .59678 .42984 L .60458 .42565 L closepath p F P
0 g
s
.625 .943 .953 r
.60307 .4254 m .60458 .42565 L .59678 .42984 L p F P
0 g
s
.625 .943 .953 r
.59296 .43004 m .60307 .4254 L p .59678 .42984 L F P
0 g
s
.768 .982 .909 r
.62291 .27535 m .62286 .27534 L .62302 .27522 L closepath p F P
0 g
s
.558 .887 .628 r
.69105 .37496 m .69101 .375 L .69301 .37363 L p F P
0 g
s
.558 .887 .628 r
.69301 .37363 m .69942 .36769 L .69105 .37496 L p F P
0 g
s
.781 .966 .922 r
.63351 .26829 m .6329 .26812 L .63492 .26668 L closepath p F P
0 g
s
.234 .635 .958 r
.24488 .43522 m .23928 .4344 L .24452 .43676 L p F P
0 g
s
.234 .635 .958 r
.24452 .43676 m .24802 .43729 L .24488 .43522 L p F P
0 g
s
.75 .987 .896 r
.62302 .27522 m .62286 .27534 L .62046 .27523 L p F P
0 g
s
.769 .989 .892 r
.62302 .27522 m .6329 .26812 L .6305 .26763 L p F P
0 g
s
.769 .989 .892 r
.6305 .26763 m .6289 .26884 L .62302 .27522 L p F P
0 g
s
.75 .987 .896 r
.62046 .27523 m .6289 .26884 L .62302 .27522 L p F P
0 g
s
0 0 0 r
.57419 .30984 m .57036 .31259 L .56902 .31371 L p F P
0 g
s
.673 .282 .297 r
.38401 .37443 m .38694 .37712 L .38258 .37673 L closepath p F P
0 g
s
.541 .551 .814 r
.73707 .24708 m .73974 .2429 L .74165 .24723 L closepath p F P
0 g
s
.605 .92 .974 r
.56855 .43755 m .57026 .43799 L .56019 .4419 L p F P
0 g
s
.605 .92 .974 r
.56019 .4419 m .55902 .4416 L .56855 .43755 L p F P
0 g
s
.628 .959 .903 r
.62907 .41559 m .62817 .4156 L .63395 .41244 L closepath p F P
0 g
s
.547 .8 .992 r
.38566 .46021 m .39542 .45848 L .3983 .46034 L p F P
0 g
s
.562 .796 .987 r
.39542 .45848 m .38566 .46021 L .38276 .45834 L p F P
0 g
s
.453 .066 .215 r
.48099 .36664 m .48227 .36379 L .47154 .36635 L p F P
0 g
s
.453 .066 .215 r
.47154 .36635 m .4702 .36915 L .48099 .36664 L p F P
0 g
s
.669 .12 0 r
.26384 .32131 m .26511 .32255 L .26075 .31985 L closepath p F P
0 g
s
.589 .852 .994 r
.48421 .45455 m .48605 .45556 L .47497 .45761 L p F P
0 g
s
.589 .852 .994 r
.47497 .45761 m .47427 .45724 L .48421 .45455 L p F P
0 g
s
.267 0 .056 r
.5152 .34896 m .51546 .34851 L .50563 .35223 L p F P
0 g
s
.267 0 .056 r
.50563 .35223 m .5052 .35296 L .5152 .34896 L p F P
0 g
s
.476 .77 .995 r
.34605 .45753 m .34487 .45678 L .343 .45695 L closepath p F P
0 g
s
0 0 0 r
.73077 .3311 m .73051 .33184 L .73147 .33028 L closepath p F P
0 g
s
.557 .177 .275 r
.44767 .37297 m .44726 .37384 L .44525 .37323 L closepath p F P
0 g
s
.553 .169 .268 r
.44638 .37588 m .44726 .37384 L .44525 .37323 L p F P
0 g
s
.553 .169 .268 r
.43476 .37705 m .44638 .37588 L p .44525 .37323 L F P
0 g
s
.553 .169 .268 r
.43455 .37698 m .43476 .37705 L p .44525 .37323 L F P
0 g
s
.606 .886 .99 r
.53229 .44633 m .53423 .44716 L .52409 .45039 L p F P
0 g
s
.606 .886 .99 r
.52409 .45039 m .52225 .44962 L .53229 .44633 L p F P
0 g
s
.431 0 0 r
.2304 .29777 m .23305 .29979 L .23702 .30278 L p F P
0 g
s
0 .108 .57 r
.23305 .29979 m .2304 .29777 L .22725 .29521 L p F P
0 g
s
.584 .022 0 r
.25606 .31704 m .26064 .31978 L .25707 .31694 L p F P
0 g
s
.584 .022 0 r
.25707 .31694 m .25264 .31415 L .25606 .31704 L p F P
0 g
s
.448 .426 .741 r
.7466 .26075 m .74672 .26056 L .74682 .26085 L closepath p F P
0 g
s
.572 .051 0 r
.11894 .36518 m .11676 .36293 L .12027 .36606 L p F P
0 g
s
.572 .051 0 r
.12027 .36606 m .12223 .36807 L .11894 .36518 L p F P
0 g
s
.594 .87 .994 r
.50754 .45056 m .50958 .45154 L .4996 .45448 L p F P
0 g
s
.594 .87 .994 r
.4996 .45448 m .49694 .45325 L .50754 .45056 L p F P
0 g
s
.575 .868 .995 r
.49694 .45325 m .4996 .45448 L p .48693 .456 L F P
0 g
s
.749 .303 .192 r
.32648 .36031 m .33301 .36226 L .3302 .35902 L p F P
0 g
s
.749 .303 .192 r
.32497 .35841 m .32648 .36031 L p .3302 .35902 L F P
0 g
s
.749 .303 .192 r
.3302 .35902 m .32613 .35775 L .32497 .35841 L p F P
0 g
s
.692 .291 .281 r
.36888 .37506 m .37756 .37621 L .37437 .37306 L p F P
0 g
s
.692 .291 .281 r
.36837 .3745 m .36888 .37506 L p .37437 .37306 L F P
0 g
s
.692 .291 .281 r
.37437 .37306 m .36988 .37244 L .36837 .3745 L p F P
0 g
s
.425 .818 .594 r
.58037 .30547 m .57419 .30984 L .5793 .3062 L closepath p F P
0 g
s
0 0 0 r
.5779 .30718 m .5793 .3062 L .57419 .30984 L p F P
0 g
s
0 0 0 r
.57427 .30988 m .5779 .30718 L p .57419 .30984 L F P
0 g
s
0 0 0 r
.56902 .31371 m .57427 .30988 L p .57419 .30984 L F P
0 g
s
.015 .404 .854 r
.19745 .27425 m .19697 .27402 L .19382 .27077 L p F P
0 g
s
.092 0 0 r
.53781 .33461 m .53165 .33794 L .53739 .33521 L closepath p F P
0 g
s
.129 0 0 r
.53582 .33751 m .53739 .33521 L .53165 .33794 L p F P
0 g
s
.129 0 0 r
.52654 .342 m .53582 .33751 L p .53165 .33794 L F P
0 g
s
0 .316 .751 r
.15878 .39626 m .16204 .39799 L .16613 .40085 L p F P
0 g
s
0 .321 .761 r
.16204 .39799 m .15878 .39626 L .15551 .39377 L p F P
0 g
s
0 .122 .574 r
.23675 .30253 m .24082 .30549 L .23702 .30278 L p F P
0 g
s
0 .122 .574 r
.23702 .30278 m .23305 .29979 L .23675 .30253 L p F P
0 g
s
0 0 .159 r
.73908 .31916 m .73846 .31995 L .73898 .31681 L p F P
0 g
s
0 0 .159 r
.73898 .31681 m .74112 .31408 L .73908 .31916 L p F P
0 g
s
.698 .747 .889 r
.711 .23348 m .70073 .23759 L .69835 .23465 L p F P
0 g
s
.685 .729 .884 r
.70073 .23759 m .711 .23348 L .7134 .23696 L p F P
0 g
s
.534 .153 .264 r
.45785 .3742 m .45912 .37129 L .44767 .37297 L p F P
0 g
s
.534 .153 .264 r
.45263 .37495 m .45785 .3742 L p .44767 .37297 L F P
0 g
s
.534 .153 .264 r
.44767 .37297 m .44726 .37384 L .45263 .37495 L p F P
0 g
s
.646 .675 .863 r
.7134 .23696 m .72376 .23391 L .72618 .23803 L p F P
0 g
s
.661 .695 .871 r
.72376 .23391 m .7134 .23696 L .711 .23348 L p F P
0 g
s
.41 .388 .724 r
.74682 .26085 m .7511 .26347 L .74876 .26728 L closepath p F P
0 g
s
.393 .391 .738 r
.74672 .26056 m .74682 .26085 L .7511 .26347 L p F P
0 g
s
.459 .454 .766 r
.74419 .25349 m .74975 .25541 L .74672 .26056 L closepath p F P
0 g
s
.393 .391 .738 r
.75446 .25807 m .74975 .25541 L .74672 .26056 L p F P
0 g
s
.393 .391 .738 r
.7511 .26347 m .75446 .25807 L p .74672 .26056 L F P
0 g
s
.558 .806 .991 r
.3983 .46034 m .40809 .45844 L .41095 .46027 L p F P
0 g
s
.574 .8 .985 r
.40809 .45844 m .3983 .46034 L .39542 .45848 L p F P
0 g
s
.668 .116 0 r
.27585 .33088 m .27297 .32823 L .27799 .33078 L p F P
0 g
s
.668 .116 0 r
.27799 .33078 m .27903 .33169 L .27585 .33088 L p F P
0 g
s
.383 .728 .99 r
.29161 .44913 m .29344 .44914 L .28995 .44812 L closepath p F P
0 g
s
0 .161 .619 r
.14041 .38321 m .1415 .38398 L .14534 .38695 L p F P
0 g
s
0 .235 .692 r
.1457 .38664 m .14953 .38962 L .14534 .38695 L p F P
0 g
s
0 .235 .692 r
.14534 .38695 m .1415 .38398 L .1457 .38664 L p F P
0 g
s
.76 .293 .137 r
.31138 .35288 m .31735 .35504 L .31456 .35182 L p F P
0 g
s
.76 .293 .137 r
.30958 .35063 m .31138 .35288 L p .31456 .35182 L F P
0 g
s
.76 .293 .137 r
.31456 .35182 m .31062 .35033 L .30958 .35063 L p F P
0 g
s
.717 .301 .258 r
.35595 .36852 m .35774 .37049 L .35468 .36989 L closepath p F P
0 g
s
.615 .957 .839 r
.65679 .39987 m .65072 .40368 L .64902 .404 L p F P
0 g
s
.733 .307 .237 r
.34272 .36732 m .35002 .36899 L .34711 .36576 L p F P
0 g
s
.733 .307 .237 r
.34043 .36446 m .34272 .36732 L p .34711 .36576 L F P
0 g
s
.733 .307 .237 r
.34711 .36576 m .34074 .36419 L .34043 .36446 L p F P
0 g
s
0 .276 .748 r
.21784 .28786 m .22151 .29101 L .21733 .28848 L p F P
0 g
s
0 .276 .748 r
.21733 .28848 m .21373 .28532 L .21784 .28786 L p F P
0 g
s
0 .27 .742 r
.21212 .28431 m .21373 .28532 L .21733 .28848 L p F P
0 g
s
.302 .683 .976 r
.26357 .44235 m .26452 .44242 L .26246 .44166 L closepath p F P
0 g
s
.499 .494 .782 r
.74345 .25334 m .74388 .25268 L .74419 .25349 L closepath p F P
0 g
s
0 .352 .783 r
.16699 .40042 m .16204 .39799 L .16613 .40085 L p F P
0 g
s
0 .352 .783 r
.16954 .40222 m .16699 .40042 L p .16613 .40085 L F P
0 g
s
0 .352 .783 r
.16613 .40085 m .17075 .40312 L .16954 .40222 L p F P
0 g
s
.477 .769 .995 r
.33228 .45576 m .33535 .45548 L .343 .45695 L p F P
0 g
s
.474 .771 .996 r
.33228 .45576 m .33535 .45548 L .33035 .45457 L closepath p F P
0 g
s
.432 0 0 r
.24677 .30949 m .24553 .3087 L .24505 .30838 L closepath p F P
0 g
s
.484 .765 .993 r
.34189 .45481 m .33535 .45548 L .343 .45695 L p F P
0 g
s
.484 .765 .993 r
.343 .45695 m .34487 .45678 L .34189 .45481 L p F P
0 g
s
.329 .307 .682 r
.75441 .26663 m .7511 .26347 L .74876 .26728 L p F P
0 g
s
.329 .307 .682 r
.75105 .27202 m .75441 .26663 L p .74876 .26728 L F P
0 g
s
.329 .307 .682 r
.74876 .26728 m .7496 .2705 L .75105 .27202 L p F P
0 g
s
.141 .578 .928 r
.22017 .42779 m .22128 .42804 L .21815 .42646 L closepath p F P
0 g
s
.015 .404 .854 r
.19382 .27077 m .19416 .27093 L .19745 .27425 L p F P
0 g
s
.016 .405 .855 r
.19886 .27321 m .20217 .27652 L .19745 .27425 L p F P
0 g
s
.016 .405 .855 r
.19745 .27425 m .19416 .27093 L .19886 .27321 L p F P
0 g
s
.575 .868 .995 r
.48693 .456 m .49633 .45339 L .49694 .45325 L p F P
0 g
s
.59 .858 .994 r
.48693 .456 m .49633 .45339 L .48605 .45556 L closepath p F P
0 g
s
.567 .812 .991 r
.41095 .46027 m .42076 .45823 L .4236 .46003 L p F P
0 g
s
.582 .805 .984 r
.42076 .45823 m .41095 .46027 L .40809 .45844 L p F P
0 g
s
.696 .295 .283 r
.36988 .37244 m .36837 .3745 L .3658 .37187 L closepath p F P
0 g
s
0 0 0 r
.7329 .33008 m .73631 .32451 L .73147 .33028 L p F P
0 g
s
0 0 0 r
.72985 .33373 m .7329 .33008 L p .73147 .33028 L F P
0 g
s
0 0 0 r
.73147 .33028 m .73051 .33184 L .72985 .33373 L p F P
0 g
s
0 0 .258 r
.74553 .30842 m .74112 .31408 L .74258 .3092 L p F P
0 g
s
0 0 .258 r
.74581 .30748 m .74553 .30842 L p .74258 .3092 L F P
0 g
s
0 0 .258 r
.74258 .3092 m .74606 .30473 L .74581 .30748 L p F P
0 g
s
.764 .889 .934 r
.67313 .24441 m .66549 .24901 L .66311 .24734 L p F P
0 g
s
.267 .186 .575 r
.75209 .28343 m .75108 .28487 L .74964 .28103 L p F P
0 g
s
.267 .186 .575 r
.74964 .28103 m .75135 .27858 L .75209 .28343 L p F P
0 g
s
.758 .265 .057 r
.29428 .34157 m .29453 .34186 L .2999 .34426 L p F P
0 g
s
.768 .285 .085 r
.2972 .34511 m .30276 .34744 L .2999 .34426 L p F P
0 g
s
.768 .285 .085 r
.2999 .34426 m .29453 .34186 L .2972 .34511 L p F P
0 g
s
.772 .975 .917 r
.63492 .26668 m .6329 .26812 L .6305 .26763 L p F P
0 g
s
.574 .818 .991 r
.4236 .46003 m .43345 .45786 L .43626 .45962 L p F P
0 g
s
.588 .812 .985 r
.43345 .45786 m .4236 .46003 L .42076 .45823 L p F P
0 g
s
.455 .836 .605 r
.5859 .30138 m .58037 .30547 L .5793 .3062 L p F P
0 g
s
.447 .463 .782 r
.74388 .25268 m .74419 .25349 L .74975 .25541 L p F P
0 g
s
.603 .842 .989 r
.48421 .45455 m .47427 .45724 L .47152 .45567 L p F P
0 g
s
.604 .642 .862 r
.72618 .23803 m .72698 .2379 L .72656 .23872 L closepath p F P
0 g
s
.572 .621 .862 r
.73667 .23654 m .72698 .2379 L .72656 .23872 L p F P
0 g
s
.572 .621 .862 r
.73914 .2416 m .73667 .23654 L p .72656 .23872 L F P
0 g
s
.351 0 .139 r
.50286 .35752 m .50422 .35483 L .49409 .35817 L p F P
0 g
s
.351 0 .139 r
.49409 .35817 m .4927 .36084 L .50286 .35752 L p F P
0 g
s
0 0 0 r
.72161 .34409 m .72082 .34542 L .72374 .34172 L closepath p F P
0 g
s
0 .076 .551 r
.12675 .37199 m .13035 .37509 L .12691 .37219 L p F P
0 g
s
.538 .012 0 r
.12223 .36807 m .12331 .3691 L .12691 .37219 L p F P
0 g
s
0 .076 .551 r
.12691 .37219 m .12331 .3691 L .12675 .37199 L p F P
0 g
s
.353 .311 .672 r
.7496 .2705 m .75105 .27202 L .75028 .27324 L closepath p F P
0 g
s
.357 .703 .984 r
.27043 .44129 m .27293 .44294 L .26452 .44242 L p F P
0 g
s
.357 .703 .984 r
.26935 .44086 m .27043 .44129 L p .26452 .44242 L F P
0 g
s
.357 .703 .984 r
.26045 .44034 m .26935 .44086 L p .26452 .44242 L F P
0 g
s
.357 .703 .984 r
.26452 .44242 m .26246 .44166 L .26045 .44034 L p F P
0 g
s
.748 .823 .91 r
.67561 .24291 m .68577 .23719 L .68814 .23963 L p F P
0 g
s
.723 .817 .924 r
.6929 .23731 m .68814 .23963 L .68577 .23719 L p F P
0 g
s
.502 .512 .799 r
.74165 .24723 m .74649 .24802 L .74388 .25268 L closepath p F P
0 g
s
.447 .463 .782 r
.75248 .24979 m .74649 .24802 L .74388 .25268 L p F P
0 g
s
.447 .463 .782 r
.75273 .25052 m .75248 .24979 L p .74388 .25268 L F P
0 g
s
.447 .463 .782 r
.74975 .25541 m .75273 .25052 L p .74388 .25268 L F P
0 g
s
.612 .907 .984 r
.55762 .44115 m .54756 .44482 L .54496 .44394 L p F P
0 g
s
.597 .902 .985 r
.53492 .44742 m .54496 .44394 L .54756 .44482 L p F P
0 g
s
0 .394 .813 r
.17532 .40607 m .174 .40549 L .17075 .40312 L p F P
0 g
s
.58 .825 .991 r
.43626 .45962 m .44614 .45731 L .44893 .45902 L p F P
0 g
s
.592 .818 .986 r
.44614 .45731 m .43626 .45962 L .43345 .45786 L p F P
0 g
s
.599 .833 .988 r
.47152 .45567 m .4616 .45823 L .45883 .45658 L p F P
0 g
s
.585 .832 .992 r
.44893 .45902 m .45883 .45658 L .4616 .45823 L p F P
0 g
s
.791 .973 .912 r
.63492 .26668 m .64295 .261 L .64056 .26015 L p F P
0 g
s
.791 .973 .912 r
.64056 .26015 m .63998 .26058 L .63492 .26668 L p F P
0 g
s
.772 .975 .917 r
.6305 .26763 m .63998 .26058 L .63492 .26668 L p F P
0 g
s
.596 .825 .987 r
.45883 .45658 m .44893 .45902 L .44614 .45731 L p F P
0 g
s
0 0 0 r
.73051 .33184 m .72792 .33589 L .72985 .33373 L closepath p F P
0 g
s
.534 .853 .559 r
.70245 .365 m .70101 .36623 L .70674 .36077 L closepath p F P
0 g
s
.615 .937 .957 r
.59156 .42979 m .59296 .43004 L .58287 .43445 L p F P
0 g
s
.615 .937 .957 r
.58287 .43445 m .58239 .43437 L .59156 .42979 L p F P
0 g
s
.298 0 .106 r
.51407 .35112 m .5152 .34896 L .5052 .35296 L p F P
0 g
s
.298 0 .106 r
.5052 .35296 m .50422 .35483 L .51407 .35112 L p F P
0 g
s
.067 .524 .898 r
.20472 .42114 m .20476 .42115 L .20464 .42108 L closepath p F P
0 g
s
.162 .578 .934 r
.20711 .4203 m .21172 .42293 L .20476 .42115 L p F P
0 g
s
.162 .578 .934 r
.20151 .41888 m .20711 .4203 L p .20476 .42115 L F P
0 g
s
.162 .578 .934 r
.20476 .42115 m .20464 .42108 L .20151 .41888 L p F P
0 g
s
.078 .524 .902 r
.20464 .42108 m .20151 .41888 L .20022 .4185 L closepath p F P
0 g
s
.766 .281 0 r
.10475 .35019 m .1044 .34965 L .10111 .34645 L p F P
0 g
s
.693 .296 .289 r
.36053 .37378 m .35774 .37049 L .3658 .37187 L p F P
0 g
s
.693 .296 .289 r
.36806 .37494 m .36053 .37378 L p .3658 .37187 L F P
0 g
s
.693 .296 .289 r
.3658 .37187 m .36837 .3745 L .36806 .37494 L p F P
0 g
s
.122 .001 .429 r
.7516 .2934 m .74766 .29893 L .74776 .29454 L p F P
0 g
s
.122 .001 .429 r
.74776 .29454 m .75171 .289 L .7516 .2934 L p F P
0 g
s
.424 .739 .992 r
.29803 .44701 m .30108 .44904 L .29344 .44914 L p F P
0 g
s
.424 .739 .992 r
.28854 .4472 m .29803 .44701 L p .29344 .44914 L F P
0 g
s
.424 .739 .992 r
.29344 .44914 m .28995 .44812 L .28854 .4472 L p F P
0 g
s
.223 .62 .954 r
.22416 .42705 m .22899 .42959 L .22128 .42804 L p F P
0 g
s
.223 .62 .954 r
.21698 .42566 m .22416 .42705 L p .22128 .42804 L F P
0 g
s
.223 .62 .954 r
.22128 .42804 m .21815 .42646 L .21698 .42566 L p F P
0 g
s
.733 .28 .175 r
.32613 .35775 m .32497 .35841 L .32372 .35706 L closepath p F P
0 g
s
.618 .66 .869 r
.72698 .2379 m .72618 .23803 L .72376 .23391 L p F P
0 g
s
0 .463 .859 r
.18932 .41374 m .1895 .41381 L .18886 .41342 L closepath p F P
0 g
s
.406 .019 .188 r
.48257 .36316 m .489 .36187 L .48227 .36379 L closepath p F P
0 g
s
.588 .942 .796 r
.66081 .39724 m .65679 .39987 L .66006 .39745 L closepath p F P
0 g
s
.615 .957 .839 r
.6585 .39771 m .66006 .39745 L .65679 .39987 L p F P
0 g
s
.615 .957 .839 r
.65176 .40199 m .6585 .39771 L p .65679 .39987 L F P
0 g
s
.615 .957 .839 r
.64902 .404 m .65176 .40199 L p .65679 .39987 L F P
0 g
s
.699 .16 0 r
.26358 .32287 m .26818 .32559 L .26511 .32255 L p F P
0 g
s
.699 .16 0 r
.26067 .31981 m .26358 .32287 L p .26511 .32255 L F P
0 g
s
.699 .16 0 r
.26511 .32255 m .26075 .31985 L .26067 .31981 L p F P
0 g
s
.636 .956 .93 r
.61706 .4209 m .61564 .42078 L .62563 .41568 L closepath p F P
0 g
s
.537 .166 .285 r
.44726 .37384 m .45263 .37495 L .44638 .37588 L closepath p F P
0 g
s
.529 .776 .988 r
.35453 .45553 m .34487 .45678 L .34189 .45481 L p F P
0 g
s
.751 .235 0 r
.28101 .33386 m .27903 .33169 L .27585 .33088 L p F P
0 g
s
.54 .9 .695 r
.59038 .29809 m .5859 .30138 L .58949 .29855 L closepath p F P
0 g
s
.455 .836 .605 r
.58793 .29939 m .58949 .29855 L .5859 .30138 L p F P
0 g
s
.455 .836 .605 r
.58476 .30184 m .58793 .29939 L p .5859 .30138 L F P
0 g
s
.455 .836 .605 r
.5793 .3062 m .58476 .30184 L p .5859 .30138 L F P
0 g
s
.095 .529 .908 r
.19136 .41309 m .19575 .41582 L .1895 .41381 L p F P
0 g
s
.095 .529 .908 r
.1861 .41141 m .19136 .41309 L p .1895 .41381 L F P
0 g
s
.095 .529 .908 r
.1895 .41381 m .18886 .41342 L .1861 .41141 L p F P
0 g
s
.301 .246 .627 r
.75327 .27557 m .75135 .27858 L .75028 .27324 L p F P
0 g
s
.301 .246 .627 r
.75028 .27324 m .75105 .27202 L .75327 .27557 L p F P
0 g
s
.411 0 0 r
.24237 .30659 m .24082 .30549 L .24505 .30838 L p F P
0 g
s
.411 0 0 r
.24505 .30838 m .24553 .3087 L .24237 .30659 L p F P
0 g
s
.028 0 0 r
.54642 .33037 m .54783 .3285 L .53781 .33461 L p F P
0 g
s
.028 0 0 r
.53781 .33461 m .53739 .33521 L .54642 .33037 L p F P
0 g
s
.748 .235 0 r
.28385 .33702 m .28908 .33949 L .28606 .33639 L p F P
0 g
s
.748 .235 0 r
.28606 .33639 m .28101 .33386 L .28385 .33702 L p F P
0 g
s
.631 .96 .905 r
.63395 .41244 m .62817 .4156 L .62577 .41561 L p F P
0 g
s
0 .281 .731 r
.15225 .3912 m .14953 .38962 L .15343 .39256 L p F P
0 g
s
0 .281 .731 r
.15343 .39256 m .15551 .39377 L .15225 .3912 L p F P
0 g
s
.618 .66 .869 r
.72376 .23391 m .72958 .23269 L .72698 .2379 L p F P
0 g
s
.594 .62 .848 r
.73422 .23182 m .72958 .23269 L .72698 .2379 L p F P
0 g
s
.594 .62 .848 r
.72698 .2379 m .73667 .23654 L .73422 .23182 L p F P
0 g
s
0 .271 .748 r
.21373 .28532 m .21212 .28431 L .20897 .2813 L p F P
0 g
s
.736 .256 .105 r
.31062 .35033 m .30958 .35063 L .30864 .34964 L closepath p F P
0 g
s
0 .301 .758 r
.22409 .29253 m .22151 .29101 L .22529 .29409 L p F P
0 g
s
0 .301 .758 r
.22529 .29409 m .22725 .29521 L .22409 .29253 L p F P
0 g
s
.296 .671 .974 r
.26246 .44166 m .26045 .44034 L .25894 .44019 L closepath p F P
0 g
s
.455 .745 .991 r
.31356 .45064 m .30413 .451 L .30108 .44904 L p F P
0 g
s
.436 .744 .993 r
.31375 .45069 m .31669 .45258 L p .30413 .451 L F P
0 g
s
.436 .744 .993 r
.30413 .451 m .31356 .45064 L .31375 .45069 L p F P
0 g
s
.623 .95 .934 r
.61342 .42059 m .61564 .42078 L .60554 .42574 L p F P
0 g
s
.623 .95 .934 r
.60554 .42574 m .60458 .42565 L .61342 .42059 L p F P
0 g
s
.045 0 .344 r
.74691 .30356 m .74606 .30473 L .74615 .30103 L p F P
0 g
s
.045 0 .344 r
.74615 .30103 m .74766 .29893 L .74691 .30356 L p F P
0 g
s
.619 .914 .98 r
.5677 .43728 m .56855 .43755 L .55902 .4416 L p F P
0 g
s
.619 .914 .98 r
.55902 .4416 m .55762 .44115 L .5677 .43728 L p F P
0 g
s
.5 .127 .264 r
.46706 .36974 m .45912 .37129 L .45785 .3742 L p F P
0 g
s
.766 .281 0 r
.10111 .34645 m .10143 .34695 L .10475 .35019 L p F P
0 g
s
.68 .179 0 r
.1039 .35016 m .10721 .35341 L .10475 .35019 L p F P
0 g
s
.68 .179 0 r
.10475 .35019 m .10143 .34695 L .1039 .35016 L p F P
0 g
s
.649 .263 .299 r
.39656 .37733 m .39709 .37774 L .39635 .37771 L closepath p F P
0 g
s
.005 .469 .868 r
.18886 .41342 m .1861 .41141 L .18515 .41107 L closepath p F P
0 g
s
.724 .295 .229 r
.34074 .36419 m .34043 .36446 L .34003 .36402 L closepath p F P
0 g
s
.601 .852 .992 r
.49633 .45339 m .48605 .45556 L .48421 .45455 L p F P
0 g
s
.036 .429 .868 r
.20582 .27818 m .20217 .27652 L .20559 .27978 L p F P
0 g
s
.036 .429 .868 r
.20559 .27978 m .20897 .2813 L .20582 .27818 L p F P
0 g
s
.559 .909 .7 r
.59691 .29316 m .59038 .29809 L .58949 .29855 L p F P
0 g
s
.281 .662 .97 r
.24802 .43729 m .25354 .43789 L .25894 .44019 L p F P
0 g
s
.292 .665 .972 r
.25354 .43789 m .24802 .43729 L .24488 .43522 L p F P
0 g
s
.216 .626 .953 r
.23249 .43176 m .23409 .43202 L .23928 .4344 L p F P
0 g
s
.245 .638 .961 r
.24173 .4331 m .23409 .43202 L .23928 .4344 L p F P
0 g
s
.245 .638 .961 r
.23928 .4344 m .24488 .43522 L .24173 .4331 L p F P
0 g
s
.608 .949 .798 r
.67013 .39092 m .66081 .39724 L .66006 .39745 L p F P
0 g
s
.5 .773 .993 r
.33891 .45275 m .34189 .45481 L .33535 .45548 L p F P
0 g
s
.5 .773 .993 r
.32928 .45386 m .33891 .45275 L p .33535 .45548 L F P
0 g
s
.5 .773 .993 r
.33535 .45548 m .33035 .45457 L .32928 .45386 L p F P
0 g
s
0 .125 .596 r
.13385 .3778 m .13035 .37509 L .13402 .37815 L p F P
0 g
s
0 .125 .596 r
.13402 .37815 m .13713 .38055 L .13385 .3778 L p F P
0 g
s
0 .168 .632 r
.1415 .38398 m .14041 .38321 L .13713 .38055 L p F P
0 g
s
.734 .28 .172 r
.32012 .35829 m .31735 .35504 L .32372 .35706 L p F P
0 g
s
.734 .28 .172 r
.32337 .35928 m .32012 .35829 L p .32372 .35706 L F P
0 g
s
.734 .28 .172 r
.32372 .35706 m .32497 .35841 L .32337 .35928 L p F P
0 g
s
.6 .051 0 r
.24838 .31128 m .24553 .3087 L .24237 .30659 L p F P
0 g
s
.631 .932 .968 r
.59046 .42952 m .59156 .42979 L .58239 .43437 L p F P
0 g
s
.631 .932 .968 r
.58239 .43437 m .58035 .43386 L .59046 .42952 L p F P
0 g
s
.724 .295 .23 r
.33577 .36553 m .33301 .36226 L .34003 .36402 L p F P
0 g
s
.724 .295 .23 r
.33843 .36619 m .33577 .36553 L p .34003 .36402 L F P
0 g
s
.724 .295 .23 r
.34003 .36402 m .34043 .36446 L .33843 .36619 L p F P
0 g
s
.781 .954 .928 r
.64743 .25791 m .64295 .261 L .64056 .26015 L p F P
0 g
s
0 0 0 r
.72875 .33612 m .72374 .34172 L .72792 .33589 L p F P
0 g
s
0 0 0 r
.72792 .33589 m .72985 .33373 L .72875 .33612 L p F P
0 g
s
.621 .245 .309 r
.42049 .37789 m .40957 .37807 L .40918 .37885 L p F P
0 g
s
.641 .267 .319 r
.40957 .37807 m .40918 .37885 L .40813 .37805 L closepath p F P
0 g
s
.638 .27 .33 r
.40058 .38082 m .39709 .37774 L .40813 .37805 L p F P
0 g
s
.638 .27 .33 r
.4082 .38099 m .40058 .38082 L p .40813 .37805 L F P
0 g
s
.638 .27 .33 r
.40813 .37805 m .40918 .37885 L .4082 .38099 L p F P
0 g
s
.607 .897 .987 r
.54416 .44364 m .54496 .44394 L .53492 .44742 L p F P
0 g
s
.607 .897 .987 r
.53492 .44742 m .53423 .44716 L .54416 .44364 L p F P
0 g
s
.764 .889 .934 r
.67324 .24093 m .67462 .24209 L .67313 .24441 L p F P
0 g
s
.764 .889 .934 r
.66311 .24734 m .67324 .24093 L p .67313 .24441 L F P
0 g
s
.764 .863 .922 r
.67561 .24291 m .67313 .24441 L .67462 .24209 L closepath p F P
0 g
s
0 .394 .813 r
.17075 .40312 m .17109 .40327 L .17532 .40607 L p F P
0 g
s
0 .444 .853 r
.1767 .40548 m .18089 .40829 L .17532 .40607 L p F P
0 g
s
0 .444 .853 r
.17532 .40607 m .17109 .40327 L .1767 .40548 L p F P
0 g
s
.734 .808 .91 r
.6929 .23731 m .69835 .23465 L .69597 .23185 L p F P
0 g
s
.734 .808 .91 r
.69597 .23185 m .6957 .232 L .6929 .23731 L p F P
0 g
s
.723 .817 .924 r
.68577 .23719 m .6957 .232 L .6929 .23731 L p F P
0 g
s
.494 .525 .817 r
.73974 .2429 m .74165 .24723 L .74649 .24802 L p F P
0 g
s
.619 .248 .317 r
.42227 .37784 m .42185 .37875 L .42049 .37789 L closepath p F P
0 g
s
.621 .245 .309 r
.42096 .38082 m .42185 .37875 L .42049 .37789 L p F P
0 g
s
.621 .245 .309 r
.41208 .38097 m .42096 .38082 L p .42049 .37789 L F P
0 g
s
.621 .245 .309 r
.40918 .37885 m .41208 .38097 L p .42049 .37789 L F P
0 g
s
.533 .785 .99 r
.35748 .45751 m .36718 .45605 L .37011 .45802 L p F P
0 g
s
.548 .781 .985 r
.36718 .45605 m .35748 .45751 L .35453 .45553 L p F P
0 g
s
.421 .044 .215 r
.489 .36187 m .48227 .36379 L .48099 .36664 L p F P
0 g
s
.608 .236 .312 r
.43328 .38011 m .4345 .37708 L .42227 .37784 L p F P
0 g
s
.608 .236 .312 r
.42507 .38059 m .43328 .38011 L p .42227 .37784 L F P
0 g
s
.608 .236 .312 r
.42227 .37784 m .42185 .37875 L .42507 .38059 L p F P
0 g
s
.374 .715 .987 r
.28995 .44812 m .28854 .4472 L .28717 .44717 L closepath p F P
0 g
s
.367 .711 .986 r
.27603 .44493 m .28121 .44508 L .28717 .44717 L p F P
0 g
s
.379 .715 .987 r
.28121 .44508 m .27603 .44493 L .27293 .44294 L p F P
0 g
s
.737 .254 .096 r
.30562 .35063 m .30276 .34744 L .30864 .34964 L p F P
0 g
s
.737 .254 .096 r
.30728 .35124 m .30562 .35063 L p .30864 .34964 L F P
0 g
s
.737 .254 .096 r
.30864 .34964 m .30958 .35063 L .30728 .35124 L p F P
0 g
s
.657 .284 .326 r
.39491 .38058 m .40058 .38082 L .39709 .37774 L p F P
0 g
s
.657 .284 .326 r
.39709 .37774 m .39635 .37771 L .39491 .38058 L p F P
0 g
s
.671 .299 .333 r
.39015 .38028 m .39491 .38058 L .39635 .37771 L p F P
0 g
s
.671 .299 .333 r
.39635 .37771 m .38694 .37712 L .39015 .38028 L p F P
0 g
s
.625 .115 0 r
.10992 .35654 m .1133 .35975 L .1106 .35661 L p F P
0 g
s
.625 .115 0 r
.1106 .35661 m .10721 .35341 L .10992 .35654 L p F P
0 g
s
.744 .322 .248 r
.34043 .36446 m .34272 .36732 L .33843 .36619 L closepath p F P
0 g
s
.635 .956 .777 r
.6004 .29054 m .59691 .29316 L .59961 .29082 L closepath p F P
0 g
s
.559 .909 .7 r
.59796 .29143 m .59961 .29082 L .59691 .29316 L p F P
0 g
s
.559 .909 .7 r
.59476 .29397 m .59796 .29143 L p .59691 .29316 L F P
0 g
s
.559 .909 .7 r
.58949 .29855 m .59476 .29397 L p .59691 .29316 L F P
0 g
s
.722 .316 .278 r
.35285 .37226 m .36053 .37378 L .35774 .37049 L p F P
0 g
s
.722 .316 .278 r
.35276 .37214 m .35285 .37226 L p .35774 .37049 L F P
0 g
s
.722 .316 .278 r
.35774 .37049 m .35468 .36989 L .35276 .37214 L p F P
0 g
s
.525 .004 0 r
.12331 .3691 m .12223 .36807 L .11894 .36518 L p F P
0 g
s
.76 .862 .925 r
.6834 .23488 m .68577 .23719 L .67561 .24291 L p F P
0 g
s
.76 .862 .925 r
.67692 .23874 m .6834 .23488 L p .67561 .24291 L F P
0 g
s
.76 .862 .925 r
.67561 .24291 m .67462 .24209 L .67692 .23874 L p F P
0 g
s
.302 .251 .633 r
.75672 .27016 m .75327 .27557 L .75105 .27202 L p F P
0 g
s
.302 .251 .633 r
.75105 .27202 m .75441 .26663 L .75672 .27016 L p F P
0 g
s
.677 .128 0 r
.27129 .32863 m .26818 .32559 L .27297 .32823 L p F P
0 g
s
.677 .128 0 r
.27518 .33067 m .27129 .32863 L p .27297 .32823 L F P
0 g
s
.677 .128 0 r
.27297 .32823 m .27585 .33088 L .27518 .33067 L p F P
0 g
s
.79 .93 .926 r
.65302 .25406 m .64743 .25791 L .65106 .25307 L closepath p F P
0 g
s
.781 .954 .928 r
.65063 .25286 m .65106 .25307 L .64743 .25791 L p F P
0 g
s
.781 .954 .928 r
.64056 .26015 m .65063 .25286 L p .64743 .25791 L F P
0 g
s
0 0 0 r
.54807 .32822 m .54783 .3285 L .54973 .32722 L closepath p F P
0 g
s
.594 .039 0 r
.25167 .31422 m .25606 .31704 L .25264 .31415 L p F P
0 g
s
.594 .039 0 r
.25264 .31415 m .24838 .31128 L .25167 .31422 L p F P
0 g
s
.033 0 0 r
.54528 .33192 m .54642 .33037 L .53739 .33521 L p F P
0 g
s
.033 0 0 r
.5407 .33484 m .54528 .33192 L p .53739 .33521 L F P
0 g
s
.033 0 0 r
.53739 .33521 m .53582 .33751 L .5407 .33484 L p F P
0 g
s
.758 .259 .033 r
.29428 .34157 m .29453 .34186 L .29388 .34156 L closepath p F P
0 g
s
0 0 .142 r
.74342 .31353 m .73908 .31916 L .74112 .31408 L p F P
0 g
s
0 0 .142 r
.74112 .31408 m .74553 .30842 L .74342 .31353 L p F P
0 g
s
.619 .925 .972 r
.57792 .43324 m .58035 .43386 L .57026 .43799 L p F P
0 g
s
.619 .925 .972 r
.57026 .43799 m .56855 .43755 L .57792 .43324 L p F P
0 g
s
0 0 0 r
.55862 .32106 m .55785 .32185 L .56285 .31825 L closepath p F P
0 g
s
.613 .956 .879 r
.63828 .41 m .63395 .41244 L .63759 .41005 L closepath p F P
0 g
s
.631 .96 .905 r
.6359 .41002 m .63759 .41005 L .63395 .41244 L p F P
0 g
s
.631 .96 .905 r
.62577 .41561 m .6359 .41002 L p .63395 .41244 L F P
0 g
s
.146 .573 .929 r
.21815 .42646 m .21698 .42566 L .2164 .42552 L closepath p F P
0 g
s
.567 .193 .292 r
.43455 .37698 m .43476 .37705 L .4345 .37708 L closepath p F P
0 g
s
.467 .759 .994 r
.33035 .45457 m .32928 .45386 L .32781 .45397 L closepath p F P
0 g
s
.645 .959 .778 r
.60758 .28505 m .6004 .29054 L .59961 .29082 L p F P
0 g
s
.125 0 0 r
.53524 .33838 m .53582 .33751 L .52654 .342 L p F P
0 g
s
.125 0 0 r
.52654 .342 m .52521 .34408 L .53524 .33838 L p F P
0 g
s
0 .108 .57 r
.22725 .29521 m .22921 .29673 L .23305 .29979 L p F P
0 g
s
0 .113 .575 r
.23281 .29951 m .23675 .30253 L .23305 .29979 L p F P
0 g
s
0 .113 .575 r
.23305 .29979 m .22921 .29673 L .23281 .29951 L p F P
0 g
s
.548 .79 .988 r
.37011 .45802 m .37985 .45637 L .38276 .45834 L p F P
0 g
s
.568 .784 .98 r
.37985 .45637 m .37011 .45802 L .36718 .45605 L p F P
0 g
s
.678 .295 .314 r
.38099 .37947 m .39015 .38028 L .38694 .37712 L p F P
0 g
s
.678 .295 .314 r
.38694 .37712 m .38258 .37673 L .38099 .37947 L p F P
0 g
s
.613 .881 .99 r
.53229 .44633 m .52225 .44962 L .5196 .44842 L p F P
0 g
s
.6 .877 .992 r
.50958 .45154 m .5196 .44842 L .52225 .44962 L p F P
0 g
s
.578 .218 .32 r
.43476 .37705 m .4345 .37708 L .43328 .38011 L p F P
0 g
s
.578 .217 .319 r
.44638 .37588 m .43476 .37705 L .44042 .37939 L p F P
0 g
s
.578 .218 .32 r
.43328 .38011 m .44042 .37939 L .43476 .37705 L p F P
0 g
s
.235 .164 .569 r
.75465 .27944 m .75209 .28343 L .75135 .27858 L p F P
0 g
s
.235 .164 .569 r
.75135 .27858 m .75327 .27557 L .75465 .27944 L p F P
0 g
s
.772 .285 .07 r
.29193 .34266 m .2972 .34511 L .29453 .34186 L p F P
0 g
s
.772 .285 .07 r
.29108 .34158 m .29193 .34266 L p .29453 .34186 L F P
0 g
s
.772 .285 .07 r
.29453 .34186 m .29388 .34156 L .29108 .34158 L p F P
0 g
s
.468 .758 .993 r
.31669 .45258 m .32077 .45228 L .32781 .45397 L p F P
0 g
s
.463 .76 .994 r
.31669 .45258 m .32077 .45228 L .31375 .45069 L closepath p F P
0 g
s
0 0 0 r
.56902 .31371 m .56787 .3147 L .57427 .30988 L closepath p F P
0 g
s
.561 .044 0 r
.11565 .36217 m .1133 .35975 L .11676 .36293 L p F P
0 g
s
.561 .044 0 r
.11676 .36293 m .11894 .36518 L .11565 .36217 L p F P
0 g
s
0 0 0 r
.71156 .35589 m .71096 .35652 L .71324 .35414 L closepath p F P
0 g
s
0 .168 .632 r
.13713 .38055 m .13772 .38097 L .1415 .38398 L p F P
0 g
s
0 .246 .707 r
.14194 .38362 m .1457 .38664 L .1415 .38398 L p F P
0 g
s
0 .246 .707 r
.1415 .38398 m .13772 .38097 L .14194 .38362 L p F P
0 g
s
.632 .264 .327 r
.40918 .37885 m .41208 .38097 L .4082 .38099 L closepath p F P
0 g
s
.719 .312 .276 r
.35468 .36989 m .35276 .37214 L .35002 .36899 L closepath p F P
0 g
s
0 0 0 r
.72865 .33627 m .72875 .33612 L .72374 .34172 L p F P
0 g
s
0 0 0 r
.72422 .34188 m .72865 .33627 L p .72374 .34172 L F P
0 g
s
0 0 0 r
.72033 .34627 m .72422 .34188 L p .72374 .34172 L F P
0 g
s
0 0 0 r
.72374 .34172 m .72082 .34542 L .72033 .34627 L p F P
0 g
s
.303 .67 .974 r
.25733 .43824 m .25354 .43789 L .25894 .44019 L p F P
0 g
s
.303 .67 .974 r
.25894 .44019 m .26045 .44034 L .25733 .43824 L p F P
0 g
s
0 .321 .761 r
.15551 .39377 m .15802 .3951 L .16204 .39799 L p F P
0 g
s
0 .365 .798 r
.16299 .39751 m .16699 .40042 L .16204 .39799 L p F P
0 g
s
0 .365 .798 r
.16204 .39799 m .15802 .3951 L .16299 .39751 L p F P
0 g
s
.576 .928 .747 r
.67089 .39038 m .67013 .39092 L .67074 .39045 L closepath p F P
0 g
s
.608 .949 .798 r
.66861 .39099 m .67074 .39045 L .67013 .39092 L p F P
0 g
s
.608 .949 .798 r
.66615 .39268 m .66861 .39099 L p .67013 .39092 L F P
0 g
s
.608 .949 .798 r
.66006 .39745 m .66615 .39268 L p .67013 .39092 L F P
0 g
s
.222 .626 .955 r
.23249 .43176 m .23409 .43202 L .22992 .43006 L closepath p F P
0 g
s
.382 .714 .987 r
.28546 .44514 m .28121 .44508 L .28717 .44717 L p F P
0 g
s
.382 .714 .987 r
.28717 .44717 m .28854 .4472 L .28546 .44514 L p F P
0 g
s
.619 .89 .989 r
.54235 .44286 m .54416 .44364 L .53423 .44716 L p F P
0 g
s
.619 .89 .989 r
.53423 .44716 m .53229 .44633 L .54235 .44286 L p F P
0 g
s
.661 .695 .871 r
.711 .23348 m .72135 .23003 L .72376 .23391 L p F P
0 g
s
.674 .714 .878 r
.72135 .23003 m .711 .23348 L .70862 .23019 L p F P
0 g
s
.698 .747 .889 r
.69835 .23465 m .70862 .23019 L .711 .23348 L p F P
0 g
s
.027 .406 .857 r
.19416 .27093 m .19382 .27077 L .19067 .26743 L p F P
0 g
s
.5 .127 .264 r
.46898 .3721 m .46985 .36993 L .46706 .36974 L p F P
0 g
s
.5 .127 .264 r
.45785 .3742 m .46898 .3721 L p .46706 .36974 L F P
0 g
s
.501 .125 .258 r
.4702 .36915 m .46985 .36993 L .46706 .36974 L closepath p F P
0 g
s
.601 .938 .751 r
.67872 .38382 m .68095 .38299 L .67089 .39038 L p F P
0 g
s
.601 .938 .751 r
.67833 .38411 m .67872 .38382 L p .67089 .39038 L F P
0 g
s
.601 .938 .751 r
.67089 .39038 m .67074 .39045 L .67833 .38411 L p F P
0 g
s
0 .274 .751 r
.2143 .28467 m .21784 .28786 L .21373 .28532 L p F P
0 g
s
0 .274 .751 r
.21373 .28532 m .21024 .2821 L .2143 .28467 L p F P
0 g
s
0 .271 .748 r
.20897 .2813 m .21024 .2821 L .21373 .28532 L p F P
0 g
s
0 0 0 r
.54973 .32722 m .54783 .3285 L .54642 .33037 L p F P
0 g
s
.686 .305 .319 r
.38062 .37943 m .38099 .37947 L .38258 .37673 L p F P
0 g
s
.686 .305 .319 r
.38258 .37673 m .37756 .37621 L .38062 .37943 L p F P
0 g
s
.736 .228 .014 r
.29388 .34156 m .29108 .34158 L .28908 .33949 L closepath p F P
0 g
s
.781 .93 .931 r
.66098 .24876 m .65302 .25406 L .65106 .25307 L p F P
0 g
s
.212 0 .026 r
.51546 .34851 m .5152 .34896 L .52084 .34619 L closepath p F P
0 g
s
.474 .755 .991 r
.32628 .45181 m .32077 .45228 L .32781 .45397 L p F P
0 g
s
.474 .755 .991 r
.32781 .45397 m .32928 .45386 L .32628 .45181 L p F P
0 g
s
.494 .525 .817 r
.74969 .24263 m .74041 .24164 L .73974 .2429 L p F P
0 g
s
.494 .525 .817 r
.74649 .24802 m .74969 .24263 L p .73974 .2429 L F P
0 g
s
.54 .562 .826 r
.73914 .2416 m .74041 .24164 L .73974 .2429 L closepath p F P
0 g
s
.606 .242 .325 r
.42185 .37875 m .42507 .38059 L .42096 .38082 L closepath p F P
0 g
s
.77 .305 .141 r
.30958 .35063 m .31138 .35288 L .30728 .35124 L closepath p F P
0 g
s
.48 .847 .605 r
.5793 .3062 m .5779 .30718 L .58476 .30184 L closepath p F P
0 g
s
.76 .318 .201 r
.32497 .35841 m .32648 .36031 L .32337 .35928 L closepath p F P
0 g
s
.706 .985 .837 r
.61042 .28289 m .60758 .28505 L .60971 .28303 L closepath p F P
0 g
s
.645 .959 .778 r
.608 .28338 m .60971 .28303 L .60758 .28505 L p F P
0 g
s
.645 .959 .778 r
.60451 .28618 m .608 .28338 L p .60758 .28505 L F P
0 g
s
.645 .959 .778 r
.59961 .29082 m .60451 .28618 L p .60758 .28505 L F P
0 g
s
.562 .796 .987 r
.38276 .45834 m .39253 .45651 L .39542 .45848 L p F P
0 g
s
.583 .787 .976 r
.39253 .45651 m .38276 .45834 L .37985 .45637 L p F P
0 g
s
.71 .763 .894 r
.70862 .23019 m .69835 .23465 L .69597 .23185 L p F P
0 g
s
0 0 0 r
.55785 .32185 m .54973 .32722 L .55685 .32301 L closepath p F P
0 g
s
0 0 0 r
.55533 .32483 m .55685 .32301 L .54973 .32722 L p F P
0 g
s
0 0 0 r
.55386 .32585 m .55533 .32483 L p .54973 .32722 L F P
0 g
s
0 0 0 r
.54642 .33037 m .55386 .32585 L p .54973 .32722 L F P
0 g
s
.027 .406 .857 r
.19067 .26743 m .19096 .26757 L .19416 .27093 L p F P
0 g
s
.028 .407 .857 r
.19565 .26985 m .19886 .27321 L .19416 .27093 L p F P
0 g
s
.028 .407 .857 r
.19416 .27093 m .19096 .26757 L .19565 .26985 L p F P
0 g
s
0 .109 .58 r
.22921 .29673 m .22725 .29521 L .22409 .29253 L p F P
0 g
s
0 .327 .77 r
.15802 .3951 m .15551 .39377 L .15225 .3912 L p F P
0 g
s
.641 .948 .951 r
.6132 .42055 m .61342 .42059 L .60458 .42565 L p F P
0 g
s
.641 .948 .951 r
.60458 .42565 m .60307 .4254 L .6132 .42055 L p F P
0 g
s
.632 .963 .879 r
.64604 .40421 m .64839 .40405 L .63828 .41 L p F P
0 g
s
.632 .963 .879 r
.64551 .40452 m .64604 .40421 L p .63828 .41 L F P
0 g
s
.632 .963 .879 r
.63828 .41 m .63759 .41005 L .64551 .40452 L p F P
0 g
s
.642 .963 .81 r
.67074 .39045 m .66861 .39099 L .67833 .38411 L closepath p F P
0 g
s
.608 .872 .992 r
.51792 .4476 m .5196 .44842 L .50958 .45154 L p F P
0 g
s
.608 .872 .992 r
.50958 .45154 m .50754 .45056 L .51792 .4476 L p F P
0 g
s
.646 .968 .847 r
.66006 .39745 m .6585 .39771 L .66615 .39268 L closepath p F P
0 g
s
.758 .334 .244 r
.32899 .36367 m .33577 .36553 L .33301 .36226 L p F P
0 g
s
.758 .334 .244 r
.33301 .36226 m .32648 .36031 L .32899 .36367 L p F P
0 g
s
.196 .096 .507 r
.75252 .28785 m .75171 .289 L .75108 .28487 L p F P
0 g
s
.196 .096 .507 r
.75108 .28487 m .75209 .28343 L .75252 .28785 L p F P
0 g
s
.033 0 .336 r
.75082 .29805 m .74691 .30356 L .74766 .29893 L p F P
0 g
s
.033 0 .336 r
.74766 .29893 m .7516 .2934 L .75082 .29805 L p F P
0 g
s
0 0 0 r
.72082 .34542 m .71888 .34779 L .72033 .34627 L closepath p F P
0 g
s
.088 .527 .906 r
.1983 .41657 m .19575 .41582 L .20022 .4185 L p F P
0 g
s
.088 .527 .906 r
.20022 .4185 m .20151 .41888 L .1983 .41657 L p F P
0 g
s
.156 .575 .932 r
.21379 .42341 m .21172 .42293 L .2164 .42552 L p F P
0 g
s
.156 .575 .932 r
.2164 .42552 m .21698 .42566 L .21379 .42341 L p F P
0 g
s
.708 .985 .837 r
.61817 .27697 m .61042 .28289 L .60971 .28303 L p F P
0 g
s
0 0 .032 r
.73846 .31995 m .73823 .32085 L .73908 .31916 L closepath p F P
0 g
s
.705 .329 .333 r
.37159 .37839 m .38062 .37943 L .37756 .37621 L p F P
0 g
s
.705 .329 .333 r
.37756 .37621 m .36888 .37506 L .37159 .37839 L p F P
0 g
s
.469 .093 .243 r
.47979 .36944 m .48099 .36664 L .4702 .36915 L p F P
0 g
s
.469 .093 .243 r
.4702 .36915 m .46985 .36993 L .47979 .36944 L p F P
0 g
s
.629 .942 .955 r
.60059 .42497 m .60307 .4254 L .59296 .43004 L p F P
0 g
s
.629 .942 .955 r
.60038 .42507 m .60059 .42497 L p .59296 .43004 L F P
0 g
s
.629 .942 .955 r
.59296 .43004 m .59156 .42979 L .60038 .42507 L p F P
0 g
s
.769 .322 .188 r
.31393 .35621 m .32012 .35829 L .31735 .35504 L p F P
0 g
s
.769 .322 .188 r
.31735 .35504 m .31138 .35288 L .31393 .35621 L p F P
0 g
s
.6 .034 0 r
.26075 .31985 m .26067 .31981 L .26064 .31978 L closepath p F P
0 g
s
0 .087 .569 r
.12322 .36886 m .12675 .37199 L .12331 .3691 L p F P
0 g
s
.525 .004 0 r
.11894 .36518 m .11977 .36597 L .12331 .3691 L p F P
0 g
s
0 .087 .569 r
.12331 .3691 m .11977 .36597 L .12322 .36886 L p F P
0 g
s
.555 .581 .835 r
.74041 .24164 m .73914 .2416 L .73667 .23654 L p F P
0 g
s
.751 .235 0 r
.27585 .33088 m .27617 .33124 L .28101 .33386 L p F P
0 g
s
.763 .255 0 r
.27887 .33446 m .28385 .33702 L .28101 .33386 L p F P
0 g
s
.763 .255 0 r
.28101 .33386 m .27617 .33124 L .27887 .33446 L p F P
0 g
s
.588 .022 0 r
.2575 .31826 m .25606 .31704 L .26064 .31978 L p F P
0 g
s
.588 .022 0 r
.26064 .31978 m .26067 .31981 L .2575 .31826 L p F P
0 g
s
.631 .659 .858 r
.72958 .23269 m .72376 .23391 L .72135 .23003 L p F P
0 g
s
.375 .342 .694 r
.75643 .26343 m .75441 .26663 L .7511 .26347 L p F P
0 g
s
.375 .342 .694 r
.75523 .25871 m .75643 .26343 L p .7511 .26347 L F P
0 g
s
.375 .342 .694 r
.7511 .26347 m .75446 .25807 L .75523 .25871 L p F P
0 g
s
.713 .179 0 r
.26358 .32287 m .26067 .31981 L .2575 .31826 L p F P
0 g
s
.717 .312 .278 r
.34528 .37069 m .34272 .36732 L .35002 .36899 L p F P
0 g
s
.717 .312 .278 r
.35269 .37222 m .34528 .37069 L p .35002 .36899 L F P
0 g
s
.717 .312 .278 r
.35002 .36899 m .35276 .37214 L .35269 .37222 L p F P
0 g
s
.435 .732 .989 r
.29803 .44701 m .28854 .4472 L .28546 .44514 L p F P
0 g
s
.574 .8 .985 r
.40554 .4567 m .40809 .45844 L p .39542 .45848 L F P
0 g
s
.574 .8 .985 r
.39542 .45848 m .40431 .45666 L .40554 .4567 L p F P
0 g
s
.594 .792 .975 r
.40431 .45666 m .39542 .45848 L .39253 .45651 L p F P
0 g
s
.594 .86 .994 r
.49694 .45325 m .4969 .45323 L .49633 .45339 L closepath p F P
0 g
s
.601 .852 .992 r
.49419 .45169 m .4969 .45323 L .49633 .45339 L p F P
0 g
s
.601 .852 .992 r
.48421 .45455 m .49419 .45169 L p .49633 .45339 L F P
0 g
s
.583 .918 .698 r
.58949 .29855 m .58793 .29939 L .59476 .29397 L closepath p F P
0 g
s
0 0 0 r
.72899 .33583 m .72875 .33612 L .72985 .33373 L p F P
0 g
s
0 0 0 r
.72985 .33373 m .7329 .33008 L .72899 .33583 L p F P
0 g
s
.412 .025 .192 r
.4927 .36084 m .49253 .36121 L .489 .36187 L closepath p F P
0 g
s
.421 .044 .215 r
.49146 .3637 m .49253 .36121 L .489 .36187 L p F P
0 g
s
.421 .044 .215 r
.48099 .36664 m .49146 .3637 L p .489 .36187 L F P
0 g
s
.307 0 .122 r
.51272 .35379 m .51407 .35112 L .50422 .35483 L p F P
0 g
s
.307 0 .122 r
.50422 .35483 m .50286 .35752 L .51272 .35379 L p F P
0 g
s
0 0 0 r
.71885 .3482 m .71324 .35414 L .71888 .34779 L p F P
0 g
s
0 0 0 r
.71888 .34779 m .72033 .34627 L .71885 .3482 L p F P
0 g
s
.625 .949 .76 r
.68105 .38296 m .68095 .38299 L .68136 .38268 L closepath p F P
0 g
s
.36 .695 .983 r
.26935 .44086 m .26045 .44034 L .25733 .43824 L p F P
0 g
s
.016 .473 .874 r
.18287 .40901 m .18089 .40829 L .18515 .41107 L p F P
0 g
s
.016 .473 .874 r
.18515 .41107 m .1861 .41141 L .18287 .40901 L p F P
0 g
s
.545 .184 .305 r
.45263 .37495 m .44638 .37588 L .44516 .37891 L p F P
0 g
s
.578 .217 .319 r
.44042 .37939 m .44516 .37891 L .44638 .37588 L p F P
0 g
s
0 .137 .578 r
.23921 .30433 m .23675 .30253 L .24082 .30549 L p F P
0 g
s
0 .137 .578 r
.24082 .30549 m .24237 .30659 L .23921 .30433 L p F P
0 g
s
.648 .968 .878 r
.64902 .404 m .64839 .40405 L .65176 .40199 L closepath p F P
0 g
s
.605 .864 .992 r
.50689 .45023 m .50754 .45056 L .49694 .45325 L p F P
0 g
s
.605 .864 .992 r
.49694 .45325 m .4969 .45323 L .50689 .45023 L p F P
0 g
s
.211 .606 .949 r
.22416 .42705 m .21698 .42566 L .21379 .42341 L p F P
0 g
s
.25 0 .081 r
.52084 .34619 m .5152 .34896 L .51407 .35112 L p F P
0 g
s
.626 .911 .982 r
.5677 .43728 m .55762 .44115 L .55504 .44026 L p F P
0 g
s
.612 .907 .984 r
.54496 .44394 m .55504 .44026 L .55762 .44115 L p F P
0 g
s
.639 .956 .932 r
.62563 .41568 m .61564 .42078 L .61342 .42059 L p F P
0 g
s
.523 .767 .986 r
.33891 .45275 m .32928 .45386 L .32628 .45181 L p F P
0 g
s
.761 .864 .925 r
.67462 .24209 m .67324 .24093 L .67692 .23874 L closepath p F P
0 g
s
.617 .852 .988 r
.50689 .45023 m .4969 .45323 L .49419 .45169 L p F P
0 g
s
.29 .657 .97 r
.24003 .43193 m .24173 .4331 L .23409 .43202 L p F P
0 g
s
.29 .657 .97 r
.23773 .43079 m .24003 .43193 L p .23409 .43202 L F P
0 g
s
.29 .657 .97 r
.22932 .42964 m .23773 .43079 L p .23409 .43202 L F P
0 g
s
.29 .657 .97 r
.23409 .43202 m .22992 .43006 L .22932 .42964 L p F P
0 g
s
.703 .308 .295 r
.36837 .3745 m .36888 .37506 L .36806 .37494 L closepath p F P
0 g
s
.629 .951 .764 r
.68136 .38268 m .68095 .38299 L .67872 .38382 L p F P
0 g
s
.587 .92 .697 r
.68136 .38268 m .691 .375 L .6888 .37609 L p F P
0 g
s
.587 .92 .697 r
.6888 .37609 m .68875 .37613 L .68136 .38268 L p F P
0 g
s
.629 .951 .764 r
.67872 .38382 m .68875 .37613 L .68136 .38268 L p F P
0 g
s
.582 .805 .984 r
.41841 .45662 m .42076 .45823 L p .40809 .45844 L F P
0 g
s
.582 .805 .984 r
.40809 .45844 m .4163 .45664 L .41841 .45662 L p F P
0 g
s
.583 .804 .983 r
.40809 .45844 m .4163 .45664 L .40554 .4567 L closepath p F P
0 g
s
.769 .294 .114 r
.29986 .34837 m .30562 .35063 L .30276 .34744 L p F P
0 g
s
.769 .294 .114 r
.30276 .34744 m .2972 .34511 L .29986 .34837 L p F P
0 g
s
0 .286 .739 r
.14898 .38855 m .1457 .38664 L .14953 .38962 L p F P
0 g
s
0 .286 .739 r
.14953 .38962 m .15225 .3912 L .14898 .38855 L p F P
0 g
s
.753 .992 .877 r
.62046 .27523 m .61817 .27697 L .61982 .27525 L closepath p F P
0 g
s
.708 .985 .837 r
.61805 .27533 m .61982 .27525 L .61817 .27697 L p F P
0 g
s
.708 .985 .837 r
.6142 .27841 m .61805 .27533 L p .61817 .27697 L F P
0 g
s
.708 .985 .837 r
.60971 .28303 m .6142 .27841 L p .61817 .27697 L F P
0 g
s
0 0 .029 r
.74076 .31885 m .74342 .31353 L .73908 .31916 L p F P
0 g
s
0 0 .029 r
.73773 .32279 m .74076 .31885 L p .73908 .31916 L F P
0 g
s
0 0 .029 r
.73908 .31916 m .73823 .32085 L .73773 .32279 L p F P
0 g
s
0 .299 .763 r
.22094 .28972 m .21784 .28786 L .22151 .29101 L p F P
0 g
s
0 .299 .763 r
.22151 .29101 m .22409 .29253 L .22094 .28972 L p F P
0 g
s
.785 .904 .925 r
.66311 .24734 m .66098 .24876 L .6623 .24682 L closepath p F P
0 g
s
.781 .93 .931 r
.66073 .24583 m .6623 .24682 L .66098 .24876 L p F P
0 g
s
.781 .93 .931 r
.65183 .25203 m .66073 .24583 L p .66098 .24876 L F P
0 g
s
.781 .93 .931 r
.65106 .25307 m .65183 .25203 L p .66098 .24876 L F P
0 g
s
0 .4 .821 r
.17075 .40312 m .17109 .40327 L .16954 .40222 L closepath p F P
0 g
s
.615 .843 .986 r
.49419 .45169 m .48421 .45455 L .48147 .45294 L p F P
0 g
s
.603 .842 .989 r
.47152 .45567 m .48147 .45294 L .48421 .45455 L p F P
0 g
s
.555 .581 .835 r
.73667 .23654 m .74317 .23639 L .74041 .24164 L p F P
0 g
s
.534 .556 .823 r
.74979 .24246 m .74969 .24263 L .74041 .24164 L p F P
0 g
s
.534 .556 .823 r
.74733 .23657 m .74979 .24246 L p .74041 .24164 L F P
0 g
s
.534 .556 .823 r
.74041 .24164 m .74317 .23639 L .74733 .23657 L p F P
0 g
s
.735 .832 .924 r
.6957 .232 m .68577 .23719 L .6834 .23488 L p F P
0 g
s
.588 .812 .985 r
.43092 .45616 m .43345 .45786 L p .42076 .45823 L F P
0 g
s
.588 .812 .985 r
.42076 .45823 m .42948 .45622 L .43092 .45616 L p F P
0 g
s
.59 .808 .983 r
.42076 .45823 m .42948 .45622 L .41841 .45662 L closepath p F P
0 g
s
.751 .992 .878 r
.6289 .26884 m .62046 .27523 L .61982 .27525 L p F P
0 g
s
.665 .965 .773 r
.59961 .29082 m .59796 .29143 L .60451 .28618 L closepath p F P
0 g
s
.512 .817 .49 r
.71882 .34823 m .71885 .3482 L .71324 .35414 L p F P
0 g
s
.512 .817 .49 r
.71267 .35468 m .71882 .34823 L p .71324 .35414 L F P
0 g
s
.512 .817 .49 r
.7099 .35762 m .71267 .35468 L p .71324 .35414 L F P
0 g
s
.512 .817 .49 r
.71324 .35414 m .71096 .35652 L .7099 .35762 L p F P
0 g
s
.143 .561 .927 r
.20711 .4203 m .20151 .41888 L .1983 .41657 L p F P
0 g
s
0 0 0 r
.56285 .31825 m .55785 .32185 L .55685 .32301 L p F P
0 g
s
.612 .834 .985 r
.48147 .45294 m .47152 .45567 L .46876 .45397 L p F P
0 g
s
.599 .833 .988 r
.45883 .45658 m .46876 .45397 L .47152 .45567 L p F P
0 g
s
0 0 .243 r
.74606 .30473 m .74581 .30748 L .74691 .30356 L closepath p F P
0 g
s
.783 .904 .926 r
.67086 .23909 m .67324 .24093 L .66311 .24734 L p F P
0 g
s
.783 .904 .926 r
.66497 .24301 m .67086 .23909 L p .66311 .24734 L F P
0 g
s
.783 .904 .926 r
.66311 .24734 m .6623 .24682 L .66497 .24301 L p F P
0 g
s
.036 .478 .882 r
.17259 .40263 m .1767 .40548 L .17109 .40327 L p F P
0 g
s
.036 .478 .882 r
.1675 .40064 m .17259 .40263 L p .17109 .40327 L F P
0 g
s
.036 .478 .882 r
.17109 .40327 m .16954 .40222 L .1675 .40064 L p F P
0 g
s
.596 .814 .983 r
.44306 .45527 m .44333 .45547 L .43345 .45786 L p F P
0 g
s
.596 .814 .983 r
.43345 .45786 m .43092 .45616 L .44306 .45527 L p F P
0 g
s
.592 .818 .986 r
.43345 .45786 m .44333 .45547 L .44614 .45731 L p F P
0 g
s
0 .131 .608 r
.13041 .37483 m .12675 .37199 L .13035 .37509 L p F P
0 g
s
0 .131 .608 r
.13217 .37634 m .13041 .37483 L p .13035 .37509 L F P
0 g
s
0 .131 .608 r
.13035 .37509 m .13385 .3778 L .13217 .37634 L p F P
0 g
s
.071 .509 .898 r
.19136 .41309 m .1861 .41141 L .18287 .40901 L p F P
0 g
s
.419 .399 .73 r
.75487 .2574 m .75446 .25807 L .74975 .25541 L p F P
0 g
s
.419 .399 .73 r
.74975 .25541 m .75273 .25052 L .75487 .2574 L p F P
0 g
s
0 0 0 r
.71096 .35652 m .70674 .36077 L .7099 .35762 L closepath p F P
0 g
s
.047 .428 .869 r
.20267 .27495 m .19886 .27321 L .20217 .27652 L p F P
0 g
s
.047 .428 .869 r
.20217 .27652 m .20582 .27818 L .20267 .27495 L p F P
0 g
s
.71 .328 .322 r
.36639 .37761 m .37159 .37839 L .36888 .37506 L p F P
0 g
s
.71 .328 .322 r
.36888 .37506 m .36806 .37494 L .36639 .37761 L p F P
0 g
s
.477 .113 .268 r
.47975 .36955 m .47979 .36944 L .46985 .36993 L p F P
0 g
s
.477 .113 .268 r
.46985 .36993 m .46898 .3721 L .47975 .36955 L p F P
0 g
s
0 .274 .755 r
.21024 .2821 m .20897 .2813 L .20582 .27818 L p F P
0 g
s
.61 .826 .983 r
.46876 .45397 m .45883 .45658 L .45605 .45481 L p F P
0 g
s
.596 .825 .987 r
.44614 .45731 m .45605 .45481 L .45883 .45658 L p F P
0 g
s
.611 .815 .979 r
.45605 .45481 m .44614 .45731 L .44333 .45547 L p F P
0 g
s
.614 .933 .71 r
.69101 .375 m .691 .375 L .69105 .37496 L closepath p F P
0 g
s
.617 .935 .713 r
.69105 .37496 m .691 .375 L .6888 .37609 L p F P
0 g
s
.579 .903 .651 r
.69777 .36862 m .69105 .37496 L .69942 .36769 L p F P
0 g
s
.617 .935 .713 r
.6888 .37609 m .69777 .36862 L .69105 .37496 L p F P
0 g
s
.547 .183 .302 r
.45785 .3742 m .4571 .37607 L .45263 .37495 L closepath p F P
0 g
s
.545 .184 .305 r
.45667 .37724 m .4571 .37607 L .45263 .37495 L p F P
0 g
s
.545 .184 .305 r
.44516 .37891 m .45667 .37724 L p .45263 .37495 L F P
0 g
s
.16 .071 .498 r
.75526 .28358 m .75252 .28785 L .75209 .28343 L p F P
0 g
s
.16 .071 .498 r
.75209 .28343 m .75465 .27944 L .75526 .28358 L p F P
0 g
s
.712 .33 .323 r
.36321 .37712 m .36639 .37761 L .36806 .37494 L p F P
0 g
s
.712 .33 .323 r
.36806 .37494 m .36053 .37378 L .36321 .37712 L p F P
0 g
s
0 0 .042 r
.73823 .32085 m .73631 .32451 L .73773 .32279 L closepath p F P
0 g
s
.37 0 .172 r
.50252 .35825 m .50286 .35752 L .4927 .36084 L p F P
0 g
s
.37 0 .172 r
.4927 .36084 m .49253 .36121 L .50252 .35825 L p F P
0 g
s
.708 .171 0 r
.26654 .32596 m .27129 .32863 L .26818 .32559 L p F P
0 g
s
.708 .171 0 r
.26818 .32559 m .26358 .32287 L .26654 .32596 L p F P
0 g
s
.656 .967 .909 r
.63759 .41005 m .6359 .41002 L .64551 .40452 L closepath p F P
0 g
s
.538 .856 .563 r
.70887 .35844 m .7099 .35762 L .70674 .36077 L p F P
0 g
s
.538 .856 .563 r
.70568 .36149 m .70887 .35844 L p .70674 .36077 L F P
0 g
s
.538 .856 .563 r
.70063 .36655 m .70568 .36149 L p .70674 .36077 L F P
0 g
s
.538 .856 .563 r
.70674 .36077 m .70101 .36623 L .70063 .36655 L p F P
0 g
s
.491 .764 .992 r
.32327 .44967 m .32628 .45181 L .32077 .45228 L p F P
0 g
s
.491 .764 .992 r
.31366 .45063 m .32327 .44967 L p .32077 .45228 L F P
0 g
s
.491 .764 .992 r
.32077 .45228 m .31375 .45069 L .31366 .45063 L p F P
0 g
s
.529 .776 .988 r
.34189 .45481 m .35157 .45346 L .35453 .45553 L p F P
0 g
s
.546 .771 .981 r
.35157 .45346 m .34189 .45481 L .33891 .45275 L p F P
0 g
s
.472 .468 .772 r
.74987 .24267 m .74969 .24263 L .74649 .24802 L p F P
0 g
s
.472 .468 .772 r
.74649 .24802 m .75248 .24979 L .74987 .24267 L p F P
0 g
s
.513 .844 .556 r
.70101 .36623 m .69942 .36769 L .70063 .36655 L closepath p F P
0 g
s
.579 .903 .651 r
.69886 .36767 m .69777 .36862 L p .69942 .36769 L F P
0 g
s
.579 .903 .651 r
.69942 .36769 m .70063 .36655 L .69886 .36767 L p F P
0 g
s
.735 .223 0 r
.2867 .3402 m .28385 .33702 L .28908 .33949 L p F P
0 g
s
.735 .223 0 r
.28964 .34153 m .2867 .3402 L p .28908 .33949 L F P
0 g
s
.735 .223 0 r
.28908 .33949 m .29108 .34158 L .28964 .34153 L p F P
0 g
s
.379 .715 .987 r
.27293 .44294 m .27524 .44298 L .28121 .44508 L p F P
0 g
s
.395 .715 .987 r
.28238 .44302 m .27524 .44298 L .28121 .44508 L p F P
0 g
s
.395 .715 .987 r
.28121 .44508 m .28546 .44514 L .28238 .44302 L p F P
0 g
s
.6 .051 0 r
.24237 .30659 m .24426 .30835 L .24838 .31128 L p F P
0 g
s
.601 .052 0 r
.24745 .31132 m .25167 .31422 L .24838 .31128 L p F P
0 g
s
.601 .052 0 r
.24838 .31128 m .24426 .30835 L .24745 .31132 L p F P
0 g
s
0 .176 .645 r
.13772 .38097 m .13713 .38055 L .13385 .3778 L p F P
0 g
s
0 0 0 r
.56787 .3147 m .56285 .31825 L .56712 .31545 L closepath p F P
0 g
s
0 0 0 r
.56538 .31723 m .56712 .31545 L .56285 .31825 L p F P
0 g
s
0 0 0 r
.56486 .31761 m .56538 .31723 L p .56285 .31825 L F P
0 g
s
0 0 0 r
.55685 .32301 m .56486 .31761 L p .56285 .31825 L F P
0 g
s
.621 .902 .986 r
.5539 .43983 m .55504 .44026 L .54496 .44394 L p F P
0 g
s
.621 .902 .986 r
.54496 .44394 m .54416 .44364 L .5539 .43983 L p F P
0 g
s
.726 .989 .83 r
.60971 .28303 m .608 .28338 L .6142 .27841 L closepath p F P
0 g
s
.612 .106 0 r
.1066 .35329 m .10992 .35654 L .10721 .35341 L p F P
0 g
s
.612 .106 0 r
.10721 .35341 m .1039 .35016 L .1066 .35329 L p F P
0 g
s
.292 .665 .972 r
.24488 .43522 m .24818 .43556 L .25354 .43789 L p F P
0 g
s
.314 .672 .976 r
.2542 .43608 m .24818 .43556 L .25354 .43789 L p F P
0 g
s
.314 .672 .976 r
.25354 .43789 m .25733 .43824 L .2542 .43608 L p F P
0 g
s
.455 .745 .991 r
.30108 .44904 m .3071 .44873 L .31356 .45064 L p F P
0 g
s
.469 .749 .99 r
.3071 .44873 m .30108 .44904 L .29803 .44701 L p F P
0 g
s
.782 .984 .901 r
.6305 .26763 m .6289 .26884 L .63001 .26757 L closepath p F P
0 g
s
.751 .992 .878 r
.6281 .26735 m .63001 .26757 L .6289 .26884 L p F P
0 g
s
.751 .992 .878 r
.62401 .2706 m .6281 .26735 L p .6289 .26884 L F P
0 g
s
.751 .992 .878 r
.61982 .27525 m .62401 .2706 L p .6289 .26884 L F P
0 g
s
0 0 0 r
.71893 .34811 m .71885 .3482 L .72033 .34627 L p F P
0 g
s
0 0 0 r
.72033 .34627 m .72422 .34188 L .71893 .34811 L p F P
0 g
s
.651 .969 .881 r
.65176 .40199 m .64839 .40405 L .64604 .40421 L p F P
0 g
s
.767 .336 .227 r
.32267 .36163 m .32899 .36367 L .32648 .36031 L p F P
0 g
s
.767 .336 .227 r
.32176 .36031 m .32267 .36163 L p .32648 .36031 L F P
0 g
s
.767 .336 .227 r
.32648 .36031 m .32337 .35928 L .32176 .36031 L p F P
0 g
s
.75 .339 .271 r
.33828 .36891 m .34528 .37069 L .34272 .36732 L p F P
0 g
s
.75 .339 .271 r
.33722 .36737 m .33828 .36891 L p .34272 .36732 L F P
0 g
s
.75 .339 .271 r
.34272 .36732 m .33843 .36619 L .33722 .36737 L p F P
0 g
s
.224 0 .039 r
.52521 .34408 m .52084 .34619 L .52503 .34441 L closepath p F P
0 g
s
.25 0 .081 r
.52365 .347 m .52503 .34441 L .52084 .34619 L p F P
0 g
s
.25 0 .081 r
.51407 .35112 m .52365 .347 L p .52084 .34619 L F P
0 g
s
.389 .018 .207 r
.50163 .36037 m .50252 .35825 L .49253 .36121 L p F P
0 g
s
.389 .018 .207 r
.49253 .36121 m .49146 .3637 L .50163 .36037 L p F P
0 g
s
.304 .669 .974 r
.24818 .43556 m .24488 .43522 L .24173 .4331 L p F P
0 g
s
.776 .984 .903 r
.63998 .26058 m .6305 .26763 L .63001 .26757 L p F P
0 g
s
.633 .931 .97 r
.58794 .42885 m .59046 .42952 L .58035 .43386 L p F P
0 g
s
.633 .931 .97 r
.57897 .43271 m .58794 .42885 L p .58035 .43386 L F P
0 g
s
.633 .931 .97 r
.58035 .43386 m .57792 .43324 L .57897 .43271 L p F P
0 g
s
.52 .157 .291 r
.46784 .37517 m .46898 .3721 L .45785 .3742 L p F P
0 g
s
.52 .157 .291 r
.46056 .3765 m .46784 .37517 L p .45785 .3742 L F P
0 g
s
.52 .157 .291 r
.45785 .3742 m .4571 .37607 L .46056 .3765 L p F P
0 g
s
0 .109 .58 r
.22409 .29253 m .22548 .29363 L .22921 .29673 L p F P
0 g
s
0 .108 .579 r
.22902 .29643 m .23281 .29951 L .22921 .29673 L p F P
0 g
s
0 .108 .579 r
.22921 .29673 m .22548 .29363 L .22902 .29643 L p F P
0 g
s
.632 .919 .978 r
.57781 .4332 m .57792 .43324 L .56855 .43755 L p F P
0 g
s
.632 .919 .978 r
.56855 .43755 m .5677 .43728 L .57781 .4332 L p F P
0 g
s
.238 .168 .571 r
.75814 .27402 m .75465 .27944 L .75327 .27557 L p F P
0 g
s
.238 .168 .571 r
.75327 .27557 m .75672 .27016 L .75814 .27402 L p F P
0 g
s
.595 .051 0 r
.24426 .30835 m .24237 .30659 L .23921 .30433 L p F P
0 g
s
.511 0 0 r
.11977 .36597 m .11894 .36518 L .11565 .36217 L p F P
0 g
s
0 .412 .835 r
.16954 .40222 m .1675 .40064 L .16699 .40042 L closepath p F P
0 g
s
.78 .327 .173 r
.30811 .35397 m .31393 .35621 L .31138 .35288 L p F P
0 g
s
.78 .327 .173 r
.30638 .35153 m .30811 .35397 L p .31138 .35288 L F P
0 g
s
.78 .327 .173 r
.31138 .35288 m .30728 .35124 L .30638 .35153 L p F P
0 g
s
0 0 .241 r
.74944 .30291 m .75082 .29805 L .74691 .30356 L p F P
0 g
s
0 0 .241 r
.74575 .30813 m .74944 .30291 L p .74691 .30356 L F P
0 g
s
0 0 .241 r
.74691 .30356 m .74581 .30748 L .74575 .30813 L p F P
0 g
s
0 .327 .77 r
.15225 .3912 m .15408 .39217 L .15802 .3951 L p F P
0 g
s
0 .374 .81 r
.15907 .39457 m .16299 .39751 L .15802 .3951 L p F P
0 g
s
0 .374 .81 r
.15802 .3951 m .15408 .39217 L .15907 .39457 L p F P
0 g
s
.639 .281 .348 r
.41208 .38097 m .4082 .38099 L .40693 .38405 L p F P
0 g
s
.657 .3 .356 r
.40388 .38398 m .40693 .38405 L .4082 .38099 L p F P
0 g
s
.657 .3 .356 r
.4082 .38099 m .40058 .38082 L .40388 .38398 L p F P
0 g
s
.548 .781 .985 r
.35453 .45553 m .36424 .45396 L .36718 .45605 L p F P
0 g
s
.57 .774 .975 r
.36424 .45396 m .35453 .45553 L .35157 .45346 L p F P
0 g
s
.747 .227 0 r
.27585 .33088 m .27617 .33124 L .27518 .33067 L closepath p F P
0 g
s
0 0 0 r
.57427 .30988 m .56787 .3147 L .56712 .31545 L p F P
0 g
s
0 .176 .645 r
.13385 .3778 m .13402 .37792 L .13772 .38097 L p F P
0 g
s
0 .257 .722 r
.13825 .38056 m .14194 .38362 L .13772 .38097 L p F P
0 g
s
0 .257 .722 r
.13772 .38097 m .13402 .37792 L .13825 .38056 L p F P
0 g
s
.636 .283 .356 r
.42096 .38082 m .41208 .38097 L .41579 .38399 L p F P
0 g
s
.639 .281 .348 r
.40693 .38405 m .41579 .38399 L .41208 .38097 L p F P
0 g
s
.574 .584 .826 r
.74317 .23639 m .73667 .23654 L .73422 .23182 L p F P
0 g
s
.38 .714 .987 r
.27293 .44294 m .27524 .44298 L .27043 .44129 L closepath p F P
0 g
s
.766 .994 .87 r
.61982 .27525 m .61805 .27533 L .62401 .2706 L closepath p F P
0 g
s
.548 .037 0 r
.11236 .35907 m .10992 .35654 L .1133 .35975 L p F P
0 g
s
.548 .037 0 r
.1133 .35975 m .11565 .36217 L .11236 .35907 L p F P
0 g
s
.632 .963 .85 r
.6585 .39771 m .65176 .40199 L .65721 .39791 L closepath p F P
0 g
s
.651 .969 .881 r
.65618 .39795 m .65721 .39791 L .65176 .40199 L p F P
0 g
s
.651 .969 .881 r
.64604 .40421 m .65618 .39795 L p .65176 .40199 L F P
0 g
s
0 0 0 r
.73679 .32538 m .7329 .33008 L .73631 .32451 L p F P
0 g
s
0 0 0 r
.73631 .32451 m .73773 .32279 L .73679 .32538 L p F P
0 g
s
.734 .352 .328 r
.35525 .37569 m .36321 .37712 L .36053 .37378 L p F P
0 g
s
.734 .352 .328 r
.36053 .37378 m .35285 .37226 L .35525 .37569 L p F P
0 g
s
.614 .26 .346 r
.42507 .38059 m .42096 .38082 L .41976 .38392 L p F P
0 g
s
.636 .283 .356 r
.41579 .38399 m .41976 .38392 L .42096 .38082 L p F P
0 g
s
.662 .298 .344 r
.39354 .38355 m .40388 .38398 L .40058 .38082 L p F P
0 g
s
.662 .298 .344 r
.40058 .38082 m .39491 .38058 L .39354 .38355 L p F P
0 g
s
.22 .617 .953 r
.22992 .43006 m .22932 .42964 L .22899 .42959 L closepath p F P
0 g
s
.434 .062 .232 r
.49027 .36664 m .49146 .3637 L .48099 .36664 L p F P
0 g
s
.434 .062 .232 r
.48061 .36931 m .49027 .36664 L p .48099 .36664 L F P
0 g
s
.434 .062 .232 r
.48099 .36664 m .47979 .36944 L .48061 .36931 L p F P
0 g
s
0 .274 .755 r
.20582 .27818 m .20684 .27883 L .21024 .2821 L p F P
0 g
s
0 .274 .756 r
.21087 .28141 m .2143 .28467 L .21024 .2821 L p F P
0 g
s
0 .274 .756 r
.21024 .2821 m .20684 .27883 L .21087 .28141 L p F P
0 g
s
.166 .577 .935 r
.2106 .42111 m .20711 .4203 L .21172 .42293 L p F P
0 g
s
.166 .577 .935 r
.21172 .42293 m .21379 .42341 L .2106 .42111 L p F P
0 g
s
.784 .906 .926 r
.6623 .24682 m .66073 .24583 L .66497 .24301 L closepath p F P
0 g
s
.607 .915 .656 r
.70063 .36655 m .69886 .36767 L .70568 .36149 L closepath p F P
0 g
s
.631 .659 .858 r
.73231 .22832 m .72958 .23269 L p .72135 .23003 L F P
0 g
s
.61 .643 .858 r
.72958 .23269 m .73231 .22832 L .73422 .23182 L closepath p F P
0 g
s
.098 .529 .909 r
.19509 .41419 m .19136 .41309 L .19575 .41582 L p F P
0 g
s
.098 .529 .909 r
.19575 .41582 m .1983 .41657 L .19509 .41419 L p F P
0 g
s
.625 .885 .988 r
.54235 .44286 m .53229 .44633 L .52964 .44512 L p F P
0 g
s
.613 .881 .99 r
.5196 .44842 m .52964 .44512 L .53229 .44633 L p F P
0 g
s
.613 .261 .35 r
.43328 .38011 m .42507 .38059 L .42943 .38339 L p F P
0 g
s
.614 .26 .346 r
.41976 .38392 m .42943 .38339 L .42507 .38059 L p F P
0 g
s
.675 .312 .35 r
.39319 .38353 m .39354 .38355 L .39491 .38058 L p F P
0 g
s
.675 .312 .35 r
.39491 .38058 m .39015 .38028 L .39319 .38353 L p F P
0 g
s
.115 0 .426 r
.75267 .29188 m .7516 .2934 L .75171 .289 L p F P
0 g
s
.115 0 .426 r
.75171 .289 m .75252 .28785 L .75267 .29188 L p F P
0 g
s
.767 .259 0 r
.2741 .3318 m .27887 .33446 L .27617 .33124 L p F P
0 g
s
.767 .259 0 r
.27267 .33001 m .2741 .3318 L p .27617 .33124 L F P
0 g
s
.767 .259 0 r
.27617 .33124 m .27518 .33067 L .27267 .33001 L p F P
0 g
s
.674 .714 .878 r
.70862 .23019 m .71895 .22635 L .72135 .23003 L p F P
0 g
s
.687 .731 .884 r
.71895 .22635 m .70862 .23019 L .70623 .22706 L p F P
0 g
s
.71 .763 .894 r
.69597 .23185 m .70623 .22706 L .70862 .23019 L p F P
0 g
s
.644 .937 .966 r
.59156 .42979 m .59046 .42952 L .60038 .42507 L closepath p F P
0 g
s
.651 .948 .954 r
.6132 .42055 m .60307 .4254 L .60059 .42497 L p F P
0 g
s
.625 .957 .913 r
.62577 .41561 m .62563 .41568 L .62575 .41561 L closepath p F P
0 g
s
.639 .956 .932 r
.62334 .41534 m .62575 .41561 L .62563 .41568 L p F P
0 g
s
.639 .956 .932 r
.61468 .41981 m .62334 .41534 L p .62563 .41568 L F P
0 g
s
.639 .956 .932 r
.61342 .42059 m .61468 .41981 L p .62563 .41568 L F P
0 g
s
.589 .028 0 r
.25433 .31655 m .25167 .31422 L .25606 .31704 L p F P
0 g
s
.589 .028 0 r
.25606 .31704 m .2575 .31826 L .25433 .31655 L p F P
0 g
s
.644 .963 .913 r
.63422 .40998 m .6359 .41002 L .62577 .41561 L p F P
0 g
s
.644 .963 .913 r
.62577 .41561 m .62575 .41561 L .63422 .40998 L p F P
0 g
s
.751 .313 .21 r
.32337 .35928 m .32176 .36031 L .32012 .35829 L closepath p F P
0 g
s
.761 .876 .93 r
.67692 .23874 m .67324 .24093 L .67086 .23909 L p F P
0 g
s
.663 .961 .934 r
.6335 .40989 m .63422 .40998 L .62575 .41561 L p F P
0 g
s
.663 .961 .934 r
.62575 .41561 m .62334 .41534 L .6335 .40989 L p F P
0 g
s
.796 .967 .914 r
.64056 .26015 m .63998 .26058 L .64037 .2601 L closepath p F P
0 g
s
.776 .984 .903 r
.63817 .2595 m .64037 .2601 L .63998 .26058 L p F P
0 g
s
.776 .984 .903 r
.63408 .26269 m .63817 .2595 L p .63998 .26058 L F P
0 g
s
.776 .984 .903 r
.63001 .26757 m .63408 .26269 L p .63998 .26058 L F P
0 g
s
0 0 0 r
.5779 .30718 m .57427 .30988 L .57726 .30771 L closepath p F P
0 g
s
0 0 0 r
.57543 .30926 m .57726 .30771 L .57427 .30988 L p F P
0 g
s
0 0 0 r
.57479 .30976 m .57543 .30926 L p .57427 .30988 L F P
0 g
s
0 0 0 r
.56712 .31545 m .57479 .30976 L p .57427 .30988 L F P
0 g
s
.786 .315 .118 r
.29442 .34599 m .29986 .34837 L .2972 .34511 L p F P
0 g
s
.786 .315 .118 r
.2972 .34511 m .29193 .34266 L .29442 .34599 L p F P
0 g
s
.789 .986 .896 r
.63001 .26757 m .6281 .26735 L .63408 .26269 L closepath p F P
0 g
s
.687 .319 .345 r
.38331 .38279 m .39319 .38353 L .39015 .38028 L p F P
0 g
s
.687 .319 .345 r
.38086 .37973 m .38331 .38279 L p .39015 .38028 L F P
0 g
s
.687 .319 .345 r
.39015 .38028 m .38099 .37947 L .38086 .37973 L p F P
0 g
s
.799 .967 .912 r
.64825 .25185 m .65063 .25286 L .64056 .26015 L p F P
0 g
s
.799 .967 .912 r
.64462 .2546 m .64825 .25185 L p .64056 .26015 L F P
0 g
s
.799 .967 .912 r
.64056 .26015 m .64037 .2601 L .64462 .2546 L p F P
0 g
s
.74 .326 .263 r
.33843 .36619 m .33722 .36737 L .33577 .36553 L closepath p F P
0 g
s
.229 .618 .955 r
.22615 .42739 m .22416 .42705 L .22899 .42959 L p F P
0 g
s
.229 .618 .955 r
.22899 .42959 m .22932 .42964 L .22615 .42739 L p F P
0 g
s
.568 .784 .98 r
.37837 .45529 m .37985 .45637 L p .36718 .45605 L F P
0 g
s
.568 .784 .98 r
.36718 .45605 m .37394 .45479 L .37837 .45529 L p F P
0 g
s
.586 .782 .973 r
.37394 .45479 m .36718 .45605 L .36424 .45396 L p F P
0 g
s
.453 .748 .992 r
.31375 .45069 m .31366 .45063 L .31356 .45064 L closepath p F P
0 g
s
.63 .894 .987 r
.55244 .4392 m .5539 .43983 L .54416 .44364 L p F P
0 g
s
.63 .894 .987 r
.54416 .44364 m .54235 .44286 L .55244 .4392 L p F P
0 g
s
.17 0 .013 r
.53434 .33994 m .53524 .33838 L .52521 .34408 L p F P
0 g
s
.17 0 .013 r
.52521 .34408 m .52503 .34441 L .53434 .33994 L p F P
0 g
s
.461 .744 .99 r
.31063 .4485 m .3071 .44873 L .31356 .45064 L p F P
0 g
s
.461 .744 .99 r
.31356 .45064 m .31366 .45063 L .31063 .4485 L p F P
0 g
s
.646 .677 .865 r
.73179 .22741 m .72135 .23003 L .71895 .22635 L p F P
0 g
s
.631 .659 .858 r
.72135 .23003 m .73179 .22741 L .73231 .22832 L p F P
0 g
s
.512 .758 .985 r
.32327 .44967 m .31366 .45063 L .31063 .4485 L p F P
0 g
s
.585 .233 .339 r
.44042 .37939 m .43328 .38011 L .43211 .38324 L p F P
0 g
s
.613 .261 .35 r
.42943 .38339 m .43211 .38324 L .43328 .38011 L p F P
0 g
s
.026 .475 .878 r
.17963 .40654 m .1767 .40548 L .18089 .40829 L p F P
0 g
s
.026 .475 .878 r
.18089 .40829 m .18287 .40901 L .17963 .40654 L p F P
0 g
s
.618 .865 .989 r
.51693 .44707 m .51792 .4476 L .50754 .45056 L p F P
0 g
s
.618 .865 .989 r
.50754 .45056 m .50689 .45023 L .51693 .44707 L p F P
0 g
s
.511 0 0 r
.11565 .36217 m .1163 .3628 L .11977 .36597 L p F P
0 g
s
0 .098 .585 r
.11976 .36569 m .12322 .36886 L .11977 .36597 L p F P
0 g
s
0 .098 .585 r
.11977 .36597 m .1163 .3628 L .11976 .36569 L p F P
0 g
s
0 .135 .587 r
.23604 .30193 m .23281 .29951 L .23675 .30253 L p F P
0 g
s
0 .135 .587 r
.23675 .30253 m .23921 .30433 L .23604 .30193 L p F P
0 g
s
.283 .646 .967 r
.23773 .43079 m .22932 .42964 L .22615 .42739 L p F P
0 g
s
.709 .172 0 r
.27518 .33067 m .27267 .33001 L .27129 .32863 L closepath p F P
0 g
s
.734 .806 .909 r
.69597 .23185 m .6957 .232 L .69585 .23171 L closepath p F P
0 g
s
.735 .832 .924 r
.6936 .22924 m .69585 .23171 L .6957 .232 L p F P
0 g
s
.735 .832 .924 r
.6834 .23488 m .6936 .22924 L p .6957 .232 L F P
0 g
s
0 0 0 r
.58476 .30184 m .5779 .30718 L .57726 .30771 L p F P
0 g
s
.791 .932 .925 r
.65106 .25307 m .65063 .25286 L .65183 .25203 L closepath p F P
0 g
s
.725 .804 .913 r
.70385 .22409 m .70623 .22706 L .69597 .23185 L p F P
0 g
s
.725 .804 .913 r
.6993 .22638 m .70385 .22409 L p .69597 .23185 L F P
0 g
s
.725 .804 .913 r
.69597 .23185 m .69585 .23171 L .6993 .22638 L p F P
0 g
s
.8 .968 .911 r
.64037 .2601 m .63817 .2595 L .64462 .2546 L closepath p F P
0 g
s
0 .112 .592 r
.22548 .29363 m .22409 .29253 L .22094 .28972 L p F P
0 g
s
0 .332 .778 r
.15408 .39217 m .15225 .3912 L .14898 .38855 L p F P
0 g
s
.05 0 0 r
.53582 .33751 m .53524 .33838 L .5407 .33484 L closepath p F P
0 g
s
.621 .875 .989 r
.5281 .44435 m .52964 .44512 L .5196 .44842 L p F P
0 g
s
.621 .875 .989 r
.5196 .44842 m .51792 .4476 L .5281 .44435 L p F P
0 g
s
.649 .969 .85 r
.66615 .39268 m .6585 .39771 L .65721 .39791 L p F P
0 g
s
0 0 0 r
.54642 .33037 m .54528 .33192 L .55386 .32585 L closepath p F P
0 g
s
.726 .805 .914 r
.69585 .23171 m .6936 .22924 L .6993 .22638 L closepath p F P
0 g
s
.773 .868 .918 r
.67692 .23874 m .6834 .23488 L .68102 .23269 L p F P
0 g
s
.773 .868 .918 r
.68102 .23269 m .6801 .23327 L .67692 .23874 L p F P
0 g
s
.761 .876 .93 r
.67086 .23909 m .6801 .23327 L .67692 .23874 L p F P
0 g
s
.641 .915 .98 r
.57781 .4332 m .5677 .43728 L .56514 .43637 L p F P
0 g
s
.626 .911 .982 r
.55504 .44026 m .56514 .43637 L .5677 .43728 L p F P
0 g
s
.182 0 .04 r
.53292 .34246 m .53434 .33994 L .52503 .34441 L p F P
0 g
s
.182 0 .04 r
.52503 .34441 m .52365 .347 L .53292 .34246 L p F P
0 g
s
.583 .787 .976 r
.39223 .45628 m .39253 .45651 L p .37985 .45637 L F P
0 g
s
.583 .787 .976 r
.37985 .45637 m .38349 .45561 L .39223 .45628 L p F P
0 g
s
.581 .79 .978 r
.37985 .45637 m .38349 .45561 L .37837 .45529 L closepath p F P
0 g
s
.74 .326 .263 r
.33143 .36707 m .32899 .36367 L .33577 .36553 L p F P
0 g
s
.74 .326 .263 r
.33622 .36833 m .33143 .36707 L p .33577 .36553 L F P
0 g
s
.74 .326 .263 r
.33577 .36553 m .33722 .36737 L .33622 .36833 L p F P
0 g
s
0 .291 .748 r
.1457 .38582 m .14194 .38362 L .1457 .38664 L p F P
0 g
s
0 .291 .748 r
.1457 .38664 m .14898 .38855 L .1457 .38582 L p F P
0 g
s
.421 .726 .989 r
.27929 .44085 m .28238 .44302 L .27524 .44298 L p F P
0 g
s
.421 .726 .989 r
.26983 .44088 m .27929 .44085 L p .27524 .44298 L F P
0 g
s
.421 .726 .989 r
.27524 .44298 m .27043 .44129 L .26983 .44088 L p F P
0 g
s
0 .299 .768 r
.21779 .28678 m .2143 .28467 L .21784 .28786 L p F P
0 g
s
0 .299 .768 r
.21784 .28786 m .22094 .28972 L .21779 .28678 L p F P
0 g
s
.075 0 .414 r
.75519 .28798 m .75267 .29188 L .75252 .28785 L p F P
0 g
s
.075 0 .414 r
.75252 .28785 m .75526 .28358 L .75519 .28798 L p F P
0 g
s
.694 .327 .348 r
.38099 .37947 m .38086 .37973 L .38062 .37943 L closepath p F P
0 g
s
.752 .312 .206 r
.31642 .35956 m .31393 .35621 L .32012 .35829 L p F P
0 g
s
.752 .312 .206 r
.32071 .36094 m .31642 .35956 L p .32012 .35829 L F P
0 g
s
.752 .312 .206 r
.32012 .35829 m .32176 .36031 L .32071 .36094 L p F P
0 g
s
.691 .328 .354 r
.37415 .3818 m .37159 .37839 L .38062 .37943 L p F P
0 g
s
.691 .328 .354 r
.37958 .38241 m .37415 .3818 L p .38062 .37943 L F P
0 g
s
.691 .328 .354 r
.38062 .37943 m .38086 .37973 L .37958 .38241 L p F P
0 g
s
.756 .291 .142 r
.30728 .35124 m .30638 .35153 L .30562 .35063 L closepath p F P
0 g
s
.732 .331 .289 r
.35276 .37214 m .35285 .37226 L .35269 .37222 L closepath p F P
0 g
s
0 0 0 r
.73368 .33011 m .72899 .33583 L .7329 .33008 L p F P
0 g
s
0 0 0 r
.73645 .32607 m .73368 .33011 L p .7329 .33008 L F P
0 g
s
0 0 0 r
.7329 .33008 m .73679 .32538 L .73645 .32607 L p F P
0 g
s
.303 .251 .632 r
.75755 .26884 m .75672 .27016 L .75441 .26663 L p F P
0 g
s
.303 .251 .632 r
.75441 .26663 m .75643 .26343 L .75755 .26884 L p F P
0 g
s
0 0 0 r
.55685 .32301 m .55533 .32483 L .56486 .31761 L closepath p F P
0 g
s
.587 .235 .34 r
.44516 .37891 m .44433 .38121 L .44042 .37939 L closepath p F P
0 g
s
.585 .233 .339 r
.44404 .38206 m .44433 .38121 L .44042 .37939 L p F P
0 g
s
.585 .233 .339 r
.43211 .38324 m .44404 .38206 L p .44042 .37939 L F P
0 g
s
.502 .865 .632 r
.58793 .29939 m .58476 .30184 L .58728 .29981 L closepath p F P
0 g
s
0 0 0 r
.58547 .30102 m .58728 .29981 L .58476 .30184 L p F P
0 g
s
0 0 0 r
.58414 .30211 m .58547 .30102 L p .58476 .30184 L F P
0 g
s
0 0 0 r
.57726 .30771 m .58414 .30211 L p .58476 .30184 L F P
0 g
s
0 0 .252 r
.74581 .30748 m .74553 .30842 L .74575 .30813 L closepath p F P
0 g
s
.766 .264 .015 r
.28156 .33769 m .2867 .3402 L .28385 .33702 L p F P
0 g
s
.766 .264 .015 r
.28385 .33702 m .27887 .33446 L .28156 .33769 L p F P
0 g
s
.252 0 .092 r
.5226 .34905 m .52365 .347 L .51407 .35112 L p F P
0 g
s
.252 0 .092 r
.5161 .35232 m .5226 .34905 L p .51407 .35112 L F P
0 g
s
.252 0 .092 r
.51407 .35112 m .51272 .35379 L .5161 .35232 L p F P
0 g
s
.739 .352 .318 r
.35086 .37475 m .35525 .37569 L .35285 .37226 L p F P
0 g
s
.739 .352 .318 r
.35285 .37226 m .35269 .37222 L .35086 .37475 L p F P
0 g
s
0 .417 .841 r
.16425 .39806 m .16299 .39751 L .16699 .40042 L p F P
0 g
s
0 .417 .841 r
.16699 .40042 m .1675 .40064 L .16425 .39806 L p F P
0 g
s
.735 .347 .316 r
.34773 .3741 m .35086 .37475 L .35269 .37222 L p F P
0 g
s
.735 .347 .316 r
.35269 .37222 m .34528 .37069 L .34773 .3741 L p F P
0 g
s
.719 .187 0 r
.262 .3232 m .26654 .32596 L .26358 .32287 L p F P
0 g
s
.719 .187 0 r
.26358 .32287 m .25916 .32007 L .262 .3232 L p F P
0 g
s
.713 .179 0 r
.2575 .31826 m .25916 .32007 L .26358 .32287 L p F P
0 g
s
.435 .732 .989 r
.29586 .44552 m .29803 .44701 L p .28546 .44514 L F P
0 g
s
.435 .732 .989 r
.28546 .44514 m .2941 .44492 L .29586 .44552 L p F P
0 g
s
.451 .733 .987 r
.2941 .44492 m .28546 .44514 L .28238 .44302 L p F P
0 g
s
0 0 0 r
.73758 .32435 m .73679 .32538 L .73773 .32279 L p F P
0 g
s
0 0 0 r
.73773 .32279 m .74076 .31885 L .73758 .32435 L p F P
0 g
s
.304 .669 .974 r
.24173 .4331 m .24286 .43321 L .24818 .43556 L p F P
0 g
s
.325 .674 .977 r
.25107 .43388 m .24286 .43321 L .24818 .43556 L p F P
0 g
s
.325 .674 .977 r
.24818 .43556 m .2542 .43608 L .25107 .43388 L p F P
0 g
s
.593 .8 .979 r
.4163 .45664 m .40554 .4567 L .40522 .45647 L p F P
0 g
s
.583 .797 .981 r
.40554 .4567 m .40522 .45647 L .40431 .45666 L closepath p F P
0 g
s
.491 .136 .291 r
.47868 .37266 m .47975 .36955 L .46898 .3721 L p F P
0 g
s
.491 .136 .291 r
.46898 .3721 m .46784 .37517 L .47868 .37266 L p F P
0 g
s
.779 .293 .067 r
.29108 .34158 m .29193 .34266 L .28964 .34153 L closepath p F P
0 g
s
.594 .792 .975 r
.39253 .45651 m .39338 .45632 L .40431 .45666 L p F P
0 g
s
.594 .792 .975 r
.39253 .45651 m .39338 .45632 L .39223 .45628 L closepath p F P
0 g
s
.591 .784 .972 r
.40235 .45424 m .39338 .45632 L .40431 .45666 L p F P
0 g
s
.591 .784 .972 r
.40431 .45666 m .40522 .45647 L .40235 .45424 L p F P
0 g
s
.211 .606 .949 r
.21379 .42341 m .2194 .42448 L .22416 .42705 L p F P
0 g
s
.222 .609 .952 r
.2194 .42448 m .21379 .42341 L .2106 .42111 L p F P
0 g
s
.592 .801 .98 r
.41841 .45662 m .41792 .45628 L .4163 .45664 L closepath p F P
0 g
s
.593 .8 .979 r
.41507 .45406 m .41792 .45628 L .4163 .45664 L p F P
0 g
s
.593 .8 .979 r
.40522 .45647 m .41507 .45406 L p .4163 .45664 L F P
0 g
s
.696 .333 .356 r
.38086 .37973 m .38331 .38279 L .37958 .38241 L closepath p F P
0 g
s
.36 .695 .983 r
.25733 .43824 m .26388 .43857 L .26935 .44086 L p F P
0 g
s
.372 .698 .983 r
.26388 .43857 m .25733 .43824 L .2542 .43608 L p F P
0 g
s
.627 .854 .985 r
.51693 .44707 m .50689 .45023 L .5042 .44867 L p F P
0 g
s
.617 .852 .988 r
.49419 .45169 m .5042 .44867 L .50689 .45023 L p F P
0 g
s
.788 .944 .927 r
.65183 .25203 m .65063 .25286 L .64825 .25185 L p F P
0 g
s
.599 .804 .978 r
.42948 .45622 m .41841 .45662 L .41792 .45628 L p F P
0 g
s
.523 .876 .638 r
.59476 .29397 m .58793 .29939 L .58728 .29981 L p F P
0 g
s
0 .142 .624 r
.12688 .37169 m .13041 .37483 L .12675 .37199 L p F P
0 g
s
0 .142 .624 r
.12675 .37199 m .12322 .36886 L .12688 .37169 L p F P
0 g
s
.523 .767 .986 r
.32628 .45181 m .33592 .4506 L .33891 .45275 L p F P
0 g
s
.538 .762 .98 r
.33592 .4506 m .32628 .45181 L .32327 .44967 L p F P
0 g
s
.06 .429 .871 r
.19952 .27162 m .19565 .26985 L .19886 .27321 L p F P
0 g
s
.06 .429 .871 r
.19886 .27321 m .20267 .27495 L .19952 .27162 L p F P
0 g
s
.802 .943 .918 r
.65183 .25203 m .66073 .24583 L .65835 .24445 L p F P
0 g
s
.802 .943 .918 r
.65835 .24445 m .6559 .24625 L .65183 .25203 L p F P
0 g
s
.788 .944 .927 r
.64825 .25185 m .6559 .24625 L .65183 .25203 L p F P
0 g
s
0 0 .129 r
.7452 .31121 m .74342 .31353 L .74553 .30842 L p F P
0 g
s
0 0 .129 r
.74553 .30842 m .74575 .30813 L .7452 .31121 L p F P
0 g
s
.566 .215 .332 r
.45562 .38045 m .45667 .37724 L .44516 .37891 L p F P
0 g
s
.566 .215 .332 r
.44596 .38178 m .45562 .38045 L p .44516 .37891 L F P
0 g
s
.566 .215 .332 r
.44516 .37891 m .44433 .38121 L .44596 .38178 L p F P
0 g
s
0 0 0 r
.56712 .31545 m .56538 .31723 L .57479 .30976 L closepath p F P
0 g
s
.595 .051 0 r
.23921 .30433 m .24028 .30536 L .24426 .30835 L p F P
0 g
s
.605 .062 0 r
.24338 .30836 m .24745 .31132 L .24426 .30835 L p F P
0 g
s
.605 .062 0 r
.24426 .30835 m .24028 .30536 L .24338 .30836 L p F P
0 g
s
.758 .289 .132 r
.3025 .35166 m .29986 .34837 L .30562 .35063 L p F P
0 g
s
.758 .289 .132 r
.30398 .35223 m .3025 .35166 L p .30562 .35063 L F P
0 g
s
.758 .289 .132 r
.30562 .35063 m .30638 .35153 L .30398 .35223 L p F P
0 g
s
.008 .455 .868 r
.17259 .40263 m .1675 .40064 L .16425 .39806 L p F P
0 g
s
.589 .887 .592 r
.7099 .35762 m .70887 .35844 L .71267 .35468 L closepath p F P
0 g
s
.602 .788 .97 r
.39947 .45183 m .40235 .45424 L .39338 .45632 L p F P
0 g
s
.602 .788 .97 r
.38964 .45429 m .39947 .45183 L p .39338 .45632 L F P
0 g
s
.602 .788 .97 r
.39338 .45632 m .39223 .45628 L .38964 .45429 L p F P
0 g
s
.523 .17 .31 r
.4571 .37607 m .46056 .3765 L .45667 .37724 L closepath p F P
0 g
s
.714 .182 0 r
.25916 .32007 m .2575 .31826 L .25433 .31655 L p F P
0 g
s
.623 .781 .957 r
.41507 .45406 m .40522 .45647 L .40235 .45424 L p F P
0 g
s
.591 .784 .972 r
.39223 .45628 m .38964 .45429 L .38349 .45561 L closepath p F P
0 g
s
0 .278 .763 r
.20684 .27883 m .20582 .27818 L .20267 .27495 L p F P
0 g
s
.325 0 .152 r
.51255 .35416 m .51272 .35379 L .50286 .35752 L p F P
0 g
s
.325 0 .152 r
.50286 .35752 m .50252 .35825 L .51255 .35416 L p F P
0 g
s
.597 .807 .98 r
.43092 .45616 m .43062 .45595 L .42948 .45622 L closepath p F P
0 g
s
.599 .804 .978 r
.42779 .45376 m .43062 .45595 L .42948 .45622 L p F P
0 g
s
.599 .804 .978 r
.41792 .45628 m .42779 .45376 L p .42948 .45622 L F P
0 g
s
0 0 .112 r
.74748 .30798 m .7452 .31121 L .74575 .30813 L p F P
0 g
s
0 0 .112 r
.74575 .30813 m .74944 .30291 L .74748 .30798 L p F P
0 g
s
.625 .844 .984 r
.5042 .44867 m .49419 .45169 L .49147 .45004 L p F P
0 g
s
.615 .843 .986 r
.48147 .45294 m .49147 .45004 L .49419 .45169 L p F P
0 g
s
.612 .812 .977 r
.44052 .45335 m .44306 .45527 L .43092 .45616 L p F P
0 g
s
.612 .812 .977 r
.43092 .45616 m .43062 .45595 L .44052 .45335 L p F P
0 g
s
.627 .958 .812 r
.66861 .39099 m .66615 .39268 L .66811 .39112 L closepath p F P
0 g
s
.649 .969 .85 r
.66632 .39135 m .66811 .39112 L .66615 .39268 L p F P
0 g
s
.649 .969 .85 r
.66113 .39479 m .66632 .39135 L p .66615 .39268 L F P
0 g
s
.649 .969 .85 r
.65721 .39791 m .66113 .39479 L p .66615 .39268 L F P
0 g
s
.61 .936 .728 r
.59796 .29143 m .59476 .29397 L .59722 .29178 L closepath p F P
0 g
s
.523 .876 .638 r
.59552 .29261 m .59722 .29178 L .59476 .29397 L p F P
0 g
s
.523 .876 .638 r
.59318 .29457 m .59552 .29261 L p .59476 .29397 L F P
0 g
s
.523 .876 .638 r
.58728 .29981 m .59318 .29457 L p .59476 .29397 L F P
0 g
s
.574 .584 .826 r
.74546 .23237 m .74317 .23639 L p .73422 .23182 L F P
0 g
s
.574 .584 .826 r
.73422 .23182 m .74483 .23102 L .74546 .23237 L p F P
0 g
s
.568 .622 .866 r
.73231 .22832 m .73422 .23182 L .74483 .23102 L p F P
0 g
s
.143 .561 .927 r
.1983 .41657 m .20257 .41764 L .20711 .4203 L p F P
0 g
s
.155 .564 .93 r
.20257 .41764 m .1983 .41657 L .19509 .41419 L p F P
0 g
s
.071 .509 .898 r
.18287 .40901 m .18703 .41033 L .19136 .41309 L p F P
0 g
s
.083 .512 .902 r
.18703 .41033 m .18287 .40901 L .17963 .40654 L p F P
0 g
s
0 0 0 r
.72875 .33612 m .72865 .33627 L .72899 .33583 L closepath p F P
0 g
s
.627 .784 .957 r
.42779 .45376 m .41792 .45628 L .41507 .45406 L p F P
0 g
s
.754 .823 .906 r
.6936 .22924 m .6834 .23488 L .68102 .23269 L p F P
0 g
s
.65 .935 .968 r
.60038 .42507 m .59046 .42952 L .58794 .42885 L p F P
0 g
s
.716 .343 .343 r
.36568 .38055 m .37415 .3818 L .37159 .37839 L p F P
0 g
s
.716 .343 .343 r
.36516 .37979 m .36568 .38055 L p .37159 .37839 L F P
0 g
s
.716 .343 .343 r
.37159 .37839 m .36639 .37761 L .36516 .37979 L p F P
0 g
s
.62 .94 .73 r
.60451 .28618 m .59796 .29143 L .59722 .29178 L p F P
0 g
s
.624 .834 .981 r
.49147 .45004 m .48147 .45294 L .47873 .45119 L p F P
0 g
s
.612 .834 .985 r
.46876 .45397 m .47873 .45119 L .48147 .45294 L p F P
0 g
s
.633 .907 .983 r
.56344 .43573 m .56514 .43637 L .55504 .44026 L p F P
0 g
s
.633 .907 .983 r
.55504 .44026 m .5539 .43983 L .56344 .43573 L p F P
0 g
s
.656 .953 .948 r
.61342 .42059 m .6132 .42055 L .61468 .41981 L closepath p F P
0 g
s
.659 .967 .911 r
.64551 .40452 m .6359 .41002 L .63422 .40998 L p F P
0 g
s
0 .112 .592 r
.22094 .28972 m .22187 .29046 L .22548 .29363 L p F P
0 g
s
0 .105 .585 r
.22534 .29329 m .22902 .29643 L .22548 .29363 L p F P
0 g
s
0 .105 .585 r
.22548 .29363 m .22187 .29046 L .22534 .29329 L p F P
0 g
s
.645 .965 .813 r
.67833 .38411 m .66861 .39099 L .66811 .39112 L p F P
0 g
s
0 0 0 r
.57726 .30771 m .57543 .30926 L .58414 .30211 L closepath p F P
0 g
s
.475 .744 .988 r
.30759 .44631 m .30055 .44684 L .3071 .44873 L p F P
0 g
s
.475 .744 .988 r
.3071 .44873 m .31063 .4485 L .30759 .44631 L p F P
0 g
s
.469 .749 .99 r
.29803 .44701 m .30055 .44684 L .3071 .44873 L p F P
0 g
s
.63 .789 .959 r
.44052 .45335 m .43062 .45595 L .42779 .45376 L p F P
0 g
s
.162 .073 .499 r
.75876 .27816 m .75526 .28358 L .75465 .27944 L p F P
0 g
s
.162 .073 .499 r
.75876 .27812 m .75876 .27816 L p .75465 .27944 L F P
0 g
s
.162 .073 .499 r
.75465 .27944 m .75814 .27402 L .75876 .27812 L p F P
0 g
s
0 0 0 r
.72918 .33607 m .73368 .33011 L .72899 .33583 L p F P
0 g
s
0 0 0 r
.72743 .33822 m .72918 .33607 L p .72899 .33583 L F P
0 g
s
0 0 0 r
.72899 .33583 m .72865 .33627 L .72743 .33822 L p F P
0 g
s
0 .184 .659 r
.13385 .3778 m .13402 .37792 L .13217 .37634 L closepath p F P
0 g
s
.62 .826 .98 r
.4776 .45038 m .47873 .45119 L .46876 .45397 L p F P
0 g
s
.62 .826 .98 r
.46876 .45397 m .4664 .45239 L .4776 .45038 L p F P
0 g
s
.61 .826 .983 r
.4664 .45239 m .46876 .45397 L p .45605 .45481 L F P
0 g
s
.107 0 0 r
.5407 .33484 m .53524 .33838 L .53434 .33994 L p F P
0 g
s
0 .383 .82 r
.15522 .39159 m .15907 .39457 L .15408 .39217 L p F P
0 g
s
0 .383 .82 r
.15408 .39217 m .1502 .3892 L .15522 .39159 L p F P
0 g
s
0 .332 .778 r
.14898 .38855 m .1502 .3892 L .15408 .39217 L p F P
0 g
s
0 0 0 r
.72865 .33627 m .72422 .34188 L .72743 .33822 L closepath p F P
0 g
s
.615 .807 .974 r
.44333 .45547 m .44465 .45512 L .44306 .45527 L closepath p F P
0 g
s
.611 .815 .979 r
.45483 .45396 m .45605 .45481 L p .44333 .45547 L F P
0 g
s
.611 .815 .979 r
.44333 .45547 m .44465 .45512 L .45483 .45396 L p F P
0 g
s
.591 .787 .973 r
.38674 .45191 m .38964 .45429 L .38349 .45561 L p F P
0 g
s
.591 .787 .973 r
.37694 .45421 m .38674 .45191 L p .38349 .45561 L F P
0 g
s
.591 .787 .973 r
.38349 .45561 m .37837 .45529 L .37694 .45421 L p F P
0 g
s
.024 0 .332 r
.75257 .29556 m .75082 .29805 L .7516 .2934 L p F P
0 g
s
.024 0 .332 r
.7516 .2934 m .75267 .29188 L .75257 .29556 L p F P
0 g
s
.61 .826 .983 r
.45605 .45481 m .46327 .45286 L .4664 .45239 L p F P
0 g
s
.616 .815 .977 r
.45605 .45481 m .46327 .45286 L .45483 .45396 L closepath p F P
0 g
s
.702 .162 0 r
.26947 .32899 m .26654 .32596 L .27129 .32863 L p F P
0 g
s
.702 .162 0 r
.27129 .32863 m .27267 .33001 L .26947 .32899 L p F P
0 g
s
.546 .771 .981 r
.34901 .45158 m .35157 .45346 L p .33891 .45275 L F P
0 g
s
.546 .771 .981 r
.33891 .45275 m .34798 .45137 L .34901 .45158 L p F P
0 g
s
.566 .767 .973 r
.34798 .45137 m .33891 .45275 L .33592 .4506 L p F P
0 g
s
.175 .578 .937 r
.2074 .41875 m .20257 .41764 L .20711 .4203 L p F P
0 g
s
.175 .578 .937 r
.20711 .4203 m .2106 .42111 L .2074 .41875 L p F P
0 g
s
.373 .342 .695 r
.75446 .25807 m .75487 .2574 L .75523 .25871 L closepath p F P
0 g
s
.793 .319 .105 r
.28925 .34349 m .29442 .34599 L .29193 .34266 L p F P
0 g
s
.793 .319 .105 r
.28788 .34155 m .28925 .34349 L p .29193 .34266 L F P
0 g
s
.793 .319 .105 r
.29193 .34266 m .28964 .34153 L .28788 .34155 L p F P
0 g
s
0 .303 .766 r
.13463 .37747 m .13825 .38056 L .13402 .37792 L p F P
0 g
s
0 .303 .766 r
.13056 .37493 m .13463 .37747 L p .13402 .37792 L F P
0 g
s
0 .303 .766 r
.13402 .37792 m .13217 .37634 L .13056 .37493 L p F P
0 g
s
.693 .978 .802 r
.608 .28338 m .60451 .28618 L .6071 .28365 L closepath p F P
0 g
s
.62 .94 .73 r
.60558 .28412 m .6071 .28365 L .60451 .28618 L p F P
0 g
s
.62 .94 .73 r
.60207 .28707 m .60558 .28412 L p .60451 .28618 L F P
0 g
s
.62 .94 .73 r
.59722 .29178 m .60207 .28707 L p .60451 .28618 L F P
0 g
s
.664 .951 .952 r
.61468 .41981 m .6132 .42055 L .61074 .42007 L p F P
0 g
s
.651 .948 .954 r
.60059 .42497 m .61074 .42007 L .6132 .42055 L p F P
0 g
s
.108 .531 .912 r
.19186 .41175 m .18703 .41033 L .19136 .41309 L p F P
0 g
s
.108 .531 .912 r
.19136 .41309 m .19509 .41419 L .19186 .41175 L p F P
0 g
s
.367 .7 .984 r
.27043 .44129 m .26983 .44088 L .26935 .44086 L closepath p F P
0 g
s
.401 .036 .226 r
.50046 .36332 m .50163 .36037 L .49146 .3637 L p F P
0 g
s
.401 .036 .226 r
.49146 .3637 m .49027 .36664 L .50046 .36332 L p F P
0 g
s
.789 .338 .175 r
.30638 .35153 m .30811 .35397 L .30398 .35223 L closepath p F P
0 g
s
.775 .366 .276 r
.3249 .3651 m .33143 .36707 L .32899 .36367 L p F P
0 g
s
.775 .366 .276 r
.32899 .36367 m .32267 .36163 L .3249 .3651 L p F P
0 g
s
.496 0 0 r
.1163 .3628 m .11565 .36217 L .11236 .35907 L p F P
0 g
s
.757 .369 .319 r
.34049 .37241 m .34773 .3741 L .34528 .37069 L p F P
0 g
s
.757 .369 .319 r
.34528 .37069 m .33828 .36891 L .34049 .37241 L p F P
0 g
s
.783 .917 .929 r
.66497 .24301 m .66073 .24583 L .65835 .24445 L p F P
0 g
s
.576 .782 .976 r
.37837 .45529 m .37694 .45421 L .37394 .45479 L closepath p F P
0 g
s
.534 .028 0 r
.10908 .35585 m .1066 .35329 L .10992 .35654 L p F P
0 g
s
.534 .028 0 r
.10992 .35654 m .11236 .35907 L .10908 .35585 L p F P
0 g
s
.589 .033 0 r
.2507 .31429 m .24745 .31132 L .25167 .31422 L p F P
0 g
s
.589 .033 0 r
.25241 .31542 m .2507 .31429 L p .25167 .31422 L F P
0 g
s
.589 .033 0 r
.25167 .31422 m .25433 .31655 L .25241 .31542 L p F P
0 g
s
.621 .802 .969 r
.44465 .45512 m .44306 .45527 L .44052 .45335 L p F P
0 g
s
.238 .619 .956 r
.22297 .42509 m .2194 .42448 L .22416 .42705 L p F P
0 g
s
.238 .619 .956 r
.22416 .42705 m .22615 .42739 L .22297 .42509 L p F P
0 g
s
.467 .75 .991 r
.29803 .44701 m .30055 .44684 L .29586 .44552 L closepath p F P
0 g
s
.695 .979 .802 r
.6142 .27841 m .608 .28338 L .6071 .28365 L p F P
0 g
s
.717 .345 .343 r
.36639 .37761 m .36516 .37979 L .36321 .37712 L closepath p F P
0 g
s
.76 .352 .279 r
.33722 .36737 m .33828 .36891 L .33622 .36833 L closepath p F P
0 g
s
0 .278 .763 r
.20267 .27495 m .20355 .27552 L .20684 .27883 L p F P
0 g
s
0 .278 .762 r
.20755 .2781 m .21087 .28141 L .20684 .27883 L p F P
0 g
s
0 .278 .762 r
.20684 .27883 m .20355 .27552 L .20755 .2781 L p F P
0 g
s
.349 0 .191 r
.51151 .35665 m .51255 .35416 L .50252 .35825 L p F P
0 g
s
.349 0 .191 r
.50252 .35825 m .50163 .36037 L .51151 .35665 L p F P
0 g
s
.621 .802 .969 r
.45046 .45055 m .45326 .4528 L .44465 .45512 L p F P
0 g
s
.621 .802 .969 r
.44052 .45335 m .45046 .45055 L p .44465 .45512 L F P
0 g
s
.619 .809 .973 r
.45483 .45396 m .45326 .4528 L .44465 .45512 L closepath p F P
0 g
s
.309 .668 .974 r
.24173 .4331 m .24286 .43321 L .24003 .43193 L closepath p F P
0 g
s
.43 .428 .756 r
.75248 .24979 m .753 .25002 L .75273 .25052 L closepath p F P
0 g
s
.392 .382 .729 r
.75734 .25281 m .75487 .2574 L .75273 .25052 L p F P
0 g
s
.392 .382 .729 r
.75273 .25052 m .753 .25002 L .75734 .25281 L p F P
0 g
s
.651 .957 .937 r
.62334 .41534 m .61468 .41981 L .62205 .41518 L closepath p F P
0 g
s
.664 .951 .952 r
.62091 .41496 m .62205 .41518 L .61468 .41981 L p F P
0 g
s
.664 .951 .952 r
.61074 .42007 m .62091 .41496 L p .61468 .41981 L F P
0 g
s
.536 .552 .819 r
.74317 .23639 m .74546 .23237 L .74733 .23657 L closepath p F P
0 g
s
.447 .452 .771 r
.753 .25002 m .75248 .24979 L .74987 .24267 L p F P
0 g
s
.547 .886 .636 r
.58728 .29981 m .58547 .30102 L .59318 .29457 L closepath p F P
0 g
s
.786 .353 .221 r
.31041 .3574 m .31642 .35956 L .31393 .35621 L p F P
0 g
s
.786 .353 .221 r
.31393 .35621 m .30811 .35397 L .31041 .3574 L p F P
0 g
s
.374 .698 .983 r
.26672 .43867 m .26388 .43857 L .26935 .44086 L p F P
0 g
s
.374 .698 .983 r
.26935 .44086 m .26983 .44088 L .26672 .43867 L p F P
0 g
s
.306 .298 .686 r
.76056 .25601 m .75734 .25281 L .75487 .2574 L p F P
0 g
s
.306 .298 .686 r
.75763 .26128 m .76056 .25601 L p .75487 .2574 L F P
0 g
s
.306 .298 .686 r
.75487 .2574 m .75523 .25871 L .75763 .26128 L p F P
0 g
s
.588 .051 0 r
.24028 .30536 m .23921 .30433 L .23604 .30193 L p F P
0 g
s
.037 .477 .882 r
.17639 .40401 m .17259 .40263 L .1767 .40548 L p F P
0 g
s
.037 .477 .882 r
.1767 .40548 m .17963 .40654 L .17639 .40401 L p F P
0 g
s
.535 .194 .336 r
.46056 .3765 m .45667 .37724 L .45562 .38045 L p F P
0 g
s
.586 .782 .973 r
.36424 .45396 m .36464 .45388 L .37394 .45479 L p F P
0 g
s
.582 .771 .969 r
.37402 .45185 m .36464 .45388 L .37394 .45479 L p F P
0 g
s
.582 .771 .969 r
.37394 .45479 m .37694 .45421 L .37402 .45185 L p F P
0 g
s
.695 .979 .802 r
.61563 .27564 m .61694 .27546 L .6142 .27841 L p F P
0 g
s
.695 .979 .802 r
.61095 .27959 m .61563 .27564 L p .6142 .27841 L F P
0 g
s
.695 .979 .802 r
.6071 .28365 m .61095 .27959 L p .6142 .27841 L F P
0 g
s
.75 .994 .853 r
.61805 .27533 m .6142 .27841 L .61694 .27546 L closepath p F P
0 g
s
.06 0 0 r
.54528 .33192 m .5407 .33484 L .54483 .33262 L closepath p F P
0 g
s
.107 0 0 r
.54335 .33502 m .54483 .33262 L .5407 .33484 L p F P
0 g
s
.107 0 0 r
.53434 .33994 m .54335 .33502 L p .5407 .33484 L F P
0 g
s
0 0 0 r
.724 .34227 m .71893 .34811 L .72422 .34188 L p F P
0 g
s
0 0 0 r
.72667 .33913 m .724 .34227 L p .72422 .34188 L F P
0 g
s
0 0 0 r
.72422 .34188 m .72743 .33822 L .72667 .33913 L p F P
0 g
s
.332 .304 .677 r
.75523 .25871 m .75763 .26128 L .75643 .26343 L closepath p F P
0 g
s
.777 .349 .233 r
.32176 .36031 m .32267 .36163 L .32071 .36094 L closepath p F P
0 g
s
.636 .889 .986 r
.55244 .4392 m .54235 .44286 L .53972 .44164 L p F P
0 g
s
.625 .885 .988 r
.52964 .44512 m .53972 .44164 L .54235 .44286 L p F P
0 g
s
.57 .774 .975 r
.36406 .45382 m .36424 .45396 L p .35157 .45346 L F P
0 g
s
.57 .774 .975 r
.35157 .45346 m .35648 .45257 L .36406 .45382 L p F P
0 g
s
.566 .78 .979 r
.35157 .45346 m .35648 .45257 L .34901 .45158 L closepath p F P
0 g
s
.715 .345 .347 r
.3575 .3792 m .35525 .37569 L .36321 .37712 L p F P
0 g
s
.715 .345 .347 r
.36482 .38041 m .3575 .3792 L p .36321 .37712 L F P
0 g
s
.715 .345 .347 r
.36321 .37712 m .36516 .37979 L .36482 .38041 L p F P
0 g
s
0 .134 .597 r
.23265 .29921 m .22902 .29643 L .23281 .29951 L p F P
0 g
s
0 .134 .597 r
.23394 .30023 m .23265 .29921 L p .23281 .29951 L F P
0 g
s
0 .134 .597 r
.23281 .29951 m .23604 .30193 L .23394 .30023 L p F P
0 g
s
.646 .677 .865 r
.71895 .22635 m .72937 .2233 L .73179 .22741 L p F P
0 g
s
.66 .696 .872 r
.72937 .2233 m .71895 .22635 L .71656 .22286 L p F P
0 g
s
.687 .731 .884 r
.70623 .22706 m .71656 .22286 L .71895 .22635 L p F P
0 g
s
.7 .747 .888 r
.71656 .22286 m .70623 .22706 L .70385 .22409 L p F P
0 g
s
.427 .718 .985 r
.27929 .44085 m .26983 .44088 L .26672 .43867 L p F P
0 g
s
.797 .907 .917 r
.66497 .24301 m .67086 .23909 L .66848 .23735 L p F P
0 g
s
.797 .907 .917 r
.66848 .23735 m .66829 .23749 L .66497 .24301 L p F P
0 g
s
.783 .917 .929 r
.65835 .24445 m .66829 .23749 L .66497 .24301 L p F P
0 g
s
.618 .948 .767 r
.67872 .38382 m .67833 .38411 L .67863 .38385 L closepath p F P
0 g
s
.645 .965 .813 r
.67645 .38433 m .67863 .38385 L .67833 .38411 L p F P
0 g
s
.645 .965 .813 r
.67428 .38588 m .67645 .38433 L p .67833 .38411 L F P
0 g
s
.645 .965 .813 r
.66811 .39112 m .67428 .38588 L p .67833 .38411 L F P
0 g
s
.629 .867 .987 r
.52699 .44375 m .5281 .44435 L .51792 .4476 L p F P
0 g
s
.629 .867 .987 r
.51792 .4476 m .51693 .44707 L .52699 .44375 L p F P
0 g
s
0 0 .01 r
.74445 .31402 m .74076 .31885 L .74342 .31353 L p F P
0 g
s
0 0 .01 r
.74342 .31353 m .7452 .31121 L .74445 .31402 L p F P
0 g
s
.447 .452 .771 r
.74987 .24267 m .7557 .24481 L .753 .25002 L p F P
0 g
s
.398 .393 .737 r
.76026 .24752 m .75734 .25281 L .753 .25002 L p F P
0 g
s
.398 .393 .737 r
.753 .25002 m .7557 .24481 L .76026 .24752 L p F P
0 g
s
.637 .955 .769 r
.68875 .37613 m .67872 .38382 L .67863 .38385 L p F P
0 g
s
.678 .978 .857 r
.66811 .39112 m .66632 .39135 L .67428 .38588 L closepath p F P
0 g
s
.647 .301 .372 r
.41579 .38399 m .40693 .38405 L .40607 .38638 L p F P
0 g
s
.664 .318 .378 r
.40693 .38405 m .40607 .38638 L .40388 .38398 L closepath p F P
0 g
s
.643 .301 .377 r
.41976 .38392 m .41878 .38675 L .41579 .38399 L closepath p F P
0 g
s
.647 .301 .372 r
.41866 .38715 m .41878 .38675 L .41579 .38399 L p F P
0 g
s
.647 .301 .372 r
.4069 .38725 m .41866 .38715 L p .41579 .38399 L F P
0 g
s
.647 .301 .372 r
.40607 .38638 m .4069 .38725 L p .41579 .38399 L F P
0 g
s
.671 .323 .375 r
.40577 .38724 m .40607 .38638 L .40388 .38398 L p F P
0 g
s
.671 .323 .375 r
.39585 .38692 m .40577 .38724 L p .40388 .38398 L F P
0 g
s
.671 .323 .375 r
.39343 .38384 m .39585 .38692 L p .40388 .38398 L F P
0 g
s
.671 .323 .375 r
.40388 .38398 m .39354 .38355 L .39343 .38384 L p F P
0 g
s
0 .107 .601 r
.11636 .36247 m .11976 .36569 L .1163 .3628 L p F P
0 g
s
.496 0 0 r
.11236 .35907 m .11291 .35959 L .1163 .3628 L p F P
0 g
s
0 .107 .601 r
.1163 .3628 m .11291 .35959 L .11636 .36247 L p F P
0 g
s
.747 .994 .853 r
.62401 .2706 m .61805 .27533 L .61694 .27546 L p F P
0 g
s
.621 .278 .369 r
.42943 .38339 m .41976 .38392 L .41878 .38675 L p F P
0 g
s
.758 .262 .049 r
.28964 .34153 m .28788 .34155 L .2867 .3402 L closepath p F P
0 g
s
.78 .282 .018 r
.27665 .33508 m .28156 .33769 L .27887 .33446 L p F P
0 g
s
.78 .282 .018 r
.27887 .33446 m .2741 .3318 L .27665 .33508 L p F P
0 g
s
.637 .955 .769 r
.67863 .38385 m .68555 .3776 L p .68875 .37613 L F P
0 g
s
.677 .976 .823 r
.67863 .38385 m .67645 .38433 L .68555 .3776 L closepath p F P
0 g
s
.645 .923 .976 r
.57792 .43324 m .57781 .4332 L .57897 .43271 L closepath p F P
0 g
s
.362 .689 .981 r
.24833 .43191 m .25107 .43388 L .24286 .43321 L p F P
0 g
s
.362 .689 .981 r
.24767 .43159 m .24833 .43191 L p .24286 .43321 L F P
0 g
s
.362 .689 .981 r
.23858 .43089 m .24767 .43159 L p .24286 .43321 L F P
0 g
s
.362 .689 .981 r
.24286 .43321 m .24003 .43193 L .23858 .43089 L p F P
0 g
s
.445 .085 .259 r
.47979 .36944 m .48061 .36931 L .47975 .36955 L closepath p F P
0 g
s
.677 .976 .885 r
.65721 .39791 m .65618 .39795 L .66113 .39479 L closepath p F P
0 g
s
.49 .494 .788 r
.74969 .24263 m .74979 .24246 L .74987 .24267 L closepath p F P
0 g
s
.462 .115 .291 r
.48061 .36931 m .47975 .36955 L .47868 .37266 L p F P
0 g
s
.786 .325 .147 r
.29687 .34934 m .3025 .35166 L .29986 .34837 L p F P
0 g
s
.786 .325 .147 r
.29986 .34837 m .29442 .34599 L .29687 .34934 L p F P
0 g
s
.654 .918 .977 r
.57897 .43271 m .57781 .4332 L .57526 .43228 L p F P
0 g
s
.641 .915 .98 r
.56514 .43637 m .57526 .43228 L .57781 .4332 L p F P
0 g
s
.434 .46 .788 r
.74979 .24246 m .74987 .24267 L .7557 .24481 L p F P
0 g
s
0 0 .317 r
.75449 .2926 m .75257 .29556 L .75267 .29188 L p F P
0 g
s
0 0 .317 r
.75267 .29188 m .75519 .28798 L .75449 .2926 L p F P
0 g
s
0 .295 .756 r
.14243 .38301 m .13825 .38056 L .14194 .38362 L p F P
0 g
s
0 .295 .756 r
.14194 .38362 m .1457 .38582 L .14243 .38301 L p F P
0 g
s
.492 .511 .804 r
.74733 .23657 m .75222 .23746 L .74979 .24246 L closepath p F P
0 g
s
.434 .46 .788 r
.75826 .2394 m .75222 .23746 L .74979 .24246 L p F P
0 g
s
.434 .46 .788 r
.7584 .23981 m .75826 .2394 L p .74979 .24246 L F P
0 g
s
.434 .46 .788 r
.7557 .24481 m .7584 .23981 L p .74979 .24246 L F P
0 g
s
.601 .644 .865 r
.73179 .22741 m .73277 .22725 L .73231 .22832 L closepath p F P
0 g
s
.568 .622 .866 r
.74236 .22599 m .73277 .22725 L .73231 .22832 L p F P
0 g
s
.568 .622 .866 r
.74483 .23102 m .74236 .22599 L p .73231 .22832 L F P
0 g
s
.728 .201 0 r
.25764 .32037 m .262 .3232 L .25916 .32007 L p F P
0 g
s
.728 .201 0 r
.25916 .32007 m .2549 .31719 L .25764 .32037 L p F P
0 g
s
.714 .182 0 r
.25433 .31655 m .2549 .31719 L .25916 .32007 L p F P
0 g
s
.535 .189 .327 r
.46784 .37517 m .46701 .37763 L .46056 .3765 L closepath p F P
0 g
s
.535 .194 .336 r
.46679 .37835 m .46701 .37763 L .46056 .3765 L p F P
0 g
s
.535 .194 .336 r
.45562 .38045 m .46679 .37835 L p .46056 .3765 L F P
0 g
s
.683 .336 .38 r
.39354 .38355 m .39343 .38384 L .39319 .38353 L closepath p F P
0 g
s
.679 .336 .386 r
.38576 .38626 m .38331 .38279 L .39319 .38353 L p F P
0 g
s
.679 .336 .386 r
.39235 .38674 m .38576 .38626 L p .39319 .38353 L F P
0 g
s
.679 .336 .386 r
.39319 .38353 m .39343 .38384 L .39235 .38674 L p F P
0 g
s
.642 .947 .725 r
.59722 .29178 m .59552 .29261 L .60207 .28707 L closepath p F P
0 g
s
.784 .991 .885 r
.6281 .26735 m .62401 .2706 L .62681 .26728 L closepath p F P
0 g
s
.747 .994 .853 r
.6257 .26724 m .62681 .26728 L .62401 .2706 L p F P
0 g
s
.747 .994 .853 r
.61992 .27206 m .6257 .26724 L p .62401 .2706 L F P
0 g
s
.747 .994 .853 r
.61694 .27546 m .61992 .27206 L p .62401 .2706 L F P
0 g
s
.567 .853 .525 r
.71885 .3482 m .71882 .34823 L .71893 .34811 L closepath p F P
0 g
s
0 .301 .775 r
.21463 .28371 m .21087 .28141 L .2143 .28467 L p F P
0 g
s
0 .301 .775 r
.2143 .28467 m .21779 .28678 L .21463 .28371 L p F P
0 g
s
.586 .782 .973 r
.36424 .45396 m .36464 .45388 L .36406 .45382 L closepath p F P
0 g
s
.005 0 0 r
.55386 .32585 m .54528 .33192 L .54483 .33262 L p F P
0 g
s
.462 .115 .291 r
.48919 .36973 m .48979 .36794 L .48061 .36931 L p F P
0 g
s
.462 .115 .291 r
.47868 .37266 m .48919 .36973 L p .48061 .36931 L F P
0 g
s
.455 .099 .271 r
.49027 .36664 m .48979 .36794 L .48061 .36931 L closepath p F P
0 g
s
.271 .229 .627 r
.7598 .26486 m .75755 .26884 L .75643 .26343 L p F P
0 g
s
.271 .229 .627 r
.75643 .26343 m .75763 .26128 L .7598 .26486 L p F P
0 g
s
0 .22 .695 r
.13217 .37634 m .13056 .37493 L .13041 .37483 L closepath p F P
0 g
s
0 .419 .846 r
.161 .39541 m .15907 .39457 L .16299 .39751 L p F P
0 g
s
0 .419 .846 r
.16299 .39751 m .16425 .39806 L .161 .39541 L p F P
0 g
s
.571 .855 .528 r
.71814 .34872 m .724 .34227 L .71893 .34811 L p F P
0 g
s
.571 .855 .528 r
.71716 .34985 m .71814 .34872 L p .71893 .34811 L F P
0 g
s
.571 .855 .528 r
.71893 .34811 m .71882 .34823 L .71716 .34985 L p F P
0 g
s
.621 .282 .375 r
.43211 .38324 m .43154 .38499 L .42943 .38339 L closepath p F P
0 g
s
.621 .278 .369 r
.43108 .38652 m .43154 .38499 L .42943 .38339 L p F P
0 g
s
.621 .278 .369 r
.41923 .38712 m .43108 .38652 L p .42943 .38339 L F P
0 g
s
.621 .278 .369 r
.41878 .38675 m .41923 .38712 L p .42943 .38339 L F P
0 g
s
.547 .844 .522 r
.71882 .34823 m .71267 .35468 L .71716 .34985 L closepath p F P
0 g
s
.622 .81 .972 r
.46327 .45286 m .45483 .45396 L .45326 .4528 L p F P
0 g
s
.641 .898 .984 r
.56256 .43535 m .56344 .43573 L .5539 .43983 L p F P
0 g
s
.641 .898 .984 r
.5539 .43983 m .55244 .4392 L .56256 .43535 L p F P
0 g
s
.512 .758 .985 r
.31063 .4485 m .32025 .44746 L .32327 .44967 L p F P
0 g
s
.525 .756 .981 r
.32025 .44746 m .31063 .4485 L .30759 .44631 L p F P
0 g
s
.645 .967 .888 r
.64604 .40421 m .64551 .40452 L .64594 .40422 L closepath p F P
0 g
s
.659 .967 .911 r
.64366 .4041 m .64594 .40422 L .64551 .40452 L p F P
0 g
s
.659 .967 .911 r
.63751 .40765 m .64366 .4041 L p .64551 .40452 L F P
0 g
s
.659 .967 .911 r
.63422 .40998 m .63751 .40765 L p .64551 .40452 L F P
0 g
s
0 .116 .605 r
.22187 .29046 m .22094 .28972 L .21779 .28678 L p F P
0 g
s
0 .338 .787 r
.1502 .3892 m .14898 .38855 L .1457 .38582 L p F P
0 g
s
.494 .754 .987 r
.30455 .44404 m .30759 .44631 L .30055 .44684 L p F P
0 g
s
.494 .754 .987 r
.29497 .44489 m .30455 .44404 L p .30055 .44684 L F P
0 g
s
.494 .754 .987 r
.30055 .44684 m .29586 .44552 L .29497 .44489 L p F P
0 g
s
.283 .646 .967 r
.22615 .42739 m .23283 .42827 L .23773 .43079 L p F P
0 g
s
.294 .648 .968 r
.23283 .42827 m .22615 .42739 L .22297 .42509 L p F P
0 g
s
.778 .275 0 r
.2741 .3318 m .27267 .33001 L .26947 .32899 L p F P
0 g
s
.644 .928 .972 r
.58794 .42885 m .57897 .43271 L .58706 .42859 L closepath p F P
0 g
s
.654 .918 .977 r
.58541 .42799 m .58706 .42859 L .57897 .43271 L p F P
0 g
s
.654 .918 .977 r
.57526 .43228 m .58541 .42799 L p .57897 .43271 L F P
0 g
s
.596 .779 .968 r
.37109 .44934 m .37402 .45185 L .36464 .45388 L p F P
0 g
s
.596 .779 .968 r
.3613 .45165 m .37109 .44934 L p .36464 .45388 L F P
0 g
s
.596 .779 .968 r
.36464 .45388 m .36406 .45382 L .3613 .45165 L p F P
0 g
s
.632 .878 .987 r
.53807 .44081 m .53972 .44164 L .52964 .44512 L p F P
0 g
s
.632 .878 .987 r
.52964 .44512 m .5281 .44435 L .53807 .44081 L p F P
0 g
s
.664 .973 .887 r
.65409 .39803 m .65618 .39795 L .64604 .40421 L p F P
0 g
s
.664 .973 .887 r
.64604 .40421 m .64594 .40422 L .65409 .39803 L p F P
0 g
s
.577 .773 .972 r
.36406 .45382 m .3613 .45165 L .35648 .45257 L closepath p F P
0 g
s
.607 .268 .37 r
.44308 .3854 m .44404 .38206 L .43211 .38324 L p F P
0 g
s
.607 .268 .37 r
.43357 .38629 m .44308 .3854 L p .43211 .38324 L F P
0 g
s
.607 .268 .37 r
.43211 .38324 m .43154 .38499 L .43357 .38629 L p F P
0 g
s
.773 .887 .927 r
.6801 .23327 m .67086 .23909 L .66848 .23735 L p F P
0 g
s
.778 .991 .887 r
.63408 .26269 m .6281 .26735 L .62681 .26728 L p F P
0 g
s
.727 .816 .92 r
.6993 .22638 m .6936 .22924 L .69122 .22674 L p F P
0 g
s
.754 .823 .906 r
.68102 .23269 m .69122 .22674 L .6936 .22924 L p F P
0 g
s
.68 .336 .386 r
.39343 .38384 m .39585 .38692 L .39235 .38674 L closepath p F P
0 g
s
.606 .931 .715 r
.6888 .37609 m .68875 .37613 L .68879 .37609 L closepath p F P
0 g
s
.637 .955 .769 r
.68658 .37681 m .68879 .37609 L .68875 .37613 L p F P
0 g
s
.637 .955 .769 r
.68555 .3776 m .68658 .37681 L p .68875 .37613 L F P
0 g
s
.626 .94 .718 r
.69777 .36862 m .6888 .37609 L .68879 .37609 L p F P
0 g
s
.626 .94 .718 r
.68879 .37609 m .6953 .36984 L p .69777 .36862 L F P
0 g
s
.672 .969 .782 r
.68879 .37609 m .68658 .37681 L .6953 .36984 L closepath p F P
0 g
s
.234 .166 .571 r
.75832 .27373 m .75814 .27402 L .75672 .27016 L p F P
0 g
s
.234 .166 .571 r
.75672 .27016 m .75755 .26884 L .75832 .27373 L p F P
0 g
s
.566 .222 .346 r
.44433 .38121 m .44596 .38178 L .44404 .38206 L closepath p F P
0 g
s
.683 .973 .914 r
.65383 .39802 m .65409 .39803 L .64594 .40422 L p F P
0 g
s
.683 .973 .914 r
.64594 .40422 m .64366 .4041 L .65383 .39802 L p F P
0 g
s
.765 .369 .304 r
.33413 .37061 m .34049 .37241 L .33828 .36891 L p F P
0 g
s
.765 .369 .304 r
.33828 .36891 m .33622 .36833 L .33413 .37061 L p F P
0 g
s
.615 .661 .872 r
.73277 .22725 m .73179 .22741 L .72937 .2233 L p F P
0 g
s
.588 .051 0 r
.23604 .30193 m .23643 .30231 L .24028 .30536 L p F P
0 g
s
.606 .069 0 r
.23945 .30533 m .24338 .30836 L .24028 .30536 L p F P
0 g
s
.606 .069 0 r
.24028 .30536 m .23643 .30231 L .23945 .30533 L p F P
0 g
s
0 .151 .639 r
.12342 .36851 m .12688 .37169 L .12322 .36886 L p F P
0 g
s
0 .151 .639 r
.12322 .36886 m .11976 .36569 L .12342 .36851 L p F P
0 g
s
.592 .889 .596 r
.71675 .35014 m .71716 .34985 L .71267 .35468 L p F P
0 g
s
.592 .889 .596 r
.71139 .35546 m .71675 .35014 L p .71267 .35468 L F P
0 g
s
.592 .889 .596 r
.70804 .35909 m .71139 .35546 L p .71267 .35468 L F P
0 g
s
.592 .889 .596 r
.71267 .35468 m .70887 .35844 L .70804 .35909 L p F P
0 g
s
.622 .768 .95 r
.38674 .45191 m .37694 .45421 L .37402 .45185 L p F P
0 g
s
.783 .367 .26 r
.3188 .36298 m .3249 .3651 L .32267 .36163 L p F P
0 g
s
.783 .367 .26 r
.31851 .36249 m .3188 .36298 L p .32267 .36163 L F P
0 g
s
.783 .367 .26 r
.32267 .36163 m .32071 .36094 L .31851 .36249 L p F P
0 g
s
.701 .35 .377 r
.37827 .38549 m .38576 .38626 L .38331 .38279 L p F P
0 g
s
.701 .35 .377 r
.38331 .38279 m .37958 .38241 L .37827 .38549 L p F P
0 g
s
0 0 .225 r
.75224 .29892 m .74944 .30291 L .75082 .29805 L p F P
0 g
s
0 0 .225 r
.75082 .29805 m .75257 .29556 L .75224 .29892 L p F P
0 g
s
.744 .368 .34 r
.34997 .37761 m .3575 .3792 L .35525 .37569 L p F P
0 g
s
.744 .368 .34 r
.34951 .37682 m .34997 .37761 L p .35525 .37569 L F P
0 g
s
.744 .368 .34 r
.35525 .37569 m .35086 .37475 L .34951 .37682 L p F P
0 g
s
.569 .879 .591 r
.70887 .35844 m .70568 .36149 L .70804 .35909 L closepath p F P
0 g
s
.589 .908 .656 r
.69886 .36767 m .69777 .36862 L .69859 .36784 L closepath p F P
0 g
s
.626 .94 .718 r
.69667 .36869 m .69859 .36784 L .69777 .36862 L p F P
0 g
s
.626 .94 .718 r
.6953 .36984 m .69667 .36869 L p .69777 .36862 L F P
0 g
s
.611 .918 .659 r
.70568 .36149 m .69886 .36767 L .69859 .36784 L p F P
0 g
s
.802 .976 .903 r
.63817 .2595 m .63408 .26269 L .63676 .2592 L closepath p F P
0 g
s
.778 .991 .887 r
.63577 .259 m .63676 .2592 L .63408 .26269 L p F P
0 g
s
.778 .991 .887 r
.62909 .26447 m .63577 .259 L p .63408 .26269 L F P
0 g
s
.778 .991 .887 r
.62681 .26728 m .62909 .26447 L p .63408 .26269 L F P
0 g
s
.64 .942 .96 r
.60059 .42497 m .60038 .42507 L .60057 .42496 L closepath p F P
0 g
s
.65 .935 .968 r
.59809 .42427 m .60057 .42496 L .60038 .42507 L p F P
0 g
s
.65 .935 .968 r
.58794 .42885 m .59809 .42427 L p .60038 .42507 L F P
0 g
s
.611 .918 .659 r
.70674 .35984 m .70804 .35909 L .70568 .36149 L p F P
0 g
s
.611 .918 .659 r
.70384 .36248 m .70674 .35984 L p .70568 .36149 L F P
0 g
s
.611 .918 .659 r
.69859 .36784 m .70384 .36248 L p .70568 .36149 L F P
0 g
s
.656 .946 .957 r
.60935 .41978 m .61074 .42007 L .60059 .42497 L p F P
0 g
s
.656 .946 .957 r
.60059 .42497 m .60057 .42496 L .60935 .41978 L p F P
0 g
s
.666 .938 .966 r
.60827 .41947 m .60935 .41978 L .60057 .42496 L p F P
0 g
s
.666 .938 .966 r
.60057 .42496 m .59809 .42427 L .60827 .41947 L p F P
0 g
s
.615 .661 .872 r
.72937 .2233 m .7349 .22217 L .73277 .22725 L p F P
0 g
s
.59 .62 .85 r
.73991 .22127 m .7349 .22217 L .73277 .22725 L p F P
0 g
s
.59 .62 .85 r
.73277 .22725 m .74236 .22599 L .73991 .22127 L p F P
0 g
s
.758 .258 .031 r
.28424 .34093 m .28156 .33769 L .2867 .3402 L p F P
0 g
s
.758 .258 .031 r
.28533 .34145 m .28424 .34093 L p .2867 .3402 L F P
0 g
s
.758 .258 .031 r
.2867 .3402 m .28788 .34155 L .28533 .34145 L p F P
0 g
s
.637 .857 .983 r
.52699 .44375 m .51693 .44707 L .51424 .44549 L p F P
0 g
s
.627 .854 .985 r
.5042 .44867 m .51424 .44549 L .51693 .44707 L p F P
0 g
s
.297 .655 .97 r
.24003 .43193 m .23858 .43089 L .23773 .43079 L closepath p F P
0 g
s
.714 .983 .795 r
.6071 .28365 m .60558 .28412 L .61095 .27959 L closepath p F P
0 g
s
.666 .961 .936 r
.63109 .40957 m .6335 .40989 L .62334 .41534 L p F P
0 g
s
.666 .961 .936 r
.62774 .41138 m .63109 .40957 L p .62334 .41534 L F P
0 g
s
.666 .961 .936 r
.62334 .41534 m .62205 .41518 L .62774 .41138 L p F P
0 g
s
.708 .17 0 r
.26487 .32634 m .262 .3232 L .26654 .32596 L p F P
0 g
s
.708 .17 0 r
.26933 .32893 m .26487 .32634 L p .26654 .32596 L F P
0 g
s
.708 .17 0 r
.26654 .32596 m .26947 .32899 L .26933 .32893 L p F P
0 g
s
.755 .355 .295 r
.33377 .37051 m .33413 .37061 L .33622 .36833 L p F P
0 g
s
.755 .355 .295 r
.33622 .36833 m .33143 .36707 L .33377 .37051 L p F P
0 g
s
.074 0 .412 r
.75868 .28257 m .75519 .28798 L .75526 .28358 L p F P
0 g
s
.074 0 .412 r
.75876 .27819 m .75868 .28257 L p .75526 .28358 L F P
0 g
s
.074 0 .412 r
.75526 .28358 m .75876 .27816 L .75876 .27819 L p F P
0 g
s
.631 .767 .945 r
.39947 .45183 m .38964 .45429 L .38674 .45191 L p F P
0 g
s
.222 .609 .952 r
.2106 .42111 m .2147 .42188 L .2194 .42448 L p F P
0 g
s
.233 .611 .954 r
.2147 .42188 m .2106 .42111 L .2074 .41875 L p F P
0 g
s
0 .284 .771 r
.20355 .27552 m .20267 .27495 L .19952 .27162 L p F P
0 g
s
.707 .356 .38 r
.37649 .38529 m .37827 .38549 L .37958 .38241 L p F P
0 g
s
.707 .356 .38 r
.37958 .38241 m .37415 .3818 L .37649 .38529 L p F P
0 g
s
.451 .733 .987 r
.28238 .44302 m .28815 .44281 L .2941 .44492 L p F P
0 g
s
.464 .737 .987 r
.28815 .44281 m .28238 .44302 L .27929 .44085 L p F P
0 g
s
0 0 0 r
.74182 .31876 m .73758 .32435 L .74076 .31885 L p F P
0 g
s
0 0 0 r
.7442 .31468 m .74182 .31876 L p .74076 .31885 L F P
0 g
s
0 0 0 r
.74076 .31885 m .74445 .31402 L .7442 .31468 L p F P
0 g
s
.794 .976 .908 r
.64462 .2546 m .63817 .2595 L .63676 .2592 L p F P
0 g
s
0 0 0 r
.55533 .32483 m .55386 .32585 L .55514 .32508 L closepath p F P
0 g
s
.005 0 0 r
.55357 .32733 m .55514 .32508 L .55386 .32585 L p F P
0 g
s
.005 0 0 r
.54483 .33262 m .55357 .32733 L p .55386 .32585 L F P
0 g
s
.155 .564 .93 r
.19509 .41419 m .1981 .41494 L .20257 .41764 L p F P
0 g
s
.185 .58 .939 r
.20419 .41633 m .1981 .41494 L .20257 .41764 L p F P
0 g
s
.185 .58 .939 r
.20257 .41764 m .2074 .41875 L .20419 .41633 L p F P
0 g
s
.372 .698 .983 r
.2542 .43608 m .25844 .43626 L .26388 .43857 L p F P
0 g
s
.383 .701 .984 r
.25844 .43626 m .2542 .43608 L .25107 .43388 L p F P
0 g
s
.192 0 .056 r
.53266 .34296 m .53292 .34246 L .52365 .347 L p F P
0 g
s
.192 0 .056 r
.52365 .347 m .5226 .34905 L .53266 .34296 L p F P
0 g
s
.1 0 0 r
.54273 .33606 m .54335 .33502 L .53434 .33994 L p F P
0 g
s
.1 0 0 r
.53505 .34129 m .54273 .33606 L p .53434 .33994 L F P
0 g
s
.1 0 0 r
.53434 .33994 m .53292 .34246 L .53505 .34129 L p F P
0 g
s
.008 .455 .868 r
.16425 .39806 m .16854 .39974 L .17259 .40263 L p F P
0 g
s
.021 .458 .873 r
.16854 .39974 m .16425 .39806 L .161 .39541 L p F P
0 g
s
0 .116 .605 r
.21779 .28678 m .21836 .28725 L .22187 .29046 L p F P
0 g
s
0 .106 .594 r
.22179 .29009 m .22534 .29329 L .22187 .29046 L p F P
0 g
s
0 .106 .594 r
.22187 .29046 m .21836 .28725 L .22179 .29009 L p F P
0 g
s
.619 .819 .977 r
.4664 .45239 m .46599 .45211 L .46327 .45286 L closepath p F P
0 g
s
.622 .81 .972 r
.46322 .44995 m .46599 .45211 L .46327 .45286 L p F P
0 g
s
.622 .81 .972 r
.45326 .4528 m .46322 .44995 L p .46327 .45286 L F P
0 g
s
.505 .16 .315 r
.47767 .37587 m .47868 .37266 L .46784 .37517 L p F P
0 g
s
.505 .16 .315 r
.46955 .3777 m .47767 .37587 L p .46784 .37517 L F P
0 g
s
.505 .16 .315 r
.46784 .37517 m .46701 .37763 L .46955 .3777 L p F P
0 g
s
.538 .762 .98 r
.33316 .44853 m .33592 .4506 L p .32327 .44967 L F P
0 g
s
.538 .762 .98 r
.32327 .44967 m .33262 .44839 L .33316 .44853 L p F P
0 g
s
.558 .76 .972 r
.33262 .44839 m .32327 .44967 L .32025 .44746 L p F P
0 g
s
.797 .36 .208 r
.30475 .3551 m .31041 .3574 L .30811 .35397 L p F P
0 g
s
.797 .36 .208 r
.30315 .35254 m .30475 .3551 L p .30811 .35397 L F P
0 g
s
.797 .36 .208 r
.30811 .35397 m .30398 .35223 L .30315 .35254 L p F P
0 g
s
.644 .911 .981 r
.57281 .43136 m .57526 .43228 L .56514 .43637 L p F P
0 g
s
.644 .911 .981 r
.56514 .43637 m .56344 .43573 L .57281 .43136 L p F P
0 g
s
0 .338 .787 r
.1457 .38582 m .1464 .38619 L .1502 .3892 L p F P
0 g
s
0 .391 .829 r
.15144 .38858 m .15522 .39159 L .1502 .3892 L p F P
0 g
s
0 .391 .829 r
.1502 .3892 m .1464 .38619 L .15144 .38858 L p F P
0 g
s
0 0 0 r
.56486 .31761 m .55533 .32483 L .55514 .32508 L p F P
0 g
s
.767 .343 .243 r
.32071 .36094 m .31851 .36249 L .31642 .35956 L closepath p F P
0 g
s
.484 .523 .822 r
.74546 .23237 m .74733 .23657 L .75222 .23746 L p F P
0 g
s
.248 .621 .958 r
.21979 .42273 m .2147 .42188 L .2194 .42448 L p F P
0 g
s
.248 .621 .958 r
.2194 .42448 m .22297 .42509 L .21979 .42273 L p F P
0 g
s
.083 .512 .902 r
.17963 .40654 m .18278 .40754 L .18703 .41033 L p F P
0 g
s
.118 .532 .915 r
.18864 .40925 m .18278 .40754 L .18703 .41033 L p F P
0 g
s
.118 .532 .915 r
.18703 .41033 m .19186 .41175 L .18864 .40925 L p F P
0 g
s
.385 .7 .983 r
.26361 .43641 m .25844 .43626 L .26388 .43857 L p F P
0 g
s
.385 .7 .983 r
.26388 .43857 m .26672 .43867 L .26361 .43641 L p F P
0 g
s
0 0 0 r
.55281 .32847 m .55357 .32733 L .54483 .33262 L p F P
0 g
s
0 0 0 r
.54722 .33264 m .55281 .32847 L p .54483 .33262 L F P
0 g
s
0 0 0 r
.54483 .33262 m .54335 .33502 L .54722 .33264 L p F P
0 g
s
.577 .248 .375 r
.44596 .38178 m .44404 .38206 L .44308 .3854 L p F P
0 g
s
.275 0 .128 r
.51272 .35379 m .51255 .35416 L .5161 .35232 L closepath p F P
0 g
s
.623 .781 .957 r
.40235 .45424 m .41221 .45166 L .41507 .45406 L p F P
0 g
s
.637 .768 .942 r
.41221 .45166 m .40235 .45424 L .39947 .45183 L p F P
0 g
s
.634 .846 .981 r
.51424 .44549 m .5042 .44867 L .50149 .44699 L p F P
0 g
s
.625 .844 .984 r
.49147 .45004 m .50149 .44699 L .5042 .44867 L p F P
0 g
s
.665 .957 .735 r
.69859 .36784 m .69667 .36869 L .70384 .36248 L closepath p F P
0 g
s
.45 .735 .988 r
.29586 .44552 m .29497 .44489 L .2941 .44492 L closepath p F P
0 g
s
.605 .059 0 r
.24653 .31136 m .2507 .31429 L .24745 .31132 L p F P
0 g
s
.605 .059 0 r
.24745 .31132 m .24338 .30836 L .24653 .31136 L p F P
0 g
s
.578 .778 .974 r
.35836 .4492 m .3613 .45165 L .35648 .45257 L p F P
0 g
s
.578 .778 .974 r
.3486 .45127 m .35836 .4492 L p .35648 .45257 L F P
0 g
s
.578 .778 .974 r
.35648 .45257 m .34901 .45158 L .3486 .45127 L p F P
0 g
s
.166 .567 .933 r
.1981 .41494 m .19509 .41419 L .19186 .41175 L p F P
0 g
s
0 .228 .706 r
.12728 .37196 m .12688 .37169 L .13041 .37483 L p F P
0 g
s
0 .228 .706 r
.13041 .37483 m .13056 .37493 L .12728 .37196 L p F P
0 g
s
0 0 0 r
.73679 .32538 m .73645 .32607 L .73758 .32435 L closepath p F P
0 g
s
.197 .141 .563 r
.76115 .26874 m .75832 .27373 L .75755 .26884 L p F P
0 g
s
.197 .141 .563 r
.75755 .26884 m .7598 .26486 L .76115 .26874 L p F P
0 g
s
0 0 0 r
.745 .31324 m .74445 .31402 L .7452 .31121 L p F P
0 g
s
0 0 0 r
.7452 .31121 m .74748 .30798 L .745 .31324 L p F P
0 g
s
.094 .515 .906 r
.18278 .40754 m .17963 .40654 L .17639 .40401 L p F P
0 g
s
.739 .362 .337 r
.35086 .37475 m .34951 .37682 L .34773 .3741 L closepath p F P
0 g
s
.724 .376 .389 r
.36775 .38414 m .37649 .38529 L .37415 .3818 L p F P
0 g
s
.724 .376 .389 r
.37415 .3818 m .36568 .38055 L .36775 .38414 L p F P
0 g
s
.578 .245 .37 r
.45562 .38045 m .44596 .38178 L .4515 .3842 L p F P
0 g
s
.577 .248 .375 r
.44308 .3854 m .4515 .3842 L .44596 .38178 L p F P
0 g
s
.738 .805 .905 r
.6993 .22638 m .70385 .22409 L .70147 .22125 L p F P
0 g
s
.738 .805 .905 r
.70147 .22125 m .70144 .22127 L .6993 .22638 L p F P
0 g
s
.727 .816 .92 r
.69122 .22674 m .70144 .22127 L .6993 .22638 L p F P
0 g
s
.628 .821 .975 r
.47598 .44919 m .4776 .45038 L .4664 .45239 L p F P
0 g
s
.628 .821 .975 r
.4664 .45239 m .46599 .45211 L .47598 .44919 L p F P
0 g
s
.807 .954 .913 r
.64825 .25185 m .64462 .2546 L .6469 .25134 L closepath p F P
0 g
s
.794 .976 .908 r
.64586 .25097 m .6469 .25134 L .64462 .2546 L p F P
0 g
s
.794 .976 .908 r
.6386 .25675 m .64586 .25097 L p .64462 .2546 L F P
0 g
s
.794 .976 .908 r
.63676 .2592 m .6386 .25675 L p .64462 .2546 L F P
0 g
s
.677 .966 .932 r
.63422 .40998 m .6335 .40989 L .63751 .40765 L closepath p F P
0 g
s
0 .272 .744 r
.13463 .37747 m .13056 .37493 L .12728 .37196 L p F P
0 g
s
.627 .784 .957 r
.41507 .45406 m .42496 .45139 L .42779 .45376 L p F P
0 g
s
.641 .77 .942 r
.42496 .45139 m .41507 .45406 L .41221 .45166 L p F P
0 g
s
.773 .862 .915 r
.68102 .23269 m .6801 .23327 L .68061 .23233 L closepath p F P
0 g
s
.773 .887 .927 r
.67865 .23066 m .68061 .23233 L .6801 .23327 L p F P
0 g
s
.773 .887 .927 r
.66848 .23735 m .67865 .23066 L p .6801 .23327 L F P
0 g
s
0 0 0 r
.55514 .32508 m .56362 .3194 L p .56486 .31761 L F P
0 g
s
0 0 0 r
.56288 .32035 m .56362 .3194 L .55514 .32508 L p F P
0 g
s
0 0 0 r
.55749 .32465 m .56288 .32035 L p .55514 .32508 L F P
0 g
s
0 0 0 r
.55514 .32508 m .55357 .32733 L .55749 .32465 L p F P
0 g
s
.632 .837 .979 r
.50149 .44699 m .49147 .45004 L .48874 .44824 L p F P
0 g
s
.624 .834 .981 r
.47873 .45119 m .48874 .44824 L .49147 .45004 L p F P
0 g
s
.702 .17 0 r
.25433 .31655 m .2549 .31719 L .25241 .31542 L closepath p F P
0 g
s
.36 0 .211 r
.51035 .35958 m .51151 .35665 L .50163 .36037 L p F P
0 g
s
.36 0 .211 r
.50163 .36037 m .50046 .36332 L .51035 .35958 L p F P
0 g
s
0 .023 .52 r
.11291 .35959 m .11236 .35907 L .10908 .35585 L p F P
0 g
s
0 .283 .77 r
.20434 .27473 m .20755 .2781 L .20355 .27552 L p F P
0 g
s
0 .283 .77 r
.20355 .27552 m .20035 .27215 L .20434 .27473 L p F P
0 g
s
0 .284 .771 r
.19952 .27162 m .20035 .27215 L .20355 .27552 L p F P
0 g
s
.679 .977 .887 r
.66113 .39479 m .65618 .39795 L .65409 .39803 L p F P
0 g
s
.305 0 .17 r
.5161 .35232 m .51255 .35416 L .51151 .35665 L p F P
0 g
s
.63 .789 .959 r
.42779 .45376 m .43771 .45102 L .44052 .45335 L p F P
0 g
s
.642 .775 .944 r
.43771 .45102 m .42779 .45376 L .42496 .45139 L p F P
0 g
s
.766 .861 .92 r
.68885 .22437 m .69122 .22674 L .68102 .23269 L p F P
0 g
s
.766 .861 .92 r
.68338 .22775 m .68885 .22437 L p .68102 .23269 L F P
0 g
s
.766 .861 .92 r
.68102 .23269 m .68061 .23233 L .68338 .22775 L p F P
0 g
s
.047 .479 .886 r
.17314 .4014 m .16854 .39974 L .17259 .40263 L p F P
0 g
s
.047 .479 .886 r
.17259 .40263 m .17639 .40401 L .17314 .4014 L p F P
0 g
s
.763 .996 .845 r
.61694 .27546 m .61563 .27564 L .61992 .27206 L closepath p F P
0 g
s
.798 .954 .919 r
.6559 .24625 m .64825 .25185 L .6469 .25134 L p F P
0 g
s
.274 .235 .632 r
.7628 .25957 m .7598 .26486 L .75763 .26128 L p F P
0 g
s
.274 .235 .632 r
.75763 .26128 m .76056 .25601 L .7628 .25957 L p F P
0 g
s
.725 .357 .352 r
.36516 .37979 m .36568 .38055 L .36482 .38041 L closepath p F P
0 g
s
.457 .732 .986 r
.2919 .44262 m .28815 .44281 L .2941 .44492 L p F P
0 g
s
.457 .732 .986 r
.2941 .44492 m .29497 .44489 L .2919 .44262 L p F P
0 g
s
.304 .654 .971 r
.23542 .42857 m .23283 .42827 L .23773 .43079 L p F P
0 g
s
.304 .654 .971 r
.23773 .43079 m .23858 .43089 L .23542 .42857 L p F P
0 g
s
.63 .822 .974 r
.48864 .44817 m .48874 .44824 L .47873 .45119 L p F P
0 g
s
.63 .822 .974 r
.47873 .45119 m .4776 .45038 L .48864 .44817 L p F P
0 g
s
.802 .344 .15 r
.29155 .3469 m .29687 .34934 L .29442 .34599 L p F P
0 g
s
.802 .344 .15 r
.29442 .34599 m .28925 .34349 L .29155 .3469 L p F P
0 g
s
.643 .781 .948 r
.45046 .45055 m .44052 .45335 L .43771 .45102 L p F P
0 g
s
.778 .275 0 r
.26947 .32899 m .26953 .32906 L .2741 .3318 L p F P
0 g
s
.792 .298 .018 r
.27196 .33238 m .27665 .33508 L .2741 .3318 L p F P
0 g
s
.792 .298 .018 r
.2741 .3318 m .26953 .32906 L .27196 .33238 L p F P
0 g
s
.566 .767 .973 r
.33592 .4506 m .34054 .4498 L .34798 .45137 L p F P
0 g
s
.562 .774 .978 r
.33592 .4506 m .34054 .4498 L .33316 .44853 L closepath p F P
0 g
s
0 .122 .598 r
.22891 .29609 m .23265 .29921 L .22902 .29643 L p F P
0 g
s
0 .122 .598 r
.22902 .29643 m .22534 .29329 L .22891 .29609 L p F P
0 g
s
.655 .315 .384 r
.40607 .38638 m .4069 .38725 L .40577 .38724 L closepath p F P
0 g
s
0 0 0 r
.56538 .31723 m .56486 .31761 L .5653 .31733 L closepath p F P
0 g
s
0 0 0 r
.56362 .3194 m .5653 .31733 L .56486 .31761 L p F P
0 g
s
.773 .377 .304 r
.32703 .36863 m .33377 .37051 L .33143 .36707 L p F P
0 g
s
.773 .377 .304 r
.33143 .36707 m .3249 .3651 L .32703 .36863 L p F P
0 g
s
.642 .79 .953 r
.46322 .44995 m .45326 .4528 L .45046 .45055 L p F P
0 g
s
.604 .272 .38 r
.43154 .38499 m .43357 .38629 L .43108 .38652 L closepath p F P
0 g
s
.641 .8 .959 r
.47598 .44919 m .46599 .45211 L .46322 .44995 L p F P
0 g
s
.739 .362 .338 r
.34256 .37597 m .34049 .37241 L .34773 .3741 L p F P
0 g
s
.739 .362 .338 r
.34913 .37741 m .34256 .37597 L p .34773 .3741 L F P
0 g
s
.739 .362 .338 r
.34773 .3741 m .34951 .37682 L .34913 .37741 L p F P
0 g
s
0 0 0 r
.57479 .30976 m .56538 .31723 L .5653 .31733 L p F P
0 g
s
.799 .325 .1 r
.28788 .34155 m .28925 .34349 L .28533 .34145 L closepath p F P
0 g
s
.66 .696 .872 r
.71656 .22286 m .72697 .2194 L .72937 .2233 L p F P
0 g
s
.674 .714 .878 r
.72697 .2194 m .71656 .22286 L .71417 .21954 L p F P
0 g
s
.7 .747 .888 r
.70385 .22409 m .71417 .21954 L .71656 .22286 L p F P
0 g
s
.555 .77 .978 r
.34901 .45158 m .3486 .45127 L .34798 .45137 L closepath p F P
0 g
s
0 0 0 r
.5653 .31733 m .5735 .31124 L p .57479 .30976 L F P
0 g
s
0 0 0 r
.57295 .31183 m .5735 .31124 L .5653 .31733 L p F P
0 g
s
0 0 0 r
.56678 .31701 m .57295 .31183 L p .5653 .31733 L F P
0 g
s
0 0 0 r
.5653 .31733 m .56362 .3194 L .56678 .31701 L p F P
0 g
s
0 0 0 r
.73807 .32447 m .74182 .31876 L .73758 .32435 L p F P
0 g
s
0 0 0 r
.73565 .32768 m .73807 .32447 L p .73758 .32435 L F P
0 g
s
0 0 0 r
.73758 .32435 m .73645 .32607 L .73565 .32768 L p F P
0 g
s
.647 .892 .984 r
.56256 .43535 m .55244 .4392 L .54983 .43797 L p F P
0 g
s
.636 .889 .986 r
.53972 .44164 m .54983 .43797 L .55244 .4392 L p F P
0 g
s
.51 .747 .981 r
.30455 .44404 m .29497 .44489 L .2919 .44262 L p F P
0 g
s
.734 .212 0 r
.25344 .31746 m .25764 .32037 L .2549 .31719 L p F P
0 g
s
.734 .212 0 r
.25115 .31471 m .25344 .31746 L p .2549 .31719 L F P
0 g
s
.734 .212 0 r
.2549 .31719 m .25241 .31542 L .25115 .31471 L p F P
0 g
s
0 .116 .615 r
.11304 .35922 m .11636 .36247 L .11291 .35959 L p F P
0 g
s
0 .116 .615 r
.11291 .35959 m .10958 .35634 L .11304 .35922 L p F P
0 g
s
0 .023 .52 r
.10908 .35585 m .10958 .35634 L .11291 .35959 L p F P
0 g
s
.417 .063 .255 r
.49982 .36509 m .50046 .36332 L .49027 .36664 L p F P
0 g
s
.417 .063 .255 r
.49027 .36664 m .48979 .36794 L .49982 .36509 L p F P
0 g
s
.359 .678 .978 r
.24767 .43159 m .23858 .43089 L .23542 .42857 L p F P
0 g
s
.769 .343 .238 r
.31265 .36086 m .31041 .3574 L .31642 .35956 L p F P
0 g
s
.769 .343 .238 r
.31815 .36273 m .31265 .36086 L p .31642 .35956 L F P
0 g
s
.769 .343 .238 r
.31642 .35956 m .31851 .36249 L .31815 .36273 L p F P
0 g
s
.532 .561 .83 r
.74483 .23102 m .74605 .23107 L .74546 .23237 L closepath p F P
0 g
s
.484 .523 .822 r
.75495 .2322 m .74605 .23107 L .74546 .23237 L p F P
0 g
s
.484 .523 .822 r
.75222 .23746 m .75495 .2322 L p .74546 .23237 L F P
0 g
s
.638 .87 .985 r
.53708 .44027 m .53807 .44081 L .5281 .44435 L p F P
0 g
s
.638 .87 .985 r
.5281 .44435 m .52699 .44375 L .53708 .44027 L p F P
0 g
s
.768 .863 .92 r
.68061 .23233 m .67865 .23066 L .68338 .22775 L closepath p F P
0 g
s
.656 .932 .97 r
.59604 .42366 m .59809 .42427 L .58794 .42885 L p F P
0 g
s
.656 .932 .97 r
.58794 .42885 m .58706 .42859 L .59604 .42366 L p F P
0 g
s
.561 .761 .972 r
.34564 .44888 m .34054 .4498 L .34798 .45137 L p F P
0 g
s
.561 .761 .972 r
.34798 .45137 m .3486 .45127 L .34564 .44888 L p F P
0 g
s
.665 .974 .86 r
.66632 .39135 m .66113 .39479 L .66522 .39148 L closepath p F P
0 g
s
.679 .977 .887 r
.664 .39149 m .66522 .39148 L .66113 .39479 L p F P
0 g
s
.679 .977 .887 r
.65505 .39726 m .664 .39149 L p .66113 .39479 L F P
0 g
s
.679 .977 .887 r
.65409 .39803 m .65505 .39726 L p .66113 .39479 L F P
0 g
s
0 0 .103 r
.75134 .30248 m .74748 .30798 L .74944 .30291 L p F P
0 g
s
0 0 .103 r
.75183 .30122 m .75134 .30248 L p .74944 .30291 L F P
0 g
s
0 0 .103 r
.74944 .30291 m .75224 .29892 L .75183 .30122 L p F P
0 g
s
.548 .814 .45 r
.72743 .33822 m .72667 .33913 L .72918 .33607 L closepath p F P
0 g
s
.712 .762 .892 r
.71417 .21954 m .70385 .22409 L .70147 .22125 L p F P
0 g
s
.28 0 .129 r
.5226 .34905 m .5161 .35232 L .52231 .34967 L closepath p F P
0 g
s
.305 0 .17 r
.52111 .35251 m .52231 .34967 L .5161 .35232 L p F P
0 g
s
.305 0 .17 r
.51151 .35665 m .52111 .35251 L p .5161 .35232 L F P
0 g
s
0 .3 .764 r
.13905 .38005 m .13463 .37747 L .13825 .38056 L p F P
0 g
s
0 .3 .764 r
.14017 .38102 m .13905 .38005 L p .13825 .38056 L F P
0 g
s
0 .3 .764 r
.13825 .38056 m .14243 .38301 L .14017 .38102 L p F P
0 g
s
.731 .378 .381 r
.36342 .38342 m .36775 .38414 L .36568 .38055 L p F P
0 g
s
.731 .378 .381 r
.36568 .38055 m .36482 .38041 L .36342 .38342 L p F P
0 g
s
.568 .036 0 r
.23604 .30193 m .23643 .30231 L .23394 .30023 L closepath p F P
0 g
s
.63 .293 .382 r
.41878 .38675 m .41923 .38712 L .41866 .38715 L closepath p F P
0 g
s
.805 .928 .916 r
.65835 .24445 m .6559 .24625 L .65737 .24393 L closepath p F P
0 g
s
.798 .954 .919 r
.65597 .24321 m .65737 .24393 L .6559 .24625 L p F P
0 g
s
.798 .954 .919 r
.64866 .24883 m .65597 .24321 L p .6559 .24625 L F P
0 g
s
.798 .954 .919 r
.6469 .25134 m .64866 .24883 L p .6559 .24625 L F P
0 g
s
.775 .324 .177 r
.30398 .35223 m .30315 .35254 L .3025 .35166 L closepath p F P
0 g
s
0 0 0 r
.73645 .32607 m .73368 .33011 L .73565 .32768 L closepath p F P
0 g
s
.55 .219 .36 r
.46589 .38172 m .46679 .37835 L .45562 .38045 L p F P
0 g
s
.55 .219 .36 r
.45562 .38045 m .45465 .38376 L .46589 .38172 L p F P
0 g
s
.578 .245 .37 r
.4515 .3842 m .45465 .38376 L .45562 .38045 L p F P
0 g
s
0 .422 .851 r
.15773 .39269 m .15522 .39159 L .15907 .39457 L p F P
0 g
s
0 .422 .851 r
.15907 .39457 m .161 .39541 L .15773 .39269 L p F P
0 g
s
0 0 0 r
.57543 .30926 m .57479 .30976 L .57531 .30938 L closepath p F P
0 g
s
0 0 0 r
.5735 .31124 m .57531 .30938 L .57479 .30976 L p F P
0 g
s
.731 .378 .381 r
.35956 .38279 m .36342 .38342 L .36482 .38041 L p F P
0 g
s
.731 .378 .381 r
.36482 .38041 m .3575 .3792 L .35956 .38279 L p F P
0 g
s
.61 .762 .952 r
.35836 .4492 m .3486 .45127 L .34564 .44888 L p F P
0 g
s
0 0 0 r
.58414 .30211 m .57543 .30926 L .57531 .30938 L p F P
0 g
s
0 0 .208 r
.75321 .29744 m .75224 .29892 L .75257 .29556 L p F P
0 g
s
0 0 .208 r
.75257 .29556 m .75449 .2926 L .75321 .29744 L p F P
0 g
s
.792 .993 .879 r
.62681 .26728 m .6257 .26724 L .62909 .26447 L closepath p F P
0 g
s
0 .304 .782 r
.21148 .28051 m .20755 .2781 L .21087 .28141 L p F P
0 g
s
0 .304 .782 r
.21087 .28141 m .21463 .28371 L .21148 .28051 L p F P
0 g
s
.427 .718 .985 r
.27631 .4387 m .27929 .44085 L p .26672 .43867 L F P
0 g
s
.427 .718 .985 r
.26672 .43867 m .2761 .43862 L .27631 .4387 L p F P
0 g
s
.442 .719 .983 r
.2761 .43862 m .26672 .43867 L .26361 .43641 L p F P
0 g
s
.654 .939 .682 r
.70804 .35909 m .70674 .35984 L .71139 .35546 L closepath p F P
0 g
s
.547 .58 .839 r
.74605 .23107 m .74483 .23102 L .74236 .22599 L p F P
0 g
s
.794 .928 .923 r
.66829 .23749 m .65835 .24445 L .65737 .24393 L p F P
0 g
s
.628 .658 .86 r
.7349 .22217 m .72937 .2233 L .72697 .2194 L p F P
0 g
s
.682 .965 .934 r
.63751 .40765 m .6335 .40989 L .63109 .40957 L p F P
0 g
s
.659 .338 .418 r
.41866 .38715 m .4069 .38725 L .40953 .39067 L p F P
0 g
s
.664 .339 .413 r
.40479 .39065 m .40953 .39067 L .4069 .38725 L p F P
0 g
s
.664 .339 .413 r
.4069 .38725 m .40577 .38724 L .40479 .39065 L p F P
0 g
s
.679 .354 .418 r
.39819 .39044 m .40479 .39065 L .40577 .38724 L p F P
0 g
s
.679 .354 .418 r
.40577 .38724 m .39585 .38692 L .39819 .39044 L p F P
0 g
s
.782 .291 .044 r
.27919 .33837 m .28424 .34093 L .28156 .33769 L p F P
0 g
s
.782 .291 .044 r
.28156 .33769 m .27665 .33508 L .27919 .33837 L p F P
0 g
s
.64 .319 .412 r
.41923 .38712 m .41866 .38715 L .41773 .3906 L p F P
0 g
s
.659 .338 .418 r
.40953 .39067 m .41773 .3906 L .41866 .38715 L p F P
0 g
s
0 0 0 r
.57531 .30938 m .58322 .30285 L p .58414 .30211 L F P
0 g
s
0 0 0 r
.58301 .30303 m .58322 .30285 L .57531 .30938 L p F P
0 g
s
0 0 0 r
.57551 .30957 m .58301 .30303 L p .57531 .30938 L F P
0 g
s
0 0 0 r
.57531 .30938 m .5735 .31124 L .57551 .30957 L p F P
0 g
s
.615 .086 0 r
.23565 .30225 m .23945 .30533 L .23643 .30231 L p F P
0 g
s
.615 .086 0 r
.23288 .2994 m .23565 .30225 L p .23643 .30231 L F P
0 g
s
0 .101 .562 r
.23394 .30023 m .23288 .2994 L .23265 .29921 L closepath p F P
0 g
s
.615 .086 0 r
.23643 .30231 m .23394 .30023 L .23288 .2994 L p F P
0 g
s
.638 .319 .415 r
.43108 .38652 m .41923 .38712 L .42231 .39039 L p F P
0 g
s
.64 .319 .412 r
.41773 .3906 m .42231 .39039 L .41923 .38712 L p F P
0 g
s
.154 .067 .497 r
.75814 .27402 m .75832 .27373 L .75876 .27812 L closepath p F P
0 g
s
.668 .95 .954 r
.61845 .41443 m .62091 .41496 L .61074 .42007 L p F P
0 g
s
.668 .95 .954 r
.61538 .41598 m .61845 .41443 L p .61074 .42007 L F P
0 g
s
.668 .95 .954 r
.61074 .42007 m .60935 .41978 L .61538 .41598 L p F P
0 g
s
.354 .333 .696 r
.76225 .25297 m .76056 .25601 L .75734 .25281 L p F P
0 g
s
.354 .333 .696 r
.761 .24818 m .76225 .25297 L p .75734 .25281 L F P
0 g
s
.354 .333 .696 r
.75734 .25281 m .76026 .24752 L .761 .24818 L p F P
0 g
s
.777 .322 .167 r
.29929 .35272 m .29687 .34934 L .3025 .35166 L p F P
0 g
s
.777 .322 .167 r
.30074 .3533 m .29929 .35272 L p .3025 .35166 L F P
0 g
s
.777 .322 .167 r
.3025 .35166 m .30315 .35254 L .30074 .3533 L p F P
0 g
s
.68 .979 .859 r
.67428 .38588 m .66632 .39135 L .66522 .39148 L p F P
0 g
s
0 0 .311 r
.75794 .28721 m .75449 .2926 L .75519 .28798 L p F P
0 g
s
0 0 .311 r
.75519 .28798 m .75868 .28257 L .75794 .28721 L p F P
0 g
s
.462 .825 .565 r
.58547 .30102 m .58414 .30211 L .58519 .30124 L closepath p F P
0 g
s
0 0 0 r
.58322 .30285 m .58519 .30124 L .58414 .30211 L p F P
0 g
s
0 .122 .618 r
.21836 .28725 m .21779 .28678 L .21463 .28371 L p F P
0 g
s
.686 .355 .41 r
.39129 .39008 m .39819 .39044 L .39585 .38692 L p F P
0 g
s
.686 .355 .41 r
.39585 .38692 m .39235 .38674 L .39129 .39008 L p F P
0 g
s
.678 .955 .95 r
.62205 .41518 m .62091 .41496 L .62774 .41138 L closepath p F P
0 g
s
0 .16 .652 r
.12003 .3653 m .12342 .36851 L .11976 .36569 L p F P
0 g
s
0 .16 .652 r
.11976 .36569 m .11636 .36247 L .12003 .3653 L p F P
0 g
s
.642 .881 .985 r
.54783 .43697 m .54983 .43797 L .53972 .44164 L p F P
0 g
s
.642 .881 .985 r
.53972 .44164 m .53807 .44081 L .54783 .43697 L p F P
0 g
s
0 .343 .795 r
.1464 .38619 m .1457 .38582 L .14243 .38301 L p F P
0 g
s
.484 .837 .572 r
.59318 .29457 m .58547 .30102 L .58519 .30124 L p F P
0 g
s
.066 .006 .471 r
.76176 .2729 m .76115 .26874 L .75832 .27373 L p F P
0 g
s
.066 .006 .471 r
.75876 .27816 m .76176 .2729 L p .75832 .27373 L F P
0 g
s
.066 .006 .471 r
.75832 .27373 m .75876 .27812 L .75876 .27816 L p F P
0 g
s
.733 .207 0 r
.26039 .32355 m .26487 .32634 L .262 .3232 L p F P
0 g
s
.733 .207 0 r
.262 .3232 m .25764 .32037 L .26039 .32355 L p F P
0 g
s
.626 .76 .943 r
.37109 .44934 m .3613 .45165 L .35836 .4492 L p F P
0 g
s
.476 .138 .313 r
.48821 .37296 m .48919 .36973 L .47868 .37266 L p F P
0 g
s
.476 .138 .313 r
.47868 .37266 m .47767 .37587 L .48821 .37296 L p F P
0 g
s
.383 .701 .984 r
.25107 .43388 m .25302 .43394 L .25844 .43626 L p F P
0 g
s
.397 .701 .983 r
.26049 .4341 m .25302 .43394 L .25844 .43626 L p F P
0 g
s
.397 .701 .983 r
.25844 .43626 m .26361 .43641 L .26049 .4341 L p F P
0 g
s
.638 .817 .969 r
.486 .44614 m .48864 .44817 L .4776 .45038 L p F P
0 g
s
.638 .817 .969 r
.4776 .45038 m .47598 .44919 L .486 .44614 L p F P
0 g
s
.696 .366 .413 r
.38792 .38983 m .39129 .39008 L .39235 .38674 L p F P
0 g
s
.696 .366 .413 r
.39235 .38674 m .38576 .38626 L .38792 .38983 L p F P
0 g
s
0 0 0 r
.73379 .33036 m .72918 .33607 L .73368 .33011 L p F P
0 g
s
0 0 0 r
.73452 .32939 m .73379 .33036 L p .73368 .33011 L F P
0 g
s
0 0 0 r
.73368 .33011 m .73565 .32768 L .73452 .32939 L p F P
0 g
s
.166 .567 .933 r
.19186 .41175 m .19369 .4122 L .1981 .41494 L p F P
0 g
s
.195 .581 .941 r
.20098 .41385 m .19369 .4122 L .1981 .41494 L p F P
0 g
s
.195 .581 .941 r
.1981 .41494 m .20419 .41633 L .20098 .41385 L p F P
0 g
s
.294 .648 .968 r
.22297 .42509 m .22798 .42573 L .23283 .42827 L p F P
0 g
s
.304 .65 .969 r
.22798 .42573 m .22297 .42509 L .21979 .42273 L p F P
0 g
s
.525 .756 .981 r
.30759 .44631 m .31723 .44516 L .32025 .44746 L p F P
0 g
s
.543 .752 .973 r
.31723 .44516 m .30759 .44631 L .30455 .44404 L p F P
0 g
s
.524 .553 .827 r
.75531 .2315 m .75495 .2322 L .74605 .23107 L p F P
0 g
s
.524 .553 .827 r
.7531 .22626 m .75531 .2315 L p .74605 .23107 L F P
0 g
s
.524 .553 .827 r
.74605 .23107 m .74834 .22595 L .7531 .22626 L p F P
0 g
s
.547 .58 .839 r
.74236 .22599 m .74834 .22595 L .74605 .23107 L p F P
0 g
s
.772 .392 .335 r
.33568 .37413 m .34256 .37597 L .34049 .37241 L p F P
0 g
s
.772 .392 .335 r
.33396 .37083 m .33568 .37413 L p .34049 .37241 L F P
0 g
s
.772 .392 .335 r
.34049 .37241 m .33413 .37061 L .33396 .37083 L p F P
0 g
s
.233 .611 .954 r
.2074 .41875 m .21007 .41924 L .2147 .42188 L p F P
0 g
s
.257 .622 .959 r
.2166 .42031 m .21007 .41924 L .2147 .42188 L p F P
0 g
s
.257 .622 .959 r
.2147 .42188 m .21979 .42273 L .2166 .42031 L p F P
0 g
s
.614 .296 .408 r
.43357 .38629 m .43108 .38652 L .43019 .38999 L p F P
0 g
s
.638 .319 .415 r
.42231 .39039 m .43019 .38999 L .43108 .38652 L p F P
0 g
s
.582 .911 .674 r
.59552 .29261 m .59318 .29457 L .59496 .29294 L closepath p F P
0 g
s
.484 .837 .572 r
.59308 .2941 m .59496 .29294 L .59318 .29457 L p F P
0 g
s
.484 .837 .572 r
.59205 .29501 m .59308 .2941 L p .59318 .29457 L F P
0 g
s
.484 .837 .572 r
.58519 .30124 m .59205 .29501 L p .59318 .29457 L F P
0 g
s
.806 .978 .899 r
.63676 .2592 m .63577 .259 L .6386 .25675 L closepath p F P
0 g
s
.671 .969 .917 r
.64366 .4041 m .63751 .40765 L .64253 .40403 L closepath p F P
0 g
s
.682 .965 .934 r
.64127 .40385 m .64253 .40403 L .63751 .40765 L p F P
0 g
s
.682 .965 .934 r
.63109 .40957 m .64127 .40385 L p .63751 .40765 L F P
0 g
s
.74 .83 .92 r
.70144 .22127 m .69122 .22674 L .68885 .22437 L p F P
0 g
s
.593 .916 .677 r
.60207 .28707 m .59552 .29261 L .59496 .29294 L p F P
0 g
s
.094 .515 .906 r
.17639 .40401 m .1786 .4047 L .18278 .40754 L p F P
0 g
s
.128 .534 .918 r
.18515 .40661 m .1786 .4047 L .18278 .40754 L p F P
0 g
s
.128 .534 .918 r
.1863 .4074 m .18515 .40661 L p .18278 .40754 L F P
0 g
s
.128 .534 .918 r
.18278 .40754 m .18864 .40925 L .1863 .4074 L p F P
0 g
s
.792 .397 .306 r
.32075 .36656 m .32703 .36863 L .3249 .3651 L p F P
0 g
s
.792 .397 .306 r
.3249 .3651 m .3188 .36298 L .32075 .36656 L p F P
0 g
s
.614 .296 .407 r
.44308 .3854 m .43357 .38629 L .43736 .38932 L p F P
0 g
s
.614 .296 .408 r
.43019 .38999 m .43736 .38932 L .43357 .38629 L p F P
0 g
s
.622 .768 .95 r
.37402 .45185 m .38384 .44934 L .38674 .45191 L p F P
0 g
s
.638 .757 .934 r
.38384 .44934 m .37402 .45185 L .37109 .44934 L p F P
0 g
s
.752 .399 .385 r
.35181 .38127 m .35956 .38279 L .3575 .3792 L p F P
0 g
s
.752 .399 .385 r
.3575 .3792 m .34997 .37761 L .35181 .38127 L p F P
0 g
s
.509 .173 .333 r
.46701 .37763 m .46955 .3777 L .46679 .37835 L closepath p F P
0 g
s
.708 .371 .405 r
.37849 .38892 m .38792 .38983 L .38576 .38626 L p F P
0 g
s
.708 .371 .405 r
.37762 .3873 m .37849 .38892 L p .38576 .38626 L F P
0 g
s
.708 .371 .405 r
.38576 .38626 m .37827 .38549 L .37762 .3873 L p F P
0 g
s
0 .122 .618 r
.21463 .28371 m .21496 .28398 L .21836 .28725 L p F P
0 g
s
0 .109 .605 r
.21835 .28683 m .22179 .29009 L .21836 .28725 L p F P
0 g
s
0 .109 .605 r
.21836 .28725 m .21496 .28398 L .21835 .28683 L p F P
0 g
s
.464 .737 .987 r
.27929 .44085 m .28216 .44071 L .28815 .44281 L p F P
0 g
s
.47 .733 .984 r
.28883 .4403 m .28216 .44071 L .28815 .44281 L p F P
0 g
s
.47 .733 .984 r
.28815 .44281 m .2919 .44262 L .28883 .4403 L p F P
0 g
s
.402 .392 .734 r
.76063 .24684 m .76026 .24752 L .7557 .24481 L p F P
0 g
s
.402 .392 .734 r
.7557 .24481 m .7584 .23981 L .76063 .24684 L p F P
0 g
s
.652 .902 .982 r
.5727 .43132 m .57281 .43136 L .56344 .43573 L p F P
0 g
s
.652 .902 .982 r
.56344 .43573 m .56256 .43535 L .5727 .43132 L p F P
0 g
s
0 .343 .795 r
.14243 .38301 m .14268 .38315 L .1464 .38619 L p F P
0 g
s
0 .398 .837 r
.14773 .38552 m .15144 .38858 L .1464 .38619 L p F P
0 g
s
0 .398 .837 r
.1464 .38619 m .14268 .38315 L .14773 .38552 L p F P
0 g
s
.574 .772 .973 r
.34266 .44637 m .34564 .44888 L .34054 .4498 L p F P
0 g
s
.574 .772 .973 r
.33293 .44835 m .34266 .44637 L p .34054 .4498 L F P
0 g
s
.574 .772 .973 r
.34054 .4498 m .33316 .44853 L .33293 .44835 L p F P
0 g
s
.664 .923 .975 r
.59558 .4235 m .59604 .42366 L .58706 .42859 L p F P
0 g
s
.664 .923 .975 r
.58706 .42859 m .58541 .42799 L .59558 .4235 L p F P
0 g
s
.606 .066 0 r
.24252 .30836 m .24653 .31136 L .24338 .30836 L p F P
0 g
s
.606 .066 0 r
.24338 .30836 m .23945 .30533 L .24252 .30836 L p F P
0 g
s
.629 .077 0 r
.25241 .31542 m .25115 .31471 L .2507 .31429 L closepath p F P
0 g
s
.655 .916 .978 r
.58287 .42702 m .58541 .42799 L .57526 .43228 L p F P
0 g
s
.655 .916 .978 r
.57377 .43087 m .58287 .42702 L p .57526 .43228 L F P
0 g
s
.655 .916 .978 r
.57526 .43228 m .57281 .43136 L .57377 .43087 L p F P
0 g
s
.43 .087 .281 r
.49939 .3664 m .49982 .36509 L .48979 .36794 L p F P
0 g
s
.43 .087 .281 r
.48979 .36794 m .48919 .36973 L .49939 .3664 L p F P
0 g
s
.508 .846 .568 r
.58388 .30225 m .58322 .30285 L .58519 .30124 L p F P
0 g
s
.508 .846 .568 r
.58519 .30124 m .59205 .29501 L .58388 .30225 L p F P
0 g
s
.677 .967 .762 r
.60558 .28412 m .60207 .28707 L .60464 .2845 L closepath p F P
0 g
s
.593 .916 .677 r
.60315 .28513 m .60464 .2845 L .60207 .28707 L p F P
0 g
s
.593 .916 .677 r
.60016 .28779 m .60315 .28513 L p .60207 .28707 L F P
0 g
s
.593 .916 .677 r
.59496 .29294 m .60016 .28779 L p .60207 .28707 L F P
0 g
s
.645 .859 .981 r
.53708 .44027 m .52699 .44375 L .52432 .44216 L p F P
0 g
s
.637 .857 .983 r
.51424 .44549 m .52432 .44216 L .52699 .44375 L p F P
0 g
s
.806 .369 .207 r
.30315 .35254 m .30475 .3551 L .30074 .3533 L closepath p F P
0 g
s
.228 0 .105 r
.53163 .34516 m .53266 .34296 L .5226 .34905 L p F P
0 g
s
.228 0 .105 r
.5226 .34905 m .52231 .34967 L .53163 .34516 L p F P
0 g
s
.797 .902 .916 r
.66848 .23735 m .66829 .23749 L .6684 .2373 L closepath p F P
0 g
s
.794 .928 .923 r
.6661 .23578 m .6684 .2373 L .66829 .23749 L p F P
0 g
s
.794 .928 .923 r
.65954 .2406 m .6661 .23578 L p .66829 .23749 L F P
0 g
s
.794 .928 .923 r
.65737 .24393 m .65954 .2406 L p .66829 .23749 L F P
0 g
s
.792 .902 .919 r
.67627 .22873 m .67865 .23066 L .66848 .23735 L p F P
0 g
s
.792 .902 .919 r
.67169 .23192 m .67627 .22873 L p .66848 .23735 L F P
0 g
s
.792 .902 .919 r
.66848 .23735 m .6684 .2373 L .67169 .23192 L p F P
0 g
s
.459 .464 .776 r
.75564 .23236 m .75495 .2322 L .75222 .23746 L p F P
0 g
s
.459 .464 .776 r
.75222 .23746 m .75826 .2394 L .75564 .23236 L p F P
0 g
s
.812 .352 .14 r
.28649 .34435 m .29155 .3469 L .28925 .34349 L p F P
0 g
s
.812 .352 .14 r
.28466 .34146 m .28649 .34435 L p .28925 .34349 L F P
0 g
s
.812 .352 .14 r
.28925 .34349 m .28533 .34145 L .28466 .34146 L p F P
0 g
s
.679 .967 .762 r
.61095 .27959 m .60558 .28412 L .60464 .2845 L p F P
0 g
s
.663 .972 .825 r
.67645 .38433 m .67428 .38588 L .67596 .38443 L closepath p F P
0 g
s
.68 .979 .859 r
.67417 .38459 m .67596 .38443 L .67428 .38588 L p F P
0 g
s
.68 .979 .859 r
.66927 .38798 m .67417 .38459 L p .67428 .38588 L F P
0 g
s
.68 .979 .859 r
.66522 .39148 m .66927 .38798 L p .67428 .38588 L F P
0 g
s
.313 .655 .971 r
.23225 .42619 m .22798 .42573 L .23283 .42827 L p F P
0 g
s
.313 .655 .971 r
.23283 .42827 m .23542 .42857 L .23225 .42619 L p F P
0 g
s
0 .233 .715 r
.124 .3689 m .12342 .36851 L .12688 .37169 L p F P
0 g
s
0 .233 .715 r
.12688 .37169 m .12728 .37196 L .124 .3689 L p F P
0 g
s
.793 .904 .919 r
.6684 .2373 m .6661 .23578 L .67169 .23192 L closepath p F P
0 g
s
.631 .767 .945 r
.38674 .45191 m .39659 .44923 L .39947 .45183 L p F P
0 g
s
.647 .754 .928 r
.39659 .44923 m .38674 .45191 L .38384 .44934 L p F P
0 g
s
0 0 0 r
.7488 .30777 m .745 .31324 L .74748 .30798 L p F P
0 g
s
0 0 0 r
.74748 .30798 m .75134 .30248 L .7488 .30777 L p F P
0 g
s
.243 .613 .955 r
.21007 .41924 m .2074 .41875 L .20419 .41633 L p F P
0 g
s
.021 .458 .873 r
.161 .39541 m .16458 .39681 L .16854 .39974 L p F P
0 g
s
.033 .461 .877 r
.16458 .39681 m .161 .39541 L .15773 .39269 L p F P
0 g
s
.775 .268 0 r
.26947 .32899 m .26953 .32906 L .26933 .32893 L closepath p F P
0 g
s
.808 .956 .911 r
.6469 .25134 m .64586 .25097 L .64866 .24883 L closepath p F P
0 g
s
.802 .384 .252 r
.30682 .35862 m .31265 .36086 L .31041 .3574 L p F P
0 g
s
.802 .384 .252 r
.31041 .3574 m .30475 .3551 L .30682 .35862 L p F P
0 g
s
.744 .993 .824 r
.61563 .27564 m .61095 .27959 L .61425 .27594 L closepath p F P
0 g
s
.679 .967 .762 r
.61322 .27618 m .61425 .27594 L .61095 .27959 L p F P
0 g
s
.679 .967 .762 r
.60829 .28055 m .61322 .27618 L p .61095 .27959 L F P
0 g
s
.679 .967 .762 r
.60464 .2845 m .60829 .28055 L p .61095 .27959 L F P
0 g
s
.463 .738 .987 r
.27929 .44085 m .28216 .44071 L .27631 .4387 L closepath p F P
0 g
s
.795 .301 .008 r
.26747 .3296 m .27196 .33238 L .26953 .32906 L p F P
0 g
s
.795 .301 .008 r
.26627 .32792 m .26747 .3296 L p .26953 .32906 L F P
0 g
s
.795 .301 .008 r
.26953 .32906 m .26933 .32893 L .26627 .32792 L p F P
0 g
s
.679 .977 .825 r
.68555 .3776 m .67645 .38433 L .67596 .38443 L p F P
0 g
s
.385 .7 .983 r
.25107 .43388 m .25302 .43394 L .24833 .43191 L closepath p F P
0 g
s
.058 .481 .889 r
.16989 .39873 m .16458 .39681 L .16854 .39974 L p F P
0 g
s
.058 .481 .889 r
.16854 .39974 m .17314 .4014 L .16989 .39873 L p F P
0 g
s
.552 .817 .453 r
.72873 .33654 m .73379 .33036 L .72918 .33607 L p F P
0 g
s
.552 .817 .453 r
.72591 .34006 m .72873 .33654 L p .72918 .33607 L F P
0 g
s
.552 .817 .453 r
.72918 .33607 m .72667 .33913 L .72591 .34006 L p F P
0 g
s
.737 .213 0 r
.26933 .32893 m .26627 .32792 L .26487 .32634 L closepath p F P
0 g
s
.558 .76 .972 r
.32025 .44746 m .32584 .44658 L .33262 .44839 L p F P
0 g
s
.573 .763 .968 r
.32584 .44658 m .32025 .44746 L .31723 .44516 L p F P
0 g
s
.713 .377 .407 r
.37827 .38549 m .37762 .3873 L .37649 .38529 L closepath p F P
0 g
s
.74 .992 .825 r
.61992 .27206 m .61563 .27564 L .61425 .27594 L p F P
0 g
s
.753 .38 .347 r
.34951 .37682 m .34997 .37761 L .34913 .37741 L closepath p F P
0 g
s
.652 .753 .923 r
.40935 .44903 m .39947 .45183 L .39659 .44923 L p F P
0 g
s
.637 .768 .942 r
.39947 .45183 m .40935 .44903 L .41221 .45166 L p F P
0 g
s
.642 .848 .979 r
.52432 .44216 m .51424 .44549 L .51155 .44379 L p F P
0 g
s
.634 .846 .981 r
.50149 .44699 m .51155 .44379 L .51424 .44549 L p F P
0 g
s
.524 .202 .364 r
.46955 .3777 m .46679 .37835 L .46589 .38172 L p F P
0 g
s
.803 .931 .917 r
.65737 .24393 m .65597 .24321 L .65954 .2406 L closepath p F P
0 g
s
0 .272 .744 r
.12728 .37196 m .13108 .37433 L .13463 .37747 L p F P
0 g
s
0 .277 .752 r
.13108 .37433 m .12728 .37196 L .124 .3689 L p F P
0 g
s
.586 .269 .399 r
.4515 .3842 m .44308 .3854 L .44221 .38887 L p F P
0 g
s
.614 .296 .407 r
.43736 .38932 m .44221 .38887 L .44308 .3854 L p F P
0 g
s
.177 .569 .935 r
.19369 .4122 m .19186 .41175 L .18864 .40925 L p F P
0 g
s
.71 .376 .41 r
.36957 .38783 m .36775 .38414 L .37649 .38529 L p F P
0 g
s
.71 .376 .41 r
.37711 .38876 m .36957 .38783 L p .37649 .38529 L F P
0 g
s
.71 .376 .41 r
.37649 .38529 m .37762 .3873 L .37711 .38876 L p F P
0 g
s
.106 .518 .909 r
.1786 .4047 m .17639 .40401 L .17314 .4014 L p F P
0 g
s
.786 .996 .865 r
.6257 .26724 m .61992 .27206 L .62382 .2673 L closepath p F P
0 g
s
.74 .992 .825 r
.62329 .26732 m .62382 .2673 L .61992 .27206 L p F P
0 g
s
.74 .992 .825 r
.6165 .27329 m .62329 .26732 L p .61992 .27206 L F P
0 g
s
.74 .992 .825 r
.61425 .27594 m .6165 .27329 L p .61992 .27206 L F P
0 g
s
0 .122 .608 r
.22531 .2929 m .22891 .29609 L .22534 .29329 L p F P
0 g
s
0 .122 .608 r
.22534 .29329 m .22179 .29009 L .22531 .2929 L p F P
0 g
s
.64 .916 .624 r
.71716 .34985 m .71675 .35014 L .71814 .34872 L closepath p F P
0 g
s
.687 .973 .915 r
.65147 .39783 m .65383 .39802 L .64366 .4041 L p F P
0 g
s
.687 .973 .915 r
.64745 .40025 m .65147 .39783 L p .64366 .4041 L F P
0 g
s
.687 .973 .915 r
.64366 .4041 m .64253 .40403 L .64745 .40025 L p F P
0 g
s
0 0 0 r
.72667 .33913 m .724 .34227 L .72591 .34006 L closepath p F P
0 g
s
.202 .145 .566 r
.76419 .26344 m .76115 .26874 L .7598 .26486 L p F P
0 g
s
.202 .145 .566 r
.7598 .26486 m .7628 .25957 L .76419 .26344 L p F P
0 g
s
.641 .77 .942 r
.41221 .45166 m .42212 .44878 L .42496 .45139 L p F P
0 g
s
.655 .753 .922 r
.42212 .44878 m .41221 .45166 L .40935 .44903 L p F P
0 g
s
.566 .582 .829 r
.74834 .22595 m .74236 .22599 L .73991 .22127 L p F P
0 g
s
.242 0 .134 r
.53039 .34794 m .53163 .34516 L .52231 .34967 L p F P
0 g
s
.242 0 .134 r
.52231 .34967 m .52111 .35251 L .53039 .34794 L p F P
0 g
s
.613 .063 0 r
.24797 .31274 m .24653 .31136 L .2507 .31429 L p F P
0 g
s
.613 .063 0 r
.2507 .31429 m .25115 .31471 L .24797 .31274 L p F P
0 g
s
.668 .937 .967 r
.60578 .41872 m .60827 .41947 L .59809 .42427 L p F P
0 g
s
.668 .937 .967 r
.59891 .42196 m .60578 .41872 L p .59809 .42427 L F P
0 g
s
.668 .937 .967 r
.59809 .42427 m .59604 .42366 L .59891 .42196 L p F P
0 g
s
.779 .995 .868 r
.62909 .26447 m .6257 .26724 L .62382 .2673 L p F P
0 g
s
.641 .835 .975 r
.50977 .44254 m .51155 .44379 L .50149 .44699 L p F P
0 g
s
.641 .835 .975 r
.50149 .44699 m .49932 .44551 L .50977 .44254 L p F P
0 g
s
.632 .837 .979 r
.49932 .44551 m .50149 .44699 L p .48874 .44824 L F P
0 g
s
.31 0 .187 r
.51998 .35531 m .52111 .35251 L .51151 .35665 L p F P
0 g
s
.31 0 .187 r
.51915 .35575 m .51998 .35531 L p .51151 .35665 L F P
0 g
s
.31 0 .187 r
.51151 .35665 m .51035 .35958 L .51915 .35575 L p F P
0 g
s
.617 .924 .673 r
.59496 .29294 m .59308 .2941 L .60016 .28779 L closepath p F P
0 g
s
.125 0 .015 r
.53292 .34246 m .53266 .34296 L .53505 .34129 L closepath p F P
0 g
s
.628 .658 .86 r
.73767 .21719 m .7349 .22217 L p .72697 .2194 L F P
0 g
s
.606 .642 .86 r
.7349 .22217 m .73767 .21719 L .73991 .22127 L closepath p F P
0 g
s
.642 .775 .944 r
.42496 .45139 m .43489 .44846 L .43771 .45102 L p F P
0 g
s
.655 .757 .924 r
.43489 .44846 m .42496 .45139 L .42212 .44878 L p F P
0 g
s
.547 .762 .977 r
.33316 .44853 m .33293 .44835 L .33262 .44839 L closepath p F P
0 g
s
0 0 0 r
.74445 .31402 m .7442 .31468 L .745 .31324 L closepath p F P
0 g
s
.522 .194 .352 r
.47767 .37587 m .47698 .3783 L .46955 .3777 L closepath p F P
0 g
s
.524 .202 .364 r
.47675 .37921 m .47698 .3783 L .46955 .3777 L p F P
0 g
s
.524 .202 .364 r
.46589 .38172 m .47675 .37921 L p .46955 .3777 L F P
0 g
s
.808 .984 .89 r
.63577 .259 m .62909 .26447 L .6334 .25865 L closepath p F P
0 g
s
.779 .995 .868 r
.63337 .25864 m .6334 .25865 L .62909 .26447 L p F P
0 g
s
.779 .995 .868 r
.62486 .26598 m .63337 .25864 L p .62909 .26447 L F P
0 g
s
.779 .995 .868 r
.62382 .2673 m .62486 .26598 L p .62909 .26447 L F P
0 g
s
.761 .378 .328 r
.33413 .37061 m .33396 .37083 L .33377 .37051 L closepath p F P
0 g
s
.6 .876 .554 r
.7231 .34291 m .71814 .34872 L .724 .34227 L p F P
0 g
s
.6 .876 .554 r
.72463 .34122 m .7231 .34291 L p .724 .34227 L F P
0 g
s
.6 .876 .554 r
.724 .34227 m .72591 .34006 L .72463 .34122 L p F P
0 g
s
.802 .354 .179 r
.2938 .35033 m .29929 .35272 L .29687 .34934 L p F P
0 g
s
.802 .354 .179 r
.29687 .34934 m .29155 .3469 L .2938 .35033 L p F P
0 g
s
.658 .896 .981 r
.5727 .43132 m .56256 .43535 L .55996 .43412 L p F P
0 g
s
.647 .892 .984 r
.54983 .43797 m .55996 .43412 L .56256 .43535 L p F P
0 g
s
.552 .755 .971 r
.32993 .4459 m .32584 .44658 L .33262 .44839 L p F P
0 g
s
.552 .755 .971 r
.33262 .44839 m .33293 .44835 L .32993 .4459 L p F P
0 g
s
.674 .714 .878 r
.71417 .21954 m .72456 .21569 L .72697 .2194 L p F P
0 g
s
.687 .73 .883 r
.72456 .21569 m .71417 .21954 L .71179 .21636 L p F P
0 g
s
.712 .762 .892 r
.70147 .22125 m .71179 .21636 L .71417 .21954 L p F P
0 g
s
.792 .378 .263 r
.31851 .36249 m .3188 .36298 L .31815 .36273 L closepath p F P
0 g
s
.759 .401 .376 r
.34758 .38029 m .35181 .38127 L .34997 .37761 L p F P
0 g
s
.759 .401 .376 r
.34997 .37761 m .34913 .37741 L .34758 .38029 L p F P
0 g
s
.657 .965 .784 r
.68658 .37681 m .68555 .3776 L .68633 .37689 L closepath p F P
0 g
s
.679 .977 .825 r
.68432 .37725 m .68633 .37689 L .68555 .3776 L p F P
0 g
s
.679 .977 .825 r
.68145 .37938 m .68432 .37725 L p .68555 .3776 L F P
0 g
s
.679 .977 .825 r
.67596 .38443 m .68145 .37938 L p .68555 .3776 L F P
0 g
s
.762 .378 .327 r
.32903 .37221 m .32703 .36863 L .33377 .37051 L p F P
0 g
s
.762 .378 .327 r
.3322 .37309 m .32903 .37221 L p .33377 .37051 L F P
0 g
s
.762 .378 .327 r
.33377 .37051 m .33396 .37083 L .3322 .37309 L p F P
0 g
s
.643 .781 .948 r
.43771 .45102 m .44766 .44807 L .45046 .45055 L p F P
0 g
s
.654 .763 .929 r
.44766 .44807 m .43771 .45102 L .43489 .44846 L p F P
0 g
s
.682 .954 .951 r
.62774 .41138 m .62091 .41496 L .61845 .41443 L p F P
0 g
s
.632 .837 .979 r
.48874 .44824 m .49 .44785 L .49932 .44551 L p F P
0 g
s
.64 .818 .968 r
.48874 .44824 m .49 .44785 L .48864 .44817 L closepath p F P
0 g
s
.795 .308 .045 r
.27438 .33572 m .27919 .33837 L .27665 .33508 L p F P
0 g
s
.795 .308 .045 r
.27665 .33508 m .27196 .33238 L .27438 .33572 L p F P
0 g
s
0 0 .195 r
.75662 .29206 m .75321 .29744 L .75449 .2926 L p F P
0 g
s
0 0 .195 r
.75449 .2926 m .75794 .28721 L .75662 .29206 L p F P
0 g
s
.675 .97 .785 r
.6953 .36984 m .68658 .37681 L .68633 .37689 L p F P
0 g
s
.018 0 0 r
.54335 .33502 m .54273 .33606 L .54722 .33264 L closepath p F P
0 g
s
.605 .757 .951 r
.34266 .44637 m .33293 .44835 L .32993 .4459 L p F P
0 g
s
.376 .026 .239 r
.50989 .36088 m .51035 .35958 L .50046 .36332 L p F P
0 g
s
.376 .026 .239 r
.50046 .36332 m .49982 .36509 L .50989 .36088 L p F P
0 g
s
0 .308 .774 r
.13551 .37691 m .13905 .38005 L .13463 .37747 L p F P
0 g
s
0 .308 .774 r
.13463 .37747 m .13108 .37433 L .13551 .37691 L p F P
0 g
s
0 .425 .855 r
.15447 .3899 m .15144 .38858 L .15522 .39159 L p F P
0 g
s
0 .425 .855 r
.15522 .39159 m .15773 .39269 L .15447 .3899 L p F P
0 g
s
.642 .79 .953 r
.45046 .45055 m .46044 .44758 L .46322 .44995 L p F P
0 g
s
.653 .772 .937 r
.46044 .44758 m .45046 .45055 L .44766 .44807 L p F P
0 g
s
.753 .394 .374 r
.34446 .37961 m .34758 .38029 L .34913 .37741 L p F P
0 g
s
.753 .394 .374 r
.34913 .37741 m .34256 .37597 L .34446 .37961 L p F P
0 g
s
.736 .215 0 r
.25344 .31746 m .25115 .31471 L .24797 .31274 L p F P
0 g
s
.643 .812 .964 r
.49 .44785 m .48864 .44817 L .486 .44614 L p F P
0 g
s
.648 .796 .953 r
.486 .44614 m .47598 .44919 L .47322 .44694 L p F P
0 g
s
.641 .8 .959 r
.46322 .44995 m .47322 .44694 L .47598 .44919 L p F P
0 g
s
.65 .783 .945 r
.47322 .44694 m .46322 .44995 L .46044 .44758 L p F P
0 g
s
.707 .985 .864 r
.67596 .38443 m .67417 .38459 L .68145 .37938 L closepath p F P
0 g
s
.425 .713 .984 r
.25736 .43173 m .26049 .4341 L .25302 .43394 L p F P
0 g
s
.425 .713 .984 r
.24792 .4316 m .25736 .43173 L p .25302 .43394 L F P
0 g
s
.425 .713 .984 r
.25302 .43394 m .24833 .43191 L .24792 .4316 L p F P
0 g
s
.703 .982 .89 r
.66522 .39148 m .664 .39149 L .66927 .38798 L closepath p F P
0 g
s
.677 .942 .963 r
.60935 .41978 m .60827 .41947 L .61538 .41598 L closepath p F P
0 g
s
.768 .872 .924 r
.68338 .22775 m .67865 .23066 L .67627 .22873 L p F P
0 g
s
.799 .984 .895 r
.6386 .25675 m .63577 .259 L .6334 .25865 L p F P
0 g
s
.78 .402 .34 r
.33396 .37083 m .33568 .37413 L .3322 .37309 L closepath p F P
0 g
s
.122 .043 .486 r
.75876 .27812 m .75876 .27816 L .75876 .27816 L closepath p F P
0 g
s
.628 .658 .86 r
.72697 .2194 m .73747 .21684 L .73767 .21719 L p F P
0 g
s
.643 .676 .866 r
.73747 .21684 m .72697 .2194 L .72456 .21569 L p F P
0 g
s
.031 0 .398 r
.75876 .27816 m .75876 .27819 L .75876 .27816 L closepath p F P
0 g
s
.028 0 .397 r
.76171 .27729 m .76176 .2729 L .75876 .27816 L p F P
0 g
s
.028 0 .397 r
.75891 .28219 m .76171 .27729 L p .75876 .27816 L F P
0 g
s
.028 0 .397 r
.75876 .27816 m .75876 .27819 L .75891 .28219 L p F P
0 g
s
.061 0 .408 r
.75876 .27819 m .75868 .28257 L .75891 .28219 L closepath p F P
0 g
s
0 0 0 r
.73565 .32768 m .73452 .32939 L .73807 .32447 L closepath p F P
0 g
s
0 .309 .79 r
.20832 .27718 m .20434 .27473 L .20755 .2781 L p F P
0 g
s
0 .309 .79 r
.20755 .2781 m .21148 .28051 L .20832 .27718 L p F P
0 g
s
.799 .398 .293 r
.31572 .36468 m .32075 .36656 L .3188 .36298 L p F P
0 g
s
.799 .398 .293 r
.3188 .36298 m .31815 .36273 L .31572 .36468 L p F P
0 g
s
.589 .271 .398 r
.45465 .38376 m .45417 .38568 L .4515 .3842 L closepath p F P
0 g
s
.586 .269 .399 r
.45381 .38725 m .45417 .38568 L .4515 .3842 L p F P
0 g
s
.586 .269 .399 r
.44221 .38887 m .45381 .38725 L p .4515 .3842 L F P
0 g
s
.647 .873 .983 r
.54721 .43663 m .54783 .43697 L .53807 .44081 L p F P
0 g
s
.647 .873 .983 r
.53807 .44081 m .53708 .44027 L .54721 .43663 L p F P
0 g
s
.51 .747 .981 r
.2919 .44262 m .3015 .44169 L .30455 .44404 L p F P
0 g
s
.521 .746 .977 r
.3015 .44169 m .2919 .44262 L .28883 .4403 L p F P
0 g
s
.639 .826 .973 r
.49932 .44551 m .49878 .44512 L .49 .44785 L closepath p F P
0 g
s
.643 .812 .964 r
.49605 .44296 m .49878 .44512 L .49 .44785 L p F P
0 g
s
.643 .812 .964 r
.486 .44614 m .49605 .44296 L p .49 .44785 L F P
0 g
s
.819 .979 .89 r
.6386 .25675 m .64586 .25097 L .64347 .25022 L p F P
0 g
s
.819 .979 .89 r
.64347 .25022 m .64255 .25099 L .6386 .25675 L p F P
0 g
s
.799 .984 .895 r
.63346 .25857 m .64255 .25099 L .6386 .25675 L p F P
0 g
s
.799 .984 .895 r
.6334 .25865 m .63346 .25857 L p .6386 .25675 L F P
0 g
s
0 .116 .588 r
.22972 .29673 m .22891 .29609 L .23265 .29921 L p F P
0 g
s
0 .116 .588 r
.23265 .29921 m .23288 .2994 L .22972 .29673 L p F P
0 g
s
.736 .395 .404 r
.36215 .3866 m .36957 .38783 L .36775 .38414 L p F P
0 g
s
.736 .395 .404 r
.36775 .38414 m .36342 .38342 L .36215 .3866 L p F P
0 g
s
.643 .918 .627 r
.71667 .34956 m .7231 .34291 L .71814 .34872 L p F P
0 g
s
.643 .918 .627 r
.71525 .35122 m .71667 .34956 L p .71814 .34872 L F P
0 g
s
.643 .918 .627 r
.71814 .34872 m .71675 .35014 L .71525 .35122 L p F P
0 g
s
.359 .678 .978 r
.23542 .42857 m .24272 .42908 L .24767 .43159 L p F P
0 g
s
.369 .68 .978 r
.24272 .42908 m .23542 .42857 L .23225 .42619 L p F P
0 g
s
.172 0 .071 r
.53505 .34129 m .53266 .34296 L .53163 .34516 L p F P
0 g
s
.49 .743 .984 r
.28575 .43791 m .28883 .4403 L .28216 .44071 L p F P
0 g
s
.49 .743 .984 r
.27619 .43861 m .28575 .43791 L p .28216 .44071 L F P
0 g
s
.49 .743 .984 r
.28216 .44071 m .27631 .4387 L .27619 .43861 L p F P
0 g
s
.74 .219 0 r
.25609 .32068 m .26039 .32355 L .25764 .32037 L p F P
0 g
s
.74 .219 0 r
.25764 .32037 m .25344 .31746 L .25609 .32068 L p F P
0 g
s
.738 .804 .905 r
.70147 .22125 m .70144 .22127 L .70145 .22122 L closepath p F P
0 g
s
.74 .83 .92 r
.6991 .21856 m .70145 .22122 L .70144 .22127 L p F P
0 g
s
.74 .83 .92 r
.68885 .22437 m .6991 .21856 L p .70144 .22127 L F P
0 g
s
.727 .801 .911 r
.7094 .21332 m .71179 .21636 L .70147 .22125 L p F P
0 g
s
.727 .801 .911 r
.70461 .21576 m .7094 .21332 L p .70147 .22125 L F P
0 g
s
.727 .801 .911 r
.70147 .22125 m .70145 .22122 L .70461 .21576 L p F P
0 g
s
0 0 0 r
.74575 .31324 m .7488 .30777 L .745 .31324 L p F P
0 g
s
0 0 0 r
.74348 .31653 m .74575 .31324 L p .745 .31324 L F P
0 g
s
0 0 0 r
.745 .31324 m .7442 .31468 L .74348 .31653 L p F P
0 g
s
.728 .803 .911 r
.70145 .22122 m .6991 .21856 L .70461 .21576 L closepath p F P
0 g
s
.622 .91 .624 r
.71675 .35014 m .71139 .35546 L .71525 .35122 L closepath p F P
0 g
s
.649 .952 .737 r
.69667 .36869 m .6953 .36984 L .69633 .36884 L closepath p F P
0 g
s
.675 .97 .785 r
.69446 .36936 m .69633 .36884 L .6953 .36984 L p F P
0 g
s
.675 .97 .785 r
.692 .37134 m .69446 .36936 L p .6953 .36984 L F P
0 g
s
.675 .97 .785 r
.68633 .37689 m .692 .37134 L p .6953 .36984 L F P
0 g
s
.783 .374 .277 r
.31479 .36437 m .31572 .36468 L .31815 .36273 L p F P
0 g
s
.783 .374 .277 r
.31815 .36273 m .31265 .36086 L .31479 .36437 L p F P
0 g
s
.708 .985 .833 r
.68633 .37689 m .68432 .37725 L .692 .37134 L closepath p F P
0 g
s
0 0 0 r
.55357 .32733 m .55281 .32847 L .55749 .32465 L closepath p F P
0 g
s
.668 .959 .738 r
.70384 .36248 m .69667 .36869 L .69633 .36884 L p F P
0 g
s
.779 .297 .084 r
.28533 .34145 m .28466 .34146 L .28424 .34093 L closepath p F P
0 g
s
.445 .114 .308 r
.49844 .36964 m .49939 .3664 L .48919 .36973 L p F P
0 g
s
.445 .114 .308 r
.48919 .36973 m .48821 .37296 L .49844 .36964 L p F P
0 g
s
.177 .569 .935 r
.18864 .40925 m .18937 .40943 L .19369 .4122 L p F P
0 g
s
.205 .583 .943 r
.19677 .41105 m .18937 .40943 L .19369 .4122 L p F P
0 g
s
.205 .583 .943 r
.20085 .41375 m .19677 .41105 L p .19369 .4122 L F P
0 g
s
.205 .583 .943 r
.19369 .4122 m .20098 .41385 L .20085 .41375 L p F P
0 g
s
.599 .073 0 r
.23565 .30225 m .23288 .2994 L .22972 .29673 L p F P
0 g
s
.699 .977 .912 r
.65409 .39803 m .65383 .39802 L .65505 .39726 L closepath p F P
0 g
s
0 0 .085 r
.75224 .29892 m .75183 .30122 L .75321 .29744 L closepath p F P
0 g
s
.243 .613 .955 r
.20419 .41633 m .20551 .41656 L .21007 .41924 L p F P
0 g
s
.267 .623 .96 r
.2134 .41784 m .20551 .41656 L .21007 .41924 L p F P
0 g
s
.267 .623 .96 r
.21007 .41924 m .2166 .42031 L .2134 .41784 L p F P
0 g
s
.61 .762 .952 r
.34564 .44888 m .35541 .4466 L .35836 .4492 L p F P
0 g
s
.625 .754 .939 r
.35541 .4466 m .34564 .44888 L .34266 .44637 L p F P
0 g
s
.657 .941 .685 r
.71463 .35154 m .71525 .35122 L .71139 .35546 L p F P
0 g
s
.657 .941 .685 r
.70939 .3565 m .71463 .35154 L p .71139 .35546 L F P
0 g
s
.657 .941 .685 r
.70596 .36029 m .70939 .3565 L p .71139 .35546 L F P
0 g
s
.657 .941 .685 r
.71139 .35546 m .70674 .35984 L .70596 .36029 L p F P
0 g
s
.566 .249 .391 r
.46509 .38523 m .46589 .38172 L .45465 .38376 L p F P
0 g
s
.566 .249 .391 r
.45688 .38669 m .46509 .38523 L p .45465 .38376 L F P
0 g
s
.566 .249 .391 r
.45465 .38376 m .45417 .38568 L .45688 .38669 L p F P
0 g
s
.128 0 .01 r
.54273 .33606 m .53505 .34129 L .54195 .33755 L closepath p F P
0 g
s
.172 0 .071 r
.54063 .34019 m .54195 .33755 L .53505 .34129 L p F P
0 g
s
.172 0 .071 r
.53163 .34516 m .54063 .34019 L p .53505 .34129 L F P
0 g
s
.637 .934 .683 r
.70674 .35984 m .70384 .36248 L .70596 .36029 L closepath p F P
0 g
s
.668 .959 .738 r
.70457 .36083 m .70596 .36029 L .70384 .36248 L p F P
0 g
s
.668 .959 .738 r
.70123 .36373 m .70457 .36083 L p .70384 .36248 L F P
0 g
s
.668 .959 .738 r
.69633 .36884 m .70123 .36373 L p .70384 .36248 L F P
0 g
s
0 .168 .664 r
.1167 .36204 m .12003 .3653 L .11636 .36247 L p F P
0 g
s
0 .168 .664 r
.11636 .36247 m .11304 .35922 L .1167 .36204 L p F P
0 g
s
.442 .719 .983 r
.26361 .43641 m .27067 .4363 L .2761 .43862 L p F P
0 g
s
.454 .721 .982 r
.27067 .4363 m .26361 .43641 L .26049 .4341 L p F P
0 g
s
0 0 0 r
.7442 .31468 m .74182 .31876 L .74348 .31653 L closepath p F P
0 g
s
.699 .972 .755 r
.60464 .2845 m .60315 .28513 L .60829 .28055 L closepath p F P
0 g
s
.805 .964 .91 r
.64866 .24883 m .64586 .25097 L .64347 .25022 L p F P
0 g
s
.666 .359 .443 r
.41773 .3906 m .40953 .39067 L .41172 .39426 L p F P
0 g
s
.67 .36 .439 r
.40395 .39424 m .41172 .39426 L .40953 .39067 L p F P
0 g
s
.67 .36 .439 r
.40953 .39067 m .40479 .39065 L .40395 .39424 L p F P
0 g
s
.684 .374 .443 r
.40014 .39411 m .40395 .39424 L .40479 .39065 L p F P
0 g
s
.684 .374 .443 r
.40479 .39065 m .39819 .39044 L .40014 .39411 L p F P
0 g
s
.651 .885 .983 r
.5574 .43284 m .55996 .43412 L .54983 .43797 L p F P
0 g
s
.651 .885 .983 r
.54983 .43797 m .54783 .43697 L .5574 .43284 L p F P
0 g
s
.647 .341 .438 r
.42231 .39039 m .41773 .3906 L .41694 .39422 L p F P
0 g
s
.666 .359 .443 r
.41172 .39426 m .41694 .39422 L .41773 .3906 L p F P
0 g
s
.768 .872 .924 r
.67627 .22873 m .68586 .22249 L .68338 .22775 L p F P
0 g
s
.779 .862 .911 r
.68338 .22775 m .68885 .22437 L .68647 .22209 L p F P
0 g
s
.779 .862 .911 r
.68647 .22209 m .68586 .22249 L .68338 .22775 L p F P
0 g
s
0 .13 .633 r
.21496 .28398 m .21463 .28371 L .21148 .28051 L p F P
0 g
s
.146 .54 .923 r
.1811 .40371 m .18515 .40661 L .1786 .4047 L p F P
0 g
s
.146 .54 .923 r
.1786 .4047 m .1745 .40183 L .1811 .40371 L p F P
0 g
s
.106 .518 .909 r
.17314 .4014 m .1745 .40183 L .1786 .4047 L p F P
0 g
s
.275 .235 .631 r
.76342 .25846 m .7628 .25957 L .76056 .25601 L p F P
0 g
s
.275 .235 .631 r
.76056 .25601 m .76225 .25297 L .76342 .25846 L p F P
0 g
s
.735 .395 .404 r
.36138 .38647 m .36215 .3866 L .36342 .38342 L p F P
0 g
s
.735 .395 .404 r
.36342 .38342 m .35956 .38279 L .36138 .38647 L p F P
0 g
s
.814 .391 .241 r
.30132 .35625 m .30682 .35862 L .30475 .3551 L p F P
0 g
s
.814 .391 .241 r
.2999 .35365 m .30132 .35625 L p .30475 .3551 L F P
0 g
s
.814 .391 .241 r
.30475 .3551 m .30074 .3533 L .2999 .35365 L p F P
0 g
s
.78 .293 .066 r
.28143 .34133 m .27919 .33837 L .28424 .34093 L p F P
0 g
s
.78 .293 .066 r
.28424 .34093 m .28466 .34146 L .28143 .34133 L p F P
0 g
s
0 .348 .803 r
.14243 .38301 m .14268 .38315 L .14017 .38102 L closepath p F P
0 g
s
.715 .382 .412 r
.37762 .3873 m .37849 .38892 L .37711 .38876 L closepath p F P
0 g
s
.692 .376 .436 r
.39037 .3936 m .40014 .39411 L .39819 .39044 L p F P
0 g
s
.692 .376 .436 r
.39819 .39044 m .39129 .39008 L .39037 .3936 L p F P
0 g
s
.821 .958 .902 r
.64866 .24883 m .65597 .24321 L .65358 .24209 L p F P
0 g
s
.821 .958 .902 r
.65358 .24209 m .65221 .2432 L .64866 .24883 L p F P
0 g
s
.805 .964 .91 r
.64347 .25022 m .65221 .2432 L .64866 .24883 L p F P
0 g
s
.645 .34 .44 r
.43019 .38999 m .42231 .39039 L .42489 .39386 L p F P
0 g
s
.647 .341 .438 r
.41694 .39422 m .42489 .39386 L .42231 .39039 L p F P
0 g
s
.704 .976 .916 r
.65505 .39726 m .65383 .39802 L .65147 .39783 L p F P
0 g
s
.304 .65 .969 r
.21979 .42273 m .2232 .42315 L .22798 .42573 L p F P
0 g
s
.323 .656 .971 r
.22908 .42377 m .2232 .42315 L .22798 .42573 L p F P
0 g
s
.323 .656 .971 r
.22798 .42573 m .23225 .42619 L .22908 .42377 L p F P
0 g
s
.604 .071 0 r
.23865 .3053 m .24252 .30836 L .23945 .30533 L p F P
0 g
s
.604 .071 0 r
.23945 .30533 m .23565 .30225 L .23865 .3053 L p F P
0 g
s
.626 .76 .943 r
.35836 .4492 m .36817 .44665 L .37109 .44934 L p F P
0 g
s
.642 .749 .927 r
.36817 .44665 m .35836 .4492 L .35541 .4466 L p F P
0 g
s
.67 .919 .975 r
.59558 .4235 m .58541 .42799 L .58287 .42702 L p F P
0 g
s
.015 .434 .865 r
.1441 .38242 m .14773 .38552 L .14268 .38315 L p F P
0 g
s
.015 .434 .865 r
.13915 .38011 m .1441 .38242 L p .14268 .38315 L F P
0 g
s
.015 .434 .865 r
.14268 .38315 m .14017 .38102 L .13915 .38011 L p F P
0 g
s
0 0 0 r
.56362 .3194 m .56288 .32035 L .56678 .31701 L closepath p F P
0 g
s
0 .13 .633 r
.21148 .28051 m .21165 .28066 L .21496 .28398 L p F P
0 g
s
0 .116 .619 r
.21503 .28351 m .21835 .28683 L .21496 .28398 L p F P
0 g
s
0 .116 .619 r
.21496 .28398 m .21165 .28066 L .21503 .28351 L p F P
0 g
s
.692 .979 .894 r
.664 .39149 m .65505 .39726 L .66205 .3915 L closepath p F P
0 g
s
.704 .976 .916 r
.66167 .39146 m .66205 .3915 L .65505 .39726 L p F P
0 g
s
.704 .976 .916 r
.65147 .39783 m .66167 .39146 L p .65505 .39726 L F P
0 g
s
.675 .961 .94 r
.63109 .40957 m .62774 .41138 L .63051 .40949 L closepath p F P
0 g
s
.682 .954 .951 r
.62865 .40905 m .63051 .40949 L .62774 .41138 L p F P
0 g
s
.682 .954 .951 r
.61845 .41443 m .62865 .40905 L p .62774 .41138 L F P
0 g
s
.773 .414 .377 r
.33738 .37784 m .34446 .37961 L .34256 .37597 L p F P
0 g
s
.773 .414 .377 r
.34256 .37597 m .33568 .37413 L .33738 .37784 L p F P
0 g
s
.707 .981 .796 r
.69633 .36884 m .69446 .36936 L .70123 .36373 L closepath p F P
0 g
s
.731 .203 0 r
.26307 .32664 m .26039 .32355 L .26487 .32634 L p F P
0 g
s
.731 .203 0 r
.26487 .32634 m .26627 .32792 L .26307 .32664 L p F P
0 g
s
.702 .385 .439 r
.38973 .39355 m .39037 .3936 L .39129 .39008 L p F P
0 g
s
.702 .385 .439 r
.39129 .39008 m .38792 .38983 L .38973 .39355 L p F P
0 g
s
.49 .164 .341 r
.48731 .3763 m .48821 .37296 L .47767 .37587 L p F P
0 g
s
.49 .164 .341 r
.48157 .37786 m .48731 .3763 L p .47767 .37587 L F P
0 g
s
.49 .164 .341 r
.47767 .37587 m .47698 .3783 L .48157 .37786 L p F P
0 g
s
.314 .652 .97 r
.2232 .42315 m .21979 .42273 L .2166 .42031 L p F P
0 g
s
.623 .319 .434 r
.43736 .38932 m .43019 .38999 L .42944 .39363 L p F P
0 g
s
.645 .34 .44 r
.42489 .39386 m .42944 .39363 L .43019 .38999 L p F P
0 g
s
.543 .752 .973 r
.31623 .44437 m .31723 .44516 L p .30455 .44404 L F P
0 g
s
.543 .752 .973 r
.30455 .44404 m .31204 .44302 L .31623 .44437 L p F P
0 g
s
.559 .753 .968 r
.31204 .44302 m .30455 .44404 L .3015 .44169 L p F P
0 g
s
.573 .763 .968 r
.31723 .44516 m .31866 .4449 L .32584 .44658 L p F P
0 g
s
.568 .752 .964 r
.32693 .44335 m .31866 .4449 L .32584 .44658 L p F P
0 g
s
.568 .752 .964 r
.32584 .44658 m .32993 .4459 L .32693 .44335 L p F P
0 g
s
.821 .366 .146 r
.28649 .34435 m .28466 .34146 L .28143 .34133 L p F P
0 g
s
.79 .409 .335 r
.32257 .3702 m .32903 .37221 L .32703 .36863 L p F P
0 g
s
.79 .409 .335 r
.32703 .36863 m .32075 .36656 L .32257 .3702 L p F P
0 g
s
.75 .413 .413 r
.35342 .38503 m .36138 .38647 L .35956 .38279 L p F P
0 g
s
.75 .413 .413 r
.35956 .38279 m .35181 .38127 L .35342 .38503 L p F P
0 g
s
.699 .968 .933 r
.64253 .40403 m .64127 .40385 L .64745 .40025 L closepath p F P
0 g
s
.714 .401 .447 r
.38005 .39272 m .38973 .39355 L .38792 .38983 L p F P
0 g
s
.714 .401 .447 r
.38792 .38983 m .37849 .38892 L .38005 .39272 L p F P
0 g
s
.802 .939 .918 r
.65954 .2406 m .65597 .24321 L .65358 .24209 L p F P
0 g
s
.566 .582 .829 r
.75077 .22108 m .74834 .22595 L p .73991 .22127 L F P
0 g
s
.566 .582 .829 r
.73991 .22127 m .75059 .22068 L .75077 .22108 L p F P
0 g
s
.559 .619 .868 r
.73767 .21719 m .73991 .22127 L .75059 .22068 L p F P
0 g
s
0 .239 .724 r
.12071 .36576 m .12003 .3653 L .12342 .36851 L p F P
0 g
s
0 .239 .724 r
.12342 .36851 m .124 .3689 L .12071 .36576 L p F P
0 g
s
.638 .757 .934 r
.37109 .44934 m .38094 .44656 L .38384 .44934 L p F P
0 g
s
.654 .744 .916 r
.38094 .44656 m .37109 .44934 L .36817 .44665 L p F P
0 g
s
.076 0 0 r
.54722 .33264 m .54273 .33606 L .54195 .33755 L p F P
0 g
s
.033 .461 .877 r
.15773 .39269 m .16068 .39384 L .16458 .39681 L p F P
0 g
s
.069 .484 .892 r
.16654 .39596 m .16068 .39384 L .16458 .39681 L p F P
0 g
s
.069 .484 .892 r
.16711 .3964 m .16654 .39596 L p .16458 .39681 L F P
0 g
s
.069 .484 .892 r
.16458 .39681 m .16989 .39873 L .16711 .3964 L p F P
0 g
s
.653 .863 .979 r
.54721 .43663 m .53708 .44027 L .53443 .43867 L p F P
0 g
s
.645 .859 .981 r
.52432 .44216 m .53443 .43867 L .53708 .44027 L p F P
0 g
s
.631 .889 .56 r
.72591 .34006 m .72463 .34122 L .72873 .33654 L closepath p F P
0 g
s
.757 .819 .901 r
.6991 .21856 m .68885 .22437 L .68647 .22209 L p F P
0 g
s
0 0 0 r
.74223 .31888 m .73807 .32447 L .74182 .31876 L p F P
0 g
s
0 0 0 r
.74235 .31871 m .74223 .31888 L p .74182 .31876 L F P
0 g
s
0 0 0 r
.74182 .31876 m .74348 .31653 L .74235 .31871 L p F P
0 g
s
0 0 .082 r
.75476 .29711 m .75662 .29206 L .75321 .29744 L p F P
0 g
s
0 0 .082 r
.75169 .30198 m .75476 .29711 L p .75321 .29744 L F P
0 g
s
0 0 .082 r
.75321 .29744 m .75183 .30122 L .75169 .30198 L p F P
0 g
s
.682 .94 .964 r
.61538 .41598 m .60827 .41947 L .60578 .41872 L p F P
0 g
s
.366 .684 .979 r
.24833 .43191 m .24792 .4316 L .24767 .43159 L closepath p F P
0 g
s
.817 .372 .18 r
.28861 .34784 m .2938 .35033 L .29155 .3469 L p F P
0 g
s
.817 .372 .18 r
.29155 .3469 m .28649 .34435 L .28861 .34784 L p F P
0 g
s
.689 .964 .938 r
.63887 .40347 m .64127 .40385 L .63109 .40957 L p F P
0 g
s
.689 .964 .938 r
.63844 .40371 m .63887 .40347 L p .63109 .40957 L F P
0 g
s
.689 .964 .938 r
.63109 .40957 m .63051 .40949 L .63844 .40371 L p F P
0 g
s
.816 .931 .908 r
.65954 .2406 m .6661 .23578 L .66372 .2343 L p F P
0 g
s
.816 .931 .908 r
.66372 .2343 m .66265 .23513 L .65954 .2406 L p F P
0 g
s
.802 .939 .918 r
.65358 .24209 m .66265 .23513 L .65954 .2406 L p F P
0 g
s
.647 .754 .928 r
.38384 .44934 m .39371 .44637 L .39659 .44923 L p F P
0 g
s
.662 .738 .907 r
.39371 .44637 m .38384 .44934 L .38094 .44656 L p F P
0 g
s
.045 .464 .881 r
.16068 .39384 m .15773 .39269 L .15447 .3899 L p F P
0 g
s
.623 .319 .434 r
.44221 .38887 m .43736 .38932 L .44055 .39258 L p F P
0 g
s
.623 .319 .434 r
.42944 .39363 m .44055 .39258 L .43736 .38932 L p F P
0 g
s
.016 0 0 r
.55281 .32847 m .54722 .33264 L .55207 .32969 L closepath p F P
0 g
s
.076 0 0 r
.55065 .33217 m .55207 .32969 L .54722 .33264 L p F P
0 g
s
.076 0 0 r
.54195 .33755 m .55065 .33217 L p .54722 .33264 L F P
0 g
s
.393 .054 .267 r
.50931 .36267 m .50989 .36088 L .49982 .36509 L p F P
0 g
s
.393 .054 .267 r
.49982 .36509 m .49939 .3664 L .50931 .36267 L p F P
0 g
s
.607 .062 0 r
.24479 .31059 m .24252 .30836 L .24653 .31136 L p F P
0 g
s
.607 .062 0 r
.24653 .31136 m .24797 .31274 L .24479 .31059 L p F P
0 g
s
.757 .994 .816 r
.61425 .27594 m .61322 .27618 L .6165 .27329 L closepath p F P
0 g
s
0 .127 .621 r
.22184 .28966 m .22531 .2929 L .22179 .29009 L p F P
0 g
s
0 .127 .621 r
.22179 .29009 m .21835 .28683 L .22184 .28966 L p F P
0 g
s
.352 .332 .697 r
.76026 .24752 m .76063 .24684 L .761 .24818 L closepath p F P
0 g
s
.801 .395 .282 r
.30879 .36219 m .31479 .36437 L .31265 .36086 L p F P
0 g
s
.801 .395 .282 r
.31265 .36086 m .30682 .35862 L .30879 .36219 L p F P
0 g
s
.119 .044 .489 r
.76467 .26783 m .76176 .2729 L .76115 .26874 L p F P
0 g
s
.119 .044 .489 r
.76429 .26413 m .76467 .26783 L p .76115 .26874 L F P
0 g
s
.119 .044 .489 r
.76115 .26874 m .76419 .26344 L .76429 .26413 L p F P
0 g
s
0 0 0 r
.5735 .31124 m .57295 .31183 L .57551 .30957 L closepath p F P
0 g
s
.254 .615 .957 r
.20551 .41656 m .20419 .41633 L .20098 .41385 L p F P
0 g
s
0 .277 .752 r
.124 .3689 m .12761 .37116 L .13108 .37433 L p F P
0 g
s
0 .283 .761 r
.12761 .37116 m .124 .3689 L .12071 .36576 L p F P
0 g
s
.441 .722 .985 r
.27631 .4387 m .27619 .43861 L .2761 .43862 L closepath p F P
0 g
s
.372 .682 .978 r
.24478 .4292 m .24272 .42908 L .24767 .43159 L p F P
0 g
s
.372 .682 .978 r
.24767 .43159 m .24792 .4316 L .24478 .4292 L p F P
0 g
s
.806 .322 .044 r
.26977 .33298 m .27438 .33572 L .27196 .33238 L p F P
0 g
s
.806 .322 .044 r
.27196 .33238 m .26747 .3296 L .26977 .33298 L p F P
0 g
s
.447 .718 .982 r
.2731 .43623 m .27067 .4363 L .2761 .43862 L p F P
0 g
s
.447 .718 .982 r
.2761 .43862 m .27619 .43861 L .2731 .43623 L p F P
0 g
s
.652 .753 .923 r
.39659 .44923 m .40649 .44614 L .40935 .44903 L p F P
0 g
s
.667 .735 .901 r
.40649 .44614 m .39659 .44923 L .39371 .44637 L p F P
0 g
s
.503 .736 .978 r
.28575 .43791 m .27619 .43861 L .2731 .43623 L p F P
0 g
s
.65 .85 .977 r
.53443 .43867 m .52432 .44216 L .52164 .44044 L p F P
0 g
s
.642 .848 .979 r
.51155 .44379 m .52164 .44044 L .52432 .44216 L p F P
0 g
s
.721 .404 .442 r
.37616 .39227 m .38005 .39272 L .37849 .38892 L p F P
0 g
s
.721 .404 .442 r
.37849 .38892 m .37711 .38876 L .37616 .39227 L p F P
0 g
s
.421 .705 .981 r
.25736 .43173 m .24792 .4316 L .24478 .4292 L p F P
0 g
s
.526 .549 .822 r
.74834 .22595 m .75077 .22108 L .7531 .22626 L closepath p F P
0 g
s
.602 .299 .428 r
.45315 .39095 m .45381 .38725 L .44221 .38887 L p F P
0 g
s
.602 .299 .428 r
.44221 .38887 m .44147 .3925 L .45315 .39095 L p F P
0 g
s
.623 .319 .434 r
.44055 .39258 m .44147 .3925 L .44221 .38887 L p F P
0 g
s
.572 .765 .97 r
.31723 .44516 m .31866 .4449 L .31623 .44437 L closepath p F P
0 g
s
0 0 .304 r
.7588 .28584 m .75794 .28721 L .75868 .28257 L p F P
0 g
s
0 0 .304 r
.75868 .28257 m .75891 .28219 L .7588 .28584 L p F P
0 g
s
.662 .907 .979 r
.57281 .43136 m .5727 .43132 L .57377 .43087 L closepath p F P
0 g
s
.565 .255 .401 r
.45417 .38568 m .45688 .38669 L .45381 .38725 L closepath p F P
0 g
s
.645 .828 .971 r
.50885 .44187 m .50977 .44254 L .49932 .44551 L p F P
0 g
s
.645 .828 .971 r
.49932 .44551 m .49878 .44512 L .50885 .44187 L p F P
0 g
s
.538 .229 .39 r
.476 .38275 m .47675 .37921 L .46589 .38172 L p F P
0 g
s
.538 .229 .39 r
.46589 .38172 m .46509 .38523 L .476 .38275 L p F P
0 g
s
.725 .409 .444 r
.37108 .39165 m .37616 .39227 L .37711 .38876 L p F P
0 g
s
.725 .409 .444 r
.37711 .38876 m .36957 .38783 L .37108 .39165 L p F P
0 g
s
.117 .52 .912 r
.1745 .40183 m .17314 .4014 L .16989 .39873 L p F P
0 g
s
.705 .982 .892 r
.66927 .38798 m .664 .39149 L .66205 .3915 L p F P
0 g
s
.792 .355 .211 r
.30074 .3533 m .2999 .35365 L .29929 .35272 L closepath p F P
0 g
s
.185 .57 .937 r
.18864 .40925 m .18937 .40943 L .1863 .4074 L closepath p F P
0 g
s
0 0 0 r
.55749 .32465 m .55281 .32847 L .55207 .32969 L p F P
0 g
s
.655 .753 .922 r
.40935 .44903 m .41928 .44588 L .42212 .44878 L p F P
0 g
s
.668 .733 .899 r
.41928 .44588 m .40935 .44903 L .40649 .44614 L p F P
0 g
s
.669 .899 .978 r
.57377 .43087 m .5727 .43132 L .57012 .43009 L p F P
0 g
s
.658 .896 .981 r
.55996 .43412 m .57012 .43009 L .5727 .43132 L p F P
0 g
s
.793 .911 .921 r
.67169 .23192 m .6661 .23578 L .66372 .2343 L p F P
0 g
s
.703 .973 .753 r
.70596 .36029 m .70457 .36083 L .70939 .3565 L closepath p F P
0 g
s
.412 .421 .759 r
.75826 .2394 m .75853 .23953 L .7584 .23981 L closepath p F P
0 g
s
.371 .373 .731 r
.76271 .24238 m .76063 .24684 L .7584 .23981 L p F P
0 g
s
.371 .373 .731 r
.7584 .23981 m .75853 .23953 L .76271 .24238 L p F P
0 g
s
.43 .445 .774 r
.75853 .23953 m .75826 .2394 L .75564 .23236 L p F P
0 g
s
0 .428 .859 r
.1512 .38703 m .14773 .38552 L .15144 .38858 L p F P
0 g
s
0 .428 .859 r
.15144 .38858 m .15447 .3899 L .1512 .38703 L p F P
0 g
s
.277 .283 .686 r
.76582 .24562 m .76271 .24238 L .76063 .24684 L p F P
0 g
s
.277 .283 .686 r
.76333 .25078 m .76582 .24562 L p .76063 .24684 L F P
0 g
s
.277 .283 .686 r
.76063 .24684 m .761 .24818 L .76333 .25078 L p F P
0 g
s
0 .315 .783 r
.13204 .37373 m .13551 .37691 L .13108 .37433 L p F P
0 g
s
0 .315 .783 r
.13108 .37433 m .12761 .37116 L .13204 .37373 L p F P
0 g
s
0 0 .287 r
.76106 .28191 m .7588 .28584 L .75891 .28219 L p F P
0 g
s
0 0 .287 r
.75891 .28219 m .76171 .27729 L .76106 .28191 L p F P
0 g
s
0 0 0 r
.56288 .32035 m .55749 .32465 L .56202 .32158 L closepath p F P
0 g
s
0 0 0 r
.56048 .32387 m .56202 .32158 L .55749 .32465 L p F P
0 g
s
0 0 0 r
.55207 .32969 m .56048 .32387 L p .55749 .32465 L F P
0 g
s
.305 .29 .677 r
.761 .24818 m .76333 .25078 L .76225 .25297 L closepath p F P
0 g
s
.649 .834 .972 r
.52 .43927 m .52164 .44044 L .51155 .44379 L p F P
0 g
s
.649 .834 .972 r
.51155 .44379 m .50977 .44254 L .52 .43927 L p F P
0 g
s
.655 .757 .924 r
.42212 .44878 m .43206 .44561 L .43489 .44846 L p F P
0 g
s
.668 .735 .901 r
.43206 .44561 m .42212 .44878 L .41928 .44588 L p F P
0 g
s
.687 .73 .883 r
.71179 .21636 m .72217 .21214 L .72456 .21569 L p F P
0 g
s
.699 .745 .887 r
.72217 .21214 m .71179 .21636 L .7094 .21332 L p F P
0 g
s
.43 .445 .774 r
.75564 .23236 m .76079 .23444 L .75853 .23953 L p F P
0 g
s
.377 .384 .74 r
.76517 .23721 m .76271 .24238 L .75853 .23953 L p F P
0 g
s
.377 .384 .74 r
.75853 .23953 m .76079 .23444 L .76517 .23721 L p F P
0 g
s
.763 .418 .4 r
.34617 .38334 m .35342 .38503 L .35181 .38127 L p F P
0 g
s
.763 .418 .4 r
.35181 .38127 m .34758 .38029 L .34617 .38334 L p F P
0 g
s
.663 .911 .978 r
.58287 .42702 m .57377 .43087 L .58192 .42662 L closepath p F P
0 g
s
.669 .899 .978 r
.58031 .42586 m .58192 .42662 L .57377 .43087 L p F P
0 g
s
.669 .899 .978 r
.57012 .43009 m .58031 .42586 L p .57377 .43087 L F P
0 g
s
.657 .693 .872 r
.73505 .21269 m .72456 .21569 L .72217 .21214 L p F P
0 g
s
.643 .676 .866 r
.72456 .21569 m .73505 .21269 L .73747 .21684 L p F P
0 g
s
.736 .215 0 r
.24797 .31274 m .24938 .31449 L .25344 .31746 L p F P
0 g
s
.745 .228 0 r
.25196 .31773 m .25609 .32068 L .25344 .31746 L p F P
0 g
s
.745 .228 0 r
.25344 .31746 m .24938 .31449 L .25196 .31773 L p F P
0 g
s
.784 .419 .364 r
.33083 .37587 m .33738 .37784 L .33568 .37413 L p F P
0 g
s
.784 .419 .364 r
.33063 .37542 m .33083 .37587 L p .33568 .37413 L F P
0 g
s
.784 .419 .364 r
.33568 .37413 m .3322 .37309 L .33063 .37542 L p F P
0 g
s
0 0 0 r
.73792 .3248 m .74223 .31888 L .73807 .32447 L p F P
0 g
s
0 0 0 r
.7343 .32972 m .73792 .3248 L p .73807 .32447 L F P
0 g
s
0 0 0 r
.73807 .32447 m .73452 .32939 L .7343 .32972 L p F P
0 g
s
0 .121 .603 r
.22655 .29391 m .22531 .2929 L .22891 .29609 L p F P
0 g
s
0 .121 .603 r
.22891 .29609 m .22972 .29673 L .22655 .29391 L p F P
0 g
s
.675 .927 .971 r
.59604 .42366 m .59558 .4235 L .59891 .42196 L closepath p F P
0 g
s
.698 .956 .949 r
.63051 .40949 m .62865 .40905 L .63844 .40371 L closepath p F P
0 g
s
.254 .615 .957 r
.20098 .41385 m .20102 .41386 L .20551 .41656 L p F P
0 g
s
.277 .624 .961 r
.20939 .41515 m .20102 .41386 L .20551 .41656 L p F P
0 g
s
.277 .624 .961 r
.21239 .41704 m .20939 .41515 L p .20551 .41656 L F P
0 g
s
.277 .624 .961 r
.20551 .41656 m .2134 .41784 L .21239 .41704 L p F P
0 g
s
.583 .764 .965 r
.32393 .44069 m .32693 .44335 L .31866 .4449 L p F P
0 g
s
.583 .764 .965 r
.3142 .44271 m .32393 .44069 L p .31866 .4449 L F P
0 g
s
.583 .764 .965 r
.31866 .4449 m .31623 .44437 L .3142 .44271 L p F P
0 g
s
.801 .31 .005 r
.26747 .3296 m .26627 .32792 L .26307 .32664 L p F P
0 g
s
.26 .608 .955 r
.19259 .4082 m .19677 .41105 L .18937 .40943 L p F P
0 g
s
.26 .608 .955 r
.1854 .40667 m .19259 .4082 L p .18937 .40943 L F P
0 g
s
.26 .608 .955 r
.18937 .40943 m .1863 .4074 L .1854 .40667 L p F P
0 g
s
.654 .763 .929 r
.43489 .44846 m .44486 .4453 L .44766 .44807 L p F P
0 g
s
.666 .741 .906 r
.44486 .4453 m .43489 .44846 L .43206 .44561 L p F P
0 g
s
.795 .355 .2 r
.29599 .3538 m .2938 .35033 L .29929 .35272 L p F P
0 g
s
.795 .355 .2 r
.29756 .35447 m .29599 .3538 L p .29929 .35272 L F P
0 g
s
.795 .355 .2 r
.29929 .35272 m .2999 .35365 L .29756 .35447 L p F P
0 g
s
.478 .49 .791 r
.75495 .2322 m .75531 .2315 L .75564 .23236 L closepath p F P
0 g
s
0 .365 .817 r
.14017 .38102 m .13915 .38011 L .13905 .38005 L closepath p F P
0 g
s
0 0 0 r
.56678 .31701 m .56288 .32035 L .56202 .32158 L p F P
0 g
s
0 0 .096 r
.75183 .30122 m .75134 .30248 L .75169 .30198 L closepath p F P
0 g
s
.653 .809 .958 r
.50885 .44187 m .49878 .44512 L .49605 .44296 L p F P
0 g
s
.786 .299 .057 r
.27677 .33908 m .27438 .33572 L .27919 .33837 L p F P
0 g
s
.786 .299 .057 r
.28091 .34127 m .27677 .33908 L p .27919 .33837 L F P
0 g
s
.786 .299 .057 r
.27919 .33837 m .28143 .34133 L .28091 .34127 L p F P
0 g
s
.605 .757 .951 r
.32993 .4459 m .33968 .44372 L .34266 .44637 L p F P
0 g
s
.62 .751 .94 r
.33968 .44372 m .32993 .4459 L .32693 .44335 L p F P
0 g
s
.695 .982 .868 r
.67417 .38459 m .66927 .38798 L .67303 .38469 L closepath p F P
0 g
s
.705 .982 .892 r
.67186 .38466 m .67303 .38469 L .66927 .38798 L p F P
0 g
s
.705 .982 .892 r
.66329 .39041 m .67186 .38466 L p .66927 .38798 L F P
0 g
s
.705 .982 .892 r
.66205 .3915 m .66329 .39041 L p .66927 .38798 L F P
0 g
s
.653 .772 .937 r
.44766 .44807 m .45765 .44493 L .46044 .44758 L p F P
0 g
s
.663 .75 .915 r
.45765 .44493 m .44766 .44807 L .44486 .4453 L p F P
0 g
s
.253 0 .152 r
.53007 .34872 m .53039 .34794 L .52111 .35251 L p F P
0 g
s
.253 0 .152 r
.52111 .35251 m .51998 .35531 L .53007 .34872 L p F P
0 g
s
.33 0 .219 r
.51035 .35958 m .50989 .36088 L .51915 .35575 L closepath p F P
0 g
s
.493 .832 .547 r
.58322 .30285 m .58301 .30303 L .58388 .30225 L closepath p F P
0 g
s
0 0 0 r
.57295 .31183 m .56678 .31701 L .57178 .31323 L closepath p F P
0 g
s
0 0 0 r
.57046 .31488 m .57178 .31323 L .56678 .31701 L p F P
0 g
s
0 0 0 r
.56879 .31638 m .57046 .31488 L p .56678 .31701 L F P
0 g
s
0 0 0 r
.56202 .32158 m .56879 .31638 L p .56678 .31701 L F P
0 g
s
.794 .883 .911 r
.67627 .22873 m .67169 .23192 L .67408 .22704 L closepath p F P
0 g
s
.793 .911 .921 r
.67389 .2269 m .67408 .22704 L .67169 .23192 L p F P
0 g
s
.793 .911 .921 r
.66372 .2343 m .67389 .2269 L p .67169 .23192 L F P
0 g
s
.654 .793 .949 r
.49605 .44296 m .486 .44614 L .48325 .44381 L p F P
0 g
s
.648 .796 .953 r
.47322 .44694 m .48325 .44381 L .486 .44614 L p F P
0 g
s
.65 .783 .945 r
.46044 .44758 m .47045 .44445 L .47322 .44694 L p F P
0 g
s
.659 .763 .926 r
.47045 .44445 m .46044 .44758 L .45765 .44493 L p F P
0 g
s
.742 .419 .437 r
.36276 .39033 m .37108 .39165 L .36957 .38783 L p F P
0 g
s
.742 .419 .437 r
.36183 .38764 m .36276 .39033 L p .36957 .38783 L F P
0 g
s
.742 .419 .437 r
.36957 .38783 m .36215 .3866 L .36183 .38764 L p F P
0 g
s
.805 .419 .325 r
.31654 .36804 m .32257 .3702 L .32075 .36656 L p F P
0 g
s
.805 .419 .325 r
.31522 .36516 m .31654 .36804 L p .32075 .36656 L F P
0 g
s
.805 .419 .325 r
.32075 .36656 m .31572 .36468 L .31522 .36516 L p F P
0 g
s
.793 .997 .858 r
.62382 .2673 m .62329 .26732 L .62486 .26598 L closepath p F P
0 g
s
.656 .777 .938 r
.48325 .44381 m .47322 .44694 L .47045 .44445 L p F P
0 g
s
.167 0 .082 r
.54017 .34116 m .54063 .34019 L .53163 .34516 L p F P
0 g
s
.167 0 .082 r
.53292 .34653 m .54017 .34116 L p .53163 .34516 L F P
0 g
s
.167 0 .082 r
.53163 .34516 m .53039 .34794 L .53292 .34653 L p F P
0 g
s
.314 .652 .97 r
.2166 .42031 m .21848 .42053 L .2232 .42315 L p F P
0 g
s
.333 .657 .972 r
.2259 .42128 m .21848 .42053 L .2232 .42315 L p F P
0 g
s
.333 .657 .972 r
.2232 .42315 m .22908 .42377 L .2259 .42128 L p F P
0 g
s
.237 .21 .624 r
.76543 .25439 m .76342 .25846 L .76225 .25297 L p F P
0 g
s
.237 .21 .624 r
.76225 .25297 m .76333 .25078 L .76543 .25439 L p F P
0 g
s
.41 .083 .297 r
.50837 .3659 m .50931 .36267 L .49939 .3664 L p F P
0 g
s
.41 .083 .297 r
.49939 .3664 m .49844 .36964 L .50837 .3659 L p F P
0 g
s
.415 .452 .79 r
.75531 .2315 m .75564 .23236 L .76079 .23444 L p F P
0 g
s
.161 .545 .926 r
.17712 .40077 m .1811 .40371 L .1745 .40183 L p F P
0 g
s
.161 .545 .926 r
.1745 .40183 m .17048 .39892 L .17712 .40077 L p F P
0 g
s
.117 .52 .912 r
.16989 .39873 m .17048 .39892 L .1745 .40183 L p F P
0 g
s
.55 .752 .971 r
.31623 .44437 m .3142 .44271 L .31204 .44302 L closepath p F P
0 g
s
.676 .949 .957 r
.61845 .41443 m .61538 .41598 L .61797 .41431 L closepath p F P
0 g
s
.682 .94 .964 r
.61598 .41369 m .61797 .41431 L .61538 .41598 L p F P
0 g
s
.682 .94 .964 r
.60578 .41872 m .61598 .41369 L p .61538 .41598 L F P
0 g
s
0 0 0 r
.57551 .30957 m .57295 .31183 L .57178 .31323 L p F P
0 g
s
0 0 0 r
.7509 .30471 m .7488 .30777 L .75134 .30248 L p F P
0 g
s
0 0 0 r
.75134 .30248 m .75169 .30198 L .7509 .30471 L p F P
0 g
s
0 0 0 r
.58301 .30303 m .57551 .30957 L .58138 .30464 L closepath p F P
0 g
s
0 0 0 r
.58055 .30549 m .58138 .30464 L .57551 .30957 L p F P
0 g
s
0 0 0 r
.57641 .30931 m .58055 .30549 L p .57551 .30957 L F P
0 g
s
0 0 0 r
.57178 .31323 m .57641 .30931 L p .57551 .30957 L F P
0 g
s
.521 .746 .977 r
.28883 .4403 m .29844 .43926 L .3015 .44169 L p F P
0 g
s
.539 .742 .97 r
.29844 .43926 m .28883 .4403 L .28575 .43791 L p F P
0 g
s
.478 .506 .808 r
.7531 .22626 m .75712 .22711 L .75531 .2315 L closepath p F P
0 g
s
.415 .452 .79 r
.76319 .22927 m .75712 .22711 L .75531 .2315 L p F P
0 g
s
.415 .452 .79 r
.76079 .23444 m .76319 .22927 L p .75531 .2315 L F P
0 g
s
.732 .214 0 r
.24938 .31449 m .24797 .31274 L .24479 .31059 L p F P
0 g
s
.369 .68 .978 r
.23225 .42619 m .23781 .42655 L .24272 .42908 L p F P
0 g
s
.379 .682 .977 r
.23781 .42655 m .23225 .42619 L .22908 .42377 L p F P
0 g
s
0 0 0 r
.74348 .31653 m .74235 .31871 L .74575 .31324 L closepath p F P
0 g
s
.729 .812 .917 r
.70461 .21576 m .6991 .21856 L .69672 .21599 L p F P
0 g
s
.757 .819 .901 r
.68647 .22209 m .69672 .21599 L .6991 .21856 L p F P
0 g
s
.66 .89 .98 r
.56753 .42879 m .57012 .43009 L .55996 .43412 L p F P
0 g
s
.66 .89 .98 r
.55794 .43259 m .56753 .42879 L p .55996 .43412 L F P
0 g
s
.66 .89 .98 r
.55996 .43412 m .5574 .43284 L .55794 .43259 L p F P
0 g
s
.681 .922 .972 r
.59891 .42196 m .59558 .4235 L .59306 .42251 L p F P
0 g
s
.67 .919 .975 r
.58287 .42702 m .59306 .42251 L .59558 .4235 L p F P
0 g
s
.757 .411 .397 r
.34614 .38333 m .34617 .38334 L .34758 .38029 L p F P
0 g
s
.757 .411 .397 r
.34758 .38029 m .34446 .37961 L .34614 .38333 L p F P
0 g
s
.594 .642 .867 r
.73747 .21684 m .73781 .21679 L .73767 .21719 L closepath p F P
0 g
s
.559 .619 .868 r
.74811 .21563 m .73781 .21679 L .73767 .21719 L p F P
0 g
s
.559 .619 .868 r
.75059 .22068 m .74811 .21563 L p .73767 .21719 L F P
0 g
s
.733 .206 0 r
.25876 .3239 m .25609 .32068 L .26039 .32355 L p F P
0 g
s
.733 .206 0 r
.26283 .32653 m .25876 .3239 L p .26039 .32355 L F P
0 g
s
.733 .206 0 r
.26039 .32355 m .26307 .32664 L .26283 .32653 L p F P
0 g
s
0 0 0 r
.58388 .30225 m .58301 .30303 L .58138 .30464 L p F P
0 g
s
.542 .872 .602 r
.59081 .2958 m .58388 .30225 L .59205 .29501 L p F P
0 g
s
0 0 0 r
.59063 .29594 m .59081 .2958 L .58388 .30225 L p F P
0 g
s
0 0 0 r
.58389 .3023 m .59063 .29594 L p .58388 .30225 L F P
0 g
s
0 0 0 r
.58138 .30464 m .58389 .3023 L p .58388 .30225 L F P
0 g
s
.709 .986 .866 r
.68145 .37938 m .67417 .38459 L .67303 .38469 L p F P
0 g
s
.656 .876 .981 r
.55736 .43282 m .5574 .43284 L .54783 .43697 L p F P
0 g
s
.656 .876 .981 r
.54783 .43697 m .54721 .43663 L .55736 .43282 L p F P
0 g
s
.599 .073 0 r
.22972 .29673 m .23198 .2991 L .23565 .30225 L p F P
0 g
s
.598 .072 0 r
.23493 .30217 m .23865 .3053 L .23565 .30225 L p F P
0 g
s
.598 .072 0 r
.23565 .30225 m .23198 .2991 L .23493 .30217 L p F P
0 g
s
.585 .066 0 r
.23198 .2991 m .22972 .29673 L .22655 .29391 L p F P
0 g
s
.625 .754 .939 r
.34266 .44637 m .35245 .44384 L .35541 .4466 L p F P
0 g
s
.641 .746 .925 r
.35245 .44384 m .34266 .44637 L .33968 .44372 L p F P
0 g
s
.495 .177 .357 r
.47698 .3783 m .48157 .37786 L .47675 .37921 L closepath p F P
0 g
s
0 0 0 r
.73452 .32939 m .73379 .33036 L .7343 .32972 L closepath p F P
0 g
s
.701 .968 .934 r
.64745 .40025 m .64127 .40385 L .63887 .40347 L p F P
0 g
s
.774 .404 .357 r
.3322 .37309 m .33063 .37542 L .32903 .37221 L closepath p F P
0 g
s
.78 .882 .92 r
.68586 .22249 m .67627 .22873 L .67408 .22704 L p F P
0 g
s
.577 .283 .433 r
.45688 .38669 m .45381 .38725 L .45315 .39095 L p F P
0 g
s
0 .14 .648 r
.21165 .28066 m .21148 .28051 L .20832 .27718 L p F P
0 g
s
.197 .142 .566 r
.76422 .26339 m .76419 .26344 L .7628 .25957 L p F P
0 g
s
.197 .142 .566 r
.7628 .25957 m .76342 .25846 L .76422 .26339 L p F P
0 g
s
.553 .882 .618 r
.59308 .2941 m .59205 .29501 L .59283 .29428 L closepath p F P
0 g
s
.542 .872 .602 r
.59205 .29501 m .59283 .29428 L .59081 .2958 L p F P
0 g
s
.068 0 0 r
.55027 .33288 m .55065 .33217 L .54195 .33755 L p F P
0 g
s
.068 0 0 r
.5434 .33846 m .55027 .33288 L p .54195 .33755 L F P
0 g
s
.068 0 0 r
.54195 .33755 m .54063 .34019 L .5434 .33846 L p F P
0 g
s
.822 .399 .238 r
.2999 .35365 m .30132 .35625 L .29756 .35447 L closepath p F P
0 g
s
.673 .382 .472 r
.41694 .39422 m .41172 .39426 L .41335 .39807 L p F P
0 g
s
.678 .384 .469 r
.40328 .39803 m .41335 .39807 L .41172 .39426 L p F P
0 g
s
.678 .384 .469 r
.41172 .39426 m .40395 .39424 L .40328 .39803 L p F P
0 g
s
.564 .887 .62 r
.60016 .28779 m .59308 .2941 L .59283 .29428 L p F P
0 g
s
.608 .659 .874 r
.73781 .21679 m .73747 .21684 L .73505 .21269 L p F P
0 g
s
.459 .138 .333 r
.49757 .37298 m .49844 .36964 L .48821 .37296 L p F P
0 g
s
.459 .138 .333 r
.48821 .37296 m .48731 .3763 L .49757 .37298 L p F P
0 g
s
0 .369 .823 r
.13587 .3771 m .13551 .37691 L .13905 .38005 L p F P
0 g
s
0 .369 .823 r
.13905 .38005 m .13915 .38011 L .13587 .3771 L p F P
0 g
s
.691 .396 .471 r
.40159 .39798 m .40328 .39803 L .40395 .39424 L p F P
0 g
s
.691 .396 .471 r
.40395 .39424 m .40014 .39411 L .40159 .39798 L p F P
0 g
s
.655 .366 .468 r
.42489 .39386 m .41694 .39422 L .41632 .39804 L p F P
0 g
s
.673 .382 .472 r
.41335 .39807 m .41632 .39804 L .41694 .39422 L p F P
0 g
s
.586 .844 .486 r
.73274 .33147 m .72873 .33654 L .73379 .33036 L p F P
0 g
s
.586 .844 .486 r
.73379 .33036 m .7343 .32972 L .73274 .33147 L p F P
0 g
s
0 0 0 r
.75239 .30235 m .7509 .30471 L .75169 .30198 L p F P
0 g
s
0 0 0 r
.75169 .30198 m .75476 .29711 L .75239 .30235 L p F P
0 g
s
.66 .951 .718 r
.60315 .28513 m .60016 .28779 L .60232 .28555 L closepath p F P
0 g
s
.564 .887 .62 r
.60071 .28641 m .60232 .28555 L .60016 .28779 L p F P
0 g
s
.564 .887 .62 r
.59865 .28835 m .60071 .28641 L p .60016 .28779 L F P
0 g
s
.564 .887 .62 r
.59283 .29428 m .59865 .28835 L p .60016 .28779 L F P
0 g
s
0 .407 .849 r
.1441 .38242 m .13915 .38011 L .13587 .3771 L p F P
0 g
s
0 .14 .648 r
.20832 .27718 m .20845 .27729 L .21165 .28066 L p F P
0 g
s
0 .126 .634 r
.21182 .28014 m .21503 .28351 L .21165 .28066 L p F P
0 g
s
0 .126 .634 r
.21165 .28066 m .20845 .27729 L .21182 .28014 L p F P
0 g
s
.7 .403 .47 r
.391 .39747 m .40159 .39798 L .40014 .39411 L p F P
0 g
s
.7 .403 .47 r
.39014 .39481 m .391 .39747 L p .40014 .39411 L F P
0 g
s
.7 .403 .47 r
.40014 .39411 m .39037 .3936 L .39014 .39481 L p F P
0 g
s
.661 .951 .718 r
.60829 .28055 m .60315 .28513 L .60232 .28555 L p F P
0 g
s
.608 .659 .874 r
.73505 .21269 m .73939 .21187 L .73781 .21679 L p F P
0 g
s
.583 .616 .851 r
.74566 .21087 m .73939 .21187 L .73781 .21679 L p F P
0 g
s
.583 .616 .851 r
.73781 .21679 m .74811 .21563 L .74566 .21087 L p F P
0 g
s
.454 .721 .982 r
.26049 .4341 m .26525 .43397 L .27067 .4363 L p F P
0 g
s
.465 .724 .981 r
.26525 .43397 m .26049 .4341 L .25736 .43173 L p F P
0 g
s
.818 .413 .283 r
.30315 .35987 m .30879 .36219 L .30682 .35862 L p F P
0 g
s
.818 .413 .283 r
.30682 .35862 m .30132 .35625 L .30315 .35987 L p F P
0 g
s
.737 .988 .792 r
.61322 .27618 m .60829 .28055 L .61171 .27664 L closepath p F P
0 g
s
.661 .951 .718 r
.61079 .27695 m .61171 .27664 L .60829 .28055 L p F P
0 g
s
.661 .951 .718 r
.6061 .28135 m .61079 .27695 L p .60829 .28055 L F P
0 g
s
.661 .951 .718 r
.60232 .28555 m .6061 .28135 L p .60829 .28055 L F P
0 g
s
.821 .366 .146 r
.28143 .34133 m .28166 .34171 L .28649 .34435 L p F P
0 g
s
.831 .388 .18 r
.28366 .34523 m .28861 .34784 L .28649 .34435 L p F P
0 g
s
.831 .388 .18 r
.28649 .34435 m .28166 .34171 L .28366 .34523 L p F P
0 g
s
.689 .952 .954 r
.62639 .40851 m .62865 .40905 L .61845 .41443 L p F P
0 g
s
.689 .952 .954 r
.61845 .41443 m .61797 .41431 L .62639 .40851 L p F P
0 g
s
.732 .987 .793 r
.6165 .27329 m .61322 .27618 L .61171 .27664 L p F P
0 g
s
.787 .998 .843 r
.62329 .26732 m .6165 .27329 L .62101 .26758 L closepath p F P
0 g
s
.732 .987 .793 r
.62088 .2676 m .62101 .26758 L .6165 .27329 L p F P
0 g
s
.732 .987 .793 r
.61362 .27432 m .62088 .2676 L p .6165 .27329 L F P
0 g
s
.732 .987 .793 r
.61171 .27664 m .61362 .27432 L p .6165 .27329 L F P
0 g
s
.654 .365 .469 r
.42944 .39363 m .42489 .39386 L .42682 .39756 L p F P
0 g
s
.655 .366 .468 r
.41632 .39804 m .42682 .39756 L .42489 .39386 L p F P
0 g
s
.045 .464 .881 r
.15447 .3899 m .15687 .39083 L .16068 .39384 L p F P
0 g
s
.084 .488 .897 r
.16275 .39294 m .16654 .39596 L .16068 .39384 L p F P
0 g
s
.084 .488 .897 r
.16068 .39384 m .15687 .39083 L .16275 .39294 L p F P
0 g
s
.642 .749 .927 r
.35541 .4466 m .36524 .44375 L .36817 .44665 L p F P
0 g
s
.658 .738 .909 r
.36524 .44375 m .35541 .4466 L .35245 .44384 L p F P
0 g
s
.771 .428 .406 r
.33887 .38163 m .34614 .38333 L .34446 .37961 L p F P
0 g
s
.771 .428 .406 r
.34446 .37961 m .33738 .37784 L .33887 .38163 L p F P
0 g
s
.697 .959 .706 r
.71525 .35122 m .71463 .35154 L .71667 .34956 L closepath p F P
0 g
s
.579 .281 .427 r
.46509 .38523 m .45688 .38669 L .46183 .38934 L p F P
0 g
s
.577 .283 .433 r
.45315 .39095 m .46183 .38934 L .45688 .38669 L p F P
0 g
s
.459 .719 .981 r
.26999 .43379 m .26525 .43397 L .27067 .4363 L p F P
0 g
s
.459 .719 .981 r
.27067 .4363 m .2731 .43623 L .26999 .43379 L p F P
0 g
s
.778 .998 .845 r
.62486 .26598 m .62329 .26732 L .62101 .26758 L p F P
0 g
s
.74 .418 .437 r
.36215 .3866 m .36183 .38764 L .36138 .38647 L closepath p F P
0 g
s
0 .245 .732 r
.11742 .36253 m .1167 .36204 L .12003 .3653 L p F P
0 g
s
0 .245 .732 r
.12003 .3653 m .12071 .36576 L .11742 .36253 L p F P
0 g
s
.802 .999 .844 r
.62486 .26598 m .63337 .25864 L .63097 .2585 L p F P
0 g
s
.802 .999 .844 r
.63097 .2585 m .62922 .26007 L .62486 .26598 L p F P
0 g
s
.778 .998 .845 r
.62125 .26726 m .62922 .26007 L .62486 .26598 L p F P
0 g
s
.778 .998 .845 r
.62101 .26758 m .62125 .26726 L p .62486 .26598 L F P
0 g
s
.632 .345 .465 r
.44055 .39258 m .42944 .39363 L .42885 .39746 L p F P
0 g
s
.654 .365 .469 r
.42682 .39756 m .42885 .39746 L .42944 .39363 L p F P
0 g
s
.382 .683 .978 r
.24162 .42674 m .23781 .42655 L .24272 .42908 L p F P
0 g
s
.382 .683 .978 r
.24272 .42908 m .24478 .4292 L .24162 .42674 L p F P
0 g
s
0 0 .186 r
.75845 .28916 m .75662 .29206 L .75794 .28721 L p F P
0 g
s
0 0 .186 r
.75794 .28721 m .7588 .28584 L .75845 .28916 L p F P
0 g
s
.708 .411 .472 r
.39037 .3936 m .39014 .39481 L .38973 .39355 L closepath p F P
0 g
s
.676 .934 .968 r
.60578 .41872 m .59891 .42196 L .6048 .4184 L closepath p F P
0 g
s
.681 .922 .972 r
.60327 .4178 m .6048 .4184 L .59891 .42196 L p F P
0 g
s
.681 .922 .972 r
.59306 .42251 m .60327 .4178 L p .59891 .42196 L F P
0 g
s
.587 .894 .614 r
.59127 .29532 m .59081 .2958 L .59283 .29428 L p F P
0 g
s
.587 .894 .614 r
.59283 .29428 m .59865 .28835 L .59127 .29532 L p F P
0 g
s
.695 .982 .836 r
.68432 .37725 m .68145 .37938 L .68361 .37737 L closepath p F P
0 g
s
.709 .986 .866 r
.68205 .37745 m .68361 .37737 L .68145 .37938 L p F P
0 g
s
.709 .986 .866 r
.67646 .38147 m .68205 .37745 L p .68145 .37938 L F P
0 g
s
.709 .986 .866 r
.67303 .38469 m .67646 .38147 L p .68145 .37938 L F P
0 g
s
.739 .417 .438 r
.35474 .3889 m .35342 .38503 L .36138 .38647 L p F P
0 g
s
.739 .417 .438 r
.3611 .39003 m .35474 .3889 L p .36138 .38647 L F P
0 g
s
.739 .417 .438 r
.36138 .38647 m .36183 .38764 L .3611 .39003 L p F P
0 g
s
.62 .858 .494 r
.73318 .33087 m .73274 .33147 L .7343 .32972 L p F P
0 g
s
.62 .858 .494 r
.7343 .32972 m .73792 .3248 L .73318 .33087 L p F P
0 g
s
.704 .409 .474 r
.38119 .39668 m .38005 .39272 L .38973 .39355 L p F P
0 g
s
.704 .409 .474 r
.38967 .39738 m .38119 .39668 L p .38973 .39355 L F P
0 g
s
.704 .409 .474 r
.38973 .39355 m .39014 .39481 L .38967 .39738 L p F P
0 g
s
0 0 0 r
.56037 .32404 m .56048 .32387 L .55207 .32969 L p F P
0 g
s
0 0 0 r
.55253 .33086 m .56037 .32404 L p .55207 .32969 L F P
0 g
s
0 0 0 r
.55207 .32969 m .55065 .33217 L .55253 .33086 L p F P
0 g
s
.019 0 .393 r
.76475 .272 m .76171 .27729 L .76176 .2729 L p F P
0 g
s
.019 0 .393 r
.76477 .27029 m .76475 .272 L p .76176 .2729 L F P
0 g
s
.019 0 .393 r
.76176 .2729 m .76467 .26783 L .76477 .27029 L p F P
0 g
s
.775 .405 .355 r
.32422 .37392 m .32257 .3702 L .32903 .37221 L p F P
0 g
s
.775 .405 .355 r
.33041 .37574 m .32422 .37392 L p .32903 .37221 L F P
0 g
s
.775 .405 .355 r
.32903 .37221 m .33063 .37542 L .33041 .37574 L p F P
0 g
s
.598 .059 0 r
.24161 .30825 m .23865 .3053 L .24252 .30836 L p F P
0 g
s
.598 .059 0 r
.24252 .30836 m .24479 .31059 L .24161 .30825 L p F P
0 g
s
.801 .31 .005 r
.26307 .32664 m .26314 .32675 L .26747 .3296 L p F P
0 g
s
.815 .335 .041 r
.26536 .33016 m .26977 .33298 L .26747 .3296 L p F P
0 g
s
.815 .335 .041 r
.26747 .3296 m .26314 .32675 L .26536 .33016 L p F P
0 g
s
.811 .986 .886 r
.6334 .25865 m .63337 .25864 L .63346 .25857 L closepath p F P
0 g
s
.661 .866 .977 r
.55736 .43282 m .54721 .43663 L .54457 .43503 L p F P
0 g
s
.653 .863 .979 r
.53443 .43867 m .54457 .43503 L .54721 .43663 L p F P
0 g
s
.325 .654 .97 r
.21848 .42053 m .2166 .42031 L .2134 .41784 L p F P
0 g
s
.511 .209 .39 r
.48157 .37786 m .47675 .37921 L .476 .38275 L p F P
0 g
s
.559 .753 .968 r
.3015 .44169 m .30571 .44103 L .31204 .44302 L p F P
0 g
s
.554 .746 .966 r
.31117 .44014 m .30571 .44103 L .31204 .44302 L p F P
0 g
s
.554 .746 .966 r
.31204 .44302 m .3142 .44271 L .31117 .44014 L p F P
0 g
s
.801 .992 .878 r
.63346 .25857 m .63337 .25864 L .63097 .2585 L p F P
0 g
s
.825 .974 .891 r
.63752 .25277 m .63346 .25857 L .64255 .25099 L p F P
0 g
s
.801 .992 .878 r
.63097 .2585 m .63752 .25277 L .63346 .25857 L p F P
0 g
s
.654 .744 .916 r
.36817 .44665 m .37803 .44353 L .38094 .44656 L p F P
0 g
s
.67 .729 .894 r
.37803 .44353 m .36817 .44665 L .36524 .44375 L p F P
0 g
s
.574 .757 .965 r
.30571 .44103 m .3015 .44169 L .29844 .43926 L p F P
0 g
s
.352 .017 .25 r
.51915 .35575 m .50989 .36088 L .50931 .36267 L p F P
0 g
s
.634 .892 .564 r
.73251 .33166 m .73274 .33147 L .72873 .33654 L p F P
0 g
s
.634 .892 .564 r
.72762 .33723 m .73251 .33166 L p .72873 .33654 L F P
0 g
s
.634 .892 .564 r
.72418 .34163 m .72762 .33723 L p .72873 .33654 L F P
0 g
s
.634 .892 .564 r
.72873 .33654 m .72463 .34122 L .72418 .34163 L p F P
0 g
s
.71 .986 .835 r
.692 .37134 m .68432 .37725 L .68361 .37737 L p F P
0 g
s
.155 .114 .556 r
.76675 .25829 m .76422 .26339 L .76342 .25846 L p F P
0 g
s
.155 .114 .556 r
.76342 .25846 m .76543 .25439 L .76675 .25829 L p F P
0 g
s
0 .134 .635 r
.21849 .28635 m .22184 .28966 L .21835 .28683 L p F P
0 g
s
0 .134 .635 r
.21835 .28683 m .21503 .28351 L .21849 .28635 L p F P
0 g
s
.181 .562 .934 r
.1863 .4074 m .1854 .40667 L .18515 .40661 L closepath p F P
0 g
s
.469 .516 .824 r
.75077 .22108 m .7531 .22626 L .75712 .22711 L p F P
0 g
s
.695 .973 .92 r
.65147 .39783 m .64745 .40025 L .65064 .39775 L closepath p F P
0 g
s
.701 .968 .934 r
.64908 .39747 m .65064 .39775 L .64745 .40025 L p F P
0 g
s
.701 .968 .934 r
.63887 .40347 m .64908 .39747 L p .64745 .40025 L F P
0 g
s
.739 .802 .902 r
.70461 .21576 m .7094 .21332 L .70702 .2104 L p F P
0 g
s
.739 .802 .902 r
.70702 .2104 m .70636 .21076 L .70461 .21576 L p F P
0 g
s
.729 .812 .917 r
.69672 .21599 m .70636 .21076 L .70461 .21576 L p F P
0 g
s
.789 .396 .31 r
.31572 .36468 m .31522 .36516 L .31479 .36437 L closepath p F P
0 g
s
.695 .942 .961 r
.62621 .40845 m .62639 .40851 L .61797 .41431 L p F P
0 g
s
.695 .942 .961 r
.61797 .41431 m .61598 .41369 L .62621 .40845 L p F P
0 g
s
.662 .738 .907 r
.38094 .44656 m .39083 .44323 L .39371 .44637 L p F P
0 g
s
.677 .72 .882 r
.39083 .44323 m .38094 .44656 L .37803 .44353 L p F P
0 g
s
0 .283 .761 r
.12071 .36576 m .12421 .36794 L .12761 .37116 L p F P
0 g
s
0 .289 .768 r
.12421 .36794 m .12071 .36576 L .11742 .36253 L p F P
0 g
s
.056 .466 .885 r
.15687 .39083 m .15447 .3899 L .1512 .38703 L p F P
0 g
s
0 0 0 r
.74949 .30778 m .74575 .31324 L .7488 .30777 L p F P
0 g
s
0 0 0 r
.75011 .30667 m .74949 .30778 L p .7488 .30777 L F P
0 g
s
0 0 0 r
.7488 .30777 m .7509 .30471 L .75011 .30667 L p F P
0 g
s
.818 .384 .21 r
.29065 .35136 m .29599 .3538 L .2938 .35033 L p F P
0 g
s
.818 .384 .21 r
.2938 .35033 m .28861 .34784 L .29065 .35136 L p F P
0 g
s
.824 .972 .893 r
.64347 .25022 m .64255 .25099 L .64311 .25013 L closepath p F P
0 g
s
.825 .974 .891 r
.64107 .24965 m .63752 .25277 L p .64255 .25099 L F P
0 g
s
.825 .974 .891 r
.64255 .25099 m .64311 .25013 L .64107 .24965 L p F P
0 g
s
.652 .828 .968 r
.51896 .4385 m .52 .43927 L .50977 .44254 L p F P
0 g
s
.652 .828 .968 r
.50977 .44254 m .50885 .44187 L .51896 .4385 L p F P
0 g
s
.813 .972 .9 r
.65221 .2432 m .64347 .25022 L .64311 .25013 L p F P
0 g
s
.78 .882 .92 r
.68409 .21996 m .68616 .22181 L .68586 .22249 L p F P
0 g
s
.78 .882 .92 r
.67433 .2266 m .68409 .21996 L p .68586 .22249 L F P
0 g
s
.78 .882 .92 r
.67408 .22704 m .67433 .2266 L p .68586 .22249 L F P
0 g
s
.779 .857 .908 r
.68647 .22209 m .68586 .22249 L .68616 .22181 L closepath p F P
0 g
s
.673 .913 .976 r
.59088 .42162 m .59306 .42251 L .58287 .42702 L p F P
0 g
s
.673 .913 .976 r
.58287 .42702 m .58192 .42662 L .59088 .42162 L p F P
0 g
s
.792 .397 .305 r
.31065 .36581 m .30879 .36219 L .31479 .36437 L p F P
0 g
s
.792 .397 .305 r
.31342 .36681 m .31065 .36581 L p .31479 .36437 L F P
0 g
s
.792 .397 .305 r
.31479 .36437 m .31522 .36516 L .31342 .36681 L p F P
0 g
s
.611 .882 .559 r
.72463 .34122 m .7231 .34291 L .72418 .34163 L closepath p F P
0 g
s
.726 .427 .471 r
.3754 .39601 m .38119 .39668 L .38005 .39272 L p F P
0 g
s
.726 .427 .471 r
.38005 .39272 m .37616 .39227 L .3754 .39601 L p F P
0 g
s
.24 .216 .629 r
.76799 .24921 m .76543 .25439 L .76333 .25078 L p F P
0 g
s
.24 .216 .629 r
.76333 .25078 m .76582 .24562 L .76799 .24921 L p F P
0 g
s
.77 .855 .914 r
.69434 .21351 m .69672 .21599 L .68647 .22209 L p F P
0 g
s
.77 .855 .914 r
.68862 .21711 m .69434 .21351 L p .68647 .22209 L F P
0 g
s
.77 .855 .914 r
.68647 .22209 m .68616 .22181 L .68862 .21711 L p F P
0 g
s
.667 .735 .901 r
.39371 .44637 m .40363 .44291 L .40649 .44614 L p F P
0 g
s
.68 .714 .874 r
.40363 .44291 m .39371 .44637 L .39083 .44323 L p F P
0 g
s
.693 .978 .799 r
.69446 .36936 m .692 .37134 L .69382 .36954 L closepath p F P
0 g
s
.71 .986 .835 r
.69222 .36975 m .69382 .36954 L .692 .37134 L p F P
0 g
s
.71 .986 .835 r
.68787 .37312 m .69222 .36975 L p .692 .37134 L F P
0 g
s
.71 .986 .835 r
.68361 .37737 m .68787 .37312 L p .692 .37134 L F P
0 g
s
.01 .43 .863 r
.14792 .38409 m .1441 .38242 L .14773 .38552 L p F P
0 g
s
.01 .43 .863 r
.14773 .38552 m .1512 .38703 L .14792 .38409 L p F P
0 g
s
.657 .853 .975 r
.54457 .43503 m .53443 .43867 L .53177 .43695 L p F P
0 g
s
.65 .85 .977 r
.52164 .44044 m .53177 .43695 L .53443 .43867 L p F P
0 g
s
.261 .615 .957 r
.20098 .41385 m .20102 .41386 L .20085 .41375 L closepath p F P
0 g
s
.67 .935 .652 r
.7215 .34378 m .71667 .34956 L .7231 .34291 L p F P
0 g
s
.67 .935 .652 r
.72254 .3427 m .7215 .34378 L p .7231 .34291 L F P
0 g
s
.67 .935 .652 r
.7231 .34291 m .72418 .34163 L .72254 .3427 L p F P
0 g
s
.634 .348 .468 r
.44147 .3925 m .44129 .39373 L .44055 .39258 L closepath p F P
0 g
s
.632 .345 .465 r
.44093 .39637 m .44129 .39373 L .44055 .39258 L p F P
0 g
s
.632 .345 .465 r
.42885 .39746 m .44093 .39637 L p .44055 .39258 L F P
0 g
s
.749 .428 .441 r
.36183 .38764 m .36276 .39033 L .3611 .39003 L closepath p F P
0 g
s
.323 .643 .967 r
.2051 .41236 m .20939 .41515 L .20102 .41386 L p F P
0 g
s
.323 .643 .967 r
.19776 .41124 m .2051 .41236 L p .20102 .41386 L F P
0 g
s
.323 .643 .967 r
.20102 .41386 m .20085 .41375 L .19776 .41124 L p F P
0 g
s
0 0 0 r
.56093 .32353 m .56048 .32387 L .56202 .32158 L p F P
0 g
s
0 0 0 r
.56202 .32158 m .56879 .31638 L .56093 .32353 L p F P
0 g
s
.732 .214 0 r
.24479 .31059 m .24547 .31145 L .24938 .31449 L p F P
0 g
s
.748 .235 0 r
.24797 .31472 m .25196 .31773 L .24938 .31449 L p F P
0 g
s
.748 .235 0 r
.24938 .31449 m .24547 .31145 L .24797 .31472 L p F P
0 g
s
.706 .411 .474 r
.39014 .39481 m .391 .39747 L .38967 .39738 L closepath p F P
0 g
s
.618 .334 .465 r
.45263 .39483 m .45315 .39095 L .44147 .3925 L p F P
0 g
s
.618 .334 .465 r
.44312 .39607 m .45263 .39483 L p .44147 .3925 L F P
0 g
s
.618 .334 .465 r
.44147 .3925 m .44129 .39373 L .44312 .39607 L p F P
0 g
s
.81 .333 .071 r
.27205 .33638 m .27677 .33908 L .27438 .33572 L p F P
0 g
s
.81 .333 .071 r
.27438 .33572 m .26977 .33298 L .27205 .33638 L p F P
0 g
s
.709 .982 .798 r
.70123 .36373 m .69446 .36936 L .69382 .36954 L p F P
0 g
s
.248 .602 .952 r
.20085 .41375 m .19776 .41124 L .19677 .41105 L closepath p F P
0 g
s
0 .32 .79 r
.12864 .37052 m .13204 .37373 L .12761 .37116 L p F P
0 g
s
0 .32 .79 r
.12761 .37116 m .12421 .36794 L .12864 .37052 L p F P
0 g
s
.71 .977 .917 r
.65931 .3912 m .66167 .39146 L .65147 .39783 L p F P
0 g
s
.71 .977 .917 r
.65596 .3933 m .65931 .3912 L p .65147 .39783 L F P
0 g
s
.71 .977 .917 r
.65147 .39783 m .65064 .39775 L .65596 .3933 L p F P
0 g
s
.189 .562 .935 r
.18217 .40398 m .1811 .40371 L .18515 .40661 L p F P
0 g
s
.189 .562 .935 r
.18515 .40661 m .1854 .40667 L .18217 .40398 L p F P
0 g
s
.668 .733 .899 r
.40649 .44614 m .41643 .44263 L .41928 .44588 L p F P
0 g
s
.681 .71 .87 r
.41643 .44263 m .40649 .44614 L .40363 .44291 L p F P
0 g
s
.503 .736 .978 r
.2731 .43623 m .28267 .43545 L .28575 .43791 L p F P
0 g
s
.512 .735 .974 r
.28267 .43545 m .2731 .43623 L .26999 .43379 L p F P
0 g
s
.421 .705 .981 r
.24478 .4292 m .25422 .4293 L .25736 .43173 L p F P
0 g
s
.437 .703 .978 r
.25422 .4293 m .24478 .4292 L .24162 .42674 L p F P
0 g
s
.553 .258 .42 r
.47536 .38644 m .476 .38275 L .46509 .38523 L p F P
0 g
s
.553 .258 .42 r
.46509 .38523 m .46441 .38889 L .47536 .38644 L p F P
0 g
s
.579 .281 .427 r
.46183 .38934 m .46441 .38889 L .46509 .38523 L p F P
0 g
s
.61 .749 .943 r
.32393 .44069 m .3142 .44271 L .31117 .44014 L p F P
0 g
s
0 0 .167 r
.75984 .28674 m .75845 .28916 L .7588 .28584 L p F P
0 g
s
0 0 .167 r
.7588 .28584 m .76106 .28191 L .75984 .28674 L p F P
0 g
s
.128 .521 .914 r
.16989 .39873 m .17048 .39892 L .16711 .3964 L closepath p F P
0 g
s
.729 .43 .472 r
.37217 .39562 m .3754 .39601 L .37616 .39227 L p F P
0 g
s
.729 .43 .472 r
.37616 .39227 m .37108 .39165 L .37217 .39562 L p F P
0 g
s
0 .128 .619 r
.22339 .29092 m .22184 .28966 L .22531 .2929 L p F P
0 g
s
0 .128 .619 r
.22531 .2929 m .22655 .29391 L .22339 .29092 L p F P
0 g
s
.824 .948 .902 r
.65358 .24209 m .65221 .2432 L .653 .24185 L closepath p F P
0 g
s
.813 .972 .9 r
.65119 .24112 m .653 .24185 L .65221 .2432 L p F P
0 g
s
.813 .972 .9 r
.64624 .24531 m .65119 .24112 L p .65221 .2432 L F P
0 g
s
.813 .972 .9 r
.64311 .25013 m .64624 .24531 L p .65221 .2432 L F P
0 g
s
.657 .693 .872 r
.72217 .21214 m .73263 .20874 L .73505 .21269 L p F P
0 g
s
.67 .71 .878 r
.73263 .20874 m .72217 .21214 L .71977 .20875 L p F P
0 g
s
.699 .745 .887 r
.7094 .21332 m .71977 .20875 L .72217 .21214 L p F P
0 g
s
.24 .591 .948 r
.19259 .4082 m .1854 .40667 L .18217 .40398 L p F P
0 g
s
.771 .857 .914 r
.68616 .22181 m .68409 .21996 L .68862 .21711 L closepath p F P
0 g
s
.812 .949 .911 r
.66265 .23513 m .65358 .24209 L .653 .24185 L p F P
0 g
s
.699 .96 .708 r
.71452 .35063 m .7215 .34378 L .71667 .34956 L p F P
0 g
s
.699 .96 .708 r
.71311 .35231 m .71452 .35063 L p .71667 .34956 L F P
0 g
s
.699 .96 .708 r
.71667 .34956 m .71463 .35154 L .71311 .35231 L p F P
0 g
s
.325 .654 .97 r
.2134 .41784 m .21383 .41789 L .21848 .42053 L p F P
0 g
s
.342 .658 .971 r
.22271 .41874 m .21383 .41789 L .21848 .42053 L p F P
0 g
s
.342 .658 .971 r
.21848 .42053 m .2259 .42128 L .22271 .41874 L p F P
0 g
s
.768 .443 .436 r
.34732 .38726 m .35474 .3889 L .35342 .38503 L p F P
0 g
s
.768 .443 .436 r
.34616 .38338 m .34732 .38726 L p .35342 .38503 L F P
0 g
s
.768 .443 .436 r
.35342 .38503 m .34617 .38334 L .34616 .38338 L p F P
0 g
s
.689 .969 .756 r
.70457 .36083 m .70123 .36373 L .70365 .36118 L closepath p F P
0 g
s
.709 .982 .798 r
.70237 .36148 m .70365 .36118 L .70123 .36373 L p F P
0 g
s
.709 .982 .798 r
.69784 .36525 m .70237 .36148 L p .70123 .36373 L F P
0 g
s
.709 .982 .798 r
.69382 .36954 m .69784 .36525 L p .70123 .36373 L F P
0 g
s
.668 .735 .901 r
.41928 .44588 m .42924 .44239 L .43206 .44561 L p F P
0 g
s
.679 .71 .872 r
.42924 .44239 m .41928 .44588 L .41643 .44263 L p F P
0 g
s
.824 .974 .891 r
.64311 .25013 m .64107 .24965 L .64624 .24531 L closepath p F P
0 g
s
.681 .955 .707 r
.71463 .35154 m .70939 .3565 L .71311 .35231 L closepath p F P
0 g
s
.51 .201 .379 r
.48731 .3763 m .48702 .37763 L .48157 .37786 L closepath p F P
0 g
s
.511 .209 .39 r
.48657 .37983 m .48702 .37763 L .48157 .37786 L p F P
0 g
s
.511 .209 .39 r
.476 .38275 m .48657 .37983 L p .48157 .37786 L F P
0 g
s
.79 .447 .407 r
.33217 .37972 m .33887 .38163 L .33738 .37784 L p F P
0 g
s
.79 .447 .407 r
.33738 .37784 m .33083 .37587 L .33217 .37972 L p F P
0 g
s
.706 .974 .756 r
.70939 .3565 m .70457 .36083 L .70365 .36118 L p F P
0 g
s
.683 .956 .711 r
.60232 .28555 m .60071 .28641 L .6061 .28135 L closepath p F P
0 g
s
.813 .428 .325 r
.31522 .36516 m .31654 .36804 L .31342 .36681 L closepath p F P
0 g
s
.706 .974 .756 r
.71248 .35253 m .71311 .35231 L .70939 .3565 L p F P
0 g
s
.706 .974 .756 r
.70666 .35778 m .71248 .35253 L p .70939 .3565 L F P
0 g
s
.706 .974 .756 r
.70365 .36118 m .70666 .35778 L p .70939 .3565 L F P
0 g
s
.656 .835 .969 r
.53 .43569 m .53177 .43695 L .52164 .44044 L p F P
0 g
s
.656 .835 .969 r
.52164 .44044 m .52 .43927 L .53 .43569 L p F P
0 g
s
.711 .758 .89 r
.71977 .20875 m .7094 .21332 L .70702 .2104 L p F P
0 g
s
.666 .741 .906 r
.43206 .44561 m .44205 .44217 L .44486 .4453 L p F P
0 g
s
.676 .715 .878 r
.44205 .44217 m .43206 .44561 L .42924 .44239 L p F P
0 g
s
.212 .569 .939 r
.17322 .3978 m .17712 .40077 L .17048 .39892 L p F P
0 g
s
.212 .569 .939 r
.16663 .39599 m .17322 .3978 L p .17048 .39892 L F P
0 g
s
.212 .569 .939 r
.17048 .39892 m .16711 .3964 L .16663 .39599 L p F P
0 g
s
.824 .364 .127 r
.28143 .34133 m .28166 .34171 L .28091 .34127 L closepath p F P
0 g
s
.686 .936 .966 r
.6135 .41288 m .61598 .41369 L .60578 .41872 L p F P
0 g
s
.686 .936 .966 r
.61283 .41321 m .6135 .41288 L p .60578 .41872 L F P
0 g
s
.686 .936 .966 r
.60578 .41872 m .6048 .4184 L .61283 .41321 L p F P
0 g
s
.727 .986 .894 r
.67303 .38469 m .67186 .38466 L .67646 .38147 L closepath p F P
0 g
s
.829 .421 .273 r
.29782 .35742 m .30315 .35987 L .30132 .35625 L p F P
0 g
s
.829 .421 .273 r
.29663 .35491 m .29782 .35742 L p .30132 .35625 L F P
0 g
s
.829 .421 .273 r
.30132 .35625 m .29756 .35447 L .29663 .35491 L p F P
0 g
s
.751 .235 0 r
.25453 .32099 m .25876 .3239 L .25609 .32068 L p F P
0 g
s
.751 .235 0 r
.25609 .32068 m .25196 .31773 L .25453 .32099 L p F P
0 g
s
.744 .445 .476 r
.36371 .39435 m .37217 .39562 L .37108 .39165 L p F P
0 g
s
.744 .445 .476 r
.37108 .39165 m .36276 .39033 L .36371 .39435 L p F P
0 g
s
.7 .956 .95 r
.63844 .40371 m .62865 .40905 L .62639 .40851 L p F P
0 g
s
.663 .75 .915 r
.44486 .4453 m .45486 .44195 L .45765 .44493 L p F P
0 g
s
.672 .724 .889 r
.45486 .44195 m .44486 .4453 L .44205 .44217 L p F P
0 g
s
.733 .99 .87 r
.68361 .37737 m .68205 .37745 L .68787 .37312 L closepath p F P
0 g
s
.657 .81 .956 r
.51896 .4385 m .50885 .44187 L .50614 .43967 L p F P
0 g
s
.653 .809 .958 r
.49605 .44296 m .50614 .43967 L .50885 .44187 L p F P
0 g
s
.806 .441 .365 r
.31805 .37181 m .32422 .37392 L .32257 .3702 L p F P
0 g
s
.806 .441 .365 r
.32257 .3702 m .31654 .36804 L .31805 .37181 L p F P
0 g
s
.721 .979 .914 r
.66205 .3915 m .66167 .39146 L .66329 .39041 L closepath p F P
0 g
s
.62 .751 .94 r
.32693 .44335 m .3367 .44092 L .33968 .44372 L p F P
0 g
s
.636 .744 .927 r
.3367 .44092 m .32693 .44335 L .32393 .44069 L p F P
0 g
s
.325 .316 .695 r
.76769 .24178 m .76582 .24562 L .76271 .24238 L p F P
0 g
s
.325 .316 .695 r
.76693 .23889 m .76769 .24178 L p .76271 .24238 L F P
0 g
s
.325 .316 .695 r
.76271 .24238 m .76517 .23721 L .76693 .23889 L p F P
0 g
s
.469 .516 .824 r
.75935 .22199 m .75092 .2207 L .75077 .22108 L p F P
0 g
s
.469 .516 .824 r
.75712 .22711 m .75935 .22199 L p .75077 .22108 L F P
0 g
s
.52 .557 .833 r
.75059 .22068 m .75092 .2207 L .75077 .22108 L closepath p F P
0 g
s
0 0 .059 r
.75788 .29216 m .75476 .29711 L .75662 .29206 L p F P
0 g
s
0 0 .059 r
.75662 .29206 m .75845 .28916 L .75788 .29216 L p F P
0 g
s
.614 .334 .469 r
.44129 .39373 m .44312 .39607 L .44093 .39637 L closepath p F P
0 g
s
.622 .669 .874 r
.73939 .21187 m .73505 .21269 L .73263 .20874 L p F P
0 g
s
.836 .391 .168 r
.27894 .34254 m .28366 .34523 L .28166 .34171 L p F P
0 g
s
.836 .391 .168 r
.27819 .34117 m .27894 .34254 L p .28166 .34171 L F P
0 g
s
.836 .391 .168 r
.28166 .34171 m .28091 .34127 L .27819 .34117 L p F P
0 g
s
.659 .763 .926 r
.45765 .44493 m .46767 .44165 L .47045 .44445 L p F P
0 g
s
.668 .738 .902 r
.46767 .44165 m .45765 .44493 L .45486 .44195 L p F P
0 g
s
.585 .066 0 r
.22655 .29391 m .22843 .29589 L .23198 .2991 L p F P
0 g
s
.588 .069 0 r
.23134 .29897 m .23493 .30217 L .23198 .2991 L p F P
0 g
s
.588 .069 0 r
.23198 .2991 m .22843 .29589 L .23134 .29897 L p F P
0 g
s
.47 .72 .978 r
.26688 .43128 m .25983 .43163 L .26525 .43397 L p F P
0 g
s
.47 .72 .978 r
.26525 .43397 m .26999 .43379 L .26688 .43128 L p F P
0 g
s
.465 .724 .981 r
.25736 .43173 m .25983 .43163 L .26525 .43397 L p F P
0 g
s
.671 .894 .978 r
.58031 .42586 m .57012 .43009 L .56753 .42879 L p F P
0 g
s
0 0 0 r
.7459 .31345 m .74949 .30778 L .74575 .31324 L p F P
0 g
s
0 0 0 r
.74231 .31878 m .7459 .31345 L p .74575 .31324 L F P
0 g
s
0 0 0 r
.74575 .31324 m .74235 .31871 L .74231 .31878 L p F P
0 g
s
0 0 0 r
.57178 .31323 m .57046 .31488 L .57641 .30931 L closepath p F P
0 g
s
.817 .922 .906 r
.66372 .2343 m .66265 .23513 L .66323 .23402 L closepath p F P
0 g
s
.812 .949 .911 r
.66133 .23296 m .66323 .23402 L .66265 .23513 L p F P
0 g
s
.812 .949 .911 r
.65553 .23764 m .66133 .23296 L p .66265 .23513 L F P
0 g
s
.812 .949 .911 r
.653 .24185 m .65553 .23764 L p .66265 .23513 L F P
0 g
s
.696 .943 .654 r
.72418 .34163 m .72254 .3427 L .72762 .33723 L closepath p F P
0 g
s
.574 .757 .965 r
.29844 .43926 m .29902 .43916 L .30571 .44103 L p F P
0 g
s
.569 .744 .959 r
.30813 .43748 m .29902 .43916 L .30571 .44103 L p F P
0 g
s
.569 .744 .959 r
.30571 .44103 m .31117 .44014 L .30813 .43748 L p F P
0 g
s
.536 .576 .843 r
.75092 .2207 m .75059 .22068 L .74811 .21563 L p F P
0 g
s
.658 .791 .946 r
.50614 .43967 m .49605 .44296 L .49332 .44056 L p F P
0 g
s
.654 .793 .949 r
.48325 .44381 m .49332 .44056 L .49605 .44296 L p F P
0 g
s
.656 .777 .938 r
.47045 .44445 m .48049 .44121 L .48325 .44381 L p F P
0 g
s
.664 .754 .917 r
.48049 .44121 m .47045 .44445 L .46767 .44165 L p F P
0 g
s
.108 .037 .486 r
.76419 .26344 m .76422 .26339 L .76429 .26413 L closepath p F P
0 g
s
.329 0 .21 r
.51998 .35531 m .51915 .35575 L .51994 .35541 L closepath p F P
0 g
s
.352 .017 .25 r
.51893 .35853 m .51994 .35541 L .51915 .35575 L p F P
0 g
s
.352 .017 .25 r
.50931 .36267 m .51893 .35853 L p .51915 .35575 L F P
0 g
s
.811 .922 .91 r
.6715 .22521 m .67389 .2269 L .66372 .2343 L p F P
0 g
s
.811 .922 .91 r
.66567 .22966 m .6715 .22521 L p .66372 .2343 L F P
0 g
s
.811 .922 .91 r
.66372 .2343 m .66323 .23402 L .66567 .22966 L p F P
0 g
s
.66 .772 .932 r
.49332 .44056 m .48325 .44381 L .48049 .44121 L p F P
0 g
s
.011 0 .456 r
.76736 .26245 m .76675 .25829 L .76422 .26339 L p F P
0 g
s
.011 0 .456 r
.76479 .2676 m .76736 .26245 L p .76422 .26339 L F P
0 g
s
.011 0 .456 r
.76422 .26339 m .76429 .26413 L .76479 .2676 L p F P
0 g
s
.536 .576 .843 r
.74811 .21563 m .75272 .21572 L .75092 .2207 L p F P
0 g
s
.509 .547 .83 r
.76037 .2197 m .75935 .22199 L .75092 .2207 L p F P
0 g
s
.509 .547 .83 r
.75896 .21634 m .76037 .2197 L p .75092 .2207 L F P
0 g
s
.509 .547 .83 r
.75092 .2207 m .75272 .21572 L .75896 .21634 L p F P
0 g
s
.677 .903 .976 r
.59052 .42145 m .59088 .42162 L .58192 .42662 L p F P
0 g
s
.677 .903 .976 r
.58192 .42662 m .58031 .42586 L .59052 .42145 L p F P
0 g
s
0 .373 .827 r
.13259 .37402 m .13204 .37373 L .13551 .37691 L p F P
0 g
s
0 .373 .827 r
.13551 .37691 m .13587 .3771 L .13259 .37402 L p F P
0 g
s
.366 .043 .279 r
.51798 .36173 m .51893 .35853 L .50931 .36267 L p F P
0 g
s
.366 .043 .279 r
.50931 .36267 m .50837 .3659 L .51798 .36173 L p F P
0 g
s
.283 0 .19 r
.52927 .35088 m .53007 .34872 L .51998 .35531 L p F P
0 g
s
.283 0 .19 r
.51998 .35531 m .51994 .35541 L .52927 .35088 L p F P
0 g
s
.379 .682 .977 r
.22908 .42377 m .23296 .42399 L .23781 .42655 L p F P
0 g
s
.391 .684 .977 r
.23846 .42423 m .23296 .42399 L .23781 .42655 L p F P
0 g
s
.391 .684 .977 r
.23781 .42655 m .24162 .42674 L .23846 .42423 L p F P
0 g
s
.805 .335 .11 r
.28091 .34127 m .27819 .34117 L .27677 .33908 L closepath p F P
0 g
s
.822 .951 .903 r
.653 .24185 m .65119 .24112 L .65553 .23764 L closepath p F P
0 g
s
.68 .409 .504 r
.41632 .39804 m .41335 .39807 L .41426 .40214 L p F P
0 g
s
.685 .412 .503 r
.40285 .4021 m .41426 .40214 L .41335 .39807 L p F P
0 g
s
.685 .412 .503 r
.41335 .39807 m .40328 .39803 L .40285 .4021 L p F P
0 g
s
.589 .311 .463 r
.46183 .38934 m .45315 .39095 L .45263 .39483 L p F P
0 g
s
.423 .107 .323 r
.5075 .36923 m .50837 .3659 L .49844 .36964 L p F P
0 g
s
.423 .107 .323 r
.49844 .36964 m .49757 .37298 L .5075 .36923 L p F P
0 g
s
.664 .394 .502 r
.42682 .39756 m .41632 .39804 L .41592 .40213 L p F P
0 g
s
.68 .409 .504 r
.41426 .40214 m .41592 .40213 L .41632 .39804 L p F P
0 g
s
.539 .742 .97 r
.29796 .43887 m .29844 .43926 L p .28575 .43791 L F P
0 g
s
.539 .742 .97 r
.28575 .43791 m .29318 .43698 L .29796 .43887 L p F P
0 g
s
.553 .744 .966 r
.29318 .43698 m .28575 .43791 L .28267 .43545 L p F P
0 g
s
.697 .423 .504 r
.40238 .40208 m .40285 .4021 L .40328 .39803 L p F P
0 g
s
.697 .423 .504 r
.40328 .39803 m .40159 .39798 L .40238 .40208 L p F P
0 g
s
0 0 .282 r
.76406 .27664 m .76106 .28191 L .76171 .27729 L p F P
0 g
s
0 0 .282 r
.76171 .27729 m .76475 .272 L .76406 .27664 L p F P
0 g
s
.301 0 .227 r
.52824 .35394 m .52927 .35088 L .51994 .35541 L p F P
0 g
s
.301 0 .227 r
.51994 .35541 m .51893 .35853 L .52824 .35394 L p F P
0 g
s
.389 .683 .977 r
.23296 .42399 m .22908 .42377 L .2259 .42128 L p F P
0 g
s
.705 .431 .508 r
.39165 .40162 m .40238 .40208 L .40159 .39798 L p F P
0 g
s
.705 .431 .508 r
.40159 .39798 m .391 .39747 L .39165 .40162 L p F P
0 g
s
.641 .746 .925 r
.33968 .44372 m .3495 .44087 L .35245 .44384 L p F P
0 g
s
.657 .736 .908 r
.3495 .44087 m .33968 .44372 L .3367 .44092 L p F P
0 g
s
.737 .992 .841 r
.69382 .36954 m .69222 .36975 L .69784 .36525 L closepath p F P
0 g
s
.056 .466 .885 r
.1512 .38703 m .15313 .38778 L .15687 .39083 L p F P
0 g
s
.098 .492 .901 r
.15904 .38987 m .16275 .39294 L .15687 .39083 L p F P
0 g
s
.098 .492 .901 r
.15687 .39083 m .15313 .38778 L .15904 .38987 L p F P
0 g
s
.568 .057 0 r
.22843 .29589 m .22655 .29391 L .22339 .29092 L p F P
0 g
s
.073 .01 .473 r
.76429 .26413 m .76479 .2676 L .76467 .26783 L closepath p F P
0 g
s
.798 .304 0 r
.26307 .32664 m .26314 .32675 L .26283 .32653 L closepath p F P
0 g
s
0 .407 .849 r
.13587 .3771 m .14054 .37928 L .1441 .38242 L p F P
0 g
s
0 .41 .853 r
.14054 .37928 m .13587 .3771 L .13259 .37402 L p F P
0 g
s
.741 .824 .916 r
.70636 .21076 m .69672 .21599 L .69434 .21351 L p F P
0 g
s
.4 .406 .75 r
.76598 .2355 m .76517 .23721 L .76079 .23444 L p F P
0 g
s
.4 .406 .75 r
.76415 .22979 m .76598 .2355 L p .76079 .23444 L F P
0 g
s
.4 .406 .75 r
.76079 .23444 m .76319 .22927 L .76415 .22979 L p F P
0 g
s
.82 .34 .033 r
.26111 .32726 m .26536 .33016 L .26314 .32675 L p F P
0 g
s
.82 .34 .033 r
.25986 .32528 m .26111 .32726 L p .26314 .32675 L F P
0 g
s
.82 .34 .033 r
.26314 .32675 m .26283 .32653 L .25986 .32528 L p F P
0 g
s
.725 .979 .917 r
.66329 .39041 m .66167 .39146 L .65931 .3912 L p F P
0 g
s
.719 .97 .933 r
.65064 .39775 m .64908 .39747 L .65596 .3933 L closepath p F P
0 g
s
.727 .212 0 r
.24547 .31145 m .24479 .31059 L .24161 .30825 L p F P
0 g
s
.816 .426 .313 r
.30486 .36354 m .31065 .36581 L .30879 .36219 L p F P
0 g
s
.816 .426 .313 r
.30879 .36219 m .30315 .35987 L .30486 .36354 L p F P
0 g
s
.193 0 .121 r
.53039 .34794 m .53007 .34872 L .53292 .34653 L closepath p F P
0 g
s
.587 .055 0 r
.23792 .30523 m .23493 .30217 L .23865 .3053 L p F P
0 g
s
.587 .055 0 r
.24112 .30786 m .23792 .30523 L p .23865 .3053 L F P
0 g
s
.587 .055 0 r
.23865 .3053 m .24161 .30825 L .24112 .30786 L p F P
0 g
s
.477 .172 .369 r
.4971 .37512 m .49757 .37298 L .48731 .3763 L p F P
0 g
s
.477 .172 .369 r
.48731 .3763 m .48702 .37763 L .4971 .37512 L p F P
0 g
s
.46 .481 .793 r
.76364 .22829 m .76319 .22927 L .75712 .22711 L p F P
0 g
s
.46 .481 .793 r
.76152 .2226 m .76364 .22829 L p .75712 .22711 L F P
0 g
s
.46 .481 .793 r
.75712 .22711 m .75935 .22199 L .76152 .2226 L p F P
0 g
s
.793 .428 .367 r
.33063 .37542 m .33083 .37587 L .33041 .37574 L closepath p F P
0 g
s
.762 .248 0 r
.26283 .32653 m .25986 .32528 L .25876 .3239 L closepath p F P
0 g
s
.662 .393 .503 r
.42885 .39746 m .42682 .39756 L .4279 .40158 L p F P
0 g
s
.664 .394 .502 r
.41592 .40213 m .4279 .40158 L .42682 .39756 L p F P
0 g
s
.832 .4 .21 r
.28559 .3488 m .29065 .35136 L .28861 .34784 L p F P
0 g
s
.832 .4 .21 r
.28861 .34784 m .28366 .34523 L .28559 .3488 L p F P
0 g
s
.762 .436 .434 r
.34617 .38334 m .34616 .38338 L .34614 .38333 L closepath p F P
0 g
s
.762 .436 .434 r
.34009 .38554 m .33887 .38163 L .34614 .38333 L p F P
0 g
s
.762 .436 .434 r
.34501 .38668 m .34009 .38554 L p .34614 .38333 L F P
0 g
s
.762 .436 .434 r
.34614 .38333 m .34616 .38338 L .34501 .38668 L p F P
0 g
s
.788 .885 .916 r
.67408 .22704 m .67389 .2269 L .67433 .2266 L closepath p F P
0 g
s
.716 .983 .898 r
.67186 .38466 m .66329 .39041 L .6698 .3846 L closepath p F P
0 g
s
.725 .979 .917 r
.66953 .38456 m .6698 .3846 L .66329 .39041 L p F P
0 g
s
.725 .979 .917 r
.65931 .3912 m .66953 .38456 L p .66329 .39041 L F P
0 g
s
.776 .451 .438 r
.34616 .38338 m .34732 .38726 L .34501 .38668 L closepath p F P
0 g
s
.477 .727 .98 r
.25983 .43163 m .25736 .43173 L .25422 .4293 L p F P
0 g
s
.711 .436 .507 r
.38923 .40146 m .39165 .40162 L .391 .39747 L p F P
0 g
s
.711 .436 .507 r
.391 .39747 m .38967 .39738 L .38923 .40146 L p F P
0 g
s
.646 .379 .5 r
.4406 .4005 m .44093 .39637 L .42885 .39746 L p F P
0 g
s
.646 .379 .5 r
.42885 .39746 m .42847 .40155 L .4406 .4005 L p F P
0 g
s
.662 .393 .503 r
.4279 .40158 m .42847 .40155 L .42885 .39746 L p F P
0 g
s
.658 .738 .909 r
.35245 .44384 m .36231 .44061 L .36524 .44375 L p F P
0 g
s
.674 .724 .888 r
.36231 .44061 m .35245 .44384 L .3495 .44087 L p F P
0 g
s
.753 .45 .472 r
.36028 .39373 m .36371 .39435 L .36276 .39033 L p F P
0 g
s
.753 .45 .472 r
.36276 .39033 m .3611 .39003 L .36028 .39373 L p F P
0 g
s
.75 .989 .783 r
.61171 .27664 m .61079 .27695 L .61362 .27432 L closepath p F P
0 g
s
.813 .924 .91 r
.66323 .23402 m .66133 .23296 L .66567 .22966 L closepath p F P
0 g
s
.718 .443 .508 r
.38178 .40085 m .38923 .40146 L .38967 .39738 L p F P
0 g
s
.718 .443 .508 r
.38967 .39738 m .38119 .39668 L .38178 .40085 L p F P
0 g
s
.664 .881 .979 r
.5574 .43284 m .55736 .43282 L .55794 .43259 L closepath p F P
0 g
s
.671 .869 .974 r
.55794 .43259 m .55736 .43282 L .55474 .43123 L p F P
0 g
s
.661 .866 .977 r
.54457 .43503 m .55474 .43123 L .55736 .43282 L p F P
0 g
s
.797 .45 .4 r
.32884 .37864 m .33217 .37972 L .33083 .37587 L p F P
0 g
s
.797 .45 .4 r
.33083 .37587 m .33041 .37574 L .32884 .37864 L p F P
0 g
s
0 .144 .652 r
.21528 .28298 m .21849 .28635 L .21503 .28351 L p F P
0 g
s
0 .144 .652 r
.21503 .28351 m .21182 .28014 L .21528 .28298 L p F P
0 g
s
.788 .896 .92 r
.67433 .2266 m .67389 .2269 L .6715 .22521 L p F P
0 g
s
.751 .448 .472 r
.35569 .39292 m .36028 .39373 L .3611 .39003 L p F P
0 g
s
.751 .448 .472 r
.3611 .39003 m .35474 .3889 L .35569 .39292 L p F P
0 g
s
.801 .897 .911 r
.67433 .2266 m .68409 .21996 L .68171 .21791 L p F P
0 g
s
.801 .897 .911 r
.68171 .21791 m .67712 .22121 L .67433 .2266 L p F P
0 g
s
.788 .896 .92 r
.6715 .22521 m .67712 .22121 L .67433 .2266 L p F P
0 g
s
.808 .386 .245 r
.29756 .35447 m .29663 .35491 L .29599 .3538 L closepath p F P
0 g
s
.691 .926 .969 r
.6048 .4184 m .60327 .4178 L .61283 .41321 L closepath p F P
0 g
s
.67 .729 .894 r
.36524 .44375 m .37513 .44019 L .37803 .44353 L p F P
0 g
s
.685 .712 .869 r
.37513 .44019 m .36524 .44375 L .36231 .44061 L p F P
0 g
s
0 0 0 r
.74235 .31871 m .74223 .31888 L .74231 .31878 L closepath p F P
0 g
s
0 0 0 r
.7509 .30471 m .75011 .30667 L .75239 .30235 L closepath p F P
0 g
s
.667 .881 .978 r
.56753 .42879 m .55794 .43259 L .5667 .42832 L closepath p F P
0 g
s
.671 .869 .974 r
.56493 .42727 m .5667 .42832 L .55794 .43259 L p F P
0 g
s
.671 .869 .974 r
.55474 .43123 m .56493 .42727 L p .55794 .43259 L F P
0 g
s
.786 .437 .395 r
.32568 .37772 m .32884 .37864 L .33041 .37574 L p F P
0 g
s
.786 .437 .395 r
.33041 .37574 m .32422 .37392 L .32568 .37772 L p F P
0 g
s
0 0 0 r
.7409 .32071 m .73792 .3248 L .74223 .31888 L p F P
0 g
s
0 0 0 r
.74223 .31888 m .74231 .31878 L .7409 .32071 L p F P
0 g
s
.683 .919 .972 r
.60075 .41675 m .60327 .4178 L .59306 .42251 L p F P
0 g
s
.683 .919 .972 r
.593 .42033 m .60075 .41675 L p .59306 .42251 L F P
0 g
s
.683 .919 .972 r
.59306 .42251 m .59088 .42162 L .593 .42033 L p F P
0 g
s
.093 0 .034 r
.54063 .34019 m .54017 .34116 L .5434 .33846 L closepath p F P
0 g
s
0 0 0 r
.58138 .30464 m .58055 .30549 L .58389 .3023 L closepath p F P
0 g
s
.527 .239 .42 r
.48596 .38354 m .48657 .37983 L .476 .38275 L p F P
0 g
s
.527 .239 .42 r
.476 .38275 m .47536 .38644 L .48596 .38354 L p F P
0 g
s
.607 .823 .425 r
.74187 .31928 m .7409 .32071 L .74231 .31878 L p F P
0 g
s
.607 .823 .425 r
.74231 .31878 m .7459 .31345 L .74187 .31928 L p F P
0 g
s
.821 .346 .068 r
.26753 .33359 m .27205 .33638 L .26977 .33298 L p F P
0 g
s
.821 .346 .068 r
.26977 .33298 m .26536 .33016 L .26753 .33359 L p F P
0 g
s
.33 .653 .97 r
.2134 .41784 m .21383 .41789 L .21239 .41704 L closepath p F P
0 g
s
.255 .602 .953 r
.19454 .40858 m .19259 .4082 L .19677 .41105 L p F P
0 g
s
.255 .602 .953 r
.19677 .41105 m .19776 .41124 L .19454 .40858 L p F P
0 g
s
.677 .72 .882 r
.37803 .44353 m .38795 .43971 L .39083 .44323 L p F P
0 g
s
.691 .7 .854 r
.38795 .43971 m .37803 .44353 L .37513 .44019 L p F P
0 g
s
.573 .758 .965 r
.29844 .43926 m .29902 .43916 L .29796 .43887 L closepath p F P
0 g
s
0 .289 .768 r
.11742 .36253 m .12088 .36469 L .12421 .36794 L p F P
0 g
s
.727 .212 0 r
.24161 .30825 m .24168 .30835 L .24547 .31145 L p F P
0 g
s
.748 .239 0 r
.24413 .31164 m .24797 .31472 L .24547 .31145 L p F P
0 g
s
.748 .239 0 r
.24547 .31145 m .24168 .30835 L .24413 .31164 L p F P
0 g
s
.738 .99 .808 r
.70365 .36118 m .70237 .36148 L .70666 .35778 L closepath p F P
0 g
s
.731 .452 .504 r
.3749 .40005 m .38178 .40085 L .38119 .39668 L p F P
0 g
s
.731 .452 .504 r
.38119 .39668 m .3754 .39601 L .3749 .40005 L p F P
0 g
s
.622 .669 .874 r
.73263 .20874 m .74166 .20669 L .73939 .21187 L p F P
0 g
s
.599 .637 .861 r
.74321 .20637 m .74166 .20669 L .73939 .21187 L p F P
0 g
s
.599 .637 .861 r
.73939 .21187 m .74566 .21087 L .74321 .20637 L p F P
0 g
s
.657 .829 .966 r
.52909 .43502 m .53 .43569 L .52 .43927 L p F P
0 g
s
.657 .829 .966 r
.52 .43927 m .51896 .4385 L .52909 .43502 L p F P
0 g
s
.022 .432 .866 r
.14465 .38107 m .14054 .37928 L .1441 .38242 L p F P
0 g
s
.022 .432 .866 r
.1441 .38242 m .14792 .38409 L .14465 .38107 L p F P
0 g
s
.696 .963 .941 r
.63887 .40347 m .63844 .40371 L .63878 .40346 L closepath p F P
0 g
s
.7 .956 .95 r
.63644 .40284 m .63878 .40346 L .63844 .40371 L p F P
0 g
s
.7 .956 .95 r
.62714 .40795 m .63644 .40284 L p .63844 .40371 L F P
0 g
s
.7 .956 .95 r
.62639 .40851 m .62714 .40795 L p .63844 .40371 L F P
0 g
s
0 0 0 r
.75572 .297 m .75239 .30235 L .75476 .29711 L p F P
0 g
s
0 0 0 r
.75774 .29259 m .75572 .297 L p .75476 .29711 L F P
0 g
s
0 0 0 r
.75476 .29711 m .75788 .29216 L .75774 .29259 L p F P
0 g
s
.198 .563 .936 r
.17892 .40123 m .17712 .40077 L .1811 .40371 L p F P
0 g
s
.198 .563 .936 r
.1811 .40371 m .18217 .40398 L .17892 .40123 L p F P
0 g
s
.068 .469 .888 r
.15313 .38778 m .1512 .38703 L .14792 .38409 L p F P
0 g
s
.38 .672 .974 r
.22115 .41747 m .22271 .41874 L .21383 .41789 L p F P
0 g
s
.38 .672 .974 r
.21889 .41607 m .22115 .41747 L p .21383 .41789 L F P
0 g
s
.38 .672 .974 r
.2102 .41526 m .21889 .41607 L p .21383 .41789 L F P
0 g
s
.38 .672 .974 r
.21383 .41789 m .21239 .41704 L .2102 .41526 L p F P
0 g
s
.68 .714 .874 r
.39083 .44323 m .40077 .43927 L .40363 .44291 L p F P
0 g
s
.693 .69 .843 r
.40077 .43927 m .39083 .44323 L .38795 .43971 L p F P
0 g
s
.231 0 .164 r
.53292 .34653 m .53007 .34872 L .52927 .35088 L p F P
0 g
s
.159 .118 .559 r
.76935 .2531 m .76675 .25829 L .76543 .25439 L p F P
0 g
s
.159 .118 .559 r
.76543 .25439 m .76799 .24921 L .76935 .2531 L p F P
0 g
s
.585 .757 .96 r
.30509 .43471 m .30813 .43748 L .29902 .43916 L p F P
0 g
s
.585 .757 .96 r
.29538 .43669 m .30509 .43471 L p .29902 .43916 L F P
0 g
s
.585 .757 .96 r
.29902 .43916 m .29796 .43887 L .29538 .43669 L p F P
0 g
s
.71 .966 .938 r
.64683 .39705 m .64908 .39747 L .63887 .40347 L p F P
0 g
s
.71 .966 .938 r
.63887 .40347 m .63878 .40346 L .64683 .39705 L p F P
0 g
s
.817 .447 .354 r
.31226 .36954 m .31805 .37181 L .31654 .36804 L p F P
0 g
s
.817 .447 .354 r
.31188 .36853 m .31226 .36954 L p .31654 .36804 L F P
0 g
s
.817 .447 .354 r
.31654 .36804 m .31342 .36681 L .31188 .36853 L p F P
0 g
s
.592 .312 .461 r
.46441 .38889 m .46409 .39127 L .46183 .38934 L closepath p F P
0 g
s
.589 .311 .463 r
.4639 .39276 m .46409 .39127 L .46183 .38934 L p F P
0 g
s
.589 .311 .463 r
.45263 .39483 m .4639 .39276 L p .46183 .38934 L F P
0 g
s
.812 .387 .234 r
.29262 .35492 m .29065 .35136 L .29599 .3538 L p F P
0 g
s
.812 .387 .234 r
.29446 .35575 m .29262 .35492 L p .29599 .3538 L F P
0 g
s
.812 .387 .234 r
.29599 .3538 m .29663 .35491 L .29446 .35575 L p F P
0 g
s
.129 .518 .914 r
.16711 .3964 m .16663 .39599 L .16654 .39596 L closepath p F P
0 g
s
0 .325 .797 r
.12531 .36726 m .12864 .37052 L .12421 .36794 L p F P
0 g
s
0 .325 .797 r
.12421 .36794 m .12088 .36469 L .12531 .36726 L p F P
0 g
s
.625 .364 .503 r
.44312 .39607 m .44093 .39637 L .4406 .4005 L p F P
0 g
s
.701 .939 .962 r
.62621 .40845 m .61598 .41369 L .6135 .41288 L p F P
0 g
s
.716 .957 .948 r
.64668 .39701 m .64683 .39705 L .63878 .40346 L p F P
0 g
s
.716 .957 .948 r
.63878 .40346 m .63644 .40284 L .64668 .39701 L p F P
0 g
s
.664 .857 .974 r
.55474 .43123 m .54457 .43503 L .54192 .43331 L p F P
0 g
s
.657 .853 .975 r
.53177 .43695 m .54192 .43331 L .54457 .43503 L p F P
0 g
s
.681 .71 .87 r
.40363 .44291 m .41359 .43891 L .41643 .44263 L p F P
0 g
s
.692 .684 .837 r
.41359 .43891 m .40363 .44291 L .40077 .43927 L p F P
0 g
s
.729 .986 .895 r
.67646 .38147 m .67186 .38466 L .6698 .3846 L p F P
0 g
s
.191 0 .108 r
.54017 .34116 m .53292 .34653 L .53941 .34298 L closepath p F P
0 g
s
.231 0 .164 r
.53828 .34588 m .53941 .34298 L .53292 .34653 L p F P
0 g
s
.231 0 .164 r
.52927 .35088 m .53828 .34588 L p .53292 .34653 L F P
0 g
s
0 .137 .636 r
.22023 .28776 m .21849 .28635 L .22184 .28966 L p F P
0 g
s
0 .137 .636 r
.22184 .28966 m .22339 .29092 L .22023 .28776 L p F P
0 g
s
.483 .185 .383 r
.49682 .37649 m .4971 .37512 L .48702 .37763 L p F P
0 g
s
.483 .185 .383 r
.48702 .37763 m .48657 .37983 L .49682 .37649 L p F P
0 g
s
.545 .743 .968 r
.29796 .43887 m .29538 .43669 L .29318 .43698 L closepath p F P
0 g
s
.552 .59 .846 r
.75272 .21572 m .74811 .21563 L .74566 .21087 L p F P
0 g
s
0 0 0 r
.55065 .33217 m .55027 .33288 L .55253 .33086 L closepath p F P
0 g
s
.306 .629 .962 r
.2051 .41236 m .19776 .41124 L .19454 .40858 L p F P
0 g
s
.477 .727 .98 r
.25422 .4293 m .25438 .42929 L .25983 .43163 L p F P
0 g
s
.482 .721 .976 r
.26376 .42872 m .25438 .42929 L .25983 .43163 L p F P
0 g
s
.482 .721 .976 r
.25983 .43163 m .26688 .43128 L .26376 .42872 L p F P
0 g
s
.627 .365 .502 r
.45263 .39483 m .44312 .39607 L .44462 .39995 L p F P
0 g
s
.625 .364 .503 r
.4406 .4005 m .44462 .39995 L .44312 .39607 L p F P
0 g
s
.67 .71 .878 r
.71977 .20875 m .73023 .20496 L .73263 .20874 L p F P
0 g
s
.683 .725 .882 r
.73023 .20496 m .71977 .20875 L .71738 .20549 L p F P
0 g
s
.711 .758 .89 r
.70702 .2104 m .71738 .20549 L .71977 .20875 L p F P
0 g
s
.679 .71 .872 r
.41643 .44263 m .42641 .43869 L .42924 .44239 L p F P
0 g
s
.689 .682 .838 r
.42641 .43869 m .41643 .44263 L .41359 .43891 L p F P
0 g
s
.734 .454 .505 r
.37274 .39979 m .3749 .40005 L .3754 .39601 L p F P
0 g
s
.734 .454 .505 r
.3754 .39601 m .37217 .39562 L .37274 .39979 L p F P
0 g
s
.768 .465 .473 r
.34814 .39132 m .35569 .39292 L .35474 .3889 L p F P
0 g
s
.768 .465 .473 r
.35474 .3889 m .34732 .38726 L .34814 .39132 L p F P
0 g
s
.568 .291 .456 r
.47488 .39033 m .47536 .38644 L .46441 .38889 L p F P
0 g
s
.568 .291 .456 r
.46605 .39227 m .47488 .39033 L p .46441 .38889 L F P
0 g
s
.568 .291 .456 r
.46441 .38889 m .46409 .39127 L .46605 .39227 L p F P
0 g
s
.138 .519 .915 r
.16338 .39313 m .16275 .39294 L .16654 .39596 L p F P
0 g
s
.138 .519 .915 r
.16654 .39596 m .16663 .39599 L .16338 .39313 L p F P
0 g
s
.807 .332 .089 r
.27429 .33981 m .27205 .33638 L .27677 .33908 L p F P
0 g
s
.807 .332 .089 r
.27631 .34094 m .27429 .33981 L p .27677 .33908 L F P
0 g
s
.807 .332 .089 r
.27677 .33908 m .27819 .34117 L .27631 .34094 L p F P
0 g
s
.754 .242 0 r
.25048 .318 m .25453 .32099 L .25196 .31773 L p F P
0 g
s
.754 .242 0 r
.25196 .31773 m .24797 .31472 L .25048 .318 L p F P
0 g
s
.645 .881 .528 r
.73715 .32535 m .73318 .33087 L .73792 .3248 L p F P
0 g
s
.645 .881 .528 r
.74038 .32124 m .73715 .32535 L p .73792 .3248 L F P
0 g
s
.645 .881 .528 r
.73792 .3248 m .7409 .32071 L .74038 .32124 L p F P
0 g
s
.188 .549 .93 r
.17322 .3978 m .16663 .39599 L .16338 .39313 L p F P
0 g
s
.788 .463 .437 r
.33325 .38367 m .34009 .38554 L .33887 .38163 L p F P
0 g
s
.788 .463 .437 r
.33887 .38163 m .33217 .37972 L .33325 .38367 L p F P
0 g
s
.61 .749 .943 r
.31117 .44014 m .32092 .43789 L .32393 .44069 L p F P
0 g
s
.624 .744 .933 r
.32092 .43789 m .31117 .44014 L .30813 .43748 L p F P
0 g
s
.512 .735 .974 r
.26999 .43379 m .27957 .43292 L .28267 .43545 L p F P
0 g
s
.525 .732 .969 r
.27957 .43292 m .26999 .43379 L .26688 .43128 L p F P
0 g
s
0 0 .377 r
.76467 .26783 m .76477 .27029 L .76479 .2676 L closepath p F P
0 g
s
0 0 .04 r
.75811 .29175 m .75788 .29216 L .75845 .28916 L p F P
0 g
s
0 0 .04 r
.75845 .28916 m .75984 .28674 L .75811 .29175 L p F P
0 g
s
.24 .591 .948 r
.18217 .40398 m .1885 .40532 L .19259 .4082 L p F P
0 g
s
.249 .592 .949 r
.1885 .40532 m .18217 .40398 L .17892 .40123 L p F P
0 g
s
.437 .703 .978 r
.25399 .42912 m .25422 .4293 L p .24162 .42674 L F P
0 g
s
.437 .703 .978 r
.24162 .42674 m .24945 .42676 L .25399 .42912 L p F P
0 g
s
.446 .704 .976 r
.24945 .42676 m .24162 .42674 L .23846 .42423 L p F P
0 g
s
.676 .715 .878 r
.42924 .44239 m .43924 .43858 L .44205 .44217 L p F P
0 g
s
.684 .685 .845 r
.43924 .43858 m .42924 .44239 L .42641 .43869 L p F P
0 g
s
.31 .637 .965 r
.21239 .41704 m .2102 .41526 L .20939 .41515 L closepath p F P
0 g
s
.772 .865 .918 r
.68862 .21711 m .68409 .21996 L .68171 .21791 L p F P
0 g
s
.721 .988 .874 r
.68205 .37745 m .67646 .38147 L .68062 .37751 L closepath p F P
0 g
s
.729 .986 .895 r
.67975 .37746 m .68062 .37751 L .67646 .38147 L p F P
0 g
s
.729 .986 .895 r
.67057 .38386 m .67975 .37746 L p .67646 .38147 L F P
0 g
s
.729 .986 .895 r
.6698 .3846 m .67057 .38386 L p .67646 .38147 L F P
0 g
s
0 0 .155 r
.76281 .28148 m .75984 .28674 L .76106 .28191 L p F P
0 g
s
0 0 .155 r
.76106 .28191 m .76406 .27664 L .76281 .28148 L p F P
0 g
s
.661 .838 .968 r
.53979 .4318 m .54192 .43331 L .53177 .43695 L p F P
0 g
s
.661 .838 .968 r
.53177 .43695 m .53 .43569 L .53979 .4318 L p F P
0 g
s
.745 .465 .508 r
.36418 .39855 m .37274 .39979 L .37217 .39562 L p F P
0 g
s
.745 .465 .508 r
.37217 .39562 m .36371 .39435 L .36418 .39855 L p F P
0 g
s
.636 .671 .866 r
.74166 .20669 m .73263 .20874 L .73023 .20496 L p F P
0 g
s
.739 .799 .901 r
.70702 .2104 m .70636 .21076 L .70662 .20993 L closepath p F P
0 g
s
.741 .824 .916 r
.70463 .2076 m .70662 .20993 L .70636 .21076 L p F P
0 g
s
.741 .824 .916 r
.69434 .21351 m .70463 .2076 L p .70636 .21076 L F P
0 g
s
0 0 .375 r
.76733 .26685 m .76736 .26245 L .76479 .2676 L p F P
0 g
s
0 0 .375 r
.76483 .27186 m .76733 .26685 L p .76479 .2676 L F P
0 g
s
0 0 .375 r
.76479 .2676 m .76477 .27029 L .76483 .27186 L p F P
0 g
s
.793 .999 .835 r
.62101 .26758 m .62088 .2676 L .62125 .26726 L closepath p F P
0 g
s
.389 .683 .977 r
.2259 .42128 m .22817 .4214 L .23296 .42399 L p F P
0 g
s
.401 .685 .976 r
.23529 .42166 m .22817 .4214 L .23296 .42399 L p F P
0 g
s
.401 .685 .976 r
.23296 .42399 m .23846 .42423 L .23529 .42166 L p F P
0 g
s
.141 0 .086 r
.5434 .33846 m .54017 .34116 L .53941 .34298 L p F P
0 g
s
.672 .724 .889 r
.44205 .44217 m .45206 .43852 L .45486 .44195 L p F P
0 g
s
.679 .694 .857 r
.45206 .43852 m .44205 .44217 L .43924 .43858 L p F P
0 g
s
.683 .919 .596 r
.73274 .33147 m .73251 .33166 L .73318 .33087 L closepath p F P
0 g
s
.725 .795 .907 r
.71499 .20235 m .71738 .20549 L .70702 .2104 L p F P
0 g
s
.725 .795 .907 r
.70894 .20543 m .71499 .20235 L p .70702 .2104 L F P
0 g
s
.725 .795 .907 r
.70702 .2104 m .70662 .20993 L .70894 .20543 L p F P
0 g
s
.68 .897 .975 r
.59052 .42145 m .58031 .42586 L .57774 .42456 L p F P
0 g
s
.671 .894 .978 r
.56753 .42879 m .57774 .42456 L .58031 .42586 L p F P
0 g
s
.568 .057 0 r
.22339 .29092 m .225 .29263 L .22843 .29589 L p F P
0 g
s
.575 .064 0 r
.22787 .29572 m .23134 .29897 L .22843 .29589 L p F P
0 g
s
.575 .064 0 r
.22843 .29589 m .225 .29263 L .22787 .29572 L p F P
0 g
s
.832 .443 .313 r
.2994 .36114 m .30486 .36354 L .30315 .35987 L p F P
0 g
s
.832 .443 .313 r
.30315 .35987 m .29782 .35742 L .2994 .36114 L p F P
0 g
s
.837 .428 .269 r
.29663 .35491 m .29782 .35742 L .29446 .35575 L closepath p F P
0 g
s
.574 .882 .595 r
.59081 .2958 m .59063 .29594 L .59127 .29532 L closepath p F P
0 g
s
.086 0 .016 r
.55027 .33288 m .5434 .33846 L .54935 .3348 L closepath p F P
0 g
s
.141 0 .086 r
.5481 .33753 m .54935 .3348 L .5434 .33846 L p F P
0 g
s
.141 0 .086 r
.53941 .34298 m .5481 .33753 L p .5434 .33846 L F P
0 g
s
.776 .997 .819 r
.62125 .26726 m .62088 .2676 L .61846 .26809 L p F P
0 g
s
.77 .992 .779 r
.61362 .27432 m .62088 .2676 L .61846 .26809 L p F P
0 g
s
.818 .996 .855 r
.62555 .26137 m .62125 .26726 L .62922 .26007 L p F P
0 g
s
.776 .997 .819 r
.61846 .26809 m .62555 .26137 L .62125 .26726 L p F P
0 g
s
.804 .455 .396 r
.31936 .37566 m .32568 .37772 L .32422 .37392 L p F P
0 g
s
.804 .455 .396 r
.32422 .37392 m .31805 .37181 L .31936 .37566 L p F P
0 g
s
.802 .424 .341 r
.31342 .36681 m .31188 .36853 L .31065 .36581 L closepath p F P
0 g
s
.77 .992 .779 r
.61846 .26809 m .61819 .26834 L .61362 .27432 L p F P
0 g
s
.723 .978 .757 r
.6112 .27519 m .61819 .26834 L .61362 .27432 L p F P
0 g
s
.723 .978 .757 r
.60931 .27755 m .6112 .27519 L p .61362 .27432 L F P
0 g
s
.723 .978 .757 r
.61362 .27432 m .61079 .27695 L .60931 .27755 L p F P
0 g
s
.729 .98 .757 r
.61079 .27695 m .6061 .28135 L .60931 .27755 L closepath p F P
0 g
s
.818 .996 .855 r
.62856 .25851 m .62555 .26137 L p .62922 .26007 L F P
0 g
s
.818 .996 .855 r
.62922 .26007 m .63031 .25849 L .62856 .25851 L p F P
0 g
s
.819 .995 .859 r
.63097 .2585 m .62922 .26007 L .63031 .25849 L closepath p F P
0 g
s
.668 .738 .902 r
.45486 .44195 m .46489 .43845 L .46767 .44165 L p F P
0 g
s
.674 .708 .873 r
.46489 .43845 m .45486 .44195 L .45206 .43852 L p F P
0 g
s
.808 .995 .864 r
.63752 .25277 m .63097 .2585 L .63031 .25849 L p F P
0 g
s
.642 .932 .671 r
.60836 .27797 m .60931 .27755 L .6061 .28135 L p F P
0 g
s
.642 .932 .671 r
.60429 .28201 m .60836 .27797 L p .6061 .28135 L F P
0 g
s
.642 .932 .671 r
.60012 .28678 m .60429 .28201 L p .6061 .28135 L F P
0 g
s
.642 .932 .671 r
.6061 .28135 m .60071 .28641 L .60012 .28678 L p F P
0 g
s
.661 .812 .955 r
.52909 .43502 m .51896 .4385 L .51626 .43628 L p F P
0 g
s
.657 .81 .956 r
.50614 .43967 m .51626 .43628 L .51896 .4385 L p F P
0 g
s
.636 .744 .927 r
.32393 .44069 m .33372 .43796 L .3367 .44092 L p F P
0 g
s
.651 .737 .912 r
.33372 .43796 m .32393 .44069 L .32092 .43789 L p F P
0 g
s
0 .376 .832 r
.1293 .37086 m .12864 .37052 L .13204 .37373 L p F P
0 g
s
0 .376 .832 r
.13204 .37373 m .13259 .37402 L .1293 .37086 L p F P
0 g
s
.641 .932 .671 r
.60071 .28641 m .59865 .28835 L .60012 .28678 L closepath p F P
0 g
s
.734 .99 .871 r
.68787 .37312 m .68205 .37745 L .68062 .37751 L p F P
0 g
s
.688 .439 .541 r
.41592 .40213 m .41426 .40214 L .41419 .40656 L p F P
0 g
s
.693 .443 .541 r
.40272 .40652 m .41419 .40656 L .41426 .40214 L p F P
0 g
s
.693 .443 .541 r
.41426 .40214 m .40285 .4021 L .40272 .40652 L p F P
0 g
s
.634 .925 .659 r
.59746 .2888 m .59127 .29532 L .59865 .28835 L p F P
0 g
s
.634 .925 .659 r
.59827 .288 m .59746 .2888 L p .59865 .28835 L F P
0 g
s
.634 .925 .659 r
.59865 .28835 m .60012 .28678 L .59827 .288 L p F P
0 g
s
.755 .239 0 r
.25665 .32369 m .25453 .32099 L .25876 .3239 L p F P
0 g
s
.755 .239 0 r
.25876 .3239 m .25986 .32528 L .25665 .32369 L p F P
0 g
s
.844 .415 .209 r
.28076 .34614 m .28559 .3488 L .28366 .34523 L p F P
0 g
s
.844 .415 .209 r
.28366 .34523 m .27894 .34254 L .28076 .34614 L p F P
0 g
s
.673 .427 .541 r
.4279 .40158 m .41592 .40213 L .41581 .40655 L p F P
0 g
s
.688 .439 .541 r
.41419 .40656 m .41581 .40655 L .41592 .40213 L p F P
0 g
s
.832 .979 .881 r
.64107 .24965 m .63752 .25277 L .63962 .24937 L closepath p F P
0 g
s
.808 .995 .864 r
.63867 .24921 m .63962 .24937 L .63752 .25277 L p F P
0 g
s
.808 .995 .864 r
.63313 .25431 m .63867 .24921 L p .63752 .25277 L F P
0 g
s
.808 .995 .864 r
.63031 .25849 m .63313 .25431 L p .63752 .25277 L F P
0 g
s
0 0 0 r
.56048 .32387 m .56037 .32404 L .56093 .32353 L closepath p F P
0 g
s
.703 .452 .542 r
.4023 .4065 m .40272 .40652 L .40285 .4021 L p F P
0 g
s
.703 .452 .542 r
.40285 .4021 m .40238 .40208 L .4023 .4065 L p F P
0 g
s
.738 .984 .769 r
.71311 .35231 m .71248 .35253 L .71452 .35063 L closepath p F P
0 g
s
.708 .457 .542 r
.39155 .40605 m .4023 .4065 L .40238 .40208 L p F P
0 g
s
.708 .457 .542 r
.40238 .40208 m .39165 .40162 L .39155 .40605 L p F P
0 g
s
.242 .216 .629 r
.76891 .24733 m .76799 .24921 L .76582 .24562 L p F P
0 g
s
.242 .216 .629 r
.76582 .24562 m .76769 .24178 L .76891 .24733 L p F P
0 g
s
.664 .754 .917 r
.46767 .44165 m .47773 .43826 L .48049 .44121 L p F P
0 g
s
.67 .726 .892 r
.47773 .43826 m .46767 .44165 L .46489 .43845 L p F P
0 g
s
.82 .98 .889 r
.64624 .24531 m .64107 .24965 L .63962 .24937 L p F P
0 g
s
.782 .856 .905 r
.68862 .21711 m .69434 .21351 L .69195 .21112 L p F P
0 g
s
.782 .856 .905 r
.69195 .21112 m .69065 .21198 L .68862 .21711 L p F P
0 g
s
.772 .865 .918 r
.68171 .21791 m .69065 .21198 L .68862 .21711 L p F P
0 g
s
.037 0 0 r
.55253 .33086 m .55027 .33288 L .54935 .3348 L p F P
0 g
s
.516 .838 .538 r
.59078 .29554 m .59746 .2888 L .59127 .29532 L p F P
0 g
s
.516 .838 .538 r
.58891 .2975 m .59078 .29554 L p .59127 .29532 L F P
0 g
s
.516 .838 .538 r
.59127 .29532 m .59063 .29594 L .58891 .2975 L p F P
0 g
s
.068 .469 .888 r
.14792 .38409 m .14947 .38469 L .15313 .38778 L p F P
0 g
s
.112 .495 .904 r
.1554 .38677 m .15904 .38987 L .15313 .38778 L p F P
0 g
s
.112 .495 .904 r
.15313 .38778 m .14947 .38469 L .1554 .38677 L p F P
0 g
s
.686 .921 .599 r
.73188 .33162 m .73715 .32535 L .73318 .33087 L p F P
0 g
s
.686 .921 .599 r
.73094 .33293 m .73188 .33162 L p .73318 .33087 L F P
0 g
s
.686 .921 .599 r
.73318 .33087 m .73251 .33166 L .73094 .33293 L p F P
0 g
s
.506 .833 .535 r
.59063 .29594 m .58389 .3023 L .58891 .2975 L closepath p F P
0 g
s
0 0 0 r
.56037 .32404 m .55253 .33086 L .55908 .32635 L closepath p F P
0 g
s
.037 0 0 r
.55786 .3286 m .55908 .32635 L .55253 .33086 L p F P
0 g
s
.037 0 0 r
.55702 .32938 m .55786 .3286 L p .55253 .33086 L F P
0 g
s
.037 0 0 r
.54935 .3348 m .55702 .32938 L p .55253 .33086 L F P
0 g
s
.726 .797 .908 r
.70662 .20993 m .70463 .2076 L .70894 .20543 L closepath p F P
0 g
s
.661 .791 .944 r
.51626 .43628 m .50614 .43967 L .50341 .43723 L p F P
0 g
s
.658 .791 .946 r
.49332 .44056 m .50341 .43723 L .50614 .43967 L p F P
0 g
s
.603 .345 .498 r
.46361 .39691 m .4639 .39276 L .45263 .39483 L p F P
0 g
s
.603 .345 .498 r
.45263 .39483 m .45231 .39895 L .46361 .39691 L p F P
0 g
s
.627 .365 .502 r
.44462 .39995 m .45231 .39895 L .45263 .39483 L p F P
0 g
s
0 0 0 r
.75281 .30244 m .75572 .297 L .75239 .30235 L p F P
0 g
s
0 0 0 r
.7499 .30716 m .75281 .30244 L p .75239 .30235 L F P
0 g
s
0 0 0 r
.75239 .30235 m .75011 .30667 L .7499 .30716 L p F P
0 g
s
.666 .914 .597 r
.73251 .33166 m .72762 .33723 L .73094 .33293 L closepath p F P
0 g
s
.66 .772 .932 r
.48049 .44121 m .49057 .43787 L .49332 .44056 L p F P
0 g
s
.666 .747 .911 r
.49057 .43787 m .48049 .44121 L .47773 .43826 L p F P
0 g
s
0 0 0 r
.58818 .29819 m .58891 .2975 L .58389 .3023 L p F P
0 g
s
0 0 0 r
.58411 .30228 m .58818 .29819 L p .58389 .3023 L F P
0 g
s
0 0 0 r
.57962 .30656 m .58411 .30228 L p .58389 .3023 L F P
0 g
s
0 0 0 r
.58389 .3023 m .58055 .30549 L .57962 .30656 L p F P
0 g
s
.663 .769 .929 r
.50341 .43723 m .49332 .44056 L .49057 .43787 L p F P
0 g
s
0 0 0 r
.58055 .30549 m .57641 .30931 L .57962 .30656 L closepath p F P
0 g
s
.833 .956 .894 r
.65119 .24112 m .64624 .24531 L .649 .24032 L closepath p F P
0 g
s
.82 .98 .889 r
.64879 .24025 m .649 .24032 L .64624 .24531 L p F P
0 g
s
.82 .98 .889 r
.64101 .24715 m .64879 .24025 L p .64624 .24531 L F P
0 g
s
.82 .98 .889 r
.63962 .24937 m .64101 .24715 L p .64624 .24531 L F P
0 g
s
0 0 0 r
.57808 .30839 m .57962 .30656 L .57641 .30931 L p F P
0 g
s
0 0 0 r
.57744 .30901 m .57808 .30839 L p .57641 .30931 L F P
0 g
s
0 0 0 r
.57014 .31534 m .57744 .30901 L p .57641 .30931 L F P
0 g
s
0 0 0 r
.57641 .30931 m .57046 .31488 L .57014 .31534 L p F P
0 g
s
0 0 0 r
.56861 .31761 m .56093 .32353 L .56879 .31638 L p F P
0 g
s
0 0 0 r
.56797 .3186 m .56861 .31761 L .56093 .32353 L p F P
0 g
s
0 0 0 r
.56392 .32256 m .56797 .3186 L p .56093 .32353 L F P
0 g
s
0 0 0 r
.55908 .32635 m .56392 .32256 L p .56093 .32353 L F P
0 g
s
0 0 0 r
.56093 .32353 m .56037 .32404 L .55908 .32635 L p F P
0 g
s
.586 .064 0 r
.23428 .30205 m .23792 .30523 L .23493 .30217 L p F P
0 g
s
.586 .064 0 r
.23493 .30217 m .23134 .29897 L .23428 .30205 L p F P
0 g
s
0 0 0 r
.57046 .31488 m .56879 .31638 L .57014 .31534 L closepath p F P
0 g
s
0 0 0 r
.56879 .31638 m .57014 .31534 L .56861 .31761 L p F P
0 g
s
.721 .969 .934 r
.65596 .3933 m .64908 .39747 L .64683 .39705 L p F P
0 g
s
0 .41 .853 r
.13259 .37402 m .13706 .37611 L .14054 .37928 L p F P
0 g
s
.009 .413 .857 r
.13706 .37611 m .13259 .37402 L .1293 .37086 L p F P
0 g
s
.657 .736 .908 r
.3367 .44092 m .34654 .43769 L .3495 .44087 L p F P
0 g
s
.673 .725 .889 r
.34654 .43769 m .3367 .44092 L .33372 .43796 L p F P
0 g
s
.717 .464 .542 r
.38908 .40588 m .39155 .40605 L .39165 .40162 L p F P
0 g
s
.717 .464 .542 r
.39165 .40162 m .38923 .40146 L .38908 .40588 L p F P
0 g
s
.671 .425 .541 r
.42847 .40155 m .4279 .40158 L .42787 .406 L p F P
0 g
s
.673 .427 .541 r
.41581 .40655 m .42787 .406 L .4279 .40158 L p F P
0 g
s
.734 .99 .871 r
.68995 .36992 m .69104 .3699 L .68787 .37312 L p F P
0 g
s
.734 .99 .871 r
.6829 .37519 m .68995 .36992 L p .68787 .37312 L F P
0 g
s
.734 .99 .871 r
.68062 .37751 m .6829 .37519 L p .68787 .37312 L F P
0 g
s
.724 .989 .845 r
.69222 .36975 m .68787 .37312 L .69104 .3699 L closepath p F P
0 g
s
.82 .957 .903 r
.65553 .23764 m .65119 .24112 L .649 .24032 L p F P
0 g
s
.548 .046 0 r
.225 .29263 m .22339 .29092 L .22023 .28776 L p F P
0 g
s
.656 .413 .54 r
.44052 .40492 m .4406 .4005 L .42847 .40155 L p F P
0 g
s
.656 .413 .54 r
.42847 .40155 m .42837 .40597 L .44052 .40492 L p F P
0 g
s
.671 .425 .541 r
.42787 .406 m .42837 .40597 L .42847 .40155 L p F P
0 g
s
.553 .744 .966 r
.28267 .43545 m .28744 .43476 L .29318 .43698 L p F P
0 g
s
.566 .748 .962 r
.28744 .43476 m .28267 .43545 L .27957 .43292 L p F P
0 g
s
.779 .472 .468 r
.34409 .3903 m .34814 .39132 L .34732 .38726 L p F P
0 g
s
.779 .472 .468 r
.34732 .38726 m .34501 .38668 L .34409 .3903 L p F P
0 g
s
.38 .068 .305 r
.51734 .36416 m .51798 .36173 L .50837 .3659 L p F P
0 g
s
.38 .068 .305 r
.51271 .36696 m .51734 .36416 L p .50837 .3659 L F P
0 g
s
.38 .068 .305 r
.50837 .3659 m .5075 .36923 L .51271 .36696 L p F P
0 g
s
.757 .474 .504 r
.35974 .39774 m .36418 .39855 L .36371 .39435 L p F P
0 g
s
.757 .474 .504 r
.36371 .39435 m .36028 .39373 L .35974 .39774 L p F P
0 g
s
.723 .469 .543 r
.38166 .40528 m .38908 .40588 L .38923 .40146 L p F P
0 g
s
.723 .469 .543 r
.38923 .40146 m .38178 .40085 L .38166 .40528 L p F P
0 g
s
.399 .685 .976 r
.22817 .4214 m .2259 .42128 L .22271 .41874 L p F P
0 g
s
.442 .141 .357 r
.50721 .37056 m .5075 .36923 L .49757 .37298 L p F P
0 g
s
.442 .141 .357 r
.49757 .37298 m .4971 .37512 L .50721 .37056 L p F P
0 g
s
.694 .922 .969 r
.61283 .41321 m .60327 .4178 L .60075 .41675 L p F P
0 g
s
.548 .738 .964 r
.29231 .43403 m .28744 .43476 L .29318 .43698 L p F P
0 g
s
.548 .738 .964 r
.29318 .43698 m .29538 .43669 L .29231 .43403 L p F P
0 g
s
.707 .946 .957 r
.62639 .40851 m .62621 .40845 L .62714 .40795 L closepath p F P
0 g
s
.806 .426 .336 r
.30641 .36729 m .30486 .36354 L .31065 .36581 L p F P
0 g
s
.806 .426 .336 r
.3113 .36913 m .30641 .36729 L p .31065 .36581 L F P
0 g
s
.806 .426 .336 r
.31065 .36581 m .31188 .36853 L .3113 .36913 L p F P
0 g
s
.829 .357 .064 r
.26321 .33073 m .26753 .33359 L .26536 .33016 L p F P
0 g
s
.829 .357 .064 r
.26536 .33016 m .26111 .32726 L .26321 .33073 L p F P
0 g
s
.835 .946 .894 r
.65553 .23764 m .66133 .23296 L .65894 .2317 L p F P
0 g
s
.835 .946 .894 r
.65894 .2317 m .65826 .23227 L .65553 .23764 L p F P
0 g
s
.82 .957 .903 r
.64928 .23984 m .65826 .23227 L .65553 .23764 L p F P
0 g
s
.82 .957 .903 r
.649 .24032 m .64928 .23984 L p .65553 .23764 L F P
0 g
s
.699 .945 .657 r
.73044 .33322 m .73094 .33293 L .72762 .33723 L p F P
0 g
s
.699 .945 .657 r
.72585 .33815 m .73044 .33322 L p .72762 .33723 L F P
0 g
s
.699 .945 .657 r
.72222 .34291 m .72585 .33815 L p .72762 .33723 L F P
0 g
s
.699 .945 .657 r
.72762 .33723 m .72254 .3427 L .72222 .34291 L p F P
0 g
s
.674 .724 .888 r
.3495 .44087 m .35938 .43717 L .36231 .44061 L p F P
0 g
s
.689 .71 .864 r
.35938 .43717 m .3495 .44087 L .34654 .43769 L p F P
0 g
s
.675 .883 .975 r
.57582 .42352 m .57774 .42456 L .56753 .42879 L p F P
0 g
s
.675 .883 .975 r
.56753 .42879 m .5667 .42832 L .57582 .42352 L p F P
0 g
s
.313 0 .251 r
.52748 .3564 m .52824 .35394 L .51893 .35853 L p F P
0 g
s
.313 0 .251 r
.52489 .35828 m .52748 .3564 L p .51893 .35853 L F P
0 g
s
.313 0 .251 r
.51893 .35853 m .51798 .36173 L .52489 .35828 L p F P
0 g
s
.738 .992 .843 r
.69784 .36525 m .69222 .36975 L .69104 .3699 L p F P
0 g
s
.5 .217 .416 r
.49624 .38022 m .49682 .37649 L .48657 .37983 L p F P
0 g
s
.5 .217 .416 r
.48657 .37983 m .48596 .38354 L .49624 .38022 L p F P
0 g
s
.833 .413 .241 r
.28743 .35241 m .29262 .35492 L .29065 .35136 L p F P
0 g
s
.833 .413 .241 r
.29065 .35136 m .28559 .3488 L .28743 .35241 L p F P
0 g
s
.004 0 .388 r
.76477 .27029 m .76475 .272 L .76483 .27186 L closepath p F P
0 g
s
.567 .294 .461 r
.46409 .39127 m .46605 .39227 L .4639 .39276 L closepath p F P
0 g
s
.263 .602 .953 r
.19131 .40586 m .1885 .40532 L .19259 .4082 L p F P
0 g
s
.263 .602 .953 r
.19259 .4082 m .19454 .40858 L .19131 .40586 L p F P
0 g
s
.801 .469 .428 r
.32748 .3818 m .33325 .38367 L .33217 .37972 L p F P
0 g
s
.801 .469 .428 r
.33217 .37972 m .32884 .37864 L .32748 .3818 L p F P
0 g
s
.701 .939 .962 r
.6135 .41288 m .62374 .4076 L .62621 .40845 L p F P
0 g
s
.712 .942 .958 r
.62714 .40795 m .62621 .40845 L .62374 .4076 L p F P
0 g
s
.757 .813 .897 r
.70463 .2076 m .69434 .21351 L .69195 .21112 L p F P
0 g
s
.714 .201 0 r
.24161 .30825 m .24168 .30835 L .24112 .30786 L closepath p F P
0 g
s
.699 .693 .841 r
.37223 .43648 m .36231 .44061 L .35938 .43717 L p F P
0 g
s
.685 .712 .869 r
.36231 .44061 m .37223 .43648 L .37513 .44019 L p F P
0 g
s
.316 .636 .964 r
.20699 .41261 m .2051 .41236 L .20939 .41515 L p F P
0 g
s
.316 .636 .964 r
.20939 .41515 m .2102 .41526 L .20699 .41261 L p F P
0 g
s
.479 .725 .979 r
.25422 .4293 m .25438 .42929 L .25399 .42912 L closepath p F P
0 g
s
.772 .464 .467 r
.34096 .38958 m .34409 .3903 L .34501 .38668 L p F P
0 g
s
.772 .464 .467 r
.34501 .38668 m .34009 .38554 L .34096 .38958 L p F P
0 g
s
.552 .59 .846 r
.74566 .21087 m .7548 .21062 L .75272 .21572 L p F P
0 g
s
.572 .596 .838 r
.7548 .21062 m .74566 .21087 L .74321 .20637 L p F P
0 g
s
.812 .93 .911 r
.66567 .22966 m .66133 .23296 L .65894 .2317 L p F P
0 g
s
.324 .316 .696 r
.76517 .23721 m .76598 .2355 L .76693 .23889 L closepath p F P
0 g
s
.753 .249 0 r
.24043 .30849 m .24413 .31164 L .24168 .30835 L p F P
0 g
s
.753 .249 0 r
.23843 .30577 m .24043 .30849 L p .24168 .30835 L F P
0 g
s
.753 .249 0 r
.24168 .30835 m .24112 .30786 L .23843 .30577 L p F P
0 g
s
.841 .394 .156 r
.27819 .34117 m .27894 .34254 L .27631 .34094 L closepath p F P
0 g
s
.736 .48 .542 r
.37474 .40447 m .38166 .40528 L .38178 .40085 L p F P
0 g
s
.736 .48 .542 r
.38178 .40085 m .3749 .40005 L .37474 .40447 L p F P
0 g
s
.754 .472 .505 r
.35616 .39712 m .35974 .39774 L .36028 .39373 L p F P
0 g
s
.754 .472 .505 r
.36028 .39373 m .35569 .39292 L .35616 .39712 L p F P
0 g
s
.707 .954 .952 r
.63644 .40284 m .62714 .40795 L .63458 .40233 L closepath p F P
0 g
s
.712 .942 .958 r
.634 .40213 m .63458 .40233 L .62714 .40795 L p F P
0 g
s
.712 .942 .958 r
.62374 .4076 m .634 .40213 L p .62714 .40795 L F P
0 g
s
.726 .988 .811 r
.70237 .36148 m .69784 .36525 L .70108 .36177 L closepath p F P
0 g
s
.738 .992 .843 r
.70014 .36185 m .70108 .36177 L .69784 .36525 L p F P
0 g
s
.738 .992 .843 r
.69368 .36704 m .70014 .36185 L p .69784 .36525 L F P
0 g
s
.738 .992 .843 r
.69104 .3699 m .69368 .36704 L p .69784 .36525 L F P
0 g
s
.504 .73 .974 r
.26063 .42609 m .26376 .42872 L .25438 .42929 L p F P
0 g
s
.504 .73 .974 r
.25108 .42674 m .26063 .42609 L p .25438 .42929 L F P
0 g
s
.504 .73 .974 r
.25438 .42929 m .25399 .42912 L .25108 .42674 L p F P
0 g
s
.821 .996 .854 r
.63031 .25849 m .62856 .25851 L .63313 .25431 L closepath p F P
0 g
s
.691 .7 .854 r
.37513 .44019 m .38507 .43575 L .38795 .43971 L p F P
0 g
s
.703 .677 .822 r
.38507 .43575 m .37513 .44019 L .37223 .43648 L p F P
0 g
s
.679 .939 .655 r
.72254 .3427 m .7215 .34378 L .72222 .34291 L closepath p F P
0 g
s
.206 .563 .937 r
.17568 .39842 m .17322 .3978 L .17712 .40077 L p F P
0 g
s
.206 .563 .937 r
.17712 .40077 m .17892 .40123 L .17568 .39842 L p F P
0 g
s
.512 .54 .822 r
.75644 .21068 m .7548 .21062 L .75272 .21572 L p F P
0 g
s
.512 .54 .822 r
.75272 .21572 m .75896 .21634 L .75644 .21068 L p F P
0 g
s
0 0 0 r
.57074 .31577 m .56861 .31761 L .57014 .31534 L p F P
0 g
s
0 0 0 r
.57014 .31534 m .57744 .30901 L .57074 .31577 L p F P
0 g
s
.721 .972 .73 r
.71921 .34489 m .71452 .35063 L .7215 .34378 L p F P
0 g
s
.721 .972 .73 r
.7204 .34371 m .71921 .34489 L p .7215 .34378 L F P
0 g
s
.721 .972 .73 r
.7215 .34378 m .72222 .34291 L .7204 .34371 L p F P
0 g
s
.233 0 .185 r
.53761 .34773 m .53828 .34588 L .52927 .35088 L p F P
0 g
s
.233 0 .185 r
.53407 .35065 m .53761 .34773 L p .52927 .35088 L F P
0 g
s
.233 0 .185 r
.52927 .35088 m .52824 .35394 L .53407 .35065 L p F P
0 g
s
.543 .271 .453 r
.48551 .38744 m .48596 .38354 L .47536 .38644 L p F P
0 g
s
.543 .271 .453 r
.47536 .38644 m .47488 .39033 L .48551 .38744 L p F P
0 g
s
.448 .706 .977 r
.25399 .42912 m .25108 .42674 L .24945 .42676 L closepath p F P
0 g
s
.664 .937 .664 r
.60012 .28678 m .59827 .288 L .60429 .28201 L closepath p F P
0 g
s
.693 .69 .843 r
.38795 .43971 m .39792 .43509 L .40077 .43927 L p F P
0 g
s
.704 .668 .812 r
.38795 .43971 m .39792 .43509 L .39617 .43213 L p F P
0 g
s
.704 .668 .812 r
.38507 .43575 m .38795 .43971 L p .39617 .43213 L F P
0 g
s
.033 .435 .87 r
.14137 .37798 m .13706 .37611 L .14054 .37928 L p F P
0 g
s
.033 .435 .87 r
.14054 .37928 m .14465 .38107 L .14137 .37798 L p F P
0 g
s
0 0 0 r
.75011 .30667 m .74949 .30778 L .7499 .30716 L closepath p F P
0 g
s
.064 .006 .473 r
.76997 .25727 m .76736 .26245 L .76675 .25829 L p F P
0 g
s
.064 .006 .473 r
.76675 .25829 m .76935 .2531 L .76997 .25727 L p F P
0 g
s
.74 .991 .809 r
.70666 .35778 m .70237 .36148 L .70108 .36177 L p F P
0 g
s
0 0 .018 r
.76104 .28651 m .75811 .29175 L .75984 .28674 L p F P
0 g
s
0 0 .018 r
.75984 .28674 m .76281 .28148 L .76104 .28651 L p F P
0 g
s
.821 .342 .021 r
.26111 .32726 m .25986 .32528 L .25665 .32369 L p F P
0 g
s
.635 .396 .539 r
.44462 .39995 m .4406 .4005 L .44052 .40492 L p F P
0 g
s
.692 .684 .837 r
.40077 .43927 m .41076 .43461 L .41359 .43891 L p F P
0 g
s
.7 .659 .806 r
.40077 .43927 m .41076 .43461 L .40952 .43243 L p F P
0 g
s
.7 .659 .806 r
.39792 .43509 m .40077 .43927 L p .40952 .43243 L F P
0 g
s
.725 .982 .772 r
.71248 .35253 m .70666 .35778 L .71074 .3531 L closepath p F P
0 g
s
.74 .991 .809 r
.71029 .35318 m .71074 .3531 L .70666 .35778 L p F P
0 g
s
.74 .991 .809 r
.7032 .35931 m .71029 .35318 L p .70666 .35778 L F P
0 g
s
.74 .991 .809 r
.70108 .36177 m .7032 .35931 L p .70666 .35778 L F P
0 g
s
.825 .92 .899 r
.66567 .22966 m .6715 .22521 L .66911 .22358 L p F P
0 g
s
.825 .92 .899 r
.66911 .22358 m .66811 .22439 L .66567 .22966 L p F P
0 g
s
.812 .93 .911 r
.65894 .2317 m .66811 .22439 L .66567 .22966 L p F P
0 g
s
.74 .985 .771 r
.71168 .35194 m .71921 .34489 L .71452 .35063 L p F P
0 g
s
.74 .985 .771 r
.71074 .3531 m .71168 .35194 L p .71452 .35063 L F P
0 g
s
.74 .985 .771 r
.71452 .35063 m .71248 .35253 L .71074 .3531 L p F P
0 g
s
.825 .358 .096 r
.26967 .33706 m .27429 .33981 L .27205 .33638 L p F P
0 g
s
.825 .358 .096 r
.27205 .33638 m .26753 .33359 L .26967 .33706 L p F P
0 g
s
.717 .976 .922 r
.65931 .3912 m .65596 .3933 L .65854 .3911 L closepath p F P
0 g
s
.721 .969 .934 r
.65693 .39076 m .65854 .3911 L .65596 .3933 L p F P
0 g
s
.721 .969 .934 r
.64733 .39663 m .65693 .39076 L p .65596 .3933 L F P
0 g
s
.721 .969 .934 r
.64683 .39705 m .64733 .39663 L p .65596 .3933 L F P
0 g
s
.625 .095 0 r
.24112 .30786 m .23843 .30577 L .23792 .30523 L closepath p F P
0 g
s
.367 .659 .969 r
.21889 .41607 m .2102 .41526 L .20699 .41261 L p F P
0 g
s
.607 .743 .941 r
.30509 .43471 m .29538 .43669 L .29231 .43403 L p F P
0 g
s
0 0 0 r
.74867 .3093 m .7459 .31345 L .74949 .30778 L p F P
0 g
s
0 0 0 r
.74949 .30778 m .7499 .30716 L .74867 .3093 L p F P
0 g
s
.08 .471 .89 r
.14947 .38469 m .14792 .38409 L .14465 .38107 L p F P
0 g
s
.821 .472 .396 r
.31346 .37343 m .31936 .37566 L .31805 .37181 L p F P
0 g
s
.821 .472 .396 r
.31805 .37181 m .31226 .36954 L .31346 .37343 L p F P
0 g
s
.689 .682 .838 r
.41359 .43891 m .42359 .43437 L .42641 .43869 L p F P
0 g
s
.696 .654 .805 r
.41359 .43891 m .42359 .43437 L .42237 .43217 L p F P
0 g
s
.696 .654 .805 r
.41076 .43461 m .41359 .43891 L p .42237 .43217 L F P
0 g
s
.686 .908 .973 r
.59088 .42162 m .59052 .42145 L .593 .42033 L closepath p F P
0 g
s
0 .147 .654 r
.21707 .28445 m .21528 .28298 L .21849 .28635 L p F P
0 g
s
0 .147 .654 r
.21849 .28635 m .22023 .28776 L .21707 .28445 L p F P
0 g
s
.671 .861 .972 r
.56493 .42727 m .55474 .43123 L .5521 .42953 L p F P
0 g
s
.664 .857 .974 r
.54192 .43331 m .5521 .42953 L .55474 .43123 L p F P
0 g
s
.755 .246 0 r
.24658 .31494 m .25048 .318 L .24797 .31472 L p F P
0 g
s
.755 .246 0 r
.24797 .31472 m .24413 .31164 L .24658 .31494 L p F P
0 g
s
.843 .451 .304 r
.29424 .35863 m .2994 .36114 L .29782 .35742 L p F P
0 g
s
.843 .451 .304 r
.29333 .35635 m .29424 .35863 L p .29782 .35742 L F P
0 g
s
.843 .451 .304 r
.29782 .35742 m .29446 .35575 L .29333 .35635 L p F P
0 g
s
0 0 .272 r
.76471 .27548 m .76406 .27664 L .76475 .272 L p F P
0 g
s
0 0 .272 r
.76475 .272 m .76483 .27186 L .76471 .27548 L p F P
0 g
s
.399 .406 .751 r
.76319 .22927 m .76364 .22829 L .76415 .22979 L closepath p F P
0 g
s
.663 .831 .964 r
.53926 .43141 m .53979 .4318 L .53 .43569 L p F P
0 g
s
.663 .831 .964 r
.53 .43569 m .52909 .43502 L .53926 .43141 L p F P
0 g
s
.147 .52 .916 r
.16011 .39022 m .15904 .38987 L .16275 .39294 L p F P
0 g
s
.147 .52 .916 r
.16275 .39294 m .16338 .39313 L .16011 .39022 L p F P
0 g
s
.737 .481 .542 r
.37261 .40422 m .37474 .40447 L .3749 .40005 L p F P
0 g
s
.737 .481 .542 r
.3749 .40005 m .37274 .39979 L .37261 .40422 L p F P
0 g
s
.399 .685 .976 r
.22271 .41874 m .22343 .41877 L .22817 .4214 L p F P
0 g
s
.41 .685 .975 r
.23212 .41904 m .22343 .41877 L .22817 .4214 L p F P
0 g
s
.41 .685 .975 r
.22817 .4214 m .23529 .42166 L .23212 .41904 L p F P
0 g
s
.768 .485 .506 r
.34854 .39554 m .35616 .39712 L .35569 .39292 L p F P
0 g
s
.768 .485 .506 r
.35569 .39292 m .34814 .39132 L .34854 .39554 L p F P
0 g
s
.789 .456 .423 r
.32688 .38163 m .32748 .3818 L .32884 .37864 L p F P
0 g
s
.789 .456 .423 r
.32884 .37864 m .32568 .37772 L .32688 .38163 L p F P
0 g
s
0 0 .253 r
.76673 .27146 m .76471 .27548 L .76483 .27186 L p F P
0 g
s
0 0 .253 r
.76483 .27186 m .76733 .26685 L .76673 .27146 L p F P
0 g
s
.684 .685 .845 r
.42641 .43869 m .43643 .43436 L .43924 .43858 L p F P
0 g
s
.69 .654 .809 r
.42641 .43869 m .43643 .43436 L .43476 .4314 L p F P
0 g
s
.69 .654 .809 r
.42359 .43437 m .42641 .43869 L p .43476 .4314 L F P
0 g
s
.461 .48 .792 r
.75935 .22199 m .76037 .2197 L .76152 .2226 L closepath p F P
0 g
s
.638 .398 .539 r
.45231 .39895 m .44462 .39995 L .44462 .40437 L p F P
0 g
s
.635 .396 .539 r
.44052 .40492 m .44462 .40437 L .44462 .39995 L p F P
0 g
s
.799 .902 .914 r
.67712 .22121 m .6715 .22521 L .66911 .22358 L p F P
0 g
s
.138 0 .105 r
.54774 .33839 m .5481 .33753 L .53941 .34298 L p F P
0 g
s
.138 0 .105 r
.54221 .34339 m .54774 .33839 L p .53941 .34298 L F P
0 g
s
.138 0 .105 r
.53941 .34298 m .53828 .34588 L .54221 .34339 L p F P
0 g
s
.581 .328 .498 r
.46605 .39227 m .4639 .39276 L .46361 .39691 L p F P
0 g
s
.744 .977 .728 r
.72222 .34291 m .7204 .34371 L .72585 .33815 L closepath p F P
0 g
s
.731 .978 .918 r
.66718 .38421 m .66953 .38456 L .65931 .3912 L p F P
0 g
s
.731 .978 .918 r
.66337 .3867 m .66718 .38421 L p .65931 .3912 L F P
0 g
s
.731 .978 .918 r
.65931 .3912 m .65854 .3911 L .66337 .3867 L p F P
0 g
s
.676 .874 .973 r
.57515 .42313 m .57582 .42352 L .5667 .42832 L p F P
0 g
s
.676 .874 .973 r
.5667 .42832 m .56493 .42727 L .57515 .42313 L p F P
0 g
s
.683 .725 .882 r
.71738 .20549 m .72782 .20133 L .73023 .20496 L p F P
0 g
s
.695 .739 .885 r
.72782 .20133 m .71738 .20549 L .71499 .20235 L p F P
0 g
s
.746 .489 .542 r
.36403 .40299 m .37261 .40422 L .37274 .39979 L p F P
0 g
s
.746 .489 .542 r
.37274 .39979 m .36418 .39855 L .36403 .40299 L p F P
0 g
s
.787 .48 .469 r
.33402 .38775 m .34096 .38958 L .34009 .38554 L p F P
0 g
s
.787 .48 .469 r
.34009 .38554 m .33325 .38367 L .33402 .38775 L p F P
0 g
s
0 0 0 r
.74945 .30804 m .74867 .3093 L .7499 .30716 L p F P
0 g
s
0 0 0 r
.7499 .30716 m .75281 .30244 L .74945 .30804 L p F P
0 g
s
.306 .629 .962 r
.19454 .40858 m .20088 .40952 L .2051 .41236 L p F P
0 g
s
.314 .629 .961 r
.20088 .40952 m .19454 .40858 L .19131 .40586 L p F P
0 g
s
.636 .671 .866 r
.74247 .20505 m .74166 .20669 L p .73023 .20496 L F P
0 g
s
.636 .671 .866 r
.73023 .20496 m .74078 .20213 L .74247 .20505 L p F P
0 g
s
.65 .687 .872 r
.74078 .20213 m .73023 .20496 L .72782 .20133 L p F P
0 g
s
.692 .9 .971 r
.593 .42033 m .59052 .42145 L .58796 .42015 L p F P
0 g
s
.68 .897 .975 r
.57774 .42456 m .58796 .42015 L .59052 .42145 L p F P
0 g
s
.679 .694 .857 r
.43924 .43858 m .44927 .43451 L .45206 .43852 L p F P
0 g
s
.684 .658 .818 r
.43924 .43858 m .44927 .43451 L .44667 .43007 L p F P
0 g
s
.684 .658 .818 r
.43643 .43436 m .43924 .43858 L p .44667 .43007 L F P
0 g
s
.188 .549 .93 r
.16338 .39313 m .1694 .39478 L .17322 .3978 L p F P
0 g
s
.197 .55 .931 r
.1694 .39478 m .16338 .39313 L .16011 .39022 L p F P
0 g
s
.853 .422 .201 r
.27615 .3434 m .28076 .34614 L .27894 .34254 L p F P
0 g
s
.853 .422 .201 r
.27493 .34088 m .27615 .3434 L p .27894 .34254 L F P
0 g
s
.853 .422 .201 r
.27894 .34254 m .27631 .34094 L .27493 .34088 L p F P
0 g
s
.695 .473 .583 r
.41581 .40655 m .41419 .40656 L .41283 .41145 L p F P
0 g
s
.699 .478 .584 r
.403 .41141 m .41283 .41145 L .41419 .40656 L p F P
0 g
s
.699 .478 .584 r
.41419 .40656 m .40272 .40652 L .403 .41141 L p F P
0 g
s
.548 .046 0 r
.22023 .28776 m .22167 .28931 L .225 .29263 L p F P
0 g
s
.558 .055 0 r
.22453 .2924 m .22787 .29572 L .225 .29263 L p F P
0 g
s
.558 .055 0 r
.225 .29263 m .22167 .28931 L .22453 .2924 L p F P
0 g
s
.681 .463 .584 r
.42787 .406 m .41581 .40655 L .41609 .41142 L p F P
0 g
s
.695 .473 .583 r
.41283 .41145 m .41609 .41142 L .41581 .40655 L p F P
0 g
s
.639 .739 .921 r
.3179 .43497 m .30813 .43748 L .30509 .43471 L p F P
0 g
s
.624 .744 .933 r
.30813 .43748 m .3179 .43497 L .32092 .43789 L p F P
0 g
s
.709 .486 .584 r
.40104 .41135 m .403 .41141 L .40272 .40652 L p F P
0 g
s
.709 .486 .584 r
.40272 .40652 m .4023 .4065 L .40104 .41135 L p F P
0 g
s
.584 .328 .495 r
.47488 .39033 m .46605 .39227 L .4689 .3957 L p F P
0 g
s
.581 .328 .498 r
.46361 .39691 m .4689 .3957 L .46605 .39227 L p F P
0 g
s
.713 .486 .579 r
.39045 .41083 m .40104 .41135 L .4023 .4065 L p F P
0 g
s
.713 .486 .579 r
.4023 .4065 m .39155 .40605 L .39045 .41083 L p F P
0 g
s
.249 .592 .949 r
.17892 .40123 m .18448 .40239 L .1885 .40532 L p F P
0 g
s
.257 .592 .949 r
.18448 .40239 m .17892 .40123 L .17568 .39842 L p F P
0 g
s
.667 .842 .967 r
.54946 .42768 m .5521 .42953 L .54192 .43331 L p F P
0 g
s
.667 .842 .967 r
.54817 .42815 m .54946 .42768 L p .54192 .43331 L F P
0 g
s
.667 .842 .967 r
.54192 .43331 m .53979 .4318 L .54817 .42815 L p F P
0 g
s
.753 .238 0 r
.25298 .3213 m .25048 .318 L .25453 .32099 L p F P
0 g
s
.753 .238 0 r
.25506 .32279 m .25298 .3213 L p .25453 .32099 L F P
0 g
s
.753 .238 0 r
.25453 .32099 m .25665 .32369 L .25506 .32279 L p F P
0 g
s
.525 .732 .969 r
.27757 .43124 m .27957 .43292 L p .26688 .43128 L F P
0 g
s
.525 .732 .969 r
.26688 .43128 m .27573 .43038 L .27757 .43124 L p F P
0 g
s
.538 .732 .964 r
.27573 .43038 m .26688 .43128 L .26376 .42872 L p F P
0 g
s
.345 .358 .731 r
.76415 .22979 m .76732 .23214 L .76598 .2355 L closepath p F P
0 g
s
.24 .26 .681 r
.77031 .23543 m .76732 .23214 L .76598 .2355 L p F P
0 g
s
.24 .26 .681 r
.76825 .24047 m .77031 .23543 L p .76598 .2355 L F P
0 g
s
.24 .26 .681 r
.76598 .2355 m .76693 .23889 L .76825 .24047 L p F P
0 g
s
.322 .358 .743 r
.76364 .22829 m .76415 .22979 L .76732 .23214 L p F P
0 g
s
.446 .704 .976 r
.23846 .42423 m .2446 .42419 L .24945 .42676 L p F P
0 g
s
.456 .706 .975 r
.2446 .42419 m .23846 .42423 L .23529 .42166 L p F P
0 g
s
.452 .157 .373 r
.50678 .37276 m .50721 .37056 L .4971 .37512 L p F P
0 g
s
.452 .157 .373 r
.4971 .37512 m .49682 .37649 L .50678 .37276 L p F P
0 g
s
.81 .889 .901 r
.67712 .22121 m .68171 .21791 L .67932 .21594 L p F P
0 g
s
.81 .889 .901 r
.67932 .21594 m .67915 .21607 L .67712 .22121 L p F P
0 g
s
.799 .902 .914 r
.66911 .22358 m .67915 .21607 L .67712 .22121 L p F P
0 g
s
.674 .708 .873 r
.45206 .43852 m .46211 .43472 L .46489 .43845 L p F P
0 g
s
.679 .673 .838 r
.46211 .43472 m .45206 .43852 L .44927 .43451 L p F P
0 g
s
.407 .433 .775 r
.76152 .2226 m .76514 .22425 L .76364 .22829 L closepath p F P
0 g
s
.322 .358 .743 r
.76933 .2271 m .76514 .22425 L .76364 .22829 L p F P
0 g
s
.322 .358 .743 r
.76732 .23214 m .76933 .2271 L p .76364 .22829 L F P
0 g
s
.566 .748 .962 r
.27957 .43292 m .28151 .4326 L .28744 .43476 L p F P
0 g
s
.562 .737 .958 r
.28924 .43129 m .28151 .4326 L .28744 .43476 L p F P
0 g
s
.562 .737 .958 r
.28744 .43476 m .29231 .43403 L .28924 .43129 L p F P
0 g
s
.831 .457 .345 r
.30084 .36493 m .30641 .36729 L .30486 .36354 L p F P
0 g
s
.831 .457 .345 r
.30486 .36354 m .2994 .36114 L .30084 .36493 L p F P
0 g
s
0 0 0 r
.57962 .30656 m .57808 .30839 L .58411 .30228 L closepath p F P
0 g
s
.802 .471 .428 r
.32042 .37961 m .32688 .38163 L .32568 .37772 L p F P
0 g
s
.802 .471 .428 r
.32568 .37772 m .31936 .37566 L .32042 .37961 L p F P
0 g
s
.675 .892 .533 r
.7409 .32071 m .74038 .32124 L .74187 .31928 L closepath p F P
0 g
s
0 .379 .836 r
.12601 .36762 m .12531 .36726 L .12864 .37052 L p F P
0 g
s
0 .379 .836 r
.12864 .37052 m .1293 .37086 L .12601 .36762 L p F P
0 g
s
0 0 0 r
.75788 .29216 m .75774 .29259 L .75811 .29175 L closepath p F P
0 g
s
.614 .657 .868 r
.74166 .20669 m .74247 .20505 L .74321 .20637 L closepath p F P
0 g
s
.688 .914 .972 r
.60075 .41675 m .593 .42033 L .59959 .41623 L closepath p F P
0 g
s
.692 .9 .971 r
.59821 .41554 m .59959 .41623 L .593 .42033 L p F P
0 g
s
.692 .9 .971 r
.58796 .42015 m .59821 .41554 L p .593 .42033 L F P
0 g
s
.692 .932 .966 r
.6135 .41288 m .61283 .41321 L .61339 .41284 L closepath p F P
0 g
s
.694 .922 .969 r
.611 .41182 m .61339 .41284 L .61283 .41321 L p F P
0 g
s
.694 .922 .969 r
.60075 .41675 m .611 .41182 L p .61283 .41321 L F P
0 g
s
.616 .381 .537 r
.46356 .40134 m .46361 .39691 L .45231 .39895 L p F P
0 g
s
.616 .381 .537 r
.45231 .39895 m .45225 .40338 L .46356 .40134 L p F P
0 g
s
.638 .398 .539 r
.44462 .40437 m .45225 .40338 L .45231 .39895 L p F P
0 g
s
.831 .981 .879 r
.63962 .24937 m .63867 .24921 L .64101 .24715 L closepath p F P
0 g
s
.08 .471 .89 r
.14465 .38107 m .14589 .38156 L .14947 .38469 L p F P
0 g
s
.124 .498 .906 r
.15184 .38363 m .1554 .38677 L .14947 .38469 L p F P
0 g
s
.124 .498 .906 r
.14947 .38469 m .14589 .38156 L .15184 .38363 L p F P
0 g
s
.271 .27 .674 r
.76693 .23889 m .76825 .24047 L .76769 .24178 L closepath p F P
0 g
s
.721 .494 .581 r
.38934 .41076 m .39045 .41083 L .39155 .40605 L p F P
0 g
s
.721 .494 .581 r
.39155 .40605 m .38908 .40588 L .38934 .41076 L p F P
0 g
s
.825 .455 .353 r
.31188 .36853 m .31226 .36954 L .3113 .36913 L closepath p F P
0 g
s
.631 .845 .457 r
.74544 .31387 m .74187 .31928 L .7459 .31345 L p F P
0 g
s
.631 .845 .457 r
.74821 .30989 m .74544 .31387 L p .7459 .31345 L F P
0 g
s
.631 .845 .457 r
.7459 .31345 m .74867 .3093 L .74821 .30989 L p F P
0 g
s
.025 0 .005 r
.54982 .33631 m .5481 .33753 L .54935 .3348 L p F P
0 g
s
.025 0 .005 r
.54935 .3348 m .55702 .32938 L .54982 .33631 L p F P
0 g
s
.727 .805 .913 r
.70894 .20543 m .70463 .2076 L .70225 .20491 L p F P
0 g
s
.757 .813 .897 r
.69195 .21112 m .70225 .20491 L .70463 .2076 L p F P
0 g
s
.749 .988 .896 r
.68062 .37751 m .67975 .37746 L .6829 .37519 L closepath p F P
0 g
s
.68 .461 .583 r
.42837 .40597 m .42787 .406 L .42633 .41095 L p F P
0 g
s
.681 .463 .584 r
.41609 .41142 m .42633 .41095 L .42787 .406 L p F P
0 g
s
.664 .45 .583 r
.44077 .40974 m .44052 .40492 L .42837 .40597 L p F P
0 g
s
.664 .45 .583 r
.42837 .40597 m .42865 .41084 L .44077 .40974 L p F P
0 g
s
.68 .461 .583 r
.42633 .41095 m .42865 .41084 L .42837 .40597 L p F P
0 g
s
.67 .726 .892 r
.46489 .43845 m .47496 .43486 L .47773 .43826 L p F P
0 g
s
.674 .693 .86 r
.47496 .43486 m .46489 .43845 L .46211 .43472 L p F P
0 g
s
.719 .956 .948 r
.64426 .3963 m .64668 .39701 L .63644 .40284 L p F P
0 g
s
.719 .956 .948 r
.63666 .40065 m .64426 .3963 L p .63644 .40284 L F P
0 g
s
.719 .956 .948 r
.63644 .40284 m .63458 .40233 L .63666 .40065 L p F P
0 g
s
.741 .981 .914 r
.6698 .3846 m .66953 .38456 L .67057 .38386 L closepath p F P
0 g
s
.704 .935 .963 r
.62173 .40689 m .62374 .4076 L .6135 .41288 L p F P
0 g
s
.704 .935 .963 r
.6135 .41288 m .61339 .41284 L .62173 .40689 L p F P
0 g
s
.156 .116 .558 r
.76973 .25231 m .76935 .2531 L .76799 .24921 L p F P
0 g
s
.156 .116 .558 r
.76799 .24921 m .76891 .24733 L .76973 .25231 L p F P
0 g
s
.665 .815 .955 r
.53926 .43141 m .52909 .43502 L .52641 .4328 L p F P
0 g
s
.661 .812 .955 r
.51626 .43628 m .52641 .4328 L .52909 .43502 L p F P
0 g
s
.726 .499 .581 r
.38058 .41006 m .38934 .41076 L .38908 .40588 L p F P
0 g
s
.726 .499 .581 r
.38908 .40588 m .38166 .40528 L .38058 .41006 L p F P
0 g
s
.651 .737 .912 r
.32092 .43789 m .33074 .43481 L .33372 .43796 L p F P
0 g
s
.667 .729 .896 r
.33074 .43481 m .32092 .43789 L .3179 .43497 L p F P
0 g
s
.571 .058 0 r
.23078 .29881 m .23428 .30205 L .23134 .29897 L p F P
0 g
s
.571 .058 0 r
.23134 .29897 m .22787 .29572 L .23078 .29881 L p F P
0 g
s
.783 .873 .914 r
.69065 .21198 m .68171 .21791 L .67932 .21594 L p F P
0 g
s
.846 .428 .24 r
.2825 .34979 m .28743 .35241 L .28559 .3488 L p F P
0 g
s
.846 .428 .24 r
.28559 .3488 m .28076 .34614 L .2825 .34979 L p F P
0 g
s
.741 .981 .747 r
.60931 .27755 m .60836 .27797 L .6112 .27519 L closepath p F P
0 g
s
0 0 0 r
.75878 .29172 m .76104 .28651 L .75811 .29175 L p F P
0 g
s
0 0 0 r
.75705 .29482 m .75878 .29172 L p .75811 .29175 L F P
0 g
s
0 0 0 r
.75811 .29175 m .75774 .29259 L .75705 .29482 L p F P
0 g
s
.705 .924 .965 r
.62126 .40669 m .62173 .40689 L .61339 .41284 L p F P
0 g
s
.705 .924 .965 r
.61339 .41284 m .611 .41182 L .62126 .40669 L p F P
0 g
s
.759 .5 .541 r
.35955 .40216 m .36403 .40299 L .36418 .39855 L p F P
0 g
s
.759 .5 .541 r
.36418 .39855 m .35974 .39774 L .35955 .40216 L p F P
0 g
s
.666 .747 .911 r
.47773 .43826 m .48782 .43481 L .49057 .43787 L p F P
0 g
s
.669 .716 .884 r
.48782 .43481 m .47773 .43826 L .47496 .43486 L p F P
0 g
s
.199 .187 .619 r
.77028 .24411 m .76891 .24733 L .76769 .24178 L p F P
0 g
s
.199 .187 .619 r
.76769 .24178 m .76825 .24047 L .77028 .24411 L p F P
0 g
s
.821 .342 .021 r
.25665 .32369 m .25702 .32429 L .26111 .32726 L p F P
0 g
s
.835 .366 .057 r
.25905 .32778 m .26321 .33073 L .26111 .32726 L p F P
0 g
s
.835 .366 .057 r
.26111 .32726 m .25702 .32429 L .25905 .32778 L p F P
0 g
s
.823 .417 .278 r
.29446 .35575 m .29333 .35635 L .29262 .35492 L closepath p F P
0 g
s
.781 .495 .502 r
.34348 .39426 m .34854 .39554 L .34814 .39132 L p F P
0 g
s
.781 .495 .502 r
.34814 .39132 m .34409 .3903 L .34348 .39426 L p F P
0 g
s
.664 .793 .944 r
.52641 .4328 m .51626 .43628 L .51355 .43382 L p F P
0 g
s
.661 .791 .944 r
.50341 .43723 m .51355 .43382 L .51626 .43628 L p F P
0 g
s
.391 .438 .79 r
.76037 .2197 m .76152 .2226 L .76514 .22425 L p F P
0 g
s
.756 .993 .873 r
.69104 .3699 m .68995 .36992 L .69368 .36704 L closepath p F P
0 g
s
.009 .413 .857 r
.1293 .37086 m .13366 .37289 L .13706 .37611 L p F P
0 g
s
.021 .416 .86 r
.13366 .37289 m .1293 .37086 L .12601 .36762 L p F P
0 g
s
.663 .769 .929 r
.49057 .43787 m .50068 .43448 L .50341 .43723 L p F P
0 g
s
.666 .742 .907 r
.50068 .43448 m .49057 .43787 L .48782 .43481 L p F P
0 g
s
.572 .596 .838 r
.75556 .2088 m .7548 .21062 L p .74321 .20637 L F P
0 g
s
.572 .596 .838 r
.74321 .20637 m .75395 .2055 L .75556 .2088 L p F P
0 g
s
.566 .633 .877 r
.74247 .20505 m .74321 .20637 L .75395 .2055 L p F P
0 g
s
0 0 0 r
.75774 .29259 m .75572 .297 L .75705 .29482 L closepath p F P
0 g
s
.664 .768 .927 r
.51355 .43382 m .50341 .43723 L .50068 .43448 L p F P
0 g
s
.673 .725 .889 r
.33372 .43796 m .34359 .43426 L .34654 .43769 L p F P
0 g
s
.688 .713 .867 r
.34359 .43426 m .33372 .43796 L .33074 .43481 L p F P
0 g
s
.452 .704 .975 r
.24793 .42413 m .2446 .42419 L .24945 .42676 L p F P
0 g
s
.452 .704 .975 r
.24945 .42676 m .25108 .42674 L .24793 .42413 L p F P
0 g
s
.745 .979 .917 r
.67057 .38386 m .66953 .38456 L .66718 .38421 L p F P
0 g
s
.737 .97 .932 r
.65854 .3911 m .65693 .39076 L .66337 .3867 L closepath p F P
0 g
s
.526 .033 0 r
.22167 .28931 m .22023 .28776 L .21707 .28445 L p F P
0 g
s
.682 .889 .974 r
.5854 .41878 m .58796 .42015 L .57774 .42456 L p F P
0 g
s
.682 .889 .974 r
.58035 .42095 m .5854 .41878 L p .57774 .42456 L F P
0 g
s
.682 .889 .974 r
.57774 .42456 m .57582 .42352 L .58035 .42095 L p F P
0 g
s
.271 .602 .953 r
.18807 .40308 m .18448 .40239 L .1885 .40532 L p F P
0 g
s
.271 .602 .953 r
.1885 .40532 m .19131 .40586 L .18807 .40308 L p F P
0 g
s
.739 .511 .583 r
.37502 .4094 m .38058 .41006 L .38166 .40528 L p F P
0 g
s
.739 .511 .583 r
.38166 .40528 m .37474 .40447 L .37502 .4094 L p F P
0 g
s
.739 .986 .899 r
.67057 .38386 m .67975 .37746 L .67743 .3773 L p F P
0 g
s
.739 .986 .899 r
.67743 .3773 m .67705 .37756 L .67057 .38386 L p F P
0 g
s
.745 .979 .917 r
.66718 .38421 m .67705 .37756 L .67057 .38386 L p F P
0 g
s
.324 .636 .964 r
.20378 .4099 m .20088 .40952 L .2051 .41236 L p F P
0 g
s
.324 .636 .964 r
.2051 .41236 m .20699 .41261 L .20378 .4099 L p F P
0 g
s
.829 .476 .387 r
.30939 .37172 m .31346 .37343 L .31226 .36954 L p F P
0 g
s
.829 .476 .387 r
.31226 .36954 m .3113 .36913 L .30939 .37172 L p F P
0 g
s
.689 .71 .864 r
.34654 .43769 m .35646 .43339 L .35938 .43717 L p F P
0 g
s
.703 .694 .838 r
.35646 .43339 m .34654 .43769 L .34359 .43426 L p F P
0 g
s
.824 .368 .144 r
.27631 .34094 m .27493 .34088 L .27429 .33981 L closepath p F P
0 g
s
.804 .493 .464 r
.32761 .38571 m .33402 .38775 L .33325 .38367 L p F P
0 g
s
.804 .493 .464 r
.32714 .38293 m .32761 .38571 L p .33325 .38367 L F P
0 g
s
.804 .493 .464 r
.33325 .38367 m .32748 .3818 L .32714 .38293 L p F P
0 g
s
.699 .693 .841 r
.35938 .43717 m .36933 .43232 L .37223 .43648 L p F P
0 g
s
.712 .679 .816 r
.35938 .43717 m .36933 .43232 L .36762 .42953 L p F P
0 g
s
.712 .679 .816 r
.35646 .43339 m .35938 .43717 L p .36762 .42953 L F P
0 g
s
.704 .668 .812 r
.39617 .43213 m .39202 .43196 L .38507 .43575 L p F P
0 g
s
.707 .679 .82 r
.39202 .43196 m .38507 .43575 L .38221 .43121 L p F P
0 g
s
.703 .677 .822 r
.37223 .43648 m .38221 .43121 L .38507 .43575 L p F P
0 g
s
.565 .75 .964 r
.27957 .43292 m .28151 .4326 L .27757 .43124 L closepath p F P
0 g
s
.713 .663 .798 r
.37223 .43648 m .38221 .43121 L .38216 .43111 L p F P
0 g
s
.713 .663 .798 r
.36933 .43232 m .37223 .43648 L p .38216 .43111 L F P
0 g
s
.471 .193 .409 r
.50621 .37647 m .50678 .37276 L .49682 .37649 L p F P
0 g
s
.471 .193 .409 r
.49682 .37649 m .49624 .38022 L .50621 .37647 L p F P
0 g
s
.7 .659 .806 r
.40952 .43243 m .40291 .43237 L .39792 .43509 L p F P
0 g
s
.703 .666 .811 r
.40291 .43237 m .39617 .43213 L .39792 .43509 L closepath p F P
0 g
s
.603 .079 0 r
.23525 .30309 m .23428 .30205 L .23792 .30523 L p F P
0 g
s
.603 .079 0 r
.23792 .30523 m .23843 .30577 L .23525 .30309 L p F P
0 g
s
.402 .684 .975 r
.22271 .41874 m .22343 .41877 L .22115 .41747 L closepath p F P
0 g
s
0 0 .369 r
.76993 .26167 m .76733 .26685 L .76736 .26245 L p F P
0 g
s
0 0 .369 r
.76736 .26245 m .76997 .25727 L .76993 .26167 L p F P
0 g
s
.46 .495 .809 r
.75896 .21634 m .76132 .21695 L .76037 .2197 L closepath p F P
0 g
s
.391 .438 .79 r
.76706 .21922 m .76132 .21695 L .76037 .2197 L p F P
0 g
s
.391 .438 .79 r
.76514 .22425 m .76706 .21922 L p .76037 .2197 L F P
0 g
s
.738 .798 .901 r
.70894 .20543 m .71499 .20235 L .7126 .19932 L p F P
0 g
s
.738 .798 .901 r
.7126 .19932 m .71054 .20044 L .70894 .20543 L p F P
0 g
s
.727 .805 .913 r
.70225 .20491 m .71054 .20044 L .70894 .20543 L p F P
0 g
s
.214 .564 .937 r
.17242 .39555 m .1694 .39478 L .17322 .3978 L p F P
0 g
s
.214 .564 .937 r
.17322 .3978 m .17568 .39842 L .17242 .39555 L p F P
0 g
s
.646 .432 .579 r
.44462 .40437 m .44052 .40492 L .44077 .40974 L p F P
0 g
s
.517 .251 .45 r
.4958 .38412 m .49624 .38022 L .48596 .38354 L p F P
0 g
s
.517 .251 .45 r
.48596 .38354 m .48551 .38744 L .4958 .38412 L p F P
0 g
s
0 0 .144 r
.76433 .27875 m .76281 .28148 L .76406 .27664 L p F P
0 g
s
0 0 .144 r
.76406 .27664 m .76471 .27548 L .76433 .27875 L p F P
0 g
s
.756 .498 .542 r
.35601 .40155 m .35955 .40216 L .35974 .39774 L p F P
0 g
s
.756 .498 .542 r
.35974 .39774 m .35616 .39712 L .35601 .40155 L p F P
0 g
s
.404 .108 .345 r
.5075 .36923 m .50721 .37056 L .51271 .36696 L closepath p F P
0 g
s
.834 .37 .092 r
.26525 .33422 m .26967 .33706 L .26753 .33359 L p F P
0 g
s
.834 .37 .092 r
.26753 .33359 m .26321 .33073 L .26525 .33422 L p F P
0 g
s
.696 .654 .805 r
.42237 .43217 m .41504 .43235 L .41076 .43461 L p F P
0 g
s
.697 .657 .807 r
.41504 .43235 m .40952 .43243 L .41076 .43461 L closepath p F P
0 g
s
.828 .418 .267 r
.28916 .35607 m .28743 .35241 L .29262 .35492 L p F P
0 g
s
.828 .418 .267 r
.29147 .35717 m .28916 .35607 L p .29262 .35492 L F P
0 g
s
.828 .418 .267 r
.29262 .35492 m .29333 .35635 L .29147 .35717 L p F P
0 g
s
.678 .894 .536 r
.74089 .31989 m .74544 .31387 L .74187 .31928 L p F P
0 g
s
.678 .894 .536 r
.73928 .32235 m .74089 .31989 L p .74187 .31928 L F P
0 g
s
.678 .894 .536 r
.74187 .31928 m .74038 .32124 L .73928 .32235 L p F P
0 g
s
.814 .455 .376 r
.30778 .37111 m .30939 .37172 L .3113 .36913 L p F P
0 g
s
.814 .455 .376 r
.3113 .36913 m .30641 .36729 L .30778 .37111 L p F P
0 g
s
0 0 0 r
.55908 .32635 m .55786 .3286 L .56392 .32256 L closepath p F P
0 g
s
.044 .437 .872 r
.13808 .37481 m .13366 .37289 L .13706 .37611 L p F P
0 g
s
.044 .437 .872 r
.13706 .37611 m .14137 .37798 L .13808 .37481 L p F P
0 g
s
.598 .653 .875 r
.74078 .20213 m .74328 .20172 L .74247 .20505 L closepath p F P
0 g
s
.566 .633 .877 r
.75148 .20065 m .74328 .20172 L .74247 .20505 L p F P
0 g
s
.566 .633 .877 r
.75395 .2055 m .75148 .20065 L p .74247 .20505 L F P
0 g
s
.56 .308 .491 r
.48524 .39158 m .48551 .38744 L .47488 .39033 L p F P
0 g
s
.56 .308 .491 r
.47488 .39033 m .47459 .39445 L .48524 .39158 L p F P
0 g
s
.584 .328 .495 r
.4689 .3957 m .47459 .39445 L .47488 .39033 L p F P
0 g
s
.69 .654 .809 r
.43476 .4314 m .42885 .43175 L .42359 .43437 L p F P
0 g
s
.689 .652 .807 r
.42885 .43175 m .42237 .43217 L .42359 .43437 L closepath p F P
0 g
s
.774 .488 .502 r
.34139 .39379 m .34348 .39426 L .34409 .3903 L p F P
0 g
s
.774 .488 .502 r
.34409 .3903 m .34096 .38958 L .34139 .39379 L p F P
0 g
s
.762 .996 .847 r
.70108 .36177 m .70014 .36185 L .7032 .35931 L closepath p F P
0 g
s
.44 .696 .974 r
.22894 .41637 m .23212 .41904 L .22343 .41877 L p F P
0 g
s
.44 .696 .974 r
.21952 .41612 m .22894 .41637 L p .22343 .41877 L F P
0 g
s
.44 .696 .974 r
.22343 .41877 m .22115 .41747 L .21952 .41612 L p F P
0 g
s
.334 .026 .285 r
.51798 .36173 m .51734 .36416 L .52489 .35828 L closepath p F P
0 g
s
.74 .512 .584 r
.37154 .40899 m .37502 .4094 L .37474 .40447 L p F P
0 g
s
.74 .512 .584 r
.37474 .40447 m .37261 .40422 L .37154 .40899 L p F P
0 g
s
.657 .886 .532 r
.74038 .32124 m .73715 .32535 L .73928 .32235 L closepath p F P
0 g
s
.506 .722 .97 r
.26063 .42609 m .25108 .42674 L .24793 .42413 L p F P
0 g
s
.783 .873 .914 r
.68957 .20884 m .6912 .21039 L .69065 .21198 L p F P
0 g
s
.783 .873 .914 r
.67932 .21594 m .68957 .20884 L p .69065 .21198 L F P
0 g
s
.781 .848 .902 r
.69195 .21112 m .69065 .21198 L .6912 .21039 L closepath p F P
0 g
s
.542 .846 .533 r
.58891 .2975 m .58818 .29819 L .59078 .29554 L closepath p F P
0 g
s
.199 .192 .625 r
.77241 .23905 m .77028 .24411 L .76825 .24047 L p F P
0 g
s
.199 .192 .625 r
.76825 .24047 m .77031 .23543 L .77241 .23905 L p F P
0 g
s
.649 .435 .58 r
.45225 .40338 m .44462 .40437 L .44262 .40949 L p F P
0 g
s
.646 .432 .579 r
.44077 .40974 m .44262 .40949 L .44462 .40437 L p F P
0 g
s
.7 .51 .628 r
.41609 .41142 m .41283 .41145 L .40967 .41697 L p F P
0 g
s
.705 .516 .631 r
.40385 .41694 m .40967 .41697 L .41283 .41145 L p F P
0 g
s
.705 .516 .631 r
.41283 .41145 m .403 .41141 L .40385 .41694 L p F P
0 g
s
.737 .234 0 r
.24043 .30849 m .23843 .30577 L .23525 .30309 L p F P
0 g
s
.753 .248 0 r
.24282 .31181 m .24658 .31494 L .24413 .31164 L p F P
0 g
s
.753 .248 0 r
.24413 .31164 m .24043 .30849 L .24282 .31181 L p F P
0 g
s
.688 .502 .63 r
.42633 .41095 m .41609 .41142 L .4169 .4169 L p F P
0 g
s
.7 .51 .628 r
.40967 .41697 m .4169 .4169 L .41609 .41142 L p F P
0 g
s
.713 .522 .629 r
.39815 .41677 m .40385 .41694 L .403 .41141 L p F P
0 g
s
.713 .522 .629 r
.403 .41141 m .40104 .41135 L .39815 .41677 L p F P
0 g
s
.83 .959 .895 r
.649 .24032 m .64879 .24025 L .64928 .23984 L closepath p F P
0 g
s
.768 .508 .542 r
.34836 .39998 m .35601 .40155 L .35616 .39712 L p F P
0 g
s
.768 .508 .542 r
.35616 .39712 m .34854 .39554 L .34836 .39998 L p F P
0 g
s
.769 .846 .909 r
.69986 .20231 m .70225 .20491 L .69195 .21112 L p F P
0 g
s
.769 .846 .909 r
.69282 .20679 m .69986 .20231 L p .69195 .21112 L F P
0 g
s
.769 .846 .909 r
.69195 .21112 m .6912 .21039 L .69282 .20679 L p F P
0 g
s
.718 .517 .617 r
.39022 .41634 m .39815 .41677 L .40104 .41135 L p F P
0 g
s
.718 .517 .617 r
.38961 .41272 m .39022 .41634 L p .40104 .41135 L F P
0 g
s
.718 .517 .617 r
.40104 .41135 m .39045 .41083 L .38961 .41272 L p F P
0 g
s
.748 .516 .58 r
.36306 .40772 m .37154 .40899 L .37261 .40422 L p F P
0 g
s
.748 .516 .58 r
.37261 .40422 m .36403 .40299 L .36306 .40772 L p F P
0 g
s
.738 .963 .68 r
.73094 .33293 m .73044 .33322 L .73188 .33162 L closepath p F P
0 g
s
.728 .96 .943 r
.64683 .39705 m .64668 .39701 L .64733 .39663 L closepath p F P
0 g
s
.82 .488 .428 r
.31442 .37742 m .32042 .37961 L .31936 .37566 L p F P
0 g
s
.82 .488 .428 r
.31936 .37566 m .31346 .37343 L .31442 .37742 L p F P
0 g
s
.107 .083 .545 r
.77156 .24804 m .76973 .25231 L .76891 .24733 L p F P
0 g
s
.107 .083 .545 r
.76891 .24733 m .77028 .24411 L .77156 .24804 L p F P
0 g
s
.684 .658 .818 r
.44667 .43007 m .44548 .43018 L .43643 .43436 L p F P
0 g
s
.682 .651 .813 r
.44548 .43018 m .43476 .4314 L .43643 .43436 L closepath p F P
0 g
s
.156 .521 .917 r
.15685 .38723 m .1554 .38677 L .15904 .38987 L p F P
0 g
s
.156 .521 .917 r
.15904 .38987 m .16011 .39022 L .15685 .38723 L p F P
0 g
s
.678 .866 .97 r
.57515 .42313 m .56493 .42727 L .56232 .42558 L p F P
0 g
s
.671 .861 .972 r
.5521 .42953 m .56232 .42558 L .56493 .42727 L p F P
0 g
s
.578 .75 .959 r
.28617 .42846 m .28924 .43129 L .28151 .4326 L p F P
0 g
s
.578 .75 .959 r
.27647 .43029 m .28617 .42846 L p .28151 .4326 L F P
0 g
s
.578 .75 .959 r
.28151 .4326 m .27757 .43124 L .27647 .43029 L p F P
0 g
s
.478 .515 .818 r
.76132 .21695 m .75896 .21634 L .75644 .21068 L p F P
0 g
s
.751 .987 .897 r
.6829 .37519 m .67975 .37746 L .67743 .3773 L p F P
0 g
s
.091 .472 .892 r
.14589 .38156 m .14465 .38107 L .14137 .37798 L p F P
0 g
s
.595 .364 .535 r
.4689 .3957 m .46361 .39691 L .46356 .40134 L p F P
0 g
s
.827 .986 .876 r
.64101 .24715 m .63867 .24921 L .63632 .2489 L p F P
0 g
s
.84 .985 .868 r
.63867 .24921 m .63313 .25431 L .63632 .2489 L closepath p F P
0 g
s
.697 .916 .969 r
.60848 .41071 m .611 .41182 L .60075 .41675 L p F P
0 g
s
.697 .916 .969 r
.60635 .41173 m .60848 .41071 L p .60075 .41675 L F P
0 g
s
.697 .916 .969 r
.60075 .41675 m .59959 .41623 L .60635 .41173 L p F P
0 g
s
.812 .998 .845 r
.63626 .24889 m .63632 .2489 L .63313 .25431 L p F P
0 g
s
.812 .998 .845 r
.62928 .25566 m .63626 .24889 L p .63313 .25431 L F P
0 g
s
.812 .998 .845 r
.62738 .25858 m .62928 .25566 L p .63313 .25431 L F P
0 g
s
.812 .998 .845 r
.63313 .25431 m .62856 .25851 L .62738 .25858 L p F P
0 g
s
.824 .998 .84 r
.62856 .25851 m .62555 .26137 L .62738 .25858 L closepath p F P
0 g
s
.844 .981 .869 r
.64101 .24715 m .64879 .24025 L .64639 .23952 L p F P
0 g
s
.844 .981 .869 r
.64639 .23952 m .64411 .24164 L .64101 .24715 L p F P
0 g
s
.827 .986 .876 r
.6364 .24876 m .64411 .24164 L .64101 .24715 L p F P
0 g
s
.827 .986 .876 r
.63632 .2489 m .6364 .24876 L p .64101 .24715 L F P
0 g
s
.827 .366 .123 r
.27168 .34044 m .26967 .33706 L .27429 .33981 L p F P
0 g
s
.827 .366 .123 r
.27429 .33981 m .27493 .34088 L .27168 .34044 L p F P
0 g
s
.778 .996 .798 r
.62614 .25869 m .62738 .25858 L .62555 .26137 L p F P
0 g
s
.778 .996 .798 r
.62234 .2625 m .62614 .25869 L p .62555 .26137 L F P
0 g
s
.778 .996 .798 r
.61836 .26811 m .62234 .2625 L p .62555 .26137 L F P
0 g
s
.778 .996 .798 r
.62555 .26137 m .61846 .26809 L .61836 .26811 L p F P
0 g
s
.367 .659 .969 r
.20699 .41261 m .21456 .41328 L .21889 .41607 L p F P
0 g
s
.375 .66 .969 r
.21456 .41328 m .20699 .41261 L .20378 .4099 L p F P
0 g
s
0 0 0 r
.75601 .29719 m .75281 .30244 L .75572 .297 L p F P
0 g
s
0 0 0 r
.75572 .297 m .75705 .29482 L .75601 .29719 L p F P
0 g
s
.846 .472 .344 r
.29557 .36245 m .30084 .36493 L .2994 .36114 L p F P
0 g
s
.846 .472 .344 r
.2994 .36114 m .29424 .35863 L .29557 .36245 L p F P
0 g
s
.703 .602 .741 r
.40952 .43243 m .41504 .43235 L p .41859 .42337 L F P
0 g
s
.703 .602 .741 r
.40794 .42926 m .40952 .43243 L p .41859 .42337 L F P
0 g
s
.705 .639 .78 r
.40794 .42926 m .40291 .43237 L .40952 .43243 L closepath p F P
0 g
s
.607 .743 .941 r
.29231 .43403 m .30205 .43183 L .30509 .43471 L p F P
0 g
s
.62 .74 .932 r
.30205 .43183 m .29231 .43403 L .28924 .43129 L p F P
0 g
s
.732 .956 .945 r
.64733 .39663 m .64668 .39701 L .64426 .3963 L p F P
0 g
s
.71 .611 .744 r
.40291 .43237 m .40794 .42926 L .40559 .42347 L p F P
0 g
s
.71 .611 .744 r
.39617 .43213 m .40291 .43237 L p .40559 .42347 L F P
0 g
s
.254 0 .217 r
.52824 .35394 m .52748 .3564 L .53407 .35065 L closepath p F P
0 g
s
.828 .966 .894 r
.64928 .23984 m .64879 .24025 L .64639 .23952 L p F P
0 g
s
.786 .5 .504 r
.33436 .39198 m .34139 .39379 L .34096 .38958 L p F P
0 g
s
.786 .5 .504 r
.34096 .38958 m .33402 .38775 L .33436 .39198 L p F P
0 g
s
.699 .633 .78 r
.42079 .42895 m .41504 .43235 L .42237 .43217 L closepath p F P
0 g
s
.703 .602 .741 r
.41504 .43235 m .42079 .42895 L .41859 .42337 L p F P
0 g
s
.687 .5 .629 r
.42865 .41084 m .42633 .41095 L .4227 .41664 L p F P
0 g
s
.688 .502 .63 r
.4169 .4169 m .4227 .41664 L .42633 .41095 L p F P
0 g
s
.838 .94 .892 r
.65225 .23437 m .64928 .23984 L .65826 .23227 L p F P
0 g
s
.828 .966 .894 r
.64639 .23952 m .65225 .23437 L .64928 .23984 L p F P
0 g
s
.788 .997 .796 r
.61846 .26809 m .61819 .26834 L .61836 .26811 L closepath p F P
0 g
s
0 0 .123 r
.76558 .27627 m .76433 .27875 L .76471 .27548 L p F P
0 g
s
0 0 .123 r
.76471 .27548 m .76673 .27146 L .76558 .27627 L p F P
0 g
s
.785 .996 .789 r
.61556 .26928 m .6112 .27519 L .61819 .26834 L p F P
0 g
s
.785 .996 .789 r
.61603 .26879 m .61556 .26928 L p .61819 .26834 L F P
0 g
s
.785 .996 .789 r
.61819 .26834 m .61836 .26811 L .61603 .26879 L p F P
0 g
s
.713 .939 .627 r
.73574 .32613 m .73188 .33162 L .73715 .32535 L p F P
0 g
s
.713 .939 .627 r
.73834 .32303 m .73574 .32613 L p .73715 .32535 L F P
0 g
s
.713 .939 .627 r
.73715 .32535 m .73928 .32235 L .73834 .32303 L p F P
0 g
s
.728 .967 .936 r
.65693 .39076 m .64733 .39663 L .65467 .39027 L closepath p F P
0 g
s
.732 .956 .945 r
.65454 .39023 m .65467 .39027 L .64733 .39663 L p F P
0 g
s
.732 .956 .945 r
.64426 .3963 m .65454 .39023 L p .64733 .39663 L F P
0 g
s
.745 .991 .878 r
.68995 .36992 m .6829 .37519 L .68799 .36992 L closepath p F P
0 g
s
.751 .987 .897 r
.68766 .36989 m .68799 .36992 L .6829 .37519 L p F P
0 g
s
.751 .987 .897 r
.67743 .3773 m .68766 .36989 L p .6829 .37519 L F P
0 g
s
.672 .49 .631 r
.44101 .41165 m .44077 .40974 L .42865 .41084 L p F P
0 g
s
.672 .49 .631 r
.4381 .41549 m .44101 .41165 L p .42865 .41084 L F P
0 g
s
.672 .49 .631 r
.42865 .41084 m .42946 .41631 L .4381 .41549 L p F P
0 g
s
.687 .5 .629 r
.4227 .41664 m .42946 .41631 L .42865 .41084 L p F P
0 g
s
.724 .524 .62 r
.39045 .41083 m .38934 .41076 L .38961 .41272 L closepath p F P
0 g
s
.694 .597 .743 r
.42237 .43217 m .42885 .43175 L p .43107 .42268 L F P
0 g
s
.694 .597 .743 r
.42079 .42895 m .42237 .43217 L p .43107 .42268 L F P
0 g
s
.65 .687 .872 r
.72782 .20133 m .73836 .19809 L .74078 .20213 L p F P
0 g
s
.663 .703 .876 r
.73836 .19809 m .72782 .20133 L .72542 .19784 L p F P
0 g
s
.695 .739 .885 r
.71499 .20235 m .72542 .19784 L .72782 .20133 L p F P
0 g
s
.729 .53 .623 r
.38779 .41617 m .38961 .41272 L .38934 .41076 L p F P
0 g
s
.729 .53 .623 r
.37821 .4153 m .38779 .41617 L p .38934 .41076 L F P
0 g
s
.729 .53 .623 r
.38934 .41076 m .38058 .41006 L .37821 .4153 L p F P
0 g
s
.675 .656 .824 r
.44667 .43007 m .44927 .43451 L .45933 .43029 L p F P
0 g
s
.679 .673 .838 r
.44927 .43451 m .45933 .43029 L .46211 .43472 L p F P
0 g
s
.71 .611 .744 r
.39508 .43006 m .39617 .43213 L p .40559 .42347 L F P
0 g
s
.709 .649 .787 r
.39508 .43006 m .39202 .43196 L .39617 .43213 L closepath p F P
0 g
s
.793 .997 .787 r
.61836 .26811 m .61603 .26879 L .62234 .2625 L closepath p F P
0 g
s
.762 .254 0 r
.24902 .31826 m .25298 .3213 L .25048 .318 L p F P
0 g
s
.762 .254 0 r
.25048 .318 m .24658 .31494 L .24902 .31826 L p F P
0 g
s
.712 .967 .719 r
.60913 .27593 m .61556 .26928 L .6112 .27519 L p F P
0 g
s
.712 .967 .719 r
.60703 .27865 m .60913 .27593 L p .6112 .27519 L F P
0 g
s
.712 .967 .719 r
.6112 .27519 m .60836 .27797 L .60703 .27865 L p F P
0 g
s
.713 .94 .959 r
.63154 .40122 m .634 .40213 L .62374 .4076 L p F P
0 g
s
.713 .94 .959 r
.62354 .4055 m .63154 .40122 L p .62374 .4076 L F P
0 g
s
.713 .94 .959 r
.62374 .4076 m .62173 .40689 L .62354 .4055 L p F P
0 g
s
.417 .127 .362 r
.51271 .36696 m .50721 .37056 L .50678 .37276 L p F P
0 g
s
.85 .457 .299 r
.29333 .35635 m .29424 .35863 L .29147 .35717 L closepath p F P
0 g
s
.707 .752 .887 r
.72542 .19784 m .71499 .20235 L .7126 .19932 L p F P
0 g
s
.722 .635 .76 r
.39202 .43196 m .39508 .43006 L .39228 .42361 L p F P
0 g
s
.722 .635 .76 r
.39228 .42361 m .38233 .43113 L .39202 .43196 L p F P
0 g
s
.707 .679 .82 r
.38221 .43121 m .38233 .43113 L .39202 .43196 L p F P
0 g
s
.72 .969 .719 r
.60836 .27797 m .60429 .28201 L .60703 .27865 L closepath p F P
0 g
s
.836 .938 .893 r
.65894 .2317 m .65826 .23227 L .65861 .23154 L closepath p F P
0 g
s
.838 .94 .892 r
.65655 .23057 m .65225 .23437 L p .65826 .23227 L F P
0 g
s
.838 .94 .892 r
.65826 .23227 m .65861 .23154 L .65655 .23057 L p F P
0 g
s
.526 .033 0 r
.21707 .28445 m .21846 .28593 L .22167 .28931 L p F P
0 g
s
.536 .043 0 r
.22131 .28903 m .22453 .2924 L .22167 .28931 L p F P
0 g
s
.536 .043 0 r
.22167 .28931 m .21846 .28593 L .22131 .28903 L p F P
0 g
s
.822 .939 .904 r
.66811 .22439 m .65894 .2317 L .65861 .23154 L p F P
0 g
s
.628 .42 .581 r
.46382 .40614 m .46356 .40134 L .45225 .40338 L p F P
0 g
s
.628 .42 .581 r
.45225 .40338 m .45252 .40821 L .46382 .40614 L p F P
0 g
s
.649 .435 .58 r
.44262 .40949 m .45252 .40821 L .45225 .40338 L p F P
0 g
s
.818 .336 0 r
.25665 .32369 m .25702 .32429 L .25506 .32279 L closepath p F P
0 g
s
.287 .293 .692 r
.77243 .23035 m .77031 .23543 L .76732 .23214 L p F P
0 g
s
.287 .293 .692 r
.76732 .23214 m .76933 .2271 L .77243 .23035 L p F P
0 g
s
.668 .835 .963 r
.53979 .4318 m .53926 .43141 L .54817 .42815 L closepath p F P
0 g
s
.314 .629 .961 r
.19131 .40586 m .19674 .40665 L .20088 .40952 L p F P
0 g
s
.322 .629 .961 r
.19674 .40665 m .19131 .40586 L .18807 .40308 L p F P
0 g
s
.197 .55 .931 r
.16011 .39022 m .16566 .39173 L .1694 .39478 L p F P
0 g
s
.205 .55 .931 r
.16566 .39173 m .16011 .39022 L .15685 .38723 L p F P
0 g
s
.621 .909 .622 r
.60593 .27925 m .60703 .27865 L .60429 .28201 L p F P
0 g
s
.621 .909 .622 r
.60279 .28256 m .60593 .27925 L p .60429 .28201 L F P
0 g
s
.621 .909 .622 r
.59803 .28818 m .60279 .28256 L p .60429 .28201 L F P
0 g
s
.621 .909 .622 r
.60429 .28201 m .59827 .288 L .59803 .28818 L p F P
0 g
s
.692 .633 .786 r
.43363 .42913 m .42885 .43175 L .43476 .4314 L closepath p F P
0 g
s
.694 .597 .743 r
.42885 .43175 m .43363 .42913 L .43107 .42268 L p F P
0 g
s
.375 .666 .971 r
.22115 .41747 m .21952 .41612 L .21889 .41607 L closepath p F P
0 g
s
.792 .48 .461 r
.32748 .3818 m .32714 .38293 L .32688 .38163 L closepath p F P
0 g
s
.672 .851 .968 r
.56232 .42558 m .5521 .42953 L .54946 .42768 L p F P
0 g
s
.858 .441 .237 r
.2778 .34707 m .2825 .34979 L .28076 .34614 L p F P
0 g
s
.858 .441 .237 r
.28076 .34614 m .27615 .3434 L .2778 .34707 L p F P
0 g
s
0 0 0 r
.56861 .31761 m .56797 .3186 L .57074 .31577 L closepath p F P
0 g
s
.53 .563 .834 r
.7548 .21062 m .75556 .2088 L .75644 .21068 L closepath p F P
0 g
s
.639 .739 .921 r
.30509 .43471 m .31489 .43189 L .3179 .43497 L p F P
0 g
s
.654 .734 .908 r
.31489 .43189 m .30509 .43471 L .30205 .43183 L p F P
0 g
s
.674 .693 .86 r
.46211 .43472 m .47219 .43085 L .47496 .43486 L p F P
0 g
s
.674 .651 .819 r
.46211 .43472 m .47219 .43085 L .46956 .42628 L p F P
0 g
s
.674 .651 .819 r
.45933 .43029 m .46211 .43472 L p .46956 .42628 L F P
0 g
s
.257 .592 .949 r
.17568 .39842 m .18054 .39943 L .18448 .40239 L p F P
0 g
s
.265 .592 .948 r
.18054 .39943 m .17568 .39842 L .17242 .39555 L p F P
0 g
s
.795 .482 .459 r
.32117 .38369 m .32042 .37961 L .32688 .38163 L p F P
0 g
s
.795 .482 .459 r
.32642 .3853 m .32117 .38369 L p .32688 .38163 L F P
0 g
s
.795 .482 .459 r
.32688 .38163 m .32714 .38293 L .32642 .3853 L p F P
0 g
s
.766 .996 .817 r
.71074 .3531 m .71029 .35318 L .71168 .35194 L closepath p F P
0 g
s
.757 .993 .875 r
.69368 .36704 m .68995 .36992 L .68799 .36992 L p F P
0 g
s
.725 .536 .635 r
.38961 .41272 m .38779 .41617 L .39022 .41634 L closepath p F P
0 g
s
.761 .529 .582 r
.35985 .40713 m .36306 .40772 L .36403 .40299 L p F P
0 g
s
.761 .529 .582 r
.36403 .40299 m .35955 .40216 L .35985 .40713 L p F P
0 g
s
.771 .848 .909 r
.6912 .21039 m .68957 .20884 L .69282 .20679 L closepath p F P
0 g
s
.622 .909 .622 r
.59827 .288 m .59746 .2888 L .59803 .28818 L closepath p F P
0 g
s
.091 .472 .892 r
.14137 .37798 m .1424 .37838 L .14589 .38156 L p F P
0 g
s
.136 .5 .908 r
.14835 .38044 m .15184 .38363 L .14589 .38156 L p F P
0 g
s
.136 .5 .908 r
.14589 .38156 m .1424 .37838 L .14835 .38044 L p F P
0 g
s
.83 .472 .378 r
.30208 .3688 m .30778 .37111 L .30641 .36729 L p F P
0 g
s
.83 .472 .378 r
.30641 .36729 m .30084 .36493 L .30208 .3688 L p F P
0 g
s
.741 .964 .683 r
.72997 .33258 m .73574 .32613 L .73188 .33162 L p F P
0 g
s
.741 .964 .683 r
.72892 .33408 m .72997 .33258 L p .73188 .33162 L F P
0 g
s
.741 .964 .683 r
.73188 .33162 m .73044 .33322 L .72892 .33408 L p F P
0 g
s
.162 0 .139 r
.53828 .34588 m .53761 .34773 L .54221 .34339 L closepath p F P
0 g
s
.703 .602 .741 r
.41859 .42337 m .41596 .42341 L .40794 .42926 L p F P
0 g
s
.705 .606 .744 r
.41596 .42341 m .40559 .42347 L .40794 .42926 L closepath p F P
0 g
s
.74 .544 .628 r
.37593 .41503 m .37821 .4153 L .38058 .41006 L p F P
0 g
s
.74 .544 .628 r
.38058 .41006 m .37502 .4094 L .37593 .41503 L p F P
0 g
s
.61 .899 .604 r
.59606 .28974 m .59078 .29554 L .59746 .2888 L p F P
0 g
s
.61 .899 .604 r
.59746 .2888 m .59803 .28818 L .59606 .28974 L p F P
0 g
s
.859 .428 .193 r
.27615 .3434 m .27493 .34088 L .27168 .34044 L p F P
0 g
s
.054 0 .47 r
.77021 .25678 m .76997 .25727 L .76935 .2531 L p F P
0 g
s
.054 0 .47 r
.76935 .2531 m .76973 .25231 L .77021 .25678 L p F P
0 g
s
.71 .611 .744 r
.40559 .42347 m .4038 .42344 L .39508 .43006 L p F P
0 g
s
.716 .621 .751 r
.4038 .42344 m .39508 .43006 L .39228 .42361 L p F P
0 g
s
.683 .629 .789 r
.43363 .42913 m .43476 .4314 L .44548 .43018 L p F P
0 g
s
.599 .367 .536 r
.47459 .39445 m .4689 .3957 L .46899 .40009 L p F P
0 g
s
.595 .364 .535 r
.46356 .40134 m .46899 .40009 L .4689 .3957 L p F P
0 g
s
.538 .732 .964 r
.26376 .42872 m .27061 .42791 L .27573 .43038 L p F P
0 g
s
.55 .734 .961 r
.27061 .42791 m .26376 .42872 L .26063 .42609 L p F P
0 g
s
.456 .706 .975 r
.23529 .42166 m .23979 .42159 L .2446 .42419 L p F P
0 g
s
.461 .704 .973 r
.24478 .42146 m .23979 .42159 L .2446 .42419 L p F P
0 g
s
.461 .704 .973 r
.2446 .42419 m .24793 .42413 L .24478 .42146 L p F P
0 g
s
.724 .96 .683 r
.73044 .33322 m .72585 .33815 L .72892 .33408 L closepath p F P
0 g
s
.465 .707 .973 r
.23979 .42159 m .23529 .42166 L .23212 .41904 L p F P
0 g
s
.841 .375 .053 r
.25505 .32477 m .25905 .32778 L .25702 .32429 L p F P
0 g
s
.841 .375 .053 r
.25344 .32193 m .25505 .32477 L p .25702 .32429 L F P
0 g
s
.841 .375 .053 r
.25702 .32429 m .25506 .32279 L .25344 .32193 L p F P
0 g
s
0 0 .008 r
.76372 .28169 m .76104 .28651 L .76281 .28148 L p F P
0 g
s
0 0 .008 r
.76281 .28148 m .76433 .27875 L .76372 .28169 L p F P
0 g
s
.822 .939 .904 r
.65861 .23154 m .66098 .22689 L p .66811 .22439 L F P
0 g
s
.832 .941 .897 r
.65861 .23154 m .65655 .23057 L .66098 .22689 L closepath p F P
0 g
s
.825 .911 .897 r
.66911 .22358 m .66811 .22439 L .66859 .22325 L closepath p F P
0 g
s
.822 .939 .904 r
.66672 .22208 m .66859 .22325 L .66811 .22439 L p F P
0 g
s
.822 .939 .904 r
.66098 .22689 m .66672 .22208 L p .66811 .22439 L F P
0 g
s
.552 .048 0 r
.22742 .2955 m .23078 .29881 L .22787 .29572 L p F P
0 g
s
.552 .048 0 r
.22787 .29572 m .22453 .2924 L .22742 .2955 L p F P
0 g
s
.532 .733 .967 r
.27757 .43124 m .27647 .43029 L .27573 .43038 L closepath p F P
0 g
s
.751 .994 .852 r
.70014 .36185 m .69368 .36704 L .69824 .36201 L closepath p F P
0 g
s
.757 .993 .875 r
.69788 .362 m .69824 .36201 L .69368 .36704 L p F P
0 g
s
.757 .993 .875 r
.68874 .36909 m .69788 .362 L p .69368 .36704 L F P
0 g
s
.757 .993 .875 r
.68799 .36992 m .68874 .36909 L p .69368 .36704 L F P
0 g
s
.704 .548 .674 r
.4169 .4169 m .40967 .41697 L .40516 .42211 L p F P
0 g
s
.708 .554 .677 r
.40967 .41697 m .40385 .41694 L .40516 .42211 L closepath p F P
0 g
s
.694 .597 .743 r
.43107 .42268 m .42999 .42274 L .42079 .42895 L p F P
0 g
s
.694 .597 .743 r
.42999 .42274 m .41859 .42337 L .42079 .42895 L closepath p F P
0 g
s
.612 .665 .877 r
.74328 .20172 m .74078 .20213 L .73836 .19809 L p F P
0 g
s
.715 .56 .677 r
.4038 .42344 m .40516 .42211 L .40385 .41694 L p F P
0 g
s
.715 .56 .677 r
.39292 .42302 m .4038 .42344 L p .40385 .41694 L F P
0 g
s
.715 .56 .677 r
.40385 .41694 m .39815 .41677 L .39292 .42302 L p F P
0 g
s
.783 .521 .54 r
.34327 .39869 m .34836 .39998 L .34854 .39554 L p F P
0 g
s
.783 .521 .54 r
.34854 .39554 m .34348 .39426 L .34327 .39869 L p F P
0 g
s
.81 .911 .909 r
.67915 .21607 m .66911 .22358 L .66859 .22325 L p F P
0 g
s
.693 .541 .675 r
.4227 .41664 m .4169 .4169 L .41802 .4215 L closepath p F P
0 g
s
.704 .548 .674 r
.41596 .42341 m .41802 .4215 L .4169 .4169 L p F P
0 g
s
.704 .548 .674 r
.40559 .42347 m .41596 .42341 L p .4169 .4169 L F P
0 g
s
.704 .548 .674 r
.40516 .42211 m .40559 .42347 L p .4169 .4169 L F P
0 g
s
.395 .088 .322 r
.51734 .36416 m .51271 .36696 L .51713 .36506 L closepath p F P
0 g
s
.417 .127 .362 r
.51644 .3686 m .51713 .36506 L .51271 .36696 L p F P
0 g
s
.417 .127 .362 r
.50678 .37276 m .51644 .3686 L p .51271 .36696 L F P
0 g
s
.716 .661 .794 r
.38233 .43113 m .38216 .43111 L .38221 .43121 L closepath p F P
0 g
s
.656 .468 .619 r
.44262 .40949 m .44077 .40974 L .44101 .41165 L closepath p F P
0 g
s
.722 .604 .724 r
.38233 .43113 m .39228 .42361 L .39204 .42297 L p F P
0 g
s
.722 .604 .724 r
.38216 .43111 m .38233 .43113 L p .39204 .42297 L F P
0 g
s
.367 .387 .749 r
.77087 .22329 m .76933 .2271 L .76514 .22425 L p F P
0 g
s
.367 .387 .749 r
.77019 .22116 m .77087 .22329 L p .76514 .22425 L F P
0 g
s
.367 .387 .749 r
.76514 .22425 m .76706 .21922 L .77019 .22116 L p F P
0 g
s
.722 .604 .724 r
.37938 .42543 m .38216 .43111 L p .39204 .42297 L F P
0 g
s
.72 .641 .768 r
.37938 .42543 m .37264 .4303 L .38216 .43111 L closepath p F P
0 g
s
.713 .663 .798 r
.38216 .43111 m .37264 .4303 L .36933 .43232 L p F P
0 g
s
.669 .716 .884 r
.47496 .43486 m .48506 .43124 L .48782 .43481 L p F P
0 g
s
.67 .68 .851 r
.48506 .43124 m .47496 .43486 L .47219 .43085 L p F P
0 g
s
0 0 0 r
.59582 .28993 m .59606 .28974 L .59078 .29554 L p F P
0 g
s
0 0 0 r
.59049 .29568 m .59582 .28993 L p .59078 .29554 L F P
0 g
s
0 0 0 r
.59078 .29554 m .58818 .29819 L .5871 .29932 L p F P
0 g
s
0 0 0 r
.5871 .29932 m .59049 .29568 L p .59078 .29554 L F P
0 g
s
.722 .57 .683 r
.39204 .42297 m .39292 .42302 L .39815 .41677 L p F P
0 g
s
.722 .57 .683 r
.39815 .41677 m .39022 .41634 L .39204 .42297 L p F P
0 g
s
.667 .729 .896 r
.3179 .43497 m .32775 .43145 L .33074 .43481 L p F P
0 g
s
.682 .72 .878 r
.32775 .43145 m .3179 .43497 L .31489 .43189 L p F P
0 g
s
.672 .817 .953 r
.54817 .42815 m .53926 .43141 L .53659 .42921 L p F P
0 g
s
.665 .815 .955 r
.52641 .4328 m .53659 .42921 L .53926 .43141 L p F P
0 g
s
.478 .515 .818 r
.75644 .21068 m .76305 .21197 L .76132 .21695 L p F P
0 g
s
.434 .467 .795 r
.76838 .21583 m .76706 .21922 L .76132 .21695 L p F P
0 g
s
.434 .467 .795 r
.76751 .21349 m .76838 .21583 L p .76132 .21695 L F P
0 g
s
.434 .467 .795 r
.76132 .21695 m .76305 .21197 L .76751 .21349 L p F P
0 g
s
.691 .896 .971 r
.59821 .41554 m .58796 .42015 L .5854 .41878 L p F P
0 g
s
0 0 .247 r
.76929 .2663 m .76673 .27146 L .76733 .26685 L p F P
0 g
s
0 0 .247 r
.76733 .26685 m .76993 .26167 L .76929 .2663 L p F P
0 g
s
.278 .602 .952 r
.18483 .40023 m .18054 .39943 L .18448 .40239 L p F P
0 g
s
.278 .602 .952 r
.18448 .40239 m .18807 .40308 L .18483 .40023 L p F P
0 g
s
.331 .636 .963 r
.20056 .40714 m .19674 .40665 L .20088 .40952 L p F P
0 g
s
.331 .636 .963 r
.20088 .40952 m .20378 .4099 L .20056 .40714 L p F P
0 g
s
0 0 0 r
.58818 .29819 m .58411 .30228 L .5871 .29932 L closepath p F P
0 g
s
.719 .678 .809 r
.37264 .4303 m .36762 .42953 L .36933 .43232 L closepath p F P
0 g
s
.692 .539 .674 r
.42946 .41631 m .4227 .41664 L .41802 .4215 L p F P
0 g
s
.746 .978 .731 r
.72833 .3343 m .72892 .33408 L .72585 .33815 L p F P
0 g
s
.746 .978 .731 r
.72343 .3393 m .72833 .3343 L p .72585 .33815 L F P
0 g
s
.746 .978 .731 r
.72002 .34388 m .72343 .3393 L p .72585 .33815 L F P
0 g
s
.746 .978 .731 r
.72585 .33815 m .7204 .34371 L .72002 .34388 L p F P
0 g
s
.659 .472 .621 r
.45252 .40821 m .44262 .40949 L .44101 .41165 L p F P
0 g
s
.847 .442 .273 r
.28412 .35349 m .28916 .35607 L .28743 .35241 L p F P
0 g
s
.847 .442 .273 r
.28743 .35241 m .2825 .34979 L .28412 .35349 L p F P
0 g
s
.722 .945 .954 r
.63458 .40233 m .634 .40213 L .63666 .40065 L closepath p F P
0 g
s
.642 .912 .611 r
.59655 .28915 m .59606 .28974 L .59803 .28818 L p F P
0 g
s
.642 .912 .611 r
.59803 .28818 m .60279 .28256 L .59655 .28915 L p F P
0 g
s
.613 .804 .383 r
.75263 .30273 m .74945 .30804 L .75281 .30244 L p F P
0 g
s
.613 .804 .383 r
.75281 .30244 m .75601 .29719 L .75598 .29725 L p F P
0 g
s
.613 .804 .383 r
.75598 .29725 m .75263 .30273 L p .75281 .30244 L F P
0 g
s
.763 .996 .848 r
.7032 .35931 m .70014 .36185 L .69824 .36201 L p F P
0 g
s
.741 .545 .629 r
.36915 .41423 m .37593 .41503 L .37502 .4094 L p F P
0 g
s
.741 .545 .629 r
.37502 .4094 m .37154 .40899 L .36915 .41423 L p F P
0 g
s
.739 .816 .912 r
.71054 .20044 m .70225 .20491 L .69986 .20231 L p F P
0 g
s
.021 .416 .86 r
.12601 .36762 m .13033 .36962 L .13366 .37289 L p F P
0 g
s
.467 .528 .837 r
.75556 .2088 m .75644 .21068 L .76305 .21197 L p F P
0 g
s
.666 .742 .907 r
.48782 .43481 m .49794 .43133 L .50068 .43448 L p F P
0 g
s
.667 .709 .879 r
.49794 .43133 m .48782 .43481 L .48506 .43124 L p F P
0 g
s
.688 .713 .867 r
.33074 .43481 m .34064 .43053 L .34359 .43426 L p F P
0 g
s
.703 .7 .844 r
.34064 .43053 m .33074 .43481 L .32775 .43145 L p F P
0 g
s
.757 .527 .584 r
.35499 .4063 m .35985 .40713 L .35955 .40216 L p F P
0 g
s
.757 .527 .584 r
.35955 .40216 m .35601 .40155 L .35499 .4063 L p F P
0 g
s
0 0 0 r
.58572 .30085 m .5871 .29932 L .58411 .30228 L p F P
0 g
s
0 0 0 r
.58445 .30221 m .58572 .30085 L p .58411 .30228 L F P
0 g
s
0 0 0 r
.57793 .30858 m .58445 .30221 L p .58411 .30228 L F P
0 g
s
0 0 0 r
.58411 .30228 m .57808 .30839 L .57793 .30858 L p F P
0 g
s
.712 .679 .816 r
.36762 .42953 m .36394 .42912 L .35646 .43339 L p F P
0 g
s
.719 .699 .83 r
.36394 .42912 m .35646 .43339 L .35355 .4292 L p F P
0 g
s
.703 .694 .838 r
.34359 .43426 m .35355 .4292 L .35646 .43339 L p F P
0 g
s
.683 .629 .789 r
.44648 .42969 m .4437 .42312 L .43363 .42913 L p F P
0 g
s
.683 .629 .789 r
.44548 .43018 m .44648 .42969 L p .43363 .42913 L F P
0 g
s
.682 .593 .749 r
.43107 .42268 m .43363 .42913 L .4437 .42312 L p F P
0 g
s
.001 0 .453 r
.77217 .25221 m .77021 .25678 L .76973 .25231 L p F P
0 g
s
.001 0 .453 r
.76973 .25231 m .77156 .24804 L .77217 .25221 L p F P
0 g
s
.755 .994 .821 r
.71029 .35318 m .7032 .35931 L .70811 .35355 L closepath p F P
0 g
s
.763 .996 .848 r
.70808 .35356 m .70811 .35355 L .7032 .35931 L p F P
0 g
s
.763 .996 .848 r
.69901 .3611 m .70808 .35356 L p .7032 .35931 L F P
0 g
s
.763 .996 .848 r
.69824 .36201 m .69901 .3611 L p .7032 .35931 L F P
0 g
s
.684 .88 .971 r
.57582 .42352 m .57515 .42313 L .58035 .42095 L closepath p F P
0 g
s
.666 .797 .944 r
.53659 .42921 m .52641 .4328 L .52371 .43033 L p F P
0 g
s
.664 .793 .944 r
.51355 .43382 m .52371 .43033 L .52641 .4328 L p F P
0 g
s
.712 .578 .703 r
.40516 .42211 m .4038 .42344 L .40559 .42347 L closepath p F P
0 g
s
.842 .38 .085 r
.26102 .33131 m .26525 .33422 L .26321 .33073 L p F P
0 g
s
.842 .38 .085 r
.26321 .33073 m .25905 .32778 L .26102 .33131 L p F P
0 g
s
.725 .573 .682 r
.38275 .42235 m .39204 .42297 L .39022 .41634 L p F P
0 g
s
.725 .573 .682 r
.39022 .41634 m .38779 .41617 L .38275 .42235 L p F P
0 g
s
.717 .684 .817 r
.34359 .43426 m .35355 .4292 L .35215 .42698 L p F P
0 g
s
.717 .684 .817 r
.34064 .43053 m .34359 .43426 L p .35215 .42698 L F P
0 g
s
.664 .858 .465 r
.74867 .3093 m .74821 .30989 L .74945 .30804 L closepath p F P
0 g
s
.738 .969 .932 r
.66337 .3867 m .65693 .39076 L .65467 .39027 L p F P
0 g
s
.811 .5 .464 r
.32714 .38293 m .32761 .38571 L .32642 .3853 L closepath p F P
0 g
s
.68 .533 .679 r
.4381 .41549 m .42946 .41631 L .43086 .42201 L closepath p F P
0 g
s
.692 .539 .674 r
.42999 .42274 m .43086 .42201 L .42946 .41631 L p F P
0 g
s
.692 .539 .674 r
.41859 .42337 m .42999 .42274 L p .42946 .41631 L F P
0 g
s
.692 .539 .674 r
.41802 .4215 m .41859 .42337 L p .42946 .41631 L F P
0 g
s
.716 .621 .751 r
.39228 .42361 m .39292 .42302 L .4038 .42344 L p F P
0 g
s
.73 .974 .732 r
.7204 .34371 m .71921 .34489 L .72002 .34388 L closepath p F P
0 g
s
.804 .516 .502 r
.32791 .38997 m .33436 .39198 L .33402 .38775 L p F P
0 g
s
.804 .516 .502 r
.33402 .38775 m .32761 .38571 L .32791 .38997 L p F P
0 g
s
.703 .569 .701 r
.41802 .4215 m .41596 .42341 L .41859 .42337 L closepath p F P
0 g
s
.758 .992 .789 r
.71621 .34625 m .71168 .35194 L .71921 .34489 L p F P
0 g
s
.758 .992 .789 r
.71823 .34434 m .71621 .34625 L p .71921 .34489 L F P
0 g
s
.758 .992 .789 r
.71921 .34489 m .72002 .34388 L .71823 .34434 L p F P
0 g
s
.833 .497 .42 r
.3088 .37508 m .31442 .37742 L .31346 .37343 L p F P
0 g
s
.833 .497 .42 r
.30843 .37345 m .3088 .37508 L p .31346 .37343 L F P
0 g
s
.833 .497 .42 r
.31346 .37343 m .30939 .37172 L .30843 .37345 L p F P
0 g
s
.698 .905 .969 r
.59959 .41623 m .59821 .41554 L .60635 .41173 L closepath p F P
0 g
s
.585 .069 0 r
.23208 .30021 m .23078 .29881 L .23428 .30205 L p F P
0 g
s
.585 .069 0 r
.23428 .30205 m .23525 .30309 L .23208 .30021 L p F P
0 g
s
.664 .768 .927 r
.50068 .43448 m .51083 .43104 L .51355 .43382 L p F P
0 g
s
.665 .74 .906 r
.51083 .43104 m .50068 .43448 L .49794 .43133 L p F P
0 g
s
.659 .472 .621 r
.44101 .41165 m .44156 .41518 L p .45252 .40821 L F P
0 g
s
.674 .494 .634 r
.44101 .41165 m .4381 .41549 L .44156 .41518 L closepath p F P
0 g
s
.222 .564 .937 r
.16917 .39261 m .16566 .39173 L .1694 .39478 L p F P
0 g
s
.222 .564 .937 r
.1694 .39478 m .17242 .39555 L .16917 .39261 L p F P
0 g
s
.768 .996 .818 r
.71168 .35194 m .71029 .35318 L .70811 .35355 L p F P
0 g
s
.665 .77 .928 r
.52371 .43033 m .51355 .43382 L .51083 .43104 L p F P
0 g
s
.732 .565 .665 r
.37792 .42183 m .38275 .42235 L .38779 .41617 L p F P
0 g
s
.732 .565 .665 r
.37661 .41764 m .37792 .42183 L p .38779 .41617 L F P
0 g
s
.732 .565 .665 r
.38779 .41617 m .37821 .4153 L .37661 .41764 L p F P
0 g
s
.768 .996 .818 r
.70816 .35348 m .71621 .34625 L .71168 .35194 L p F P
0 g
s
.768 .996 .818 r
.70811 .35355 m .70816 .35348 L p .71168 .35194 L F P
0 g
s
0 0 0 r
.75606 .2971 m .75601 .29719 L .75705 .29482 L p F P
0 g
s
0 0 0 r
.75705 .29482 m .75878 .29172 L .75606 .2971 L p F P
0 g
s
.75 .549 .623 r
.36099 .41285 m .36915 .41423 L .37154 .40899 L p F P
0 g
s
.75 .549 .623 r
.37154 .40899 m .36306 .40772 L .36099 .41285 L p F P
0 g
s
.534 .729 .964 r
.27337 .42756 m .27061 .42791 L .27573 .43038 L p F P
0 g
s
.534 .729 .964 r
.27573 .43038 m .27647 .43029 L .27337 .42756 L p F P
0 g
s
0 0 0 r
.57808 .30839 m .57744 .30901 L .57793 .30858 L closepath p F P
0 g
s
.379 .664 .97 r
.21632 .4134 m .21456 .41328 L .21889 .41607 L p F P
0 g
s
.379 .664 .97 r
.21889 .41607 m .21952 .41612 L .21632 .4134 L p F P
0 g
s
0 0 0 r
.57637 .3108 m .57074 .31577 L .57744 .30901 L p F P
0 g
s
0 0 0 r
.57744 .30901 m .57793 .30858 L .57637 .3108 L p F P
0 g
s
.728 .623 .74 r
.37264 .4303 m .37938 .42543 L .37792 .42183 L p F P
0 g
s
.728 .623 .74 r
.36762 .42953 m .37264 .4303 L p .37792 .42183 L F P
0 g
s
.056 0 .048 r
.5481 .33753 m .54774 .33839 L .54982 .33631 L closepath p F P
0 g
s
.355 .053 .308 r
.52489 .35828 m .51734 .36416 L .51713 .36506 L p F P
0 g
s
.535 .289 .489 r
.49555 .38826 m .4958 .38412 L .48551 .38744 L p F P
0 g
s
.535 .289 .489 r
.48551 .38744 m .48524 .39158 L .49555 .38826 L p F P
0 g
s
.81 .911 .909 r
.66859 .22325 m .67056 .21909 L p .67915 .21607 L F P
0 g
s
.819 .914 .903 r
.66859 .22325 m .66672 .22208 L .67056 .21909 L closepath p F P
0 g
s
.685 .64 .798 r
.44648 .42969 m .44548 .43018 L .44667 .43007 L closepath p F P
0 g
s
.489 .228 .445 r
.50578 .38038 m .50621 .37647 L .49624 .38022 L p F P
0 g
s
.489 .228 .445 r
.49624 .38022 m .4958 .38412 L .50578 .38038 L p F P
0 g
s
.81 .884 .899 r
.67932 .21594 m .67915 .21607 L .67922 .21586 L closepath p F P
0 g
s
.81 .911 .909 r
.67693 .21409 m .67922 .21586 L .67915 .21607 L p F P
0 g
s
.81 .911 .909 r
.67056 .21909 m .67693 .21409 L p .67915 .21607 L F P
0 g
s
.72 .599 .721 r
.39292 .42302 m .39204 .42297 L .39228 .42361 L closepath p F P
0 g
s
.8 .884 .907 r
.68718 .20664 m .68957 .20884 L .67932 .21594 L p F P
0 g
s
.8 .884 .907 r
.68147 .21081 m .68718 .20664 L p .67932 .21594 L F P
0 g
s
.8 .884 .907 r
.67932 .21594 m .67922 .21586 L .68147 .21081 L p F P
0 g
s
.578 .35 .534 r
.48521 .39601 m .48524 .39158 L .47459 .39445 L p F P
0 g
s
.578 .35 .534 r
.47459 .39445 m .47455 .39888 L .48521 .39601 L p F P
0 g
s
.599 .367 .536 r
.46899 .40009 m .47455 .39888 L .47459 .39445 L p F P
0 g
s
.722 .604 .724 r
.39204 .42297 m .38275 .42235 L .37938 .42543 L p F P
0 g
s
.768 .535 .581 r
.34744 .40469 m .35499 .4063 L .35601 .40155 L p F P
0 g
s
.768 .535 .581 r
.35601 .40155 m .34836 .39998 L .34744 .40469 L p F P
0 g
s
.612 .665 .877 r
.73836 .19809 m .74469 .19681 L .74328 .20172 L p F P
0 g
s
.587 .628 .859 r
.74903 .19605 m .74469 .19681 L .74328 .20172 L p F P
0 g
s
.587 .628 .859 r
.74328 .20172 m .75148 .20065 L .74903 .19605 L p F P
0 g
s
.679 .637 .801 r
.44648 .42969 m .44667 .43007 L .45837 .42847 L p F P
0 g
s
.675 .656 .824 r
.45933 .43029 m .45837 .42847 L .44667 .43007 L p F P
0 g
s
.467 .528 .837 r
.76492 .20691 m .75647 .20564 L .75556 .2088 L p F P
0 g
s
.467 .528 .837 r
.76493 .20694 m .76492 .20691 L p .75556 .2088 L F P
0 g
s
.467 .528 .837 r
.76305 .21197 m .76493 .20694 L p .75556 .2088 L F P
0 g
s
.52 .568 .844 r
.75395 .2055 m .75647 .20564 L .75556 .2088 L closepath p F P
0 g
s
.597 .738 .943 r
.28617 .42846 m .27647 .43029 L .27337 .42756 L p F P
0 g
s
.856 .479 .335 r
.29058 .35986 m .29557 .36245 L .29424 .35863 L p F P
0 g
s
.856 .479 .335 r
.28999 .35808 m .29058 .35986 L p .29424 .35863 L F P
0 g
s
.856 .479 .335 r
.29424 .35863 m .29147 .35717 L .28999 .35808 L p F P
0 g
s
.056 .439 .875 r
.13479 .37156 m .13033 .36962 L .13366 .37289 L p F P
0 g
s
.056 .439 .875 r
.13366 .37289 m .13808 .37481 L .13479 .37156 L p F P
0 g
s
.802 .886 .906 r
.67922 .21586 m .67693 .21409 L .68147 .21081 L closepath p F P
0 g
s
0 0 0 r
.5756 .31194 m .57637 .3108 L .57074 .31577 L p F P
0 g
s
0 0 0 r
.57261 .31518 m .5756 .31194 L p .57074 .31577 L F P
0 g
s
0 0 0 r
.56716 .32001 m .57261 .31518 L p .57074 .31577 L F P
0 g
s
0 0 0 r
.57074 .31577 m .56797 .3186 L .56716 .32001 L p F P
0 g
s
.775 .514 .541 r
.34122 .39822 m .34327 .39869 L .34348 .39426 L p F P
0 g
s
.775 .514 .541 r
.34348 .39426 m .34139 .39379 L .34122 .39822 L p F P
0 g
s
.708 .92 .965 r
.62126 .40669 m .611 .41182 L .60848 .41071 L p F P
0 g
s
.43 .684 .97 r
.22894 .41637 m .21952 .41612 L .21632 .4134 L p F P
0 g
s
.679 .637 .801 r
.45837 .42847 m .45655 .42453 L .44648 .42969 L p F P
0 g
s
.676 .573 .731 r
.44648 .42969 m .45655 .42453 L .45489 .41997 L p F P
0 g
s
.676 .573 .731 r
.4437 .42312 m .44648 .42969 L p .45489 .41997 L F P
0 g
s
0 0 0 r
.57852 .30869 m .57637 .3108 L .57793 .30858 L p F P
0 g
s
0 0 0 r
.57793 .30858 m .58445 .30221 L .57852 .30869 L p F P
0 g
s
.61 .403 .577 r
.46899 .40009 m .46356 .40134 L .46382 .40614 L p F P
0 g
s
.825 .999 .834 r
.62738 .25858 m .62614 .25869 L .62928 .25566 L closepath p F P
0 g
s
.693 .565 .706 r
.43086 .42201 m .42999 .42274 L .43107 .42268 L closepath p F P
0 g
s
.436 .163 .399 r
.51586 .3723 m .51644 .3686 L .50678 .37276 L p F P
0 g
s
.436 .163 .399 r
.50678 .37276 m .50621 .37647 L .51586 .3723 L p F P
0 g
s
.783 .28 0 r
.25506 .32279 m .25344 .32193 L .25298 .3213 L closepath p F P
0 g
s
.831 .369 .108 r
.26724 .33776 m .26525 .33422 L .26967 .33706 L p F P
0 g
s
.831 .369 .108 r
.27149 .3404 m .26724 .33776 L p .26967 .33706 L F P
0 g
s
.831 .369 .108 r
.26967 .33706 m .27168 .34044 L .27149 .3404 L p F P
0 g
s
.737 .234 0 r
.23525 .30309 m .23685 .30529 L .24043 .30849 L p F P
0 g
s
.748 .247 0 r
.23921 .30862 m .24282 .31181 L .24043 .30849 L p F P
0 g
s
.748 .247 0 r
.24043 .30849 m .23685 .30529 L .23921 .30862 L p F P
0 g
s
.681 .536 .681 r
.43086 .42201 m .43107 .42268 L p .44156 .41518 L F P
0 g
s
.681 .536 .681 r
.44156 .41518 m .4381 .41549 L .43086 .42201 L p F P
0 g
s
.681 .536 .681 r
.43107 .42268 m .44317 .42156 L .44156 .41518 L p F P
0 g
s
.682 .593 .749 r
.4437 .42312 m .44317 .42156 L .43107 .42268 L p F P
0 g
s
0 0 0 r
.56797 .3186 m .56392 .32256 L .56716 .32001 L closepath p F P
0 g
s
.726 .941 .955 r
.63666 .40065 m .634 .40213 L .63154 .40122 L p F P
0 g
s
.109 .086 .548 r
.77372 .24297 m .77156 .24804 L .77028 .24411 L p F P
0 g
s
.109 .086 .548 r
.77028 .24411 m .77241 .23905 L .77372 .24297 L p F P
0 g
s
.327 .01 .265 r
.52748 .3564 m .52489 .35828 L .52728 .35711 L closepath p F P
0 g
s
.355 .053 .308 r
.52648 .36049 m .52728 .35711 L .52489 .35828 L p F P
0 g
s
.355 .053 .308 r
.51713 .36506 m .52648 .36049 L p .52489 .35828 L F P
0 g
s
0 0 0 r
.56578 .32251 m .56716 .32001 L .56392 .32256 L p F P
0 g
s
0 0 0 r
.55772 .32889 m .56578 .32251 L p .56392 .32256 L F P
0 g
s
0 0 0 r
.56392 .32256 m .55786 .3286 L .55772 .32889 L p F P
0 g
s
.641 .463 .627 r
.46394 .4071 m .46382 .40614 L .45252 .40821 L p F P
0 g
s
.641 .463 .627 r
.45842 .41264 m .46394 .4071 L p .45252 .40821 L F P
0 g
s
.641 .463 .627 r
.45252 .40821 m .45327 .41359 L .45842 .41264 L p F P
0 g
s
.659 .472 .621 r
.44156 .41518 m .45327 .41359 L .45252 .40821 L p F P
0 g
s
.164 .521 .918 r
.15357 .38418 m .15184 .38363 L .1554 .38677 L p F P
0 g
s
.164 .521 .918 r
.1554 .38677 m .15685 .38723 L .15357 .38418 L p F P
0 g
s
.688 .868 .967 r
.58035 .42095 m .57515 .42313 L .57255 .42147 L p F P
0 g
s
.678 .866 .97 r
.56232 .42558 m .57255 .42147 L .57515 .42313 L p F P
0 g
s
.818 .506 .462 r
.31508 .38152 m .32117 .38369 L .32042 .37961 L p F P
0 g
s
.818 .506 .462 r
.32042 .37961 m .31442 .37742 L .31508 .38152 L p F P
0 g
s
.74 .575 .67 r
.37821 .4153 m .37593 .41503 L .37661 .41764 L closepath p F P
0 g
s
.777 .994 .785 r
.72002 .34388 m .71823 .34434 L .72343 .3393 L closepath p F P
0 g
s
.728 .623 .74 r
.36646 .42745 m .36762 .42953 L p .37792 .42183 L F P
0 g
s
.72 .66 .79 r
.36646 .42745 m .36394 .42912 L .36762 .42953 L closepath p F P
0 g
s
.737 .977 .922 r
.66718 .38421 m .66337 .3867 L .66622 .38406 L closepath p F P
0 g
s
.738 .969 .932 r
.66481 .38371 m .66622 .38406 L .66337 .3867 L p F P
0 g
s
.738 .969 .932 r
.65503 .38993 m .66481 .38371 L p .66337 .3867 L F P
0 g
s
.738 .969 .932 r
.65467 .39027 m .65503 .38993 L p .66337 .3867 L F P
0 g
s
.73 .618 .733 r
.38275 .42235 m .37792 .42183 L .37938 .42543 L closepath p F P
0 g
s
.784 .523 .541 r
.33417 .39642 m .34122 .39822 L .34139 .39379 L p F P
0 g
s
.784 .523 .541 r
.34139 .39379 m .33436 .39198 L .33417 .39642 L p F P
0 g
s
.666 .528 .685 r
.45381 .41604 m .45327 .41359 L .44156 .41518 L p F P
0 g
s
.666 .528 .685 r
.44716 .42098 m .45381 .41604 L p .44156 .41518 L F P
0 g
s
.666 .528 .685 r
.44156 .41518 m .44317 .42156 L .44716 .42098 L p F P
0 g
s
.739 .945 .628 r
.73928 .32235 m .73834 .32303 L .74089 .31989 L closepath p F P
0 g
s
.506 .722 .97 r
.24793 .42413 m .25749 .42341 L .26063 .42609 L p F P
0 g
s
.514 .721 .967 r
.25749 .42341 m .24793 .42413 L .24478 .42146 L p F P
0 g
s
.667 .861 .468 r
.74878 .30852 m .75263 .30273 L .74945 .30804 L p F P
0 g
s
.667 .861 .468 r
.74722 .31113 m .74878 .30852 L p .74945 .30804 L F P
0 g
s
.667 .861 .468 r
.74945 .30804 m .74821 .30989 L .74722 .31113 L p F P
0 g
s
.283 0 .248 r
.53407 .35065 m .52748 .3564 L .52728 .35711 L p F P
0 g
s
0 0 0 r
.55786 .3286 m .55702 .32938 L .55772 .32889 L closepath p F P
0 g
s
.033 0 .013 r
.5565 .33163 m .54982 .33631 L .55702 .32938 L p F P
0 g
s
.033 0 .013 r
.55702 .32938 m .55772 .32889 L .5565 .33163 L p F P
0 g
s
.375 .09 .347 r
.52576 .36399 m .52648 .36049 L .51713 .36506 L p F P
0 g
s
.375 .09 .347 r
.51713 .36506 m .51644 .3686 L .52576 .36399 L p F P
0 g
s
.739 .579 .677 r
.37344 .42138 m .37661 .41764 L .37593 .41503 L p F P
0 g
s
.739 .579 .677 r
.36487 .42014 m .37344 .42138 L p .37593 .41503 L F P
0 g
s
.739 .579 .677 r
.37593 .41503 m .36915 .41423 L .36487 .42014 L p F P
0 g
s
0 0 0 r
.76165 .28649 m .75878 .29172 L .76104 .28651 L p F P
0 g
s
0 0 0 r
.76358 .28211 m .76165 .28649 L p .76104 .28651 L F P
0 g
s
0 0 0 r
.76104 .28651 m .76372 .28169 L .76358 .28211 L p F P
0 g
s
.102 .474 .894 r
.1424 .37838 m .14137 .37798 L .13808 .37481 L p F P
0 g
s
.725 .226 0 r
.23685 .30529 m .23525 .30309 L .23208 .30021 L p F P
0 g
s
.723 .953 .949 r
.64426 .3963 m .63666 .40065 L .64256 .39578 L closepath p F P
0 g
s
.726 .941 .955 r
.64183 .39551 m .64256 .39578 L .63666 .40065 L p F P
0 g
s
.726 .941 .955 r
.63154 .40122 m .64183 .39551 L p .63666 .40065 L F P
0 g
s
.247 0 .198 r
.53761 .34773 m .53407 .35065 L .53723 .3489 L closepath p F P
0 g
s
.283 0 .248 r
.53631 .3521 m .53723 .3489 L .53407 .35065 L p F P
0 g
s
.283 0 .248 r
.52728 .35711 m .53631 .3521 L p .53407 .35065 L F P
0 g
s
.845 .488 .377 r
.29672 .36635 m .30208 .3688 L .30084 .36493 L p F P
0 g
s
.845 .488 .377 r
.30084 .36493 m .29557 .36245 L .29672 .36635 L p F P
0 g
s
.76 .256 0 r
.24521 .31515 m .24902 .31826 L .24658 .31494 L p F P
0 g
s
.76 .256 0 r
.24658 .31494 m .24282 .31181 L .24521 .31515 L p F P
0 g
s
.674 .651 .819 r
.46956 .42628 m .4683 .4265 L .45933 .43029 L p F P
0 g
s
.67 .636 .807 r
.4683 .4265 m .45837 .42847 L .45933 .43029 L closepath p F P
0 g
s
.76 .56 .627 r
.36081 .41281 m .36099 .41285 L .36306 .40772 L p F P
0 g
s
.76 .56 .627 r
.36306 .40772 m .35985 .40713 L .36081 .41281 L p F P
0 g
s
.105 0 .096 r
.55535 .33433 m .5565 .33163 L .54982 .33631 L p F P
0 g
s
.105 0 .096 r
.55513 .33456 m .55535 .33433 L p .54982 .33631 L F P
0 g
s
.105 0 .096 r
.54697 .34042 m .55513 .33456 L p .54982 .33631 L F P
0 g
s
.105 0 .096 r
.54982 .33631 m .54774 .33839 L .54697 .34042 L p F P
0 g
s
.735 .651 .766 r
.36394 .42912 m .36646 .42745 L .36362 .42145 L p F P
0 g
s
.735 .651 .766 r
.36362 .42145 m .35573 .42776 L .36394 .42912 L p F P
0 g
s
.719 .699 .83 r
.35355 .4292 m .35573 .42776 L .36394 .42912 L p F P
0 g
s
.859 .428 .193 r
.27168 .34044 m .27174 .34057 L .27615 .3434 L p F P
0 g
s
.868 .453 .234 r
.2733 .34427 m .2778 .34707 L .27615 .3434 L p F P
0 g
s
.868 .453 .234 r
.27615 .3434 m .27174 .34057 L .2733 .34427 L p F P
0 g
s
.151 0 .116 r
.54774 .33839 m .54221 .34339 L .54697 .34042 L closepath p F P
0 g
s
.201 0 .179 r
.54593 .34343 m .54697 .34042 L .54221 .34339 L p F P
0 g
s
.201 0 .179 r
.53723 .3489 m .54593 .34343 L p .54221 .34339 L F P
0 g
s
.201 0 .179 r
.54221 .34339 m .53761 .34773 L .53723 .3489 L p F P
0 g
s
.734 .589 .695 r
.37661 .41764 m .37344 .42138 L .37792 .42183 L closepath p F P
0 g
s
.644 .852 .463 r
.74821 .30989 m .74544 .31387 L .74722 .31113 L closepath p F P
0 g
s
.62 .74 .932 r
.28924 .43129 m .299 .42885 L .30205 .43183 L p F P
0 g
s
.633 .737 .923 r
.299 .42885 m .28924 .43129 L .28617 .42846 L p F P
0 g
s
.728 .623 .74 r
.37792 .42183 m .37344 .42138 L .36646 .42745 L p F P
0 g
s
.375 .66 .969 r
.20378 .4099 m .21031 .41045 L .21456 .41328 L p F P
0 g
s
.382 .66 .967 r
.21031 .41045 m .20378 .4099 L .20056 .40714 L p F P
0 g
s
.663 .703 .876 r
.72542 .19784 m .73595 .19421 L .73836 .19809 L p F P
0 g
s
.676 .717 .88 r
.73595 .19421 m .72542 .19784 L .72302 .19447 L p F P
0 g
s
.707 .752 .887 r
.7126 .19932 m .72302 .19447 L .72542 .19784 L p F P
0 g
s
.748 .978 .918 r
.67705 .37756 m .66718 .38421 L .66622 .38406 L p F P
0 g
s
.737 .791 .896 r
.7126 .19932 m .71054 .20044 L .71117 .19756 L closepath p F P
0 g
s
.739 .816 .912 r
.71021 .19638 m .71117 .19756 L .71054 .20044 L p F P
0 g
s
.739 .816 .912 r
.69986 .20231 m .71021 .19638 L p .71054 .20044 L F P
0 g
s
0 0 0 r
.56548 .32311 m .56578 .32251 L .55772 .32889 L p F P
0 g
s
0 0 0 r
.56089 .32812 m .56548 .32311 L p .55772 .32889 L F P
0 g
s
0 0 0 r
.55772 .32889 m .5565 .33163 L .56089 .32812 L p F P
0 g
s
.818 .477 .412 r
.30939 .37172 m .30843 .37345 L .30778 .37111 L closepath p F P
0 g
s
.772 .855 .913 r
.69282 .20679 m .68957 .20884 L .68718 .20664 L p F P
0 g
s
.676 .573 .731 r
.45489 .41997 m .44716 .42098 L .4437 .42312 L p F P
0 g
s
.672 .565 .725 r
.44716 .42098 m .44317 .42156 L .4437 .42312 L closepath p F P
0 g
s
.47 .705 .971 r
.24162 .41874 m .23503 .41897 L .23979 .42159 L p F P
0 g
s
.47 .705 .971 r
.23979 .42159 m .24478 .42146 L .24162 .41874 L p F P
0 g
s
.465 .707 .973 r
.23212 .41904 m .23503 .41897 L .23979 .42159 L p F P
0 g
s
.739 .643 .753 r
.37344 .42138 m .36646 .42745 L .36362 .42145 L p F P
0 g
s
0 0 0 r
.76394 .28127 m .76372 .28169 L .76433 .27875 L p F P
0 g
s
0 0 0 r
.76433 .27875 m .76558 .27627 L .76394 .28127 L p F P
0 g
s
0 0 .363 r
.77036 .26079 m .76993 .26167 L .76997 .25727 L p F P
0 g
s
0 0 .363 r
.76997 .25727 m .77021 .25678 L .77036 .26079 L p F P
0 g
s
.615 .409 .58 r
.47455 .39888 m .46899 .40009 L .46541 .40577 L p F P
0 g
s
.61 .403 .577 r
.46382 .40614 m .46541 .40577 L .46899 .40009 L p F P
0 g
s
.536 .583 .849 r
.75647 .20564 m .75395 .2055 L .75148 .20065 L p F P
0 g
s
.731 .969 .708 r
.60703 .27865 m .60593 .27925 L .60913 .27593 L closepath p F P
0 g
s
.837 .448 .311 r
.29147 .35717 m .28999 .35808 L .28916 .35607 L closepath p F P
0 g
s
0 0 .11 r
.76812 .27113 m .76558 .27627 L .76673 .27146 L p F P
0 g
s
0 0 .11 r
.76673 .27146 m .76929 .2663 L .76812 .27113 L p F P
0 g
s
.812 .523 .499 r
.32572 .38921 m .32791 .38997 L .32761 .38571 L p F P
0 g
s
.812 .523 .499 r
.32761 .38571 m .32642 .3853 L .32572 .38921 L p F P
0 g
s
.679 .856 .967 r
.57255 .42147 m .56232 .42558 L .55969 .42376 L p F P
0 g
s
.672 .851 .968 r
.54946 .42768 m .55969 .42376 L .56232 .42558 L p F P
0 g
s
.756 .558 .629 r
.3528 .41147 m .36081 .41281 L .35985 .40713 L p F P
0 g
s
.756 .558 .629 r
.35985 .40713 m .35499 .4063 L .3528 .41147 L p F P
0 g
s
.783 .549 .582 r
.34361 .40371 m .34744 .40469 L .34836 .39998 L p F P
0 g
s
.783 .549 .582 r
.34836 .39998 m .34327 .39869 L .34361 .40371 L p F P
0 g
s
.299 .005 .286 r
.53547 .35541 m .53631 .3521 L .52728 .35711 L p F P
0 g
s
.299 .005 .286 r
.52728 .35711 m .52648 .36049 L .53547 .35541 L p F P
0 g
s
.739 .643 .753 r
.36362 .42145 m .36487 .42014 L .37344 .42138 L p F P
0 g
s
.754 .581 .662 r
.36296 .41981 m .36487 .42014 L .36915 .41423 L p F P
0 g
s
.754 .581 .662 r
.36087 .41305 m .36296 .41981 L p .36915 .41423 L F P
0 g
s
.754 .581 .662 r
.36915 .41423 m .36099 .41285 L .36087 .41305 L p F P
0 g
s
.667 .61 .781 r
.45655 .42453 m .45837 .42847 L .4683 .4265 L p F P
0 g
s
.72 .786 .904 r
.72063 .19121 m .72302 .19447 L .7126 .19932 L p F P
0 g
s
.72 .786 .904 r
.71216 .19542 m .72063 .19121 L p .7126 .19932 L F P
0 g
s
.72 .786 .904 r
.7126 .19932 m .71117 .19756 L .71216 .19542 L p F P
0 g
s
.775 .272 0 r
.25023 .31998 m .24902 .31826 L .25298 .3213 L p F P
0 g
s
.775 .272 0 r
.25298 .3213 m .25344 .32193 L .25023 .31998 L p F P
0 g
s
.205 .55 .931 r
.15685 .38723 m .162 .38863 L .16566 .39173 L p F P
0 g
s
.214 .55 .931 r
.162 .38863 m .15685 .38723 L .15357 .38418 L p F P
0 g
s
.67 .68 .851 r
.47219 .43085 m .4823 .42701 L .48506 .43124 L p F P
0 g
s
.664 .651 .827 r
.46956 .42628 m .47219 .43085 L .4823 .42701 L p F P
0 g
s
.102 .474 .894 r
.13808 .37481 m .13898 .37516 L .1424 .37838 L p F P
0 g
s
.146 .501 .909 r
.14495 .37722 m .14835 .38044 L .1424 .37838 L p F P
0 g
s
.146 .501 .909 r
.1424 .37838 m .13898 .37516 L .14495 .37722 L p F P
0 g
s
.86 .456 .27 r
.27933 .35081 m .28412 .35349 L .2825 .34979 L p F P
0 g
s
.86 .456 .27 r
.2825 .34979 m .2778 .34707 L .27933 .35081 L p F P
0 g
s
.322 .629 .961 r
.18807 .40308 m .19268 .40373 L .19674 .40665 L p F P
0 g
s
.329 .629 .96 r
.19268 .40373 m .18807 .40308 L .18483 .40023 L p F P
0 g
s
.625 .663 .866 r
.74469 .19681 m .73836 .19809 L .73595 .19421 L p F P
0 g
s
.715 .928 .962 r
.62173 .40689 m .62126 .40669 L .62354 .4055 L closepath p F P
0 g
s
.217 .209 .635 r
.77396 .23537 m .77241 .23905 L .77031 .23543 L p F P
0 g
s
.217 .209 .635 r
.77307 .23138 m .77396 .23537 L p .77031 .23543 L F P
0 g
s
.217 .209 .635 r
.77031 .23543 m .77243 .23035 L .77307 .23138 L p F P
0 g
s
.823 .48 .408 r
.3031 .37276 m .30208 .3688 L .30778 .37111 L p F P
0 g
s
.823 .48 .408 r
.30775 .37461 m .3031 .37276 L p .30778 .37111 L F P
0 g
s
.823 .48 .408 r
.30778 .37111 m .30843 .37345 L .30775 .37461 L p F P
0 g
s
.654 .734 .908 r
.30205 .43183 m .31187 .42867 L .31489 .43189 L p F P
0 g
s
.668 .728 .894 r
.31187 .42867 m .30205 .43183 L .299 .42885 L p F P
0 g
s
.783 .85 .902 r
.69282 .20679 m .69986 .20231 L .69747 .19977 L p F P
0 g
s
.783 .85 .902 r
.69747 .19977 m .69457 .20172 L .69282 .20679 L p F P
0 g
s
.772 .855 .913 r
.68718 .20664 m .69457 .20172 L .69282 .20679 L p F P
0 g
s
0 0 .342 r
.77217 .25661 m .77036 .26079 L .77021 .25678 L p F P
0 g
s
0 0 .342 r
.77021 .25678 m .77217 .25221 L .77217 .25661 L p F P
0 g
s
.708 .915 .568 r
.74436 .31451 m .74089 .31989 L .74544 .31387 L p F P
0 g
s
.708 .915 .568 r
.74622 .31203 m .74436 .31451 L p .74544 .31387 L F P
0 g
s
.708 .915 .568 r
.74544 .31387 m .74722 .31113 L .74622 .31203 L p F P
0 g
s
.8 .511 .499 r
.32151 .38792 m .32572 .38921 L .32642 .3853 L p F P
0 g
s
.8 .511 .499 r
.32642 .3853 m .32117 .38369 L .32151 .38792 L p F P
0 g
s
.702 .898 .967 r
.60635 .41173 m .59821 .41554 L .59566 .41417 L p F P
0 g
s
.691 .896 .971 r
.5854 .41878 m .59566 .41417 L .59821 .41554 L p F P
0 g
s
.265 .592 .948 r
.17242 .39555 m .17668 .39642 L .18054 .39943 L p F P
0 g
s
.273 .592 .948 r
.17668 .39642 m .17242 .39555 L .16917 .39261 L p F P
0 g
s
.671 .827 .958 r
.54946 .42768 m .54817 .42815 L .54937 .4276 L closepath p F P
0 g
s
.672 .817 .953 r
.5468 .42551 m .54937 .4276 L .54817 .42815 L p F P
0 g
s
.672 .817 .953 r
.53659 .42921 m .5468 .42551 L p .54817 .42815 L F P
0 g
s
.671 .539 .695 r
.45381 .41604 m .44716 .42098 L .45489 .41997 L closepath p F P
0 g
s
.528 .035 0 r
.2242 .29213 m .22742 .2955 L .22453 .2924 L p F P
0 g
s
.528 .035 0 r
.22453 .2924 m .22131 .28903 L .2242 .29213 L p F P
0 g
s
.73 .684 .806 r
.35573 .42776 m .35215 .42698 L .35355 .4292 L closepath p F P
0 g
s
.687 .882 .971 r
.5854 .41878 m .58035 .42095 L .58471 .41837 L closepath p F P
0 g
s
.688 .868 .967 r
.58282 .41718 m .58471 .41837 L .58035 .42095 L p F P
0 g
s
.688 .868 .967 r
.57255 .42147 m .58282 .41718 L p .58035 .42095 L F P
0 g
s
.338 .636 .962 r
.19733 .40431 m .19268 .40373 L .19674 .40665 L p F P
0 g
s
.338 .636 .962 r
.19674 .40665 m .20056 .40714 L .19733 .40431 L p F P
0 g
s
.285 .602 .952 r
.18159 .39733 m .17668 .39642 L .18054 .39943 L p F P
0 g
s
.285 .602 .952 r
.18054 .39943 m .18483 .40023 L .18159 .39733 L p F P
0 g
s
0 0 0 r
.5871 .29932 m .58572 .30085 L .59049 .29568 L closepath p F P
0 g
s
.55 .734 .961 r
.26063 .42609 m .26545 .42544 L .27061 .42791 L p F P
0 g
s
.546 .729 .959 r
.27027 .42477 m .26545 .42544 L .27061 .42791 L p F P
0 g
s
.546 .729 .959 r
.27061 .42791 m .27337 .42756 L .27027 .42477 L p F P
0 g
s
.651 .503 .67 r
.45842 .41264 m .45327 .41359 L .45381 .41604 L closepath p F P
0 g
s
.561 .737 .958 r
.26545 .42544 m .26063 .42609 L .25749 .42341 L p F P
0 g
s
.848 .387 .077 r
.25696 .32832 m .26102 .33131 L .25905 .32778 L p F P
0 g
s
.848 .387 .077 r
.25905 .32778 m .25505 .32477 L .25696 .32832 L p F P
0 g
s
.682 .72 .878 r
.31489 .43189 m .32477 .42787 L .32775 .43145 L p F P
0 g
s
.697 .711 .859 r
.32477 .42787 m .31489 .43189 L .31187 .42867 L p F P
0 g
s
.474 .708 .972 r
.23503 .41897 m .23212 .41904 L .22894 .41637 L p F P
0 g
s
.739 .629 .737 r
.35573 .42776 m .36362 .42145 L .36296 .41981 L p F P
0 g
s
.739 .629 .737 r
.35215 .42698 m .35573 .42776 L p .36296 .41981 L F P
0 g
s
.667 .709 .879 r
.48506 .43124 m .49519 .42765 L .49794 .43133 L p F P
0 g
s
.666 .671 .846 r
.49519 .42765 m .48506 .43124 L .4823 .42701 L p F P
0 g
s
.839 .372 .034 r
.25505 .32477 m .25344 .32193 L .25023 .31998 L p F P
0 g
s
.717 .684 .817 r
.35215 .42698 m .34781 .4263 L .34064 .43053 L p F P
0 g
s
.725 .707 .833 r
.34781 .4263 m .34064 .43053 L .3377 .42647 L p F P
0 g
s
.703 .7 .844 r
.32775 .43145 m .3377 .42647 L .34064 .43053 L p F P
0 g
s
.677 .828 .956 r
.5586 .42292 m .55969 .42376 L .54946 .42768 L p F P
0 g
s
.677 .828 .956 r
.54946 .42768 m .54937 .4276 L .5586 .42292 L p F P
0 g
s
.769 .566 .624 r
.34552 .40977 m .3528 .41147 L .35499 .4063 L p F P
0 g
s
.769 .566 .624 r
.35499 .4063 m .34744 .40469 L .34552 .40977 L p F P
0 g
s
.802 .538 .539 r
.32772 .39441 m .33417 .39642 L .33436 .39198 L p F P
0 g
s
.802 .538 .539 r
.33436 .39198 m .32791 .38997 L .32772 .39441 L p F P
0 g
s
.735 .955 .945 r
.65213 .38944 m .65454 .39023 L .64426 .3963 L p F P
0 g
s
.735 .955 .945 r
.64481 .39379 m .65213 .38944 L p .64426 .3963 L F P
0 g
s
.735 .955 .945 r
.64426 .3963 m .64256 .39578 L .64481 .39379 L p F P
0 g
s
.718 .693 .825 r
.32775 .43145 m .3377 .42647 L .33557 .42326 L p F P
0 g
s
.718 .693 .825 r
.32477 .42787 m .32775 .43145 L p .33557 .42326 L F P
0 g
s
.674 .821 .954 r
.55704 .42169 m .5586 .42292 L .54937 .4276 L p F P
0 g
s
.674 .821 .954 r
.54937 .4276 m .5468 .42551 L .55704 .42169 L p F P
0 g
s
.745 .985 .904 r
.67743 .3773 m .67705 .37756 L .67733 .37729 L closepath p F P
0 g
s
.748 .978 .918 r
.67509 .37687 m .67733 .37729 L .67705 .37756 L p F P
0 g
s
.748 .978 .918 r
.66992 .38037 m .67509 .37687 L p .67705 .37756 L F P
0 g
s
.748 .978 .918 r
.66622 .38406 m .66992 .38037 L p .67705 .37756 L F P
0 g
s
.623 .442 .617 r
.46541 .40577 m .46382 .40614 L .46394 .4071 L closepath p F P
0 g
s
.386 .664 .969 r
.21312 .41064 m .21031 .41045 L .21456 .41328 L p F P
0 g
s
.386 .664 .969 r
.21456 .41328 m .21632 .4134 L .21312 .41064 L p F P
0 g
s
.76 .987 .899 r
.68535 .36962 m .68766 .36989 L .67743 .3773 L p F P
0 g
s
.76 .987 .899 r
.68276 .3715 m .68535 .36962 L p .67743 .3773 L F P
0 g
s
.76 .987 .899 r
.67743 .3773 m .67733 .37729 L .68276 .3715 L p F P
0 g
s
.838 .987 .865 r
.63632 .2489 m .63626 .24889 L .6364 .24876 L closepath p F P
0 g
s
.844 .45 .301 r
.2856 .35725 m .28412 .35349 L .28916 .35607 L p F P
0 g
s
.844 .45 .301 r
.28862 .35877 m .2856 .35725 L p .28916 .35607 L F P
0 g
s
.844 .45 .301 r
.28916 .35607 m .28999 .35808 L .28862 .35877 L p F P
0 g
s
.207 0 .211 r
.54521 .34572 m .54593 .34343 L .53723 .3489 L p F P
0 g
s
.207 0 .211 r
.54352 .34748 m .54521 .34572 L p .53723 .3489 L F P
0 g
s
.207 0 .211 r
.53723 .3489 m .53631 .3521 L .54352 .34748 L p F P
0 g
s
0 0 0 r
.75888 .2919 m .75606 .2971 L .75878 .29172 L p F P
0 g
s
0 0 0 r
.75878 .29172 m .76165 .28649 L .75888 .2919 L p F P
0 g
s
.667 .61 .781 r
.46942 .426 m .46665 .41931 L .45655 .42453 L p F P
0 g
s
.667 .61 .781 r
.4683 .4265 m .46942 .426 L p .45655 .42453 L F P
0 g
s
.662 .57 .741 r
.45489 .41997 m .45655 .42453 L .46665 .41931 L p F P
0 g
s
.719 .922 .961 r
.62354 .4055 m .62126 .40669 L .61877 .40556 L p F P
0 g
s
.708 .92 .965 r
.60848 .41071 m .61877 .40556 L .62126 .40669 L p F P
0 g
s
.595 .395 .58 r
.48552 .40084 m .48521 .39601 L .47455 .39888 L p F P
0 g
s
.595 .395 .58 r
.47455 .39888 m .47485 .40372 L .48552 .40084 L p F P
0 g
s
.615 .409 .58 r
.46541 .40577 m .47485 .40372 L .47455 .39888 L p F P
0 g
s
.23 .564 .937 r
.1659 .3896 m .162 .38863 L .16566 .39173 L p F P
0 g
s
.23 .564 .937 r
.16566 .39173 m .16917 .39261 L .1659 .3896 L p F P
0 g
s
.837 .97 .884 r
.65225 .23437 m .64639 .23952 L .64531 .23924 L p F P
0 g
s
.851 .969 .874 r
.64639 .23952 m .64411 .24164 L .64531 .23924 L closepath p F P
0 g
s
.833 .521 .461 r
.3094 .37921 m .31508 .38152 L .31442 .37742 L p F P
0 g
s
.833 .521 .461 r
.31442 .37742 m .3088 .37508 L .3094 .37921 L p F P
0 g
s
.656 .513 .676 r
.45381 .41604 m .45489 .41997 L p .46462 .41157 L F P
0 g
s
.656 .513 .676 r
.46462 .41157 m .45842 .41264 L .45381 .41604 L p F P
0 g
s
.852 .971 .871 r
.63955 .24323 m .6364 .24876 L .64411 .24164 L p F P
0 g
s
.852 .971 .871 r
.64399 .23891 m .63955 .24323 L p .64411 .24164 L F P
0 g
s
.852 .971 .871 r
.64411 .24164 m .64531 .23924 L .64399 .23891 L p F P
0 g
s
.563 .058 0 r
.22891 .29711 m .22742 .2955 L .23078 .29881 L p F P
0 g
s
.563 .058 0 r
.23078 .29881 m .23208 .30021 L .22891 .29711 L p F P
0 g
s
.832 .992 .86 r
.63385 .24875 m .63955 .24323 L .6364 .24876 L p F P
0 g
s
.832 .992 .86 r
.6364 .24876 m .63626 .24889 L .63385 .24875 L p F P
0 g
s
.843 .997 .827 r
.62928 .25566 m .63626 .24889 L .63385 .24875 L p F P
0 g
s
.846 .944 .885 r
.65655 .23057 m .65225 .23437 L .65437 .22961 L closepath p F P
0 g
s
.837 .97 .884 r
.65414 .22951 m .65437 .22961 L .65225 .23437 L p F P
0 g
s
.837 .97 .884 r
.64689 .23624 m .65414 .22951 L p .65225 .23437 L F P
0 g
s
.837 .97 .884 r
.64531 .23924 m .64689 .23624 L p .65225 .23437 L F P
0 g
s
.763 .978 .916 r
.67733 .37729 m .67509 .37687 L .68276 .3715 L closepath p F P
0 g
s
.555 .331 .531 r
.49554 .3927 m .49555 .38826 L .48524 .39158 L p F P
0 g
s
.555 .331 .531 r
.48524 .39158 m .48521 .39601 L .49554 .3927 L p F P
0 g
s
.746 .625 .725 r
.36487 .42014 m .36296 .41981 L .36362 .42145 L closepath p F P
0 g
s
.775 .543 .584 r
.34023 .40296 m .34361 .40371 L .34327 .39869 L p F P
0 g
s
.775 .543 .584 r
.34327 .39869 m .34122 .39822 L .34023 .40296 L p F P
0 g
s
.665 .74 .906 r
.49794 .43133 m .5081 .42786 L .51083 .43104 L p F P
0 g
s
.664 .706 .879 r
.5081 .42786 m .49794 .43133 L .49519 .42765 L p F P
0 g
s
.669 .802 .946 r
.5468 .42551 m .53659 .42921 L .53391 .42677 L p F P
0 g
s
.666 .797 .944 r
.52371 .43033 m .53391 .42677 L .53659 .42921 L p F P
0 g
s
.831 .945 .897 r
.66098 .22689 m .65655 .23057 L .65437 .22961 L p F P
0 g
s
.628 .451 .623 r
.46394 .4071 m .46462 .41157 L p .47485 .40372 L F P
0 g
s
.628 .451 .623 r
.47485 .40372 m .46541 .40577 L .46394 .4071 L p F P
0 g
s
.646 .472 .633 r
.46394 .4071 m .45842 .41264 L .46462 .41157 L closepath p F P
0 g
s
0 0 0 r
.56676 .32164 m .56578 .32251 L .56716 .32001 L p F P
0 g
s
0 0 0 r
.56716 .32001 m .57261 .31518 L .56676 .32164 L p F P
0 g
s
.289 .293 .691 r
.77268 .22973 m .77243 .23035 L .76933 .2271 L p F P
0 g
s
.289 .293 .691 r
.76933 .2271 m .77087 .22329 L .77268 .22973 L p F P
0 g
s
.494 .526 .819 r
.76238 .20111 m .75796 .20071 L .75647 .20564 L p F P
0 g
s
.494 .526 .819 r
.75647 .20564 m .76492 .20691 L .76238 .20111 L p F P
0 g
s
.536 .583 .849 r
.75148 .20065 m .75796 .20071 L .75647 .20564 L p F P
0 g
s
.843 .997 .827 r
.63385 .24875 m .6325 .25012 L .62928 .25566 L p F P
0 g
s
.815 1 .825 r
.62588 .25685 m .6325 .25012 L .62928 .25566 L p F P
0 g
s
.815 1 .825 r
.6246 .2589 m .62588 .25685 L p .62928 .25566 L F P
0 g
s
.815 1 .825 r
.62928 .25566 m .62614 .25869 L .6246 .2589 L p F P
0 g
s
.758 .587 .664 r
.36099 .41285 m .36081 .41281 L .36087 .41305 L closepath p F P
0 g
s
.848 .394 .115 r
.26294 .33487 m .26724 .33776 L .26525 .33422 L p F P
0 g
s
.848 .394 .115 r
.26525 .33422 m .26102 .33131 L .26294 .33487 L p F P
0 g
s
.662 .57 .741 r
.46665 .41931 m .46618 .41788 L .45489 .41997 L p F P
0 g
s
.656 .513 .676 r
.45489 .41997 m .46618 .41788 L .46462 .41157 L p F P
0 g
s
.752 .591 .676 r
.35648 .41884 m .36087 .41305 L .36081 .41281 L p F P
0 g
s
.752 .591 .676 r
.34892 .41724 m .35648 .41884 L p .36081 .41281 L F P
0 g
s
.752 .591 .676 r
.36081 .41281 m .3528 .41147 L .34892 .41724 L p F P
0 g
s
.768 .988 .896 r
.68799 .36992 m .68766 .36989 L .68874 .36909 L closepath p F P
0 g
s
.741 .947 .631 r
.73932 .32071 m .74436 .31451 L .74089 .31989 L p F P
0 g
s
.741 .947 .631 r
.73743 .32369 m .73932 .32071 L p .74089 .31989 L F P
0 g
s
.741 .947 .631 r
.74089 .31989 m .73834 .32303 L .73743 .32369 L p F P
0 g
s
.746 .595 .688 r
.36087 .41305 m .35648 .41884 L .36296 .41981 L closepath p F P
0 g
s
.828 1 .82 r
.62614 .25869 m .62234 .2625 L .6246 .2589 L closepath p F P
0 g
s
.755 .805 .892 r
.71021 .19638 m .69986 .20231 L .69747 .19977 L p F P
0 g
s
.665 .77 .928 r
.51083 .43104 m .521 .42756 L .52371 .43033 L p F P
0 g
s
.665 .742 .907 r
.521 .42756 m .51083 .43104 L .5081 .42786 L p F P
0 g
s
.666 .774 .93 r
.53391 .42677 m .52371 .43033 L .521 .42756 L p F P
0 g
s
.844 .934 .886 r
.66098 .22689 m .66672 .22208 L .66432 .22064 L p F P
0 g
s
.844 .934 .886 r
.66432 .22064 m .66312 .2217 L .66098 .22689 L p F P
0 g
s
.831 .945 .897 r
.6546 .22911 m .66312 .2217 L .66098 .22689 L p F P
0 g
s
.831 .945 .897 r
.65437 .22961 m .6546 .22911 L p .66098 .22689 L F P
0 g
s
.509 .267 .484 r
.50554 .38451 m .50578 .38038 L .4958 .38412 L p F P
0 g
s
.509 .267 .484 r
.4958 .38412 m .49555 .38826 L .50554 .38451 L p F P
0 g
s
.777 .987 .746 r
.72892 .33408 m .72833 .3343 L .72997 .33258 L closepath p F P
0 g
s
.739 .629 .737 r
.35065 .42433 m .35215 .42698 L p .36296 .41981 L F P
0 g
s
.727 .666 .789 r
.35065 .42433 m .34781 .4263 L .35215 .42698 L closepath p F P
0 g
s
.739 .629 .737 r
.36296 .41981 m .35648 .41884 L .35065 .42433 L p F P
0 g
s
.717 .936 .959 r
.63154 .40122 m .62354 .4055 L .62986 .40057 L closepath p F P
0 g
s
.719 .922 .961 r
.62907 .40022 m .62986 .40057 L .62354 .4055 L p F P
0 g
s
.719 .922 .961 r
.61877 .40556 m .62907 .40022 L p .62354 .4055 L F P
0 g
s
.753 .969 .93 r
.66622 .38406 m .66481 .38371 L .66992 .38037 L closepath p F P
0 g
s
.775 .992 .77 r
.62372 .25904 m .6246 .2589 L .62234 .2625 L p F P
0 g
s
.775 .992 .77 r
.61952 .26349 m .62372 .25904 L p .62234 .2625 L F P
0 g
s
.775 .992 .77 r
.61586 .26886 m .61952 .26349 L p .62234 .2625 L F P
0 g
s
.775 .992 .77 r
.62234 .2625 m .61603 .26879 L .61586 .26886 L p F P
0 g
s
.783 .549 .582 r
.33325 .40113 m .34023 .40296 L .34122 .39822 L p F P
0 g
s
.783 .549 .582 r
.34122 .39822 m .33417 .39642 L .33325 .40113 L p F P
0 g
s
.725 .226 0 r
.23208 .30021 m .23339 .30203 L .23685 .30529 L p F P
0 g
s
.739 .243 0 r
.23572 .30537 m .23921 .30862 L .23685 .30529 L p F P
0 g
s
.739 .243 0 r
.23685 .30529 m .23339 .30203 L .23572 .30537 L p F P
0 g
s
.858 .502 .375 r
.29165 .36379 m .29672 .36635 L .29557 .36245 L p F P
0 g
s
.858 .502 .375 r
.29557 .36245 m .29058 .35986 L .29165 .36379 L p F P
0 g
s
.002 0 .454 r
.77434 .24714 m .77217 .25221 L .77156 .24804 L p F P
0 g
s
.002 0 .454 r
.77156 .24804 m .77372 .24297 L .77434 .24714 L p F P
0 g
s
.819 .919 .904 r
.67056 .21909 m .66672 .22208 L .66432 .22064 L p F P
0 g
s
.694 .884 .968 r
.59339 .41288 m .59566 .41417 L .5854 .41878 L p F P
0 g
s
.694 .884 .968 r
.5854 .41878 m .58471 .41837 L .59339 .41288 L p F P
0 g
s
.723 .942 .63 r
.73834 .32303 m .73574 .32613 L .73743 .32369 L closepath p F P
0 g
s
.816 .526 .499 r
.31536 .38578 m .32151 .38792 L .32117 .38369 L p F P
0 g
s
.816 .526 .499 r
.32117 .38369 m .31508 .38152 L .31536 .38578 L p F P
0 g
s
.787 .993 .768 r
.61603 .26879 m .61556 .26928 L .61586 .26886 L closepath p F P
0 g
s
.784 .991 .76 r
.61326 .27009 m .60913 .27593 L .61556 .26928 L p F P
0 g
s
.784 .991 .76 r
.6136 .26972 m .61326 .27009 L p .61556 .26928 L F P
0 g
s
.784 .991 .76 r
.61556 .26928 m .61586 .26886 L .6136 .26972 L p F P
0 g
s
.597 .738 .943 r
.27337 .42756 m .28308 .42556 L .28617 .42846 L p F P
0 g
s
.607 .737 .937 r
.28308 .42556 m .27337 .42756 L .27027 .42477 L p F P
0 g
s
.369 .387 .748 r
.76706 .21922 m .76838 .21583 L .77019 .22116 L closepath p F P
0 g
s
.173 .521 .918 r
.1503 .38106 m .14835 .38044 L .15184 .38363 L p F P
0 g
s
.173 .521 .918 r
.15184 .38363 m .15357 .38418 L .1503 .38106 L p F P
0 g
s
.456 .2 .436 r
.51543 .37619 m .51586 .3723 L .50621 .37647 L p F P
0 g
s
.456 .2 .436 r
.50621 .37647 m .50578 .38038 L .51543 .37619 L p F P
0 g
s
.673 .633 .801 r
.46942 .426 m .4683 .4265 L .46956 .42628 L closepath p F P
0 g
s
.863 .428 .176 r
.27168 .34044 m .27174 .34057 L .27149 .3404 L closepath p F P
0 g
s
.43 .684 .97 r
.22597 .41383 m .22894 .41637 L p .21632 .4134 L F P
0 g
s
.43 .684 .97 r
.21632 .4134 m .22567 .41363 L .22597 .41383 L p F P
0 g
s
.437 .684 .968 r
.22567 .41363 m .21632 .4134 L .21312 .41064 L p F P
0 g
s
.437 .465 .791 r
.76305 .21197 m .76493 .20694 L .76751 .21349 L closepath p F P
0 g
s
.83 .91 .893 r
.67056 .21909 m .67693 .21409 L .67453 .2123 L p F P
0 g
s
.83 .91 .893 r
.67453 .2123 m .67252 .21395 L .67056 .21909 L p F P
0 g
s
.819 .919 .904 r
.66432 .22064 m .67252 .21395 L .67056 .21909 L p F P
0 g
s
0 0 0 r
.76643 .27614 m .76394 .28127 L .76558 .27627 L p F P
0 g
s
0 0 0 r
.76558 .27627 m .76812 .27113 L .76643 .27614 L p F P
0 g
s
.84 .505 .418 r
.30843 .37345 m .3088 .37508 L .30775 .37461 L closepath p F P
0 g
s
.771 .987 .898 r
.68874 .36909 m .68766 .36989 L .68535 .36962 L p F P
0 g
s
.874 .458 .224 r
.26899 .34139 m .2733 .34427 L .27174 .34057 L p F P
0 g
s
.874 .458 .224 r
.26841 .33998 m .26899 .34139 L p .27174 .34057 L F P
0 g
s
.874 .458 .224 r
.27174 .34057 m .27149 .3404 L .26841 .33998 L p F P
0 g
s
.777 .994 .876 r
.69824 .36201 m .69788 .362 L .69901 .3611 L closepath p F P
0 g
s
.721 .788 .905 r
.71117 .19756 m .71021 .19638 L .71216 .19542 L closepath p F P
0 g
s
.744 .662 .769 r
.34781 .4263 m .35065 .42433 L .34779 .41851 L p F P
0 g
s
.744 .662 .769 r
.34779 .41851 m .34037 .42466 L .34781 .4263 L p F P
0 g
s
.725 .707 .833 r
.3377 .42647 m .34037 .42466 L .34781 .4263 L p F P
0 g
s
.768 .993 .88 r
.68874 .36909 m .69788 .362 L .69561 .36189 L p F P
0 g
s
.768 .993 .88 r
.69561 .36189 m .69394 .36318 L .68874 .36909 L p F P
0 g
s
.771 .987 .898 r
.68535 .36962 m .69394 .36318 L .68874 .36909 L p F P
0 g
s
.667 .63 .804 r
.46942 .426 m .46956 .42628 L .4806 .42388 L p F P
0 g
s
.664 .651 .827 r
.4823 .42701 m .4806 .42388 L .46956 .42628 L p F P
0 g
s
.552 .596 .852 r
.75796 .20071 m .75148 .20065 L .74903 .19605 L p F P
0 g
s
.763 .975 .707 r
.7337 .32712 m .72997 .33258 L .73574 .32613 L p F P
0 g
s
.763 .975 .707 r
.73626 .32425 m .7337 .32712 L p .73574 .32613 L F P
0 g
s
.763 .975 .707 r
.73574 .32613 m .73743 .32369 L .73626 .32425 L p F P
0 g
s
.1 0 .118 r
.54925 .34104 m .54593 .34343 L .54697 .34042 L p F P
0 g
s
.1 0 .118 r
.54697 .34042 m .55513 .33456 L .54925 .34104 L p F P
0 g
s
.755 .255 0 r
.24156 .31197 m .24521 .31515 L .24282 .31181 L p F P
0 g
s
.755 .255 0 r
.24282 .31181 m .23921 .30862 L .24156 .31197 L p F P
0 g
s
.847 .405 .165 r
.27149 .3404 m .26841 .33998 L .26724 .33776 L closepath p F P
0 g
s
.657 .565 .74 r
.46942 .426 m .47953 .42166 L .47716 .41539 L p F P
0 g
s
.657 .565 .74 r
.46665 .41931 m .46942 .426 L p .47716 .41539 L F P
0 g
s
.667 .63 .804 r
.4806 .42388 m .47953 .42166 L .46942 .426 L p F P
0 g
s
.791 .992 .759 r
.61586 .26886 m .6136 .26972 L .61952 .26349 L closepath p F P
0 g
s
.78 .579 .628 r
.34469 .40956 m .34552 .40977 L .34744 .40469 L p F P
0 g
s
.78 .579 .628 r
.34744 .40469 m .34361 .40371 L .34469 .40956 L p F P
0 g
s
0 0 .238 r
.77023 .26439 m .76929 .2663 L .76993 .26167 L p F P
0 g
s
0 0 .238 r
.76993 .26167 m .77036 .26079 L .77023 .26439 L p F P
0 g
s
.479 .705 .968 r
.23845 .41597 m .23031 .41632 L .23503 .41897 L p F P
0 g
s
.479 .705 .968 r
.23503 .41897 m .24162 .41874 L .23845 .41597 L p F P
0 g
s
.474 .708 .972 r
.22894 .41637 m .23031 .41632 L .23503 .41897 L p F P
0 g
s
.7 .952 .678 r
.60737 .27656 m .61326 .27009 L .60913 .27593 L p F P
0 g
s
.7 .952 .678 r
.60486 .27992 m .60737 .27656 L p .60913 .27593 L F P
0 g
s
.7 .952 .678 r
.60913 .27593 m .60593 .27925 L .60486 .27992 L p F P
0 g
s
.701 .911 .968 r
.60848 .41071 m .60635 .41173 L .60811 .41053 L closepath p F P
0 g
s
.702 .898 .967 r
.60595 .40938 m .60811 .41053 L .60635 .41173 L p F P
0 g
s
.702 .898 .967 r
.59566 .41417 m .60595 .40938 L p .60635 .41173 L F P
0 g
s
.743 .959 .941 r
.65467 .39027 m .65454 .39023 L .65503 .38993 L closepath p F P
0 g
s
.112 .475 .895 r
.13898 .37516 m .13808 .37481 L .13479 .37156 L p F P
0 g
s
.843 .505 .413 r
.29764 .37035 m .3031 .37276 L .30208 .3688 L p F P
0 g
s
.843 .505 .413 r
.30208 .3688 m .29672 .36635 L .29764 .37035 L p F P
0 g
s
.753 .653 .751 r
.34779 .41851 m .34892 .41724 L .35648 .41884 L p F P
0 g
s
.753 .653 .751 r
.35648 .41884 m .35065 .42433 L .34779 .41851 L p F P
0 g
s
.802 .891 .908 r
.68147 .21081 m .67693 .21409 L .67453 .2123 L p F P
0 g
s
.525 .719 .961 r
.25435 .42067 m .24478 .42146 L .24162 .41874 L p F P
0 g
s
.514 .721 .967 r
.24478 .42146 m .25435 .42067 L .25749 .42341 L p F P
0 g
s
.649 .819 .393 r
.75601 .29719 m .75598 .29725 L .75606 .2971 L closepath p F P
0 g
s
.628 .451 .623 r
.46462 .41157 m .47563 .40912 L .47485 .40372 L p F P
0 g
s
.641 .509 .686 r
.47678 .41408 m .47563 .40912 L .46462 .41157 L p F P
0 g
s
.641 .509 .686 r
.47258 .41639 m .47678 .41408 L p .46462 .41157 L F P
0 g
s
.641 .509 .686 r
.46462 .41157 m .46618 .41788 L .47258 .41639 L p F P
0 g
s
.71 .955 .679 r
.60593 .27925 m .60279 .28256 L .60486 .27992 L closepath p F P
0 g
s
.652 .822 .396 r
.75567 .29746 m .75888 .2919 L .75606 .2971 L p F P
0 g
s
.652 .822 .396 r
.75472 .29922 m .75567 .29746 L p .75606 .2971 L F P
0 g
s
.652 .822 .396 r
.75606 .2971 m .75598 .29725 L .75472 .29922 L p F P
0 g
s
.393 .124 .382 r
.52517 .36765 m .52576 .36399 L .51644 .3686 L p F P
0 g
s
.393 .124 .382 r
.51644 .3686 m .51586 .3723 L .52517 .36765 L p F P
0 g
s
.628 .811 .389 r
.75598 .29725 m .75263 .30273 L .75472 .29922 L closepath p F P
0 g
s
.771 .598 .664 r
.34705 .41679 m .34892 .41724 L .3528 .41147 L p F P
0 g
s
.771 .598 .664 r
.34501 .41067 m .34705 .41679 L p .3528 .41147 L F P
0 g
s
.771 .598 .664 r
.3528 .41147 m .34552 .40977 L .34501 .41067 L p F P
0 g
s
.747 .955 .942 r
.65503 .38993 m .65454 .39023 L .65213 .38944 L p F P
0 g
s
.863 .485 .329 r
.28999 .35808 m .29058 .35986 L .28862 .35877 L closepath p F P
0 g
s
.871 .469 .267 r
.27476 .34803 m .27933 .35081 L .2778 .34707 L p F P
0 g
s
.871 .469 .267 r
.2778 .34707 m .2733 .34427 L .27476 .34803 L p F P
0 g
s
.812 .547 .538 r
.32549 .39364 m .32772 .39441 L .32791 .38997 L p F P
0 g
s
.812 .547 .538 r
.32791 .38997 m .32572 .38921 L .32549 .39364 L p F P
0 g
s
.711 .217 0 r
.23339 .30203 m .23208 .30021 L .22891 .29711 L p F P
0 g
s
.745 .965 .935 r
.65503 .38993 m .66481 .38371 L .66243 .38311 L p F P
0 g
s
.745 .965 .935 r
.66243 .38311 m .66178 .38352 L .65503 .38993 L p F P
0 g
s
.747 .955 .942 r
.65213 .38944 m .66178 .38352 L .65503 .38993 L p F P
0 g
s
.625 .663 .866 r
.74672 .19189 m .74469 .19681 L p .73595 .19421 L F P
0 g
s
.603 .647 .867 r
.74469 .19681 m .74672 .19189 L .74903 .19605 L closepath p F P
0 g
s
.688 .731 .883 r
.73354 .19047 m .72302 .19447 L .72063 .19121 L p F P
0 g
s
.676 .717 .88 r
.72302 .19447 m .73354 .19047 L .73595 .19421 L p F P
0 g
s
.629 .9 .59 r
.59606 .28974 m .59582 .28993 L .59655 .28915 L closepath p F P
0 g
s
.702 .949 .666 r
.60152 .28303 m .59655 .28915 L .60279 .28256 L p F P
0 g
s
.702 .949 .666 r
.60349 .28082 m .60152 .28303 L p .60279 .28256 L F P
0 g
s
.702 .949 .666 r
.60279 .28256 m .60486 .27992 L .60349 .28082 L p F P
0 g
s
.646 .734 .913 r
.29595 .42576 m .28617 .42846 L .28308 .42556 L p F P
0 g
s
.633 .737 .923 r
.28617 .42846 m .29595 .42576 L .299 .42885 L p F P
0 g
s
.736 .923 .571 r
.74722 .31113 m .74622 .31203 L .74878 .30852 L closepath p F P
0 g
s
.779 .988 .748 r
.72744 .33375 m .7337 .32712 L .72997 .33258 L p F P
0 g
s
.779 .988 .748 r
.72665 .33492 m .72744 .33375 L p .72997 .33258 L F P
0 g
s
.779 .988 .748 r
.72997 .33258 m .72833 .3343 L .72665 .33492 L p F P
0 g
s
.78 .993 .878 r
.69901 .3611 m .69788 .362 L .69561 .36189 L p F P
0 g
s
.77 .267 0 r
.24703 .31775 m .24521 .31515 L .24902 .31826 L p F P
0 g
s
.77 .267 0 r
.24902 .31826 m .25023 .31998 L .24703 .31775 L p F P
0 g
s
.693 .874 .966 r
.5931 .41271 m .59339 .41288 L .58471 .41837 L p F P
0 g
s
.693 .874 .966 r
.58471 .41837 m .58282 .41718 L .5931 .41271 L p F P
0 g
s
.382 .66 .967 r
.20056 .40714 m .20613 .40758 L .21031 .41045 L p F P
0 g
s
.389 .66 .966 r
.20613 .40758 m .20056 .40714 L .19733 .40431 L p F P
0 g
s
.71 .913 .965 r
.6164 .40445 m .61877 .40556 L .60848 .41071 L p F P
0 g
s
.71 .913 .965 r
.60848 .41071 m .60811 .41053 L .6164 .40445 L p F P
0 g
s
.686 .862 .966 r
.58282 .41718 m .57255 .42147 L .56994 .41968 L p F P
0 g
s
.679 .856 .967 r
.55969 .42376 m .56994 .41968 L .57255 .42147 L p F P
0 g
s
.78 .993 .878 r
.69561 .36189 m .70378 .35533 L .69901 .3611 L p F P
0 g
s
.775 .997 .855 r
.69901 .3611 m .70808 .35356 L .70584 .35361 L p F P
0 g
s
.775 .997 .855 r
.70584 .35361 m .70378 .35533 L .69901 .3611 L p F P
0 g
s
.561 .737 .958 r
.25749 .42341 m .26023 .42299 L .26545 .42544 L p F P
0 g
s
.557 .729 .955 r
.26715 .42191 m .26023 .42299 L .26545 .42544 L p F P
0 g
s
.557 .729 .955 r
.26545 .42544 m .27027 .42477 L .26715 .42191 L p F P
0 g
s
.765 .986 .75 r
.72833 .3343 m .72343 .3393 L .72665 .33492 L closepath p F P
0 g
s
.812 .881 .895 r
.68147 .21081 m .68718 .20664 L .68478 .20451 L p F P
0 g
s
.812 .881 .895 r
.68478 .20451 m .68314 .20577 L .68147 .21081 L p F P
0 g
s
.802 .891 .908 r
.67453 .2123 m .68314 .20577 L .68147 .21081 L p F P
0 g
s
.625 .663 .866 r
.73595 .19421 m .74659 .19166 L .74672 .19189 L p F P
0 g
s
.639 .678 .871 r
.74659 .19166 m .73595 .19421 L .73354 .19047 L p F P
0 g
s
0 0 .215 r
.7716 .26121 m .77023 .26439 L .77036 .26079 L p F P
0 g
s
0 0 .215 r
.77036 .26079 m .77217 .25661 L .7716 .26121 L p F P
0 g
s
0 0 0 r
.57637 .3108 m .5756 .31194 L .57852 .30869 L closepath p F P
0 g
s
.112 .475 .895 r
.13479 .37156 m .13565 .3719 L .13898 .37516 L p F P
0 g
s
.156 .502 .909 r
.14162 .37395 m .14495 .37722 L .13898 .37516 L p F P
0 g
s
.156 .502 .909 r
.13898 .37516 m .13565 .3719 L .14162 .37395 L p F P
0 g
s
.848 .972 .875 r
.64531 .23924 m .64399 .23891 L .64689 .23624 L closepath p F P
0 g
s
.329 .629 .96 r
.18483 .40023 m .1887 .40077 L .19268 .40373 L p F P
0 g
s
.345 .635 .961 r
.1941 .40144 m .1887 .40077 L .19268 .40373 L p F P
0 g
s
.345 .635 .961 r
.19268 .40373 m .19733 .40431 L .1941 .40144 L p F P
0 g
s
.728 .938 .955 r
.63938 .39453 m .64183 .39551 L .63154 .40122 L p F P
0 g
s
.728 .938 .955 r
.63247 .39838 m .63938 .39453 L p .63154 .40122 L F P
0 g
s
.728 .938 .955 r
.63154 .40122 m .62986 .40057 L .63247 .39838 L p F P
0 g
s
.611 .443 .63 r
.48628 .40621 m .48552 .40084 L .47485 .40372 L p F P
0 g
s
.611 .443 .63 r
.47485 .40372 m .47563 .40912 L .48628 .40621 L p F P
0 g
s
.771 .574 .632 r
.3381 .4081 m .34469 .40956 L .34361 .40371 L p F P
0 g
s
.771 .574 .632 r
.34361 .40371 m .34023 .40296 L .3381 .4081 L p F P
0 g
s
.666 .671 .846 r
.4823 .42701 m .49244 .42326 L .49519 .42765 L p F P
0 g
s
.659 .638 .818 r
.4806 .42388 m .4823 .42701 L .49244 .42326 L p F P
0 g
s
.842 .527 .455 r
.30645 .3779 m .3094 .37921 L .3088 .37508 L p F P
0 g
s
.842 .527 .455 r
.3088 .37508 m .30775 .37461 L .30645 .3779 L p F P
0 g
s
.778 .995 .787 r
.72618 .33501 m .72665 .33492 L .72343 .3393 L p F P
0 g
s
.778 .995 .787 r
.72035 .34067 m .72618 .33501 L p .72343 .3393 L F P
0 g
s
.778 .995 .787 r
.71757 .34452 m .72035 .34067 L p .72343 .3393 L F P
0 g
s
.778 .995 .787 r
.72343 .3393 m .71823 .34434 L .71757 .34452 L p F P
0 g
s
.214 .55 .931 r
.15357 .38418 m .15842 .38549 L .162 .38863 L p F P
0 g
s
.222 .55 .931 r
.15842 .38549 m .15357 .38418 L .1503 .38106 L p F P
0 g
s
.784 .998 .852 r
.70811 .35355 m .70808 .35356 L .70816 .35348 L closepath p F P
0 g
s
.582 .866 .545 r
.59587 .28942 m .60152 .28303 L .59655 .28915 L p F P
0 g
s
.582 .866 .545 r
.59419 .29147 m .59587 .28942 L p .59655 .28915 L F P
0 g
s
.582 .866 .545 r
.59655 .28915 m .59582 .28993 L .59419 .29147 L p F P
0 g
s
.657 .565 .74 r
.47716 .41539 m .47258 .41639 L .46665 .41931 L p F P
0 g
s
.651 .549 .726 r
.47258 .41639 m .46618 .41788 L .46665 .41931 L closepath p F P
0 g
s
.737 .695 .811 r
.34037 .42466 m .33557 .42326 L .3377 .42647 L closepath p F P
0 g
s
.108 .086 .548 r
.77481 .24039 m .77372 .24297 L .77241 .23905 L p F P
0 g
s
.108 .086 .548 r
.77241 .23905 m .77396 .23537 L .77481 .24039 L p F P
0 g
s
.801 .564 .579 r
.32688 .39909 m .33325 .40113 L .33417 .39642 L p F P
0 g
s
.801 .564 .579 r
.33417 .39642 m .32772 .39441 L .32688 .39909 L p F P
0 g
s
.273 .592 .948 r
.16917 .39261 m .17291 .39337 L .17668 .39642 L p F P
0 g
s
.292 .601 .951 r
.17834 .39437 m .17291 .39337 L .17668 .39642 L p F P
0 g
s
.292 .601 .951 r
.17668 .39642 m .18159 .39733 L .17834 .39437 L p F P
0 g
s
.861 .473 .306 r
.28071 .3546 m .2856 .35725 L .28412 .35349 L p F P
0 g
s
.861 .473 .306 r
.28412 .35349 m .27933 .35081 L .28071 .3546 L p F P
0 g
s
.788 .997 .855 r
.70816 .35348 m .70808 .35356 L .70584 .35361 L p F P
0 g
s
.781 .998 .832 r
.71251 .34785 m .70816 .35348 L .71621 .34625 L p F P
0 g
s
.788 .997 .855 r
.70584 .35361 m .71251 .34785 L .70816 .35348 L p F P
0 g
s
.585 .868 .546 r
.59582 .28993 m .59049 .29568 L .59419 .29147 L closepath p F P
0 g
s
.8 .537 .54 r
.3213 .39237 m .32549 .39364 L .32572 .38921 L p F P
0 g
s
.8 .537 .54 r
.32572 .38921 m .32151 .38792 L .3213 .39237 L p F P
0 g
s
.765 .993 .79 r
.71823 .34434 m .71621 .34625 L .71757 .34452 L closepath p F P
0 g
s
.781 .998 .832 r
.71603 .34468 m .71251 .34785 L p .71621 .34625 L F P
0 g
s
.781 .998 .832 r
.71621 .34625 m .71757 .34452 L .71603 .34468 L p F P
0 g
s
.839 .372 .034 r
.25023 .31998 m .25119 .32169 L .25505 .32477 L p F P
0 g
s
.852 .393 .066 r
.25305 .32525 m .25696 .32832 L .25505 .32477 L p F P
0 g
s
.852 .393 .066 r
.25505 .32477 m .25119 .32169 L .25305 .32525 L p F P
0 g
s
.336 .628 .959 r
.1887 .40077 m .18483 .40023 L .18159 .39733 L p F P
0 g
s
.668 .728 .894 r
.299 .42885 m .30885 .42528 L .31187 .42867 L p F P
0 g
s
.682 .722 .88 r
.30885 .42528 m .299 .42885 L .29595 .42576 L p F P
0 g
s
.722 .796 .91 r
.71216 .19542 m .71021 .19638 L .70781 .19355 L p F P
0 g
s
.755 .805 .892 r
.69747 .19977 m .70781 .19355 L .71021 .19638 L p F P
0 g
s
.318 .037 .32 r
.53506 .35733 m .53547 .35541 L .52648 .36049 L p F P
0 g
s
.318 .037 .32 r
.53229 .36027 m .53506 .35733 L p .52648 .36049 L F P
0 g
s
.318 .037 .32 r
.52648 .36049 m .52576 .36399 L .53229 .36027 L p F P
0 g
s
.709 .901 .965 r
.61626 .40438 m .6164 .40445 L .60811 .41053 L p F P
0 g
s
.709 .901 .965 r
.60811 .41053 m .60595 .40938 L .61626 .40438 L p F P
0 g
s
0 0 0 r
.76372 .28169 m .76358 .28211 L .76394 .28127 L closepath p F P
0 g
s
.28 .592 .947 r
.17291 .39337 m .16917 .39261 L .1659 .3896 L p F P
0 g
s
.393 .663 .967 r
.20991 .40782 m .20613 .40758 L .21031 .41045 L p F P
0 g
s
.393 .663 .967 r
.21031 .41045 m .21312 .41064 L .20991 .40782 L p F P
0 g
s
.783 .862 .909 r
.69457 .20172 m .68718 .20664 L .68478 .20451 L p F P
0 g
s
.827 .509 .451 r
.30381 .37685 m .30645 .3779 L .30775 .37461 L p F P
0 g
s
.827 .509 .451 r
.30775 .37461 m .3031 .37276 L .30381 .37685 L p F P
0 g
s
.748 .642 .743 r
.34037 .42466 m .34779 .41851 L .34705 .41679 L p F P
0 g
s
.748 .642 .743 r
.33557 .42326 m .34037 .42466 L p .34705 .41679 L F P
0 g
s
.718 .693 .825 r
.33557 .42326 m .33343 .42284 L .32477 .42787 L p F P
0 g
s
.727 .72 .843 r
.33343 .42284 m .32477 .42787 L .32179 .42404 L p F P
0 g
s
.697 .711 .859 r
.31187 .42867 m .32179 .42404 L .32477 .42787 L p F P
0 g
s
0 0 .002 r
.5565 .33163 m .55535 .33433 L .56089 .32812 L closepath p F P
0 g
s
.574 .378 .578 r
.49585 .39753 m .49554 .3927 L .48521 .39601 L p F P
0 g
s
.574 .378 .578 r
.48521 .39601 m .48552 .40084 L .49585 .39753 L p F P
0 g
s
.711 .702 .839 r
.32179 .42404 m .31187 .42867 L .30885 .42528 L p F P
0 g
s
.68 .836 .958 r
.5677 .41802 m .56994 .41968 L .55969 .42376 L p F P
0 g
s
.68 .836 .958 r
.55969 .42376 m .5586 .42292 L .5677 .41802 L p F P
0 g
s
0 0 0 r
.59337 .29228 m .59419 .29147 L .59049 .29568 L p F P
0 g
s
0 0 0 r
.59033 .29578 m .59337 .29228 L p .59049 .29568 L F P
0 g
s
0 0 0 r
.59049 .29568 m .58572 .30085 L .58537 .30127 L p F P
0 g
s
0 0 0 r
.58537 .30127 m .59033 .29578 L p .59049 .29568 L F P
0 g
s
.831 .541 .497 r
.30964 .38348 m .31536 .38578 L .31508 .38152 L p F P
0 g
s
.831 .541 .497 r
.31508 .38152 m .3094 .37921 L .30964 .38348 L p F P
0 g
s
.782 .58 .627 r
.33134 .4062 m .3381 .4081 L .34023 .40296 L p F P
0 g
s
.782 .58 .627 r
.34023 .40296 m .33325 .40113 L .33134 .4062 L p F P
0 g
s
.735 .943 .951 r
.64256 .39578 m .64183 .39551 L .64481 .39379 L closepath p F P
0 g
s
.237 .563 .937 r
.16264 .38653 m .15842 .38549 L .162 .38863 L p F P
0 g
s
.237 .563 .937 r
.162 .38863 m .1659 .3896 L .16264 .38653 L p F P
0 g
s
.761 .639 .726 r
.34892 .41724 m .34705 .41679 L .34779 .41851 L closepath p F P
0 g
s
.733 .795 .901 r
.71216 .19542 m .72063 .19121 L .71823 .18804 L p F P
0 g
s
.733 .795 .901 r
.71823 .18804 m .71391 .19034 L .71216 .19542 L p F P
0 g
s
.722 .796 .91 r
.70781 .19355 m .71391 .19034 L .71216 .19542 L p F P
0 g
s
0 0 0 r
.76428 .28133 m .76643 .27614 L .76394 .28127 L p F P
0 g
s
0 0 0 r
.76285 .28427 m .76428 .28133 L p .76394 .28127 L F P
0 g
s
0 0 0 r
.76394 .28127 m .76358 .28211 L .76285 .28427 L p F P
0 g
s
.7 .886 .504 r
.75187 .30324 m .74878 .30852 L .75263 .30273 L p F P
0 g
s
.7 .886 .504 r
.75406 .29996 m .75187 .30324 L p .75263 .30273 L F P
0 g
s
.7 .886 .504 r
.75263 .30273 m .75472 .29922 L .75406 .29996 L p F P
0 g
s
.664 .706 .879 r
.49519 .42765 m .50536 .42414 L .5081 .42786 L p F P
0 g
s
.66 .667 .845 r
.50536 .42414 m .49519 .42765 L .49244 .42326 L p F P
0 g
s
.855 .402 .107 r
.25881 .3319 m .26294 .33487 L .26102 .33131 L p F P
0 g
s
.855 .402 .107 r
.26102 .33131 m .25696 .32832 L .25881 .3319 L p F P
0 g
s
.572 .739 .955 r
.26023 .42299 m .25749 .42341 L .25435 .42067 L p F P
0 g
s
.538 .044 0 r
.22575 .29381 m .2242 .29213 L .22742 .2955 L p F P
0 g
s
.538 .044 0 r
.22742 .2955 m .22891 .29711 L .22575 .29381 L p F P
0 g
s
.867 .508 .366 r
.28683 .36112 m .29165 .36379 L .29058 .35986 L p F P
0 g
s
.867 .508 .366 r
.2866 .36027 m .28683 .36112 L p .29058 .35986 L F P
0 g
s
.867 .508 .366 r
.29058 .35986 m .28862 .35877 L .2866 .36027 L p F P
0 g
s
.476 .707 .971 r
.22894 .41637 m .23031 .41632 L .22597 .41383 L closepath p F P
0 g
s
.755 .968 .93 r
.66992 .38037 m .66481 .38371 L .66243 .38311 L p F P
0 g
s
0 0 0 r
.76358 .28211 m .76165 .28649 L .76285 .28427 L closepath p F P
0 g
s
.776 .605 .667 r
.34552 .40977 m .34469 .40956 L .34501 .41067 L closepath p F P
0 g
s
.531 .312 .528 r
.50554 .38895 m .50554 .38451 L .49555 .38826 L p F P
0 g
s
.531 .312 .528 r
.49555 .38826 m .49554 .3927 L .50554 .38895 L p F P
0 g
s
0 0 0 r
.58572 .30085 m .58445 .30221 L .58537 .30127 L closepath p F P
0 g
s
0 0 .34 r
.77433 .25155 m .77217 .25661 L .77217 .25221 L p F P
0 g
s
0 0 .34 r
.77217 .25221 m .77434 .24714 L .77433 .25155 L p F P
0 g
s
.758 .609 .693 r
.34501 .41067 m .34133 .41565 L .34705 .41679 L closepath p F P
0 g
s
.748 .642 .743 r
.33477 .42193 m .33557 .42326 L p .34705 .41679 L F P
0 g
s
.748 .642 .743 r
.34705 .41679 m .34133 .41565 L .33477 .42193 L p F P
0 g
s
.673 .809 .948 r
.55704 .42169 m .5468 .42551 L .54413 .42312 L p F P
0 g
s
.669 .802 .946 r
.53391 .42677 m .54413 .42312 L .5468 .42551 L p F P
0 g
s
.784 .979 .704 r
.73743 .32369 m .73626 .32425 L .73932 .32071 L closepath p F P
0 g
s
0 0 0 r
.58375 .30338 m .57852 .30869 L .58445 .30221 L p F P
0 g
s
0 0 0 r
.58445 .30221 m .58537 .30127 L .58375 .30338 L p F P
0 g
s
.656 .613 .794 r
.47953 .42166 m .4806 .42388 L .49124 .42098 L p F P
0 g
s
.659 .638 .818 r
.49244 .42326 m .49124 .42098 L .4806 .42388 L p F P
0 g
s
.765 .606 .681 r
.34133 .41565 m .34501 .41067 L .34469 .40956 L p F P
0 g
s
.765 .606 .681 r
.33435 .41383 m .34133 .41565 L p .34469 .40956 L F P
0 g
s
.765 .606 .681 r
.34469 .40956 m .3381 .4081 L .33435 .41383 L p F P
0 g
s
.702 .892 .966 r
.60341 .40794 m .60595 .40938 L .59566 .41417 L p F P
0 g
s
.702 .892 .966 r
.5947 .41198 m .60341 .40794 L p .59566 .41417 L F P
0 g
s
.702 .892 .966 r
.59566 .41417 m .59339 .41288 L .5947 .41198 L p F P
0 g
s
.665 .742 .907 r
.5081 .42786 m .51828 .42439 L .521 .42756 L p F P
0 g
s
.662 .707 .881 r
.51828 .42439 m .5081 .42786 L .50536 .42414 L p F P
0 g
s
0 0 .099 r
.76983 .26761 m .76812 .27113 L .76929 .2663 L p F P
0 g
s
0 0 .099 r
.76929 .2663 m .77023 .26439 L .76983 .26761 L p F P
0 g
s
.552 .596 .852 r
.74903 .19605 m .7597 .19568 L .75796 .20071 L p F P
0 g
s
.546 .619 .876 r
.74672 .19189 m .74903 .19605 L .7597 .19568 L p F P
0 g
s
.711 .217 0 r
.22891 .29711 m .23005 .29871 L .23339 .30203 L p F P
0 g
s
.728 .236 0 r
.23237 .30205 m .23572 .30537 L .23339 .30203 L p F P
0 g
s
.728 .236 0 r
.23339 .30203 m .23005 .29871 L .23237 .30205 L p F P
0 g
s
.813 .549 .539 r
.31514 .39023 m .3213 .39237 L .32151 .38792 L p F P
0 g
s
.813 .549 .539 r
.32151 .38792 m .31536 .38578 L .31514 .39023 L p F P
0 g
s
.309 .335 .726 r
.77019 .22116 m .77128 .22206 L .77087 .22329 L closepath p F P
0 g
s
.243 .263 .683 r
.77413 .22541 m .77268 .22973 L .77087 .22329 L p F P
0 g
s
.243 .263 .683 r
.77087 .22329 m .77128 .22206 L .77413 .22541 L p F P
0 g
s
.284 .333 .736 r
.76838 .21583 m .77019 .22116 L .77128 .22206 L p F P
0 g
s
.231 0 .244 r
.53781 .35391 m .53547 .35541 L .53631 .3521 L p F P
0 g
s
.231 0 .244 r
.53631 .3521 m .54352 .34748 L .53781 .35391 L p F P
0 g
s
.838 .371 .013 r
.25119 .32169 m .25023 .31998 L .24703 .31775 L p F P
0 g
s
.851 .403 .142 r
.26477 .33847 m .26294 .33487 L .26724 .33776 L p F P
0 g
s
.851 .403 .142 r
.26625 .33944 m .26477 .33847 L p .26724 .33776 L F P
0 g
s
.851 .403 .142 r
.26724 .33776 m .26841 .33998 L .26625 .33944 L p F P
0 g
s
.211 .207 .635 r
.77243 .23035 m .77268 .22973 L .77307 .23138 L closepath p F P
0 g
s
.78 .837 .895 r
.69747 .19977 m .69457 .20172 L .69555 .1978 L closepath p F P
0 g
s
.783 .862 .909 r
.69507 .19731 m .69555 .1978 L .69457 .20172 L p F P
0 g
s
.783 .862 .909 r
.68478 .20451 m .69507 .19731 L p .69457 .20172 L F P
0 g
s
.857 .519 .411 r
.2925 .36781 m .29764 .37035 L .29672 .36635 L p F P
0 g
s
.857 .519 .411 r
.29672 .36635 m .29165 .36379 L .2925 .36781 L p F P
0 g
s
.668 .781 .933 r
.54413 .42312 m .53391 .42677 L .53121 .42404 L p F P
0 g
s
.666 .774 .93 r
.521 .42756 m .53121 .42404 L .53391 .42677 L p F P
0 g
s
.664 .746 .911 r
.53121 .42404 m .521 .42756 L .51828 .42439 L p F P
0 g
s
.65 .533 .708 r
.47678 .41408 m .47258 .41639 L .47716 .41539 L closepath p F P
0 g
s
.828 1 .813 r
.6246 .2589 m .62372 .25904 L .62588 .25685 L closepath p F P
0 g
s
.501 .714 .967 r
.23528 .41314 m .23845 .41597 L .23031 .41632 L p F P
0 g
s
.501 .714 .967 r
.22575 .41363 m .23528 .41314 L p .23031 .41632 L F P
0 g
s
.501 .714 .967 r
.23031 .41632 m .22597 .41383 L .22575 .41363 L p F P
0 g
s
.377 .414 .773 r
.76751 .21349 m .76888 .21421 L .76838 .21583 L closepath p F P
0 g
s
.284 .333 .736 r
.77284 .21714 m .76888 .21421 L .76838 .21583 L p F P
0 g
s
.284 .333 .736 r
.77128 .22206 m .77284 .21714 L p .76838 .21583 L F P
0 g
s
.625 .491 .679 r
.48692 .40917 m .48628 .40621 L .47563 .40912 L p F P
0 g
s
.625 .491 .679 r
.47563 .40912 m .47678 .41408 L .48692 .40917 L p F P
0 g
s
.181 .522 .919 r
.14702 .37787 m .14495 .37722 L .14835 .38044 L p F P
0 g
s
.181 .522 .919 r
.14835 .38044 m .1503 .38106 L .14702 .37787 L p F P
0 g
s
.479 .243 .478 r
.51519 .38031 m .51543 .37619 L .50578 .38038 L p F P
0 g
s
.479 .243 .478 r
.50578 .38038 m .50554 .38451 L .51519 .38031 L p F P
0 g
s
.754 .976 .92 r
.67509 .37687 m .66992 .38037 L .67366 .37659 L closepath p F P
0 g
s
.755 .968 .93 r
.67273 .37633 m .67366 .37659 L .66992 .38037 L p F P
0 g
s
.755 .968 .93 r
.66243 .38311 m .67273 .37633 L p .66992 .38037 L F P
0 g
s
.797 .999 .827 r
.71757 .34452 m .71603 .34468 L .72035 .34067 L closepath p F P
0 g
s
.729 .677 .799 r
.33477 .42193 m .33343 .42284 L .33557 .42326 L closepath p F P
0 g
s
0 0 0 r
.58326 .30407 m .58375 .30338 L .57852 .30869 L p F P
0 g
s
0 0 0 r
.57961 .30837 m .58326 .30407 L p .57852 .30869 L F P
0 g
s
0 0 0 r
.57489 .31312 m .57961 .30837 L p .57852 .30869 L F P
0 g
s
0 0 0 r
.57852 .30869 m .5756 .31194 L .57489 .31312 L p F P
0 g
s
.645 .567 .752 r
.47716 .41539 m .47953 .42166 L .48968 .41758 L p F P
0 g
s
.656 .613 .794 r
.49124 .42098 m .48968 .41758 L .47953 .42166 L p F P
0 g
s
.85 .478 .346 r
.28862 .35877 m .2866 .36027 L .2856 .35725 L closepath p F P
0 g
s
.766 .834 .905 r
.70542 .1908 m .70781 .19355 L .69747 .19977 L p F P
0 g
s
.766 .834 .905 r
.69593 .19678 m .70542 .1908 L p .69747 .19977 L F P
0 g
s
.766 .834 .905 r
.69747 .19977 m .69555 .1978 L .69593 .19678 L p F P
0 g
s
.747 .251 0 r
.23804 .30873 m .24156 .31197 L .23921 .30862 L p F P
0 g
s
.747 .251 0 r
.23921 .30862 m .23572 .30537 L .23804 .30873 L p F P
0 g
s
.36 .418 .786 r
.76493 .20694 m .76751 .21349 L .76888 .21421 L p F P
0 g
s
.72 .954 .667 r
.60486 .27992 m .60349 .28082 L .60737 .27656 L closepath p F P
0 g
s
.607 .737 .937 r
.27027 .42477 m .28 .42257 L .28308 .42556 L p F P
0 g
s
.618 .735 .93 r
.28 .42257 m .27027 .42477 L .26715 .42191 L p F P
0 g
s
.739 .925 .573 r
.74753 .3092 m .75187 .30324 L .74878 .30852 L p F P
0 g
s
.739 .925 .573 r
.74553 .31266 m .74753 .3092 L p .74878 .30852 L F P
0 g
s
.739 .925 .573 r
.74878 .30852 m .74622 .31203 L .74553 .31266 L p F P
0 g
s
.109 .137 .609 r
.77615 .22906 m .77413 .22541 L .77268 .22973 L p F P
0 g
s
.109 .137 .609 r
.77445 .23401 m .77615 .22906 L p .77268 .22973 L F P
0 g
s
.109 .137 .609 r
.77268 .22973 m .77307 .23138 L .77445 .23401 L p F P
0 g
s
.81 .573 .579 r
.32588 .39874 m .32688 .39909 L .32772 .39441 L p F P
0 g
s
.81 .573 .579 r
.32772 .39441 m .32549 .39364 L .32588 .39874 L p F P
0 g
s
.88 .48 .262 r
.27038 .34517 m .27476 .34803 L .2733 .34427 L p F P
0 g
s
.88 .48 .262 r
.2733 .34427 m .26899 .34139 L .27038 .34517 L p F P
0 g
s
.739 .939 .951 r
.64481 .39379 m .64183 .39551 L .63938 .39453 L p F P
0 g
s
.719 .919 .961 r
.62658 .39902 m .62907 .40022 L .61877 .40556 L p F P
0 g
s
.719 .919 .961 r
.6169 .40406 m .62658 .39902 L p .61877 .40556 L F P
0 g
s
.719 .919 .961 r
.61877 .40556 m .6164 .40445 L .6169 .40406 L p F P
0 g
s
0 0 0 r
.58491 .30209 m .58375 .30338 L .58537 .30127 L p F P
0 g
s
0 0 0 r
.58537 .30127 m .59033 .29578 L .58491 .30209 L p F P
0 g
s
.572 .739 .955 r
.25435 .42067 m .25489 .42058 L .26023 .42299 L p F P
0 g
s
.568 .729 .95 r
.26403 .41899 m .25489 .42058 L .26023 .42299 L p F P
0 g
s
.568 .729 .95 r
.26023 .42299 m .26715 .42191 L .26403 .41899 L p F P
0 g
s
.437 .684 .968 r
.21312 .41064 m .22142 .41079 L .22567 .41363 L p F P
0 g
s
.444 .684 .967 r
.22142 .41079 m .21312 .41064 L .20991 .40782 L p F P
0 g
s
.841 .947 .889 r
.65437 .22961 m .65414 .22951 L .6546 .22911 L closepath p F P
0 g
s
.679 .829 .955 r
.56732 .41772 m .5677 .41802 L .5586 .42292 L p F P
0 g
s
.679 .829 .955 r
.5586 .42292 m .55704 .42169 L .56732 .41772 L p F P
0 g
s
0 0 0 r
.5756 .31194 m .57261 .31518 L .57489 .31312 L closepath p F P
0 g
s
.841 .524 .451 r
.29828 .37446 m .30381 .37685 L .3031 .37276 L p F P
0 g
s
.841 .524 .451 r
.3031 .37276 m .29764 .37035 L .29828 .37446 L p F P
0 g
s
.745 .67 .778 r
.33343 .42284 m .33477 .42193 L .33187 .41661 L p F P
0 g
s
.745 .67 .778 r
.33187 .41661 m .32626 .42109 L .33343 .42284 L p F P
0 g
s
.727 .72 .843 r
.32179 .42404 m .32626 .42109 L .33343 .42284 L p F P
0 g
s
.765 .672 .761 r
.33187 .41661 m .33435 .41383 L .34133 .41565 L p F P
0 g
s
.765 .672 .761 r
.34133 .41565 m .33477 .42193 L .33187 .41661 L p F P
0 g
s
0 0 0 r
.56578 .32251 m .56548 .32311 L .56676 .32164 L closepath p F P
0 g
s
.511 .55 .833 r
.75987 .19568 m .7597 .19568 L .75796 .20071 L p F P
0 g
s
.511 .55 .833 r
.75796 .20071 m .76238 .20111 L .75987 .19568 L p F P
0 g
s
.153 .158 .61 r
.77307 .23138 m .77445 .23401 L .77396 .23537 L closepath p F P
0 g
s
.638 .526 .71 r
.48785 .41254 m .48692 .40917 L .47678 .41408 L p F P
0 g
s
.638 .526 .71 r
.47678 .41408 m .47716 .41539 L .48785 .41254 L p F P
0 g
s
.8 .591 .619 r
.32716 .40482 m .33134 .4062 L .33325 .40113 L p F P
0 g
s
.8 .591 .619 r
.32629 .40088 m .32716 .40482 L p .33325 .40113 L F P
0 g
s
.8 .591 .619 r
.33325 .40113 m .32688 .39909 L .32629 .40088 L p F P
0 g
s
.764 .978 .916 r
.68276 .3715 m .67509 .37687 L .67366 .37659 L p F P
0 g
s
0 0 0 r
.57348 .31556 m .56676 .32164 L .57261 .31518 L p F P
0 g
s
0 0 0 r
.57261 .31518 m .57489 .31312 L .57348 .31556 L p F P
0 g
s
.247 .271 .69 r
.7758 .22045 m .77413 .22541 L .77128 .22206 L p F P
0 g
s
.247 .271 .69 r
.77128 .22206 m .77284 .21714 L .7758 .22045 L p F P
0 g
s
.762 .262 0 r
.24383 .31527 m .24156 .31197 L .24521 .31515 L p F P
0 g
s
.762 .262 0 r
.24521 .31515 m .24703 .31775 L .24383 .31527 L p F P
0 g
s
0 0 0 r
.76168 .28668 m .75888 .2919 L .76165 .28649 L p F P
0 g
s
0 0 0 r
.76181 .28643 m .76168 .28668 L p .76165 .28649 L F P
0 g
s
0 0 0 r
.76165 .28649 m .76285 .28427 L .76181 .28643 L p F P
0 g
s
.645 .567 .752 r
.48968 .41758 m .48785 .41254 L .47716 .41539 L p F P
0 g
s
.839 .954 .889 r
.6546 .22911 m .65414 .22951 L .65173 .22859 L p F P
0 g
s
.861 .969 .864 r
.64689 .23624 m .65414 .22951 L .65173 .22859 L p F P
0 g
s
.846 .926 .883 r
.65699 .22382 m .6546 .22911 L .66312 .2217 L p F P
0 g
s
.839 .954 .889 r
.65173 .22859 m .65699 .22382 L .6546 .22911 L p F P
0 g
s
.686 .862 .966 r
.56994 .41968 m .58022 .41543 L .58282 .41718 L p F P
0 g
s
.693 .867 .964 r
.5931 .41271 m .58282 .41718 L .58022 .41543 L p F P
0 g
s
.861 .969 .864 r
.65173 .22859 m .6493 .23095 L .64689 .23624 L p F P
0 g
s
.846 .976 .873 r
.64207 .23791 m .6493 .23095 L .64689 .23624 L p F P
0 g
s
.846 .976 .873 r
.64181 .23843 m .64207 .23791 L p .64689 .23624 L F P
0 g
s
.846 .976 .873 r
.64689 .23624 m .64399 .23891 L .64181 .23843 L p F P
0 g
s
.86 .973 .862 r
.64399 .23891 m .63955 .24323 L .64181 .23843 L closepath p F P
0 g
s
.738 .952 .946 r
.65213 .38944 m .64481 .39379 L .65031 .38884 L closepath p F P
0 g
s
.739 .939 .951 r
.6497 .38859 m .65031 .38884 L .64481 .39379 L p F P
0 g
s
.739 .939 .951 r
.63938 .39453 m .6497 .38859 L p .64481 .39379 L F P
0 g
s
.416 .165 .423 r
.52491 .37003 m .52517 .36765 L .51586 .3723 L p F P
0 g
s
.416 .165 .423 r
.5229 .37244 m .52491 .37003 L p .51586 .3723 L F P
0 g
s
.416 .165 .423 r
.51586 .3723 m .51543 .37619 L .5229 .37244 L p F P
0 g
s
.873 .485 .303 r
.27607 .35186 m .28071 .3546 L .27933 .35081 L p F P
0 g
s
.873 .485 .303 r
.27933 .35081 m .27476 .34803 L .27607 .35186 L p F P
0 g
s
.781 .614 .673 r
.32986 .41242 m .33435 .41383 L .3381 .4081 L p F P
0 g
s
.781 .614 .673 r
.32901 .41025 m .32986 .41242 L p .3381 .4081 L F P
0 g
s
.781 .614 .673 r
.3381 .4081 m .33134 .4062 L .32901 .41025 L p F P
0 g
s
.525 .719 .961 r
.25358 .41998 m .25435 .42067 L p .24162 .41874 L F P
0 g
s
.525 .719 .961 r
.24162 .41874 m .25014 .41794 L .25358 .41998 L p F P
0 g
s
.533 .719 .959 r
.25014 .41794 m .24162 .41874 L .23845 .41597 L p F P
0 g
s
.719 .92 .572 r
.74622 .31203 m .74436 .31451 L .74553 .31266 L closepath p F P
0 g
s
.694 .205 0 r
.23005 .29871 m .22891 .29711 L .22575 .29381 L p F P
0 g
s
.594 .429 .627 r
.49661 .40289 m .49585 .39753 L .48552 .40084 L p F P
0 g
s
.594 .429 .627 r
.48552 .40084 m .48628 .40621 L .49661 .40289 L p F P
0 g
s
.841 .993 .848 r
.64157 .23839 m .64181 .23843 L .63955 .24323 L p F P
0 g
s
.841 .993 .848 r
.63546 .24464 m .64157 .23839 L p .63955 .24323 L F P
0 g
s
.841 .993 .848 r
.63323 .24873 m .63546 .24464 L p .63955 .24323 L F P
0 g
s
.841 .993 .848 r
.63955 .24323 m .63385 .24875 L .63323 .24873 L p F P
0 g
s
.798 .564 .584 r
.32035 .39708 m .32588 .39874 L .32549 .39364 L p F P
0 g
s
.798 .564 .584 r
.32549 .39364 m .3213 .39237 L .32035 .39708 L p F P
0 g
s
.653 .693 .875 r
.74416 .18751 m .73354 .19047 L .73113 .18686 L p F P
0 g
s
.688 .731 .883 r
.72063 .19121 m .73113 .18686 L .73354 .19047 L p F P
0 g
s
.639 .678 .871 r
.73354 .19047 m .74416 .18751 L .74659 .19166 L p F P
0 g
s
.7 .743 .885 r
.73113 .18686 m .72063 .19121 L .71823 .18804 L p F P
0 g
s
.336 .628 .959 r
.18159 .39733 m .18481 .39777 L .1887 .40077 L p F P
0 g
s
.351 .635 .96 r
.19086 .3985 m .18481 .39777 L .1887 .40077 L p F P
0 g
s
.351 .635 .96 r
.1887 .40077 m .1941 .40144 L .19086 .3985 L p F P
0 g
s
.844 .924 .884 r
.66432 .22064 m .66312 .2217 L .66365 .22026 L closepath p F P
0 g
s
.846 .926 .883 r
.66192 .21931 m .65699 .22382 L p .66312 .2217 L F P
0 g
s
.846 .926 .883 r
.66312 .2217 m .66365 .22026 L .66192 .21931 L p F P
0 g
s
.829 .925 .898 r
.67252 .21395 m .66432 .22064 L .66365 .22026 L p F P
0 g
s
.128 0 .156 r
.54593 .34343 m .54521 .34572 L .54925 .34104 L closepath p F P
0 g
s
.646 .734 .913 r
.28308 .42556 m .29289 .42255 L .29595 .42576 L p F P
0 g
s
.659 .731 .902 r
.29289 .42255 m .28308 .42556 L .28 .42257 L p F P
0 g
s
.843 .549 .492 r
.3056 .38168 m .30964 .38348 L .3094 .37921 L p F P
0 g
s
.843 .549 .492 r
.3094 .37921 m .30645 .3779 L .3056 .38168 L p F P
0 g
s
.855 .992 .839 r
.63385 .24875 m .6325 .25012 L .63323 .24873 L closepath p F P
0 g
s
.727 .926 .958 r
.62986 .40057 m .62907 .40022 L .63247 .39838 L closepath p F P
0 g
s
0 0 .452 r
.77529 .24488 m .77434 .24714 L .77372 .24297 L p F P
0 g
s
0 0 .452 r
.77372 .24297 m .77481 .24039 L .77529 .24488 L p F P
0 g
s
.389 .66 .966 r
.19733 .40431 m .20204 .40467 L .20613 .40758 L p F P
0 g
s
.396 .659 .965 r
.20204 .40467 m .19733 .40431 L .1941 .40144 L p F P
0 g
s
.855 .993 .834 r
.62901 .25132 m .62588 .25685 L .6325 .25012 L p F P
0 g
s
.855 .993 .834 r
.63143 .24874 m .62901 .25132 L p .6325 .25012 L F P
0 g
s
.855 .993 .834 r
.6325 .25012 m .63323 .24873 L .63143 .24874 L p F P
0 g
s
.28 .592 .947 r
.1659 .3896 m .16923 .39027 L .17291 .39337 L p F P
0 g
s
.299 .601 .95 r
.17508 .39134 m .16923 .39027 L .17291 .39337 L p F P
0 g
s
.299 .601 .95 r
.17291 .39337 m .17834 .39437 L .17508 .39134 L p F P
0 g
s
0 0 .076 r
.77052 .26601 m .76983 .26761 L .77023 .26439 L p F P
0 g
s
0 0 .076 r
.77023 .26439 m .7716 .26121 L .77052 .26601 L p F P
0 g
s
.838 .371 .013 r
.24703 .31775 m .24747 .31855 L .25119 .32169 L p F P
0 g
s
.854 .397 .054 r
.24929 .32212 m .25305 .32525 L .25119 .32169 L p F P
0 g
s
.854 .397 .054 r
.25119 .32169 m .24747 .31855 L .24929 .32212 L p F P
0 g
s
.765 .962 .659 r
.74268 .31535 m .73932 .32071 L .74436 .31451 L p F P
0 g
s
.765 .962 .659 r
.74417 .3135 m .74268 .31535 L p .74436 .31451 L F P
0 g
s
.765 .962 .659 r
.74436 .31451 m .74553 .31266 L .74417 .3135 L p F P
0 g
s
.36 .418 .786 r
.76888 .21421 m .77033 .20931 L p .76493 .20694 L F P
0 g
s
.331 .367 .748 r
.77446 .21219 m .77284 .21714 L .76888 .21421 L p F P
0 g
s
.331 .367 .748 r
.76888 .21421 m .77033 .20931 L .77446 .21219 L p F P
0 g
s
0 0 0 r
.57313 .31623 m .57348 .31556 L .56676 .32164 L p F P
0 g
s
0 0 0 r
.56935 .32082 m .57313 .31623 L p .56676 .32164 L F P
0 g
s
0 0 0 r
.56453 .32519 m .56935 .32082 L p .56676 .32164 L F P
0 g
s
0 0 0 r
.56676 .32164 m .56548 .32311 L .56453 .32519 L p F P
0 g
s
.4 .663 .966 r
.20669 .40495 m .20204 .40467 L .20613 .40758 L p F P
0 g
s
.4 .663 .966 r
.20613 .40758 m .20991 .40782 L .20669 .40495 L p F P
0 g
s
.435 .48 .808 r
.76492 .20691 m .76494 .20691 L .76493 .20694 L closepath p F P
0 g
s
.36 .418 .786 r
.77033 .20931 m .76494 .20691 L .76493 .20694 L p F P
0 g
s
.451 .501 .819 r
.76494 .20691 m .76492 .20691 L .76238 .20111 L p F P
0 g
s
.66 .667 .845 r
.49244 .42326 m .50261 .41968 L .50536 .42414 L p F P
0 g
s
.653 .629 .814 r
.49124 .42098 m .49244 .42326 L .50261 .41968 L p F P
0 g
s
.451 .501 .819 r
.76238 .20111 m .76618 .20207 L .76494 .20691 L p F P
0 g
s
.403 .451 .796 r
.77186 .20437 m .77033 .20931 L .76494 .20691 L p F P
0 g
s
.403 .451 .796 r
.76494 .20691 m .76618 .20207 L .77186 .20437 L p F P
0 g
s
.222 .55 .931 r
.1503 .38106 m .15492 .3823 L .15842 .38549 L p F P
0 g
s
.229 .55 .931 r
.15492 .3823 m .1503 .38106 L .14702 .37787 L p F P
0 g
s
.739 .71 .824 r
.32626 .42109 m .32179 .42404 L .31882 .41993 L p F P
0 g
s
.711 .702 .839 r
.30885 .42528 m .31882 .41993 L .32179 .42404 L p F P
0 g
s
0 0 0 r
.56548 .32311 m .56089 .32812 L .56453 .32519 L closepath p F P
0 g
s
.858 .482 .336 r
.28193 .35848 m .28071 .3546 L .2856 .35725 L p F P
0 g
s
.858 .482 .336 r
.286 .36064 m .28193 .35848 L p .2856 .35725 L F P
0 g
s
.858 .482 .336 r
.2856 .35725 m .2866 .36027 L .286 .36064 L p F P
0 g
s
.829 .898 .889 r
.67453 .2123 m .67252 .21395 L .67333 .21143 L closepath p F P
0 g
s
.829 .925 .898 r
.67213 .21058 m .67333 .21143 L .67252 .21395 L p F P
0 g
s
.829 .925 .898 r
.66524 .21649 m .67213 .21058 L p .67252 .21395 L F P
0 g
s
.829 .925 .898 r
.66365 .22026 m .66524 .21649 L p .67252 .21395 L F P
0 g
s
.054 .049 .532 r
.77569 .23795 m .77481 .24039 L .77396 .23537 L p F P
0 g
s
.054 .049 .532 r
.77396 .23537 m .77445 .23401 L .77569 .23795 L p F P
0 g
s
.764 .985 .904 r
.68535 .36962 m .68276 .3715 L .68459 .36952 L closepath p F P
0 g
s
.764 .978 .916 r
.68302 .36917 m .68459 .36952 L .68276 .3715 L p F P
0 g
s
.764 .978 .916 r
.67581 .37424 m .68302 .36917 L p .68276 .3715 L F P
0 g
s
.764 .978 .916 r
.67366 .37659 m .67581 .37424 L p .68276 .3715 L F P
0 g
s
.696 .717 .865 r
.30583 .42171 m .29595 .42576 L .29289 .42255 L p F P
0 g
s
.682 .722 .88 r
.29595 .42576 m .30583 .42171 L .30885 .42528 L p F P
0 g
s
.818 1 .803 r
.62286 .2579 m .62901 .25132 L .62588 .25685 L p F P
0 g
s
.818 1 .803 r
.62195 .25941 m .62286 .2579 L p .62588 .25685 L F P
0 g
s
.818 1 .803 r
.62588 .25685 m .62372 .25904 L .62195 .25941 L p F P
0 g
s
.812 .897 .902 r
.68314 .20577 m .67453 .2123 L .67333 .21143 L p F P
0 g
s
.829 .563 .536 r
.30941 .38793 m .31514 .39023 L .31536 .38578 L p F P
0 g
s
.829 .563 .536 r
.31536 .38578 m .30964 .38348 L .30941 .38793 L p F P
0 g
s
0 0 0 r
.76893 .271 m .76643 .27614 L .76812 .27113 L p F P
0 g
s
0 0 0 r
.76934 .26976 m .76893 .271 L p .76812 .27113 L F P
0 g
s
0 0 0 r
.76812 .27113 m .76983 .26761 L .76934 .26976 L p F P
0 g
s
.878 .458 .207 r
.26841 .33998 m .26899 .34139 L .26625 .33944 L closepath p F P
0 g
s
.833 .999 .797 r
.62372 .25904 m .61952 .26349 L .62195 .25941 L closepath p F P
0 g
s
.343 .628 .958 r
.18481 .39777 m .18159 .39733 L .17834 .39437 L p F P
0 g
s
.725 .699 .825 r
.30885 .42528 m .31882 .41993 L .31752 .41802 L p F P
0 g
s
.725 .699 .825 r
.30583 .42171 m .30885 .42528 L p .31752 .41802 L F P
0 g
s
.86 .409 .096 r
.25485 .32885 m .25881 .3319 L .25696 .32832 L p F P
0 g
s
.86 .409 .096 r
.25696 .32832 m .25305 .32525 L .25485 .32885 L p F P
0 g
s
.686 .845 .959 r
.57761 .41354 m .58022 .41543 L .56994 .41968 L p F P
0 g
s
.686 .845 .959 r
.57012 .4166 m .57761 .41354 L p .56994 .41968 L F P
0 g
s
.686 .845 .959 r
.56994 .41968 m .5677 .41802 L .57012 .4166 L p F P
0 g
s
0 0 .206 r
.77375 .25617 m .7716 .26121 L .77217 .25661 L p F P
0 g
s
0 0 .206 r
.77217 .25661 m .77433 .25155 L .77375 .25617 L p F P
0 g
s
.287 .591 .946 r
.16923 .39027 m .1659 .3896 L .16264 .38653 L p F P
0 g
s
.774 .986 .899 r
.69394 .36318 m .68535 .36962 L .68459 .36952 L p F P
0 g
s
.554 .362 .576 r
.50587 .39379 m .50554 .38895 L .49554 .3927 L p F P
0 g
s
.554 .362 .576 r
.49554 .3927 m .49585 .39753 L .50587 .39379 L p F P
0 g
s
.345 .079 .36 r
.52721 .36649 m .52517 .36765 L .52576 .36399 L p F P
0 g
s
.345 .079 .36 r
.52576 .36399 m .53229 .36027 L .52721 .36649 L p F P
0 g
s
.245 .563 .936 r
.15936 .3834 m .15492 .3823 L .15842 .38549 L p F P
0 g
s
.245 .563 .936 r
.15842 .38549 m .16264 .38653 L .15936 .3834 L p F P
0 g
s
.025 0 .052 r
.56334 .32796 m .56453 .32519 L .56089 .32812 L p F P
0 g
s
.025 0 .052 r
.55531 .33443 m .56334 .32796 L p .56089 .32812 L F P
0 g
s
.025 0 .052 r
.56089 .32812 m .55535 .33433 L .55531 .33443 L p F P
0 g
s
.734 .805 .908 r
.71391 .19034 m .70781 .19355 L .70542 .1908 L p F P
0 g
s
.584 .643 .875 r
.74659 .19166 m .74677 .19164 L .74672 .19189 L closepath p F P
0 g
s
.546 .619 .876 r
.75739 .1907 m .74677 .19164 L .74672 .19189 L p F P
0 g
s
.546 .619 .876 r
.75977 .19547 m .75739 .1907 L p .74672 .19189 L F P
0 g
s
.546 .619 .876 r
.7597 .19568 m .75977 .19547 L p .74672 .19189 L F P
0 g
s
.711 .897 .964 r
.61626 .40438 m .60595 .40938 L .60341 .40794 L p F P
0 g
s
.773 .986 .741 r
.6213 .25957 m .62195 .25941 L .61952 .26349 L p F P
0 g
s
.773 .986 .741 r
.61702 .26436 m .6213 .25957 L p .61952 .26349 L F P
0 g
s
.773 .986 .741 r
.61347 .26978 m .61702 .26436 L p .61952 .26349 L F P
0 g
s
.773 .986 .741 r
.61952 .26349 m .6136 .26972 L .61347 .26978 L p F P
0 g
s
.87 .532 .408 r
.28762 .36517 m .2925 .36781 L .29165 .36379 L p F P
0 g
s
.87 .532 .408 r
.29165 .36379 m .28683 .36112 L .28762 .36517 L p F P
0 g
s
.754 .658 .755 r
.32626 .42109 m .33187 .41661 L .32986 .41242 L p F P
0 g
s
.754 .658 .755 r
.32007 .419 m .32626 .42109 L p .32986 .41242 L F P
0 g
s
.739 .71 .824 r
.31882 .41993 m .32007 .419 L .32626 .42109 L p F P
0 g
s
.747 .953 .943 r
.66178 .38352 m .65213 .38944 L .65031 .38884 L p F P
0 g
s
.598 .658 .88 r
.74677 .19164 m .74659 .19166 L .74416 .18751 L p F P
0 g
s
.73 .895 .508 r
.75472 .29922 m .75406 .29996 L .75567 .29746 L closepath p F P
0 g
s
.786 .979 .706 r
.73715 .32174 m .74268 .31535 L .73932 .32071 L p F P
0 g
s
.786 .979 .706 r
.73532 .3247 m .73715 .32174 L p .73932 .32071 L F P
0 g
s
.786 .979 .706 r
.73932 .32071 m .73626 .32425 L .73532 .3247 L p F P
0 g
s
.81 .575 .582 r
.31425 .39493 m .32035 .39708 L .3213 .39237 L p F P
0 g
s
.81 .575 .582 r
.3213 .39237 m .31514 .39023 L .31425 .39493 L p F P
0 g
s
.772 .657 .736 r
.33435 .41383 m .32986 .41242 L .33187 .41661 L closepath p F P
0 g
s
.44 .688 .97 r
.22597 .41383 m .22575 .41363 L .22567 .41363 L closepath p F P
0 g
s
.647 .601 .788 r
.48968 .41758 m .49124 .42098 L .50157 .41768 L p F P
0 g
s
.653 .629 .814 r
.50261 .41968 m .50157 .41768 L .49124 .42098 L p F P
0 g
s
.598 .658 .88 r
.74416 .18751 m .74747 .18695 L .74677 .19164 L p F P
0 g
s
.571 .615 .857 r
.75493 .18595 m .74747 .18695 L .74677 .19164 L p F P
0 g
s
.571 .615 .857 r
.74677 .19164 m .75739 .1907 L .75493 .18595 L p F P
0 g
s
.837 .927 .891 r
.66365 .22026 m .66192 .21931 L .66524 .21649 L closepath p F P
0 g
s
.803 .998 .795 r
.72665 .33492 m .72618 .33501 L .72744 .33375 L closepath p F P
0 g
s
.678 .84 .419 r
.7584 .29228 m .75567 .29746 L .75888 .2919 L p F P
0 g
s
.678 .84 .419 r
.75888 .2919 m .76168 .28668 L .7584 .29228 L p F P
0 g
s
.662 .707 .881 r
.50536 .42414 m .51555 .4207 L .51828 .42439 L p F P
0 g
s
.655 .667 .849 r
.51555 .4207 m .50536 .42414 L .50261 .41968 L p F P
0 g
s
.828 .533 .491 r
.30412 .38109 m .3056 .38168 L .30645 .3779 L p F P
0 g
s
.828 .533 .491 r
.30645 .3779 m .30381 .37685 L .30412 .38109 L p F P
0 g
s
.862 .419 .14 r
.26058 .33552 m .26477 .33847 L .26294 .33487 L p F P
0 g
s
.862 .419 .14 r
.26294 .33487 m .25881 .3319 L .26058 .33552 L p F P
0 g
s
.572 .739 .955 r
.25435 .42067 m .25489 .42058 L .25358 .41998 L closepath p F P
0 g
s
.443 .686 .968 r
.22256 .4108 m .22142 .41079 L .22567 .41363 L p F P
0 g
s
.443 .686 .968 r
.22567 .41363 m .22575 .41363 L .22256 .4108 L p F P
0 g
s
.811 .871 .892 r
.68478 .20451 m .68314 .20577 L .68373 .2036 L closepath p F P
0 g
s
.812 .897 .902 r
.68238 .20245 m .68373 .2036 L .68314 .20577 L p F P
0 g
s
.812 .897 .902 r
.67433 .20885 m .68238 .20245 L p .68314 .20577 L F P
0 g
s
.812 .897 .902 r
.67333 .21143 m .67433 .20885 L p .68314 .20577 L F P
0 g
s
.852 .993 .836 r
.63323 .24873 m .63143 .24874 L .63546 .24464 L closepath p F P
0 g
s
.498 .706 .963 r
.23528 .41314 m .22575 .41363 L .22256 .4108 L p F P
0 g
s
.787 .987 .739 r
.6136 .26972 m .61326 .27009 L .61347 .26978 L closepath p F P
0 g
s
.677 .817 .95 r
.56732 .41772 m .55704 .42169 L .55439 .41936 L p F P
0 g
s
.673 .809 .948 r
.54413 .42312 m .55439 .41936 L .55704 .42169 L p F P
0 g
s
.798 .87 .901 r
.69267 .19495 m .69507 .19731 L .68478 .20451 L p F P
0 g
s
.798 .87 .901 r
.68478 .20071 m .69267 .19495 L p .68478 .20451 L F P
0 g
s
.798 .87 .901 r
.68478 .20451 m .68373 .2036 L .68478 .20071 L p F P
0 g
s
0 0 0 r
.57443 .31461 m .57348 .31556 L .57489 .31312 L p F P
0 g
s
0 0 0 r
.57489 .31312 m .57961 .30837 L .57443 .31461 L p F P
0 g
s
.73 .921 .957 r
.63247 .39838 m .62907 .40022 L .62658 .39902 L p F P
0 g
s
.782 .984 .729 r
.61119 .27086 m .60737 .27656 L .61326 .27009 L p F P
0 g
s
.782 .984 .729 r
.61326 .27009 m .61347 .26978 L .61119 .27086 L p F P
0 g
s
.771 .977 .708 r
.73626 .32425 m .7337 .32712 L .73532 .3247 L closepath p F P
0 g
s
.066 0 .07 r
.55535 .33433 m .55513 .33456 L .55531 .33443 L closepath p F P
0 g
s
.806 .598 .621 r
.32688 .39909 m .32588 .39874 L .32629 .40088 L closepath p F P
0 g
s
.584 .74 .95 r
.2609 .416 m .26403 .41899 L .25489 .42058 L p F P
0 g
s
.584 .74 .95 r
.25121 .41783 m .2609 .416 L p .25489 .42058 L F P
0 g
s
.584 .74 .95 r
.25489 .42058 m .25358 .41998 L .25121 .41783 L p F P
0 g
s
.104 0 .122 r
.55429 .33744 m .54925 .34104 L .55513 .33456 L p F P
0 g
s
.104 0 .122 r
.55513 .33456 m .55531 .33443 L .55429 .33744 L p F P
0 g
s
.694 .205 0 r
.22575 .29381 m .22684 .29533 L .23005 .29871 L p F P
0 g
s
.712 .226 0 r
.22915 .29868 m .23237 .30205 L .23005 .29871 L p F P
0 g
s
.712 .226 0 r
.23005 .29871 m .22684 .29533 L .22915 .29868 L p F P
0 g
s
.611 .476 .673 r
.49709 .40515 m .49661 .40289 L .48628 .40621 L p F P
0 g
s
.611 .476 .673 r
.48628 .40621 m .48692 .40917 L .49709 .40515 L p F P
0 g
s
.791 .628 .679 r
.33134 .4062 m .32716 .40482 L .32901 .41025 L closepath p F P
0 g
s
.772 .992 .883 r
.69561 .36189 m .69394 .36318 L .69509 .36186 L closepath p F P
0 g
s
.774 .986 .899 r
.69331 .36157 m .69509 .36186 L .69394 .36318 L p F P
0 g
s
.774 .986 .899 r
.68796 .36558 m .69331 .36157 L p .69394 .36318 L F P
0 g
s
.774 .986 .899 r
.68459 .36952 m .68796 .36558 L p .69394 .36318 L F P
0 g
s
.855 .538 .449 r
.29307 .37194 m .29828 .37446 L .29764 .37035 L p F P
0 g
s
.855 .538 .449 r
.29764 .37035 m .2925 .36781 L .29307 .37194 L p F P
0 g
s
.606 .871 .536 r
.59419 .29147 m .59337 .29228 L .59587 .28942 L closepath p F P
0 g
s
0 0 0 r
.76285 .28427 m .76181 .28643 L .76428 .28133 L closepath p F P
0 g
s
.029 0 .09 r
.563 .32886 m .56334 .32796 L .55531 .33443 L p F P
0 g
s
.029 0 .09 r
.55962 .3331 m .563 .32886 L p .55531 .33443 L F P
0 g
s
.029 0 .09 r
.55531 .33443 m .55429 .33744 L .55962 .3331 L p F P
0 g
s
.784 .993 .879 r
.70378 .35533 m .69561 .36189 L .69509 .36186 L p F P
0 g
s
.049 .048 .534 r
.77743 .233 m .77569 .23795 L .77445 .23401 L p F P
0 g
s
.049 .048 .534 r
.77445 .23401 m .77615 .22906 L .77743 .233 L p F P
0 g
s
.504 .291 .524 r
.5152 .38476 m .51519 .38031 L .50554 .38451 L p F P
0 g
s
.504 .291 .524 r
.50554 .38451 m .50554 .38895 L .5152 .38476 L p F P
0 g
s
.789 .985 .728 r
.61123 .27081 m .61119 .27086 L .61347 .26978 L p F P
0 g
s
.789 .985 .728 r
.61347 .26978 m .61702 .26436 L .61123 .27081 L p F P
0 g
s
.796 .994 .767 r
.73103 .32833 m .72744 .33375 L .7337 .32712 L p F P
0 g
s
.796 .994 .767 r
.73413 .32504 m .73103 .32833 L p .7337 .32712 L F P
0 g
s
.796 .994 .767 r
.7337 .32712 m .73532 .3247 L .73413 .32504 L p F P
0 g
s
.664 .746 .911 r
.51828 .42439 m .5285 .42094 L .53121 .42404 L p F P
0 g
s
.659 .713 .887 r
.5285 .42094 m .51828 .42439 L .51555 .4207 L p F P
0 g
s
.889 .489 .257 r
.26619 .34224 m .27038 .34517 L .26899 .34139 L p F P
0 g
s
.889 .489 .257 r
.26514 .33928 m .26619 .34224 L p .26899 .34139 L F P
0 g
s
.889 .489 .257 r
.26899 .34139 m .26625 .33944 L .26514 .33928 L p F P
0 g
s
.792 .593 .632 r
.32487 .40419 m .32629 .40088 L .32588 .39874 L p F P
0 g
s
.792 .593 .632 r
.31838 .40218 m .32487 .40419 L p .32588 .39874 L F P
0 g
s
.792 .593 .632 r
.32588 .39874 m .32035 .39708 L .31838 .40218 L p F P
0 g
s
.189 .522 .918 r
.14373 .37461 m .14162 .37395 L .14495 .37722 L p F P
0 g
s
.189 .522 .918 r
.14495 .37722 m .14702 .37787 L .14373 .37461 L p F P
0 g
s
.671 .789 .937 r
.55439 .41936 m .54413 .42312 L .54145 .42046 L p F P
0 g
s
.668 .781 .933 r
.53121 .42404 m .54145 .42046 L .54413 .42312 L p F P
0 g
s
.788 .965 .657 r
.74553 .31266 m .74417 .3135 L .74753 .3092 L closepath p F P
0 g
s
.635 .555 .747 r
.48785 .41254 m .48968 .41758 L .49985 .41386 L p F P
0 g
s
.647 .601 .788 r
.50157 .41768 m .49985 .41386 L .48968 .41758 L p F P
0 g
s
.665 .754 .917 r
.54145 .42046 m .53121 .42404 L .5285 .42094 L p F P
0 g
s
.735 .244 0 r
.23467 .30542 m .23804 .30873 L .23572 .30537 L p F P
0 g
s
.735 .244 0 r
.23572 .30537 m .23237 .30205 L .23467 .30542 L p F P
0 g
s
.471 .519 .826 r
.76618 .20207 m .76238 .20111 L .75987 .19568 L p F P
0 g
s
.767 .837 .905 r
.69555 .1978 m .69507 .19731 L .69593 .19678 L closepath p F P
0 g
s
.701 .881 .965 r
.59339 .41288 m .5931 .41271 L .5947 .41198 L closepath p F P
0 g
s
.622 .509 .704 r
.4982 .40924 m .49709 .40515 L .48692 .40917 L p F P
0 g
s
.622 .509 .704 r
.48692 .40917 m .48785 .41254 L .4982 .40924 L p F P
0 g
s
.529 .72 .96 r
.25358 .41998 m .25121 .41783 L .25014 .41794 L closepath p F P
0 g
s
.688 .935 .636 r
.61117 .27088 m .61119 .27086 L .60737 .27656 L p F P
0 g
s
.688 .935 .636 r
.60584 .27711 m .61117 .27088 L p .60737 .27656 L F P
0 g
s
.688 .935 .636 r
.6028 .28133 m .60584 .27711 L p .60737 .27656 L F P
0 g
s
.688 .935 .636 r
.60737 .27656 m .60349 .28082 L .6028 .28133 L p F P
0 g
s
.263 0 .291 r
.53547 .35541 m .53506 .35733 L .53781 .35391 L closepath p F P
0 g
s
.168 0 .192 r
.55332 .34055 m .55429 .33744 L .54925 .34104 L p F P
0 g
s
.168 0 .192 r
.54497 .34656 m .55332 .34055 L p .54925 .34104 L F P
0 g
s
.168 0 .192 r
.54925 .34104 m .54521 .34572 L .54497 .34656 L p F P
0 g
s
.73 .935 .955 r
.63938 .39453 m .63247 .39838 L .63775 .39385 L closepath p F P
0 g
s
.73 .921 .957 r
.63691 .39346 m .63775 .39385 L .63247 .39838 L p F P
0 g
s
.73 .921 .957 r
.62658 .39902 m .63691 .39346 L p .63247 .39838 L F P
0 g
s
.839 .545 .492 r
.29853 .37872 m .30412 .38109 L .30381 .37685 L p F P
0 g
s
.839 .545 .492 r
.30381 .37685 m .29828 .37446 L .29853 .37872 L p F P
0 g
s
.784 .993 .879 r
.70357 .35346 m .70517 .35362 L .70378 .35533 L p F P
0 g
s
.784 .993 .879 r
.69864 .35743 m .70357 .35346 L p .70378 .35533 L F P
0 g
s
.784 .993 .879 r
.69509 .36186 m .69864 .35743 L p .70378 .35533 L F P
0 g
s
.78 .997 .86 r
.70584 .35361 m .70378 .35533 L .70517 .35362 L closepath p F P
0 g
s
.743 .794 .894 r
.71391 .19034 m .71823 .18804 L .71583 .18495 L p F P
0 g
s
.743 .794 .894 r
.71583 .18495 m .71471 .18558 L .71391 .19034 L p F P
0 g
s
.734 .805 .908 r
.70542 .1908 m .71471 .18558 L .71391 .19034 L p F P
0 g
s
.804 .999 .797 r
.72429 .33514 m .73103 .32833 L .72744 .33375 L p F P
0 g
s
.804 .999 .797 r
.72411 .33541 m .72429 .33514 L p .72744 .33375 L F P
0 g
s
.804 .999 .797 r
.72744 .33375 m .72618 .33501 L .72411 .33541 L p F P
0 g
s
.785 .592 .64 r
.32629 .40088 m .32487 .40419 L .32716 .40482 L closepath p F P
0 g
s
.835 .368 0 r
.24747 .31855 m .24703 .31775 L .24383 .31527 L p F P
0 g
s
.792 .997 .855 r
.71251 .34785 m .70584 .35361 L .70517 .35362 L p F P
0 g
s
.883 .497 .298 r
.27163 .34902 m .27607 .35186 L .27476 .34803 L p F P
0 g
s
.883 .497 .298 r
.27476 .34803 m .27038 .34517 L .27163 .34902 L p F P
0 g
s
.792 .998 .8 r
.72618 .33501 m .72035 .34067 L .72411 .33541 L closepath p F P
0 g
s
.779 .976 .913 r
.68459 .36952 m .68302 .36917 L .68796 .36558 L closepath p F P
0 g
s
.635 .555 .747 r
.49985 .41386 m .4982 .40924 L .48785 .41254 L p F P
0 g
s
0 0 .431 r
.77629 .24213 m .77529 .24488 L .77481 .24039 L p F P
0 g
s
0 0 .431 r
.77481 .24039 m .77569 .23795 L .77629 .24213 L p F P
0 g
s
.618 .735 .93 r
.26715 .42191 m .2769 .4195 L .28 .42257 L p F P
0 g
s
.629 .734 .923 r
.2769 .4195 m .26715 .42191 L .26403 .41899 L p F P
0 g
s
.768 .967 .926 r
.67366 .37659 m .67273 .37633 L .67581 .37424 L closepath p F P
0 g
s
.754 .658 .755 r
.32986 .41242 m .32772 .41189 L .32007 .419 L p F P
0 g
s
.766 .63 .709 r
.32901 .41025 m .32772 .41189 L .32986 .41242 L closepath p F P
0 g
s
.705 .87 .96 r
.5947 .41198 m .5931 .41271 L .59052 .41099 L p F P
0 g
s
.693 .867 .964 r
.58022 .41543 m .59052 .41099 L .5931 .41271 L p F P
0 g
s
0 0 0 r
.76672 .27621 m .76428 .28133 L .76643 .27614 L p F P
0 g
s
0 0 0 r
.76643 .27614 m .76893 .271 L .76672 .27621 L p F P
0 g
s
.787 .999 .832 r
.71603 .34468 m .71251 .34785 L .71484 .3448 L closepath p F P
0 g
s
.792 .997 .855 r
.71381 .34477 m .71484 .3448 L .71251 .34785 L p F P
0 g
s
.792 .997 .855 r
.70812 .34968 m .71381 .34477 L p .71251 .34785 L F P
0 g
s
.792 .997 .855 r
.70517 .35362 m .70812 .34968 L p .71251 .34785 L F P
0 g
s
.799 1 .828 r
.724 .33541 m .72411 .33541 L .72035 .34067 L p F P
0 g
s
.799 1 .828 r
.71661 .34227 m .724 .33541 L p .72035 .34067 L F P
0 g
s
.799 1 .828 r
.71484 .3448 m .71661 .34227 L p .72035 .34067 L F P
0 g
s
.799 1 .828 r
.72035 .34067 m .71603 .34468 L .71484 .3448 L p F P
0 g
s
.751 .254 0 r
.24035 .31211 m .23804 .30873 L .24156 .31197 L p F P
0 g
s
.751 .254 0 r
.24334 .31484 m .24035 .31211 L p .24156 .31197 L F P
0 g
s
.751 .254 0 r
.24156 .31197 m .24383 .31527 L .24334 .31484 L p F P
0 g
s
.7 .939 .638 r
.60349 .28082 m .60152 .28303 L .6028 .28133 L closepath p F P
0 g
s
.444 .684 .967 r
.20991 .40782 m .21724 .40792 L .22142 .41079 L p F P
0 g
s
.45 .684 .965 r
.21724 .40792 m .20991 .40782 L .20669 .40495 L p F P
0 g
s
.82 .9 .897 r
.67333 .21143 m .67213 .21058 L .67433 .20885 L closepath p F P
0 g
s
.733 .897 .511 r
.75472 .29802 m .7584 .29228 L .75567 .29746 L p F P
0 g
s
.733 .897 .511 r
.7532 .30093 m .75472 .29802 L p .75567 .29746 L F P
0 g
s
.733 .897 .511 r
.75567 .29746 m .75406 .29996 L .7532 .30093 L p F P
0 g
s
.748 .963 .936 r
.66243 .38311 m .66178 .38352 L .66226 .38306 L closepath p F P
0 g
s
.747 .953 .943 r
.66003 .38226 m .66226 .38306 L .66178 .38352 L p F P
0 g
s
.747 .953 .943 r
.65194 .38725 m .66003 .38226 L p .66178 .38352 L F P
0 g
s
.747 .953 .943 r
.65031 .38884 m .65194 .38725 L p .66178 .38352 L F P
0 g
s
.776 .623 .691 r
.32772 .41189 m .32901 .41025 L .32716 .40482 L p F P
0 g
s
.841 .573 .533 r
.30534 .3861 m .30941 .38793 L .30964 .38348 L p F P
0 g
s
.841 .573 .533 r
.30964 .38348 m .3056 .38168 L .30534 .3861 L p F P
0 g
s
.211 0 .209 r
.54521 .34572 m .54352 .34748 L .54497 .34656 L closepath p F P
0 g
s
.691 .931 .622 r
.60044 .28343 m .59587 .28942 L .60152 .28303 L p F P
0 g
s
.691 .931 .622 r
.60105 .2827 m .60044 .28343 L p .60152 .28303 L F P
0 g
s
.691 .931 .622 r
.60152 .28303 m .6028 .28133 L .60105 .2827 L p F P
0 g
s
.768 .843 .908 r
.69593 .19678 m .69507 .19731 L .69267 .19495 L p F P
0 g
s
.343 .628 .958 r
.17834 .39437 m .18101 .39472 L .18481 .39777 L p F P
0 g
s
.357 .634 .959 r
.18761 .39551 m .18101 .39472 L .18481 .39777 L p F P
0 g
s
.357 .634 .959 r
.18481 .39777 m .19086 .3985 L .18761 .39551 L p F P
0 g
s
0 0 .335 r
.77545 .24888 m .77433 .25155 L .77434 .24714 L p F P
0 g
s
0 0 .335 r
.77434 .24714 m .77529 .24488 L .77545 .24888 L p F P
0 g
s
.76 .964 .931 r
.67035 .37563 m .67273 .37633 L .66243 .38311 L p F P
0 g
s
.76 .964 .931 r
.66771 .37737 m .67035 .37563 L p .66243 .38311 L F P
0 g
s
.76 .964 .931 r
.66243 .38311 m .66226 .38306 L .66771 .37737 L p F P
0 g
s
.79 .985 .897 r
.69509 .36186 m .69331 .36157 L .69864 .35743 L closepath p F P
0 g
s
.444 .213 .468 r
.52 .37791 m .51519 .38031 L .51543 .37619 L p F P
0 g
s
.444 .213 .468 r
.51543 .37619 m .5229 .37244 L .52 .37791 L p F P
0 g
s
.875 .513 .359 r
.2866 .36027 m .28683 .36112 L .286 .36064 L closepath p F P
0 g
s
.244 0 .256 r
.54416 .34989 m .53781 .35391 L .54352 .34748 L p F P
0 g
s
.244 0 .256 r
.54352 .34748 m .54497 .34656 L .54416 .34989 L p F P
0 g
s
.776 .623 .691 r
.321 .40996 m .32772 .41189 L p .32716 .40482 L F P
0 g
s
.776 .623 .691 r
.32716 .40482 m .32487 .40419 L .321 .40996 L p F P
0 g
s
.874 .504 .341 r
.2772 .35576 m .28193 .35848 L .28071 .3546 L p F P
0 g
s
.874 .504 .341 r
.28071 .3546 m .27607 .35186 L .2772 .35576 L p F P
0 g
s
.705 .886 .964 r
.60341 .40794 m .5947 .41198 L .60179 .40697 L closepath p F P
0 g
s
.705 .87 .96 r
.60085 .40636 m .60179 .40697 L .5947 .41198 L p F P
0 g
s
.705 .87 .96 r
.59052 .41099 m .60085 .40636 L p .5947 .41198 L F P
0 g
s
.768 .843 .908 r
.69267 .19495 m .69759 .19171 L .69593 .19678 L p F P
0 g
s
.78 .845 .901 r
.69593 .19678 m .70542 .1908 L .70302 .1881 L p F P
0 g
s
.78 .845 .901 r
.70302 .1881 m .69759 .19171 L .69593 .19678 L p F P
0 g
s
.751 .702 .805 r
.32007 .419 m .31752 .41802 L .31882 .41993 L closepath p F P
0 g
s
.653 .693 .875 r
.73113 .18686 m .74173 .1835 L .74416 .18751 L p F P
0 g
s
.665 .707 .878 r
.74173 .1835 m .73113 .18686 L .72872 .18336 L p F P
0 g
s
.7 .743 .885 r
.71823 .18804 m .72872 .18336 L .73113 .18686 L p F P
0 g
s
.159 .171 .622 r
.77788 .22409 m .77615 .22906 L .77413 .22541 L p F P
0 g
s
.159 .171 .622 r
.77413 .22541 m .7758 .22045 L .77788 .22409 L p F P
0 g
s
.765 .656 .742 r
.31752 .41802 m .32007 .419 L .32772 .41189 L p F P
0 g
s
.765 .656 .742 r
.31586 .41536 m .31752 .41802 L p .32772 .41189 L F P
0 g
s
.765 .656 .742 r
.32772 .41189 m .321 .40996 L .31586 .41536 L p F P
0 g
s
.577 .416 .627 r
.50664 .39917 m .50587 .39379 L .49585 .39753 L p F P
0 g
s
.577 .416 .627 r
.49585 .39753 m .49661 .40289 L .50664 .39917 L p F P
0 g
s
0 0 .059 r
.77264 .26098 m .77052 .26601 L .7716 .26121 L p F P
0 g
s
0 0 .059 r
.7716 .26121 m .77375 .25617 L .77264 .26098 L p F P
0 g
s
.396 .659 .965 r
.1941 .40144 m .19803 .40171 L .20204 .40467 L p F P
0 g
s
.406 .662 .964 r
.20347 .40203 m .19803 .40171 L .20204 .40467 L p F P
0 g
s
.406 .662 .964 r
.20204 .40467 m .20669 .40495 L .20347 .40203 L p F P
0 g
s
.835 .368 0 r
.24383 .31527 m .24388 .31535 L .24747 .31855 L p F P
0 g
s
.855 .399 .039 r
.24567 .31893 m .24929 .32212 L .24747 .31855 L p F P
0 g
s
.855 .399 .039 r
.24747 .31855 m .24388 .31535 L .24567 .31893 L p F P
0 g
s
.287 .591 .946 r
.16264 .38653 m .16563 .38713 L .16923 .39027 L p F P
0 g
s
.305 .6 .949 r
.17181 .38825 m .16563 .38713 L .16923 .39027 L p F P
0 g
s
.305 .6 .949 r
.16923 .39027 m .17508 .39134 L .17181 .38825 L p F P
0 g
s
.759 .952 .938 r
.66226 .38306 m .66003 .38226 L .66771 .37737 L closepath p F P
0 g
s
.533 .719 .959 r
.23845 .41597 m .24563 .4152 L .25014 .41794 L p F P
0 g
s
.542 .721 .956 r
.24563 .4152 m .23845 .41597 L .23528 .41314 L p F P
0 g
s
.826 .587 .579 r
.30858 .3926 m .31425 .39493 L .31514 .39023 L p F P
0 g
s
.826 .587 .579 r
.31514 .39023 m .30941 .38793 L .30858 .3926 L p F P
0 g
s
.659 .731 .902 r
.28 .42257 m .28983 .41922 L .29289 .42255 L p F P
0 g
s
.672 .728 .892 r
.28983 .41922 m .28 .42257 L .2769 .4195 L p F P
0 g
s
.8 .873 .901 r
.68373 .2036 m .68238 .20245 L .68478 .20071 L closepath p F P
0 g
s
.719 .908 .961 r
.6164 .40445 m .61626 .40438 L .6169 .40406 L closepath p F P
0 g
s
.71 .753 .886 r
.72872 .18336 m .71823 .18804 L .71583 .18495 L p F P
0 g
s
.712 .891 .509 r
.75406 .29996 m .75187 .30324 L .7532 .30093 L closepath p F P
0 g
s
.806 .604 .628 r
.31245 .39996 m .31838 .40218 L .32035 .39708 L p F P
0 g
s
.806 .604 .628 r
.32035 .39708 m .31425 .39493 L .31245 .39996 L p F P
0 g
s
.402 .659 .963 r
.19803 .40171 m .1941 .40144 L .19086 .3985 L p F P
0 g
s
.559 .835 .491 r
.59534 .28964 m .60044 .28343 L .59587 .28942 L p F P
0 g
s
.559 .835 .491 r
.59241 .29333 m .59534 .28964 L p .59587 .28942 L F P
0 g
s
.559 .835 .491 r
.59587 .28942 m .59337 .29228 L .59241 .29333 L p F P
0 g
s
.722 .899 .959 r
.6169 .40406 m .61626 .40438 L .61373 .40295 L p F P
0 g
s
.711 .897 .964 r
.60341 .40794 m .61373 .40295 L .61626 .40438 L p F P
0 g
s
.229 .55 .931 r
.14702 .37787 m .15151 .37907 L .15492 .3823 L p F P
0 g
s
.236 .549 .93 r
.15151 .37907 m .14702 .37787 L .14373 .37461 L p F P
0 g
s
.786 .626 .683 r
.31495 .4078 m .321 .40996 L .32487 .40419 L p F P
0 g
s
.786 .626 .683 r
.32487 .40419 m .31838 .40218 L .31495 .4078 L p F P
0 g
s
.863 .414 .084 r
.25105 .32574 m .25485 .32885 L .25305 .32525 L p F P
0 g
s
.863 .414 .084 r
.25305 .32525 m .24929 .32212 L .25105 .32574 L p F P
0 g
s
.878 .537 .4 r
.28369 .36286 m .28762 .36517 L .28683 .36112 L p F P
0 g
s
.878 .537 .4 r
.28683 .36112 m .286 .36064 L .28369 .36286 L p F P
0 g
s
.725 .699 .825 r
.31752 .41802 m .3136 .41699 L .30583 .42171 L p F P
0 g
s
.735 .727 .844 r
.3136 .41699 m .30583 .42171 L .30281 .41797 L p F P
0 g
s
.696 .717 .865 r
.29289 .42255 m .30281 .41797 L .30583 .42171 L p F P
0 g
s
.289 .016 .313 r
.54345 .35336 m .54416 .34989 L .53781 .35391 L p F P
0 g
s
.289 .016 .313 r
.53476 .3589 m .54345 .35336 L p .53781 .35391 L F P
0 g
s
.289 .016 .313 r
.53781 .35391 m .53506 .35733 L .53476 .3589 L p F P
0 g
s
0 0 0 r
.56442 .32698 m .56334 .32796 L .56453 .32519 L p F P
0 g
s
0 0 0 r
.56453 .32519 m .56935 .32082 L .56442 .32698 L p F P
0 g
s
.74 .936 .951 r
.64726 .38754 m .6497 .38859 L .63938 .39453 L p F P
0 g
s
.74 .936 .951 r
.64013 .39165 m .64726 .38754 L p .63938 .39453 L F P
0 g
s
.74 .936 .951 r
.63938 .39453 m .63775 .39385 L .64013 .39165 L p F P
0 g
s
.71 .711 .849 r
.30281 .41797 m .29289 .42255 L .28983 .41922 L p F P
0 g
s
.655 .667 .849 r
.50261 .41968 m .51281 .41629 L .51555 .4207 L p F P
0 g
s
.647 .624 .813 r
.50157 .41768 m .50261 .41968 L .51281 .41629 L p F P
0 g
s
.722 .915 .96 r
.62658 .39902 m .6169 .40406 L .62443 .39795 L closepath p F P
0 g
s
.722 .899 .959 r
.62408 .39776 m .62443 .39795 L .6169 .40406 L p F P
0 g
s
.722 .899 .959 r
.61373 .40295 m .62408 .39776 L p .6169 .40406 L F P
0 g
s
.693 .858 .961 r
.59052 .41099 m .58022 .41543 L .57761 .41354 L p F P
0 g
s
.865 .439 .201 r
.26625 .33944 m .26514 .33928 L .26477 .33847 L closepath p F P
0 g
s
.176 0 .231 r
.55285 .34229 m .55332 .34055 L .54497 .34656 L p F P
0 g
s
.176 0 .231 r
.55074 .34509 m .55285 .34229 L p .54497 .34656 L F P
0 g
s
.176 0 .231 r
.54497 .34656 m .54416 .34989 L .55074 .34509 L p F P
0 g
s
0 0 0 r
.76983 .26761 m .76934 .26976 L .77052 .26601 L closepath p F P
0 g
s
.612 .668 .88 r
.74747 .18695 m .74416 .18751 L .74173 .1835 L p F P
0 g
s
.564 .838 .492 r
.59337 .29228 m .59033 .29578 L .59241 .29333 L closepath p F P
0 g
s
.8 .992 .878 r
.70517 .35362 m .70357 .35346 L .70812 .34968 L closepath p F P
0 g
s
0 0 0 r
.58375 .30338 m .58326 .30407 L .58491 .30209 L closepath p F P
0 g
s
.251 .562 .935 r
.15609 .3802 m .15151 .37907 L .15492 .3823 L p F P
0 g
s
.251 .562 .935 r
.15492 .3823 m .15936 .3834 L .15609 .3802 L p F P
0 g
s
.529 .572 .842 r
.7597 .19568 m .75977 .19547 L .75987 .19568 L closepath p F P
0 g
s
.349 .627 .956 r
.18101 .39472 m .17834 .39437 L .17508 .39134 L p F P
0 g
s
.263 .287 .698 r
.7771 .21661 m .7758 .22045 L .77284 .21714 L p F P
0 g
s
.263 .287 .698 r
.77644 .21424 m .7771 .21661 L p .77284 .21714 L F P
0 g
s
.263 .287 .698 r
.77284 .21714 m .77446 .21219 L .77644 .21424 L p F P
0 g
s
.294 .59 .945 r
.16563 .38713 m .16264 .38653 L .15936 .3834 L p F P
0 g
s
.766 .943 .606 r
.75052 .30394 m .74753 .3092 L .75187 .30324 L p F P
0 g
s
.766 .943 .606 r
.75206 .30182 m .75052 .30394 L p .75187 .30324 L F P
0 g
s
.766 .943 .606 r
.75187 .30324 m .7532 .30093 L .75206 .30182 L p F P
0 g
s
.862 .51 .384 r
.28291 .36245 m .28369 .36286 L .286 .36064 L p F P
0 g
s
.862 .51 .384 r
.286 .36064 m .28193 .35848 L .28291 .36245 L p F P
0 g
s
.868 .55 .446 r
.28814 .36932 m .29307 .37194 L .2925 .36781 L p F P
0 g
s
.868 .55 .446 r
.2925 .36781 m .28762 .36517 L .28814 .36932 L p F P
0 g
s
.471 .519 .826 r
.75987 .19568 m .76753 .19718 L .76618 .20207 L p F P
0 g
s
.459 .532 .845 r
.75977 .19547 m .75987 .19568 L .76753 .19718 L p F P
0 g
s
.739 .684 .798 r
.31586 .41536 m .3136 .41699 L .31752 .41802 L closepath p F P
0 g
s
.685 .837 .956 r
.5677 .41802 m .56732 .41772 L .57012 .4166 L closepath p F P
0 g
s
.868 .427 .13 r
.25657 .3325 m .26058 .33552 L .25881 .3319 L p F P
0 g
s
.868 .427 .13 r
.25881 .3319 m .25485 .32885 L .25657 .3325 L p F P
0 g
s
.814 .995 .762 r
.73532 .3247 m .73413 .32504 L .73715 .32174 L closepath p F P
0 g
s
.45 .685 .966 r
.21936 .40792 m .21724 .40792 L .22142 .41079 L p F P
0 g
s
.45 .685 .966 r
.22142 .41079 m .22256 .4108 L .21936 .40792 L p F P
0 g
s
.459 .532 .845 r
.76844 .1921 m .76069 .1909 L .75977 .19547 L p F P
0 g
s
.459 .532 .845 r
.76878 .19289 m .76844 .1921 L p .75977 .19547 L F P
0 g
s
.459 .532 .845 r
.76753 .19718 m .76878 .19289 L p .75977 .19547 L F P
0 g
s
.514 .572 .852 r
.75739 .1907 m .76069 .1909 L .75977 .19547 L closepath p F P
0 g
s
.531 .717 .958 r
.24806 .41493 m .24563 .4152 L .25014 .41794 L p F P
0 g
s
.531 .717 .958 r
.25014 .41794 m .25121 .41783 L .24806 .41493 L p F P
0 g
s
.329 .049 .327 r
.53506 .35733 m .53229 .36027 L .53476 .3589 L closepath p F P
0 g
s
.376 .13 .409 r
.52517 .36765 m .52491 .37003 L .52721 .36649 L closepath p F P
0 g
s
.856 .976 .863 r
.64181 .23843 m .64157 .23839 L .64207 .23791 L closepath p F P
0 g
s
.549 .823 .471 r
.59026 .29584 m .58491 .30209 L .59033 .29578 L p F P
0 g
s
.549 .823 .471 r
.59092 .29503 m .59026 .29584 L p .59033 .29578 L F P
0 g
s
.549 .823 .471 r
.59033 .29578 m .59241 .29333 L .59092 .29503 L p F P
0 g
s
.77 .965 .927 r
.67581 .37424 m .67273 .37633 L .67035 .37563 L p F P
0 g
s
.708 .937 .625 r
.6028 .28133 m .60105 .2827 L .60584 .27711 L closepath p F P
0 g
s
.638 .773 .31 r
.76408 .28159 m .76672 .27621 L .76428 .28133 L p F P
0 g
s
.638 .773 .31 r
.76176 .28653 m .76408 .28159 L p .76428 .28133 L F P
0 g
s
.638 .773 .31 r
.76428 .28133 m .76181 .28643 L .76176 .28653 L p F P
0 g
s
.358 .095 .372 r
.53421 .36259 m .52721 .36649 L .53229 .36027 L p F P
0 g
s
.358 .095 .372 r
.53229 .36027 m .53476 .3589 L .53421 .36259 L p F P
0 g
s
.639 .594 .788 r
.49985 .41386 m .50157 .41768 L .51162 .41399 L p F P
0 g
s
.647 .624 .813 r
.51281 .41629 m .51162 .41399 L .50157 .41768 L p F P
0 g
s
.531 .346 .575 r
.51555 .38961 m .5152 .38476 L .50554 .38895 L p F P
0 g
s
.531 .346 .575 r
.50554 .38895 m .50587 .39379 L .51555 .38961 L p F P
0 g
s
.849 .956 .88 r
.65699 .22382 m .65173 .22859 L .6504 .2281 L p F P
0 g
s
.864 .954 .867 r
.65173 .22859 m .6493 .23095 L .6504 .2281 L closepath p F P
0 g
s
.862 .941 .87 r
.65699 .22382 m .66192 .21931 L .65951 .21803 L p F P
0 g
s
.862 .941 .87 r
.65951 .21803 m .65877 .21873 L .65699 .22382 L p F P
0 g
s
.849 .956 .88 r
.65141 .22575 m .65877 .21873 L .65699 .22382 L p F P
0 g
s
.849 .956 .88 r
.6504 .2281 m .65141 .22575 L p .65699 .22382 L F P
0 g
s
.837 .931 .892 r
.66524 .21649 m .66192 .21931 L .65951 .21803 L p F P
0 g
s
.866 .956 .864 r
.64454 .23259 m .64207 .23791 L .6493 .23095 L p F P
0 g
s
.866 .956 .864 r
.64932 .22773 m .64454 .23259 L p .6493 .23095 L F P
0 g
s
.866 .956 .864 r
.6493 .23095 m .6504 .2281 L .64932 .22773 L p F P
0 g
s
.826 .559 .536 r
.3039 .38554 m .30534 .3861 L .3056 .38168 L p F P
0 g
s
.826 .559 .536 r
.3056 .38168 m .30412 .38109 L .3039 .38554 L p F P
0 g
s
.748 .941 .947 r
.65031 .38884 m .6497 .38859 L .65194 .38725 L closepath p F P
0 g
s
.853 .559 .49 r
.29328 .37622 m .29853 .37872 L .29828 .37446 L p F P
0 g
s
.853 .559 .49 r
.29828 .37446 m .29307 .37194 L .29328 .37622 L p F P
0 g
s
.745 .813 .906 r
.71471 .18558 m .70542 .1908 L .70302 .1881 L p F P
0 g
s
.848 .923 .88 r
.66524 .21649 m .67213 .21058 L .66973 .20894 L p F P
0 g
s
.848 .923 .88 r
.66973 .20894 m .66697 .21141 L .66524 .21649 L p F P
0 g
s
.837 .931 .892 r
.65951 .21803 m .66697 .21141 L .66524 .21649 L p F P
0 g
s
.353 .387 .758 r
.77517 .20998 m .77446 .21219 L .77033 .20931 L p F P
0 g
s
.353 .387 .758 r
.77366 .20548 m .77517 .20998 L p .77033 .20931 L F P
0 g
s
.353 .387 .758 r
.77033 .20931 m .77186 .20437 L .77366 .20548 L p F P
0 g
s
.688 .82 .946 r
.57012 .4166 m .56732 .41772 L .56468 .41547 L p F P
0 g
s
.677 .817 .95 r
.55439 .41936 m .56468 .41547 L .56732 .41772 L p F P
0 g
s
.87 .44 .181 r
.26186 .33839 m .26058 .33552 L .26477 .33847 L p F P
0 g
s
.87 .44 .181 r
.26477 .33847 m .26514 .33928 L .26186 .33839 L p F P
0 g
s
.423 .469 .803 r
.77251 .20224 m .77186 .20437 L .76618 .20207 L p F P
0 g
s
.423 .469 .803 r
.77102 .19838 m .77251 .20224 L p .76618 .20207 L F P
0 g
s
.423 .469 .803 r
.76618 .20207 m .76753 .19718 L .77102 .19838 L p F P
0 g
s
0 0 .43 r
.77804 .23718 m .77629 .24213 L .77569 .23795 L p F P
0 g
s
0 0 .43 r
.77569 .23795 m .77743 .233 L .77804 .23718 L p F P
0 g
s
.659 .713 .887 r
.51555 .4207 m .52578 .41733 L .5285 .42094 L p F P
0 g
s
.651 .672 .858 r
.52578 .41733 m .51555 .4207 L .51281 .41629 L p F P
0 g
s
.594 .731 .939 r
.2609 .416 m .25121 .41783 L .24806 .41493 L p F P
0 g
s
.853 .981 .861 r
.63915 .238 m .64454 .23259 L .64207 .23791 L p F P
0 g
s
.853 .981 .861 r
.64207 .23791 m .64157 .23839 L .63915 .238 L p F P
0 g
s
.871 .987 .831 r
.63546 .24464 m .64157 .23839 L .63915 .238 L p F P
0 g
s
.831 .999 .789 r
.62195 .25941 m .6213 .25957 L .62286 .2579 L closepath p F P
0 g
s
.77 .975 .918 r
.68302 .36917 m .67581 .37424 L .68084 .36867 L closepath p F P
0 g
s
.77 .965 .927 r
.68068 .36861 m .68084 .36867 L .67581 .37424 L p F P
0 g
s
.77 .965 .927 r
.67035 .37563 m .68068 .36861 L p .67581 .37424 L F P
0 g
s
.498 .706 .963 r
.22256 .4108 m .2321 .41026 L .23528 .41314 L p F P
0 g
s
.503 .705 .961 r
.2321 .41026 m .22256 .4108 L .21936 .40792 L p F P
0 g
s
.597 .465 .672 r
.5073 .40214 m .50664 .39917 L .49661 .40289 L p F P
0 g
s
.597 .465 .672 r
.49661 .40289 m .49709 .40515 L .5073 .40214 L p F P
0 g
s
.82 .905 .899 r
.67433 .20885 m .67213 .21058 L .66973 .20894 L p F P
0 g
s
0 0 .311 r
.77631 .24653 m .77545 .24888 L .77529 .24488 L p F P
0 g
s
0 0 .311 r
.77529 .24488 m .77629 .24213 L .77631 .24653 L p F P
0 g
s
.781 .684 .757 r
.31292 .41023 m .31495 .4078 L .321 .40996 L p F P
0 g
s
.781 .684 .757 r
.321 .40996 m .31586 .41536 L .31292 .41023 L p F P
0 g
s
.831 .902 .888 r
.67433 .20885 m .68238 .20245 L .67998 .20046 L p F P
0 g
s
.831 .902 .888 r
.67998 .20046 m .67598 .20379 L .67433 .20885 L p F P
0 g
s
.82 .905 .899 r
.66973 .20894 m .67598 .20379 L .67433 .20885 L p F P
0 g
s
.835 .568 .536 r
.29828 .38318 m .3039 .38554 L .30412 .38109 L p F P
0 g
s
.835 .568 .536 r
.30412 .38109 m .29853 .37872 L .29828 .38318 L p F P
0 g
s
.756 .685 .783 r
.3136 .41699 m .31586 .41536 L .31292 .41023 L p F P
0 g
s
.756 .685 .783 r
.31292 .41023 m .30731 .41491 L .3136 .41699 L p F P
0 g
s
.735 .727 .844 r
.30281 .41797 m .30731 .41491 L .3136 .41699 L p F P
0 g
s
0 0 0 r
.58544 .30196 m .59026 .29584 L .58491 .30209 L p F P
0 g
s
0 0 0 r
.58223 .30563 m .58544 .30196 L p .58491 .30209 L F P
0 g
s
0 0 0 r
.58491 .30209 m .58326 .30407 L .58223 .30563 L p F P
0 g
s
.893 .507 .293 r
.26739 .3461 m .27163 .34902 L .27038 .34517 L p F P
0 g
s
.893 .507 .293 r
.27038 .34517 m .26619 .34224 L .26739 .3461 L p F P
0 g
s
.871 .987 .831 r
.63915 .238 m .6379 .23934 L .63546 .24464 L p F P
0 g
s
.847 .996 .831 r
.63177 .24591 m .6379 .23934 L .63546 .24464 L p F P
0 g
s
.847 .996 .831 r
.63028 .24878 m .63177 .24591 L p .63546 .24464 L F P
0 g
s
.847 .996 .831 r
.63546 .24464 m .63143 .24874 L .63028 .24878 L p F P
0 g
s
.719 .233 0 r
.23144 .30204 m .23467 .30542 L .23237 .30205 L p F P
0 g
s
.719 .233 0 r
.23237 .30205 m .22915 .29868 L .23144 .30204 L p F P
0 g
s
.79 .966 .659 r
.7457 .31009 m .75052 .30394 L .74753 .3092 L p F P
0 g
s
.79 .966 .659 r
.74359 .31385 m .7457 .31009 L p .74753 .3092 L F P
0 g
s
.79 .966 .659 r
.74753 .3092 m .74417 .3135 L .74359 .31385 L p F P
0 g
s
.675 .799 .941 r
.56468 .41547 m .55439 .41936 L .55172 .41679 L p F P
0 g
s
.671 .789 .937 r
.54145 .42046 m .55172 .41679 L .55439 .41936 L p F P
0 g
s
.711 .888 .962 r
.6112 .40145 m .61373 .40295 L .60341 .40794 L p F P
0 g
s
.711 .888 .962 r
.6054 .40423 m .6112 .40145 L p .60341 .40794 L F P
0 g
s
.711 .888 .962 r
.60341 .40794 m .60179 .40697 L .6054 .40423 L p F P
0 g
s
.665 .754 .917 r
.5285 .42094 m .53875 .41745 L .54145 .42046 L p F P
0 g
s
.658 .722 .896 r
.53875 .41745 m .5285 .42094 L .52578 .41733 L p F P
0 g
s
0 0 0 r
.77105 .26597 m .77264 .26098 L .77052 .26601 L p F P
0 g
s
0 0 0 r
.76918 .27047 m .77105 .26597 L p .77052 .26601 L F P
0 g
s
0 0 0 r
.77052 .26601 m .76934 .26976 L .76918 .27047 L p F P
0 g
s
.608 .498 .702 r
.50823 .40552 m .5073 .40214 L .49709 .40515 L p F P
0 g
s
.608 .498 .702 r
.49709 .40515 m .4982 .40924 L .50823 .40552 L p F P
0 g
s
.391 .147 .419 r
.5338 .36649 m .53421 .36259 L .52721 .36649 L p F P
0 g
s
.391 .147 .419 r
.52475 .37153 m .5338 .36649 L p .52721 .36649 L F P
0 g
s
.391 .147 .419 r
.52721 .36649 m .52491 .37003 L .52475 .37153 L p F P
0 g
s
.626 .548 .746 r
.4982 .40924 m .49985 .41386 L .51006 .41057 L p F P
0 g
s
.639 .594 .788 r
.51162 .41399 m .51006 .41057 L .49985 .41386 L p F P
0 g
s
.612 .668 .88 r
.74173 .1835 m .74852 .18212 L .74747 .18695 L p F P
0 g
s
.586 .634 .865 r
.75247 .18142 m .74852 .18212 L .74747 .18695 L p F P
0 g
s
.586 .634 .865 r
.74747 .18695 m .75493 .18595 L .75247 .18142 L p F P
0 g
s
.862 .993 .822 r
.63143 .24874 m .62901 .25132 L .63028 .24878 L closepath p F P
0 g
s
0 0 .199 r
.77531 .25245 m .77375 .25617 L .77433 .25155 L p F P
0 g
s
0 0 .199 r
.77433 .25155 m .77545 .24888 L .77531 .25245 L p F P
0 g
s
0 0 0 r
.58326 .30407 m .57961 .30837 L .58223 .30563 L closepath p F P
0 g
s
.893 .49 .242 r
.26619 .34224 m .26514 .33928 L .26186 .33839 L p F P
0 g
s
.666 .765 .924 r
.55172 .41679 m .54145 .42046 L .53875 .41745 L p F P
0 g
s
.837 .599 .578 r
.30586 .39137 m .30858 .3926 L .30941 .38793 L p F P
0 g
s
.837 .599 .578 r
.30941 .38793 m .30534 .3861 L .30586 .39137 L p F P
0 g
s
.809 .997 .857 r
.71484 .3448 m .71381 .34477 L .71661 .34227 L closepath p F P
0 g
s
.688 .836 .954 r
.57761 .41354 m .57012 .4166 L .57647 .41264 L closepath p F P
0 g
s
.688 .82 .946 r
.57499 .41142 m .57647 .41264 L .57012 .4166 L p F P
0 g
s
.688 .82 .946 r
.56468 .41547 m .57499 .41142 L p .57012 .4166 L F P
0 g
s
.801 .636 .677 r
.31076 .40607 m .31495 .4078 L .31838 .40218 L p F P
0 g
s
.801 .636 .677 r
.31002 .40437 m .31076 .40607 L p .31838 .40218 L F P
0 g
s
.801 .636 .677 r
.31838 .40218 m .31245 .39996 L .31002 .40437 L p F P
0 g
s
.862 .994 .816 r
.62586 .25241 m .62286 .2579 L .62901 .25132 L p F P
0 g
s
.862 .994 .816 r
.629 .24886 m .62586 .25241 L p .62901 .25132 L F P
0 g
s
.862 .994 .816 r
.62901 .25132 m .63028 .24878 L .629 .24886 L p F P
0 g
s
.885 .516 .337 r
.27271 .35294 m .2772 .35576 L .27607 .35186 L p F P
0 g
s
.885 .516 .337 r
.27607 .35186 m .27163 .34902 L .27271 .35294 L p F P
0 g
s
.801 .878 .903 r
.68478 .20071 m .68238 .20245 L .67998 .20046 L p F P
0 g
s
.821 .615 .623 r
.30746 .39782 m .31245 .39996 L .31425 .39493 L p F P
0 g
s
.821 .615 .623 r
.3072 .39685 m .30746 .39782 L p .31425 .39493 L F P
0 g
s
.821 .615 .623 r
.31425 .39493 m .30858 .3926 L .3072 .39685 L p F P
0 g
s
.743 .253 0 r
.23696 .3088 m .24035 .31211 L .23804 .30873 L p F P
0 g
s
.743 .253 0 r
.23804 .30873 m .23467 .30542 L .23696 .3088 L p F P
0 g
s
.056 0 .125 r
.55506 .33913 m .55332 .34055 L .55429 .33744 L p F P
0 g
s
.056 0 .125 r
.55429 .33744 m .55962 .3331 L .55506 .33913 L p F P
0 g
s
.626 .548 .746 r
.51006 .41057 m .50823 .40552 L .4982 .40924 L p F P
0 g
s
.78 .976 .914 r
.68796 .36558 m .68302 .36917 L .68084 .36867 L p F P
0 g
s
.751 .937 .946 r
.65194 .38725 m .6497 .38859 L .64726 .38754 L p F P
0 g
s
.304 .051 .355 r
.54286 .35699 m .54345 .35336 L .53476 .3589 L p F P
0 g
s
.304 .051 .355 r
.53476 .3589 m .53421 .36259 L .54286 .35699 L p F P
0 g
s
.349 .627 .956 r
.17508 .39134 m .17729 .39163 L .18101 .39472 L p F P
0 g
s
.363 .633 .957 r
.18436 .39245 m .17729 .39163 L .18101 .39472 L p F P
0 g
s
.363 .633 .957 r
.18101 .39472 m .18761 .39551 L .18436 .39245 L p F P
0 g
s
.639 .733 .916 r
.2738 .41636 m .26403 .41899 L .2609 .416 L p F P
0 g
s
.629 .734 .923 r
.26403 .41899 m .2738 .41636 L .2769 .4195 L p F P
0 g
s
.474 .268 .519 r
.5199 .38241 m .5152 .38476 L .51519 .38031 L p F P
0 g
s
.474 .268 .519 r
.51519 .38031 m .52 .37791 L .5199 .38241 L p F P
0 g
s
.775 .964 .661 r
.74417 .3135 m .74268 .31535 L .74359 .31385 L closepath p F P
0 g
s
.811 .874 .893 r
.68478 .20071 m .69267 .19495 L .69027 .19262 L p F P
0 g
s
.811 .874 .893 r
.69027 .19262 m .68624 .19571 L .68478 .20071 L p F P
0 g
s
.801 .878 .903 r
.67998 .20046 m .68624 .19571 L .68478 .20071 L p F P
0 g
s
.731 .917 .957 r
.63443 .3922 m .63691 .39346 L .62658 .39902 L p F P
0 g
s
.731 .917 .957 r
.62549 .39701 m .63443 .3922 L p .62658 .39902 L F P
0 g
s
.731 .917 .957 r
.62658 .39902 m .62443 .39795 L .62549 .39701 L p F P
0 g
s
0 0 0 r
.57348 .31556 m .57313 .31623 L .57443 .31461 L closepath p F P
0 g
s
0 0 0 r
.58068 .30806 m .57443 .31461 L .57961 .30837 L p F P
0 g
s
0 0 0 r
.58079 .30792 m .58068 .30806 L p .57961 .30837 L F P
0 g
s
0 0 0 r
.57961 .30837 m .58223 .30563 L .58079 .30792 L p F P
0 g
s
.402 .659 .963 r
.19086 .3985 m .19411 .39872 L .19803 .40171 L p F P
0 g
s
.412 .662 .962 r
.20024 .39905 m .19411 .39872 L .19803 .40171 L p F P
0 g
s
.412 .662 .962 r
.19803 .40171 m .20347 .40203 L .20024 .39905 L p F P
0 g
s
0 0 0 r
.76181 .28643 m .76168 .28668 L .76176 .28653 L closepath p F P
0 g
s
.45 .684 .965 r
.20669 .40495 m .21314 .405 L .21724 .40792 L p F P
0 g
s
.456 .683 .963 r
.21314 .405 m .20669 .40495 L .20347 .40203 L p F P
0 g
s
.829 .362 0 r
.24383 .31527 m .24388 .31535 L .24334 .31484 L closepath p F P
0 g
s
.751 .95 .942 r
.66003 .38226 m .65194 .38725 L .65781 .38145 L closepath p F P
0 g
s
.751 .937 .946 r
.65761 .38137 m .65781 .38145 L .65194 .38725 L p F P
0 g
s
.751 .937 .946 r
.64726 .38754 m .65761 .38137 L p .65194 .38725 L F P
0 g
s
.701 .857 .441 r
.7604 .28843 m .7584 .29228 L .76168 .28668 L p F P
0 g
s
.701 .857 .441 r
.76168 .28668 m .76176 .28653 L .7604 .28843 L p F P
0 g
s
.874 .524 .383 r
.27812 .35975 m .28291 .36245 L .28193 .35848 L p F P
0 g
s
.874 .524 .383 r
.28193 .35848 m .2772 .35576 L .27812 .35975 L p F P
0 g
s
.821 .998 .779 r
.62015 .25883 m .62586 .25241 L .62286 .2579 L p F P
0 g
s
.821 .998 .779 r
.61942 .26011 m .62015 .25883 L p .62286 .2579 L F P
0 g
s
.821 .998 .779 r
.62286 .2579 m .6213 .25957 L .61942 .26011 L p F P
0 g
s
.804 .988 .73 r
.74038 .31641 m .73715 .32174 L .74268 .31535 L p F P
0 g
s
.804 .988 .73 r
.74208 .31444 m .74038 .31641 L p .74268 .31535 L F P
0 g
s
.804 .988 .73 r
.74268 .31535 m .74359 .31385 L .74208 .31444 L p F P
0 g
s
.859 .409 .037 r
.24218 .31568 m .24567 .31893 L .24388 .31535 L p F P
0 g
s
.859 .409 .037 r
.24064 .31257 m .24218 .31568 L p .24388 .31535 L F P
0 g
s
.859 .409 .037 r
.24388 .31535 m .24334 .31484 L .24064 .31257 L p F P
0 g
s
.426 .175 .428 r
.52491 .37003 m .5229 .37244 L .52475 .37153 L closepath p F P
0 g
s
.781 .984 .902 r
.69331 .36157 m .68796 .36558 L .6916 .36128 L closepath p F P
0 g
s
.78 .976 .914 r
.69099 .36112 m .6916 .36128 L .68796 .36558 L p F P
0 g
s
.78 .976 .914 r
.68118 .36826 m .69099 .36112 L p .68796 .36558 L F P
0 g
s
.78 .976 .914 r
.68084 .36867 m .68118 .36826 L p .68796 .36558 L F P
0 g
s
.79 .947 .606 r
.7532 .30093 m .75206 .30182 L .75472 .29802 L closepath p F P
0 g
s
.294 .59 .945 r
.15936 .3834 m .16212 .38395 L .16563 .38713 L p F P
0 g
s
.312 .599 .948 r
.16855 .3851 m .16212 .38395 L .16563 .38713 L p F P
0 g
s
.312 .599 .948 r
.16563 .38713 m .17181 .38825 L .16855 .3851 L p F P
0 g
s
.733 .867 .446 r
.76102 .28711 m .7604 .28843 L .76176 .28653 L p F P
0 g
s
.733 .867 .446 r
.76176 .28653 m .76408 .28159 L .76102 .28711 L p F P
0 g
s
.054 .053 .537 r
.77918 .22802 m .77743 .233 L .77615 .22906 L p F P
0 g
s
.054 .053 .537 r
.77615 .22906 m .77788 .22409 L .77918 .22802 L p F P
0 g
s
.665 .707 .878 r
.72872 .18336 m .73931 .17962 L .74173 .1835 L p F P
0 g
s
.677 .72 .881 r
.73931 .17962 m .72872 .18336 L .72631 .17995 L p F P
0 g
s
.71 .753 .886 r
.71583 .18495 m .72631 .17995 L .72872 .18336 L p F P
0 g
s
.837 .997 .774 r
.6213 .25957 m .61702 .26436 L .61942 .26011 L closepath p F P
0 g
s
.53 .586 .855 r
.76069 .1909 m .75739 .1907 L .75493 .18595 L p F P
0 g
s
.747 .721 .828 r
.30731 .41491 m .30281 .41797 L .2998 .41403 L p F P
0 g
s
.71 .711 .849 r
.28983 .41922 m .2998 .41403 L .30281 .41797 L p F P
0 g
s
.453 .223 .474 r
.52454 .37569 m .52 .37791 L .5229 .37244 L p F P
0 g
s
.453 .223 .474 r
.5229 .37244 m .52475 .37153 L .52454 .37569 L p F P
0 g
s
.865 .417 .069 r
.24739 .32256 m .25105 .32574 L .24929 .32212 L p F P
0 g
s
.865 .417 .069 r
.24929 .32212 m .24567 .31893 L .24739 .32256 L p F P
0 g
s
.672 .728 .892 r
.2769 .4195 m .28677 .41579 L .28983 .41922 L p F P
0 g
s
.684 .725 .881 r
.28677 .41579 m .2769 .4195 L .2738 .41636 L p F P
0 g
s
.742 .791 .892 r
.71583 .18495 m .71471 .18558 L .71492 .18382 L closepath p F P
0 g
s
.745 .813 .906 r
.71342 .18195 m .71492 .18382 L .71471 .18558 L p F P
0 g
s
.745 .813 .906 r
.70302 .1881 m .71342 .18195 L p .71471 .18558 L F P
0 g
s
.583 .84 .481 r
.59241 .29333 m .59092 .29503 L .59534 .28964 L closepath p F P
0 g
s
.879 .56 .442 r
.28346 .36659 m .28814 .36932 L .28762 .36517 L p F P
0 g
s
.879 .56 .442 r
.28312 .36377 m .28346 .36659 L p .28762 .36517 L F P
0 g
s
.879 .56 .442 r
.28762 .36517 m .28369 .36286 L .28312 .36377 L p F P
0 g
s
.542 .721 .956 r
.23528 .41314 m .24116 .41244 L .24563 .4152 L p F P
0 g
s
.549 .722 .953 r
.24116 .41244 m .23528 .41314 L .2321 .41026 L p F P
0 g
s
.7 .864 .96 r
.60085 .40636 m .59052 .41099 L .58793 .40916 L p F P
0 g
s
.693 .858 .961 r
.57761 .41354 m .58793 .40916 L .59052 .41099 L p F P
0 g
s
.786 .299 0 r
.24334 .31484 m .24064 .31257 L .24035 .31211 L closepath p F P
0 g
s
.739 .924 .953 r
.63775 .39385 m .63691 .39346 L .64013 .39165 L closepath p F P
0 g
s
.791 .984 .898 r
.69864 .35743 m .69331 .36157 L .6916 .36128 L p F P
0 g
s
.559 .404 .628 r
.51637 .39504 m .51555 .38961 L .50587 .39379 L p F P
0 g
s
.559 .404 .628 r
.50587 .39379 m .50664 .39917 L .51637 .39504 L p F P
0 g
s
.779 .849 .904 r
.69759 .19171 m .69267 .19495 L .69027 .19262 L p F P
0 g
s
.236 .549 .93 r
.14373 .37461 m .14818 .3758 L .15151 .37907 L p F P
0 g
s
.624 .666 .87 r
.74852 .18212 m .74173 .1835 L .73931 .17962 L p F P
0 g
s
.723 .785 .901 r
.7239 .17663 m .72631 .17995 L .71583 .18495 L p F P
0 g
s
.723 .785 .901 r
.71612 .18059 m .7239 .17663 L p .71583 .18495 L F P
0 g
s
.723 .785 .901 r
.71583 .18495 m .71492 .18382 L .71612 .18059 L p F P
0 g
s
.835 .996 .764 r
.61478 .26514 m .61123 .27081 L .61702 .26436 L p F P
0 g
s
.835 .996 .764 r
.61886 .26029 m .61478 .26514 L p .61702 .26436 L F P
0 g
s
.835 .996 .764 r
.61702 .26436 m .61942 .26011 L .61886 .26029 L p F P
0 g
s
0 0 0 r
.76934 .26976 m .76893 .271 L .76918 .27047 L closepath p F P
0 g
s
.725 .711 .837 r
.28983 .41922 m .2998 .41403 L .29709 .41032 L p F P
0 g
s
.725 .711 .837 r
.28677 .41579 m .28983 .41922 L p .29709 .41032 L F P
0 g
s
0 0 0 r
.57616 .31408 m .58068 .30806 L .57443 .31461 L p F P
0 g
s
0 0 0 r
.57219 .31817 m .57616 .31408 L p .57443 .31461 L F P
0 g
s
0 0 0 r
.57443 .31461 m .57313 .31623 L .57219 .31817 L p F P
0 g
s
.54 .717 .955 r
.2449 .41198 m .24116 .41244 L .24563 .4152 L p F P
0 g
s
.54 .717 .955 r
.24563 .4152 m .24806 .41493 L .2449 .41198 L p F P
0 g
s
.408 .658 .961 r
.19411 .39872 m .19086 .3985 L .18761 .39551 L p F P
0 g
s
.815 .995 .764 r
.73439 .32297 m .74038 .31641 L .73715 .32174 L p F P
0 g
s
.815 .995 .764 r
.73296 .32537 m .73439 .32297 L p .73715 .32174 L F P
0 g
s
.815 .995 .764 r
.73715 .32174 m .73413 .32504 L .73296 .32537 L p F P
0 g
s
.456 .685 .964 r
.21615 .40499 m .21314 .405 L .21724 .40792 L p F P
0 g
s
.456 .685 .964 r
.21724 .40792 m .21936 .40792 L .21615 .40499 L p F P
0 g
s
.873 .432 .117 r
.25272 .3294 m .25657 .3325 L .25485 .32885 L p F P
0 g
s
.873 .432 .117 r
.25485 .32885 m .25105 .32574 L .25272 .3294 L p F P
0 g
s
.866 .571 .487 r
.28833 .3736 m .29328 .37622 L .29307 .37194 L p F P
0 g
s
.866 .571 .487 r
.29307 .37194 m .28814 .36932 L .28833 .3736 L p F P
0 g
s
.258 .562 .934 r
.1528 .37693 m .14818 .3758 L .15151 .37907 L p F P
0 g
s
.258 .562 .934 r
.15151 .37907 m .15609 .3802 L .1528 .37693 L p F P
0 g
s
.789 .674 .737 r
.31495 .4078 m .31076 .40607 L .31292 .41023 L closepath p F P
0 g
s
0 0 0 r
.57313 .31623 m .56935 .32082 L .57219 .31817 L closepath p F P
0 g
s
.858 .958 .872 r
.6504 .2281 m .64932 .22773 L .65141 .22575 L closepath p F P
0 g
s
.791 .991 .884 r
.70357 .35346 m .69864 .35743 L .70192 .35329 L closepath p F P
0 g
s
.791 .984 .898 r
.70128 .35316 m .70192 .35329 L .69864 .35743 L p F P
0 g
s
.791 .984 .898 r
.69276 .35979 m .70128 .35316 L p .69864 .35743 L F P
0 g
s
.791 .984 .898 r
.6916 .36128 m .69276 .35979 L p .69864 .35743 L F P
0 g
s
.764 .673 .761 r
.30731 .41491 m .31292 .41023 L .31076 .40607 L p F P
0 g
s
.764 .673 .761 r
.30172 .41257 m .30731 .41491 L p .31076 .40607 L F P
0 g
s
.747 .721 .828 r
.2998 .41403 m .30172 .41257 L .30731 .41491 L p F P
0 g
s
.651 .672 .858 r
.51281 .41629 m .52305 .41305 L .52578 .41733 L p F P
0 g
s
.643 .625 .816 r
.51162 .41399 m .51281 .41629 L .52305 .41305 L p F P
0 g
s
.821 .587 .585 r
.30295 .39026 m .30586 .39137 L .30534 .3861 L p F P
0 g
s
.821 .587 .585 r
.30534 .3861 m .3039 .38554 L .30295 .39026 L p F P
0 g
s
.802 .995 .767 r
.73413 .32504 m .73103 .32833 L .73296 .32537 L closepath p F P
0 g
s
.3 .589 .944 r
.16212 .38395 m .15936 .3834 L .15609 .3802 L p F P
0 g
s
0 0 0 r
.76825 .27294 m .76672 .27621 L .76893 .271 L p F P
0 g
s
0 0 0 r
.76893 .271 m .76918 .27047 L .76825 .27294 L p F P
0 g
s
.355 .626 .955 r
.17729 .39163 m .17508 .39134 L .17181 .38825 L p F P
0 g
s
.849 .582 .534 r
.29303 .38068 m .29828 .38318 L .29853 .37872 L p F P
0 g
s
.849 .582 .534 r
.29853 .37872 m .29328 .37622 L .29303 .38068 L p F P
0 g
s
.417 .195 .466 r
.53359 .37062 m .5338 .36649 L .52475 .37153 L p F P
0 g
s
.417 .195 .466 r
.52475 .37153 m .52454 .37569 L .53359 .37062 L p F P
0 g
s
0 0 .304 r
.77806 .24158 m .77631 .24653 L .77629 .24213 L p F P
0 g
s
0 0 .304 r
.77629 .24213 m .77804 .23718 L .77806 .24158 L p F P
0 g
s
.782 .981 .714 r
.61119 .27086 m .61117 .27088 L .61123 .27081 L closepath p F P
0 g
s
.801 .991 .879 r
.70812 .34968 m .70357 .35346 L .70192 .35329 L p F P
0 g
s
.874 .441 .161 r
.25818 .33619 m .25657 .3325 L .26058 .33552 L p F P
0 g
s
.874 .441 .161 r
.26034 .33779 m .25818 .33619 L p .26058 .33552 L F P
0 g
s
.874 .441 .161 r
.26058 .33552 m .26186 .33839 L .26034 .33779 L p F P
0 g
s
.816 1 .812 r
.72772 .32976 m .72429 .33514 L .73103 .32833 L p F P
0 g
s
.816 1 .812 r
.73197 .32548 m .72772 .32976 L p .73103 .32833 L F P
0 g
s
.816 1 .812 r
.73103 .32833 m .73296 .32537 L .73197 .32548 L p F P
0 g
s
.206 0 .272 r
.5468 .35092 m .54345 .35336 L .54416 .34989 L p F P
0 g
s
.206 0 .272 r
.54416 .34989 m .55074 .34509 L .5468 .35092 L p F P
0 g
s
.76 .951 .938 r
.66771 .37737 m .66003 .38226 L .65781 .38145 L p F P
0 g
s
.762 .972 .694 r
.60946 .27143 m .61478 .26514 L .61123 .27081 L p F P
0 g
s
.762 .972 .694 r
.60903 .27212 m .60946 .27143 L p .61123 .27081 L F P
0 g
s
.762 .972 .694 r
.61123 .27081 m .61117 .27088 L .60903 .27212 L p F P
0 g
s
.78 .975 .694 r
.61117 .27088 m .60584 .27711 L .60903 .27212 L closepath p F P
0 g
s
.788 .841 .892 r
.69759 .19171 m .70302 .1881 L .70061 .18545 L p F P
0 g
s
.788 .841 .892 r
.70061 .18545 m .69861 .18685 L .69759 .19171 L p F P
0 g
s
.779 .849 .904 r
.69027 .19262 m .69861 .18685 L .69759 .19171 L p F P
0 g
s
.16 .171 .622 r
.77846 .22239 m .77788 .22409 L .7758 .22045 L p F P
0 g
s
.16 .171 .622 r
.7758 .22045 m .7771 .21661 L .77846 .22239 L p F P
0 g
s
.823 .988 .725 r
.74359 .31385 m .74208 .31444 L .7457 .31009 L closepath p F P
0 g
s
.763 .92 .55 r
.75735 .29285 m .75472 .29802 L .7584 .29228 L p F P
0 g
s
.763 .92 .55 r
.75988 .28893 m .75735 .29285 L p .7584 .29228 L F P
0 g
s
.763 .92 .55 r
.7584 .29228 m .7604 .28843 L .75988 .28893 L p F P
0 g
s
.818 .999 .832 r
.72411 .33541 m .724 .33541 L .72429 .33514 L closepath p F P
0 g
s
.8 .996 .862 r
.71381 .34477 m .70812 .34968 L .71181 .34471 L closepath p F P
0 g
s
.801 .991 .879 r
.71156 .34467 m .71181 .34471 L .70812 .34968 L p F P
0 g
s
.801 .991 .879 r
.70303 .35176 m .71156 .34467 L p .70812 .34968 L F P
0 g
s
.801 .991 .879 r
.70192 .35329 m .70303 .35176 L p .70812 .34968 L F P
0 g
s
.691 .836 .953 r
.58533 .40719 m .58793 .40916 L .57761 .41354 L p F P
0 g
s
.691 .836 .953 r
.58396 .40776 m .58533 .40719 L p .57761 .41354 L F P
0 g
s
.691 .836 .953 r
.57761 .41354 m .57647 .41264 L .58396 .40776 L p F P
0 g
s
.812 .65 .682 r
.31245 .39996 m .30746 .39782 L .31002 .40437 L closepath p F P
0 g
s
0 0 .049 r
.77475 .25593 m .77264 .26098 L .77375 .25617 L p F P
0 g
s
0 0 .049 r
.77496 .255 m .77475 .25593 L p .77375 .25617 L F P
0 g
s
0 0 .049 r
.77375 .25617 m .77531 .25245 L .77496 .255 L p F P
0 g
s
.83 .595 .583 r
.29737 .38788 m .30295 .39026 L .3039 .38554 L p F P
0 g
s
.83 .595 .583 r
.3039 .38554 m .29828 .38318 L .29737 .38788 L p F P
0 g
s
0 0 0 r
.57097 .32088 m .56442 .32698 L .56935 .32082 L p F P
0 g
s
0 0 0 r
.56935 .32082 m .57219 .31817 L .57097 .32088 L p F P
0 g
s
0 0 0 r
.76901 .27113 m .76825 .27294 L .76918 .27047 L p F P
0 g
s
0 0 0 r
.76918 .27047 m .77105 .26597 L .76901 .27113 L p F P
0 g
s
.72 .895 .959 r
.62408 .39776 m .61373 .40295 L .6112 .40145 L p F P
0 g
s
0 0 .174 r
.77579 .25114 m .77531 .25245 L .77545 .24888 L p F P
0 g
s
0 0 .174 r
.77545 .24888 m .77631 .24653 L .77579 .25114 L p F P
0 g
s
0 0 .01 r
.56334 .32796 m .563 .32886 L .56442 .32698 L closepath p F P
0 g
s
.821 .999 .834 r
.72179 .33548 m .72772 .32976 L .72429 .33514 L p F P
0 g
s
.821 .999 .834 r
.72429 .33514 m .724 .33541 L .72179 .33548 L p F P
0 g
s
.809 .999 .835 r
.71661 .34227 m .724 .33541 L .72179 .33548 L p F P
0 g
s
.81 .996 .857 r
.71661 .34227 m .71381 .34477 L .71181 .34471 L p F P
0 g
s
.83 .625 .625 r
.30858 .3926 m .30586 .39137 L .3072 .39685 L closepath p F P
0 g
s
.809 .999 .835 r
.72179 .33548 m .7204 .33678 L .71661 .34227 L p F P
0 g
s
.81 .996 .857 r
.71223 .3441 m .7204 .33678 L .71661 .34227 L p F P
0 g
s
.81 .996 .857 r
.71181 .34471 m .71223 .3441 L p .71661 .34227 L F P
0 g
s
.709 .877 .96 r
.60179 .40697 m .60085 .40636 L .6054 .40423 L closepath p F P
0 g
s
.858 .995 .819 r
.63028 .24878 m .629 .24886 L .63177 .24591 L closepath p F P
0 g
s
.893 .49 .242 r
.26186 .33839 m .26216 .33923 L .26619 .34224 L p F P
0 g
s
.901 .516 .286 r
.26331 .34311 m .26739 .3461 L .26619 .34224 L p F P
0 g
s
.901 .516 .286 r
.26619 .34224 m .26216 .33923 L .26331 .34311 L p F P
0 g
s
.632 .593 .792 r
.51006 .41057 m .51162 .41399 L .52136 .40989 L p F P
0 g
s
.643 .625 .816 r
.52305 .41305 m .52136 .40989 L .51162 .41399 L p F P
0 g
s
.594 .731 .939 r
.24806 .41493 m .25777 .41296 L .2609 .416 L p F P
0 g
s
.602 .73 .935 r
.25777 .41296 m .24806 .41493 L .2449 .41198 L p F P
0 g
s
.724 .786 .902 r
.71492 .18382 m .71342 .18195 L .71612 .18059 L closepath p F P
0 g
s
.741 .919 .952 r
.64013 .39165 m .63691 .39346 L .63443 .3922 L p F P
0 g
s
.48 .273 .52 r
.52457 .38013 m .5199 .38241 L .52 .37791 L p F P
0 g
s
.48 .273 .52 r
.52 .37791 m .52454 .37569 L .52457 .38013 L p F P
0 g
s
.503 .705 .961 r
.21936 .40792 m .22891 .40733 L .2321 .41026 L p F P
0 g
s
.508 .704 .959 r
.22891 .40733 m .21936 .40792 L .21615 .40499 L p F P
0 g
s
.658 .722 .896 r
.52578 .41733 m .53605 .41399 L .53875 .41745 L p F P
0 g
s
.648 .683 .869 r
.53605 .41399 m .52578 .41733 L .52305 .41305 L p F P
0 g
s
.53 .586 .855 r
.75493 .18595 m .76177 .18606 L .76069 .1909 L p F P
0 g
s
.486 .53 .827 r
.76591 .18647 m .76177 .18606 L .76069 .1909 L p F P
0 g
s
.486 .53 .827 r
.76069 .1909 m .76844 .1921 L .76591 .18647 L p F P
0 g
s
.677 .917 .594 r
.60873 .27231 m .60903 .27212 L .60584 .27711 L p F P
0 g
s
.677 .917 .594 r
.60449 .2776 m .60873 .27231 L p .60584 .27711 L F P
0 g
s
.677 .917 .594 r
.60082 .28289 m .60449 .2776 L p .60584 .27711 L F P
0 g
s
.677 .917 .594 r
.60584 .27711 m .60105 .2827 L .60082 .28289 L p F P
0 g
s
.895 .526 .332 r
.26841 .35004 m .27271 .35294 L .27163 .34902 L p F P
0 g
s
.895 .526 .332 r
.27163 .34902 m .26739 .3461 L .26841 .35004 L p F P
0 g
s
.759 .802 .887 r
.71342 .18195 m .70302 .1881 L .70061 .18545 L p F P
0 g
s
.68 .81 .945 r
.57499 .41142 m .56468 .41547 L .56202 .413 L p F P
0 g
s
.675 .799 .941 r
.55172 .41679 m .56202 .413 L .56468 .41547 L p F P
0 g
s
.586 .46 .675 r
.51754 .40003 m .51637 .39504 L .50664 .39917 L p F P
0 g
s
.586 .46 .675 r
.50664 .39917 m .5073 .40214 L .51754 .40003 L p F P
0 g
s
.262 .286 .698 r
.77446 .21219 m .77517 .20998 L .77644 .21424 L closepath p F P
0 g
s
.505 .327 .573 r
.52353 .38562 m .51555 .38961 L .5152 .38476 L p F P
0 g
s
.505 .327 .573 r
.5152 .38476 m .5199 .38241 L .52353 .38562 L p F P
0 g
s
0 0 0 r
.58223 .30563 m .58079 .30792 L .58544 .30196 L closepath p F P
0 g
s
.762 .961 .933 r
.67035 .37563 m .66771 .37737 L .66958 .37539 L closepath p F P
0 g
s
.76 .951 .938 r
.66796 .37476 m .66958 .37539 L .66771 .37737 L p F P
0 g
s
.76 .951 .938 r
.65827 .38096 m .66796 .37476 L p .66771 .37737 L F P
0 g
s
.76 .951 .938 r
.65781 .38145 m .65827 .38096 L p .66771 .37737 L F P
0 g
s
.726 .241 0 r
.23372 .30543 m .23696 .3088 L .23467 .30542 L p F P
0 g
s
.726 .241 0 r
.23467 .30542 m .23144 .30204 L .23372 .30543 L p F P
0 g
s
.666 .765 .924 r
.53875 .41745 m .54904 .41391 L .55172 .41679 L p F P
0 g
s
.659 .735 .905 r
.54904 .41391 m .53875 .41745 L .53605 .41399 L p F P
0 g
s
.886 .536 .379 r
.27356 .35696 m .27812 .35975 L .2772 .35576 L p F P
0 g
s
.886 .536 .379 r
.2772 .35576 m .27271 .35294 L .27356 .35696 L p F P
0 g
s
0 0 .056 r
.57066 .32166 m .57097 .32088 L .56442 .32698 L p F P
0 g
s
0 0 .056 r
.56759 .32597 m .57066 .32166 L p .56442 .32698 L F P
0 g
s
0 0 .056 r
.56227 .3309 m .56759 .32597 L p .56442 .32698 L F P
0 g
s
0 0 .056 r
.56442 .32698 m .563 .32886 L .56227 .3309 L p F P
0 g
s
.67 .777 .93 r
.56202 .413 m .55172 .41679 L .54904 .41391 L p F P
0 g
s
.78 .648 .716 r
.31002 .40437 m .30911 .40554 L .31076 .40607 L closepath p F P
0 g
s
.764 .673 .761 r
.31076 .40607 m .30911 .40554 L .30172 .41257 L p F P
0 g
s
.546 .599 .857 r
.76177 .18606 m .75493 .18595 L .75247 .18142 L p F P
0 g
s
.742 .933 .951 r
.64726 .38754 m .64013 .39165 L .64539 .38671 L closepath p F P
0 g
s
.741 .919 .952 r
.6448 .38641 m .64539 .38671 L .64013 .39165 L p F P
0 g
s
.741 .919 .952 r
.63443 .3922 m .6448 .38641 L p .64013 .39165 L F P
0 g
s
.355 .626 .955 r
.17181 .38825 m .17368 .38849 L .17729 .39163 L p F P
0 g
s
.369 .632 .955 r
.18111 .38934 m .17368 .38849 L .17729 .39163 L p F P
0 g
s
.369 .632 .955 r
.17729 .39163 m .18436 .39245 L .18111 .38934 L p F P
0 g
s
.864 .538 .432 r
.28369 .36286 m .28312 .36377 L .28291 .36245 L closepath p F P
0 g
s
.619 .546 .75 r
.50823 .40552 m .51006 .41057 L .5203 .40766 L p F P
0 g
s
.632 .593 .792 r
.52136 .40989 m .5203 .40766 L .51006 .41057 L p F P
0 g
s
.792 .949 .608 r
.7532 .29877 m .75735 .29285 L .75472 .29802 L p F P
0 g
s
.792 .949 .608 r
.75143 .3023 m .7532 .29877 L p .75472 .29802 L F P
0 g
s
.792 .949 .608 r
.75472 .29802 m .75206 .30182 L .75143 .3023 L p F P
0 g
s
.408 .658 .961 r
.18761 .39551 m .19028 .39567 L .19411 .39872 L p F P
0 g
s
.417 .661 .961 r
.197 .39602 m .19028 .39567 L .19411 .39872 L p F P
0 g
s
.417 .661 .961 r
.19411 .39872 m .20024 .39905 L .197 .39602 L p F P
0 g
s
.69 .921 .597 r
.60105 .2827 m .60044 .28343 L .60082 .28289 L closepath p F P
0 g
s
.594 .492 .707 r
.51793 .40135 m .51754 .40003 L .5073 .40214 L p F P
0 g
s
.594 .492 .707 r
.5073 .40214 m .50823 .40552 L .51793 .40135 L p F P
0 g
s
.352 .387 .758 r
.77186 .20437 m .77251 .20224 L .77366 .20548 L closepath p F P
0 g
s
.425 .468 .801 r
.76753 .19718 m .76878 .19289 L .77102 .19838 L closepath p F P
0 g
s
.846 .935 .884 r
.66697 .21141 m .65951 .21803 L .65906 .2178 L p F P
0 g
s
.862 .933 .869 r
.65951 .21803 m .65877 .21873 L .65906 .2178 L closepath p F P
0 g
s
.864 .935 .867 r
.65333 .2206 m .65141 .22575 L .65877 .21873 L p F P
0 g
s
.864 .935 .867 r
.65709 .21684 m .65333 .2206 L p .65877 .21873 L F P
0 g
s
.864 .935 .867 r
.65877 .21873 m .65906 .2178 L .65709 .21684 L p F P
0 g
s
.812 .616 .638 r
.30686 .3976 m .3072 .39685 L .30586 .39137 L p F P
0 g
s
.812 .616 .638 r
.30097 .39535 m .30686 .3976 L p .30586 .39137 L F P
0 g
s
.812 .616 .638 r
.30586 .39137 m .30295 .39026 L .30097 .39535 L p F P
0 g
s
.792 .644 .698 r
.30911 .40554 m .31002 .40437 L .30746 .39782 L p F P
0 g
s
.334 .099 .401 r
.54272 .35823 m .54286 .35699 L .53421 .36259 L p F P
0 g
s
.334 .099 .401 r
.54082 .36192 m .54272 .35823 L p .53421 .36259 L F P
0 g
s
.334 .099 .401 r
.53421 .36259 m .5338 .36649 L .54082 .36192 L p F P
0 g
s
.008 0 .069 r
.563 .32886 m .55962 .3331 L .56227 .3309 L closepath p F P
0 g
s
.774 .962 .927 r
.67831 .36781 m .68068 .36861 L .67035 .37563 L p F P
0 g
s
.774 .962 .927 r
.67306 .37139 m .67831 .36781 L p .67035 .37563 L F P
0 g
s
.774 .962 .927 r
.67035 .37563 m .66958 .37539 L .67306 .37139 L p F P
0 g
s
.676 .908 .573 r
.59896 .28461 m .59534 .28964 L .60044 .28343 L p F P
0 g
s
.676 .908 .573 r
.60044 .28343 m .60082 .28289 L .59896 .28461 L p F P
0 g
s
.679 .809 .357 r
.76644 .27648 m .76408 .28159 L .76672 .27621 L p F P
0 g
s
.679 .809 .357 r
.76759 .27415 m .76644 .27648 L p .76672 .27621 L F P
0 g
s
.679 .809 .357 r
.76672 .27621 m .76825 .27294 L .76759 .27415 L p F P
0 g
s
.639 .733 .916 r
.2609 .416 m .2707 .41314 L .2738 .41636 L p F P
0 g
s
.649 .732 .91 r
.2707 .41314 m .2609 .416 L .25777 .41296 L p F P
0 g
s
0 0 .43 r
.7798 .2322 m .77804 .23718 L .77743 .233 L p F P
0 g
s
0 0 .43 r
.77743 .233 m .77918 .22802 L .7798 .2322 L p F P
0 g
s
.847 .907 .877 r
.66973 .20894 m .66697 .21141 L .66794 .20775 L closepath p F P
0 g
s
.846 .935 .884 r
.66731 .20734 m .66794 .20775 L .66697 .21141 L p F P
0 g
s
.846 .935 .884 r
.6606 .2136 m .66731 .20734 L p .66697 .21141 L F P
0 g
s
.846 .935 .884 r
.65906 .2178 m .6606 .2136 L p .66697 .21141 L F P
0 g
s
.771 .287 0 r
.23746 .30959 m .23696 .3088 L .24035 .31211 L p F P
0 g
s
.771 .287 0 r
.24035 .31211 m .24064 .31257 L .23746 .30959 L p F P
0 g
s
.873 .545 .425 r
.27875 .36386 m .27812 .35975 L .28291 .36245 L p F P
0 g
s
.873 .545 .425 r
.28182 .36557 m .27875 .36386 L p .28291 .36245 L F P
0 g
s
.873 .545 .425 r
.28291 .36245 m .28312 .36377 L .28182 .36557 L p F P
0 g
s
.83 .908 .892 r
.67598 .20379 m .66973 .20894 L .66794 .20775 L p F P
0 g
s
.858 .961 .871 r
.6469 .22695 m .65333 .2206 L .65141 .22575 L p F P
0 g
s
.858 .961 .871 r
.65141 .22575 m .64932 .22773 L .6469 .22695 L p F P
0 g
s
.758 .716 .812 r
.30172 .41257 m .29709 .41032 L .2998 .41403 L closepath p F P
0 g
s
.88 .967 .845 r
.64454 .23259 m .64932 .22773 L .6469 .22695 L p F P
0 g
s
.792 .644 .698 r
.30305 .40336 m .30911 .40554 L p .30746 .39782 L F P
0 g
s
.774 .673 .752 r
.29709 .41032 m .30172 .41257 L .30911 .40554 L p F P
0 g
s
.774 .673 .752 r
.29678 .40989 m .29709 .41032 L p .30911 .40554 L F P
0 g
s
.774 .673 .752 r
.30911 .40554 m .30305 .40336 L .29678 .40989 L p F P
0 g
s
.3 .589 .944 r
.15609 .3802 m .1587 .38072 L .16212 .38395 L p F P
0 g
s
.317 .598 .946 r
.16527 .38189 m .1587 .38072 L .16212 .38395 L p F P
0 g
s
.317 .598 .946 r
.16212 .38395 m .16855 .3851 L .16527 .38189 L p F P
0 g
s
.619 .546 .75 r
.5203 .40766 m .51793 .40135 L .50823 .40552 L p F P
0 g
s
.69 .829 .95 r
.57647 .41264 m .57499 .41142 L .58396 .40776 L closepath p F P
0 g
s
.456 .683 .963 r
.20347 .40203 m .20913 .40204 L .21314 .405 L p F P
0 g
s
.462 .683 .961 r
.20913 .40204 m .20347 .40203 L .20024 .39905 L p F P
0 g
s
.712 .867 .955 r
.6054 .40423 m .60085 .40636 L .59828 .40457 L p F P
0 g
s
.7 .864 .96 r
.58793 .40916 m .59828 .40457 L .60085 .40636 L p F P
0 g
s
.095 0 .176 r
.55332 .34055 m .55285 .34229 L .55506 .33913 L closepath p F P
0 g
s
.878 .582 .484 r
.28362 .37088 m .28833 .3736 L .28814 .36932 L p F P
0 g
s
.878 .582 .484 r
.28814 .36932 m .28346 .36659 L .28362 .37088 L p F P
0 g
s
.677 .72 .881 r
.72631 .17995 m .73689 .17587 L .73931 .17962 L p F P
0 g
s
.689 .731 .883 r
.73689 .17587 m .72631 .17995 L .7239 .17663 L p F P
0 g
s
.864 .417 .051 r
.24388 .31931 m .24739 .32256 L .24567 .31893 L p F P
0 g
s
.864 .417 .051 r
.24567 .31893 m .24218 .31568 L .24388 .31931 L p F P
0 g
s
.88 .967 .845 r
.6469 .22695 m .64641 .22746 L .64454 .23259 L p F P
0 g
s
.862 .982 .85 r
.64019 .23407 m .64641 .22746 L .64454 .23259 L p F P
0 g
s
.862 .982 .85 r
.63849 .23791 m .64019 .23407 L p .64454 .23259 L F P
0 g
s
.862 .982 .85 r
.64454 .23259 m .63915 .238 L .63849 .23791 L p F P
0 g
s
.839 .893 .878 r
.67598 .20379 m .67998 .20046 L .67756 .1985 L p F P
0 g
s
.839 .893 .878 r
.67756 .1985 m .67711 .1989 L .67598 .20379 L p F P
0 g
s
.83 .908 .892 r
.66839 .20642 m .67711 .1989 L .67598 .20379 L p F P
0 g
s
.83 .908 .892 r
.66794 .20775 m .66839 .20642 L p .67598 .20379 L F P
0 g
s
.549 .722 .953 r
.2321 .41026 m .23673 .40966 L .24116 .41244 L p F P
0 g
s
.547 .717 .952 r
.24173 .40898 m .23673 .40966 L .24116 .41244 L p F P
0 g
s
.547 .717 .952 r
.24116 .41244 m .2449 .41198 L .24173 .40898 L p F P
0 g
s
.693 .914 .576 r
.59955 .28376 m .59896 .28461 L .60082 .28289 L p F P
0 g
s
.693 .914 .576 r
.60082 .28289 m .60449 .2776 L .59955 .28376 L p F P
0 g
s
.624 .666 .87 r
.75013 .17726 m .74852 .18212 L p .73931 .17962 L F P
0 g
s
.602 .651 .871 r
.74852 .18212 m .75013 .17726 L .75247 .18142 L closepath p F P
0 g
s
.729 .905 .957 r
.62443 .39795 m .62408 .39776 L .62549 .39701 L closepath p F P
0 g
s
.847 .393 0 r
.24218 .31568 m .24064 .31257 L .23746 .30959 L p F P
0 g
s
.776 .946 .609 r
.75206 .30182 m .75052 .30394 L .75143 .3023 L closepath p F P
0 g
s
.803 .616 .649 r
.3072 .39685 m .30686 .3976 L .30746 .39782 L closepath p F P
0 g
s
.042 0 .113 r
.5613 .33399 m .55506 .33913 L .55962 .3331 L p F P
0 g
s
.042 0 .113 r
.55962 .3331 m .56227 .3309 L .5613 .33399 L p F P
0 g
s
.81 .881 .897 r
.68624 .19571 m .67998 .20046 L .67756 .1985 L p F P
0 g
s
.684 .725 .881 r
.2738 .41636 m .2837 .41224 L .28677 .41579 L p F P
0 g
s
.696 .723 .871 r
.2837 .41224 m .2738 .41636 L .2707 .41314 L p F P
0 g
s
.624 .666 .87 r
.73931 .17962 m .75002 .17707 L .75013 .17726 L p F P
0 g
s
.638 .68 .873 r
.75002 .17707 m .73931 .17962 L .73689 .17587 L p F P
0 g
s
.792 .644 .698 r
.30746 .39782 m .30686 .3976 L .30305 .40336 L p F P
0 g
s
.862 .594 .531 r
.28807 .37806 m .29303 .38068 L .29328 .37622 L p F P
0 g
s
.862 .594 .531 r
.29328 .37622 m .28833 .3736 L .28807 .37806 L p F P
0 g
s
.462 .684 .962 r
.21294 .40201 m .20913 .40204 L .21314 .405 L p F P
0 g
s
.462 .684 .962 r
.21314 .405 m .21615 .40499 L .21294 .40201 L p F P
0 g
s
.877 .979 .838 r
.63915 .238 m .6379 .23934 L .63849 .23791 L closepath p F P
0 g
s
.725 .711 .837 r
.29709 .41032 m .29645 .41012 L .28677 .41579 L p F P
0 g
s
.733 .738 .855 r
.29645 .41012 m .28677 .41579 L .2837 .41224 L p F P
0 g
s
0 0 0 r
.77311 .26094 m .77105 .26597 L .77264 .26098 L p F P
0 g
s
0 0 0 r
.77264 .26098 m .77475 .25593 L .77311 .26094 L p F P
0 g
s
.855 .937 .877 r
.65906 .2178 m .65709 .21684 L .6606 .2136 L closepath p F P
0 g
s
.875 .436 .102 r
.24903 .32623 m .25272 .3294 L .25105 .32574 L p F P
0 g
s
.875 .436 .102 r
.25105 .32574 m .24739 .32256 L .24903 .32623 L p F P
0 g
s
.878 .98 .833 r
.63415 .24062 m .63177 .24591 L .6379 .23934 L p F P
0 g
s
.878 .98 .833 r
.63672 .23772 m .63415 .24062 L p .6379 .23934 L F P
0 g
s
.878 .98 .833 r
.6379 .23934 m .63849 .23791 L .63672 .23772 L p F P
0 g
s
0 0 .159 r
.77752 .2462 m .77579 .25114 L .77631 .24653 L p F P
0 g
s
0 0 .159 r
.77631 .24653 m .77806 .24158 L .77752 .2462 L p F P
0 g
s
.557 .722 .951 r
.23673 .40966 m .2321 .41026 L .22891 .40733 L p F P
0 g
s
.799 .645 .691 r
.29751 .40098 m .30305 .40336 L .30686 .3976 L p F P
0 g
s
.799 .645 .691 r
.30686 .3976 m .30097 .39535 L .29751 .40098 L p F P
0 g
s
0 0 0 r
.5986 .28497 m .59896 .28461 L .59534 .28964 L p F P
0 g
s
0 0 0 r
.59489 .28982 m .5986 .28497 L p .59534 .28964 L F P
0 g
s
0 0 0 r
.59534 .28964 m .59092 .29503 L .5907 .2953 L p F P
0 g
s
0 0 0 r
.5907 .2953 m .59489 .28982 L p .59534 .28964 L F P
0 g
s
.844 .607 .581 r
.29215 .38537 m .29737 .38788 L .29828 .38318 L p F P
0 g
s
.844 .607 .581 r
.29828 .38318 m .29303 .38068 L .29215 .38537 L p F P
0 g
s
.897 .492 .226 r
.26186 .33839 m .26216 .33923 L .26034 .33779 L closepath p F P
0 g
s
.811 .978 .687 r
.74857 .30486 m .7457 .31009 L .75052 .30394 L p F P
0 g
s
.811 .978 .687 r
.75 .30302 m .74857 .30486 L p .75052 .30394 L F P
0 g
s
.811 .978 .687 r
.75052 .30394 m .75143 .3023 L .75 .30302 L p F P
0 g
s
.781 .964 .923 r
.68084 .36867 m .68068 .36861 L .68118 .36826 L closepath p F P
0 g
s
.823 .624 .634 r
.29552 .39293 m .30097 .39535 L .30295 .39026 L p F P
0 g
s
.823 .624 .634 r
.30295 .39026 m .29737 .38788 L .29552 .39293 L p F P
0 g
s
.887 .567 .436 r
.28312 .36377 m .28346 .36659 L .28182 .36557 L closepath p F P
0 g
s
.752 .934 .946 r
.65517 .38024 m .65761 .38137 L .64726 .38754 L p F P
0 g
s
.752 .934 .946 r
.64684 .38522 m .65517 .38024 L p .64726 .38754 L F P
0 g
s
.752 .934 .946 r
.64726 .38754 m .64539 .38671 L .64684 .38522 L p F P
0 g
s
.413 .657 .959 r
.19028 .39567 m .18761 .39551 L .18436 .39245 L p F P
0 g
s
0 0 0 r
.57177 .32006 m .57097 .32088 L .57219 .31817 L p F P
0 g
s
0 0 0 r
.57219 .31817 m .57616 .31408 L .57177 .32006 L p F P
0 g
s
.831 1 .805 r
.73296 .32537 m .73197 .32548 L .73439 .32297 L closepath p F P
0 g
s
.731 .897 .954 r
.62549 .39701 m .62408 .39776 L .62156 .39626 L p F P
0 g
s
.72 .895 .959 r
.6112 .40145 m .62156 .39626 L .62408 .39776 L p F P
0 g
s
.448 .248 .515 r
.53363 .37507 m .53359 .37062 L .52454 .37569 L p F P
0 g
s
.448 .248 .515 r
.52454 .37569 m .52457 .38013 L .53363 .37507 L p F P
0 g
s
.882 .453 .155 r
.25429 .33311 m .25818 .33619 L .25657 .3325 L p F P
0 g
s
.882 .453 .155 r
.25657 .3325 m .25272 .3294 L .25429 .33311 L p F P
0 g
s
.793 .974 .91 r
.6916 .36128 m .69099 .36112 L .69276 .35979 L closepath p F P
0 g
s
.725 .792 .905 r
.71612 .18059 m .71342 .18195 L .71102 .17902 L p F P
0 g
s
.759 .802 .887 r
.70061 .18545 m .71102 .17902 L .71342 .18195 L p F P
0 g
s
.818 .868 .883 r
.68624 .19571 m .69027 .19262 L .68786 .19034 L p F P
0 g
s
.818 .868 .883 r
.68786 .19034 m .68719 .19088 L .68624 .19571 L p F P
0 g
s
.81 .881 .897 r
.67756 .1985 m .68719 .19088 L .68624 .19571 L p F P
0 g
s
.283 .33 .734 r
.77366 .20548 m .77584 .2073 L .77517 .20998 L closepath p F P
0 g
s
.157 .217 .675 r
.77864 .21067 m .77584 .2073 L .77517 .20998 L p F P
0 g
s
.157 .217 .675 r
.7774 .2155 m .77864 .21067 L p .77517 .20998 L F P
0 g
s
.157 .217 .675 r
.77517 .20998 m .77644 .21424 L .7774 .2155 L p F P
0 g
s
.784 .961 .924 r
.68118 .36826 m .68068 .36861 L .67831 .36781 L p F P
0 g
s
.854 .997 .814 r
.62841 .24706 m .63415 .24062 L .63177 .24591 L p F P
0 g
s
.854 .997 .814 r
.62745 .24902 m .62841 .24706 L p .63177 .24591 L F P
0 g
s
.854 .997 .814 r
.63177 .24591 m .629 .24886 L .62745 .24902 L p F P
0 g
s
.306 .588 .942 r
.1587 .38072 m .15609 .3802 L .1528 .37693 L p F P
0 g
s
.786 .971 .916 r
.68118 .36826 m .69099 .36112 L .68865 .36047 L p F P
0 g
s
.786 .971 .916 r
.68865 .36047 m .68587 .36249 L .68118 .36826 L p F P
0 g
s
.784 .961 .924 r
.67831 .36781 m .68587 .36249 L .68118 .36826 L p F P
0 g
s
.712 .867 .955 r
.60864 .39978 m .60996 .40067 L .6054 .40423 L p F P
0 g
s
.712 .867 .955 r
.59828 .40457 m .60864 .39978 L p .6054 .40423 L F P
0 g
s
.713 .883 .96 r
.6112 .40145 m .6054 .40423 L .60996 .40067 L closepath p F P
0 g
s
.732 .913 .956 r
.63443 .3922 m .62549 .39701 L .6322 .39102 L closepath p F P
0 g
s
.731 .897 .954 r
.63194 .39087 m .6322 .39102 L .62549 .39701 L p F P
0 g
s
.731 .897 .954 r
.62156 .39626 m .63194 .39087 L p .62549 .39701 L F P
0 g
s
.361 .624 .953 r
.17368 .38849 m .17181 .38825 L .16855 .3851 L p F P
0 g
s
.772 .95 .934 r
.66958 .37539 m .66796 .37476 L .67306 .37139 L closepath p F P
0 g
s
.699 .855 .957 r
.59828 .40457 m .58793 .40916 L .58533 .40719 L p F P
0 g
s
.257 .326 .744 r
.77251 .20224 m .77366 .20548 L .77584 .2073 L p F P
0 g
s
.834 .996 .765 r
.61942 .26011 m .61886 .26029 L .62015 .25883 L closepath p F P
0 g
s
.789 .854 .9 r
.69861 .18685 m .69027 .19262 L .68786 .19034 L p F P
0 g
s
.047 .049 .536 r
.77936 .22749 m .77918 .22802 L .77788 .22409 L p F P
0 g
s
.047 .049 .536 r
.77788 .22409 m .77846 .22239 L .77936 .22749 L p F P
0 g
s
.194 .229 .671 r
.77644 .21424 m .7774 .2155 L .7771 .21661 L closepath p F P
0 g
s
.908 .524 .281 r
.2594 .34005 m .26331 .34311 L .26216 .33923 L p F P
0 g
s
.908 .524 .281 r
.25859 .33729 m .2594 .34005 L p .26216 .33923 L F P
0 g
s
.908 .524 .281 r
.26216 .33923 m .26034 .33779 L .25859 .33729 L p F P
0 g
s
.87 .994 .804 r
.629 .24886 m .62586 .25241 L .62745 .24902 L closepath p F P
0 g
s
.533 .383 .624 r
.52575 .39042 m .51637 .39504 L .51555 .38961 L p F P
0 g
s
.533 .383 .624 r
.52503 .38593 m .52575 .39042 L p .51555 .38961 L F P
0 g
s
.533 .383 .624 r
.51555 .38961 m .52353 .38562 L .52503 .38593 L p F P
0 g
s
.508 .327 .57 r
.5249 .38496 m .52353 .38562 L .5199 .38241 L p F P
0 g
s
.508 .327 .57 r
.5199 .38241 m .52457 .38013 L .5249 .38496 L p F P
0 g
s
.648 .683 .869 r
.52305 .41305 m .53332 .40992 L .53605 .41399 L p F P
0 g
s
.641 .63 .823 r
.52136 .40989 m .52305 .41305 L .53332 .40992 L p F P
0 g
s
.748 .879 .467 r
.76332 .28204 m .76102 .28711 L .76408 .28159 L p F P
0 g
s
.748 .879 .467 r
.76408 .28159 m .76644 .27648 L .76332 .28204 L p F P
0 g
s
0 0 0 r
.59092 .29503 m .59026 .29584 L .5907 .2953 L closepath p F P
0 g
s
.134 0 .208 r
.56053 .3368 m .5613 .33399 L .55506 .33913 L p F P
0 g
s
.134 0 .208 r
.56006 .33751 m .56053 .3368 L p .55506 .33913 L F P
0 g
s
.134 0 .208 r
.55248 .34382 m .56006 .33751 L p .55506 .33913 L F P
0 g
s
.134 0 .208 r
.55506 .33913 m .55285 .34229 L .55248 .34382 L p F P
0 g
s
.358 .412 .781 r
.77102 .19838 m .77312 .19951 L .77251 .20224 L closepath p F P
0 g
s
.257 .326 .744 r
.777 .20247 m .77312 .19951 L .77251 .20224 L p F P
0 g
s
.257 .326 .744 r
.77584 .2073 m .777 .20247 L p .77251 .20224 L F P
0 g
s
0 0 0 r
.58912 .29745 m .58544 .30196 L .59026 .29584 L p F P
0 g
s
0 0 0 r
.59026 .29584 m .5907 .2953 L .58912 .29745 L p F P
0 g
s
.102 .132 .606 r
.77933 .2192 m .77846 .22239 L .7771 .21661 L p F P
0 g
s
.102 .132 .606 r
.7771 .21661 m .7774 .2155 L .77933 .2192 L p F P
0 g
s
.735 .79 .897 r
.71612 .18059 m .7239 .17663 L .72149 .17338 L p F P
0 g
s
.735 .79 .897 r
.72149 .17338 m .71723 .17568 L .71612 .18059 L p F P
0 g
s
.725 .792 .905 r
.71102 .17902 m .71723 .17568 L .71612 .18059 L p F P
0 g
s
.241 0 .32 r
.54349 .35653 m .54286 .35699 L .54345 .35336 L p F P
0 g
s
.241 0 .32 r
.54345 .35336 m .5468 .35092 L .54349 .35653 L p F P
0 g
s
.904 .536 .326 r
.26429 .34706 m .26841 .35004 L .26739 .3461 L p F P
0 g
s
.904 .536 .326 r
.26739 .3461 m .26331 .34311 L .26429 .34706 L p F P
0 g
s
.825 .989 .726 r
.74329 .31118 m .74857 .30486 L .7457 .31009 L p F P
0 g
s
.825 .989 .726 r
.7414 .3147 m .74329 .31118 L p .7457 .31009 L F P
0 g
s
.825 .989 .726 r
.7457 .31009 m .74208 .31444 L .7414 .3147 L p F P
0 g
s
.804 .982 .895 r
.70192 .35329 m .70128 .35316 L .70303 .35176 L closepath p F P
0 g
s
0 0 .024 r
.77531 .25245 m .77496 .255 L .77579 .25114 L closepath p F P
0 g
s
.789 .925 .55 r
.7604 .28843 m .75988 .28893 L .76102 .28711 L closepath p F P
0 g
s
.87 .995 .797 r
.62299 .25339 m .62015 .25883 L .62586 .25241 L p F P
0 g
s
.87 .995 .797 r
.62657 .24913 m .62299 .25339 L p .62586 .25241 L F P
0 g
s
.87 .995 .797 r
.62586 .25241 m .62745 .24902 L .62657 .24913 L p F P
0 g
s
.872 .982 .839 r
.63849 .23791 m .63672 .23772 L .64019 .23407 L closepath p F P
0 g
s
.546 .599 .857 r
.75247 .18142 m .76305 .18114 L .76177 .18606 L p F P
0 g
s
.539 .62 .881 r
.75013 .17726 m .75247 .18142 L .76305 .18114 L p F P
0 g
s
.792 .706 .769 r
.29379 .40531 m .29751 .40098 L .30305 .40336 L p F P
0 g
s
.792 .706 .769 r
.30305 .40336 m .29678 .40989 L .29379 .40531 L p F P
0 g
s
.897 .547 .375 r
.26922 .35407 m .27356 .35696 L .27271 .35294 L p F P
0 g
s
.897 .547 .375 r
.27271 .35294 m .26841 .35004 L .26922 .35407 L p F P
0 g
s
.602 .73 .935 r
.2449 .41198 m .25463 .40987 L .25777 .41296 L p F P
0 g
s
.609 .73 .931 r
.25463 .40987 m .2449 .41198 L .24173 .40898 L p F P
0 g
s
0 0 0 r
.59034 .29585 m .58912 .29745 L .5907 .2953 L p F P
0 g
s
0 0 0 r
.5907 .2953 m .59489 .28982 L .59034 .29585 L p F P
0 g
s
.692 .813 .94 r
.58396 .40776 m .57499 .41142 L .57235 .40905 L p F P
0 g
s
.68 .81 .945 r
.56202 .413 m .57235 .40905 L .57499 .41142 L p F P
0 g
s
.171 0 .222 r
.55285 .34229 m .55074 .34509 L .55248 .34382 L closepath p F P
0 g
s
.508 .704 .959 r
.21615 .40499 m .22571 .40435 L .22891 .40733 L p F P
0 g
s
.512 .703 .956 r
.22571 .40435 m .21615 .40499 L .21294 .40201 L p F P
0 g
s
.795 .971 .911 r
.69276 .35979 m .69099 .36112 L .68865 .36047 L p F P
0 g
s
.34 .415 .793 r
.76878 .19289 m .77102 .19838 L .77312 .19951 L p F P
0 g
s
.83 .978 .683 r
.75143 .3023 m .75 .30302 L .7532 .29877 L closepath p F P
0 g
s
.74 .7 .813 r
.29678 .40989 m .29645 .41012 L .29709 .41032 L closepath p F P
0 g
s
.812 .989 .73 r
.74208 .31444 m .74038 .31641 L .7414 .3147 L closepath p F P
0 g
s
.76 .939 .942 r
.65781 .38145 m .65761 .38137 L .65827 .38096 L closepath p F P
0 g
s
.797 .98 .901 r
.69276 .35979 m .70128 .35316 L .69898 .35265 L p F P
0 g
s
.797 .98 .901 r
.69898 .35265 m .69708 .35413 L .69276 .35979 L p F P
0 g
s
.795 .971 .911 r
.68865 .36047 m .69708 .35413 L .69276 .35979 L p F P
0 g
s
.659 .735 .905 r
.53605 .41399 m .54634 .41063 L .54904 .41391 L p F P
0 g
s
.648 .698 .882 r
.54634 .41063 m .53605 .41399 L .53332 .40992 L p F P
0 g
s
.885 .558 .425 r
.27414 .36109 m .27875 .36386 L .27812 .35975 L p F P
0 g
s
.885 .558 .425 r
.27812 .35975 m .27356 .35696 L .27414 .36109 L p F P
0 g
s
.789 .854 .9 r
.6982 .18287 m .69904 .18376 L .69861 .18685 L p F P
0 g
s
.789 .854 .9 r
.68786 .19034 m .6982 .18287 L p .69861 .18685 L F P
0 g
s
.786 .832 .887 r
.70061 .18545 m .69861 .18685 L .69904 .18376 L closepath p F P
0 g
s
0 0 .083 r
.56368 .33179 m .5613 .33399 L .56227 .3309 L p F P
0 g
s
0 0 .083 r
.56227 .3309 m .56759 .32597 L .56368 .33179 L p F P
0 g
s
.753 .697 .798 r
.29645 .41012 m .29678 .40989 L .29379 .40531 L p F P
0 g
s
.753 .697 .798 r
.29379 .40531 m .29043 .40791 L .29645 .41012 L p F P
0 g
s
.733 .738 .855 r
.2837 .41224 m .29043 .40791 L .29645 .41012 L p F P
0 g
s
.361 .624 .953 r
.16855 .3851 m .17015 .38531 L .17368 .38849 L p F P
0 g
s
.374 .63 .954 r
.17785 .38618 m .17015 .38531 L .17368 .38849 L p F P
0 g
s
.374 .63 .954 r
.17368 .38849 m .18111 .38934 L .17785 .38618 L p F P
0 g
s
.823 .994 .754 r
.6177 .25967 m .62299 .25339 L .62015 .25883 L p F P
0 g
s
.823 .994 .754 r
.617 .26097 m .6177 .25967 L p .62015 .25883 L F P
0 g
s
.823 .994 .754 r
.62015 .25883 m .61886 .26029 L .617 .26097 L p F P
0 g
s
.413 .657 .959 r
.18436 .39245 m .18654 .39259 L .19028 .39567 L p F P
0 g
s
.422 .66 .959 r
.19376 .39294 m .18654 .39259 L .19028 .39567 L p F P
0 g
s
.422 .66 .959 r
.19028 .39567 m .197 .39602 L .19376 .39294 L p F P
0 g
s
0 0 .3 r
.7798 .23662 m .77806 .24158 L .77804 .23718 L p F P
0 g
s
0 0 .3 r
.77804 .23718 m .7798 .2322 L .7798 .23662 L p F P
0 g
s
.828 .998 .782 r
.73748 .31768 m .73439 .32297 L .74038 .31641 L p F P
0 g
s
.828 .998 .782 r
.73994 .31497 m .73748 .31768 L p .74038 .31641 L F P
0 g
s
.828 .998 .782 r
.74038 .31641 m .7414 .3147 L .73994 .31497 L p F P
0 g
s
0 0 0 r
.77103 .26613 m .76901 .27113 L .77105 .26597 L p F P
0 g
s
0 0 0 r
.77105 .26597 m .77311 .26094 L .77103 .26613 L p F P
0 g
s
0 0 0 r
.58847 .29839 m .58912 .29745 L .58544 .30196 L p F P
0 g
s
0 0 0 r
.58597 .30182 m .58847 .29839 L p .58544 .30196 L F P
0 g
s
0 0 0 r
.58076 .30798 m .58597 .30182 L p .58544 .30196 L F P
0 g
s
0 0 0 r
.58544 .30196 m .58079 .30792 L .58076 .30798 L p F P
0 g
s
.1 .136 .611 r
.78063 .21434 m .77933 .2192 L .7774 .2155 L p F P
0 g
s
.1 .136 .611 r
.7774 .2155 m .77864 .21067 L .78063 .21434 L p F P
0 g
s
.72 .884 .957 r
.61903 .3947 m .62156 .39626 L .6112 .40145 L p F P
0 g
s
.72 .884 .957 r
.6142 .39709 m .61903 .3947 L p .6112 .40145 L F P
0 g
s
.72 .884 .957 r
.6112 .40145 m .60996 .40067 L .6142 .39709 L p F P
0 g
s
.675 .791 .936 r
.57235 .40905 m .56202 .413 L .55936 .41026 L p F P
0 g
s
.67 .777 .93 r
.54904 .41391 m .55936 .41026 L .56202 .413 L p F P
0 g
s
.841 .994 .749 r
.61886 .26029 m .61478 .26514 L .617 .26097 L closepath p F P
0 g
s
.208 0 .274 r
.55178 .34729 m .5468 .35092 L .55074 .34509 L p F P
0 g
s
.208 0 .274 r
.55074 .34509 m .55248 .34382 L .55178 .34729 L p F P
0 g
s
.625 .597 .802 r
.5203 .40766 m .52136 .40989 L .53073 .40528 L p F P
0 g
s
.641 .63 .823 r
.53332 .40992 m .53073 .40528 L .52136 .40989 L p F P
0 g
s
.762 .934 .941 r
.65827 .38096 m .65761 .38137 L .65517 .38024 L p F P
0 g
s
.768 .828 .899 r
.70861 .17615 m .71102 .17902 L .70061 .18545 L p F P
0 g
s
.768 .828 .899 r
.69953 .18202 m .70861 .17615 L p .70061 .18545 L F P
0 g
s
.768 .828 .899 r
.70061 .18545 m .69904 .18376 L .69953 .18202 L p F P
0 g
s
.888 .478 .224 r
.26034 .33779 m .25859 .33729 L .25818 .33619 L closepath p F P
0 g
s
.714 .821 .366 r
.76825 .27294 m .76759 .27415 L .76901 .27113 L closepath p F P
0 g
s
.886 .589 .479 r
.2806 .36901 m .28362 .37088 L .28346 .36659 L p F P
0 g
s
.886 .589 .479 r
.28346 .36659 m .28182 .36557 L .2806 .36901 L p F P
0 g
s
.662 .75 .915 r
.55936 .41026 m .54904 .41391 L .54634 .41063 L p F P
0 g
s
.764 .945 .939 r
.65827 .38096 m .66796 .37476 L .66555 .3738 L p F P
0 g
s
.764 .945 .939 r
.66555 .3738 m .66379 .37492 L .65827 .38096 L p F P
0 g
s
.762 .934 .941 r
.65517 .38024 m .66379 .37492 L .65827 .38096 L p F P
0 g
s
.813 .656 .687 r
.29236 .39846 m .29751 .40098 L .30097 .39535 L p F P
0 g
s
.813 .656 .687 r
.30097 .39535 m .29552 .39293 L .29236 .39846 L p F P
0 g
s
.369 .154 .451 r
.53926 .36694 m .53359 .37062 L .5338 .36649 L p F P
0 g
s
.369 .154 .451 r
.5338 .36649 m .54082 .36192 L .53926 .36694 L p F P
0 g
s
0 .006 .515 r
.78057 .22315 m .77936 .22749 L .77846 .22239 L p F P
0 g
s
0 .006 .515 r
.77846 .22239 m .77933 .2192 L .78057 .22315 L p F P
0 g
s
.756 .276 0 r
.23429 .30633 m .23372 .30543 L .23696 .3088 L p F P
0 g
s
.756 .276 0 r
.23696 .3088 m .23746 .30959 L .23429 .30633 L p F P
0 g
s
.557 .722 .951 r
.22891 .40733 m .23234 .40685 L .23673 .40966 L p F P
0 g
s
.555 .717 .949 r
.23856 .40594 m .23234 .40685 L .23673 .40966 L p F P
0 g
s
.555 .717 .949 r
.23673 .40966 m .24173 .40898 L .23856 .40594 L p F P
0 g
s
0 0 .021 r
.77649 .25099 m .77752 .2462 L .77579 .25114 L p F P
0 g
s
0 0 .021 r
.77488 .25561 m .77649 .25099 L p .77579 .25114 L F P
0 g
s
0 0 .021 r
.77579 .25114 m .77496 .255 L .77488 .25561 L p F P
0 g
s
.874 .604 .528 r
.28336 .37534 m .28807 .37806 L .28833 .3736 L p F P
0 g
s
.874 .604 .528 r
.28833 .3736 m .28362 .37088 L .28336 .37534 L p F P
0 g
s
.791 .926 .553 r
.7598 .28774 m .76332 .28204 L .76102 .28711 L p F P
0 g
s
.791 .926 .553 r
.75879 .28999 m .7598 .28774 L p .76102 .28711 L F P
0 g
s
.791 .926 .553 r
.76102 .28711 m .75988 .28893 L .75879 .28999 L p F P
0 g
s
.815 .989 .878 r
.71181 .34471 m .71156 .34467 L .71223 .3441 L closepath p F P
0 g
s
.306 .588 .942 r
.1528 .37693 m .15537 .37744 L .1587 .38072 L p F P
0 g
s
.323 .597 .944 r
.162 .37862 m .15537 .37744 L .1587 .38072 L p F P
0 g
s
.323 .597 .944 r
.1587 .38072 m .16527 .38189 L .162 .37862 L p F P
0 g
s
.806 .98 .896 r
.70303 .35176 m .70128 .35316 L .69898 .35265 L p F P
0 g
s
.649 .732 .91 r
.25777 .41296 m .26759 .40985 L .2707 .41314 L p F P
0 g
s
.659 .731 .903 r
.26759 .40985 m .25777 .41296 L .25463 .40987 L p F P
0 g
s
.856 .618 .578 r
.28723 .38274 m .29215 .38537 L .29303 .38068 L p F P
0 g
s
.856 .618 .578 r
.29303 .38068 m .28807 .37806 L .28723 .38274 L p F P
0 g
s
.836 .635 .631 r
.29043 .39037 m .29552 .39293 L .29737 .38788 L p F P
0 g
s
.836 .635 .631 r
.29737 .38788 m .29215 .38537 L .29043 .39037 L p F P
0 g
s
.838 .911 .886 r
.66794 .20775 m .66731 .20734 L .66839 .20642 L closepath p F P
0 g
s
.578 .461 .683 r
.52736 .39679 m .52575 .39042 L .51637 .39504 L p F P
0 g
s
.578 .461 .683 r
.5218 .39943 m .52736 .39679 L p .51637 .39504 L F P
0 g
s
.578 .461 .683 r
.51637 .39504 m .51754 .40003 L .5218 .39943 L p F P
0 g
s
.741 .915 .952 r
.64232 .38508 m .6448 .38641 L .63443 .3922 L p F P
0 g
s
.741 .915 .952 r
.6329 .39035 m .64232 .38508 L p .63443 .3922 L F P
0 g
s
.741 .915 .952 r
.63443 .3922 m .6322 .39102 L .6329 .39035 L p F P
0 g
s
.832 1 .806 r
.73103 .32441 m .73748 .31768 L .73439 .32297 L p F P
0 g
s
.832 1 .806 r
.73031 .32566 m .73103 .32441 L p .73439 .32297 L F P
0 g
s
.832 1 .806 r
.73439 .32297 m .73197 .32548 L .73031 .32566 L p F P
0 g
s
.503 .552 .84 r
.7634 .18116 m .76305 .18114 L .76177 .18606 L p F P
0 g
s
.503 .552 .84 r
.76177 .18606 m .76591 .18647 L .7634 .18116 L p F P
0 g
s
.808 .988 .883 r
.70303 .35176 m .71156 .34467 L .70928 .3443 L p F P
0 g
s
.808 .988 .883 r
.70928 .3443 m .70698 .34622 L .70303 .35176 L p F P
0 g
s
.806 .98 .896 r
.69898 .35265 m .70698 .34622 L .70303 .35176 L p F P
0 g
s
.862 .416 .03 r
.24051 .316 m .24388 .31931 L .24218 .31568 L p F P
0 g
s
.862 .416 .03 r
.24218 .31568 m .23882 .31236 L .24051 .316 L p F P
0 g
s
.847 .393 0 r
.23746 .30959 m .23882 .31236 L .24218 .31568 L p F P
0 g
s
.821 1 .811 r
.73197 .32548 m .72772 .32976 L .73031 .32566 L closepath p F P
0 g
s
.838 .992 .738 r
.61275 .26584 m .60946 .27143 L .61478 .26514 L p F P
0 g
s
.838 .992 .738 r
.61642 .26121 m .61275 .26584 L p .61478 .26514 L F P
0 g
s
.838 .992 .738 r
.61478 .26514 m .617 .26097 L .61642 .26121 L p F P
0 g
s
.467 .683 .96 r
.20972 .39898 m .2052 .39904 L .20913 .40204 L p F P
0 g
s
.467 .683 .96 r
.20913 .40204 m .21294 .40201 L .20972 .39898 L p F P
0 g
s
.462 .683 .961 r
.20024 .39905 m .2052 .39904 L .20913 .40204 L p F P
0 g
s
.615 .551 .759 r
.51793 .40135 m .5203 .40766 L .53059 .405 L p F P
0 g
s
.625 .597 .802 r
.53073 .40528 m .53059 .405 L .5203 .40766 L p F P
0 g
s
.467 .682 .959 r
.2052 .39904 m .20024 .39905 L .197 .39602 L p F P
0 g
s
.774 .923 .553 r
.75988 .28893 m .75735 .29285 L .75879 .28999 L closepath p F P
0 g
s
.638 .68 .873 r
.73689 .17587 m .74759 .17291 L .75002 .17707 L p F P
0 g
s
.65 .693 .877 r
.74759 .17291 m .73689 .17587 L .73447 .17221 L p F P
0 g
s
.689 .731 .883 r
.7239 .17663 m .73447 .17221 L .73689 .17587 L p F P
0 g
s
.744 .735 .843 r
.29043 .40791 m .2837 .41224 L .28063 .40858 L p F P
0 g
s
.696 .723 .871 r
.2707 .41314 m .28063 .40858 L .2837 .41224 L p F P
0 g
s
.42 .48 .816 r
.76844 .1921 m .7689 .19225 L .76878 .19289 L closepath p F P
0 g
s
.34 .415 .793 r
.77416 .1947 m .7689 .19225 L .76878 .19289 L p F P
0 g
s
.34 .415 .793 r
.77312 .19951 m .77416 .1947 L p .76878 .19289 L F P
0 g
s
.209 .254 .691 r
.7799 .20581 m .77864 .21067 L .77584 .2073 L p F P
0 g
s
.209 .254 .691 r
.77584 .2073 m .777 .20247 L .7799 .20581 L p F P
0 g
s
.699 .741 .884 r
.73447 .17221 m .7239 .17663 L .72149 .17338 L p F P
0 g
s
.778 .97 .678 r
.60903 .27212 m .60873 .27231 L .60946 .27143 L closepath p F P
0 g
s
.825 .999 .834 r
.72978 .32565 m .73031 .32566 L .72772 .32976 L p F P
0 g
s
.825 .999 .834 r
.72379 .33141 m .72978 .32565 L p .72772 .32976 L F P
0 g
s
.825 .999 .834 r
.72127 .3355 m .72379 .33141 L p .72772 .32976 L F P
0 g
s
.825 .999 .834 r
.72772 .32976 m .72179 .33548 L .72127 .3355 L p F P
0 g
s
.876 .437 .084 r
.2455 .32299 m .24903 .32623 L .24739 .32256 L p F P
0 g
s
.876 .437 .084 r
.24739 .32256 m .24388 .31931 L .2455 .32299 L p F P
0 g
s
.818 .987 .879 r
.71223 .3441 m .71156 .34467 L .70928 .3443 L p F P
0 g
s
0 0 0 r
.58079 .30792 m .58068 .30806 L .58076 .30798 L closepath p F P
0 g
s
.708 .722 .861 r
.28063 .40858 m .2707 .41314 L .26759 .40985 L p F P
0 g
s
.482 .307 .567 r
.534 .37994 m .53363 .37507 L .52457 .38013 L p F P
0 g
s
.482 .307 .567 r
.52457 .38013 m .5249 .38496 L .534 .37994 L p F P
0 g
s
.817 .993 .866 r
.71582 .33867 m .71223 .3441 L .7204 .33678 L p F P
0 g
s
.818 .987 .879 r
.70928 .3443 m .71582 .33867 L .71223 .3441 L p F P
0 g
s
0 0 0 r
.57944 .31052 m .57616 .31408 L .58068 .30806 L p F P
0 g
s
0 0 0 r
.58068 .30806 m .58076 .30798 L .57944 .31052 L p F P
0 g
s
0 0 0 r
.5818 .30773 m .57944 .31052 L .58076 .30798 L p F P
0 g
s
0 0 0 r
.58076 .30798 m .58597 .30182 L .5818 .30773 L p F P
0 g
s
.814 .999 .839 r
.72179 .33548 m .7204 .33678 L .72127 .3355 L closepath p F P
0 g
s
.817 .993 .866 r
.71955 .33532 m .71582 .33867 L p .7204 .33678 L F P
0 g
s
.817 .993 .866 r
.7204 .33678 m .72127 .3355 L .71955 .33532 L p F P
0 g
s
.437 .5 .826 r
.7689 .19225 m .76844 .1921 L .76591 .18647 L p F P
0 g
s
.84 .387 0 r
.23882 .31236 m .23746 .30959 L .23429 .30633 L p F P
0 g
s
.872 .571 .476 r
.279 .36812 m .2806 .36901 L .28182 .36557 L p F P
0 g
s
.872 .571 .476 r
.28182 .36557 m .27875 .36386 L .279 .36812 L p F P
0 g
s
.142 0 .249 r
.55681 .3431 m .55178 .34729 L .55248 .34382 L p F P
0 g
s
.142 0 .249 r
.55248 .34382 m .56006 .33751 L .55681 .3431 L p F P
0 g
s
.886 .457 .14 r
.25057 .32995 m .25429 .33311 L .25272 .3294 L p F P
0 g
s
.886 .457 .14 r
.25272 .3294 m .24903 .32623 L .25057 .32995 L p F P
0 g
s
.583 .493 .718 r
.51754 .40003 m .5218 .39943 L .51793 .40135 L closepath p F P
0 g
s
.244 0 .322 r
.5512 .35093 m .54349 .35653 L .5468 .35092 L p F P
0 g
s
.244 0 .322 r
.5468 .35092 m .55178 .34729 L .5512 .35093 L p F P
0 g
s
.563 .723 .948 r
.23234 .40685 m .22891 .40733 L .22571 .40435 L p F P
0 g
s
.615 .551 .759 r
.52783 .39823 m .5218 .39943 L .51793 .40135 L p F P
0 g
s
.615 .551 .759 r
.53059 .405 m .52783 .39823 L p .51793 .40135 L F P
0 g
s
.303 .357 .753 r
.7782 .19762 m .777 .20247 L .77312 .19951 L p F P
0 g
s
.303 .357 .753 r
.77312 .19951 m .77416 .1947 L .7782 .19762 L p F P
0 g
s
.437 .5 .826 r
.76591 .18647 m .76974 .18751 L .7689 .19225 L p F P
0 g
s
.383 .446 .803 r
.77525 .18987 m .77416 .1947 L .7689 .19225 L p F P
0 g
s
.383 .446 .803 r
.7689 .19225 m .76974 .18751 L .77525 .18987 L p F P
0 g
s
.707 .862 .956 r
.60864 .39978 m .59828 .40457 L .59569 .40266 L p F P
0 g
s
.699 .855 .957 r
.58533 .40719 m .59569 .40266 L .59828 .40457 L p F P
0 g
s
.418 .655 .957 r
.18654 .39259 m .18436 .39245 L .18111 .38934 L p F P
0 g
s
.844 .997 .775 r
.7414 .3147 m .73994 .31497 L .74329 .31118 L closepath p F P
0 g
s
.758 .96 .659 r
.60788 .27198 m .61275 .26584 L .60946 .27143 L p F P
0 g
s
.758 .96 .659 r
.60696 .27352 m .60788 .27198 L p .60946 .27143 L F P
0 g
s
.758 .96 .659 r
.60946 .27143 m .60873 .27231 L .60696 .27352 L p F P
0 g
s
.749 .922 .948 r
.64539 .38671 m .6448 .38641 L .64684 .38522 L closepath p F P
0 g
s
.838 .915 .887 r
.66839 .20642 m .66731 .20734 L .66489 .20582 L p F P
0 g
s
.865 .93 .866 r
.6606 .2136 m .66731 .20734 L .66489 .20582 L p F P
0 g
s
.893 .48 .204 r
.25533 .33588 m .25429 .33311 L .25818 .33619 L p F P
0 g
s
.893 .48 .204 r
.25818 .33619 m .25859 .33729 L .25533 .33588 L p F P
0 g
s
.84 .889 .875 r
.66985 .2014 m .66839 .20642 L .67711 .1989 L p F P
0 g
s
.838 .915 .887 r
.66489 .20582 m .66985 .2014 L .66839 .20642 L p F P
0 g
s
.777 .964 .659 r
.60873 .27231 m .60449 .2776 L .60696 .27352 L closepath p F P
0 g
s
.865 .93 .866 r
.66489 .20582 m .66203 .20861 L .6606 .2136 L p F P
0 g
s
.855 .938 .877 r
.65473 .21561 m .66203 .20861 L .6606 .2136 L p F P
0 g
s
.855 .938 .877 r
.65471 .2157 m .65473 .21561 L p .6606 .2136 L F P
0 g
s
.855 .938 .877 r
.6606 .2136 m .65709 .21684 L .65471 .2157 L p F P
0 g
s
0 0 .425 r
.77987 .232 m .7798 .2322 L .77918 .22802 L p F P
0 g
s
0 0 .425 r
.77918 .22802 m .77936 .22749 L .77987 .232 L p F P
0 g
s
.871 .935 .861 r
.65709 .21684 m .65333 .2206 L .65471 .2157 L closepath p F P
0 g
s
.773 .948 .934 r
.67306 .37139 m .66796 .37476 L .66555 .3738 L p F P
0 g
s
.816 .964 .641 r
.75574 .29363 m .7532 .29877 L .75735 .29285 L p F P
0 g
s
.816 .964 .641 r
.75788 .29057 m .75574 .29363 L p .75735 .29285 L F P
0 g
s
.816 .964 .641 r
.75735 .29285 m .75879 .28999 L .75788 .29057 L p F P
0 g
s
.801 .7 .753 r
.2908 .40048 m .29236 .39846 L .29751 .40098 L p F P
0 g
s
.801 .7 .753 r
.29751 .40098 m .29379 .40531 L .2908 .40048 L p F P
0 g
s
.717 .824 .37 r
.76851 .27147 m .77103 .26613 L .76901 .27113 L p F P
0 g
s
.717 .824 .37 r
.76708 .27507 m .76851 .27147 L p .76901 .27113 L F P
0 g
s
.717 .824 .37 r
.76901 .27113 m .76759 .27415 L .76708 .27507 L p F P
0 g
s
.366 .623 .951 r
.17015 .38531 m .16855 .3851 L .16527 .38189 L p F P
0 g
s
.866 .963 .862 r
.65466 .21568 m .65471 .2157 L .65333 .2206 L p F P
0 g
s
.866 .963 .862 r
.64832 .2223 m .65466 .21568 L p .65333 .2206 L F P
0 g
s
.866 .963 .862 r
.64661 .22686 m .64832 .2223 L p .65333 .2206 L F P
0 g
s
.866 .963 .862 r
.65333 .2206 m .6469 .22695 L .64661 .22686 L p F P
0 g
s
.912 .544 .319 r
.26034 .34401 m .26429 .34706 L .26331 .34311 L p F P
0 g
s
.912 .544 .319 r
.26331 .34311 m .2594 .34005 L .26034 .34401 L p F P
0 g
s
.837 .886 .876 r
.67756 .1985 m .67711 .1989 L .67724 .19825 L closepath p F P
0 g
s
.84 .889 .875 r
.67515 .19663 m .66985 .2014 L p .67711 .1989 L F P
0 g
s
.84 .889 .875 r
.67711 .1989 m .67724 .19825 L .67515 .19663 L p F P
0 g
s
.736 .8 .903 r
.71723 .17568 m .71102 .17902 L .70861 .17615 L p F P
0 g
s
.579 .644 .879 r
.75002 .17707 m .75015 .17705 L .75013 .17726 L closepath p F P
0 g
s
.539 .62 .881 r
.76092 .17622 m .75015 .17705 L .75013 .17726 L p F P
0 g
s
.539 .62 .881 r
.76316 .18068 m .76092 .17622 L p .75013 .17726 L F P
0 g
s
.539 .62 .881 r
.76305 .18114 m .76316 .18068 L p .75013 .17726 L F P
0 g
s
.82 .886 .892 r
.68719 .19088 m .67756 .1985 L .67724 .19825 L p F P
0 g
s
.77 .704 .789 r
.29043 .40791 m .29379 .40531 L .2908 .40048 L p F P
0 g
s
.77 .704 .789 r
.2908 .40048 m .28508 .40546 L .29043 .40791 L p F P
0 g
s
.744 .735 .843 r
.28063 .40858 m .28508 .40546 L .29043 .40791 L p F P
0 g
s
.717 .874 .955 r
.60996 .40067 m .60864 .39978 L .6142 .39709 L closepath p F P
0 g
s
.592 .658 .883 r
.75015 .17705 m .75002 .17707 L .74759 .17291 L p F P
0 g
s
0 0 0 r
.57778 .31359 m .57177 .32006 L .57616 .31408 L p F P
0 g
s
0 0 0 r
.57833 .31278 m .57778 .31359 L p .57616 .31408 L F P
0 g
s
0 0 0 r
.57616 .31408 m .57944 .31052 L .57833 .31278 L p F P
0 g
s
0 0 .039 r
.77496 .255 m .77475 .25593 L .77488 .25561 L closepath p F P
0 g
s
.592 .658 .883 r
.74759 .17291 m .75044 .17246 L .75015 .17705 L p F P
0 g
s
.565 .615 .861 r
.75844 .17151 m .75044 .17246 L .75015 .17705 L p F P
0 g
s
.565 .615 .861 r
.75015 .17705 m .76092 .17622 L .75844 .17151 L p F P
0 g
s
.882 .959 .847 r
.6469 .22695 m .64641 .22746 L .64661 .22686 L closepath p F P
0 g
s
0 0 .399 r
.78117 .22735 m .77987 .232 L .77936 .22749 L p F P
0 g
s
0 0 .399 r
.77936 .22749 m .78057 .22315 L .78117 .22735 L p F P
0 g
s
.693 .829 .948 r
.58533 .40719 m .58396 .40776 L .58508 .40698 L closepath p F P
0 g
s
.692 .813 .94 r
.58271 .40493 m .58508 .40698 L .58396 .40776 L p F P
0 g
s
.692 .813 .94 r
.57235 .40905 m .58271 .40493 L p .58396 .40776 L F P
0 g
s
.906 .557 .37 r
.26506 .35111 m .26922 .35407 L .26841 .35004 L p F P
0 g
s
.906 .557 .37 r
.26841 .35004 m .26429 .34706 L .26506 .35111 L p F P
0 g
s
.884 .961 .843 r
.64207 .22893 m .64019 .23407 L .64641 .22746 L p F P
0 g
s
.884 .961 .843 r
.64447 .22627 m .64207 .22893 L p .64641 .22746 L F P
0 g
s
.884 .961 .843 r
.64641 .22746 m .64661 .22686 L .64447 .22627 L p F P
0 g
s
.865 .996 .8 r
.62745 .24902 m .62657 .24913 L .62841 .24706 L closepath p F P
0 g
s
.83 .993 .859 r
.72127 .3355 m .71955 .33532 L .72379 .33141 L closepath p F P
0 g
s
.285 .056 .38 r
.54286 .35699 m .54272 .35823 L .54349 .35653 L closepath p F P
0 g
s
0 0 .151 r
.77924 .24124 m .77752 .2462 L .77806 .24158 L p F P
0 g
s
0 0 .151 r
.77806 .24158 m .7798 .23662 L .77924 .24124 L p F P
0 g
s
.775 .959 .928 r
.67831 .36781 m .67306 .37139 L .67663 .36724 L closepath p F P
0 g
s
.773 .948 .934 r
.67592 .36694 m .67663 .36724 L .67306 .37139 L p F P
0 g
s
.773 .948 .934 r
.66555 .3738 m .67592 .36694 L p .67306 .37139 L F P
0 g
s
.648 .698 .882 r
.53332 .40992 m .54363 .40682 L .54634 .41063 L p F P
0 g
s
.642 .641 .834 r
.53073 .40528 m .53332 .40992 L .54363 .40682 L p F P
0 g
s
.896 .57 .421 r
.26975 .35822 m .27414 .36109 L .27356 .35696 L p F P
0 g
s
.896 .57 .421 r
.27356 .35696 m .26922 .35407 L .26975 .35822 L p F P
0 g
s
0 0 0 r
.57097 .32088 m .57066 .32166 L .57177 .32006 L closepath p F P
0 g
s
.729 .893 .954 r
.63194 .39087 m .62156 .39626 L .61903 .3947 L p F P
0 g
s
.769 .957 .642 r
.60327 .27803 m .59955 .28376 L .60449 .2776 L p F P
0 g
s
.769 .957 .642 r
.60628 .27402 m .60327 .27803 L p .60449 .2776 L F P
0 g
s
.769 .957 .642 r
.60449 .2776 m .60696 .27352 L .60628 .27402 L p F P
0 g
s
.82 .886 .892 r
.67724 .19825 m .67846 .19391 L p .68719 .19088 L F P
0 g
s
.826 .889 .887 r
.67724 .19825 m .67515 .19663 L .67846 .19391 L closepath p F P
0 g
s
0 0 0 r
.77415 .25835 m .77311 .26094 L .77475 .25593 L p F P
0 g
s
0 0 0 r
.77475 .25593 m .77488 .25561 L .77415 .25835 L p F P
0 g
s
.826 .664 .682 r
.28833 .39627 m .29236 .39846 L .29552 .39293 L p F P
0 g
s
.826 .664 .682 r
.28782 .39528 m .28833 .39627 L p .29552 .39293 L F P
0 g
s
.826 .664 .682 r
.29552 .39293 m .29043 .39037 L .28782 .39528 L p F P
0 g
s
.696 .83 .947 r
.59336 .40083 m .59569 .40266 L .58533 .40719 L p F P
0 g
s
.696 .83 .947 r
.58533 .40719 m .58508 .40698 L .59336 .40083 L p F P
0 g
s
.77 .83 .899 r
.69904 .18376 m .6982 .18287 L .69953 .18202 L closepath p F P
0 g
s
.911 .524 .262 r
.2594 .34005 m .25859 .33729 L .25533 .33588 L p F P
0 g
s
.751 .916 .947 r
.64684 .38522 m .6448 .38641 L .64232 .38508 L p F P
0 g
s
.534 .378 .616 r
.52353 .38562 m .5249 .38496 L .52503 .38593 L closepath p F P
0 g
s
.817 .862 .881 r
.68786 .19034 m .68719 .19088 L .68735 .18986 L closepath p F P
0 g
s
.82 .886 .892 r
.68545 .18812 m .68735 .18986 L .68719 .19088 L p F P
0 g
s
.82 .886 .892 r
.67846 .19391 m .68545 .18812 L p .68719 .19088 L F P
0 g
s
.677 .9 .551 r
.59896 .28461 m .5986 .28497 L .59955 .28376 L closepath p F P
0 g
s
.802 .861 .893 r
.69579 .18034 m .6982 .18287 L .68786 .19034 L p F P
0 g
s
.802 .861 .893 r
.68838 .18594 m .69579 .18034 L p .68786 .19034 L F P
0 g
s
.802 .861 .893 r
.68786 .19034 m .68735 .18986 L .68838 .18594 L p F P
0 g
s
.875 .964 .852 r
.64661 .22686 m .64447 .22627 L .64832 .2223 L closepath p F P
0 g
s
.87 .984 .837 r
.6362 .23542 m .64207 .22893 L .64019 .23407 L p F P
0 g
s
.87 .984 .837 r
.6353 .2376 m .6362 .23542 L p .64019 .23407 L F P
0 g
s
.87 .984 .837 r
.64019 .23407 m .63672 .23772 L .6353 .2376 L p F P
0 g
s
.883 .583 .474 r
.27435 .36536 m .279 .36812 L .27875 .36386 L p F P
0 g
s
.883 .583 .474 r
.27875 .36386 m .27414 .36109 L .27435 .36536 L p F P
0 g
s
.609 .73 .931 r
.24173 .40898 m .25148 .40673 L .25463 .40987 L p F P
0 g
s
.616 .73 .927 r
.25148 .40673 m .24173 .40898 L .23856 .40594 L p F P
0 g
s
.694 .816 .364 r
.76759 .27415 m .76644 .27648 L .76708 .27507 L closepath p F P
0 g
s
0 0 0 r
.77499 .25597 m .77415 .25835 L .77488 .25561 L p F P
0 g
s
0 0 0 r
.77488 .25561 m .77649 .25099 L .77499 .25597 L p F P
0 g
s
.307 .077 .393 r
.55078 .35477 m .5512 .35093 L .54349 .35653 L p F P
0 g
s
.307 .077 .393 r
.54246 .36087 m .55078 .35477 L p .54349 .35653 L F P
0 g
s
.307 .077 .393 r
.54349 .35653 m .54272 .35823 L .54246 .36087 L p F P
0 g
s
.418 .655 .957 r
.18111 .38934 m .1829 .38945 L .18654 .39259 L p F P
0 g
s
.427 .658 .957 r
.19051 .3898 m .1829 .38945 L .18654 .39259 L p F P
0 g
s
.427 .658 .957 r
.18654 .39259 m .19376 .39294 L .19051 .3898 L p F P
0 g
s
.848 .645 .627 r
.28562 .3877 m .29043 .39037 L .29215 .38537 L p F P
0 g
s
.848 .645 .627 r
.29215 .38537 m .28723 .38274 L .28562 .3877 L p F P
0 g
s
.512 .703 .956 r
.21294 .40201 m .22251 .40133 L .22571 .40435 L p F P
0 g
s
.515 .701 .954 r
.22251 .40133 m .21294 .40201 L .20972 .39898 L p F P
0 g
s
.694 .823 .944 r
.59309 .4006 m .59336 .40083 L .58508 .40698 L p F P
0 g
s
.694 .823 .944 r
.58508 .40698 m .58271 .40493 L .59309 .4006 L p F P
0 g
s
.832 .979 .684 r
.75114 .29972 m .75574 .29363 L .7532 .29877 L p F P
0 g
s
.832 .979 .684 r
.74939 .30333 m .75114 .29972 L p .7532 .29877 L F P
0 g
s
.832 .979 .684 r
.7532 .29877 m .75 .30302 L .74939 .30333 L p F P
0 g
s
.883 .613 .524 r
.28029 .37343 m .28336 .37534 L .28362 .37088 L p F P
0 g
s
.883 .613 .524 r
.28362 .37088 m .2806 .36901 L .28029 .37343 L p F P
0 g
s
.366 .623 .951 r
.16527 .38189 m .16673 .38207 L .17015 .38531 L p F P
0 g
s
.378 .629 .952 r
.17458 .38295 m .16673 .38207 L .17015 .38531 L p F P
0 g
s
.378 .629 .952 r
.17015 .38531 m .17785 .38618 L .17458 .38295 L p F P
0 g
s
.868 .628 .574 r
.28257 .38 m .28723 .38274 L .28807 .37806 L p F P
0 g
s
.868 .628 .574 r
.28807 .37806 m .28336 .37534 L .28257 .38 L p F P
0 g
s
.456 .517 .832 r
.76974 .18751 m .76591 .18647 L .7634 .18116 L p F P
0 g
s
.886 .98 .824 r
.63672 .23772 m .63415 .24062 L .6353 .2376 L closepath p F P
0 g
s
.753 .931 .946 r
.65517 .38024 m .64684 .38522 L .65276 .3791 L closepath p F P
0 g
s
.751 .916 .947 r
.65272 .37908 m .65276 .3791 L .64684 .38522 L p F P
0 g
s
.751 .916 .947 r
.64232 .38508 m .65272 .37908 L p .64684 .38522 L F P
0 g
s
.563 .723 .948 r
.22571 .40435 m .228 .40401 L .23234 .40685 L p F P
0 g
s
.562 .718 .946 r
.23538 .40285 m .228 .40401 L .23234 .40685 L p F P
0 g
s
.562 .718 .946 r
.23234 .40685 m .23856 .40594 L .23538 .40285 L p F P
0 g
s
0 .007 .517 r
.78189 .21829 m .78057 .22315 L .77933 .2192 L p F P
0 g
s
0 .007 .517 r
.77933 .2192 m .78063 .21434 L .78189 .21829 L p F P
0 g
s
.784 .96 .924 r
.68587 .36249 m .67831 .36781 L .67663 .36724 L p F P
0 g
s
.407 .217 .507 r
.53924 .37143 m .53363 .37507 L .53359 .37062 L p F P
0 g
s
.407 .217 .507 r
.53359 .37062 m .53926 .36694 L .53924 .37143 L p F P
0 g
s
.675 .791 .936 r
.55936 .41026 m .5697 .40646 L .57235 .40905 L p F P
0 g
s
.681 .804 .941 r
.58271 .40493 m .57235 .40905 L .5697 .40646 L p F P
0 g
s
.597 .518 .736 r
.5218 .39943 m .52736 .39679 L .52783 .39823 L closepath p F P
0 g
s
0 0 0 r
.57405 .31934 m .57778 .31359 L .57177 .32006 L p F P
0 g
s
0 0 0 r
.56987 .32378 m .57405 .31934 L p .57177 .32006 L F P
0 g
s
0 0 0 r
.57177 .32006 m .57066 .32166 L .56987 .32378 L p F P
0 g
s
.524 .372 .616 r
.53482 .38536 m .534 .37994 L .5249 .38496 L p F P
0 g
s
.524 .372 .616 r
.53065 .38764 m .53482 .38536 L p .5249 .38496 L F P
0 g
s
.524 .372 .616 r
.5249 .38496 m .52503 .38593 L .53065 .38764 L p F P
0 g
s
.662 .75 .915 r
.54634 .41063 m .55667 .40717 L .55936 .41026 L p F P
0 g
s
.651 .717 .896 r
.55667 .40717 m .54634 .41063 L .54363 .40682 L p F P
0 g
s
.887 .982 .818 r
.6307 .24179 m .62841 .24706 L .63415 .24062 L p F P
0 g
s
.887 .982 .818 r
.63429 .23754 m .6307 .24179 L p .63415 .24062 L F P
0 g
s
.887 .982 .818 r
.63415 .24062 m .6353 .2376 L .63429 .23754 L p F P
0 g
s
.744 .79 .89 r
.71723 .17568 m .72149 .17338 L .71908 .17019 L p F P
0 g
s
.744 .79 .89 r
.71908 .17019 m .71761 .17103 L .71723 .17568 L p F P
0 g
s
.736 .8 .903 r
.70861 .17615 m .71761 .17103 L .71723 .17568 L p F P
0 g
s
.34 .104 .403 r
.54272 .35823 m .54082 .36192 L .54246 .36087 L closepath p F P
0 g
s
.644 .877 .519 r
.59882 .28403 m .60327 .27803 L .59955 .28376 L p F P
0 g
s
.644 .877 .519 r
.59719 .28649 m .59882 .28403 L p .59955 .28376 L F P
0 g
s
.644 .877 .519 r
.59955 .28376 m .5986 .28497 L .59719 .28649 L p F P
0 g
s
.667 .767 .924 r
.5697 .40646 m .55936 .41026 L .55667 .40717 L p F P
0 g
s
.764 .891 .484 r
.76559 .27695 m .76332 .28204 L .76644 .27648 L p F P
0 g
s
.764 .891 .484 r
.76569 .27679 m .76559 .27695 L p .76644 .27648 L F P
0 g
s
.764 .891 .484 r
.76644 .27648 m .76708 .27507 L .76569 .27679 L p F P
0 g
s
.804 .863 .892 r
.68735 .18986 m .68545 .18812 L .68838 .18594 L closepath p F P
0 g
s
0 0 .004 r
.57066 .32166 m .56759 .32597 L .56987 .32378 L closepath p F P
0 g
s
.472 .683 .958 r
.20649 .3959 m .20137 .39599 L .2052 .39904 L p F P
0 g
s
.472 .683 .958 r
.2052 .39904 m .20972 .39898 L .20649 .3959 L p F P
0 g
s
.467 .682 .959 r
.197 .39602 m .20137 .39599 L .2052 .39904 L p F P
0 g
s
.518 .383 .637 r
.52503 .38593 m .53065 .38764 L .52575 .39042 L closepath p F P
0 g
s
.663 .884 .524 r
.5986 .28497 m .59489 .28982 L .59719 .28649 L closepath p F P
0 g
s
.819 .979 .688 r
.75 .30302 m .74857 .30486 L .74939 .30333 L closepath p F P
0 g
s
.659 .731 .903 r
.25463 .40987 m .26448 .4065 L .26759 .40985 L p F P
0 g
s
.668 .731 .897 r
.26448 .4065 m .25463 .40987 L .25148 .40673 L p F P
0 g
s
.856 .411 .006 r
.23727 .31262 m .24051 .316 L .23882 .31236 L p F P
0 g
s
.856 .411 .006 r
.23882 .31236 m .23559 .30898 L .23727 .31262 L p F P
0 g
s
.84 .387 0 r
.23429 .30633 m .23559 .30898 L .23882 .31236 L p F P
0 g
s
.008 0 .131 r
.5613 .33399 m .56053 .3368 L .56368 .33179 L closepath p F P
0 g
s
.755 .733 .832 r
.28508 .40546 m .28063 .40858 L .27756 .40483 L p F P
0 g
s
.708 .722 .861 r
.26759 .40985 m .27756 .40483 L .28063 .40858 L p F P
0 g
s
.771 .835 .901 r
.69953 .18202 m .6982 .18287 L .69579 .18034 L p F P
0 g
s
.874 .437 .064 r
.24211 .31968 m .2455 .32299 L .24388 .31931 L p F P
0 g
s
.874 .437 .064 r
.24388 .31931 m .24051 .316 L .24211 .31968 L p F P
0 g
s
.839 .994 .748 r
.74604 .30598 m .74329 .31118 L .74857 .30486 L p F P
0 g
s
.839 .994 .748 r
.7479 .30374 m .74604 .30598 L p .74857 .30486 L F P
0 g
s
.839 .994 .748 r
.74857 .30486 m .74939 .30333 L .7479 .30374 L p F P
0 g
s
.65 .693 .877 r
.73447 .17221 m .74515 .16888 L .74759 .17291 L p F P
0 g
s
.662 .706 .879 r
.74515 .16888 m .73447 .17221 L .73205 .16865 L p F P
0 g
s
.699 .741 .884 r
.72149 .17338 m .73205 .16865 L .73447 .17221 L p F P
0 g
s
.86 .997 .796 r
.62534 .2481 m .6307 .24179 L .62841 .24706 L p F P
0 g
s
.86 .997 .796 r
.62473 .24942 m .62534 .2481 L p .62841 .24706 L F P
0 g
s
.86 .997 .796 r
.62841 .24706 m .62657 .24913 L .62473 .24942 L p F P
0 g
s
.471 .681 .957 r
.20137 .39599 m .197 .39602 L .19376 .39294 L p F P
0 g
s
.787 .969 .917 r
.68865 .36047 m .68587 .36249 L .68771 .36019 L closepath p F P
0 g
s
.784 .96 .924 r
.68629 .35966 m .68771 .36019 L .68587 .36249 L p F P
0 g
s
.784 .96 .924 r
.67796 .36554 m .68629 .35966 L p .68587 .36249 L F P
0 g
s
.784 .96 .924 r
.67663 .36724 m .67796 .36554 L p .68587 .36249 L F P
0 g
s
.771 .835 .901 r
.69579 .18034 m .70061 .1771 L .69953 .18202 L p F P
0 g
s
.782 .836 .893 r
.69953 .18202 m .70861 .17615 L .70619 .17331 L p F P
0 g
s
.782 .836 .893 r
.70619 .17331 m .70061 .1771 L .69953 .18202 L p F P
0 g
s
.719 .721 .851 r
.27756 .40483 m .26759 .40985 L .26448 .4065 L p F P
0 g
s
.719 .865 .95 r
.6142 .39709 m .60864 .39978 L .60608 .39792 L p F P
0 g
s
.707 .862 .956 r
.59569 .40266 m .60608 .39792 L .60864 .39978 L p F P
0 g
s
0 0 0 r
.58912 .29745 m .58847 .29839 L .59034 .29585 L closepath p F P
0 g
s
.81 .695 .738 r
.29236 .39846 m .28833 .39627 L .2908 .40048 L closepath p F P
0 g
s
.888 .46 .123 r
.24701 .32672 m .25057 .32995 L .24903 .32623 L p F P
0 g
s
.888 .46 .123 r
.24903 .32623 m .2455 .32299 L .24701 .32672 L p F P
0 g
s
.877 .993 .786 r
.62657 .24913 m .62299 .25339 L .62473 .24942 L closepath p F P
0 g
s
.709 .751 .884 r
.73205 .16865 m .72149 .17338 L .71908 .17019 L p F P
0 g
s
.108 .143 .616 r
.78194 .20947 m .78063 .21434 L .77864 .21067 L p F P
0 g
s
.108 .143 .616 r
.77864 .21067 m .7799 .20581 L .78194 .20947 L p F P
0 g
s
.796 .97 .912 r
.69708 .35413 m .68865 .36047 L .68771 .36019 L p F P
0 g
s
.836 .964 .637 r
.75879 .28999 m .75788 .29057 L .7598 .28774 L closepath p F P
0 g
s
.777 .693 .771 r
.28508 .40546 m .2908 .40048 L .28833 .39627 L p F P
0 g
s
.777 .693 .771 r
.28016 .40285 m .28508 .40546 L p .28833 .39627 L F P
0 g
s
.755 .733 .832 r
.27756 .40483 m .28016 .40285 L .28508 .40546 L p F P
0 g
s
.738 .903 .952 r
.6322 .39102 m .63194 .39087 L .6329 .39035 L closepath p F P
0 g
s
0 0 .29 r
.78001 .23599 m .7798 .23662 L .7798 .2322 L p F P
0 g
s
0 0 .29 r
.7798 .2322 m .77987 .232 L .78001 .23599 L p F P
0 g
s
0 0 .051 r
.56887 .3268 m .56368 .33179 L .56759 .32597 L p F P
0 g
s
0 0 .051 r
.56759 .32597 m .56987 .32378 L .56887 .3268 L p F P
0 g
s
.836 .992 .738 r
.617 .26097 m .61642 .26121 L .6177 .25967 L closepath p F P
0 g
s
.647 .869 .499 r
.59451 .28998 m .59034 .29585 L .59489 .28982 L p F P
0 g
s
.647 .869 .499 r
.59614 .28768 m .59451 .28998 L p .59489 .28982 L F P
0 g
s
.647 .869 .499 r
.59489 .28982 m .59719 .28649 L .59614 .28768 L p F P
0 g
s
.664 .758 .273 r
.77302 .26111 m .77103 .26613 L .77311 .26094 L p F P
0 g
s
.664 .758 .273 r
.77331 .2604 m .77302 .26111 L p .77311 .26094 L F P
0 g
s
.664 .758 .273 r
.77311 .26094 m .77415 .25835 L .77331 .2604 L p F P
0 g
s
.761 .932 .942 r
.66379 .37492 m .65517 .38024 L .65276 .3791 L p F P
0 g
s
.896 .48 .182 r
.25197 .33373 m .25057 .32995 L .25429 .33311 L p F P
0 g
s
.896 .48 .182 r
.25277 .3344 m .25197 .33373 L p .25429 .33311 L F P
0 g
s
.896 .48 .182 r
.25429 .33311 m .25533 .33588 L .25277 .3344 L p F P
0 g
s
.622 .609 .817 r
.53059 .405 m .53172 .40473 L .53073 .40528 L closepath p F P
0 g
s
.642 .641 .834 r
.54091 .40229 m .53172 .40473 L .53073 .40528 L p F P
0 g
s
.642 .641 .834 r
.54363 .40682 m .54091 .40229 L p .53073 .40528 L F P
0 g
s
0 0 .262 r
.78121 .23175 m .78001 .23599 L .77987 .232 L p F P
0 g
s
0 0 .262 r
.77987 .232 m .78117 .22735 L .78121 .23175 L p F P
0 g
s
.376 .161 .455 r
.54226 .36502 m .53926 .36694 L .54082 .36192 L p F P
0 g
s
.376 .161 .455 r
.54082 .36192 m .54246 .36087 L .54226 .36502 L p F P
0 g
s
.6 .576 .798 r
.53172 .40473 m .53059 .405 L .52783 .39823 L p F P
0 g
s
.57 .723 .946 r
.228 .40401 m .22571 .40435 L .22251 .40133 L p F P
0 g
s
.868 .599 .528 r
.27874 .37258 m .28029 .37343 L .2806 .36901 L p F P
0 g
s
.868 .599 .528 r
.2806 .36901 m .279 .36812 L .27874 .37258 L p F P
0 g
s
.84 .996 .836 r
.73031 .32566 m .72978 .32565 L .73103 .32441 L closepath p F P
0 g
s
.422 .654 .955 r
.1829 .38945 m .18111 .38934 L .17785 .38618 L p F P
0 g
s
.182 0 .3 r
.5541 .34852 m .5512 .35093 L .55178 .34729 L p F P
0 g
s
.182 0 .3 r
.55178 .34729 m .55681 .3431 L .5541 .34852 L p F P
0 g
s
.845 .998 .776 r
.74032 .31246 m .74604 .30598 L .74329 .31118 L p F P
0 g
s
.845 .998 .776 r
.73892 .31516 m .74032 .31246 L p .74329 .31118 L F P
0 g
s
.845 .998 .776 r
.74329 .31118 m .73994 .31497 L .73892 .31516 L p F P
0 g
s
0 0 0 r
.77818 .24605 m .77649 .25099 L .77752 .2462 L p F P
0 g
s
0 0 0 r
.77752 .2462 m .77924 .24124 L .77818 .24605 L p F P
0 g
s
.792 .896 .486 r
.76708 .27507 m .76569 .27679 L .76851 .27147 L closepath p F P
0 g
s
.911 .524 .262 r
.25533 .33588 m .25563 .33692 L .2594 .34005 L p F P
0 g
s
.919 .551 .311 r
.25655 .34089 m .26034 .34401 L .2594 .34005 L p F P
0 g
s
.919 .551 .311 r
.2594 .34005 m .25563 .33692 L .25655 .34089 L p F P
0 g
s
.877 .993 .777 r
.62036 .25428 m .6177 .25967 L .62299 .25339 L p F P
0 g
s
.877 .993 .777 r
.62413 .24954 m .62036 .25428 L p .62299 .25339 L F P
0 g
s
.877 .993 .777 r
.62299 .25339 m .62473 .24942 L .62413 .24954 L p F P
0 g
s
.74 .895 .949 r
.6329 .39035 m .63194 .39087 L .62942 .38932 L p F P
0 g
s
.729 .893 .954 r
.61903 .3947 m .62942 .38932 L .63194 .39087 L p F P
0 g
s
.52 .573 .849 r
.76305 .18114 m .76316 .18068 L .7634 .18116 L closepath p F P
0 g
s
.605 .667 .883 r
.75044 .17246 m .74759 .17291 L .74515 .16888 L p F P
0 g
s
.549 .444 .687 r
.53649 .39181 m .52736 .39679 L .52575 .39042 L p F P
0 g
s
.549 .444 .687 r
.53538 .38783 m .53649 .39181 L p .52575 .39042 L F P
0 g
s
.549 .444 .687 r
.52575 .39042 m .53065 .38764 L .53538 .38783 L p F P
0 g
s
.915 .566 .363 r
.26108 .34807 m .26506 .35111 L .26429 .34706 L p F P
0 g
s
.915 .566 .363 r
.26429 .34706 m .26034 .34401 L .26108 .34807 L p F P
0 g
s
.837 .68 .687 r
.28489 .38923 m .28562 .3877 L .29043 .39037 L p F P
0 g
s
.837 .68 .687 r
.29043 .39037 m .28782 .39528 L .28489 .38923 L p F P
0 g
s
.74 .906 .951 r
.6329 .39035 m .64232 .38508 L .63984 .38371 L p F P
0 g
s
.74 .906 .951 r
.63984 .38371 m .63934 .38398 L .6329 .39035 L p F P
0 g
s
.74 .895 .949 r
.62942 .38932 m .63934 .38398 L .6329 .39035 L p F P
0 g
s
.811 .939 .576 r
.762 .28268 m .7598 .28774 L .76332 .28204 L p F P
0 g
s
.811 .939 .576 r
.76332 .28204 m .76559 .27695 L .762 .28268 L p F P
0 g
s
.456 .517 .832 r
.7634 .18116 m .77064 .18272 L .76974 .18751 L p F P
0 g
s
.443 .529 .851 r
.76316 .18068 m .7634 .18116 L .77064 .18272 L p F P
0 g
s
.37 .621 .949 r
.16673 .38207 m .16527 .38189 L .162 .37862 L p F P
0 g
s
.6 .576 .798 r
.53996 .40044 m .53172 .40473 L p .52783 .39823 L F P
0 g
s
.629 .617 .82 r
.53172 .40473 m .53996 .40044 L .54091 .40229 L closepath p F P
0 g
s
.799 .978 .902 r
.69898 .35265 m .69708 .35413 L .6983 .3525 L closepath p F P
0 g
s
.796 .97 .912 r
.69665 .35196 m .6983 .3525 L .69708 .35413 L p F P
0 g
s
.796 .97 .912 r
.69018 .35683 m .69665 .35196 L p .69708 .35413 L F P
0 g
s
.796 .97 .912 r
.68771 .36019 m .69018 .35683 L p .69708 .35413 L F P
0 g
s
.226 .27 .7 r
.78082 .20222 m .7799 .20581 L .777 .20247 L p F P
0 g
s
.226 .27 .7 r
.78006 .19962 m .78082 .20222 L p .777 .20247 L F P
0 g
s
.226 .27 .7 r
.777 .20247 m .7782 .19762 L .78006 .19962 L p F P
0 g
s
.906 .58 .417 r
.26557 .35526 m .26975 .35822 L .26922 .35407 L p F P
0 g
s
.906 .58 .417 r
.26922 .35407 m .26506 .35111 L .26557 .35526 L p F P
0 g
s
.834 .998 .781 r
.73994 .31497 m .73748 .31768 L .73892 .31516 L closepath p F P
0 g
s
.501 .57 .858 r
.76092 .17622 m .76366 .17644 L .76316 .18068 L closepath p F P
0 g
s
.443 .529 .851 r
.77163 .17788 m .76366 .17644 L .76316 .18068 L p F P
0 g
s
.443 .529 .851 r
.77064 .18272 m .77163 .17788 L p .76316 .18068 L F P
0 g
s
.809 .979 .897 r
.70698 .34622 m .69898 .35265 L .6983 .3525 L p F P
0 g
s
.855 .993 .741 r
.74939 .30333 m .7479 .30374 L .75114 .29972 L closepath p F P
0 g
s
.894 .594 .471 r
.26994 .3625 m .27435 .36536 L .27414 .36109 L p F P
0 g
s
.894 .594 .471 r
.27414 .36109 m .26975 .35822 L .26994 .3625 L p F P
0 g
s
.705 .845 .949 r
.60349 .39596 m .60608 .39792 L .59569 .40266 L p F P
0 g
s
.705 .845 .949 r
.5943 .40007 m .60349 .39596 L p .59569 .40266 L F P
0 g
s
.705 .845 .949 r
.59569 .40266 m .59336 .40083 L .5943 .40007 L p F P
0 g
s
0 0 0 r
.57944 .31052 m .57833 .31278 L .5818 .30773 L closepath p F P
0 g
s
.86 .652 .619 r
.28365 .38654 m .28562 .3877 L .28723 .38274 L p F P
0 g
s
.86 .652 .619 r
.28204 .38178 m .28365 .38654 L p .28723 .38274 L F P
0 g
s
.86 .652 .619 r
.28723 .38274 m .28257 .38 L .28204 .38178 L p F P
0 g
s
.841 .998 .82 r
.73396 .31916 m .73103 .32441 L .73748 .31768 L p F P
0 g
s
.841 .998 .82 r
.73777 .3152 m .73396 .31916 L p .73748 .31768 L F P
0 g
s
.841 .998 .82 r
.73748 .31768 m .73892 .31516 L .73777 .3152 L p F P
0 g
s
.721 .881 .955 r
.61903 .3947 m .6142 .39709 L .61786 .39393 L closepath p F P
0 g
s
.719 .865 .95 r
.61648 .39296 m .61786 .39393 L .6142 .39709 L p F P
0 g
s
.719 .865 .95 r
.60608 .39792 m .61648 .39296 L p .6142 .39709 L F P
0 g
s
.746 .807 .901 r
.71761 .17103 m .70861 .17615 L .70619 .17331 L p F P
0 g
s
.877 .608 .527 r
.27408 .36982 m .27874 .37258 L .279 .36812 L p F P
0 g
s
.877 .608 .527 r
.279 .36812 m .27435 .36536 L .27408 .36982 L p F P
0 g
s
.877 .638 .573 r
.28118 .37914 m .28257 .38 L .28336 .37534 L p F P
0 g
s
.877 .638 .573 r
.28336 .37534 m .28029 .37343 L .28118 .37914 L p F P
0 g
s
.326 .122 .442 r
.55057 .35888 m .55078 .35477 L .54246 .36087 L p F P
0 g
s
.326 .122 .442 r
.54246 .36087 m .54226 .36502 L .55057 .35888 L p F P
0 g
s
0 0 0 r
.59047 .29585 m .59451 .28998 L .59034 .29585 L p F P
0 g
s
0 0 0 r
.58761 .29972 m .59047 .29585 L p .59034 .29585 L F P
0 g
s
0 0 0 r
.59034 .29585 m .58847 .29839 L .58761 .29972 L p F P
0 g
s
.401 .463 .809 r
.77585 .18722 m .77525 .18987 L .76974 .18751 L p F P
0 g
s
.401 .463 .809 r
.77466 .18422 m .77585 .18722 L p .76974 .18751 L F P
0 g
s
.401 .463 .809 r
.76974 .18751 m .77064 .18272 L .77466 .18422 L p F P
0 g
s
.324 .377 .763 r
.77874 .19534 m .7782 .19762 L .77416 .1947 L p F P
0 g
s
.324 .377 .763 r
.7773 .19119 m .77874 .19534 L p .77416 .1947 L F P
0 g
s
.324 .377 .763 r
.77416 .1947 m .77525 .18987 L .7773 .19119 L p F P
0 g
s
.826 .989 .728 r
.61547 .26044 m .62036 .25428 L .6177 .25967 L p F P
0 g
s
.826 .989 .728 r
.61468 .26199 m .61547 .26044 L p .6177 .25967 L F P
0 g
s
.826 .989 .728 r
.6177 .25967 m .61642 .26121 L .61468 .26199 L p F P
0 g
s
.6 .576 .798 r
.52783 .39823 m .53816 .39644 L .53996 .40044 L p F P
0 g
s
.593 .515 .737 r
.52736 .39679 m .52783 .39823 L .53816 .39644 L p F P
0 g
s
.051 0 .165 r
.56821 .32912 m .56887 .3268 L .56368 .33179 L p F P
0 g
s
.051 0 .165 r
.56733 .33062 m .56821 .32912 L p .56368 .33179 L F P
0 g
s
.051 0 .165 r
.56042 .3372 m .56733 .33062 L p .56368 .33179 L F P
0 g
s
.051 0 .165 r
.56368 .33179 m .56053 .3368 L .56042 .3372 L p F P
0 g
s
.593 .515 .737 r
.53816 .39644 m .53649 .39181 L .52736 .39679 L p F P
0 g
s
.57 .723 .946 r
.22251 .40133 m .22371 .40113 L .228 .40401 L p F P
0 g
s
.568 .718 .943 r
.23219 .39973 m .22371 .40113 L .228 .40401 L p F P
0 g
s
.568 .718 .943 r
.228 .40401 m .23538 .40285 L .23219 .39973 L p F P
0 g
s
.811 .986 .885 r
.70928 .3443 m .70698 .34622 L .70843 .34415 L closepath p F P
0 g
s
.809 .979 .897 r
.70699 .34376 m .70843 .34415 L .70698 .34622 L p F P
0 g
s
.809 .979 .897 r
.70096 .34861 m .70699 .34376 L p .70698 .34622 L F P
0 g
s
.809 .979 .897 r
.6983 .3525 m .70096 .34861 L p .70698 .34622 L F P
0 g
s
.447 .284 .566 r
.54129 .37521 m .534 .37994 L .53363 .37507 L p F P
0 g
s
.447 .284 .566 r
.53363 .37507 m .53924 .37143 L .54129 .37521 L p F P
0 g
s
.846 .989 .723 r
.61642 .26121 m .61275 .26584 L .61468 .26199 L closepath p F P
0 g
s
.422 .654 .955 r
.17785 .38618 m .17937 .38626 L .1829 .38945 L p F P
0 g
s
.431 .657 .955 r
.18725 .38661 m .17937 .38626 L .1829 .38945 L p F P
0 g
s
.431 .657 .955 r
.1829 .38945 m .19051 .3898 L .18725 .38661 L p F P
0 g
s
.82 .986 .88 r
.71582 .33867 m .70928 .3443 L .70843 .34415 L p F P
0 g
s
.842 .996 .837 r
.72757 .32556 m .73396 .31916 L .73103 .32441 L p F P
0 g
s
.842 .996 .837 r
.73103 .32441 m .72978 .32565 L .72757 .32556 L p F P
0 g
s
.765 .943 .939 r
.66555 .3738 m .66379 .37492 L .66501 .37356 L closepath p F P
0 g
s
.761 .932 .942 r
.66312 .37264 m .66501 .37356 L .66379 .37492 L p F P
0 g
s
.761 .932 .942 r
.65283 .37902 m .66312 .37264 L p .66379 .37492 L F P
0 g
s
.761 .932 .942 r
.65276 .3791 m .65283 .37902 L p .66379 .37492 L F P
0 g
s
.832 .997 .84 r
.72379 .33141 m .72978 .32565 L .72757 .32556 L p F P
0 g
s
.847 .916 .88 r
.66985 .2014 m .66489 .20582 L .66288 .20457 L p F P
0 g
s
.864 .913 .863 r
.66489 .20582 m .66203 .20861 L .66288 .20457 L closepath p F P
0 g
s
0 0 .399 r
.78251 .22248 m .78117 .22735 L .78057 .22315 L p F P
0 g
s
0 0 .399 r
.78057 .22315 m .78189 .21829 L .78251 .22248 L p F P
0 g
s
.88 .984 .825 r
.6353 .2376 m .63429 .23754 L .6362 .23542 L closepath p F P
0 g
s
.616 .73 .927 r
.23856 .40594 m .24832 .40354 L .25148 .40673 L p F P
0 g
s
.622 .73 .924 r
.24832 .40354 m .23856 .40594 L .23538 .40285 L p F P
0 g
s
.37 .621 .949 r
.162 .37862 m .1634 .37879 L .16673 .38207 L p F P
0 g
s
.382 .627 .95 r
.1713 .37966 m .1634 .37879 L .16673 .38207 L p F P
0 g
s
.382 .627 .95 r
.16673 .38207 m .17458 .38295 L .1713 .37966 L p F P
0 g
s
0 0 0 r
.58847 .29839 m .58597 .30182 L .58761 .29972 L closepath p F P
0 g
s
.821 .993 .865 r
.71955 .33532 m .71582 .33867 L .71811 .33517 L closepath p F P
0 g
s
.82 .986 .88 r
.7173 .335 m .71811 .33517 L .71582 .33867 L p F P
0 g
s
.82 .986 .88 r
.71058 .34078 m .7173 .335 L p .71582 .33867 L F P
0 g
s
.82 .986 .88 r
.70843 .34415 m .71058 .34078 L p .71582 .33867 L F P
0 g
s
.855 .904 .868 r
.66985 .2014 m .67515 .19663 L .67272 .19477 L p F P
0 g
s
.855 .904 .868 r
.67272 .19477 m .67083 .19654 L .66985 .2014 L p F P
0 g
s
.847 .916 .88 r
.66312 .20371 m .67083 .19654 L .66985 .2014 L p F P
0 g
s
.847 .916 .88 r
.66288 .20457 m .66312 .20371 L p .66985 .2014 L F P
0 g
s
.866 .916 .861 r
.6563 .21055 m .65473 .21561 L .66203 .20861 L p F P
0 g
s
.866 .916 .861 r
.66246 .20432 m .6563 .21055 L p .66203 .20861 L F P
0 g
s
.866 .916 .861 r
.66203 .20861 m .66288 .20457 L .66246 .20432 L p F P
0 g
s
.832 .997 .84 r
.72757 .32556 m .72704 .32607 L .72379 .33141 L p F P
0 g
s
.831 .992 .859 r
.71923 .33328 m .72704 .32607 L .72379 .33141 L p F P
0 g
s
.831 .992 .859 r
.71811 .33517 m .71923 .33328 L p .72379 .33141 L F P
0 g
s
.831 .992 .859 r
.72379 .33141 m .71955 .33532 L .71811 .33517 L p F P
0 g
s
.651 .717 .896 r
.54363 .40682 m .55398 .40364 L .55667 .40717 L p F P
0 g
s
.635 .677 .872 r
.55398 .40364 m .54363 .40682 L .54091 .40229 L p F P
0 g
s
.605 .667 .883 r
.74515 .16888 m .75094 .16778 L .75044 .17246 L p F P
0 g
s
.58 .632 .868 r
.75598 .16697 m .75094 .16778 L .75044 .17246 L p F P
0 g
s
.58 .632 .868 r
.75044 .17246 m .75844 .17151 L .75598 .16697 L p F P
0 g
s
.827 .891 .888 r
.67846 .19391 m .67515 .19663 L .67272 .19477 L p F P
0 g
s
.515 .701 .954 r
.20972 .39898 m .2193 .39826 L .22251 .40133 L p F P
0 g
s
.52 .7 .951 r
.2193 .39826 m .20972 .39898 L .20649 .3959 L p F P
0 g
s
.773 .957 .642 r
.60696 .27352 m .60628 .27402 L .60788 .27198 L closepath p F P
0 g
s
.795 .957 .919 r
.68771 .36019 m .68629 .35966 L .69018 .35683 L closepath p F P
0 g
s
.863 .94 .869 r
.65471 .2157 m .65466 .21568 L .65473 .21561 L closepath p F P
0 g
s
.776 .944 .933 r
.67352 .36588 m .67592 .36694 L .66555 .3738 L p F P
0 g
s
.776 .944 .933 r
.6687 .36906 m .67352 .36588 L p .66555 .3738 L F P
0 g
s
.776 .944 .933 r
.66555 .3738 m .66501 .37356 L .6687 .36906 L p F P
0 g
s
.798 .673 .726 r
.28782 .39528 m .28738 .39586 L .28833 .39627 L closepath p F P
0 g
s
.777 .693 .771 r
.28833 .39627 m .28738 .39586 L .28016 .40285 L p F P
0 g
s
.689 .817 .944 r
.59309 .4006 m .58271 .40493 L .58008 .40247 L p F P
0 g
s
.681 .804 .941 r
.5697 .40646 m .58008 .40247 L .58271 .40493 L p F P
0 g
s
.863 .944 .869 r
.65223 .21462 m .6563 .21055 L .65473 .21561 L p F P
0 g
s
.863 .944 .869 r
.65473 .21561 m .65466 .21568 L .65223 .21462 L p F P
0 g
s
.887 .954 .842 r
.64832 .2223 m .65466 .21568 L .65223 .21462 L p F P
0 g
s
.836 .885 .877 r
.67846 .19391 m .68545 .18812 L .68302 .18594 L p F P
0 g
s
.836 .885 .877 r
.68302 .18594 m .67943 .18904 L .67846 .19391 L p F P
0 g
s
.827 .891 .888 r
.67272 .19477 m .67943 .18904 L .67846 .19391 L p F P
0 g
s
.747 .847 .403 r
.77045 .26647 m .76851 .27147 L .77103 .26613 L p F P
0 g
s
.747 .847 .403 r
.77103 .26613 m .77302 .26111 L .77045 .26647 L p F P
0 g
s
.783 .947 .929 r
.67663 .36724 m .67592 .36694 L .67796 .36554 L closepath p F P
0 g
s
.838 .965 .639 r
.75805 .28855 m .762 .28268 L .7598 .28774 L p F P
0 g
s
.838 .965 .639 r
.75691 .29119 m .75805 .28855 L p .7598 .28774 L F P
0 g
s
.838 .965 .639 r
.7598 .28774 m .75788 .29057 L .75691 .29119 L p F P
0 g
s
0 0 .024 r
.57054 .32503 m .56887 .3268 L .56987 .32378 L p F P
0 g
s
0 0 .024 r
.56987 .32378 m .57405 .31934 L .57054 .32503 L p F P
0 g
s
.471 .681 .957 r
.19376 .39294 m .19763 .39289 L .20137 .39599 L p F P
0 g
s
.476 .682 .956 r
.20326 .39278 m .19763 .39289 L .20137 .39599 L p F P
0 g
s
.476 .682 .956 r
.20137 .39599 m .20649 .3959 L .20326 .39278 L p F P
0 g
s
.81 .673 .712 r
.28738 .39586 m .28782 .39528 L .28489 .38923 L p F P
0 g
s
.842 .986 .71 r
.61089 .26648 m .60788 .27198 L .61275 .26584 L p F P
0 g
s
.842 .986 .71 r
.61397 .26234 m .61089 .26648 L p .61275 .26584 L F P
0 g
s
.842 .986 .71 r
.61275 .26584 m .61468 .26199 L .61397 .26234 L p F P
0 g
s
.728 .882 .952 r
.6269 .38769 m .62942 .38932 L .61903 .3947 L p F P
0 g
s
.728 .882 .952 r
.62162 .39039 m .6269 .38769 L p .61903 .3947 L F P
0 g
s
.728 .882 .952 r
.61903 .3947 m .61786 .39393 L .62162 .39039 L p F P
0 g
s
.766 .732 .821 r
.28016 .40285 m .27756 .40483 L .27449 .40099 L p F P
0 g
s
.719 .721 .851 r
.26448 .4065 m .27449 .40099 L .27756 .40483 L p F P
0 g
s
.81 .673 .712 r
.28489 .38923 m .28208 .39337 L .28738 .39586 L p F P
0 g
s
.786 .696 .765 r
.27555 .40012 m .28016 .40285 L .28738 .39586 L p F P
0 g
s
.786 .696 .765 r
.28738 .39586 m .28208 .39337 L .27555 .40012 L p F P
0 g
s
.808 .967 .907 r
.6983 .3525 m .69665 .35196 L .70096 .34861 L closepath p F P
0 g
s
.413 .221 .509 r
.54231 .36947 m .53924 .37143 L .53926 .36694 L p F P
0 g
s
.413 .221 .509 r
.53926 .36694 m .54226 .36502 L .54231 .36947 L p F P
0 g
s
.805 .866 .893 r
.68838 .18594 m .68545 .18812 L .68302 .18594 L p F P
0 g
s
.667 .767 .924 r
.55667 .40717 m .56704 .40357 L .5697 .40646 L p F P
0 g
s
.657 .738 .91 r
.56704 .40357 m .55667 .40717 L .55398 .40364 L p F P
0 g
s
.674 .784 .932 r
.58008 .40247 m .5697 .40646 L .56704 .40357 L p F P
0 g
s
0 0 0 r
.58619 .30211 m .5818 .30773 L .58597 .30182 L p F P
0 g
s
0 0 0 r
.58597 .30182 m .58761 .29972 L .58619 .30211 L p F P
0 g
s
.887 .954 .842 r
.65223 .21462 m .64977 .21729 L .64832 .2223 L p F P
0 g
s
.875 .965 .852 r
.64368 .22387 m .64977 .21729 L .64832 .2223 L p F P
0 g
s
.875 .965 .852 r
.64298 .22588 m .64368 .22387 L p .64832 .2223 L F P
0 g
s
.875 .965 .852 r
.64832 .2223 m .64447 .22627 L .64298 .22588 L p F P
0 g
s
.702 .774 .286 r
.77415 .25835 m .77331 .2604 L .77499 .25597 L closepath p F P
0 g
s
.766 .732 .821 r
.27449 .40099 m .27555 .40012 L .28016 .40285 L p F P
0 g
s
.916 .526 .246 r
.25533 .33588 m .25563 .33692 L .25277 .3344 L closepath p F P
0 g
s
0 0 .136 r
.77983 .23949 m .77924 .24124 L .7798 .23662 L p F P
0 g
s
0 0 .136 r
.7798 .23662 m .78001 .23599 L .77983 .23949 L p F P
0 g
s
.668 .731 .897 r
.25148 .40673 m .26135 .4031 L .26448 .4065 L p F P
0 g
s
.677 .732 .892 r
.26135 .4031 m .25148 .40673 L .24832 .40354 L p F P
0 g
s
.751 .912 .947 r
.65272 .37908 m .64232 .38508 L .63984 .38371 L p F P
0 g
s
0 0 0 r
.77664 .25104 m .77499 .25597 L .77649 .25099 L p F P
0 g
s
0 0 0 r
.77649 .25099 m .77818 .24605 L .77664 .25104 L p F P
0 g
s
.814 .862 .883 r
.68838 .18594 m .69579 .18034 L .69337 .17785 L p F P
0 g
s
.814 .862 .883 r
.69337 .17785 m .68925 .1811 L .68838 .18594 L p F P
0 g
s
.805 .866 .893 r
.68302 .18594 m .68925 .1811 L .68838 .18594 L p F P
0 g
s
.079 0 .176 r
.56053 .3368 m .56006 .33751 L .56042 .3372 L closepath p F P
0 g
s
.87 .433 .039 r
.23886 .3163 m .24211 .31968 L .24051 .316 L p F P
0 g
s
.87 .433 .039 r
.24051 .316 m .23727 .31262 L .23886 .3163 L p F P
0 g
s
.824 .965 .642 r
.75788 .29057 m .75574 .29363 L .75691 .29119 L closepath p F P
0 g
s
.891 .96 .836 r
.64447 .22627 m .64207 .22893 L .64298 .22588 L closepath p F P
0 g
s
.662 .706 .879 r
.73205 .16865 m .74272 .16496 L .74515 .16888 L p F P
0 g
s
.674 .717 .881 r
.74272 .16496 m .73205 .16865 L .72963 .16516 L p F P
0 g
s
.709 .751 .884 r
.71908 .17019 m .72963 .16516 L .73205 .16865 L p F P
0 g
s
.129 0 .239 r
.55972 .34065 m .55681 .3431 L .56006 .33751 L p F P
0 g
s
.129 0 .239 r
.56006 .33751 m .56042 .3372 L .55972 .34065 L p F P
0 g
s
.731 .725 .845 r
.26448 .4065 m .27449 .40099 L .27201 .39784 L p F P
0 g
s
.731 .725 .845 r
.26135 .4031 m .26448 .4065 L p .27201 .39784 L F P
0 g
s
.888 .46 .102 r
.2436 .32341 m .24701 .32672 L .2455 .32299 L p F P
0 g
s
.888 .46 .102 r
.2455 .32299 m .24211 .31968 L .2436 .32341 L p F P
0 g
s
.771 .931 .937 r
.66501 .37356 m .66312 .37264 L .6687 .36906 L closepath p F P
0 g
s
.475 .679 .955 r
.19763 .39289 m .19376 .39294 L .19051 .3898 L p F P
0 g
s
.893 .963 .831 r
.63805 .23029 m .6362 .23542 L .64207 .22893 L p F P
0 g
s
.893 .963 .831 r
.64203 .22565 m .63805 .23029 L p .64207 .22893 L F P
0 g
s
.893 .963 .831 r
.64207 .22893 m .64298 .22588 L .64203 .22565 L p F P
0 g
s
.743 .785 .887 r
.71908 .17019 m .71761 .17103 L .71764 .16833 L closepath p F P
0 g
s
.746 .807 .901 r
.71666 .16707 m .71764 .16833 L .71761 .17103 L p F P
0 g
s
.746 .807 .901 r
.70619 .17331 m .71666 .16707 L p .71761 .17103 L F P
0 g
s
.517 .584 .861 r
.76366 .17644 m .76092 .17622 L .75844 .17151 L p F P
0 g
s
.86 .627 .585 r
.2778 .3773 m .28118 .37914 L .28029 .37343 L p F P
0 g
s
.86 .627 .585 r
.28029 .37343 m .27874 .37258 L .2778 .3773 L p F P
0 g
s
0 .011 .52 r
.78322 .21341 m .78189 .21829 L .78063 .21434 L p F P
0 g
s
0 .011 .52 r
.78063 .21434 m .78194 .20947 L .78322 .21341 L p F P
0 g
s
.064 0 .215 r
.56454 .33607 m .55972 .34065 L .56042 .3372 L p F P
0 g
s
.064 0 .215 r
.56042 .3372 m .56733 .33062 L .56454 .33607 L p F P
0 g
s
0 0 .108 r
.78072 .23636 m .77983 .23949 L .78001 .23599 L p F P
0 g
s
0 0 .108 r
.78001 .23599 m .78121 .23175 L .78072 .23636 L p F P
0 g
s
.9 .485 .167 r
.24839 .33051 m .25197 .33373 L .25057 .32995 L p F P
0 g
s
.9 .485 .167 r
.25057 .32995 m .24701 .32672 L .24839 .33051 L p F P
0 g
s
.845 .678 .674 r
.28562 .3877 m .28365 .38654 L .28489 .38923 L closepath p F P
0 g
s
.663 .875 .503 r
.59719 .28649 m .59614 .28768 L .59882 .28403 L closepath p F P
0 g
s
.753 .947 .623 r
.60644 .27248 m .61089 .26648 L .60788 .27198 L p F P
0 g
s
.753 .947 .623 r
.60497 .27507 m .60644 .27248 L p .60788 .27198 L F P
0 g
s
.753 .947 .623 r
.60788 .27198 m .60628 .27402 L .60497 .27507 L p F P
0 g
s
.549 .437 .678 r
.53065 .38764 m .53482 .38536 L .53538 .38783 L closepath p F P
0 g
s
.848 .986 .711 r
.75355 .29461 m .75114 .29972 L .75574 .29363 L p F P
0 g
s
.848 .986 .711 r
.75582 .2916 m .75355 .29461 L p .75574 .29363 L F P
0 g
s
.848 .986 .711 r
.75574 .29363 m .75691 .29119 L .75582 .2916 L p F P
0 g
s
.72 .778 .898 r
.72721 .16173 m .72963 .16516 L .71908 .17019 L p F P
0 g
s
.72 .778 .898 r
.71824 .16627 m .72721 .16173 L p .71908 .17019 L F P
0 g
s
.72 .778 .898 r
.71908 .17019 m .71764 .16833 L .71824 .16627 L p F P
0 g
s
.781 .839 .897 r
.70061 .1771 m .69579 .18034 L .69337 .17785 L p F P
0 g
s
.82 .975 .893 r
.70843 .34415 m .70699 .34376 L .71058 .34078 L closepath p F P
0 g
s
.926 .561 .309 r
.2529 .33771 m .25655 .34089 L .25563 .33692 L p F P
0 g
s
.926 .561 .309 r
.25207 .33407 m .2529 .33771 L p .25563 .33692 L F P
0 g
s
.926 .561 .309 r
.25563 .33692 m .25277 .3344 L .25207 .33407 L p F P
0 g
s
.784 .943 .929 r
.67796 .36554 m .67592 .36694 L .67352 .36588 L p F P
0 g
s
.618 .675 .882 r
.75094 .16778 m .74515 .16888 L .74272 .16496 L p F P
0 g
s
.854 .997 .812 r
.73892 .31516 m .73777 .3152 L .74032 .31246 L closepath p F P
0 g
s
.923 .574 .356 r
.25726 .34496 m .26108 .34807 L .26034 .34401 L p F P
0 g
s
.923 .574 .356 r
.26034 .34401 m .25655 .34089 L .25726 .34496 L p F P
0 g
s
.776 .952 .625 r
.60628 .27402 m .60327 .27803 L .60497 .27507 L closepath p F P
0 g
s
.878 .986 .823 r
.63252 .23667 m .63805 .23029 L .6362 .23542 L p F P
0 g
s
.878 .986 .823 r
.63221 .23745 m .63252 .23667 L p .6362 .23542 L F P
0 g
s
.878 .986 .823 r
.6362 .23542 m .63429 .23754 L .63221 .23745 L p F P
0 g
s
.575 .724 .944 r
.22371 .40113 m .22251 .40133 L .2193 .39826 L p F P
0 g
s
0 0 0 r
.58601 .30245 m .58619 .30211 L .5818 .30773 L p F P
0 g
s
0 0 0 r
.58286 .30742 m .58601 .30245 L p .5818 .30773 L F P
0 g
s
0 0 0 r
.57816 .31315 m .58286 .30742 L p .5818 .30773 L F P
0 g
s
0 0 0 r
.5818 .30773 m .57833 .31278 L .57816 .31315 L p F P
0 g
s
.916 .59 .411 r
.26156 .35223 m .26557 .35526 L .26506 .35111 L p F P
0 g
s
.916 .59 .411 r
.26506 .35111 m .26108 .34807 L .26156 .35223 L p F P
0 g
s
.426 .652 .953 r
.17937 .38626 m .17785 .38618 L .17458 .38295 L p F P
0 g
s
.787 .954 .925 r
.67796 .36554 m .68629 .35966 L .68392 .35875 L p F P
0 g
s
.787 .954 .925 r
.68392 .35875 m .68236 .35985 L .67796 .36554 L p F P
0 g
s
.784 .943 .929 r
.67352 .36588 m .68236 .35985 L .67796 .36554 L p F P
0 g
s
.867 .66 .62 r
.28257 .38 m .28118 .37914 L .28204 .38178 L closepath p F P
0 g
s
.484 .349 .621 r
.54356 .37983 m .53482 .38536 L .534 .37994 L p F P
0 g
s
.484 .349 .621 r
.54295 .37626 m .54356 .37983 L p .534 .37994 L F P
0 g
s
.484 .349 .621 r
.534 .37994 m .54129 .37521 L .54295 .37626 L p F P
0 g
s
.795 .898 .489 r
.76749 .27199 m .77045 .26647 L .76851 .27147 L p F P
0 g
s
.795 .898 .489 r
.76564 .27684 m .76749 .27199 L p .76851 .27147 L F P
0 g
s
.795 .898 .489 r
.76851 .27147 m .76569 .27679 L .76564 .27684 L p F P
0 g
s
.818 .675 .704 r
.28208 .39337 m .28489 .38923 L .28365 .38654 L p F P
0 g
s
.904 .605 .468 r
.26573 .35956 m .26994 .3625 L .26975 .35822 L p F P
0 g
s
.904 .605 .468 r
.26975 .35822 m .26557 .35526 L .26573 .35956 L p F P
0 g
s
.713 .86 .952 r
.61648 .39296 m .60608 .39792 L .60349 .39596 L p F P
0 g
s
.226 .007 .358 r
.55208 .3537 m .55078 .35477 L .5512 .35093 L p F P
0 g
s
.226 .007 .358 r
.5512 .35093 m .5541 .34852 L .55208 .3537 L p F P
0 g
s
.889 .62 .525 r
.26965 .36697 m .27408 .36982 L .27435 .36536 L p F P
0 g
s
.889 .62 .525 r
.27435 .36536 m .26994 .3625 L .26965 .36697 L p F P
0 g
s
.895 .98 .809 r
.63429 .23754 m .6307 .24179 L .63221 .23745 L closepath p F P
0 g
s
.869 .635 .583 r
.27315 .37454 m .2778 .3773 L .27874 .37258 L p F P
0 g
s
.869 .635 .583 r
.27874 .37258 m .27408 .36982 L .27315 .37454 L p F P
0 g
s
.789 .832 .885 r
.70061 .1771 m .70619 .17331 L .70377 .17051 L p F P
0 g
s
.789 .832 .885 r
.70377 .17051 m .70116 .17237 L .70061 .1771 L p F P
0 g
s
.781 .839 .897 r
.69337 .17785 m .70116 .17237 L .70061 .1771 L p F P
0 g
s
.871 .995 .781 r
.62473 .24942 m .62413 .24954 L .62534 .2481 L closepath p F P
0 g
s
.368 .187 .499 r
.55062 .36334 m .55057 .35888 L .54226 .36502 L p F P
0 g
s
.368 .187 .499 r
.54226 .36502 m .54231 .36947 L .55062 .36334 L p F P
0 g
s
.725 .872 .95 r
.61786 .39393 m .61648 .39296 L .62162 .39039 L closepath p F P
0 g
s
.635 .677 .872 r
.54091 .40229 m .55127 .39952 L .55398 .40364 L p F P
0 g
s
.63 .617 .819 r
.53996 .40044 m .54091 .40229 L .55127 .39952 L p F P
0 g
s
.575 .724 .944 r
.2193 .39826 m .2195 .39823 L .22371 .40113 L p F P
0 g
s
.574 .718 .94 r
.229 .39656 m .2195 .39823 L .22371 .40113 L p F P
0 g
s
.574 .718 .94 r
.22371 .40113 m .23219 .39973 L .229 .39656 L p F P
0 g
s
.106 .142 .616 r
.78227 .20815 m .78194 .20947 L .7799 .20581 L p F P
0 g
s
.106 .142 .616 r
.7799 .20581 m .78082 .20222 L .78227 .20815 L p F P
0 g
s
.837 .649 .649 r
.28204 .38178 m .28072 .38506 L .28365 .38654 L closepath p F P
0 g
s
.818 .675 .704 r
.27715 .39073 m .28208 .39337 L p .28365 .38654 L F P
0 g
s
.818 .675 .704 r
.28365 .38654 m .28072 .38506 L .27715 .39073 L p F P
0 g
s
.766 .943 .605 r
.60216 .27843 m .59882 .28403 L .60327 .27803 L p F P
0 g
s
.766 .943 .605 r
.60383 .27605 m .60216 .27843 L p .60327 .27803 L F P
0 g
s
.766 .943 .605 r
.60327 .27803 m .60497 .27507 L .60383 .27605 L p F P
0 g
s
0 0 0 r
.5865 .30169 m .58619 .30211 L .58761 .29972 L p F P
0 g
s
0 0 0 r
.58761 .29972 m .59047 .29585 L .5865 .30169 L p F P
0 g
s
.856 .993 .742 r
.74851 .30086 m .75355 .29461 L .75114 .29972 L p F P
0 g
s
.856 .993 .742 r
.74707 .30397 m .74851 .30086 L p .75114 .29972 L F P
0 g
s
.856 .993 .742 r
.75114 .29972 m .7479 .30374 L .74707 .30397 L p F P
0 g
s
.17 0 .293 r
.55914 .34427 m .5541 .34852 L .55681 .3431 L p F P
0 g
s
.17 0 .293 r
.55681 .3431 m .55972 .34065 L .55914 .34427 L p F P
0 g
s
0 0 .256 r
.78254 .2269 m .78121 .23175 L .78117 .22735 L p F P
0 g
s
0 0 .256 r
.78117 .22735 m .78251 .22248 L .78254 .2269 L p F P
0 g
s
.896 .982 .802 r
.62751 .24286 m .62534 .2481 L .6307 .24179 L p F P
0 g
s
.896 .982 .802 r
.63185 .23745 m .62751 .24286 L p .6307 .24179 L F P
0 g
s
.896 .982 .802 r
.6307 .24179 m .63221 .23745 L .63185 .23745 L p F P
0 g
s
.846 .654 .643 r
.28072 .38506 m .28204 .38178 L .28118 .37914 L p F P
0 g
s
.846 .654 .643 r
.27587 .38238 m .28072 .38506 L p .28118 .37914 L F P
0 g
s
.846 .654 .643 r
.28118 .37914 m .2778 .3773 L .27587 .38238 L p F P
0 g
s
.703 .837 .947 r
.59336 .40083 m .59309 .4006 L .5943 .40007 L closepath p F P
0 g
s
.759 .92 .943 r
.65276 .3791 m .65272 .37908 L .65283 .37902 L closepath p F P
0 g
s
.761 .913 .941 r
.65283 .37902 m .65272 .37908 L .65025 .37769 L p F P
0 g
s
.751 .912 .947 r
.63984 .38371 m .65025 .37769 L .65272 .37908 L p F P
0 g
s
.426 .652 .953 r
.17458 .38295 m .17593 .38302 L .17937 .38626 L p F P
0 g
s
.434 .655 .953 r
.18399 .38336 m .17593 .38302 L .17937 .38626 L p F P
0 g
s
.434 .655 .953 r
.17937 .38626 m .18725 .38661 L .18399 .38336 L p F P
0 g
s
.763 .923 .941 r
.65283 .37902 m .66312 .37264 L .66068 .3714 L p F P
0 g
s
.763 .923 .941 r
.66068 .3714 m .65792 .3731 L .65283 .37902 L p F P
0 g
s
.761 .913 .941 r
.65025 .37769 m .65792 .3731 L .65283 .37902 L p F P
0 g
s
.517 .584 .861 r
.75844 .17151 m .76426 .17173 L .76366 .17644 L p F P
0 g
s
.483 .551 .85 r
.77175 .17727 m .77163 .17788 L .76366 .17644 L p F P
0 g
s
.483 .551 .85 r
.76954 .17241 m .77175 .17727 L p .76366 .17644 L F P
0 g
s
.483 .551 .85 r
.76366 .17644 m .76426 .17173 L .76954 .17241 L p F P
0 g
s
.738 .89 .949 r
.63934 .38398 m .62942 .38932 L .6269 .38769 L p F P
0 g
s
.796 .956 .919 r
.69018 .35683 m .68629 .35966 L .68392 .35875 L p F P
0 g
s
.707 .777 .289 r
.77467 .2562 m .77664 .25104 L .77499 .25597 L p F P
0 g
s
.707 .777 .289 r
.77317 .26072 m .77467 .2562 L p .77499 .25597 L F P
0 g
s
.707 .777 .289 r
.77499 .25597 m .77331 .2604 L .77317 .26072 L p F P
0 g
s
.797 .703 .761 r
.27201 .39784 m .27555 .40012 L .28208 .39337 L p F P
0 g
s
.797 .703 .761 r
.27141 .39705 m .27201 .39784 L p .28208 .39337 L F P
0 g
s
.797 .703 .761 r
.28208 .39337 m .27715 .39073 L .27141 .39705 L p F P
0 g
s
0 0 0 r
.57833 .31278 m .57778 .31359 L .57816 .31315 L closepath p F P
0 g
s
.758 .795 .883 r
.71666 .16707 m .70619 .17331 L .70377 .17051 L p F P
0 g
s
.602 .577 .798 r
.53816 .39644 m .53996 .40044 L .54873 .39497 L p F P
0 g
s
.63 .617 .819 r
.55127 .39952 m .54873 .39497 L .53996 .40044 L p F P
0 g
s
.704 .821 .938 r
.5943 .40007 m .59309 .4006 L .59048 .39826 L p F P
0 g
s
.689 .817 .944 r
.58008 .40247 m .59048 .39826 L .59309 .4006 L p F P
0 g
s
0 0 0 r
.77935 .24256 m .77818 .24605 L .77924 .24124 L p F P
0 g
s
0 0 0 r
.77924 .24124 m .77983 .23949 L .77935 .24256 L p F P
0 g
s
0 0 0 r
.57703 .31598 m .57405 .31934 L .57778 .31359 L p F P
0 g
s
0 0 0 r
.57778 .31359 m .57816 .31315 L .57703 .31598 L p F P
0 g
s
.451 .286 .565 r
.54268 .37433 m .54129 .37521 L .53924 .37143 L p F P
0 g
s
.451 .286 .565 r
.53924 .37143 m .54231 .36947 L .54268 .37433 L p F P
0 g
s
.622 .73 .924 r
.23538 .40285 m .24516 .40032 L .24832 .40354 L p F P
0 g
s
.628 .73 .92 r
.24516 .40032 m .23538 .40285 L .23219 .39973 L p F P
0 g
s
.845 .994 .748 r
.7479 .30374 m .74604 .30598 L .74707 .30397 L closepath p F P
0 g
s
.832 .982 .877 r
.71811 .33517 m .7173 .335 L .71923 .33328 L closepath p F P
0 g
s
.799 .966 .913 r
.69018 .35683 m .69665 .35196 L .6943 .35119 L p F P
0 g
s
.799 .966 .913 r
.6943 .35119 m .69424 .35124 L .69018 .35683 L p F P
0 g
s
.796 .956 .919 r
.68392 .35875 m .69424 .35124 L .69018 .35683 L p F P
0 g
s
.224 .27 .7 r
.7782 .19762 m .77874 .19534 L .78006 .19962 L closepath p F P
0 g
s
.52 .7 .951 r
.21857 .39756 m .2193 .39826 L p .20649 .3959 L F P
0 g
s
.52 .7 .951 r
.20649 .3959 m .21566 .39517 L .21857 .39756 L p F P
0 g
s
.524 .699 .949 r
.21566 .39517 m .20649 .3959 L .20326 .39278 L p F P
0 g
s
.776 .731 .811 r
.27555 .40012 m .27201 .39784 L .27449 .40099 L closepath p F P
0 g
s
.475 .679 .955 r
.19051 .3898 m .19399 .38975 L .19763 .39289 L p F P
0 g
s
.48 .68 .954 r
.20002 .38961 m .19399 .38975 L .19763 .39289 L p F P
0 g
s
.48 .68 .954 r
.19763 .39289 m .20326 .39278 L .20002 .38961 L p F P
0 g
s
.706 .841 .947 r
.60349 .39596 m .5943 .40007 L .60135 .3942 L closepath p F P
0 g
s
.704 .821 .938 r
.6009 .39383 m .60135 .3942 L .5943 .40007 L p F P
0 g
s
.704 .821 .938 r
.59048 .39826 m .6009 .39383 L p .5943 .40007 L F P
0 g
s
.867 .995 .777 r
.6225 .24906 m .62751 .24286 L .62534 .2481 L p F P
0 g
s
.867 .995 .777 r
.6221 .24998 m .6225 .24906 L p .62534 .2481 L F P
0 g
s
.867 .995 .777 r
.62534 .2481 m .62413 .24954 L .6221 .24998 L p F P
0 g
s
.854 .998 .793 r
.74292 .3073 m .74032 .31246 L .74604 .30598 L p F P
0 g
s
.854 .998 .793 r
.74576 .30409 m .74292 .3073 L p .74604 .30598 L F P
0 g
s
.854 .998 .793 r
.74604 .30598 m .74707 .30397 L .74576 .30409 L p F P
0 g
s
.777 .895 .488 r
.76569 .27679 m .76559 .27695 L .76564 .27684 L closepath p F P
0 g
s
0 0 0 r
.57941 .31309 m .57703 .31598 L .57816 .31315 L p F P
0 g
s
0 0 0 r
.57816 .31315 m .58286 .30742 L .57941 .31309 L p F P
0 g
s
.827 .947 .592 r
.76392 .27821 m .762 .28268 L .76559 .27695 L p F P
0 g
s
.827 .947 .592 r
.76559 .27695 m .76564 .27684 L .76392 .27821 L p F P
0 g
s
.854 .918 .874 r
.66288 .20457 m .66246 .20432 L .66312 .20371 L closepath p F P
0 g
s
.722 .78 .899 r
.71764 .16833 m .71666 .16707 L .71824 .16627 L closepath p F P
0 g
s
.657 .738 .91 r
.55398 .40364 m .56436 .40032 L .56704 .40357 L p F P
0 g
s
.641 .702 .89 r
.56436 .40032 m .55398 .40364 L .55127 .39952 L p F P
0 g
s
.848 .947 .588 r
.76414 .27764 m .76392 .27821 L .76564 .27684 L p F P
0 g
s
.848 .947 .588 r
.76564 .27684 m .76749 .27199 L .76414 .27764 L p F P
0 g
s
.885 .991 .766 r
.62413 .24954 m .62036 .25428 L .6221 .24998 L closepath p F P
0 g
s
.548 .436 .678 r
.54524 .3863 m .54356 .37983 L .53482 .38536 L p F P
0 g
s
.548 .436 .678 r
.54222 .38816 m .54524 .3863 L p .53482 .38536 L F P
0 g
s
.548 .436 .678 r
.53482 .38536 m .53538 .38783 L .54222 .38816 L p F P
0 g
s
.404 .461 .806 r
.77208 .17802 m .77163 .17788 L .77064 .18272 L p F P
0 g
s
.404 .461 .806 r
.77064 .18272 m .77466 .18422 L .77208 .17802 L p F P
0 g
s
.631 .852 .473 r
.59816 .28428 m .60216 .27843 L .59882 .28403 L p F P
0 g
s
.631 .852 .473 r
.5955 .28847 m .59816 .28428 L p .59882 .28403 L F P
0 g
s
.631 .852 .473 r
.59882 .28403 m .59614 .28768 L .5955 .28847 L p F P
0 g
s
.533 .596 .863 r
.76426 .17173 m .75844 .17151 L .75598 .16697 L p F P
0 g
s
.865 .985 .704 r
.75691 .29119 m .75582 .2916 L .75805 .28855 L closepath p F P
0 g
s
.324 .377 .763 r
.77525 .18987 m .77585 .18722 L .7773 .19119 L closepath p F P
0 g
s
.683 .8 .938 r
.59048 .39826 m .58008 .40247 L .57743 .39977 L p F P
0 g
s
.674 .784 .932 r
.56704 .40357 m .57743 .39977 L .58008 .40247 L p F P
0 g
s
.808 .966 .907 r
.70096 .34861 m .69665 .35196 L .6943 .35119 L p F P
0 g
s
.884 .966 .841 r
.64298 .22588 m .64203 .22565 L .64368 .22387 L closepath p F P
0 g
s
.911 .52 .252 r
.25277 .3344 m .25207 .33407 L .25197 .33373 L closepath p F P
0 g
s
.828 .682 .701 r
.27252 .38798 m .27715 .39073 L .28072 .38506 L p F P
0 g
s
.828 .682 .701 r
.28072 .38506 m .27587 .38238 L .27252 .38798 L p F P
0 g
s
.838 .986 .711 r
.61468 .26199 m .61397 .26234 L .61547 .26044 L closepath p F P
0 g
s
.677 .732 .892 r
.24832 .40354 m .25823 .39965 L .26135 .4031 L p F P
0 g
s
.685 .732 .887 r
.25823 .39965 m .24832 .40354 L .24516 .40032 L p F P
0 g
s
.664 .759 .921 r
.57743 .39977 m .56704 .40357 L .56436 .40032 L p F P
0 g
s
.602 .577 .798 r
.54873 .39497 m .54853 .39458 L .53816 .39644 L p F P
0 g
s
.596 .533 .755 r
.53649 .39181 m .53816 .39644 L .54853 .39458 L p F P
0 g
s
.618 .675 .882 r
.74272 .16496 m .75186 .16292 L .75094 .16778 L p F P
0 g
s
.594 .649 .874 r
.75352 .16259 m .75186 .16292 L .75094 .16778 L p F P
0 g
s
.594 .649 .874 r
.75094 .16778 m .75598 .16697 L .75352 .16259 L p F P
0 g
s
.546 .462 .712 r
.53538 .38783 m .54222 .38816 L .53649 .39181 L closepath p F P
0 g
s
.731 .725 .845 r
.27201 .39784 m .27097 .39736 L .26135 .4031 L p F P
0 g
s
.737 .747 .859 r
.27097 .39736 m .26135 .4031 L .25823 .39965 L p F P
0 g
s
.855 .997 .813 r
.73677 .31395 m .74292 .3073 L .74032 .31246 L p F P
0 g
s
.855 .997 .813 r
.73613 .31523 m .73677 .31395 L p .74032 .31246 L F P
0 g
s
.855 .997 .813 r
.74032 .31246 m .73777 .3152 L .73613 .31523 L p F P
0 g
s
.885 .458 .078 r
.24035 .32004 m .2436 .32341 L .24211 .31968 L p F P
0 g
s
.885 .458 .078 r
.24211 .31968 m .23886 .3163 L .24035 .32004 L p F P
0 g
s
.812 .975 .899 r
.70699 .34376 m .70096 .34861 L .70468 .34312 L closepath p F P
0 g
s
.808 .966 .907 r
.70467 .34312 m .70468 .34312 L .70096 .34861 L p F P
0 g
s
.808 .966 .907 r
.6943 .35119 m .70467 .34312 L p .70096 .34861 L F P
0 g
s
0 0 .401 r
.78376 .21788 m .78251 .22248 L .78189 .21829 L p F P
0 g
s
0 0 .401 r
.78333 .21411 m .78376 .21788 L p .78189 .21829 L F P
0 g
s
0 0 .401 r
.78189 .21829 m .78322 .21341 L .78333 .21411 L p F P
0 g
s
.835 .893 .882 r
.67943 .18904 m .67272 .19477 L .67125 .19365 L p F P
0 g
s
.853 .892 .864 r
.67272 .19477 m .67083 .19654 L .67125 .19365 L closepath p F P
0 g
s
.856 .894 .863 r
.66431 .19876 m .66312 .20371 L .67083 .19654 L p F P
0 g
s
.856 .894 .863 r
.67029 .19294 m .66431 .19876 L p .67083 .19654 L F P
0 g
s
.856 .894 .863 r
.67083 .19654 m .67125 .19365 L .67029 .19294 L p F P
0 g
s
.684 .727 .882 r
.74029 .16114 m .72963 .16516 L .72721 .16173 L p F P
0 g
s
.674 .717 .881 r
.72963 .16516 m .74029 .16114 L .74272 .16496 L p F P
0 g
s
0 0 .08 r
.56887 .3268 m .56821 .32912 L .57054 .32503 L closepath p F P
0 g
s
.217 0 .353 r
.55873 .3481 m .55208 .3537 L .5541 .34852 L p F P
0 g
s
.217 0 .353 r
.5541 .34852 m .55914 .34427 L .55873 .3481 L p F P
0 g
s
.854 .921 .874 r
.66003 .20288 m .66431 .19876 L .66312 .20371 L p F P
0 g
s
.854 .921 .874 r
.66312 .20371 m .66246 .20432 L .66003 .20288 L p F P
0 g
s
.881 .932 .849 r
.6563 .21055 m .66246 .20432 L .66003 .20288 L p F P
0 g
s
.902 .487 .147 r
.24497 .32721 m .24839 .33051 L .24701 .32672 L p F P
0 g
s
.902 .487 .147 r
.24701 .32672 m .2436 .32341 L .24497 .32721 L p F P
0 g
s
.653 .862 .48 r
.59614 .28768 m .59451 .28998 L .5955 .28847 L closepath p F P
0 g
s
.846 .998 .818 r
.73777 .3152 m .73396 .31916 L .73613 .31523 L closepath p F P
0 g
s
.884 .991 .756 r
.61793 .25511 m .61547 .26044 L .62036 .25428 L p F P
0 g
s
.884 .991 .756 r
.62168 .25009 m .61793 .25511 L p .62036 .25428 L F P
0 g
s
.884 .991 .756 r
.62036 .25428 m .6221 .24998 L .62168 .25009 L p F P
0 g
s
.478 .678 .953 r
.19399 .38975 m .19051 .3898 L .18725 .38661 L p F P
0 g
s
.596 .533 .755 r
.54578 .38789 m .54222 .38816 L .53649 .39181 L p F P
0 g
s
.596 .533 .755 r
.54853 .39458 m .54578 .38789 L p .53649 .39181 L F P
0 g
s
.856 .663 .641 r
.27129 .37959 m .27587 .38238 L .2778 .3773 L p F P
0 g
s
.856 .663 .641 r
.2778 .3773 m .27315 .37454 L .27129 .37959 L p F P
0 g
s
.842 .878 .868 r
.67943 .18904 m .68302 .18594 L .68059 .18376 L p F P
0 g
s
.842 .878 .868 r
.68059 .18376 m .67999 .18431 L .67943 .18904 L p F P
0 g
s
.835 .893 .882 r
.67169 .1917 m .67999 .18431 L .67943 .18904 L p F P
0 g
s
.835 .893 .882 r
.67125 .19365 m .67169 .1917 L p .67943 .18904 L F P
0 g
s
0 0 0 r
.57597 .31891 m .57054 .32503 L .57405 .31934 L p F P
0 g
s
0 0 0 r
.57405 .31934 m .57703 .31598 L .57597 .31891 L p F P
0 g
s
.68 .766 .281 r
.77331 .2604 m .77302 .26111 L .77317 .26072 L closepath p F P
0 g
s
.772 .928 .936 r
.6687 .36906 m .66312 .37264 L .66068 .3714 L p F P
0 g
s
.726 .863 .946 r
.62162 .39039 m .61648 .39296 L .61392 .39106 L p F P
0 g
s
.713 .86 .952 r
.60349 .39596 m .61392 .39106 L .61648 .39296 L p F P
0 g
s
.916 .523 .233 r
.24883 .33199 m .24839 .33051 L .25197 .33373 L p F P
0 g
s
.916 .523 .233 r
.25197 .33373 m .25207 .33407 L .24883 .33199 L p F P
0 g
s
.821 .975 .893 r
.71058 .34078 m .70699 .34376 L .70468 .34312 L p F P
0 g
s
.813 .868 .888 r
.68925 .1811 m .68302 .18594 L .68059 .18376 L p F P
0 g
s
.63 .676 .876 r
.75186 .16292 m .74272 .16496 L .74029 .16114 L p F P
0 g
s
.93 .581 .348 r
.2536 .34178 m .25726 .34496 L .25655 .34089 L p F P
0 g
s
.93 .581 .348 r
.25655 .34089 m .2529 .33771 L .2536 .34178 L p F P
0 g
s
.846 .995 .838 r
.73558 .31517 m .73613 .31523 L .73396 .31916 L p F P
0 g
s
.846 .995 .838 r
.72985 .32086 m .73558 .31517 L p .73396 .31916 L F P
0 g
s
.846 .995 .838 r
.72735 .32555 m .72985 .32086 L p .73396 .31916 L F P
0 g
s
.846 .995 .838 r
.73396 .31916 m .72757 .32556 L .72735 .32555 L p F P
0 g
s
.881 .932 .849 r
.66003 .20288 m .6574 .20565 L .6563 .21055 L p F P
0 g
s
.871 .943 .861 r
.65097 .21236 m .6574 .20565 L .6563 .21055 L p F P
0 g
s
.871 .943 .861 r
.65053 .21388 m .65097 .21236 L p .6563 .21055 L F P
0 g
s
.871 .943 .861 r
.6563 .21055 m .65223 .21462 L .65053 .21388 L p F P
0 g
s
.88 .646 .581 r
.26873 .37168 m .27315 .37454 L .27408 .36982 L p F P
0 g
s
.88 .646 .581 r
.27408 .36982 m .26965 .36697 L .26873 .37168 L p F P
0 g
s
0 0 0 r
.77975 .24114 m .77935 .24256 L .77983 .23949 L p F P
0 g
s
0 0 0 r
.77983 .23949 m .78072 .23636 L .77975 .24114 L p F P
0 g
s
.924 .598 .405 r
.25772 .34913 m .26156 .35223 L .26108 .34807 L p F P
0 g
s
.924 .598 .405 r
.26108 .34807 m .25726 .34496 L .25772 .34913 L p F P
0 g
s
.914 .614 .463 r
.2617 .35653 m .26573 .35956 L .26557 .35526 L p F P
0 g
s
.914 .614 .463 r
.26557 .35526 m .26156 .35223 L .2617 .35653 L p F P
0 g
s
.899 .63 .522 r
.26543 .36403 m .26965 .36697 L .26994 .3625 L p F P
0 g
s
.899 .63 .522 r
.26994 .3625 m .26573 .35956 L .26543 .36403 L p F P
0 g
s
.825 .982 .882 r
.71058 .34078 m .7173 .335 L .71502 .33448 L p F P
0 g
s
.825 .982 .882 r
.71502 .33448 m .71396 .33539 L .71058 .34078 L p F P
0 g
s
.821 .975 .893 r
.70468 .34312 m .71396 .33539 L .71058 .34078 L p F P
0 g
s
.821 .975 .893 r
.70468 .34312 m .70468 .34312 L p .71058 .34078 L F P
0 g
s
.767 .861 .423 r
.77189 .26268 m .77045 .26647 L .77302 .26111 L p F P
0 g
s
.767 .861 .423 r
.77302 .26111 m .77317 .26072 L .77189 .26268 L p F P
0 g
s
.929 .56 .287 r
.2529 .33771 m .25207 .33407 L .24883 .33199 L p F P
0 g
s
.632 .841 .448 r
.59389 .2906 m .59047 .29585 L .59451 .28998 L p F P
0 g
s
.632 .841 .448 r
.59451 .28998 m .5955 .28847 L .59389 .2906 L p F P
0 g
s
.887 .938 .843 r
.65223 .21462 m .64977 .21729 L .65053 .21388 L closepath p F P
0 g
s
.11 0 .271 r
.56221 .34136 m .55914 .34427 L .55972 .34065 L p F P
0 g
s
.11 0 .271 r
.55972 .34065 m .56454 .33607 L .56221 .34136 L p F P
0 g
s
.856 .976 .67 r
.76014 .28352 m .75805 .28855 L .762 .28268 L p F P
0 g
s
.856 .976 .67 r
.76369 .27832 m .76014 .28352 L p .762 .28268 L F P
0 g
s
.856 .976 .67 r
.762 .28268 m .76392 .27821 L .76369 .27832 L p F P
0 g
s
.836 .995 .844 r
.72757 .32556 m .72704 .32607 L .72735 .32555 L closepath p F P
0 g
s
.833 .981 .878 r
.71923 .33328 m .7173 .335 L .71502 .33448 L p F P
0 g
s
.835 .987 .868 r
.72229 .32799 m .71923 .33328 L .72704 .32607 L p F P
0 g
s
.835 .987 .868 r
.72532 .32519 m .72229 .32799 L p .72704 .32607 L F P
0 g
s
.835 .987 .868 r
.72704 .32607 m .72735 .32555 L .72532 .32519 L p F P
0 g
s
.741 .903 .95 r
.63984 .38371 m .63934 .38398 L .6397 .38363 L closepath p F P
0 g
s
.738 .89 .949 r
.63733 .38211 m .6397 .38363 L .63934 .38398 L p F P
0 g
s
.738 .89 .949 r
.6269 .38769 m .63733 .38211 L p .63934 .38398 L F P
0 g
s
.833 .981 .878 r
.71502 .33448 m .72229 .32799 L .71923 .33328 L p F P
0 g
s
.416 .26 .56 r
.55104 .36825 m .55062 .36334 L .54231 .36947 L p F P
0 g
s
.416 .26 .56 r
.54231 .36947 m .54268 .37433 L .55104 .36825 L p F P
0 g
s
.722 .784 .901 r
.71824 .16627 m .71666 .16707 L .71424 .164 L p F P
0 g
s
.758 .795 .883 r
.70377 .17051 m .71424 .164 L .71666 .16707 L p F P
0 g
s
.429 .649 .951 r
.17593 .38302 m .17458 .38295 L .1713 .37966 L p F P
0 g
s
.751 .904 .945 r
.64777 .37624 m .65025 .37769 L .63984 .38371 L p F P
0 g
s
.751 .904 .945 r
.64484 .37792 m .64777 .37624 L p .63984 .38371 L F P
0 g
s
.751 .904 .945 r
.63984 .38371 m .6397 .38363 L .64484 .37792 L p F P
0 g
s
.82 .856 .875 r
.68925 .1811 m .69337 .17785 L .69094 .17537 L p F P
0 g
s
.82 .856 .875 r
.69094 .17537 m .68969 .17639 L .68925 .1811 L p F P
0 g
s
.813 .868 .888 r
.68059 .18376 m .68969 .17639 L .68925 .1811 L p F P
0 g
s
.89 .941 .84 r
.64516 .21884 m .64368 .22387 L .64977 .21729 L p F P
0 g
s
.89 .941 .84 r
.64979 .21358 m .64516 .21884 L p .64977 .21729 L F P
0 g
s
.89 .941 .84 r
.64977 .21729 m .65053 .21388 L .64979 .21358 L p F P
0 g
s
.576 .722 .942 r
.2193 .39826 m .2195 .39823 L .21857 .39756 L closepath p F P
0 g
s
.797 .867 .427 r
.77229 .2615 m .77189 .26268 L .77317 .26072 L p F P
0 g
s
.797 .867 .427 r
.77317 .26072 m .77467 .2562 L .77229 .2615 L p F P
0 g
s
0 0 .096 r
.78204 .23151 m .78072 .23636 L .78121 .23175 L p F P
0 g
s
0 0 .096 r
.78121 .23175 m .78254 .2269 L .78204 .23151 L p F P
0 g
s
.587 .725 .939 r
.22579 .39336 m .229 .39656 L .2195 .39823 L p F P
0 g
s
.587 .725 .939 r
.21608 .39513 m .22579 .39336 L p .2195 .39823 L F P
0 g
s
.587 .725 .939 r
.2195 .39823 m .21857 .39756 L .21608 .39513 L p F P
0 g
s
.276 .078 .422 r
.55093 .35858 m .55057 .35888 L .55078 .35477 L p F P
0 g
s
.276 .078 .422 r
.55078 .35477 m .55208 .3537 L .55093 .35858 L p F P
0 g
s
.767 .943 .605 r
.60497 .27507 m .60383 .27605 L .60644 .27248 L closepath p F P
0 g
s
0 0 0 r
.77827 .24611 m .77664 .25104 L .77818 .24605 L p F P
0 g
s
0 0 0 r
.77887 .24416 m .77827 .24611 L p .77818 .24605 L F P
0 g
s
0 0 0 r
.77818 .24605 m .77935 .24256 L .77887 .24416 L p F P
0 g
s
.245 .313 .736 r
.7773 .19119 m .77916 .19282 L .77874 .19534 L closepath p F P
0 g
s
.106 .191 .67 r
.78189 .19622 m .77916 .19282 L .77874 .19534 L p F P
0 g
s
.106 .191 .67 r
.78106 .20097 m .78189 .19622 L p .77874 .19534 L F P
0 g
s
.106 .191 .67 r
.77874 .19534 m .78006 .19962 L .78106 .20097 L p F P
0 g
s
.868 .995 .784 r
.74707 .30397 m .74576 .30409 L .74851 .30086 L closepath p F P
0 g
s
.746 .893 .945 r
.6397 .38363 m .63733 .38211 L .64484 .37792 L closepath p F P
0 g
s
.829 .983 .702 r
.61342 .26114 m .61793 .25511 L .61547 .26044 L p F P
0 g
s
.829 .983 .702 r
.61244 .26315 m .61342 .26114 L p .61547 .26044 L F P
0 g
s
.829 .983 .702 r
.61547 .26044 m .61397 .26234 L .61244 .26315 L p F P
0 g
s
.732 .785 .895 r
.71824 .16627 m .72721 .16173 L .72478 .15837 L p F P
0 g
s
.732 .785 .895 r
.72478 .15837 m .71915 .16139 L .71824 .16627 L p F P
0 g
s
.722 .784 .901 r
.71424 .164 m .71915 .16139 L .71824 .16627 L p F P
0 g
s
.776 .94 .934 r
.67352 .36588 m .6687 .36906 L .67189 .36514 L closepath p F P
0 g
s
.772 .928 .936 r
.6711 .36473 m .67189 .36514 L .6687 .36906 L p F P
0 g
s
.772 .928 .936 r
.66068 .3714 m .6711 .36473 L p .6687 .36906 L F P
0 g
s
.789 .843 .892 r
.70116 .17237 m .69337 .17785 L .69094 .17537 L p F P
0 g
s
.145 .205 .668 r
.78006 .19962 m .78106 .20097 L .78082 .20222 L closepath p F P
0 g
s
.847 .986 .859 r
.72735 .32555 m .72532 .32519 L .72985 .32086 L closepath p F P
0 g
s
.811 .728 .773 r
.26834 .39292 m .27252 .38798 L .27715 .39073 L p F P
0 g
s
.811 .728 .773 r
.27715 .39073 m .27141 .39705 L .26834 .39292 L p F P
0 g
s
.749 .717 .822 r
.27141 .39705 m .27097 .39736 L .27201 .39784 L closepath p F P
0 g
s
.217 .308 .744 r
.77585 .18722 m .7773 .19119 L .77916 .19282 L p F P
0 g
s
0 .005 .518 r
.78324 .21335 m .78322 .21341 L .78194 .20947 L p F P
0 g
s
0 .005 .518 r
.78194 .20947 m .78227 .20815 L .78324 .21335 L p F P
0 g
s
.039 .097 .595 r
.78295 .20468 m .78227 .20815 L .78082 .20222 L p F P
0 g
s
.039 .097 .595 r
.78082 .20222 m .78106 .20097 L .78295 .20468 L p F P
0 g
s
.883 .967 .841 r
.63958 .22508 m .64516 .21884 L .64368 .22387 L p F P
0 g
s
.883 .967 .841 r
.64368 .22387 m .64203 .22565 L .63958 .22508 L p F P
0 g
s
.85 .983 .697 r
.61397 .26234 m .61089 .26648 L .61244 .26315 L closepath p F P
0 g
s
.728 .88 .951 r
.6269 .38769 m .62162 .39039 L .62547 .38672 L closepath p F P
0 g
s
.726 .863 .946 r
.62436 .38592 m .62547 .38672 L .62162 .39039 L p F P
0 g
s
.726 .863 .946 r
.61392 .39106 m .62436 .38592 L p .62162 .39039 L F P
0 g
s
.905 .967 .811 r
.63805 .23029 m .64203 .22565 L .63958 .22508 L p F P
0 g
s
.524 .701 .951 r
.21857 .39756 m .21608 .39513 L .21566 .39517 L closepath p F P
0 g
s
.711 .842 .945 r
.61134 .38903 m .61392 .39106 L .60349 .39596 L p F P
0 g
s
.711 .842 .945 r
.60261 .39305 m .61134 .38903 L p .60349 .39596 L F P
0 g
s
.711 .842 .945 r
.60349 .39596 m .60135 .3942 L .60261 .39305 L p F P
0 g
s
.429 .649 .951 r
.1713 .37966 m .17261 .37973 L .17593 .38302 L p F P
0 g
s
.437 .653 .951 r
.18072 .38007 m .17261 .37973 L .17593 .38302 L p F P
0 g
s
.437 .653 .951 r
.17593 .38302 m .18399 .38336 L .18072 .38007 L p F P
0 g
s
0 0 .114 r
.57589 .3192 m .57597 .31891 L .57054 .32503 L p F P
0 g
s
0 0 .114 r
.57329 .32417 m .57589 .3192 L p .57054 .32503 L F P
0 g
s
0 0 .114 r
.56798 .32998 m .57329 .32417 L p .57054 .32503 L F P
0 g
s
0 0 .114 r
.57054 .32503 m .56821 .32912 L .56798 .32998 L p F P
0 g
s
.76 .719 .814 r
.27097 .39736 m .27141 .39705 L .26834 .39292 L p F P
0 g
s
.76 .719 .814 r
.26834 .39292 m .26594 .39475 L .27097 .39736 L p F P
0 g
s
.737 .747 .859 r
.25823 .39965 m .26594 .39475 L .27097 .39736 L p F P
0 g
s
.327 .4 .785 r
.77466 .18422 m .77615 .18508 L .77585 .18722 L closepath p F P
0 g
s
.217 .308 .744 r
.7799 .18809 m .77615 .18508 L .77585 .18722 L p F P
0 g
s
.217 .308 .744 r
.77916 .19282 m .7799 .18809 L p .77585 .18722 L F P
0 g
s
.784 .941 .929 r
.68236 .35985 m .67352 .36588 L .67189 .36514 L p F P
0 g
s
.602 .809 .401 r
.59059 .29584 m .5865 .30169 L .59047 .29585 L p F P
0 g
s
.602 .809 .401 r
.59047 .29585 m .59389 .2906 L .59369 .2909 L p F P
0 g
s
.602 .809 .401 r
.59369 .2909 m .59059 .29584 L p .59047 .29585 L F P
0 g
s
.867 .985 .705 r
.75576 .28955 m .76014 .28352 L .75805 .28855 L p F P
0 g
s
.867 .985 .705 r
.75475 .292 m .75576 .28955 L p .75805 .28855 L F P
0 g
s
.867 .985 .705 r
.75805 .28855 m .75582 .2916 L .75475 .292 L p F P
0 g
s
.269 .072 .419 r
.55852 .35221 m .55093 .35858 L .55208 .3537 L p F P
0 g
s
.269 .072 .419 r
.55208 .3537 m .55873 .3481 L .55852 .35221 L p F P
0 g
s
.646 .847 .452 r
.5942 .29012 m .59389 .2906 L .5955 .28847 L p F P
0 g
s
.646 .847 .452 r
.5955 .28847 m .59816 .28428 L .5942 .29012 L p F P
0 g
s
.637 .64 .836 r
.54873 .39497 m .55127 .39952 L .56166 .39659 L p F P
0 g
s
.641 .702 .89 r
.55127 .39952 m .56166 .39659 L .56436 .40032 L p F P
0 g
s
.533 .596 .863 r
.75598 .16697 m .76499 .16696 L .76426 .17173 L p F P
0 g
s
.551 .601 .856 r
.76499 .16696 m .75598 .16697 L .75352 .16259 L p F P
0 g
s
.789 .843 .892 r
.69094 .17537 m .70131 .16776 L .70116 .17237 L p F P
0 g
s
.795 .829 .878 r
.70116 .17237 m .70377 .17051 L .70134 .16774 L p F P
0 g
s
.795 .829 .878 r
.70134 .16774 m .70131 .16776 L .70116 .17237 L p F P
0 g
s
.478 .678 .953 r
.18725 .38661 m .19045 .38655 L .19399 .38975 L p F P
0 g
s
.483 .679 .952 r
.19677 .38639 m .19045 .38655 L .19399 .38975 L p F P
0 g
s
.483 .679 .952 r
.19399 .38975 m .20002 .38961 L .19677 .38639 L p F P
0 g
s
.628 .73 .92 r
.23219 .39973 m .24199 .39706 L .24516 .40032 L p F P
0 g
s
.633 .73 .918 r
.24199 .39706 m .23219 .39973 L .229 .39656 L p F P
0 g
s
.905 .967 .811 r
.63958 .22508 m .63939 .22531 L .63805 .23029 L p F P
0 g
s
.906 .968 .808 r
.6343 .23154 m .63252 .23667 L .63805 .23029 L p F P
0 g
s
.906 .968 .808 r
.63805 .23029 m .63939 .22531 L .6343 .23154 L p F P
0 g
s
.487 .349 .618 r
.54129 .37521 m .54268 .37433 L .54295 .37626 L closepath p F P
0 g
s
.845 .979 .682 r
.60916 .26708 m .60644 .27248 L .61089 .26648 L p F P
0 g
s
.845 .979 .682 r
.61152 .26369 m .60916 .26708 L p .61089 .26648 L F P
0 g
s
.845 .979 .682 r
.61089 .26648 m .61244 .26315 L .61152 .26369 L p F P
0 g
s
.825 .923 .535 r
.76933 .26702 m .76749 .27199 L .77045 .26647 L p F P
0 g
s
.825 .923 .535 r
.77143 .26315 m .76933 .26702 L p .77045 .26647 L F P
0 g
s
.825 .923 .535 r
.77045 .26647 m .77189 .26268 L .77143 .26315 L p F P
0 g
s
.888 .985 .81 r
.63221 .23745 m .63185 .23745 L .63252 .23667 L closepath p F P
0 g
s
.838 .69 .699 r
.26812 .38513 m .27252 .38798 L .27587 .38238 L p F P
0 g
s
.838 .69 .699 r
.27587 .38238 m .27129 .37959 L .26812 .38513 L p F P
0 g
s
.524 .699 .949 r
.20326 .39278 m .21199 .39204 L .21566 .39517 L p F P
0 g
s
.527 .698 .948 r
.21199 .39204 m .20326 .39278 L .20002 .38961 L p F P
0 g
s
.348 .423 .797 r
.77615 .18508 m .77466 .18422 L .77208 .17802 L p F P
0 g
s
.765 .8 .881 r
.71424 .164 m .70377 .17051 L .70134 .16774 L p F P
0 g
s
.035 .099 .6 r
.78383 .19992 m .78295 .20468 L .78106 .20097 L p F P
0 g
s
.035 .099 .6 r
.78106 .20097 m .78189 .19622 L .78383 .19992 L p F P
0 g
s
.855 .986 .71 r
.75582 .2916 m .75355 .29461 L .75475 .292 L closepath p F P
0 g
s
0 0 .491 r
.78416 .20865 m .78324 .21335 L .78227 .20815 L p F P
0 g
s
0 0 .491 r
.78227 .20815 m .78295 .20468 L .78416 .20865 L p F P
0 g
s
.842 .895 .877 r
.67125 .19365 m .67029 .19294 L .67169 .1917 L closepath p F P
0 g
s
.692 .815 .941 r
.6009 .39383 m .59048 .39826 L .58785 .39573 L p F P
0 g
s
.683 .8 .938 r
.57743 .39977 m .58785 .39573 L .59048 .39826 L p F P
0 g
s
0 0 .251 r
.78386 .22203 m .78254 .2269 L .78251 .22248 L p F P
0 g
s
0 0 .251 r
.78385 .22031 m .78386 .22203 L p .78251 .22248 L F P
0 g
s
0 0 .251 r
.78251 .22248 m .78376 .21788 L .78385 .22031 L p F P
0 g
s
.486 .546 .843 r
.76702 .16712 m .76499 .16696 L .76426 .17173 L p F P
0 g
s
.486 .546 .843 r
.76426 .17173 m .76954 .17241 L .76702 .16712 L p F P
0 g
s
.737 .881 .947 r
.63481 .38043 m .63733 .38211 L .6269 .38769 L p F P
0 g
s
.737 .881 .947 r
.62804 .38402 m .63481 .38043 L p .6269 .38769 L F P
0 g
s
.737 .881 .947 r
.6269 .38769 m .62547 .38672 L .62804 .38402 L p F P
0 g
s
0 0 0 r
.58619 .30211 m .58601 .30245 L .5865 .30169 L closepath p F P
0 g
s
0 0 .12 r
.56821 .32912 m .56733 .33062 L .56798 .32998 L closepath p F P
0 g
s
.76 .91 .942 r
.65792 .3731 m .65025 .37769 L .64777 .37624 L p F P
0 g
s
.866 .673 .639 r
.26695 .37671 m .27129 .37959 L .27315 .37454 L p F P
0 g
s
.866 .673 .639 r
.27315 .37454 m .26873 .37168 L .26695 .37671 L p F P
0 g
s
.664 .759 .921 r
.56436 .40032 m .57476 .39677 L .57743 .39977 L p F P
0 g
s
.651 .729 .907 r
.57476 .39677 m .56436 .40032 L .56166 .39659 L p F P
0 g
s
.685 .732 .887 r
.24516 .40032 m .25509 .39616 L .25823 .39965 L p F P
0 g
s
.692 .734 .882 r
.25509 .39616 m .24516 .40032 L .24199 .39706 L p F P
0 g
s
.746 .747 .853 r
.26594 .39475 m .25823 .39965 L .25509 .39616 L p F P
0 g
s
.887 .986 .808 r
.62939 .23746 m .6343 .23154 L .63252 .23667 L p F P
0 g
s
.887 .986 .808 r
.63252 .23667 m .63185 .23745 L .62939 .23746 L p F P
0 g
s
.867 .995 .763 r
.7508 .29578 m .74851 .30086 L .75355 .29461 L p F P
0 g
s
.867 .995 .763 r
.75371 .29217 m .7508 .29578 L p .75355 .29461 L F P
0 g
s
.867 .995 .763 r
.75355 .29461 m .75475 .292 L .75371 .29217 L p F P
0 g
s
.788 .951 .925 r
.68392 .35875 m .68236 .35985 L .68336 .35853 L closepath p F P
0 g
s
.784 .941 .929 r
.68152 .35765 m .68336 .35853 L .68236 .35985 L p F P
0 g
s
.784 .941 .929 r
.67325 .36331 m .68152 .35765 L p .68236 .35985 L F P
0 g
s
.784 .941 .929 r
.67189 .36514 m .67325 .36331 L p .68236 .35985 L F P
0 g
s
.674 .78 .93 r
.58785 .39573 m .57743 .39977 L .57476 .39677 L p F P
0 g
s
.489 .35 .619 r
.55196 .37379 m .55104 .36825 L .54268 .37433 L p F P
0 g
s
.489 .35 .619 r
.54595 .3781 m .55196 .37379 L p .54268 .37433 L F P
0 g
s
.489 .35 .619 r
.54268 .37433 m .54295 .37626 L .54595 .3781 L p F P
0 g
s
.905 .983 .776 r
.62751 .24286 m .63185 .23745 L .62939 .23746 L p F P
0 g
s
.74 .805 .328 r
.77625 .25129 m .77467 .2562 L .77664 .25104 L p F P
0 g
s
.74 .805 .328 r
.77664 .25104 m .77827 .24611 L .77625 .25129 L p F P
0 g
s
.89 .656 .579 r
.26453 .36873 m .26873 .37168 L .26965 .36697 L p F P
0 g
s
.89 .656 .579 r
.26965 .36697 m .26543 .36403 L .26453 .36873 L p F P
0 g
s
0 0 0 r
.58714 .30151 m .59059 .29584 L .5865 .30169 L p F P
0 g
s
0 0 0 r
.58489 .30469 m .58714 .30151 L p .5865 .30169 L F P
0 g
s
0 0 0 r
.5865 .30169 m .58601 .30245 L .58489 .30469 L p F P
0 g
s
.901 .486 .124 r
.24171 .32384 m .24497 .32721 L .2436 .32341 L p F P
0 g
s
.901 .486 .124 r
.2436 .32341 m .24035 .32004 L .24171 .32384 L p F P
0 g
s
.797 .952 .919 r
.69424 .35124 m .68392 .35875 L .68336 .35853 L p F P
0 g
s
.028 0 .189 r
.56725 .33338 m .56454 .33607 L .56733 .33062 L p F P
0 g
s
.028 0 .189 r
.56733 .33062 m .56798 .32998 L .56725 .33338 L p F P
0 g
s
0 0 0 r
.78105 .23631 m .77975 .24114 L .78072 .23636 L p F P
0 g
s
0 0 0 r
.78072 .23636 m .78204 .23151 L .78105 .23631 L p F P
0 g
s
.158 .23 .688 r
.78271 .19147 m .78189 .19622 L .77916 .19282 L p F P
0 g
s
.158 .23 .688 r
.77916 .19282 m .7799 .18809 L .78271 .19147 L p F P
0 g
s
.909 .64 .518 r
.2614 .36101 m .26543 .36403 L .26573 .35956 L p F P
0 g
s
.909 .64 .518 r
.26573 .35956 m .2617 .35653 L .2614 .36101 L p F P
0 g
s
.684 .727 .882 r
.72721 .16173 m .73786 .1574 L .74029 .16114 L p F P
0 g
s
.694 .736 .883 r
.73786 .1574 m .72721 .16173 L .72478 .15837 L p F P
0 g
s
.919 .524 .211 r
.24561 .32937 m .24497 .32721 L .24839 .33051 L p F P
0 g
s
.919 .524 .211 r
.24839 .33051 m .24883 .33199 L .24561 .32937 L p F P
0 g
s
0 0 0 r
.58601 .30245 m .58286 .30742 L .58489 .30469 L closepath p F P
0 g
s
.75 .933 .587 r
.60512 .27294 m .60916 .26708 L .60644 .27248 L p F P
0 g
s
.75 .933 .587 r
.60307 .27674 m .60512 .27294 L p .60644 .27248 L F P
0 g
s
.75 .933 .587 r
.60644 .27248 m .60383 .27605 L .60307 .27674 L p F P
0 g
s
.923 .623 .458 r
.25785 .35343 m .2617 .35653 L .26156 .35223 L p F P
0 g
s
.923 .623 .458 r
.26156 .35223 m .25772 .34913 L .25785 .35343 L p F P
0 g
s
0 0 0 r
.57615 .3187 m .57597 .31891 L .57703 .31598 L p F P
0 g
s
0 0 0 r
.57703 .31598 m .57941 .31309 L .57615 .3187 L p F P
0 g
s
.481 .676 .951 r
.19045 .38655 m .18725 .38661 L .18399 .38336 L p F P
0 g
s
.932 .606 .398 r
.25404 .34595 m .25772 .34913 L .25726 .34496 L p F P
0 g
s
.932 .606 .398 r
.25726 .34496 m .2536 .34178 L .25404 .34595 L p F P
0 g
s
.929 .56 .287 r
.24883 .33199 m .24939 .33445 L .2529 .33771 L p F P
0 g
s
.936 .587 .338 r
.25007 .33853 m .2536 .34178 L .2529 .33771 L p F P
0 g
s
.936 .587 .338 r
.2529 .33771 m .24939 .33445 L .25007 .33853 L p F P
0 g
s
.642 .688 .878 r
.75107 .15837 m .74029 .16114 L .73786 .1574 L p F P
0 g
s
.63 .676 .876 r
.75241 .16066 m .75186 .16292 L p .74029 .16114 L F P
0 g
s
.63 .676 .876 r
.74029 .16114 m .75107 .15837 L .75241 .16066 L p F P
0 g
s
.425 .485 .818 r
.77163 .17788 m .77175 .17727 L .77208 .17802 L closepath p F P
0 g
s
.571 .507 .744 r
.54222 .38816 m .54524 .3863 L .54578 .38789 L closepath p F P
0 g
s
.474 .356 .639 r
.54295 .37626 m .54595 .3781 L .54356 .37983 L closepath p F P
0 g
s
.348 .423 .797 r
.77208 .17802 m .77676 .18038 L .77615 .18508 L p F P
0 g
s
.264 .342 .756 r
.78065 .18335 m .7799 .18809 L .77615 .18508 L p F P
0 g
s
.264 .342 .756 r
.77615 .18508 m .77676 .18038 L .78065 .18335 L p F P
0 g
s
.858 .953 .604 r
.76592 .2727 m .76414 .27764 L .76749 .27199 L p F P
0 g
s
.858 .953 .604 r
.76749 .27199 m .76933 .26702 L .76592 .2727 L p F P
0 g
s
0 0 .166 r
.57078 .32953 m .56725 .33338 L .56798 .32998 L p F P
0 g
s
0 0 .166 r
.56798 .32998 m .57329 .32417 L .57078 .32953 L p F P
0 g
s
.819 .727 .763 r
.26526 .38875 m .26812 .38513 L .27252 .38798 L p F P
0 g
s
.819 .727 .763 r
.27252 .38798 m .26834 .39292 L .26526 .38875 L p F P
0 g
s
.879 .944 .852 r
.65053 .21388 m .64979 .21358 L .65097 .21236 L closepath p F P
0 g
s
.525 .699 .949 r
.21286 .39196 m .21199 .39204 L .21566 .39517 L p F P
0 g
s
.525 .699 .949 r
.21566 .39517 m .21608 .39513 L .21286 .39196 L p F P
0 g
s
.905 .983 .776 r
.62939 .23746 m .62913 .2378 L .62751 .24286 L p F P
0 g
s
.906 .983 .77 r
.62453 .24386 m .6225 .24906 L .62751 .24286 L p F P
0 g
s
.906 .983 .77 r
.62751 .24286 m .62913 .2378 L .62453 .24386 L p F P
0 g
s
.329 .157 .49 r
.55094 .36307 m .55062 .36334 L .55057 .35888 L p F P
0 g
s
.329 .157 .49 r
.55057 .35888 m .55093 .35858 L .55094 .36307 L p F P
0 g
s
.869 .995 .785 r
.74534 .30219 m .7508 .29578 L .74851 .30086 L p F P
0 g
s
.869 .995 .785 r
.74445 .3042 m .74534 .30219 L p .74851 .30086 L F P
0 g
s
.869 .995 .785 r
.74851 .30086 m .74576 .30409 L .74445 .3042 L p F P
0 g
s
.328 .426 .81 r
.77175 .17727 m .77208 .17802 L .77676 .18038 L p F P
0 g
s
.161 0 .334 r
.56047 .34645 m .55873 .3481 L .55914 .34427 L p F P
0 g
s
.161 0 .334 r
.55914 .34427 m .56221 .34136 L .56047 .34645 L p F P
0 g
s
.877 .993 .76 r
.6221 .24998 m .62168 .25009 L .6225 .24906 L closepath p F P
0 g
s
.775 .939 .59 r
.60383 .27605 m .60216 .27843 L .60307 .27674 L closepath p F P
0 g
s
.858 .99 .838 r
.73613 .31523 m .73558 .31517 L .73677 .31395 L closepath p F P
0 g
s
.608 .663 .878 r
.75186 .16292 m .75241 .16066 L .75352 .16259 L closepath p F P
0 g
s
.607 .603 .821 r
.54853 .39458 m .54956 .39439 L .54873 .39497 L closepath p F P
0 g
s
.637 .64 .836 r
.55894 .39224 m .54956 .39439 L .54873 .39497 L p F P
0 g
s
.637 .64 .836 r
.56166 .39659 m .55894 .39224 L p .54873 .39497 L F P
0 g
s
.585 .718 .935 r
.22579 .39336 m .21608 .39513 L .21286 .39196 L p F P
0 g
s
.688 .722 .205 r
.77935 .24256 m .77887 .24416 L .77975 .24114 L closepath p F P
0 g
s
.412 .491 .831 r
.76954 .17241 m .77212 .17321 L .77175 .17727 L closepath p F P
0 g
s
.328 .426 .81 r
.77739 .17566 m .77212 .17321 L .77175 .17727 L p F P
0 g
s
.328 .426 .81 r
.77676 .18038 m .77739 .17566 L p .77175 .17727 L F P
0 g
s
.763 .922 .941 r
.66068 .3714 m .65792 .3731 L .65978 .37092 L closepath p F P
0 g
s
.76 .91 .942 r
.65822 .37 m .65978 .37092 L .65792 .3731 L p F P
0 g
s
.76 .91 .942 r
.64777 .37624 m .65822 .37 L p .65792 .3731 L F P
0 g
s
.325 .154 .489 r
.55858 .35667 m .55094 .36307 L .55093 .35858 L p F P
0 g
s
.325 .154 .489 r
.55093 .35858 m .55852 .35221 L .55858 .35667 L p F P
0 g
s
.842 .897 .877 r
.67169 .1917 m .67029 .19294 L .66785 .19115 L p F P
0 g
s
.87 .91 .855 r
.66431 .19876 m .67029 .19294 L .66785 .19115 L p F P
0 g
s
.577 .577 .817 r
.54956 .39439 m .54853 .39458 L .54578 .38789 L p F P
0 g
s
.843 .873 .864 r
.67254 .18685 m .67169 .1917 L .67999 .18431 L p F P
0 g
s
.842 .897 .877 r
.66785 .19115 m .67254 .18685 L .67169 .1917 L p F P
0 g
s
.797 .952 .919 r
.68336 .35853 m .68626 .3543 L p .69424 .35124 L F P
0 g
s
.794 .939 .923 r
.68336 .35853 m .68152 .35765 L .68626 .3543 L closepath p F P
0 g
s
.732 .791 .899 r
.71915 .16139 m .71424 .164 L .71181 .16097 L p F P
0 g
s
.765 .8 .881 r
.70134 .16774 m .71181 .16097 L .71424 .164 L p F P
0 g
s
.72 .859 .948 r
.62436 .38592 m .61392 .39106 L .61134 .38903 L p F P
0 g
s
.801 .962 .913 r
.6943 .35119 m .69424 .35124 L .69428 .35118 L closepath p F P
0 g
s
.797 .952 .919 r
.69194 .35016 m .69428 .35118 L .69424 .35124 L p F P
0 g
s
.797 .952 .919 r
.68626 .3543 m .69194 .35016 L p .69424 .35124 L F P
0 g
s
.773 .726 .809 r
.26594 .39475 m .26834 .39292 L .26526 .38875 L p F P
0 g
s
.773 .726 .809 r
.26526 .38875 m .2613 .392 L .26594 .39475 L p F P
0 g
s
.746 .747 .853 r
.25509 .39616 m .2613 .392 L .26594 .39475 L p F P
0 g
s
.813 .962 .906 r
.70234 .34221 m .70467 .34312 L .6943 .35119 L p F P
0 g
s
.813 .962 .906 r
.69768 .34583 m .70234 .34221 L p .6943 .35119 L F P
0 g
s
.813 .962 .906 r
.6943 .35119 m .69428 .35118 L .69768 .34583 L p F P
0 g
s
0 0 .393 r
.78322 .21341 m .78324 .21335 L .78333 .21411 L closepath p F P
0 g
s
.86 .997 .791 r
.74576 .30409 m .74292 .3073 L .74445 .3042 L closepath p F P
0 g
s
.807 .949 .914 r
.69428 .35118 m .69194 .35016 L .69768 .34583 L closepath p F P
0 g
s
0 0 .332 r
.78476 .21286 m .78416 .20865 L .78324 .21335 L p F P
0 g
s
0 0 .332 r
.78382 .21761 m .78476 .21286 L p .78324 .21335 L F P
0 g
s
0 0 .332 r
.78324 .21335 m .78333 .21411 L .78382 .21761 L p F P
0 g
s
.84 .871 .866 r
.68059 .18376 m .67999 .18431 L .68007 .1833 L closepath p F P
0 g
s
.843 .873 .864 r
.67816 .18164 m .67254 .18685 L p .67999 .18431 L F P
0 g
s
.843 .873 .864 r
.67999 .18431 m .68007 .1833 L .67816 .18164 L p F P
0 g
s
.821 .871 .883 r
.68969 .17639 m .68059 .18376 L .68007 .1833 L p F P
0 g
s
.87 .91 .855 r
.66785 .19115 m .66508 .19395 L .66431 .19876 L p F P
0 g
s
.862 .919 .866 r
.65819 .20083 m .66508 .19395 L .66431 .19876 L p F P
0 g
s
.862 .919 .866 r
.658 .20168 m .65819 .20083 L p .66431 .19876 L F P
0 g
s
.862 .919 .866 r
.66431 .19876 m .66003 .20288 L .658 .20168 L p F P
0 g
s
.933 .563 .272 r
.24939 .33445 m .24883 .33199 L .24561 .32937 L p F P
0 g
s
.879 .916 .848 r
.66003 .20288 m .6574 .20565 L .658 .20168 L closepath p F P
0 g
s
.763 .927 .568 r
.60112 .2788 m .59816 .28428 L .60216 .27843 L p F P
0 g
s
.763 .927 .568 r
.60137 .27842 m .60112 .2788 L p .60216 .27843 L F P
0 g
s
.763 .927 .568 r
.60216 .27843 m .60307 .27674 L .60137 .27842 L p F P
0 g
s
0 0 0 r
.58366 .30738 m .57941 .31309 L .58286 .30742 L p F P
0 g
s
0 0 0 r
.58286 .30742 m .58489 .30469 L .58366 .30738 L p F P
0 g
s
.577 .577 .817 r
.55732 .38919 m .54956 .39439 L p .54578 .38789 L F P
0 g
s
.619 .623 .833 r
.54956 .39439 m .55732 .38919 L .55894 .39224 L closepath p F P
0 g
s
.774 .923 .935 r
.66867 .36341 m .6711 .36473 L .66068 .3714 L p F P
0 g
s
.774 .923 .935 r
.66256 .36731 m .66867 .36341 L p .66068 .3714 L F P
0 g
s
.774 .923 .935 r
.66068 .3714 m .65978 .37092 L .66256 .36731 L p F P
0 g
s
.86 .993 .825 r
.73922 .30883 m .73677 .31395 L .74292 .3073 L p F P
0 g
s
.86 .993 .825 r
.74358 .30414 m .73922 .30883 L p .74292 .3073 L F P
0 g
s
.86 .993 .825 r
.74292 .3073 m .74445 .3042 L .74358 .30414 L p F P
0 g
s
.517 .432 .699 r
.55365 .38027 m .54524 .3863 L .54356 .37983 L p F P
0 g
s
.517 .432 .699 r
.55344 .37959 m .55365 .38027 L p .54356 .37983 L F P
0 g
s
.517 .432 .699 r
.54356 .37983 m .54595 .3781 L .55344 .37959 L p F P
0 g
s
.873 .973 .664 r
.76392 .27821 m .76369 .27832 L .76414 .27764 L closepath p F P
0 g
s
.551 .601 .856 r
.76548 .16399 m .76499 .16696 L p .75352 .16259 L F P
0 g
s
.551 .601 .856 r
.75352 .16259 m .76452 .16211 L .76548 .16399 L p F P
0 g
s
.543 .63 .888 r
.75241 .16066 m .75352 .16259 L .76452 .16211 L p F P
0 g
s
.882 .918 .845 r
.65213 .20741 m .65097 .21236 L .6574 .20565 L p F P
0 g
s
.882 .918 .845 r
.65758 .20144 m .65213 .20741 L p .6574 .20565 L F P
0 g
s
.882 .918 .845 r
.6574 .20565 m .658 .20168 L .65758 .20144 L p F P
0 g
s
0 0 .367 r
.78333 .21411 m .78382 .21761 L .78376 .21788 L closepath p F P
0 g
s
.708 .834 .943 r
.60135 .3942 m .6009 .39383 L .60261 .39305 L closepath p F P
0 g
s
.874 .993 .757 r
.61986 .24995 m .62453 .24386 L .6225 .24906 L p F P
0 g
s
.874 .993 .757 r
.61957 .25069 m .61986 .24995 L p .6225 .24906 L F P
0 g
s
.874 .993 .757 r
.6225 .24906 m .62168 .25009 L .61957 .25069 L p F P
0 g
s
.781 .929 .931 r
.67189 .36514 m .6711 .36473 L .67325 .36331 L closepath p F P
0 g
s
.077 0 .25 r
.56665 .33696 m .56221 .34136 L .56454 .33607 L p F P
0 g
s
.077 0 .25 r
.56454 .33607 m .56725 .33338 L .56665 .33696 L p F P
0 g
s
.848 .698 .696 r
.26392 .3822 m .26812 .38513 L .27129 .37959 L p F P
0 g
s
.848 .698 .696 r
.27129 .37959 m .26695 .37671 L .26392 .3822 L p F P
0 g
s
.818 .849 .872 r
.69094 .17537 m .68969 .17639 L .68979 .17421 L closepath p F P
0 g
s
.821 .871 .883 r
.68851 .17292 m .68979 .17421 L .68969 .17639 L p F P
0 g
s
.821 .871 .883 r
.68074 .17948 m .68851 .17292 L p .68969 .17639 L F P
0 g
s
.821 .871 .883 r
.68007 .1833 m .68074 .17948 L p .68969 .17639 L F P
0 g
s
.811 .879 .446 r
.77382 .25662 m .77229 .2615 L .77467 .2562 L p F P
0 g
s
.811 .879 .446 r
.77467 .2562 m .77625 .25129 L .77382 .25662 L p F P
0 g
s
.747 .888 .943 r
.64484 .37792 m .63733 .38211 L .63481 .38043 L p F P
0 g
s
.893 .988 .746 r
.62168 .25009 m .61793 .25511 L .61957 .25069 L closepath p F P
0 g
s
.797 .846 .888 r
.70131 .16776 m .69094 .17537 L .68979 .17421 L p F P
0 g
s
.732 .871 .946 r
.62547 .38672 m .62436 .38592 L .62804 .38402 L closepath p F P
0 g
s
.818 .963 .902 r
.70468 .34312 m .70467 .34312 L .70468 .34312 L closepath p F P
0 g
s
.82 .959 .903 r
.70468 .34312 m .70467 .34312 L .70234 .34221 L p F P
0 g
s
.822 .968 .898 r
.70783 .3378 m .70468 .34312 L .71396 .33539 L p F P
0 g
s
.82 .959 .903 r
.70234 .34221 m .70783 .3378 L .70468 .34312 L p F P
0 g
s
.481 .676 .951 r
.18399 .38336 m .18702 .38331 L .19045 .38655 L p F P
0 g
s
.486 .678 .95 r
.19351 .38313 m .18702 .38331 L .19045 .38655 L p F P
0 g
s
.486 .678 .95 r
.19045 .38655 m .19677 .38639 L .19351 .38313 L p F P
0 g
s
0 0 .085 r
.78333 .22665 m .78204 .23151 L .78254 .2269 L p F P
0 g
s
0 0 .085 r
.78254 .2269 m .78386 .22203 L .78333 .22665 L p F P
0 g
s
.879 .946 .852 r
.64734 .21259 m .65213 .20741 L .65097 .21236 L p F P
0 g
s
.879 .946 .852 r
.65097 .21236 m .64979 .21358 L .64734 .21259 L p F P
0 g
s
.84 .979 .683 r
.61244 .26315 m .61152 .26369 L .61342 .26114 L closepath p F P
0 g
s
.86 .989 .839 r
.73335 .31489 m .73922 .30883 L .73677 .31395 L p F P
0 g
s
.86 .989 .839 r
.73677 .31395 m .73558 .31517 L .73335 .31489 L p F P
0 g
s
.827 .873 .879 r
.68007 .1833 m .67816 .18164 L .68074 .17948 L closepath p F P
0 g
s
.875 .974 .665 r
.76216 .27851 m .76592 .2727 L .76414 .27764 L p F P
0 g
s
.875 .974 .665 r
.76191 .27918 m .76216 .27851 L p .76414 .27764 L F P
0 g
s
.875 .974 .665 r
.76414 .27764 m .76369 .27832 L .76191 .27918 L p F P
0 g
s
.851 .991 .843 r
.72985 .32086 m .73558 .31517 L .73335 .31489 L p F P
0 g
s
.903 .949 .823 r
.64516 .21884 m .64979 .21358 L .64734 .21259 L p F P
0 g
s
.633 .73 .918 r
.229 .39656 m .23881 .39377 L .24199 .39706 L p F P
0 g
s
.638 .731 .916 r
.23881 .39377 m .229 .39656 L .22579 .39336 L p F P
0 g
s
.74 .785 .888 r
.71915 .16139 m .72478 .15837 L .72235 .15504 L p F P
0 g
s
.74 .785 .888 r
.72235 .15504 m .71932 .15676 L .71915 .16139 L p F P
0 g
s
.732 .791 .899 r
.71181 .16097 m .71932 .15676 L .71915 .16139 L p F P
0 g
s
.577 .577 .817 r
.54578 .38789 m .55621 .38687 L .55732 .38919 L p F P
0 g
s
.576 .51 .743 r
.54524 .3863 m .54578 .38789 L .55621 .38687 L p F P
0 g
s
.881 .992 .754 r
.75475 .292 m .75371 .29217 L .75576 .28955 L closepath p F P
0 g
s
.864 .976 .67 r
.76369 .27832 m .76014 .28352 L .76191 .27918 L closepath p F P
0 g
s
.576 .51 .743 r
.55621 .38687 m .55365 .38027 L .54524 .3863 L p F P
0 g
s
.692 .725 .208 r
.77961 .24127 m .78105 .23631 L .77975 .24114 L p F P
0 g
s
.692 .725 .208 r
.77856 .24519 m .77961 .24127 L p .77975 .24114 L F P
0 g
s
.692 .725 .208 r
.77975 .24114 m .77887 .24416 L .77856 .24519 L p F P
0 g
s
.709 .82 .934 r
.60261 .39305 m .6009 .39383 L .59829 .39143 L p F P
0 g
s
.692 .815 .941 r
.58785 .39573 m .59829 .39143 L .6009 .39383 L p F P
0 g
s
.827 .98 .884 r
.71502 .33448 m .71396 .33539 L .71458 .33437 L closepath p F P
0 g
s
.822 .968 .898 r
.71271 .33374 m .70783 .3378 L p .71396 .33539 L F P
0 g
s
.822 .968 .898 r
.71396 .33539 m .71458 .33437 L .71271 .33374 L p F P
0 g
s
.876 .682 .637 r
.2628 .37374 m .26695 .37671 L .26873 .37168 L p F P
0 g
s
.876 .682 .637 r
.26873 .37168 m .26453 .36873 L .2628 .37374 L p F P
0 g
s
.527 .698 .948 r
.20002 .38961 m .20841 .38886 L .21199 .39204 L p F P
0 g
s
.529 .697 .946 r
.20841 .38886 m .20002 .38961 L .19677 .38639 L p F P
0 g
s
.851 .991 .843 r
.73335 .31489 m .7326 .31565 L .72985 .32086 L p F P
0 g
s
.848 .985 .859 r
.72515 .32275 m .7326 .31565 L .72985 .32086 L p F P
0 g
s
.848 .985 .859 r
.72402 .32495 m .72515 .32275 L p .72985 .32086 L F P
0 g
s
.848 .985 .859 r
.72985 .32086 m .72532 .32519 L .72402 .32495 L p F P
0 g
s
.836 .979 .878 r
.72229 .32799 m .71502 .33448 L .71458 .33437 L p F P
0 g
s
0 0 .493 r
.78507 .20389 m .78416 .20865 L .78295 .20468 L p F P
0 g
s
0 0 .493 r
.78295 .20468 m .78383 .19992 L .78507 .20389 L p F P
0 g
s
.847 .923 .533 r
.77189 .26268 m .77143 .26315 L .77229 .2615 L closepath p F P
0 g
s
.839 .986 .866 r
.72532 .32519 m .72229 .32799 L .72402 .32495 L closepath p F P
0 g
s
.836 .979 .878 r
.72306 .32467 m .72402 .32495 L .72229 .32799 L p F P
0 g
s
.836 .979 .878 r
.71692 .33013 m .72306 .32467 L p .72229 .32799 L F P
0 g
s
.836 .979 .878 r
.71458 .33437 m .71692 .33013 L p .72229 .32799 L F P
0 g
s
.632 .692 .888 r
.57209 .3934 m .56166 .39659 L .55894 .39224 L p F P
0 g
s
.651 .729 .907 r
.56166 .39659 m .57209 .3934 L .57476 .39677 L p F P
0 g
s
.712 .878 .479 r
.59754 .28451 m .5942 .29012 L .59816 .28428 L p F P
0 g
s
.712 .878 .479 r
.59816 .28428 m .60112 .2788 L .59754 .28451 L p F P
0 g
s
.43 .508 .838 r
.77212 .17321 m .76954 .17241 L .76702 .16712 L p F P
0 g
s
.899 .666 .576 r
.26052 .3657 m .26453 .36873 L .26543 .36403 L p F P
0 g
s
.899 .666 .576 r
.26543 .36403 m .2614 .36101 L .26052 .3657 L p F P
0 g
s
.903 .949 .823 r
.64734 .21259 m .64618 .21396 L .64516 .21884 L p F P
0 g
s
.891 .966 .832 r
.64082 .22029 m .64618 .21396 L .64516 .21884 L p F P
0 g
s
.891 .966 .832 r
.63945 .22505 m .64082 .22029 L p .64516 .21884 L F P
0 g
s
.891 .966 .832 r
.64516 .21884 m .63958 .22508 L .63945 .22505 L p F P
0 g
s
.711 .84 .944 r
.61134 .38903 m .60261 .39305 L .60904 .38712 L closepath p F P
0 g
s
.709 .82 .934 r
.60875 .38687 m .60904 .38712 L .60261 .39305 L p F P
0 g
s
.709 .82 .934 r
.59829 .39143 m .60875 .38687 L p .60261 .39305 L F P
0 g
s
.892 .987 .734 r
.61565 .25587 m .61342 .26114 L .61793 .25511 L p F P
0 g
s
.892 .987 .734 r
.61922 .2508 m .61565 .25587 L p .61793 .25511 L F P
0 g
s
.892 .987 .734 r
.61793 .25511 m .61957 .25069 L .61922 .2508 L p F P
0 g
s
.754 .748 .847 r
.2613 .392 m .25509 .39616 L .25195 .39265 L p F P
0 g
s
.692 .734 .882 r
.24199 .39706 m .25195 .39265 L .25509 .39616 L p F P
0 g
s
.58 .652 .886 r
.75107 .15837 m .75237 .1582 L .75241 .16066 L closepath p F P
0 g
s
.543 .63 .888 r
.76204 .15736 m .75237 .1582 L .75241 .16066 L p F P
0 g
s
.543 .63 .888 r
.76452 .16211 m .76204 .15736 L p .75241 .16066 L F P
0 g
s
0 0 0 r
.58092 .31264 m .57615 .3187 L .57941 .31309 L p F P
0 g
s
0 0 0 r
.58356 .30763 m .58092 .31264 L p .57941 .31309 L F P
0 g
s
0 0 0 r
.57941 .31309 m .58366 .30738 L .58356 .30763 L p F P
0 g
s
.763 .927 .567 r
.60307 .27674 m .60137 .27842 L .60512 .27294 L closepath p F P
0 g
s
.699 .735 .879 r
.25195 .39265 m .24199 .39706 L .23881 .39377 L p F P
0 g
s
.918 .649 .515 r
.25754 .35791 m .2614 .36101 L .2617 .35653 L p F P
0 g
s
.918 .649 .515 r
.2617 .35653 m .25785 .35343 L .25754 .35791 L p F P
0 g
s
.797 .846 .888 r
.69891 .16502 m .70131 .16771 L .70131 .16776 L p F P
0 g
s
.797 .846 .888 r
.69021 .17165 m .69891 .16502 L p .70131 .16776 L F P
0 g
s
.797 .846 .888 r
.68979 .17421 m .69021 .17165 L p .70131 .16776 L F P
0 g
s
.795 .826 .876 r
.70134 .16774 m .70131 .16776 L .70131 .16771 L closepath p F P
0 g
s
.774 .822 .89 r
.70938 .15796 m .71181 .16097 L .70134 .16774 L p F P
0 g
s
.774 .822 .89 r
.70205 .16292 m .70938 .15796 L p .70134 .16774 L F P
0 g
s
.774 .822 .89 r
.70134 .16774 m .70131 .16771 L .70205 .16292 L p F P
0 g
s
.685 .799 .936 r
.59829 .39143 m .58785 .39573 L .5852 .39296 L p F P
0 g
s
.674 .78 .93 r
.57476 .39677 m .5852 .39296 L .58785 .39573 L p F P
0 g
s
.777 .824 .89 r
.70131 .16771 m .69891 .16502 L .70205 .16292 L closepath p F P
0 g
s
.768 .911 .937 r
.65978 .37092 m .65822 .37 L .66256 .36731 L closepath p F P
0 g
s
.931 .632 .453 r
.25415 .35026 m .25785 .35343 L .25772 .34913 L p F P
0 g
s
.931 .632 .453 r
.25772 .34913 m .25404 .34595 L .25415 .35026 L p F P
0 g
s
.782 .924 .93 r
.67325 .36331 m .6711 .36473 L .66867 .36341 L p F P
0 g
s
.518 .431 .696 r
.54595 .3781 m .55196 .37379 L .55344 .37959 L closepath p F P
0 g
s
.662 .755 .919 r
.5852 .39296 m .57476 .39677 L .57209 .3934 L p F P
0 g
s
.939 .613 .39 r
.2505 .34271 m .25404 .34595 L .2536 .34178 L p F P
0 g
s
.939 .613 .39 r
.2536 .34178 m .25007 .33853 L .2505 .34271 L p F P
0 g
s
.92 .525 .188 r
.24241 .32622 m .24171 .32384 L .24497 .32721 L p F P
0 g
s
.92 .525 .188 r
.24497 .32721 m .24561 .32937 L .24241 .32622 L p F P
0 g
s
.933 .563 .272 r
.24561 .32937 m .24601 .33114 L .24939 .33445 L p F P
0 g
s
.941 .593 .328 r
.24668 .33522 m .25007 .33853 L .24939 .33445 L p F P
0 g
s
.941 .593 .328 r
.24939 .33445 m .24601 .33114 L .24668 .33522 L p F P
0 g
s
.833 .967 .889 r
.71458 .33437 m .71271 .33374 L .71692 .33013 L closepath p F P
0 g
s
.642 .688 .878 r
.73786 .1574 m .74863 .15427 L .75107 .15837 L p F P
0 g
s
.653 .699 .88 r
.74863 .15427 m .73786 .1574 L .73542 .15373 L p F P
0 g
s
.694 .736 .883 r
.72478 .15837 m .73542 .15373 L .73786 .1574 L p F P
0 g
s
.878 .989 .73 r
.75773 .28455 m .75576 .28955 L .76014 .28352 L p F P
0 g
s
.878 .989 .73 r
.76163 .27925 m .75773 .28455 L p .76014 .28352 L F P
0 g
s
.878 .989 .73 r
.76014 .28352 m .76191 .27918 L .76163 .27925 L p F P
0 g
s
.75 .902 .945 r
.64777 .37624 m .64484 .37792 L .64685 .37568 L closepath p F P
0 g
s
.747 .888 .943 r
.64527 .37463 m .64685 .37568 L .64484 .37792 L p F P
0 g
s
.747 .888 .943 r
.63481 .38043 m .64527 .37463 L p .64484 .37792 L F P
0 g
s
.827 .727 .755 r
.26217 .38455 m .26392 .3822 L .26812 .38513 L p F P
0 g
s
.827 .727 .755 r
.26812 .38513 m .26526 .38875 L .26217 .38455 L p F P
0 g
s
.385 .242 .561 r
.55252 .36703 m .55104 .36825 L .55062 .36334 L p F P
0 g
s
.385 .242 .561 r
.55062 .36334 m .55094 .36307 L .55252 .36703 L p F P
0 g
s
.483 .674 .949 r
.18702 .38331 m .18399 .38336 L .18072 .38007 L p F P
0 g
s
.907 .959 .814 r
.63958 .22508 m .63939 .22531 L .63945 .22505 L closepath p F P
0 g
s
.785 .934 .929 r
.67325 .36331 m .68152 .35765 L .67912 .35647 L p F P
0 g
s
.785 .934 .929 r
.67912 .35647 m .67731 .3577 L .67325 .36331 L p F P
0 g
s
.782 .924 .93 r
.66867 .36341 m .67731 .3577 L .67325 .36331 L p F P
0 g
s
.909 .961 .809 r
.63558 .22658 m .6343 .23154 L .63939 .22531 L p F P
0 g
s
.909 .961 .809 r
.63713 .22461 m .63558 .22658 L p .63939 .22531 L F P
0 g
s
.909 .961 .809 r
.63939 .22531 m .63945 .22505 L .63713 .22461 L p F P
0 g
s
.703 .744 .883 r
.73542 .15373 m .72478 .15837 L .72235 .15504 L p F P
0 g
s
.041 .106 .605 r
.7847 .19515 m .78383 .19992 L .78189 .19622 L p F P
0 g
s
.041 .106 .605 r
.78189 .19622 m .78271 .19147 L .7847 .19515 L p F P
0 g
s
.615 .815 .405 r
.59389 .2906 m .59369 .2909 L .5942 .29012 L closepath p F P
0 g
s
0 0 0 r
.77887 .24416 m .77827 .24611 L .77856 .24519 L closepath p F P
0 g
s
.85 .925 .536 r
.77101 .26209 m .77382 .25662 L .77229 .2615 L p F P
0 g
s
.85 .925 .536 r
.77033 .26424 m .77101 .26209 L p .77229 .2615 L F P
0 g
s
.85 .925 .536 r
.77229 .2615 m .77143 .26315 L .77033 .26424 L p F P
0 g
s
.134 0 .318 r
.56622 .34077 m .56047 .34645 L .56221 .34136 L p F P
0 g
s
.134 0 .318 r
.56221 .34136 m .56665 .33696 L .56622 .34077 L p F P
0 g
s
0 0 .218 r
.78376 .21788 m .78385 .22031 L .78382 .21761 L closepath p F P
0 g
s
.733 .862 .941 r
.62804 .38402 m .62436 .38592 L .6218 .38396 L p F P
0 g
s
.72 .859 .948 r
.61134 .38903 m .6218 .38396 L .62436 .38592 L p F P
0 g
s
.382 .241 .562 r
.55902 .3616 m .55252 .36703 L .55094 .36307 L p F P
0 g
s
.382 .241 .562 r
.55094 .36307 m .55858 .35667 L .55902 .3616 L p F P
0 g
s
.503 .566 .853 r
.76499 .16696 m .76548 .16399 L .76702 .16712 L closepath p F P
0 g
s
.899 .966 .821 r
.63945 .22505 m .63713 .22461 L .64082 .22029 L closepath p F P
0 g
s
.802 .849 .885 r
.68979 .17421 m .68851 .17292 L .69021 .17165 L closepath p F P
0 g
s
.529 .698 .947 r
.20963 .38874 m .20841 .38886 L .21199 .39204 L p F P
0 g
s
.529 .698 .947 r
.21199 .39204 m .21286 .39196 L .20963 .38874 L p F P
0 g
s
.784 .731 .804 r
.2613 .392 m .26526 .38875 L .26217 .38455 L p F P
0 g
s
.784 .731 .804 r
.26217 .38455 m .25695 .38912 L .2613 .392 L p F P
0 g
s
.754 .748 .847 r
.25195 .39265 m .25695 .38912 L .2613 .392 L p F P
0 g
s
0 0 .216 r
.78482 .21727 m .78476 .21286 L .78382 .21761 L p F P
0 g
s
0 0 .216 r
.7839 .22185 m .78482 .21727 L p .78382 .21761 L F P
0 g
s
0 0 .216 r
.78382 .21761 m .78385 .22031 L .7839 .22185 L p F P
0 g
s
.832 .976 .675 r
.6115 .26178 m .61565 .25587 L .61342 .26114 L p F P
0 g
s
.832 .976 .675 r
.6103 .26445 m .6115 .26178 L p .61342 .26114 L F P
0 g
s
.832 .976 .675 r
.61342 .26114 m .61152 .26369 L .6103 .26445 L p F P
0 g
s
0 0 0 r
.58383 .30714 m .58366 .30738 L .58489 .30469 L p F P
0 g
s
0 0 0 r
.58489 .30469 m .58714 .30151 L .58383 .30714 L p F P
0 g
s
.76 .903 .94 r
.65574 .36849 m .65822 .37 L .64777 .37624 L p F P
0 g
s
.76 .903 .94 r
.64979 .37202 m .65574 .36849 L p .64777 .37624 L F P
0 g
s
.76 .903 .94 r
.64777 .37624 m .64685 .37568 L .64979 .37202 L p F P
0 g
s
0 0 0 r
.59404 .29021 m .59754 .28451 L .5942 .29012 L p F P
0 g
s
.612 .806 .387 r
.59241 .2929 m .59369 .2909 L .59145 .29448 L p F P
0 g
s
.612 .806 .387 r
.59145 .29448 m .59059 .29584 L .59241 .2929 L p F P
0 g
s
0 0 0 r
.59241 .2929 m .59124 .29489 L .5933 .29144 L p F P
0 g
s
0 0 0 r
.5942 .29012 m .59369 .2909 L .59241 .2929 L p F P
0 g
s
0 0 0 r
.59241 .2929 m .59404 .29021 L p .5942 .29012 L F P
0 g
s
0 0 0 r
.5933 .29144 m .59404 .29021 L .59241 .2929 L p F P
0 g
s
.836 .925 .537 r
.77143 .26315 m .76933 .26702 L .77033 .26424 L closepath p F P
0 g
s
.218 .034 .404 r
.55949 .35128 m .55852 .35221 L .55873 .3481 L p F P
0 g
s
.218 .034 .404 r
.55873 .3481 m .56047 .34645 L .55949 .35128 L p F P
0 g
s
.585 .718 .935 r
.21286 .39196 m .22258 .39013 L .22579 .39336 L p F P
0 g
s
.587 .718 .934 r
.22258 .39013 m .21286 .39196 L .20963 .38874 L p F P
0 g
s
0 0 .024 r
.57597 .31891 m .57589 .3192 L .57615 .3187 L closepath p F P
0 g
s
.168 .239 .694 r
.78354 .18669 m .78271 .19147 L .7799 .18809 L p F P
0 g
s
.168 .239 .694 r
.7799 .18809 m .78065 .18335 L .78354 .18669 L p F P
0 g
s
.023 0 .229 r
.56869 .33474 m .56665 .33696 L .56725 .33338 L p F P
0 g
s
.023 0 .229 r
.56725 .33338 m .57078 .32953 L .56869 .33474 L p F P
0 g
s
.761 .819 .347 r
.77748 .24739 m .77625 .25129 L .77827 .24611 L p F P
0 g
s
.761 .819 .347 r
.77827 .24611 m .77856 .24519 L .77748 .24739 L p F P
0 g
s
.873 .991 .816 r
.74445 .3042 m .74358 .30414 L .74534 .30219 L closepath p F P
0 g
s
.895 .984 .799 r
.63077 .23272 m .63558 .22658 L .6343 .23154 L p F P
0 g
s
.895 .984 .799 r
.62922 .23746 m .63077 .23272 L p .6343 .23154 L F P
0 g
s
.895 .984 .799 r
.6343 .23154 m .62939 .23746 L .62922 .23746 L p F P
0 g
s
.855 .976 .67 r
.61152 .26369 m .60916 .26708 L .6103 .26445 L closepath p F P
0 g
s
.592 .663 .887 r
.75237 .1582 m .75107 .15837 L .74863 .15427 L p F P
0 g
s
0 0 .057 r
.57827 .31804 m .58092 .31264 L .57615 .3187 L p F P
0 g
s
0 0 .057 r
.57508 .32207 m .57827 .31804 L p .57615 .3187 L F P
0 g
s
0 0 .057 r
.57615 .3187 m .57589 .3192 L .57508 .32207 L p F P
0 g
s
0 0 0 r
.78231 .23146 m .78105 .23631 L .78204 .23151 L p F P
0 g
s
0 0 0 r
.78204 .23151 m .78333 .22665 L .78231 .23146 L p F P
0 g
s
.733 .862 .941 r
.63228 .37864 m .63277 .379 L .62804 .38402 L p F P
0 g
s
.733 .862 .941 r
.6218 .38396 m .63228 .37864 L p .62804 .38402 L F P
0 g
s
.736 .88 .947 r
.63481 .38043 m .62804 .38402 L .63277 .379 L closepath p F P
0 g
s
.882 .991 .755 r
.75293 .29074 m .75773 .28455 L .75576 .28955 L p F P
0 g
s
.882 .991 .755 r
.75229 .29239 m .75293 .29074 L p .75576 .28955 L F P
0 g
s
.882 .991 .755 r
.75576 .28955 m .75371 .29217 L .75229 .29239 L p F P
0 g
s
.856 .706 .694 r
.2599 .37919 m .26392 .3822 L .26695 .37671 L p F P
0 g
s
.856 .706 .694 r
.26695 .37671 m .2628 .37374 L .2599 .37919 L p F P
0 g
s
.794 .937 .923 r
.68626 .3543 m .68152 .35765 L .67912 .35647 L p F P
0 g
s
0 0 .055 r
.57589 .3192 m .57329 .32417 L .57508 .32207 L closepath p F P
0 g
s
.43 .508 .838 r
.76702 .16712 m .77255 .16854 L .77212 .17321 L p F P
0 g
s
.366 .448 .812 r
.77804 .17091 m .77739 .17566 L .77212 .17321 L p F P
0 g
s
.366 .448 .812 r
.77212 .17321 m .77255 .16854 L .77804 .17091 L p F P
0 g
s
.277 .354 .762 r
.78134 .17896 m .78065 .18335 L .77676 .18038 L p F P
0 g
s
.277 .354 .762 r
.78112 .17835 m .78134 .17896 L p .77676 .18038 L F P
0 g
s
.277 .354 .762 r
.77676 .18038 m .77739 .17566 L .78112 .17835 L p F P
0 g
s
.741 .796 .896 r
.71932 .15676 m .71181 .16097 L .70938 .15796 L p F P
0 g
s
.418 .517 .852 r
.76548 .16399 m .76702 .16712 L .77255 .16854 L p F P
0 g
s
.872 .994 .761 r
.75371 .29217 m .7508 .29578 L .75229 .29239 L closepath p F P
0 g
s
.592 .663 .887 r
.74863 .15427 m .75228 .15368 L .75237 .1582 L p F P
0 g
s
.565 .625 .87 r
.75957 .15277 m .75228 .15368 L .75237 .1582 L p F P
0 g
s
.565 .625 .87 r
.75237 .1582 m .76204 .15736 L .75957 .15277 L p F P
0 g
s
.936 .566 .256 r
.24601 .33114 m .24561 .32937 L .24241 .32622 L p F P
0 g
s
.717 .842 .941 r
.61923 .3819 m .6218 .38396 L .61134 .38903 L p F P
0 g
s
.717 .842 .941 r
.60972 .38642 m .61923 .3819 L p .61134 .38903 L F P
0 g
s
.717 .842 .941 r
.61134 .38903 m .60904 .38712 L .60972 .38642 L p F P
0 g
s
.799 .948 .919 r
.69194 .35016 m .68626 .3543 L .68974 .3492 L closepath p F P
0 g
s
.794 .937 .923 r
.68956 .3491 m .68974 .3492 L .68626 .3543 L p F P
0 g
s
.794 .937 .923 r
.67912 .35647 m .68956 .3491 L p .68626 .3543 L F P
0 g
s
.869 .922 .86 r
.658 .20168 m .65758 .20144 L .65819 .20083 L closepath p F P
0 g
s
.849 .97 .653 r
.60754 .26763 m .60512 .27294 L .60916 .26708 L p F P
0 g
s
.849 .97 .653 r
.60906 .2653 m .60754 .26763 L p .60916 .26708 L F P
0 g
s
.849 .97 .653 r
.60916 .26708 m .6103 .26445 L .60906 .2653 L p F P
0 g
s
.483 .674 .949 r
.18072 .38007 m .18369 .38001 L .18702 .38331 L p F P
0 g
s
.488 .676 .948 r
.19025 .37982 m .18369 .38001 L .18702 .38331 L p F P
0 g
s
.488 .676 .948 r
.18702 .38331 m .19351 .38313 L .19025 .37982 L p F P
0 g
s
.87 .961 .626 r
.76767 .26775 m .76592 .2727 L .76933 .26702 L p F P
0 g
s
.87 .961 .626 r
.76945 .26479 m .76767 .26775 L p .76933 .26702 L F P
0 g
s
.87 .961 .626 r
.76933 .26702 m .77033 .26424 L .76945 .26479 L p F P
0 g
s
.792 .827 .354 r
.77774 .2464 m .77748 .24739 L .77856 .24519 L p F P
0 g
s
.792 .827 .354 r
.77856 .24519 m .77961 .24127 L .77774 .2464 L p F P
0 g
s
.885 .69 .635 r
.25883 .3707 m .2628 .37374 L .26453 .36873 L p F P
0 g
s
.885 .69 .635 r
.26453 .36873 m .26052 .3657 L .25883 .3707 L p F P
0 g
s
.632 .692 .888 r
.55894 .39224 m .56939 .38956 L .57209 .3934 L p F P
0 g
s
.628 .627 .831 r
.55732 .38919 m .55894 .39224 L .56939 .38956 L p F P
0 g
s
.911 .977 .783 r
.62939 .23746 m .62913 .2378 L .62922 .23746 L closepath p F P
0 g
s
.912 .978 .776 r
.62602 .23884 m .62453 .24386 L .62913 .2378 L p F P
0 g
s
.912 .978 .776 r
.62693 .23758 m .62602 .23884 L p .62913 .2378 L F P
0 g
s
.912 .978 .776 r
.62913 .2378 m .62922 .23746 L .62693 .23758 L p F P
0 g
s
.827 .874 .879 r
.68074 .17948 m .67816 .18164 L .67571 .17952 L p F P
0 g
s
.857 .887 .858 r
.67254 .18685 m .67816 .18164 L .67571 .17952 L p F P
0 g
s
.846 .974 .874 r
.72402 .32495 m .72306 .32467 L .72515 .32275 L closepath p F P
0 g
s
.849 .896 .87 r
.67254 .18685 m .66785 .19115 L .66548 .1894 L p F P
0 g
s
.867 .894 .851 r
.66785 .19115 m .66508 .19395 L .66548 .1894 L closepath p F P
0 g
s
.857 .887 .858 r
.67571 .17952 m .673 .18213 L .67254 .18685 L p F P
0 g
s
.849 .896 .87 r
.6655 .18924 m .673 .18213 L .67254 .18685 L p F P
0 g
s
.849 .896 .87 r
.66548 .1894 m .6655 .18924 L p .67254 .18685 L F P
0 g
s
0 0 .358 r
.78568 .20809 m .78476 .21286 L .78416 .20865 L p F P
0 g
s
0 0 .358 r
.78416 .20865 m .78507 .20389 L .78568 .20809 L p F P
0 g
s
0 0 0 r
.59069 .29585 m .58714 .30151 L .59059 .29584 L p F P
0 g
s
0 0 0 r
.59124 .29489 m .59069 .29585 L p .59059 .29584 L F P
0 g
s
0 0 0 r
.59059 .29584 m .59241 .2929 L .59124 .29489 L p F P
0 g
s
0 0 .239 r
.78385 .22031 m .78386 .22203 L .7839 .22185 L closepath p F P
0 g
s
.875 .993 .801 r
.74749 .29715 m .74534 .30219 L .7508 .29578 L p F P
0 g
s
.875 .993 .801 r
.75157 .29238 m .74749 .29715 L p .7508 .29578 L F P
0 g
s
.875 .993 .801 r
.7508 .29578 m .75229 .29239 L .75157 .29238 L p F P
0 g
s
.836 .871 .87 r
.68074 .17948 m .68851 .17292 L .68607 .1705 L p F P
0 g
s
.836 .871 .87 r
.68607 .1705 m .68124 .17473 L .68074 .17948 L p F P
0 g
s
.827 .874 .879 r
.67571 .17952 m .68124 .17473 L .68074 .17948 L p F P
0 g
s
.638 .731 .916 r
.22579 .39336 m .23563 .39046 L .23881 .39377 L p F P
0 g
s
.641 .731 .914 r
.23563 .39046 m .22579 .39336 L .22258 .39013 L p F P
0 g
s
.754 .892 .94 r
.64685 .37568 m .64527 .37463 L .64979 .37202 L closepath p F P
0 g
s
.87 .896 .849 r
.65909 .19596 m .65819 .20083 L .66508 .19395 L p F P
0 g
s
.87 .896 .849 r
.6654 .18934 m .65909 .19596 L p .66508 .19395 L F P
0 g
s
.87 .896 .849 r
.66508 .19395 m .66548 .1894 L .6654 .18934 L p F P
0 g
s
.903 .982 .785 r
.62922 .23746 m .62693 .23758 L .63077 .23272 L closepath p F P
0 g
s
.529 .697 .946 r
.19677 .38639 m .20492 .38564 L .20841 .38886 L p F P
0 g
s
.531 .696 .944 r
.20492 .38564 m .19677 .38639 L .19351 .38313 L p F P
0 g
s
.908 .675 .574 r
.25667 .3626 m .26052 .3657 L .2614 .36101 L p F P
0 g
s
.908 .675 .574 r
.2614 .36101 m .25754 .35791 L .25667 .3626 L p F P
0 g
s
.196 .015 .394 r
.56601 .34486 m .55949 .35128 L .56047 .34645 L p F P
0 g
s
.196 .015 .394 r
.56047 .34645 m .56622 .34077 L .56601 .34486 L p F P
0 g
s
.441 .33 .632 r
.55628 .37024 m .55196 .37379 L .55104 .36825 L p F P
0 g
s
.441 .33 .632 r
.55104 .36825 m .55252 .36703 L .55628 .37024 L p F P
0 g
s
.807 .948 .914 r
.69768 .34583 m .69194 .35016 L .68974 .3492 L p F P
0 g
s
.803 .851 .886 r
.69021 .17165 m .68851 .17292 L .68607 .1705 L p F P
0 g
s
.769 .907 .936 r
.66256 .36731 m .65822 .37 L .65574 .36849 L p F P
0 g
s
.869 .923 .86 r
.65512 .20005 m .65909 .19596 L .65819 .20083 L p F P
0 g
s
.869 .923 .86 r
.65819 .20083 m .65758 .20144 L .65512 .20005 L p F P
0 g
s
.895 .93 .833 r
.65213 .20741 m .65758 .20144 L .65512 .20005 L p F P
0 g
s
.761 .749 .841 r
.25695 .38912 m .25195 .39265 L .24879 .38913 L p F P
0 g
s
.699 .735 .879 r
.23881 .39377 m .24879 .38913 L .25195 .39265 L p F P
0 g
s
.926 .658 .511 r
.25384 .35474 m .25754 .35791 L .25785 .35343 L p F P
0 g
s
.926 .658 .511 r
.25785 .35343 m .25415 .35026 L .25384 .35474 L p F P
0 g
s
.812 .85 .878 r
.69021 .17165 m .69891 .16502 L .69647 .16232 L p F P
0 g
s
.812 .85 .878 r
.69647 .16232 m .69069 .1669 L .69021 .17165 L p F P
0 g
s
.803 .851 .886 r
.68607 .1705 m .69069 .1669 L .69021 .17165 L p F P
0 g
s
.745 .881 .942 r
.64276 .37289 m .64527 .37463 L .63481 .38043 L p F P
0 g
s
.745 .881 .942 r
.63373 .37786 m .64276 .37289 L p .63481 .38043 L F P
0 g
s
.745 .881 .942 r
.63481 .38043 m .63277 .379 L .63373 .37786 L p F P
0 g
s
.696 .815 .939 r
.60875 .38687 m .59829 .39143 L .59566 .38885 L p F P
0 g
s
.685 .799 .936 r
.5852 .39296 m .59566 .38885 L .59829 .39143 L p F P
0 g
s
0 0 .118 r
.5743 .3254 m .57078 .32953 L .57329 .32417 L p F P
0 g
s
0 0 .118 r
.57329 .32417 m .57508 .32207 L .5743 .3254 L p F P
0 g
s
.939 .64 .447 r
.2506 .34703 m .25415 .35026 L .25404 .34595 L p F P
0 g
s
.939 .64 .447 r
.25404 .34595 m .2505 .34271 L .2506 .34703 L p F P
0 g
s
.705 .737 .876 r
.24879 .38913 m .23881 .39377 L .23563 .39046 L p F P
0 g
s
.835 .729 .747 r
.25908 .38035 m .2599 .37919 L .26392 .3822 L p F P
0 g
s
.835 .729 .747 r
.26392 .3822 m .26217 .38455 L .25908 .38035 L p F P
0 g
s
.812 .958 .908 r
.70234 .34221 m .69768 .34583 L .70045 .34147 L closepath p F P
0 g
s
.807 .948 .914 r
.69998 .34126 m .70045 .34147 L .69768 .34583 L p F P
0 g
s
.807 .948 .914 r
.68998 .34879 m .69998 .34126 L p .69768 .34583 L F P
0 g
s
.807 .948 .914 r
.68974 .3492 m .68998 .34879 L p .69768 .34583 L F P
0 g
s
.874 .99 .816 r
.74163 .30371 m .74749 .29715 L .74534 .30219 L p F P
0 g
s
.874 .99 .816 r
.74151 .30399 m .74163 .30371 L p .74534 .30219 L F P
0 g
s
.874 .99 .816 r
.74534 .30219 m .74358 .30414 L .74151 .30399 L p F P
0 g
s
.83 .895 .475 r
.77532 .25173 m .77382 .25662 L .77625 .25129 L p F P
0 g
s
.83 .895 .475 r
.77709 .24788 m .77532 .25173 L p .77625 .25129 L F P
0 g
s
.83 .895 .475 r
.77625 .25129 m .77748 .24739 L .77709 .24788 L p F P
0 g
s
.748 .785 .883 r
.71932 .15676 m .72235 .15504 L .71992 .15176 L p F P
0 g
s
.748 .785 .883 r
.71992 .15176 m .71905 .15228 L .71932 .15676 L p F P
0 g
s
.741 .796 .896 r
.70938 .15796 m .71905 .15228 L .71932 .15676 L p F P
0 g
s
.946 .62 .382 r
.2471 .33941 m .2505 .34271 L .25007 .33853 L p F P
0 g
s
.946 .62 .382 r
.25007 .33853 m .24668 .33522 L .2471 .33941 L p F P
0 g
s
.418 .517 .852 r
.77302 .16384 m .76554 .16223 L .76548 .16399 L p F P
0 g
s
.418 .517 .852 r
.77255 .16854 m .77302 .16384 L p .76548 .16399 L F P
0 g
s
.48 .562 .861 r
.76452 .16211 m .76554 .16223 L .76548 .16399 L closepath p F P
0 g
s
.662 .755 .919 r
.57209 .3934 m .58254 .3899 L .5852 .39296 L p F P
0 g
s
.646 .725 .906 r
.58254 .3899 m .57209 .3934 L .56939 .38956 L p F P
0 g
s
.936 .566 .256 r
.24241 .32622 m .24276 .32776 L .24601 .33114 L p F P
0 g
s
.946 .597 .315 r
.24343 .33185 m .24668 .33522 L .24601 .33114 L p F P
0 g
s
.946 .597 .315 r
.24601 .33114 m .24276 .32776 L .24343 .33185 L p F P
0 g
s
.912 .981 .751 r
.62173 .24479 m .61986 .24995 L .62453 .24386 L p F P
0 g
s
.912 .981 .751 r
.62453 .24386 m .62602 .23884 L .62173 .24479 L p F P
0 g
s
.747 .918 .552 r
.60388 .27337 m .60754 .26763 L .60512 .27294 L p F P
0 g
s
.747 .918 .552 r
.60125 .27854 m .60388 .27337 L p .60512 .27294 L F P
0 g
s
.747 .918 .552 r
.60512 .27294 m .60137 .27842 L .60125 .27854 L p F P
0 g
s
0 0 .067 r
.78368 .22528 m .78333 .22665 L .78386 .22203 L p F P
0 g
s
0 0 .067 r
.78386 .22203 m .7839 .22185 L .78368 .22528 L p F P
0 g
s
.865 .992 .823 r
.74358 .30414 m .73922 .30883 L .74151 .30399 L closepath p F P
0 g
s
.895 .93 .833 r
.65512 .20005 m .65288 .2026 L .65213 .20741 L p F P
0 g
s
.886 .943 .844 r
.64716 .20907 m .65288 .2026 L .65213 .20741 L p F P
0 g
s
.886 .943 .844 r
.64646 .21223 m .64716 .20907 L p .65213 .20741 L F P
0 g
s
.886 .943 .844 r
.65213 .20741 m .64734 .21259 L .64646 .21223 L p F P
0 g
s
.592 .585 .814 r
.55621 .38687 m .56118 .38615 L .55732 .38919 L closepath p F P
0 g
s
.628 .627 .831 r
.56667 .38508 m .56118 .38615 L .55732 .38919 L p F P
0 g
s
.628 .627 .831 r
.56939 .38956 m .56667 .38508 L p .55732 .38919 L F P
0 g
s
.675 .779 .929 r
.59566 .38885 m .5852 .39296 L .58254 .3899 L p F P
0 g
s
.653 .699 .88 r
.73542 .15373 m .74618 .15027 L .74863 .15427 L p F P
0 g
s
.664 .71 .882 r
.74618 .15027 m .73542 .15373 L .73299 .15013 L p F P
0 g
s
.703 .744 .883 r
.72235 .15504 m .73299 .15013 L .73542 .15373 L p F P
0 g
s
.773 .921 .936 r
.66867 .36341 m .66256 .36731 L .66648 .36219 L closepath p F P
0 g
s
.769 .907 .936 r
.66622 .36203 m .66648 .36219 L .66256 .36731 L p F P
0 g
s
.769 .907 .936 r
.65574 .36849 m .66622 .36203 L p .66256 .36731 L F P
0 g
s
.794 .736 .799 r
.25695 .38912 m .26217 .38455 L .25908 .38035 L p F P
0 g
s
.794 .736 .799 r
.25908 .38035 m .25284 .38615 L .25695 .38912 L p F P
0 g
s
.761 .749 .841 r
.24879 .38913 m .25284 .38615 L .25695 .38912 L p F P
0 g
s
0 0 .038 r
.78436 .22187 m .78368 .22528 L .7839 .22185 L p F P
0 g
s
0 0 .038 r
.7839 .22185 m .78482 .21727 L .78436 .22187 L p F P
0 g
s
.82 .958 .903 r
.70783 .3378 m .70234 .34221 L .70045 .34147 L p F P
0 g
s
.887 .976 .677 r
.76384 .27359 m .76216 .27851 L .76592 .2727 L p F P
0 g
s
.887 .976 .677 r
.76592 .2727 m .76767 .26775 L .76384 .27359 L p F P
0 g
s
.727 .751 .241 r
.78084 .23645 m .77961 .24127 L .78105 .23631 L p F P
0 g
s
.727 .751 .241 r
.78105 .23631 m .78231 .23146 L .78084 .23645 L p F P
0 g
s
0 0 .495 r
.78596 .19911 m .78507 .20389 L .78383 .19992 L p F P
0 g
s
0 0 .495 r
.78383 .19992 m .7847 .19515 L .78596 .19911 L p F P
0 g
s
.777 .826 .891 r
.70205 .16292 m .69891 .16502 L .69647 .16232 L p F P
0 g
s
.883 .99 .739 r
.61957 .25069 m .61922 .2508 L .61986 .24995 L closepath p F P
0 g
s
.532 .698 .945 r
.20639 .38549 m .20492 .38564 L .20841 .38886 L p F P
0 g
s
.532 .698 .945 r
.20841 .38886 m .20963 .38874 L .20639 .38549 L p F P
0 g
s
.439 .33 .633 r
.55996 .36717 m .55628 .37024 L .55252 .36703 L p F P
0 g
s
.439 .33 .633 r
.55252 .36703 m .55902 .3616 L .55996 .36717 L p F P
0 g
s
.863 .988 .839 r
.74138 .30397 m .74151 .30399 L .73922 .30883 L p F P
0 g
s
.863 .988 .839 r
.73495 .31056 m .74138 .30397 L p .73922 .30883 L F P
0 g
s
.863 .988 .839 r
.73301 .31484 m .73495 .31056 L p .73922 .30883 L F P
0 g
s
.863 .988 .839 r
.73922 .30883 m .73335 .31489 L .73301 .31484 L p F P
0 g
s
0 0 0 r
.58772 .30136 m .58383 .30714 L .58714 .30151 L p F P
0 g
s
0 0 0 r
.58714 .30151 m .59069 .29585 L .58772 .30136 L p F P
0 g
s
.712 .751 .883 r
.73299 .15013 m .72235 .15504 L .71992 .15176 L p F P
0 g
s
.902 .937 .824 r
.64734 .21259 m .64618 .21396 L .64646 .21223 L closepath p F P
0 g
s
.825 .967 .895 r
.71271 .33374 m .70783 .3378 L .71064 .33303 L closepath p F P
0 g
s
.82 .958 .903 r
.71039 .33292 m .71064 .33303 L .70783 .3378 L p F P
0 g
s
.82 .958 .903 r
.70103 .34044 m .71039 .33292 L p .70783 .3378 L F P
0 g
s
.82 .958 .903 r
.70045 .34147 m .70103 .34044 L p .70783 .3378 L F P
0 g
s
.281 .121 .479 r
.55953 .35577 m .55858 .35667 L .55852 .35221 L p F P
0 g
s
.281 .121 .479 r
.55852 .35221 m .55949 .35128 L .55953 .35577 L p F P
0 g
s
.905 .94 .82 r
.64183 .2154 m .64082 .22029 L .64618 .21396 L p F P
0 g
s
.905 .94 .82 r
.64488 .21164 m .64183 .2154 L p .64618 .21396 L F P
0 g
s
.905 .94 .82 r
.64618 .21396 m .64646 .21223 L .64488 .21164 L p F P
0 g
s
.833 .966 .89 r
.71692 .33013 m .71271 .33374 L .71064 .33303 L p F P
0 g
s
.589 .543 .771 r
.55365 .38027 m .55621 .38687 L .56118 .38615 L p F P
0 g
s
.495 .576 .866 r
.76554 .16223 m .76452 .16211 L .76204 .15736 L p F P
0 g
s
.777 .826 .891 r
.69647 .16232 m .70232 .15824 L .70205 .16292 L p F P
0 g
s
.785 .823 .882 r
.70205 .16292 m .70938 .15796 L .70694 .15498 L p F P
0 g
s
.785 .823 .882 r
.70694 .15498 m .70232 .15824 L .70205 .16292 L p F P
0 g
s
.854 .989 .846 r
.73335 .31489 m .7326 .31565 L .73301 .31484 L closepath p F P
0 g
s
.849 .979 .867 r
.7277 .3176 m .72515 .32275 L .7326 .31565 L p F P
0 g
s
.849 .979 .867 r
.7311 .31436 m .7277 .3176 L p .7326 .31565 L F P
0 g
s
.849 .979 .867 r
.7326 .31565 m .73301 .31484 L .7311 .31436 L p F P
0 g
s
.531 .439 .696 r
.56115 .37186 m .55628 .37024 L .55196 .37379 L p F P
0 g
s
.531 .439 .696 r
.56173 .37376 m .56115 .37186 L p .55196 .37379 L F P
0 g
s
.531 .439 .696 r
.55434 .37971 m .56173 .37376 L p .55196 .37379 L F P
0 g
s
.531 .439 .696 r
.55196 .37379 m .55344 .37959 L .55434 .37971 L p F P
0 g
s
.604 .671 .887 r
.75228 .15368 m .74863 .15427 L .74618 .15027 L p F P
0 g
s
.839 .974 .88 r
.71692 .33013 m .72306 .32467 L .72077 .32399 L p F P
0 g
s
.839 .974 .88 r
.72077 .32399 m .71976 .32489 L .71692 .33013 L p F P
0 g
s
.833 .966 .89 r
.71092 .33249 m .71976 .32489 L .71692 .33013 L p F P
0 g
s
.833 .966 .89 r
.71064 .33303 m .71092 .33249 L p .71692 .33013 L F P
0 g
s
.892 .985 .721 r
.76191 .27918 m .76163 .27925 L .76216 .27851 L closepath p F P
0 g
s
.864 .713 .692 r
.25603 .37612 m .2599 .37919 L .2628 .37374 L p F P
0 g
s
.864 .713 .692 r
.2628 .37374 m .25883 .3707 L .25603 .37612 L p F P
0 g
s
.846 .973 .875 r
.72077 .32399 m .7277 .3176 L .72515 .32275 L p F P
0 g
s
.846 .973 .875 r
.72515 .32275 m .72306 .32467 L .72077 .32399 L p F P
0 g
s
.587 .718 .934 r
.20963 .38874 m .21936 .38688 L .22258 .39013 L p F P
0 g
s
.589 .717 .932 r
.21936 .38688 m .20963 .38874 L .20639 .38549 L p F P
0 g
s
.881 .99 .736 r
.61739 .25077 m .62173 .24479 L .61986 .24995 L p F P
0 g
s
.881 .99 .736 r
.61711 .25152 m .61739 .25077 L p .61986 .24995 L F P
0 g
s
.881 .99 .736 r
.61986 .24995 m .61922 .2508 L .61711 .25152 L p F P
0 g
s
.842 .97 .654 r
.6103 .26445 m .60906 .2653 L .6115 .26178 L closepath p F P
0 g
s
.781 .921 .931 r
.67731 .3577 m .66867 .36341 L .66648 .36219 L p F P
0 g
s
.775 .925 .556 r
.60137 .27842 m .60112 .2788 L .60125 .27854 L closepath p F P
0 g
s
.9 .984 .725 r
.61922 .2508 m .61565 .25587 L .61711 .25152 L closepath p F P
0 g
s
.726 .859 .944 r
.63228 .37864 m .6218 .38396 L .61923 .3819 L p F P
0 g
s
.756 .906 .521 r
.59955 .28051 m .59754 .28451 L .60112 .2788 L p F P
0 g
s
.756 .906 .521 r
.60112 .2788 m .60125 .27854 L .59955 .28051 L p F P
0 g
s
.887 .958 .619 r
.77033 .26424 m .76945 .26479 L .77101 .26209 L closepath p F P
0 g
s
.061 .126 .619 r
.78519 .1923 m .7847 .19515 L .78271 .19147 L p F P
0 g
s
.061 .126 .619 r
.78395 .18741 m .78519 .1923 L p .78271 .19147 L F P
0 g
s
.061 .126 .619 r
.78271 .19147 m .78354 .18669 L .78395 .18741 L p F P
0 g
s
.083 0 .301 r
.56713 .33978 m .56622 .34077 L .56665 .33696 L p F P
0 g
s
.083 0 .301 r
.56665 .33696 m .56869 .33474 L .56713 .33978 L p F P
0 g
s
.453 .539 .855 r
.77349 .15948 m .77302 .16384 L .76554 .16223 L p F P
0 g
s
.453 .539 .855 r
.77329 .15905 m .77349 .15948 L p .76554 .16223 L F P
0 g
s
.453 .539 .855 r
.76554 .16223 m .76565 .15764 L .77329 .15905 L p F P
0 g
s
.495 .576 .866 r
.76204 .15736 m .76565 .15764 L .76554 .16223 L p F P
0 g
s
0 0 .189 r
.57366 .32891 m .56869 .33474 L .57078 .32953 L p F P
0 g
s
0 0 .189 r
.57078 .32953 m .5743 .3254 L .57366 .32891 L p F P
0 g
s
.753 .905 .52 r
.60027 .27911 m .59955 .28051 L .60125 .27854 L p F P
0 g
s
.753 .905 .52 r
.60125 .27854 m .60388 .27337 L .60027 .27911 L p F P
0 g
s
.264 .108 .474 r
.56608 .34932 m .55953 .35577 L .55949 .35128 L p F P
0 g
s
.264 .108 .474 r
.55949 .35128 m .56601 .34486 L .56608 .34932 L p F P
0 g
s
.893 .985 .722 r
.75966 .27956 m .76384 .27359 L .76216 .27851 L p F P
0 g
s
.893 .985 .722 r
.7596 .27974 m .75966 .27956 L p .76216 .27851 L F P
0 g
s
.893 .985 .722 r
.76216 .27851 m .76163 .27925 L .7596 .27974 L p F P
0 g
s
.899 .966 .821 r
.63673 .22165 m .64183 .2154 L .64082 .22029 L p F P
0 g
s
.899 .966 .821 r
.63602 .2244 m .63673 .22165 L p .64082 .22029 L F P
0 g
s
.899 .966 .821 r
.64082 .22029 m .63713 .22461 L .63602 .2244 L p F P
0 g
s
.861 .977 .857 r
.73301 .31484 m .7311 .31436 L .73495 .31056 L closepath p F P
0 g
s
.868 .934 .556 r
.77245 .25722 m .77101 .26209 L .77382 .25662 L p F P
0 g
s
.868 .934 .556 r
.77382 .25662 m .77532 .25173 L .77245 .25722 L p F P
0 g
s
0 0 .1 r
.57593 .32335 m .5743 .3254 L .57508 .32207 L p F P
0 g
s
0 0 .1 r
.57508 .32207 m .57827 .31804 L .57593 .32335 L p F P
0 g
s
.524 .464 .731 r
.55344 .37959 m .55434 .37971 L .55365 .38027 L closepath p F P
0 g
s
.589 .543 .771 r
.56393 .37949 m .55434 .37971 L .55365 .38027 L p F P
0 g
s
.589 .543 .771 r
.56548 .38281 m .56393 .37949 L p .55365 .38027 L F P
0 g
s
.589 .543 .771 r
.56118 .38615 m .56548 .38281 L p .55365 .38027 L F P
0 g
s
.893 .699 .633 r
.25502 .36759 m .25883 .3707 L .26052 .3657 L p F P
0 g
s
.893 .699 .633 r
.26052 .3657 m .25667 .3626 L .25502 .36759 L p F P
0 g
s
0 0 .198 r
.78573 .21251 m .78482 .21727 L .78476 .21286 L p F P
0 g
s
0 0 .198 r
.78476 .21286 m .78568 .20809 L .78573 .21251 L p F P
0 g
s
.884 .988 .729 r
.76163 .27925 m .75773 .28455 L .7596 .27974 L closepath p F P
0 g
s
.755 .886 .938 r
.64979 .37202 m .64527 .37463 L .64276 .37289 L p F P
0 g
s
0 0 0 r
.58366 .30738 m .58356 .30763 L .58383 .30714 L closepath p F P
0 g
s
.75 .8 .893 r
.71905 .15228 m .70938 .15796 L .70694 .15498 L p F P
0 g
s
0 0 0 r
.58494 .30682 m .58772 .30136 L .58383 .30714 L p F P
0 g
s
0 0 0 r
.58259 .31028 m .58494 .30682 L p .58383 .30714 L F P
0 g
s
0 0 0 r
.58383 .30714 m .58356 .30763 L .58259 .31028 L p F P
0 g
s
.168 .239 .694 r
.78362 .18617 m .78354 .18669 L .78065 .18335 L p F P
0 g
s
.168 .239 .694 r
.78065 .18335 m .78134 .17896 L .78362 .18617 L p F P
0 g
s
.714 .834 .939 r
.60904 .38712 m .60875 .38687 L .60972 .38642 L closepath p F P
0 g
s
.915 .958 .802 r
.63713 .22461 m .63558 .22658 L .63602 .2244 L closepath p F P
0 g
s
0 0 0 r
.58356 .30763 m .58092 .31264 L .58259 .31028 L closepath p F P
0 g
s
.916 .683 .571 r
.25298 .35943 m .25667 .3626 L .25754 .35791 L p F P
0 g
s
.916 .683 .571 r
.25754 .35791 m .25384 .35474 L .25298 .35943 L p F P
0 g
s
.887 .99 .791 r
.75229 .29239 m .75157 .29238 L .75293 .29074 L closepath p F P
0 g
s
.557 .523 .773 r
.55434 .37971 m .56173 .37376 L .56393 .37949 L closepath p F P
0 g
s
.894 .945 .835 r
.64646 .21223 m .64488 .21164 L .64716 .20907 L closepath p F P
0 g
s
.389 .468 .82 r
.77812 .17031 m .77804 .17091 L .77255 .16854 L p F P
0 g
s
.389 .468 .82 r
.77585 .16489 m .77812 .17031 L p .77255 .16854 L F P
0 g
s
.389 .468 .82 r
.77255 .16854 m .77302 .16384 L .77585 .16489 L p F P
0 g
s
.899 .982 .711 r
.6135 .25659 m .6115 .26178 L .61565 .25587 L p F P
0 g
s
.899 .982 .711 r
.61676 .25167 m .6135 .25659 L p .61565 .25587 L F P
0 g
s
.899 .982 .711 r
.61565 .25587 m .61711 .25152 L .61676 .25167 L p F P
0 g
s
.641 .731 .914 r
.22258 .39013 m .23243 .38713 L .23563 .39046 L p F P
0 g
s
.644 .732 .913 r
.23243 .38713 m .22258 .39013 L .21936 .38688 L p F P
0 g
s
.81 .84 .375 r
.77894 .24159 m .77774 .2464 L .77961 .24127 L p F P
0 g
s
.81 .84 .375 r
.77961 .24127 m .78084 .23645 L .77894 .24159 L p F P
0 g
s
.786 .932 .928 r
.67912 .35647 m .67731 .3577 L .67843 .35612 L closepath p F P
0 g
s
.781 .921 .931 r
.67669 .35511 m .67843 .35612 L .67731 .3577 L p F P
0 g
s
.781 .921 .931 r
.66689 .3616 m .67669 .35511 L p .67731 .3577 L F P
0 g
s
.781 .921 .931 r
.66648 .36219 m .66689 .3616 L p .67731 .3577 L F P
0 g
s
0 0 0 r
.78312 .22823 m .78231 .23146 L .78333 .22665 L p F P
0 g
s
0 0 0 r
.78333 .22665 m .78368 .22528 L .78312 .22823 L p F P
0 g
s
.281 .354 .761 r
.77845 .17116 m .77804 .17091 L .77739 .17566 L p F P
0 g
s
.281 .354 .761 r
.77739 .17566 m .78112 .17835 L .77845 .17116 L p F P
0 g
s
.917 .96 .796 r
.63197 .22777 m .63077 .23272 L .63558 .22658 L p F P
0 g
s
.917 .96 .796 r
.63466 .22418 m .63197 .22777 L p .63558 .22658 L F P
0 g
s
.917 .96 .796 r
.63558 .22658 m .63602 .2244 L .63466 .22418 L p F P
0 g
s
.531 .696 .944 r
.19351 .38313 m .20152 .38237 L .20492 .38564 L p F P
0 g
s
.532 .694 .943 r
.20152 .38237 m .19351 .38313 L .19025 .37982 L p F P
0 g
s
.714 .82 .931 r
.60972 .38642 m .60875 .38687 L .60615 .38444 L p F P
0 g
s
.696 .815 .939 r
.59566 .38885 m .60615 .38444 L .60875 .38687 L p F P
0 g
s
.934 .667 .506 r
.25029 .3515 m .25384 .35474 L .25415 .35026 L p F P
0 g
s
.934 .667 .506 r
.25415 .35026 m .2506 .34703 L .25029 .3515 L p F P
0 g
s
.604 .671 .887 r
.74618 .15027 m .75237 .14907 L .75228 .15368 L p F P
0 g
s
.579 .64 .875 r
.7571 .14831 m .75237 .14907 L .75228 .15368 L p F P
0 g
s
.579 .64 .875 r
.75228 .15368 m .75957 .15277 L .7571 .14831 L p F P
0 g
s
.768 .75 .837 r
.25284 .38615 m .24879 .38913 L .24563 .38561 L p F P
0 g
s
.705 .737 .876 r
.23563 .39046 m .24563 .38561 L .24879 .38913 L p F P
0 g
s
.759 .901 .94 r
.65574 .36849 m .64979 .37202 L .65368 .36718 L closepath p F P
0 g
s
.755 .886 .938 r
.65326 .36689 m .65368 .36718 L .64979 .37202 L p F P
0 g
s
.755 .886 .938 r
.64276 .37289 m .65326 .36689 L p .64979 .37202 L F P
0 g
s
.797 .933 .921 r
.68716 .34782 m .68956 .3491 L .67912 .35647 L p F P
0 g
s
.797 .933 .921 r
.6809 .35223 m .68716 .34782 L p .67912 .35647 L F P
0 g
s
.797 .933 .921 r
.67912 .35647 m .67843 .35612 L .6809 .35223 L p F P
0 g
s
.888 .99 .774 r
.75478 .28578 m .75293 .29074 L .75773 .28455 L p F P
0 g
s
.888 .99 .774 r
.75952 .27974 m .75478 .28578 L p .75773 .28455 L F P
0 g
s
.888 .99 .774 r
.75773 .28455 m .7596 .27974 L .75952 .27974 L p F P
0 g
s
.843 .731 .741 r
.25597 .37621 m .25603 .37612 L .2599 .37919 L p F P
0 g
s
.843 .731 .741 r
.2599 .37919 m .25908 .38035 L .25597 .37621 L p F P
0 g
s
.738 .887 .488 r
.59695 .28474 m .59404 .29021 L .59754 .28451 L p F P
0 g
s
.738 .887 .488 r
.59892 .28132 m .59695 .28474 L p .59754 .28451 L F P
0 g
s
.738 .887 .488 r
.59754 .28451 m .59955 .28051 L .59892 .28132 L p F P
0 g
s
.71 .825 .936 r
.60972 .38642 m .61923 .3819 L .61665 .37971 L p F P
0 g
s
.71 .825 .936 r
.61665 .37971 m .61574 .38013 L .60972 .38642 L p F P
0 g
s
.714 .82 .931 r
.60615 .38444 m .61574 .38013 L .60972 .38642 L p F P
0 g
s
.946 .648 .44 r
.2472 .34372 m .2506 .34703 L .2505 .34271 L p F P
0 g
s
.946 .648 .44 r
.2505 .34271 m .2471 .33941 L .2472 .34372 L p F P
0 g
s
.646 .725 .906 r
.56939 .38956 m .57986 .38648 L .58254 .3899 L p F P
0 g
s
.624 .688 .89 r
.57986 .38648 m .56939 .38956 L .56667 .38508 L p F P
0 g
s
.74 .871 .941 r
.63277 .379 m .63228 .37864 L .63373 .37786 L closepath p F P
0 g
s
.71 .74 .874 r
.24563 .38561 m .23563 .39046 L .23243 .38713 L p F P
0 g
s
.802 .74 .795 r
.25284 .38615 m .25908 .38035 L .25597 .37621 L p F P
0 g
s
.952 .626 .371 r
.24384 .33603 m .2471 .33941 L .24668 .33522 L p F P
0 g
s
.952 .626 .371 r
.24668 .33522 m .24343 .33185 L .24384 .33603 L p F P
0 g
s
.802 .74 .795 r
.25597 .37621 m .24891 .3831 L .25284 .38615 L p F P
0 g
s
.768 .75 .837 r
.24563 .38561 m .24891 .3831 L .25284 .38615 L p F P
0 g
s
.608 .615 .833 r
.56118 .38615 m .56548 .38281 L .56667 .38508 L closepath p F P
0 g
s
.834 .873 .873 r
.68124 .17473 m .67571 .17952 L .67326 .17738 L p F P
0 g
s
.861 .879 .85 r
.673 .18213 m .67571 .17952 L .67326 .17738 L p F P
0 g
s
.861 .879 .85 r
.67326 .17738 m .67313 .17751 L .673 .18213 L p F P
0 g
s
.86 .878 .85 r
.66616 .18443 m .6655 .18924 L .673 .18213 L p F P
0 g
s
.86 .878 .85 r
.673 .18213 m .67313 .17751 L .66616 .18443 L p F P
0 g
s
.856 .899 .865 r
.66548 .1894 m .6654 .18934 L .6655 .18924 L closepath p F P
0 g
s
0 0 .356 r
.78657 .20332 m .78568 .20809 L .78507 .20389 L p F P
0 g
s
0 0 .356 r
.78507 .20389 m .78596 .19911 L .78657 .20332 L p F P
0 g
s
.84 .864 .861 r
.68124 .17473 m .68607 .1705 L .68362 .16807 L p F P
0 g
s
.84 .864 .861 r
.68362 .16807 m .68139 .1701 L .68124 .17473 L p F P
0 g
s
.834 .873 .873 r
.67326 .17738 m .68139 .1701 L .68124 .17473 L p F P
0 g
s
.688 .8 .934 r
.60615 .38444 m .59566 .38885 L .59302 .38605 L p F P
0 g
s
.675 .779 .929 r
.58254 .3899 m .59302 .38605 L .59566 .38885 L p F P
0 g
s
.889 .959 .621 r
.76922 .26285 m .77245 .25722 L .77101 .26209 L p F P
0 g
s
.889 .959 .621 r
.76848 .26538 m .76922 .26285 L p .77101 .26209 L F P
0 g
s
.889 .959 .621 r
.77101 .26209 m .76945 .26479 L .76848 .26538 L p F P
0 g
s
.856 .9 .865 r
.66294 .18759 m .66616 .18443 L .6655 .18924 L p F P
0 g
s
.856 .9 .865 r
.6655 .18924 m .6654 .18934 L .66294 .18759 L p F P
0 g
s
.884 .911 .841 r
.65909 .19596 m .6654 .18934 L .66294 .18759 L p F P
0 g
s
.51 .589 .869 r
.76565 .15764 m .76204 .15736 L .75957 .15277 L p F P
0 g
s
.81 .851 .881 r
.69069 .1669 m .68607 .1705 L .68362 .16807 L p F P
0 g
s
.664 .71 .882 r
.73299 .15013 m .74374 .14634 L .74618 .15027 L p F P
0 g
s
.674 .719 .883 r
.74374 .14634 m .73299 .15013 L .73055 .14657 L p F P
0 g
s
.712 .751 .883 r
.71992 .15176 m .73055 .14657 L .73299 .15013 L p F P
0 g
s
.345 .214 .555 r
.56093 .3598 m .55902 .3616 L .55858 .35667 L p F P
0 g
s
.345 .214 .555 r
.55858 .35667 m .55953 .35577 L .56093 .3598 L p F P
0 g
s
.853 .896 .475 r
.77748 .24739 m .77709 .24788 L .77774 .2464 L closepath p F P
0 g
s
.037 0 .279 r
.57258 .33351 m .56713 .33978 L .56869 .33474 L p F P
0 g
s
.037 0 .279 r
.57352 .33013 m .57258 .33351 L p .56869 .33474 L F P
0 g
s
.037 0 .279 r
.56869 .33474 m .57366 .32891 L .57352 .33013 L p F P
0 g
s
.661 .755 .92 r
.59302 .38605 m .58254 .3899 L .57986 .38648 L p F P
0 g
s
.903 .982 .785 r
.62745 .23382 m .63197 .22777 L .63077 .23272 L p F P
0 g
s
.903 .982 .785 r
.62632 .23762 m .62745 .23382 L p .63077 .23272 L F P
0 g
s
.903 .982 .785 r
.63077 .23272 m .62693 .23758 L .62632 .23762 L p F P
0 g
s
.534 .696 .944 r
.20314 .38221 m .20152 .38237 L .20492 .38564 L p F P
0 g
s
.534 .696 .944 r
.20492 .38564 m .20639 .38549 L .20314 .38221 L p F P
0 g
s
.803 .936 .918 r
.68974 .3492 m .68956 .3491 L .68998 .34879 L closepath p F P
0 g
s
.836 .968 .647 r
.6097 .26239 m .6135 .25659 L .6115 .26178 L p F P
0 g
s
.836 .968 .647 r
.60823 .26588 m .6097 .26239 L p .6115 .26178 L F P
0 g
s
.836 .968 .647 r
.6115 .26178 m .60906 .2653 L .60823 .26588 L p F P
0 g
s
0 0 0 r
.78344 .22665 m .78312 .22823 L .78368 .22528 L p F P
0 g
s
0 0 0 r
.78368 .22528 m .78436 .22187 L .78344 .22665 L p F P
0 g
s
0 0 0 r
.58162 .31333 m .57827 .31804 L .58092 .31264 L p F P
0 g
s
0 0 0 r
.58092 .31264 m .58259 .31028 L .58162 .31333 L p F P
0 g
s
.741 .861 .937 r
.63373 .37786 m .63228 .37864 L .62973 .37664 L p F P
0 g
s
.726 .859 .944 r
.61923 .3819 m .62973 .37664 L .63228 .37864 L p F P
0 g
s
.769 .903 .934 r
.66375 .36044 m .66622 .36203 L .65574 .36849 L p F P
0 g
s
.769 .903 .934 r
.65437 .36622 m .66375 .36044 L p .65574 .36849 L F P
0 g
s
.769 .903 .934 r
.65574 .36849 m .65368 .36718 L .65437 .36622 L p F P
0 g
s
.888 .989 .792 r
.74959 .29211 m .75478 .28578 L .75293 .29074 L p F P
0 g
s
.888 .989 .792 r
.7495 .29235 m .74959 .29211 L p .75293 .29074 L F P
0 g
s
.888 .989 .792 r
.75293 .29074 m .75157 .29238 L .7495 .29235 L p F P
0 g
s
.817 .845 .87 r
.69069 .1669 m .69647 .16232 L .69403 .15961 L p F P
0 g
s
.817 .845 .87 r
.69403 .15961 m .69079 .16226 L .69069 .1669 L p F P
0 g
s
.81 .851 .881 r
.68362 .16807 m .69079 .16226 L .69069 .1669 L p F P
0 g
s
.747 .782 .881 r
.71992 .15176 m .71905 .15228 L .71885 .15033 L closepath p F P
0 g
s
.75 .8 .893 r
.71748 .14852 m .71885 .15033 L .71905 .15228 L p F P
0 g
s
.75 .8 .893 r
.70694 .15498 m .71748 .14852 L p .71905 .15228 L F P
0 g
s
.884 .911 .841 r
.66294 .18759 m .6596 .19121 L .65909 .19596 L p F P
0 g
s
.876 .92 .852 r
.6534 .19786 m .6596 .19121 L .65909 .19596 L p F P
0 g
s
.876 .92 .852 r
.65322 .19896 m .6534 .19786 L p .65909 .19596 L F P
0 g
s
.876 .92 .852 r
.65909 .19596 m .65512 .20005 L .65322 .19896 L p F P
0 g
s
.873 .719 .689 r
.25566 .37581 m .25603 .37612 L .25883 .3707 L p F P
0 g
s
.873 .719 .689 r
.25286 .37192 m .25566 .37581 L p .25883 .3707 L F P
0 g
s
.873 .719 .689 r
.25883 .3707 m .25502 .36759 L .25286 .37192 L p F P
0 g
s
.804 .931 .917 r
.68998 .34879 m .68956 .3491 L .68716 .34782 L p F P
0 g
s
.79 .92 .925 r
.67843 .35612 m .67669 .35511 L .6809 .35223 L closepath p F P
0 g
s
.615 .678 .886 r
.75237 .14907 m .74618 .15027 L .74374 .14634 L p F P
0 g
s
.809 .94 .914 r
.68998 .34879 m .69998 .34126 L .69761 .34009 L p F P
0 g
s
.809 .94 .914 r
.69761 .34009 m .69312 .34347 L .68998 .34879 L p F P
0 g
s
.804 .931 .917 r
.68716 .34782 m .69312 .34347 L .68998 .34879 L p F P
0 g
s
.721 .774 .895 r
.72811 .14306 m .73055 .14657 L .71992 .15176 L p F P
0 g
s
.721 .774 .895 r
.71933 .14758 m .72811 .14306 L p .71992 .15176 L F P
0 g
s
.721 .774 .895 r
.71992 .15176 m .71885 .15033 L .71933 .14758 L p F P
0 g
s
.879 .991 .798 r
.75157 .29238 m .74749 .29715 L .7495 .29235 L closepath p F P
0 g
s
.816 .945 .908 r
.70045 .34147 m .69998 .34126 L .70103 .34044 L closepath p F P
0 g
s
.878 .961 .626 r
.76945 .26479 m .76767 .26775 L .76848 .26538 L closepath p F P
0 g
s
.741 .861 .937 r
.62973 .37664 m .63863 .37195 L .63373 .37786 L p F P
0 g
s
.74 .87 .94 r
.63373 .37786 m .64276 .37289 L .64024 .37109 L p F P
0 g
s
.74 .87 .94 r
.64024 .37109 m .63863 .37195 L .63373 .37786 L p F P
0 g
s
.893 .915 .832 r
.65512 .20005 m .65288 .2026 L .65322 .19896 L closepath p F P
0 g
s
.784 .828 .886 r
.70232 .15824 m .69647 .16232 L .69403 .15961 L p F P
0 g
s
0 0 0 r
.59388 .29029 m .59695 .28474 L .59404 .29021 L p F P
0 g
s
0 0 0 r
.59404 .29021 m .59124 .29489 L .591 .29531 L p F P
0 g
s
0 0 0 r
.591 .29531 m .59388 .29029 L p .59404 .29021 L F P
0 g
s
.334 .208 .556 r
.56654 .35428 m .56093 .3598 L .55953 .35577 L p F P
0 g
s
.334 .208 .556 r
.55953 .35577 m .56608 .34932 L .56654 .35428 L p F P
0 g
s
0 0 .025 r
.78526 .21712 m .78436 .22187 L .78482 .21727 L p F P
0 g
s
0 0 .025 r
.78482 .21727 m .78573 .21251 L .78526 .21712 L p F P
0 g
s
.589 .717 .932 r
.20639 .38549 m .21613 .38359 L .21936 .38688 L p F P
0 g
s
.59 .717 .931 r
.21613 .38359 m .20639 .38549 L .20314 .38221 L p F P
0 g
s
.919 .974 .768 r
.62693 .23758 m .62602 .23884 L .62632 .23762 L closepath p F P
0 g
s
.856 .897 .478 r
.77664 .24688 m .77894 .24159 L .77774 .2464 L p F P
0 g
s
.856 .897 .478 r
.77608 .24915 m .77664 .24688 L p .77774 .2464 L F P
0 g
s
.856 .897 .478 r
.77774 .2464 m .77709 .24788 L .77608 .24915 L p F P
0 g
s
.86 .967 .644 r
.60906 .2653 m .60754 .26763 L .60823 .26588 L closepath p F P
0 g
s
.49 .412 .695 r
.55628 .37024 m .55996 .36717 L .56115 .37186 L closepath p F P
0 g
s
.896 .917 .828 r
.64794 .20424 m .64716 .20907 L .65288 .2026 L p F P
0 g
s
.896 .917 .828 r
.65266 .19865 m .64794 .20424 L p .65288 .2026 L F P
0 g
s
.896 .917 .828 r
.65288 .2026 m .65322 .19896 L .65266 .19865 L p F P
0 g
s
.907 .965 .809 r
.63602 .2244 m .63466 .22418 L .63673 .22165 L closepath p F P
0 g
s
0 0 .493 r
.78622 .1976 m .78596 .19911 L .7847 .19515 L p F P
0 g
s
0 0 .493 r
.7847 .19515 m .78519 .1923 L .78622 .1976 L p F P
0 g
s
.876 .985 .828 r
.74363 .29871 m .74163 .30371 L .74749 .29715 L p F P
0 g
s
.876 .985 .828 r
.7494 .29233 m .74363 .29871 L p .74749 .29715 L F P
0 g
s
.876 .985 .828 r
.74749 .29715 m .7495 .29235 L .7494 .29233 L p F P
0 g
s
.921 .975 .759 r
.62307 .23981 m .62173 .24479 L .62602 .23884 L p F P
0 g
s
.921 .975 .759 r
.62446 .23779 m .62307 .23981 L p .62602 .23884 L F P
0 g
s
.921 .975 .759 r
.62602 .23884 m .62632 .23762 L .62446 .23779 L p F P
0 g
s
.747 .768 .264 r
.78203 .23162 m .78084 .23645 L .78231 .23146 L p F P
0 g
s
.747 .768 .264 r
.78256 .22981 m .78203 .23162 L p .78231 .23146 L F P
0 g
s
.747 .768 .264 r
.78231 .23146 m .78312 .22823 L .78256 .22981 L p F P
0 g
s
.151 0 .38 r
.56626 .34459 m .56601 .34486 L .56622 .34077 L p F P
0 g
s
.151 0 .38 r
.56622 .34077 m .56713 .33978 L .56626 .34459 L p F P
0 g
s
.901 .707 .631 r
.25135 .36441 m .25502 .36759 L .25667 .3626 L p F P
0 g
s
.901 .707 .631 r
.25667 .3626 m .25298 .35943 L .25135 .36441 L p F P
0 g
s
.895 .98 .695 r
.76547 .26867 m .76384 .27359 L .76767 .26775 L p F P
0 g
s
.895 .98 .695 r
.7674 .26573 m .76547 .26867 L p .76767 .26775 L F P
0 g
s
.895 .98 .695 r
.76767 .26775 m .76848 .26538 L .7674 .26573 L p F P
0 g
s
.841 .897 .479 r
.77709 .24788 m .77532 .25173 L .77608 .24915 L closepath p F P
0 g
s
.817 .941 .908 r
.70103 .34044 m .69998 .34126 L .69761 .34009 L p F P
0 g
s
.853 .96 .624 r
.60599 .26816 m .60388 .27337 L .60754 .26763 L p F P
0 g
s
.853 .96 .624 r
.60659 .26717 m .60599 .26816 L p .60754 .26763 L F P
0 g
s
.853 .96 .624 r
.60754 .26763 m .60823 .26588 L .60659 .26717 L p F P
0 g
s
.791 .82 .875 r
.70232 .15824 m .70694 .15498 L .7045 .15201 L p F P
0 g
s
.791 .82 .875 r
.7045 .15201 m .70222 .15368 L .70232 .15824 L p F P
0 g
s
.784 .828 .886 r
.69403 .15961 m .70222 .15368 L .70232 .15824 L p F P
0 g
s
.817 .941 .908 r
.69761 .34009 m .70391 .33519 L .70103 .34044 L p F P
0 g
s
.822 .95 .903 r
.70103 .34044 m .71039 .33292 L .70805 .33187 L p F P
0 g
s
.822 .95 .903 r
.70805 .33187 m .70391 .33519 L .70103 .34044 L p F P
0 g
s
.872 .982 .839 r
.74151 .30399 m .74138 .30397 L .74163 .30371 L closepath p F P
0 g
s
.777 .91 .931 r
.66648 .36219 m .66622 .36203 L .66689 .3616 L closepath p F P
0 g
s
.829 .954 .897 r
.71064 .33303 m .71039 .33292 L .71092 .33249 L closepath p F P
0 g
s
.894 .943 .835 r
.64244 .21064 m .64794 .20424 L .64716 .20907 L p F P
0 g
s
.894 .943 .835 r
.64243 .21068 m .64244 .21064 L p .64716 .20907 L F P
0 g
s
.894 .943 .835 r
.64716 .20907 m .64488 .21164 L .64243 .21068 L p F P
0 g
s
.723 .85 .942 r
.62973 .37664 m .61923 .3819 L .61665 .37971 L p F P
0 g
s
.924 .692 .568 r
.24943 .3562 m .25298 .35943 L .25384 .35474 L p F P
0 g
s
.924 .692 .568 r
.25384 .35474 m .25029 .3515 L .24943 .3562 L p F P
0 g
s
.874 .98 .84 r
.73915 .30348 m .74363 .29871 L .74163 .30371 L p F P
0 g
s
.874 .98 .84 r
.74163 .30371 m .74138 .30397 L .73915 .30348 L p F P
0 g
s
.867 .983 .844 r
.73495 .31056 m .74138 .30397 L .73915 .30348 L p F P
0 g
s
.624 .688 .89 r
.56667 .38508 m .57717 .38259 L .57986 .38648 L p F P
0 g
s
.621 .621 .83 r
.56548 .38281 m .56667 .38508 L .57717 .38259 L p F P
0 g
s
0 0 .172 r
.57397 .32853 m .57366 .32891 L .5743 .3254 L p F P
0 g
s
0 0 .172 r
.5743 .3254 m .57593 .32335 L .57397 .32853 L p F P
0 g
s
.91 .936 .814 r
.64488 .21164 m .64183 .2154 L .64243 .21068 L closepath p F P
0 g
s
0 0 .034 r
.5802 .31745 m .57593 .32335 L .57827 .31804 L p F P
0 g
s
0 0 .034 r
.58115 .31512 m .5802 .31745 L p .57827 .31804 L F P
0 g
s
0 0 .034 r
.57827 .31804 m .58162 .31333 L .58115 .31512 L p F P
0 g
s
.51 .589 .869 r
.75957 .15277 m .76581 .15303 L .76565 .15764 L p F P
0 g
s
.46 .531 .843 r
.77076 .1537 m .76581 .15303 L .76565 .15764 L p F P
0 g
s
.46 .531 .843 r
.76565 .15764 m .77329 .15905 L .77076 .1537 L p F P
0 g
s
0 0 0 r
.59124 .29489 m .59069 .29585 L .591 .29531 L closepath p F P
0 g
s
.723 .776 .895 r
.71885 .15033 m .71748 .14852 L .71933 .14758 L closepath p F P
0 g
s
.759 .789 .877 r
.71748 .14852 m .70694 .15498 L .7045 .15201 L p F P
0 g
s
.777 .903 .929 r
.66689 .3616 m .66622 .36203 L .66375 .36044 L p F P
0 g
s
.83 .95 .897 r
.71092 .33249 m .71039 .33292 L .70805 .33187 L p F P
0 g
s
.644 .732 .913 r
.21936 .38688 m .22922 .38379 L .23243 .38713 L p F P
0 g
s
.647 .733 .912 r
.22922 .38379 m .21936 .38688 L .21613 .38359 L p F P
0 g
s
.051 .122 .618 r
.78354 .18669 m .78362 .18617 L .78395 .18741 L closepath p F P
0 g
s
.132 0 .379 r
.57185 .33828 m .56626 .34459 L .56713 .33978 L p F P
0 g
s
.132 0 .379 r
.56713 .33978 m .57258 .33351 L .57185 .33828 L p F P
0 g
s
.833 .959 .893 r
.71353 .32732 m .71092 .33249 L .71976 .32489 L p F P
0 g
s
.83 .95 .897 r
.70805 .33187 m .71353 .32732 L .71092 .33249 L p F P
0 g
s
.942 .675 .502 r
.24688 .3482 m .25029 .3515 L .2506 .34703 L p F P
0 g
s
.942 .675 .502 r
.2506 .34703 m .2472 .34372 L .24688 .3482 L p F P
0 g
s
.781 .912 .929 r
.66689 .3616 m .67669 .35511 L .67425 .35367 L p F P
0 g
s
.781 .912 .929 r
.67425 .35367 m .67053 .35611 L .66689 .3616 L p F P
0 g
s
.777 .903 .929 r
.66375 .36044 m .67053 .35611 L .66689 .3616 L p F P
0 g
s
.41 .31 .63 r
.56421 .36318 m .55996 .36717 L .55902 .3616 L p F P
0 g
s
.41 .31 .63 r
.55902 .3616 m .56093 .3598 L .56421 .36318 L p F P
0 g
s
.867 .983 .844 r
.73915 .30348 m .73721 .30548 L .73495 .31056 L p F P
0 g
s
.861 .977 .858 r
.73012 .31248 m .73721 .30548 L .73495 .31056 L p F P
0 g
s
.861 .977 .858 r
.72949 .31394 m .73012 .31248 L p .73495 .31056 L F P
0 g
s
.861 .977 .858 r
.73495 .31056 m .7311 .31436 L .72949 .31394 L p F P
0 g
s
.911 .98 .769 r
.62632 .23762 m .62446 .23779 L .62745 .23382 L closepath p F P
0 g
s
.774 .752 .833 r
.24891 .3831 m .24563 .38561 L .24246 .3821 L p F P
0 g
s
.71 .74 .874 r
.23243 .38713 m .24246 .3821 L .24563 .38561 L p F P
0 g
s
.85 .735 .736 r
.25603 .37612 m .25566 .37581 L .25597 .37621 L closepath p F P
0 g
s
.532 .694 .943 r
.19025 .37982 m .19821 .37905 L .20152 .38237 L p F P
0 g
s
.804 .736 .789 r
.24891 .3831 m .25597 .37621 L .25566 .37581 L p F P
0 g
s
0 0 0 r
.58973 .29791 m .58772 .30136 L .59069 .29585 L p F P
0 g
s
0 0 0 r
.59069 .29585 m .591 .29531 L .58973 .29791 L p F P
0 g
s
.919 .978 .732 r
.61908 .24567 m .61739 .25077 L .62173 .24479 L p F P
0 g
s
.919 .978 .732 r
.62173 .24479 m .62307 .23981 L .61908 .24567 L p F P
0 g
s
.853 .978 .864 r
.7311 .31436 m .7277 .3176 L .72949 .31394 L closepath p F P
0 g
s
.849 .97 .875 r
.72883 .3137 m .72949 .31394 L .7277 .3176 L p F P
0 g
s
.849 .97 .875 r
.72222 .31976 m .72883 .3137 L p .7277 .3176 L F P
0 g
s
.849 .97 .875 r
.72031 .32385 m .72222 .31976 L p .7277 .3176 L F P
0 g
s
.849 .97 .875 r
.7277 .3176 m .72077 .32399 L .72031 .32385 L p F P
0 g
s
.84 .971 .881 r
.72077 .32399 m .71976 .32489 L .72031 .32385 L closepath p F P
0 g
s
.833 .959 .893 r
.71846 .32309 m .71353 .32732 L p .71976 .32489 L F P
0 g
s
.833 .959 .893 r
.71976 .32489 m .72031 .32385 L .71846 .32309 L p F P
0 g
s
0 0 0 r
.58238 .3122 m .58162 .31333 L .58259 .31028 L p F P
0 g
s
0 0 0 r
.58259 .31028 m .58494 .30682 L .58238 .3122 L p F P
0 g
s
.752 .882 .939 r
.65326 .36689 m .64276 .37289 L .64024 .37109 L p F P
0 g
s
.953 .655 .432 r
.24394 .34035 m .2472 .34372 L .2471 .33941 L p F P
0 g
s
.953 .655 .432 r
.2471 .33941 m .24384 .33603 L .24394 .34035 L p F P
0 g
s
.19 .282 .729 r
.78112 .17835 m .78137 .17859 L .78134 .17896 L closepath p F P
0 g
s
.094 .19 .673 r
.784 .18203 m .78362 .18617 L .78134 .17896 L p F P
0 g
s
.094 .19 .673 r
.78134 .17896 m .78137 .17859 L .784 .18203 L p F P
0 g
s
.525 .6 .871 r
.76581 .15303 m .75957 .15277 L .7571 .14831 L p F P
0 g
s
.913 .938 .809 r
.63769 .21676 m .63673 .22165 L .64183 .2154 L p F P
0 g
s
.913 .938 .809 r
.64241 .21068 m .63769 .21676 L p .64183 .2154 L F P
0 g
s
.913 .938 .809 r
.64183 .2154 m .64243 .21068 L .64241 .21068 L p F P
0 g
s
.804 .736 .789 r
.24513 .37999 m .24891 .3831 L p .25566 .37581 L F P
0 g
s
.774 .752 .833 r
.24246 .3821 m .24513 .37999 L .24891 .3831 L p F P
0 g
s
0 0 .19 r
.78661 .20774 m .78573 .21251 L .78568 .20809 L p F P
0 g
s
0 0 .19 r
.78568 .20809 m .78657 .20332 L .78661 .20774 L p F P
0 g
s
.804 .736 .789 r
.25566 .37581 m .25202 .37308 L .24513 .37999 L p F P
0 g
s
.836 .726 .742 r
.25286 .37192 m .25202 .37308 L .25566 .37581 L closepath p F P
0 g
s
.21 .307 .746 r
.78137 .17859 m .78112 .17835 L .77845 .17116 L p F P
0 g
s
0 .023 .565 r
.78587 .18576 m .784 .18203 L .78362 .18617 L p F P
0 g
s
0 .023 .565 r
.78541 .19042 m .78587 .18576 L p .78362 .18617 L F P
0 g
s
0 .023 .565 r
.78362 .18617 m .78395 .18741 L .78541 .19042 L p F P
0 g
s
.881 .943 .578 r
.77386 .25235 m .77245 .25722 L .77532 .25173 L p F P
0 g
s
.881 .943 .578 r
.77515 .24987 m .77386 .25235 L p .77532 .25173 L F P
0 g
s
.881 .943 .578 r
.77532 .25173 m .77608 .24915 L .77515 .24987 L p F P
0 g
s
.901 .984 .73 r
.76122 .27467 m .75966 .27956 L .76384 .27359 L p F P
0 g
s
.901 .984 .73 r
.76384 .27359 m .76547 .26867 L .76122 .27467 L p F P
0 g
s
.715 .743 .874 r
.24246 .3821 m .23243 .38713 L .22922 .38379 L p F P
0 g
s
0 .05 .575 r
.78395 .18741 m .78541 .19042 L .78519 .1923 L closepath p F P
0 g
s
0 0 0 r
.59094 .2958 m .58973 .29791 L .591 .29531 L p F P
0 g
s
0 0 0 r
.591 .29531 m .59388 .29029 L .59094 .2958 L p F P
0 g
s
.579 .575 .812 r
.56393 .37949 m .56995 .37886 L .56548 .38281 L closepath p F P
0 g
s
.621 .621 .83 r
.57446 .37811 m .56995 .37886 L .56548 .38281 L p F P
0 g
s
.621 .621 .83 r
.57717 .38259 m .57446 .37811 L p .56548 .38281 L F P
0 g
s
.707 .805 .926 r
.61574 .38013 m .60615 .38444 L .60353 .38184 L p F P
0 g
s
.688 .8 .934 r
.59302 .38605 m .60353 .38184 L .60615 .38444 L p F P
0 g
s
.889 .985 .717 r
.61711 .25152 m .61676 .25167 L .61739 .25077 L closepath p F P
0 g
s
.21 .307 .746 r
.77845 .17116 m .78169 .17396 L .78137 .17859 L p F P
0 g
s
.094 .196 .68 r
.78438 .17738 m .784 .18203 L .78137 .17859 L p F P
0 g
s
.094 .196 .68 r
.78137 .17859 m .78169 .17396 L .78438 .17738 L p F P
0 g
s
.822 .931 .555 r
.6027 .27378 m .60027 .27911 L .60388 .27337 L p F P
0 g
s
.822 .931 .555 r
.60388 .27337 m .60599 .26816 L .6027 .27378 L p F P
0 g
s
.39 .467 .819 r
.77302 .16384 m .77349 .15948 L .77585 .16489 L closepath p F P
0 g
s
.733 .886 .486 r
.59955 .28051 m .59892 .28132 L .60027 .27911 L closepath p F P
0 g
s
.844 .96 .625 r
.60823 .26588 m .60659 .26717 L .6097 .26239 L closepath p F P
0 g
s
.615 .678 .886 r
.74374 .14634 m .75274 .14435 L .75237 .14907 L p F P
0 g
s
.592 .653 .879 r
.75463 .14398 m .75274 .14435 L .75237 .14907 L p F P
0 g
s
.592 .653 .879 r
.75237 .14907 m .7571 .14831 L .75463 .14398 L p F P
0 g
s
.661 .755 .92 r
.57986 .38648 m .59037 .38297 L .59302 .38605 L p F P
0 g
s
.643 .726 .909 r
.59037 .38297 m .57986 .38648 L .57717 .38259 L p F P
0 g
s
.303 .381 .777 r
.77804 .17091 m .77812 .17031 L .77845 .17116 L closepath p F P
0 g
s
.674 .719 .883 r
.73055 .14657 m .74129 .14249 L .74374 .14634 L p F P
0 g
s
.683 .727 .883 r
.74129 .14249 m .73055 .14657 L .72811 .14306 L p F P
0 g
s
.535 .695 .942 r
.19989 .37888 m .19821 .37905 L .20152 .38237 L p F P
0 g
s
.535 .695 .942 r
.20152 .38237 m .20314 .38221 L .19989 .37888 L p F P
0 g
s
.703 .684 .144 r
.78432 .22191 m .78344 .22665 L .78436 .22187 L p F P
0 g
s
.703 .684 .144 r
.78436 .22187 m .78526 .21712 L .78432 .22191 L p F P
0 g
s
.823 .852 .394 r
.78009 .23678 m .77894 .24159 L .78084 .23645 L p F P
0 g
s
.823 .852 .394 r
.78084 .23645 m .78203 .23162 L .78009 .23678 L p F P
0 g
s
.677 .781 .928 r
.60353 .38184 m .59302 .38605 L .59037 .38297 L p F P
0 g
s
.844 .958 .885 r
.72031 .32385 m .71846 .32309 L .72222 .31976 L closepath p F P
0 g
s
.88 .73 .691 r
.24974 .36776 m .25135 .36441 L .25502 .36759 L p F P
0 g
s
.88 .73 .691 r
.25502 .36759 m .25286 .37192 L .24974 .36776 L p F P
0 g
s
.907 .964 .809 r
.63284 .22293 m .63769 .21676 L .63673 .22165 L p F P
0 g
s
.907 .964 .809 r
.63264 .22383 m .63284 .22293 L p .63673 .22165 L F P
0 g
s
.907 .964 .809 r
.63673 .22165 m .63466 .22418 L .63264 .22383 L p F P
0 g
s
.908 .975 .685 r
.76848 .26538 m .7674 .26573 L .76922 .26285 L closepath p F P
0 g
s
.888 .985 .715 r
.61506 .25155 m .61908 .24567 L .61739 .25077 L p F P
0 g
s
.888 .985 .715 r
.61474 .25249 m .61506 .25155 L p .61739 .25077 L F P
0 g
s
.888 .985 .715 r
.61739 .25077 m .61676 .25167 L .61474 .25249 L p F P
0 g
s
.626 .679 .88 r
.75274 .14435 m .74374 .14634 L .74129 .14249 L p F P
0 g
s
.181 .302 .752 r
.77812 .17031 m .77845 .17116 L .78169 .17396 L p F P
0 g
s
.79 .917 .924 r
.6809 .35223 m .67669 .35511 L .67425 .35367 L p F P
0 g
s
0 0 .458 r
.78659 .19441 m .78622 .1976 L .78519 .1923 L p F P
0 g
s
0 0 .458 r
.78519 .1923 m .78541 .19042 L .78659 .19441 L p F P
0 g
s
.908 .979 .704 r
.61676 .25167 m .6135 .25659 L .61474 .25249 L closepath p F P
0 g
s
.301 .399 .796 r
.77585 .16489 m .77828 .16629 L .77812 .17031 L closepath p F P
0 g
s
.181 .302 .752 r
.78198 .16933 m .77828 .16629 L .77812 .17031 L p F P
0 g
s
.181 .302 .752 r
.78169 .17396 m .78198 .16933 L p .77812 .17031 L F P
0 g
s
.9 .986 .764 r
.7596 .27974 m .75952 .27974 L .75966 .27956 L closepath p F P
0 g
s
.579 .535 .77 r
.56173 .37376 m .56393 .37949 L .56995 .37886 L p F P
0 g
s
.84 .874 .867 r
.68139 .1701 m .67326 .17738 L .67313 .17727 L p F P
0 g
s
.859 .873 .848 r
.67326 .17738 m .67313 .17751 L .67313 .17727 L closepath p F P
0 g
s
.862 .876 .846 r
.66646 .17974 m .66616 .18443 L .67313 .17751 L p F P
0 g
s
.862 .876 .846 r
.67079 .17528 m .66646 .17974 L p .67313 .17751 L F P
0 g
s
.862 .876 .846 r
.67313 .17751 m .67313 .17727 L .67079 .17528 L p F P
0 g
s
.763 .891 .935 r
.65368 .36718 m .65326 .36689 L .65437 .36622 L closepath p F P
0 g
s
.513 .427 .695 r
.56893 .3652 m .56421 .36318 L .55996 .36717 L p F P
0 g
s
.513 .427 .695 r
.56937 .3666 m .56893 .3652 L p .55996 .36717 L F P
0 g
s
.513 .427 .695 r
.5633 .37233 m .56937 .3666 L p .55996 .36717 L F P
0 g
s
.513 .427 .695 r
.55996 .36717 m .56115 .37186 L .5633 .37233 L p F P
0 g
s
.923 .956 .789 r
.63466 .22418 m .63197 .22777 L .63264 .22383 L closepath p F P
0 g
s
0 0 .166 r
.57849 .32255 m .57397 .32853 L .57593 .32335 L p F P
0 g
s
0 0 .166 r
.57593 .32335 m .5802 .31745 L .57849 .32255 L p F P
0 g
s
.902 .986 .766 r
.75738 .2798 m .76122 .27467 L .75966 .27956 L p F P
0 g
s
.902 .986 .766 r
.75966 .27956 m .75952 .27974 L .75738 .2798 L p F P
0 g
s
.837 .853 .857 r
.68362 .16807 m .68139 .1701 L .68125 .16573 L closepath p F P
0 g
s
.84 .874 .867 r
.68116 .16564 m .68125 .16573 L .68139 .1701 L p F P
0 g
s
.84 .874 .867 r
.67352 .17277 m .68116 .16564 L p .68139 .1701 L F P
0 g
s
.84 .874 .867 r
.67313 .17727 m .67352 .17277 L p .68139 .1701 L F P
0 g
s
.816 .852 .875 r
.69079 .16226 m .68362 .16807 L .68125 .16573 L p F P
0 g
s
.403 .309 .634 r
.56754 .35992 m .56421 .36318 L .56093 .3598 L p F P
0 g
s
.403 .309 .634 r
.56093 .3598 m .56654 .35428 L .56754 .35992 L p F P
0 g
s
.894 .989 .767 r
.75478 .28578 m .75952 .27974 L .75738 .2798 L p F P
0 g
s
0 0 0 r
.58823 .30124 m .58494 .30682 L .58772 .30136 L p F P
0 g
s
0 0 0 r
.5888 .30005 m .58823 .30124 L p .58772 .30136 L F P
0 g
s
0 0 0 r
.58772 .30136 m .58973 .29791 L .5888 .30005 L p F P
0 g
s
.723 .778 .896 r
.71933 .14758 m .71748 .14852 L .71504 .14531 L p F P
0 g
s
.759 .789 .877 r
.7045 .15201 m .71504 .14531 L .71748 .14852 L p F P
0 g
s
.846 .877 .864 r
.67313 .17727 m .67079 .17528 L .67352 .17277 L closepath p F P
0 g
s
0 0 .348 r
.78677 .20218 m .78657 .20332 L .78596 .19911 L p F P
0 g
s
0 0 .348 r
.78596 .19911 m .78622 .1976 L .78677 .20218 L p F P
0 g
s
.59 .717 .931 r
.20314 .38221 m .21289 .38027 L .21613 .38359 L p F P
0 g
s
.59 .716 .93 r
.21289 .38027 m .20314 .38221 L .19989 .37888 L p F P
0 g
s
.781 .779 .275 r
.78312 .22823 m .78256 .22981 L .78344 .22665 L closepath p F P
0 g
s
.862 .897 .858 r
.66047 .1858 m .66646 .17974 L .66616 .18443 L p F P
0 g
s
.862 .897 .858 r
.66616 .18443 m .66294 .18759 L .66047 .1858 L p F P
0 g
s
.794 .927 .923 r
.6809 .35223 m .68716 .34782 L .68474 .34651 L p F P
0 g
s
.794 .927 .923 r
.68474 .34651 m .68434 .34679 L .6809 .35223 L p F P
0 g
s
.79 .917 .924 r
.67425 .35367 m .68434 .34679 L .6809 .35223 L p F P
0 g
s
.883 .922 .845 r
.65322 .19896 m .65266 .19865 L .6534 .19786 L closepath p F P
0 g
s
.226 .08 .464 r
.5663 .34908 m .56608 .34932 L .56601 .34486 L p F P
0 g
s
.226 .08 .464 r
.56601 .34486 m .56626 .34459 L .5663 .34908 L p F P
0 g
s
.887 .9 .832 r
.6596 .19121 m .66294 .18759 L .66047 .1858 L p F P
0 g
s
.908 .715 .63 r
.24783 .36117 m .25135 .36441 L .25298 .35943 L p F P
0 g
s
.908 .715 .63 r
.25298 .35943 m .24943 .3562 L .24783 .36117 L p F P
0 g
s
.737 .853 .935 r
.63863 .37195 m .62973 .37664 L .62716 .37454 L p F P
0 g
s
.723 .85 .942 r
.61665 .37971 m .62716 .37454 L .62973 .37664 L p F P
0 g
s
.901 .963 .639 r
.77056 .25801 m .76922 .26285 L .77245 .25722 L p F P
0 g
s
.901 .963 .639 r
.77245 .25722 m .77386 .25235 L .77056 .25801 L p F P
0 g
s
.719 .876 .473 r
.59948 .27939 m .6027 .27378 L .60027 .27911 L p F P
0 g
s
.719 .876 .473 r
.59794 .28262 m .59948 .27939 L p .60027 .27911 L F P
0 g
s
.719 .876 .473 r
.60027 .27911 m .59892 .28132 L .59794 .28262 L p F P
0 g
s
.822 .84 .863 r
.69079 .16226 m .69403 .15961 L .69157 .1569 L p F P
0 g
s
.822 .84 .863 r
.69157 .1569 m .69059 .15773 L .69079 .16226 L p F P
0 g
s
.816 .852 .875 r
.68126 .16555 m .69059 .15773 L .69079 .16226 L p F P
0 g
s
.816 .852 .875 r
.68125 .16573 m .68126 .16555 L p .69079 .16226 L F P
0 g
s
.732 .779 .89 r
.71933 .14758 m .72811 .14306 L .72566 .13959 L p F P
0 g
s
.732 .779 .89 r
.72566 .13959 m .71962 .14285 L .71933 .14758 L p F P
0 g
s
.723 .778 .896 r
.71504 .14531 m .71962 .14285 L .71933 .14758 L p F P
0 g
s
.502 .449 .73 r
.56115 .37186 m .5633 .37233 L .56173 .37376 L closepath p F P
0 g
s
.209 .068 .46 r
.57191 .34277 m .5663 .34908 L .56626 .34459 L p F P
0 g
s
.209 .068 .46 r
.56626 .34459 m .57185 .33828 L .57191 .34277 L p F P
0 g
s
.579 .535 .77 r
.57171 .37257 m .5633 .37233 L .56173 .37376 L p F P
0 g
s
.579 .535 .77 r
.57326 .37585 m .57171 .37257 L p .56173 .37376 L F P
0 g
s
.579 .535 .77 r
.56995 .37886 m .57326 .37585 L p .56173 .37376 L F P
0 g
s
.926 .958 .782 r
.62854 .2289 m .62745 .23382 L .63197 .22777 L p F P
0 g
s
.926 .958 .782 r
.63219 .22377 m .62854 .2289 L p .63197 .22777 L F P
0 g
s
.926 .958 .782 r
.63197 .22777 m .63264 .22383 L .63219 .22377 L p F P
0 g
s
.763 .884 .932 r
.65437 .36622 m .65326 .36689 L .65075 .3651 L p F P
0 g
s
.752 .882 .939 r
.64024 .37109 m .65075 .3651 L .65326 .36689 L p F P
0 g
s
.791 .83 .882 r
.70222 .15368 m .69403 .15961 L .69157 .1569 L p F P
0 g
s
.887 .9 .832 r
.66047 .1858 m .65978 .18657 L .6596 .19121 L p F P
0 g
s
.887 .9 .832 r
.65398 .19308 m .6534 .19786 L .6596 .19121 L p F P
0 g
s
.887 .9 .832 r
.6596 .19121 m .65978 .18657 L .65398 .19308 L p F P
0 g
s
.765 .892 .934 r
.65437 .36622 m .66375 .36044 L .66127 .35881 L p F P
0 g
s
.765 .892 .934 r
.66127 .35881 m .65824 .36065 L .65437 .36622 L p F P
0 g
s
.763 .884 .932 r
.65075 .3651 m .65824 .36065 L .65437 .36622 L p F P
0 g
s
.932 .701 .566 r
.24602 .3529 m .24943 .3562 L .25029 .3515 L p F P
0 g
s
.932 .701 .566 r
.25029 .3515 m .24688 .3482 L .24602 .3529 L p F P
0 g
s
.906 .976 .688 r
.61146 .25728 m .6097 .26239 L .6135 .25659 L p F P
0 g
s
.906 .976 .688 r
.61428 .25271 m .61146 .25728 L p .6135 .25659 L F P
0 g
s
.906 .976 .688 r
.6135 .25659 m .61474 .25249 L .61428 .25271 L p F P
0 g
s
.754 .888 .482 r
.59892 .28132 m .59695 .28474 L .59794 .28262 L closepath p F P
0 g
s
.892 .986 .797 r
.7513 .28718 m .74959 .29211 L .75478 .28578 L p F P
0 g
s
.892 .986 .797 r
.75478 .28578 m .75659 .28081 L .7513 .28718 L p F P
0 g
s
.894 .989 .767 r
.75738 .2798 m .75659 .28081 L .75478 .28578 L p F P
0 g
s
.803 .93 .917 r
.69312 .34347 m .68716 .34782 L .68474 .34651 L p F P
0 g
s
.845 .733 .74 r
.25202 .37308 m .25286 .37192 L .24974 .36776 L p F P
0 g
s
.898 .939 .571 r
.77608 .24915 m .77515 .24987 L .77664 .24688 L closepath p F P
0 g
s
.282 .4 .806 r
.77349 .15948 m .77585 .16489 L .77828 .16629 L p F P
0 g
s
0 0 .011 r
.78612 .21236 m .78526 .21712 L .78573 .21251 L p F P
0 g
s
0 0 .011 r
.78573 .21251 m .78661 .20774 L .78612 .21236 L p F P
0 g
s
.883 .921 .845 r
.65019 .19728 m .65398 .19308 L .6534 .19786 L p F P
0 g
s
.883 .921 .845 r
.6534 .19786 m .65266 .19865 L .65019 .19728 L p F P
0 g
s
.845 .733 .74 r
.24974 .36776 m .24818 .36996 L .25202 .37308 L p F P
0 g
s
.81 .743 .79 r
.2415 .37681 m .24513 .37999 L .25202 .37308 L p F P
0 g
s
.81 .743 .79 r
.25202 .37308 m .24818 .36996 L .2415 .37681 L p F P
0 g
s
.907 .925 .816 r
.64794 .20424 m .65266 .19865 L .65019 .19728 L p F P
0 g
s
.876 .908 .499 r
.77775 .24209 m .77664 .24688 L .77894 .24159 L p F P
0 g
s
.876 .908 .499 r
.77894 .24159 m .78009 .23678 L .77775 .24209 L p F P
0 g
s
.525 .6 .871 r
.7571 .14831 m .76603 .14837 L .76581 .15303 L p F P
0 g
s
.542 .603 .864 r
.76603 .14837 m .7571 .14831 L .75463 .14398 L p F P
0 g
s
0 0 .457 r
.78708 .18974 m .78659 .19441 L .78541 .19042 L p F P
0 g
s
0 0 .457 r
.78541 .19042 m .78587 .18576 L .78708 .18974 L p F P
0 g
s
.95 .683 .497 r
.24362 .34484 m .24688 .3482 L .2472 .34372 L p F P
0 g
s
.95 .683 .497 r
.2472 .34372 m .24394 .34035 L .24362 .34484 L p F P
0 g
s
.779 .754 .831 r
.24513 .37999 m .24246 .3821 L .23927 .3786 L p F P
0 g
s
.715 .743 .874 r
.22922 .38379 m .23927 .3786 L .24246 .3821 L p F P
0 g
s
.647 .733 .912 r
.21613 .38359 m .22601 .38044 L .22922 .38379 L p F P
0 g
s
.648 .734 .912 r
.22601 .38044 m .21613 .38359 L .21289 .38027 L p F P
0 g
s
0 0 .309 r
.78719 .19862 m .78677 .20218 L .78622 .1976 L p F P
0 g
s
0 0 .309 r
.78622 .1976 m .78659 .19441 L .78719 .19862 L p F P
0 g
s
.71 .825 .936 r
.61665 .37971 m .61574 .38013 L .61638 .37946 L closepath p F P
0 g
s
.707 .805 .926 r
.61405 .37728 m .61638 .37946 L .61574 .38013 L p F P
0 g
s
.707 .805 .926 r
.60353 .38184 m .61405 .37728 L p .61574 .38013 L F P
0 g
s
.791 .83 .882 r
.69157 .1569 m .70182 .14921 L .70222 .15368 L p F P
0 g
s
.796 .818 .869 r
.70222 .15368 m .7045 .15201 L .70204 .14904 L p F P
0 g
s
.796 .818 .869 r
.70204 .14904 m .70182 .14921 L .70222 .15368 L p F P
0 g
s
0 0 .264 r
.57366 .32891 m .57352 .33013 L .57397 .32853 L closepath p F P
0 g
s
.786 .781 .279 r
.78295 .22687 m .78432 .22191 L .78344 .22665 L p F P
0 g
s
.786 .781 .279 r
.78224 .2307 m .78295 .22687 L p .78344 .22665 L F P
0 g
s
.786 .781 .279 r
.78344 .22665 m .78256 .22981 L .78224 .2307 L p F P
0 g
s
.779 .754 .831 r
.23927 .3786 m .2415 .37681 L .24513 .37999 L p F P
0 g
s
.809 .94 .914 r
.69761 .34009 m .69312 .34347 L .69568 .33912 L closepath p F P
0 g
s
.803 .93 .917 r
.69523 .33887 m .69568 .33912 L .69312 .34347 L p F P
0 g
s
.803 .93 .917 r
.68474 .34651 m .69523 .33887 L p .69312 .34347 L F P
0 g
s
.887 .982 .818 r
.7495 .29235 m .7494 .29233 L .74959 .29211 L closepath p F P
0 g
s
.718 .827 .933 r
.62459 .37233 m .62716 .37454 L .61665 .37971 L p F P
0 g
s
.718 .827 .933 r
.62066 .37419 m .62459 .37233 L p .61665 .37971 L F P
0 g
s
.718 .827 .933 r
.61665 .37971 m .61638 .37946 L .62066 .37419 L p F P
0 g
s
.911 .98 .77 r
.62429 .23485 m .62854 .2289 L .62745 .23382 L p F P
0 g
s
.911 .98 .77 r
.62349 .23788 m .62429 .23485 L p .62745 .23382 L F P
0 g
s
.911 .98 .77 r
.62745 .23382 m .62446 .23779 L .62349 .23788 L p F P
0 g
s
0 0 0 r
.58595 .30653 m .58238 .3122 L .58494 .30682 L p F P
0 g
s
0 0 0 r
.58494 .30682 m .58823 .30124 L .58595 .30653 L p F P
0 g
s
.766 .793 .875 r
.71504 .14531 m .7045 .15201 L .70204 .14904 L p F P
0 g
s
.888 .98 .819 r
.74719 .29193 m .7513 .28718 L .74959 .29211 L p F P
0 g
s
.888 .98 .819 r
.74959 .29211 m .7494 .29233 L .74719 .29193 L p F P
0 g
s
.881 .984 .823 r
.74363 .29871 m .7494 .29233 L .74719 .29193 L p F P
0 g
s
.909 .975 .686 r
.76692 .2638 m .77056 .25801 L .76922 .26285 L p F P
0 g
s
.909 .975 .686 r
.7663 .26608 m .76692 .2638 L p .76922 .26285 L F P
0 g
s
.909 .975 .686 r
.76922 .26285 m .7674 .26573 L .7663 .26608 L p F P
0 g
s
.735 .867 .447 r
.59636 .28496 m .59388 .29029 L .59695 .28474 L p F P
0 g
s
.735 .867 .447 r
.59646 .28478 m .59636 .28496 L p .59695 .28474 L F P
0 g
s
.735 .867 .447 r
.59695 .28474 m .59794 .28262 L .59646 .28478 L p F P
0 g
s
.857 .965 .871 r
.72949 .31394 m .72883 .3137 L .73012 .31248 L closepath p F P
0 g
s
.027 0 .28 r
.57722 .3275 m .57849 .32255 L .57397 .32853 L p F P
0 g
s
.027 0 .28 r
.57323 .33271 m .57722 .3275 L p .57397 .32853 L F P
0 g
s
.027 0 .28 r
.57397 .32853 m .57352 .33013 L .57323 .33271 L p F P
0 g
s
.542 .519 .78 r
.5633 .37233 m .56937 .3666 L .57171 .37257 L closepath p F P
0 g
s
.718 .746 .873 r
.23927 .3786 m .22922 .38379 L .22601 .38044 L p F P
0 g
s
.817 .94 .908 r
.70391 .33519 m .69761 .34009 L .69568 .33912 L p F P
0 g
s
.907 .925 .816 r
.65019 .19728 m .64835 .19953 L .64794 .20424 L p F P
0 g
s
.907 .924 .816 r
.64322 .20579 m .64244 .21064 L .64794 .20424 L p F P
0 g
s
.907 .924 .816 r
.64794 .20424 m .64835 .19953 L .64322 .20579 L p F P
0 g
s
.714 .82 .931 r
.61638 .37946 m .61405 .37728 L .62066 .37419 L closepath p F P
0 g
s
.476 .55 .853 r
.76824 .14857 m .76603 .14837 L .76581 .15303 L p F P
0 g
s
.476 .55 .853 r
.76581 .15303 m .77076 .1537 L .76824 .14857 L p F P
0 g
s
.643 .726 .909 r
.57717 .38259 m .58769 .37955 L .59037 .38297 L p F P
0 g
s
.619 .69 .894 r
.58769 .37955 m .57717 .38259 L .57446 .37811 L p F P
0 g
s
.84 .958 .62 r
.60799 .26296 m .61146 .25728 L .6097 .26239 L p F P
0 g
s
.84 .958 .62 r
.60625 .26745 m .60799 .26296 L p .6097 .26239 L F P
0 g
s
.84 .958 .62 r
.6097 .26239 m .60659 .26717 L .60625 .26745 L p F P
0 g
s
0 .058 .585 r
.7863 .1811 m .78587 .18576 L .784 .18203 L p F P
0 g
s
0 .058 .585 r
.784 .18203 m .78438 .17738 L .7863 .1811 L p F P
0 g
s
.74 .869 .94 r
.64024 .37109 m .63863 .37195 L .63969 .37067 L closepath p F P
0 g
s
.737 .853 .935 r
.63769 .36908 m .63969 .37067 L .63863 .37195 L p F P
0 g
s
.737 .853 .935 r
.62716 .37454 m .63769 .36908 L p .63863 .37195 L F P
0 g
s
.776 .9 .929 r
.67053 .35611 m .66375 .36044 L .66127 .35881 L p F P
0 g
s
.928 .971 .753 r
.62446 .23779 m .62307 .23981 L .62349 .23788 L closepath p F P
0 g
s
0 0 .023 r
.58162 .31333 m .58115 .31512 L .58238 .3122 L closepath p F P
0 g
s
.881 .984 .823 r
.74719 .29193 m .74559 .29371 L .74363 .29871 L p F P
0 g
s
.876 .978 .839 r
.73922 .30047 m .74559 .29371 L .74363 .29871 L p F P
0 g
s
.876 .978 .839 r
.73817 .30326 m .73922 .30047 L p .74363 .29871 L F P
0 g
s
.876 .978 .839 r
.74363 .29871 m .73915 .30348 L .73817 .30326 L p F P
0 g
s
.822 .949 .903 r
.70805 .33187 m .70391 .33519 L .70618 .33102 L closepath p F P
0 g
s
.817 .94 .908 r
.70569 .33076 m .70618 .33102 L .70391 .33519 L p F P
0 g
s
.817 .94 .908 r
.69618 .33815 m .70569 .33076 L p .70391 .33519 L F P
0 g
s
.817 .94 .908 r
.69568 .33912 m .69618 .33815 L p .70391 .33519 L F P
0 g
s
.887 .735 .688 r
.24659 .36377 m .24783 .36117 L .25135 .36441 L p F P
0 g
s
.887 .735 .688 r
.25135 .36441 m .24974 .36776 L .24659 .36377 L p F P
0 g
s
.693 .802 .933 r
.61405 .37728 m .60353 .38184 L .60089 .37903 L p F P
0 g
s
.677 .781 .928 r
.59037 .38297 m .60089 .37903 L .60353 .38184 L p F P
0 g
s
.901 .978 .693 r
.7674 .26573 m .76547 .26867 L .7663 .26608 L closepath p F P
0 g
s
.683 .727 .883 r
.72811 .14306 m .73884 .1387 L .74129 .14249 L p F P
0 g
s
.692 .734 .883 r
.73884 .1387 m .72811 .14306 L .72566 .13959 L p F P
0 g
s
.019 0 .277 r
.57352 .33013 m .57258 .33351 L .57323 .33271 L closepath p F P
0 g
s
.75 .871 .935 r
.64823 .36324 m .65075 .3651 L .64024 .37109 L p F P
0 g
s
.75 .871 .935 r
.64284 .36626 m .64823 .36324 L p .64024 .37109 L F P
0 g
s
.75 .871 .935 r
.64024 .37109 m .63969 .37067 L .64284 .36626 L p F P
0 g
s
.599 .613 .837 r
.56995 .37886 m .57326 .37585 L .57446 .37811 L closepath p F P
0 g
s
.626 .679 .88 r
.75313 .1414 m .75274 .14435 L p .74129 .14249 L F P
0 g
s
.626 .679 .88 r
.74129 .14249 m .75217 .13976 L .75313 .1414 L p F P
0 g
s
.637 .689 .881 r
.75217 .13976 m .74129 .14249 L .73884 .1387 L p F P
0 g
s
.663 .759 .921 r
.60089 .37903 m .59037 .38297 L .58769 .37955 L p F P
0 g
s
.83 .949 .897 r
.71353 .32732 m .70805 .33187 L .70618 .33102 L p F P
0 g
s
.902 .944 .825 r
.64243 .21068 m .64241 .21068 L .64244 .21064 L closepath p F P
0 g
s
.902 .944 .825 r
.63993 .20978 m .64322 .20579 L .64244 .21064 L p F P
0 g
s
.902 .944 .825 r
.64244 .21064 m .64241 .21068 L .63993 .20978 L p F P
0 g
s
.375 .471 .831 r
.77329 .15905 m .77349 .15912 L .77349 .15948 L closepath p F P
0 g
s
.282 .4 .806 r
.77844 .16168 m .77349 .15912 L .77349 .15948 L p F P
0 g
s
.282 .4 .806 r
.77828 .16629 m .77844 .16168 L p .77349 .15948 L F P
0 g
s
.923 .943 .793 r
.63769 .21676 m .64241 .21068 L .63993 .20978 L p F P
0 g
s
.868 .98 .846 r
.73915 .30348 m .73721 .30548 L .73817 .30326 L closepath p F P
0 g
s
0 0 .176 r
.78689 .20611 m .78661 .20774 L .78657 .20332 L p F P
0 g
s
0 0 .176 r
.78657 .20332 m .78677 .20218 L .78689 .20611 L p F P
0 g
s
.929 .971 .742 r
.62026 .24073 m .61908 .24567 L .62307 .23981 L p F P
0 g
s
.929 .971 .742 r
.62198 .23809 m .62026 .24073 L p .62307 .23981 L F P
0 g
s
.929 .971 .742 r
.62307 .23981 m .62349 .23788 L .62198 .23809 L p F P
0 g
s
.763 .774 .272 r
.78256 .22981 m .78203 .23162 L .78224 .2307 L closepath p F P
0 g
s
.101 .205 .686 r
.78475 .17272 m .78438 .17738 L .78169 .17396 L p F P
0 g
s
.101 .205 .686 r
.78169 .17396 m .78198 .16933 L .78475 .17272 L p F P
0 g
s
.303 .185 .549 r
.56759 .35315 m .56654 .35428 L .56608 .34932 L p F P
0 g
s
.303 .185 .549 r
.56608 .34932 m .5663 .34908 L .56759 .35315 L p F P
0 g
s
.86 .969 .864 r
.73219 .30745 m .73012 .31248 L .73721 .30548 L p F P
0 g
s
.86 .969 .864 r
.7369 .30283 m .73219 .30745 L p .73721 .30548 L F P
0 g
s
.86 .969 .864 r
.73721 .30548 m .73817 .30326 L .7369 .30283 L p F P
0 g
s
.391 .49 .84 r
.77349 .15912 m .77329 .15905 L .77076 .1537 L p F P
0 g
s
.836 .958 .891 r
.71846 .32309 m .71353 .32732 L .71614 .32214 L closepath p F P
0 g
s
.83 .949 .897 r
.71613 .32213 m .71614 .32214 L .71353 .32732 L p F P
0 g
s
.83 .949 .897 r
.70669 .32996 m .71613 .32213 L p .71353 .32732 L F P
0 g
s
.83 .949 .897 r
.70618 .33102 m .70669 .32996 L p .71353 .32732 L F P
0 g
s
.9 .939 .574 r
.77504 .24754 m .77775 .24209 L .77664 .24688 L p F P
0 g
s
.9 .939 .574 r
.77437 .25046 m .77504 .24754 L p .77664 .24688 L F P
0 g
s
.9 .939 .574 r
.77664 .24688 m .77515 .24987 L .77437 .25046 L p F P
0 g
s
.391 .49 .84 r
.77076 .1537 m .77346 .15457 L .77349 .15912 L p F P
0 g
s
.325 .431 .816 r
.7786 .15707 m .77844 .16168 L .77349 .15912 L p F P
0 g
s
.325 .431 .816 r
.77349 .15912 m .77346 .15457 L .7786 .15707 L p F P
0 g
s
.281 .165 .538 r
.57303 .34691 m .56759 .35315 L .5663 .34908 L p F P
0 g
s
.281 .165 .538 r
.5663 .34908 m .57191 .34277 L .57303 .34691 L p F P
0 g
s
0 0 0 r
.58973 .29791 m .5888 .30005 L .59094 .2958 L closepath p F P
0 g
s
.844 .957 .885 r
.72222 .31976 m .71846 .32309 L .71614 .32214 L p F P
0 g
s
.905 .984 .745 r
.76274 .26978 m .76122 .27467 L .76547 .26867 L p F P
0 g
s
.905 .984 .745 r
.7653 .26617 m .76274 .26978 L p .76547 .26867 L F P
0 g
s
.905 .984 .745 r
.76547 .26867 m .7663 .26608 L .7653 .26617 L p F P
0 g
s
.857 .962 .871 r
.72654 .31283 m .73219 .30745 L .73012 .31248 L p F P
0 g
s
.857 .962 .871 r
.73012 .31248 m .72883 .3137 L .72654 .31283 L p F P
0 g
s
.223 .329 .761 r
.78226 .16468 m .78198 .16933 L .77828 .16629 L p F P
0 g
s
.223 .329 .761 r
.77828 .16629 m .77844 .16168 L .78226 .16468 L p F P
0 g
s
.85 .964 .877 r
.72222 .31976 m .72883 .3137 L .72654 .31283 L p F P
0 g
s
.85 .964 .877 r
.72654 .31283 m .72455 .31466 L .72222 .31976 L p F P
0 g
s
.844 .957 .885 r
.71614 .32213 m .72455 .31466 L .72222 .31976 L p F P
0 g
s
.844 .957 .885 r
.71614 .32214 m .71614 .32213 L p .72222 .31976 L F P
0 g
s
.605 .666 .882 r
.75274 .14435 m .75313 .1414 L .75463 .14398 L closepath p F P
0 g
s
.59 .716 .93 r
.19989 .37888 m .20965 .37694 L .21289 .38027 L p F P
0 g
s
.915 .723 .629 r
.24443 .35787 m .24783 .36117 L .24943 .3562 L p F P
0 g
s
.915 .723 .629 r
.24943 .3562 m .24602 .3529 L .24443 .35787 L p F P
0 g
s
.866 .958 .618 r
.60659 .26717 m .60599 .26816 L .60625 .26745 L closepath p F P
0 g
s
.781 .912 .929 r
.67425 .35367 m .67053 .35611 L .67276 .35275 L closepath p F P
0 g
s
.776 .9 .929 r
.67179 .35211 m .67276 .35275 L .67053 .35611 L p F P
0 g
s
.776 .9 .929 r
.66127 .35881 m .67179 .35211 L p .67053 .35611 L F P
0 g
s
.67 .798 .341 r
.5937 .29038 m .59094 .2958 L .59388 .29029 L p F P
0 g
s
.67 .798 .341 r
.59388 .29029 m .59636 .28496 L .5937 .29038 L p F P
0 g
s
.744 .861 .934 r
.63969 .37067 m .63769 .36908 L .64284 .36626 L closepath p F P
0 g
s
0 0 .046 r
.58394 .31173 m .58595 .30653 L .58238 .3122 L p F P
0 g
s
0 0 .046 r
.58079 .31658 m .58394 .31173 L p .58238 .3122 L F P
0 g
s
0 0 .046 r
.58238 .3122 m .58115 .31512 L .58079 .31658 L p F P
0 g
s
.731 .783 .894 r
.71962 .14285 m .71504 .14531 L .71259 .14211 L p F P
0 g
s
.766 .793 .875 r
.70204 .14904 m .71259 .14211 L .71504 .14531 L p F P
0 g
s
.72 .698 .161 r
.78516 .21717 m .78432 .22191 L .78526 .21712 L p F P
0 g
s
.72 .698 .161 r
.78526 .21712 m .78612 .21236 L .78516 .21717 L p F P
0 g
s
.841 .862 .412 r
.78103 .23269 m .78009 .23678 L .78203 .23162 L p F P
0 g
s
.841 .862 .412 r
.78203 .23162 m .78224 .2307 L .78103 .23269 L p F P
0 g
s
.857 .949 .592 r
.60436 .26915 m .6027 .27378 L .60599 .26816 L p F P
0 g
s
.857 .949 .592 r
.60599 .26816 m .60625 .26745 L .60436 .26915 L p F P
0 g
s
.464 .401 .701 r
.56421 .36318 m .56754 .35992 L .56893 .3652 L closepath p F P
0 g
s
.852 .741 .739 r
.24818 .36996 m .24974 .36776 L .24659 .36377 L p F P
0 g
s
.821 .855 .873 r
.68125 .16573 m .68116 .16564 L .68126 .16555 L closepath p F P
0 g
s
.726 .864 .445 r
.59794 .28262 m .59646 .28478 L .59948 .27939 L closepath p F P
0 g
s
0 0 .14 r
.78726 .20304 m .78689 .20611 L .78677 .20218 L p F P
0 g
s
0 0 .14 r
.78677 .20218 m .78719 .19862 L .78726 .20304 L p F P
0 g
s
.923 .943 .793 r
.63993 .20978 m .63826 .212 L .63769 .21676 L p F P
0 g
s
.924 .944 .792 r
.63375 .21805 m .63284 .22293 L .63769 .21676 L p F P
0 g
s
.924 .944 .792 r
.63769 .21676 m .63826 .212 L .63375 .21805 L p F P
0 g
s
.821 .855 .873 r
.68126 .16555 m .68116 .16564 L .67869 .16322 L p F P
0 g
s
.853 .872 .853 r
.67352 .17277 m .68116 .16564 L .67869 .16322 L p F P
0 g
s
.823 .837 .859 r
.68145 .16086 m .68126 .16555 L .69059 .15773 L p F P
0 g
s
.821 .855 .873 r
.67869 .16322 m .68145 .16086 L .68126 .16555 L p F P
0 g
s
.853 .872 .853 r
.67869 .16322 m .67361 .16813 L .67352 .17277 L p F P
0 g
s
.845 .875 .863 r
.66832 .17315 m .67361 .16813 L .67352 .17277 L p F P
0 g
s
.845 .875 .863 r
.67352 .17277 m .67079 .17528 L .66832 .17315 L p F P
0 g
s
.873 .882 .839 r
.66646 .17974 m .67079 .17528 L .66832 .17315 L p F P
0 g
s
.789 .913 .924 r
.68434 .34679 m .67425 .35367 L .67276 .35275 L p F P
0 g
s
.889 .942 .578 r
.77515 .24987 m .77386 .25235 L .77437 .25046 L closepath p F P
0 g
s
.939 .709 .563 r
.24275 .34953 m .24602 .3529 L .24688 .3482 L p F P
0 g
s
.939 .709 .563 r
.24688 .3482 m .24362 .34484 L .24275 .34953 L p F P
0 g
s
.095 0 .363 r
.57304 .33682 m .57185 .33828 L .57258 .33351 L p F P
0 g
s
.095 0 .363 r
.57258 .33351 m .57323 .33271 L .57304 .33682 L p F P
0 g
s
.542 .603 .864 r
.76625 .14464 m .76603 .14837 L p .75463 .14398 L F P
0 g
s
.542 .603 .864 r
.75463 .14398 m .76574 .14365 L .76625 .14464 L p F P
0 g
s
.533 .629 .893 r
.75313 .1414 m .75463 .14398 L .76574 .14365 L p F P
0 g
s
.915 .964 .796 r
.63264 .22383 m .63219 .22377 L .63284 .22293 L closepath p F P
0 g
s
.926 .974 .713 r
.61655 .2465 m .61506 .25155 L .61908 .24567 L p F P
0 g
s
.926 .974 .713 r
.61908 .24567 m .62026 .24073 L .61655 .2465 L p F P
0 g
s
.852 .741 .739 r
.24659 .36377 m .24454 .36677 L .24818 .36996 L p F P
0 g
s
.815 .749 .791 r
.23798 .37357 m .2415 .37681 L .24818 .36996 L p F P
0 g
s
.815 .749 .791 r
.24818 .36996 m .24454 .36677 L .23798 .37357 L p F P
0 g
s
.73 .851 .938 r
.63769 .36908 m .62716 .37454 L .62459 .37233 L p F P
0 g
s
0 0 .304 r
.78769 .19396 m .78719 .19862 L .78659 .19441 L p F P
0 g
s
0 0 .304 r
.78659 .19441 m .78708 .18974 L .78769 .19396 L p F P
0 g
s
.873 .882 .839 r
.66832 .17315 m .66644 .17515 L .66646 .17974 L p F P
0 g
s
.867 .895 .851 r
.66004 .18188 m .66644 .17515 L .66646 .17974 L p F P
0 g
s
.867 .895 .851 r
.65978 .18529 m .66004 .18188 L p .66646 .17974 L F P
0 g
s
.867 .895 .851 r
.66646 .17974 m .66047 .1858 L .65978 .18529 L p F P
0 g
s
.845 .948 .592 r
.60456 .26864 m .60436 .26915 L .60625 .26745 L p F P
0 g
s
.845 .948 .592 r
.60625 .26745 m .60799 .26296 L .60456 .26864 L p F P
0 g
s
.82 .834 .86 r
.69157 .1569 m .69059 .15773 L .69041 .15563 L closepath p F P
0 g
s
.823 .837 .859 r
.68911 .1542 m .68145 .16086 L p .69059 .15773 L F P
0 g
s
.823 .837 .859 r
.69059 .15773 m .69041 .15563 L .68911 .1542 L p F P
0 g
s
.798 .831 .877 r
.70182 .14921 m .69157 .1569 L .69041 .15563 L p F P
0 g
s
.906 .984 .764 r
.7581 .27593 m .76274 .26978 L .76122 .27467 L p F P
0 g
s
.906 .984 .764 r
.75694 .27981 m .7581 .27593 L p .76122 .27467 L F P
0 g
s
.906 .984 .764 r
.76122 .27467 m .75738 .2798 L .75694 .27981 L p F P
0 g
s
.784 .757 .829 r
.2415 .37681 m .23927 .3786 L .23608 .37513 L p F P
0 g
s
.718 .746 .873 r
.22601 .38044 m .23608 .37513 L .23927 .3786 L p F P
0 g
s
.864 .863 .413 r
.78116 .23198 m .78103 .23269 L .78224 .2307 L p F P
0 g
s
.864 .863 .413 r
.78224 .2307 m .78295 .22687 L .78116 .23198 L p F P
0 g
s
0 0 .033 r
.58115 .31512 m .5802 .31745 L .58079 .31658 L closepath p F P
0 g
s
.739 .779 .885 r
.71962 .14285 m .72566 .13959 L .72321 .13614 L p F P
0 g
s
.739 .779 .885 r
.72321 .13614 m .71936 .13831 L .71962 .14285 L p F P
0 g
s
.731 .783 .894 r
.71259 .14211 m .71936 .13831 L .71962 .14285 L p F P
0 g
s
.648 .734 .912 r
.21289 .38027 m .22278 .37709 L .22601 .38044 L p F P
0 g
s
.648 .734 .912 r
.22278 .37709 m .21289 .38027 L .20965 .37694 L p F P
0 g
s
.919 .977 .754 r
.62349 .23788 m .62198 .23809 L .62429 .23485 L closepath p F P
0 g
s
.619 .69 .894 r
.57446 .37811 m .585 .37571 L .58769 .37955 L p F P
0 g
s
.618 .622 .833 r
.57326 .37585 m .57446 .37811 L .585 .37571 L p F P
0 g
s
.895 .979 .694 r
.61474 .25249 m .61428 .25271 L .61506 .25155 L closepath p F P
0 g
s
.885 .892 .831 r
.66047 .1858 m .65978 .18657 L .65978 .18529 L closepath p F P
0 g
s
.784 .757 .829 r
.23608 .37513 m .23798 .37357 L .2415 .37681 L p F P
0 g
s
.761 .879 .932 r
.65824 .36065 m .65075 .3651 L .64823 .36324 L p F P
0 g
s
.889 .894 .828 r
.65422 .1884 m .65398 .19308 L .65978 .18657 L p F P
0 g
s
.889 .894 .828 r
.65799 .18402 m .65422 .1884 L p .65978 .18657 L F P
0 g
s
.889 .894 .828 r
.65978 .18657 m .65978 .18529 L .65799 .18402 L p F P
0 g
s
.91 .967 .656 r
.77186 .25317 m .77056 .25801 L .77386 .25235 L p F P
0 g
s
.91 .967 .656 r
.77313 .25098 m .77186 .25317 L p .77386 .25235 L F P
0 g
s
.91 .967 .656 r
.77386 .25235 m .77437 .25046 L .77313 .25098 L p F P
0 g
s
.064 0 .353 r
.57654 .33226 m .57304 .33682 L .57323 .33271 L p F P
0 g
s
.064 0 .353 r
.57323 .33271 m .57722 .3275 L .57654 .33226 L p F P
0 g
s
.915 .963 .797 r
.6297 .22341 m .63375 .21805 L .63284 .22293 L p F P
0 g
s
.915 .963 .797 r
.63284 .22293 m .63219 .22377 L .6297 .22341 L p F P
0 g
s
.871 .967 .855 r
.73817 .30326 m .7369 .30283 L .73922 .30047 L closepath p F P
0 g
s
.935 .956 .764 r
.62854 .2289 m .63219 .22377 L .6297 .22341 L p F P
0 g
s
.721 .749 .874 r
.23608 .37513 m .22601 .38044 L .22278 .37709 L p F P
0 g
s
.409 .506 .846 r
.77346 .15457 m .77076 .1537 L .76824 .14857 L p F P
0 g
s
0 0 0 r
.59121 .29574 m .5937 .29038 L .59094 .2958 L p F P
0 g
s
0 0 0 r
.58854 .30066 m .59121 .29574 L p .59094 .2958 L F P
0 g
s
0 0 0 r
.59094 .2958 m .5888 .30005 L .58854 .30066 L p F P
0 g
s
.379 .292 .631 r
.5706 .35664 m .56754 .35992 L .56654 .35428 L p F P
0 g
s
.379 .292 .631 r
.56654 .35428 m .56759 .35315 L .5706 .35664 L p F P
0 g
s
.845 .935 .559 r
.60156 .27418 m .59948 .27939 L .6027 .27378 L p F P
0 g
s
.845 .935 .559 r
.60412 .2694 m .60156 .27418 L p .6027 .27378 L F P
0 g
s
.845 .935 .559 r
.6027 .27378 m .60436 .26915 L .60412 .2694 L p F P
0 g
s
.898 .987 .772 r
.75738 .2798 m .75659 .28081 L .75694 .27981 L closepath p F P
0 g
s
.795 .924 .922 r
.68474 .34651 m .68434 .34679 L .68457 .34641 L closepath p F P
0 g
s
.789 .913 .924 r
.68231 .34498 m .68457 .34641 L .68434 .34679 L p F P
0 g
s
.789 .913 .924 r
.67397 .35067 m .68231 .34498 L p .68434 .34679 L F P
0 g
s
.789 .913 .924 r
.67276 .35275 m .67397 .35067 L p .68434 .34679 L F P
0 g
s
.806 .924 .915 r
.69282 .33745 m .69523 .33887 L .68474 .34651 L p F P
0 g
s
.806 .924 .915 r
.68718 .34154 m .69282 .33745 L p .68474 .34651 L F P
0 g
s
.806 .924 .915 r
.68474 .34651 m .68457 .34641 L .68718 .34154 L p F P
0 g
s
0 0 0 r
.78662 .20946 m .78612 .21236 L .78661 .20774 L p F P
0 g
s
0 0 0 r
.78661 .20774 m .78689 .20611 L .78662 .20946 L p F P
0 g
s
.798 .831 .877 r
.69958 .1461 m .70176 .1487 L .70182 .14921 L p F P
0 g
s
.798 .831 .877 r
.69049 .15314 m .69958 .1461 L p .70182 .14921 L F P
0 g
s
.798 .831 .877 r
.69041 .15563 m .69049 .15314 L p .70182 .14921 L F P
0 g
s
.796 .815 .867 r
.70204 .14904 m .70182 .14921 L .70176 .1487 L closepath p F P
0 g
s
0 0 .125 r
.58015 .32008 m .57849 .32255 L .5802 .31745 L p F P
0 g
s
0 0 .125 r
.5802 .31745 m .58079 .31658 L .58015 .32008 L p F P
0 g
s
.714 .808 .924 r
.62066 .37419 m .61405 .37728 L .61143 .37468 L p F P
0 g
s
.693 .802 .933 r
.60089 .37903 m .61143 .37468 L .61405 .37728 L p F P
0 g
s
.888 .917 .838 r
.64859 .19486 m .65422 .1884 L .65398 .19308 L p F P
0 g
s
.888 .917 .838 r
.64845 .19629 m .64859 .19486 L p .65398 .19308 L F P
0 g
s
.888 .917 .838 r
.65398 .19308 m .65019 .19728 L .64845 .19629 L p F P
0 g
s
.772 .81 .883 r
.71013 .13892 m .71259 .14211 L .70204 .14904 L p F P
0 g
s
.772 .81 .883 r
.70189 .14455 m .71013 .13892 L p .70204 .14904 L F P
0 g
s
.772 .81 .883 r
.70204 .14904 m .70176 .1487 L .70189 .14455 L p F P
0 g
s
0 0 .459 r
.78753 .18507 m .78708 .18974 L .78587 .18576 L p F P
0 g
s
0 0 .459 r
.78587 .18576 m .7863 .1811 L .78753 .18507 L p F P
0 g
s
.894 .982 .806 r
.75297 .28226 m .7513 .28718 L .75659 .28081 L p F P
0 g
s
.894 .982 .806 r
.7552 .27956 m .75297 .28226 L p .75659 .28081 L F P
0 g
s
.894 .982 .806 r
.75659 .28081 m .75694 .27981 L .7552 .27956 L p F P
0 g
s
.895 .979 .694 r
.61284 .25228 m .61655 .2465 L .61506 .25155 L p F P
0 g
s
.895 .979 .694 r
.61244 .25358 m .61284 .25228 L p .61506 .25155 L F P
0 g
s
.895 .979 .694 r
.61506 .25155 m .61428 .25271 L .61244 .25358 L p F P
0 g
s
.571 .574 .817 r
.57171 .37257 m .57701 .37214 L .57326 .37585 L closepath p F P
0 g
s
.618 .622 .833 r
.58229 .37133 m .57701 .37214 L .57326 .37585 L p F P
0 g
s
.618 .622 .833 r
.585 .37571 m .58229 .37133 L p .57326 .37585 L F P
0 g
s
.917 .979 .734 r
.7663 .26608 m .7653 .26617 L .76692 .2638 L closepath p F P
0 g
s
.893 .741 .685 r
.24342 .36001 m .24443 .35787 L .24783 .36117 L p F P
0 g
s
.893 .741 .685 r
.24783 .36117 m .24659 .36377 L .24342 .36001 L p F P
0 g
s
.89 .92 .527 r
.77881 .2373 m .77775 .24209 L .78009 .23678 L p F P
0 g
s
.89 .92 .527 r
.78074 .23297 m .77881 .2373 L p .78009 .23678 L F P
0 g
s
.89 .92 .527 r
.78009 .23678 m .78103 .23269 L .78074 .23297 L p F P
0 g
s
.811 .927 .911 r
.69568 .33912 m .69523 .33887 L .69618 .33815 L closepath p F P
0 g
s
.797 .912 .918 r
.68457 .34641 m .68231 .34498 L .68718 .34154 L closepath p F P
0 g
s
.916 .972 .682 r
.61428 .25271 m .61146 .25728 L .61244 .25358 L closepath p F P
0 g
s
.816 .802 .311 r
.78375 .22214 m .78295 .22687 L .78432 .22191 L p F P
0 g
s
.816 .802 .311 r
.78432 .22191 m .78516 .21717 L .78375 .22214 L p F P
0 g
s
.647 .698 .883 r
.74971 .13565 m .73884 .1387 L .73639 .13496 L p F P
0 g
s
.692 .734 .883 r
.72566 .13959 m .73639 .13496 L .73884 .1387 L p F P
0 g
s
.637 .689 .881 r
.73884 .1387 m .74971 .13565 L .75217 .13976 L p F P
0 g
s
.572 .652 .89 r
.75217 .13976 m .75293 .13967 L .75313 .1414 L closepath p F P
0 g
s
.533 .629 .893 r
.76325 .13897 m .75293 .13967 L .75313 .1414 L p F P
0 g
s
.533 .629 .893 r
.76574 .14365 m .76325 .13897 L p .75313 .1414 L F P
0 g
s
.874 .897 .846 r
.65978 .18529 m .65799 .18402 L .66004 .18188 L closepath p F P
0 g
s
.774 .812 .883 r
.70176 .1487 m .69958 .1461 L .70189 .14455 L closepath p F P
0 g
s
.905 .911 .816 r
.65019 .19728 m .64835 .19953 L .64845 .19629 L closepath p F P
0 g
s
.663 .759 .921 r
.58769 .37955 m .59824 .37597 L .60089 .37903 L p F P
0 g
s
.645 .732 .912 r
.59824 .37597 m .58769 .37955 L .585 .37571 L p F P
0 g
s
.7 .74 .883 r
.73639 .13496 m .72566 .13959 L .72321 .13614 L p F P
0 g
s
.682 .786 .929 r
.61143 .37468 m .60089 .37903 L .59824 .37597 L p F P
0 g
s
.765 .893 .934 r
.66127 .35881 m .65824 .36065 L .66009 .358 L closepath p F P
0 g
s
.761 .879 .932 r
.65878 .35703 m .66009 .358 L .65824 .36065 L p F P
0 g
s
.761 .879 .932 r
.64823 .36324 m .65878 .35703 L p .65824 .36065 L F P
0 g
s
.935 .956 .764 r
.6297 .22341 m .62922 .22411 L .62854 .2289 L p F P
0 g
s
.937 .957 .758 r
.62526 .22997 m .62429 .23485 L .62854 .2289 L p F P
0 g
s
.937 .957 .758 r
.62854 .2289 m .62922 .22411 L .62526 .22997 L p F P
0 g
s
.492 .569 .861 r
.76603 .14837 m .76625 .14464 L .76824 .14857 L closepath p F P
0 g
s
.801 .834 .876 r
.69041 .15563 m .68911 .1542 L .69049 .15314 L closepath p F P
0 g
s
.908 .913 .811 r
.64363 .20107 m .64322 .20579 L .64835 .19953 L p F P
0 g
s
.908 .913 .811 r
.6477 .19588 m .64363 .20107 L p .64835 .19953 L F P
0 g
s
.908 .913 .811 r
.64835 .19953 m .64845 .19629 L .6477 .19588 L p F P
0 g
s
0 0 .117 r
.58227 .31682 m .58015 .32008 L .58079 .31658 L p F P
0 g
s
0 0 .117 r
.58079 .31658 m .58394 .31173 L .58227 .31682 L p F P
0 g
s
.917 .975 .7 r
.76815 .25898 m .76692 .2638 L .77056 .25801 L p F P
0 g
s
.917 .975 .7 r
.77056 .25801 m .77186 .25317 L .76815 .25898 L p F P
0 g
s
.342 .254 .609 r
.57462 .35194 m .5706 .35664 L .56759 .35315 L p F P
0 g
s
.342 .254 .609 r
.57391 .34825 m .57462 .35194 L p .56759 .35315 L F P
0 g
s
.342 .254 .609 r
.56759 .35315 m .57303 .34691 L .57391 .34825 L p F P
0 g
s
.891 .979 .818 r
.74729 .28878 m .75297 .28226 L .7513 .28718 L p F P
0 g
s
.891 .979 .818 r
.74632 .29176 m .74729 .28878 L p .7513 .28718 L F P
0 g
s
.891 .979 .818 r
.7513 .28718 m .74719 .29193 L .74632 .29176 L p F P
0 g
s
0 .063 .59 r
.7867 .17642 m .7863 .1811 L .78438 .17738 L p F P
0 g
s
0 .063 .59 r
.78438 .17738 m .78475 .17272 L .7867 .17642 L p F P
0 g
s
.904 .978 .795 r
.75694 .27981 m .7552 .27956 L .7581 .27593 L closepath p F P
0 g
s
.825 .936 .902 r
.70618 .33102 m .70569 .33076 L .70669 .32996 L closepath p F P
0 g
s
.923 .961 .646 r
.77437 .25046 m .77313 .25098 L .77504 .24754 L closepath p F P
0 g
s
.174 .042 .449 r
.57312 .34129 m .57191 .34277 L .57185 .33828 L p F P
0 g
s
.174 .042 .449 r
.57185 .33828 m .57304 .33682 L .57312 .34129 L p F P
0 g
s
0 0 0 r
.5888 .30005 m .58823 .30124 L .58854 .30066 L closepath p F P
0 g
s
.921 .731 .629 r
.24116 .3545 m .24443 .35787 L .24602 .3529 L p F P
0 g
s
.921 .731 .629 r
.24602 .3529 m .24275 .34953 L .24116 .3545 L p F P
0 g
s
.812 .923 .91 r
.69618 .33815 m .69523 .33887 L .69282 .33745 L p F P
0 g
s
.859 .749 .74 r
.24454 .36677 m .24659 .36377 L .24342 .36001 L p F P
0 g
s
.572 .536 .776 r
.56937 .3666 m .57171 .37257 L .57701 .37214 L p F P
0 g
s
.817 .931 .907 r
.69618 .33815 m .70569 .33076 L .70331 .32944 L p F P
0 g
s
.817 .931 .907 r
.70331 .32944 m .69876 .33297 L .69618 .33815 L p F P
0 g
s
.812 .923 .91 r
.69282 .33745 m .69876 .33297 L .69618 .33815 L p F P
0 g
s
.776 .894 .927 r
.66932 .3504 m .67179 .35211 L .66127 .35881 L p F P
0 g
s
.776 .894 .927 r
.6618 .35516 m .66932 .3504 L p .66127 .35881 L F P
0 g
s
.776 .894 .927 r
.66127 .35881 m .66009 .358 L .6618 .35516 L p F P
0 g
s
.745 .854 .93 r
.64284 .36626 m .63769 .36908 L .63514 .36695 L p F P
0 g
s
.73 .851 .938 r
.62459 .37233 m .63514 .36695 L .63769 .36908 L p F P
0 g
s
.784 .901 .924 r
.67276 .35275 m .67179 .35211 L .67397 .35067 L closepath p F P
0 g
s
.5 .424 .702 r
.5761 .35927 m .5706 .35664 L .56754 .35992 L p F P
0 g
s
.5 .424 .702 r
.57036 .36559 m .5761 .35927 L p .56754 .35992 L F P
0 g
s
.5 .424 .702 r
.56754 .35992 m .56893 .3652 L .57036 .36559 L p F P
0 g
s
.715 .857 .434 r
.59872 .27966 m .60156 .27418 L .59948 .27939 L p F P
0 g
s
.715 .857 .434 r
.5964 .28485 m .59872 .27966 L p .59948 .27939 L F P
0 g
s
.715 .857 .434 r
.59948 .27939 m .59646 .28478 L .5964 .28485 L p F P
0 g
s
0 0 0 r
.78684 .20764 m .78662 .20946 L .78689 .20611 L p F P
0 g
s
0 0 0 r
.78689 .20611 m .78726 .20304 L .78684 .20764 L p F P
0 g
s
0 0 0 r
.58752 .30363 m .58595 .30653 L .58823 .30124 L p F P
0 g
s
0 0 0 r
.58823 .30124 m .58854 .30066 L .58752 .30363 L p F P
0 g
s
.883 .981 .825 r
.74719 .29193 m .74559 .29371 L .74632 .29176 L closepath p F P
0 g
s
.914 .968 .664 r
.6095 .25793 m .60799 .26296 L .61146 .25728 L p F P
0 g
s
.914 .968 .664 r
.6118 .25394 m .6095 .25793 L p .61146 .25728 L F P
0 g
s
.914 .968 .664 r
.61146 .25728 m .61244 .25358 L .6118 .25394 L p F P
0 g
s
.583 .662 .892 r
.75293 .13967 m .75217 .13976 L .74971 .13565 L p F P
0 g
s
0 0 .128 r
.78775 .19838 m .78726 .20304 L .78719 .19862 L p F P
0 g
s
0 0 .128 r
.78719 .19862 m .78769 .19396 L .78775 .19838 L p F P
0 g
s
.109 .213 .692 r
.78509 .16805 m .78475 .17272 L .78198 .16933 L p F P
0 g
s
.109 .213 .692 r
.78198 .16933 m .78226 .16468 L .78509 .16805 L p F P
0 g
s
.739 .786 .891 r
.71936 .13831 m .71259 .14211 L .71013 .13892 L p F P
0 g
s
.875 .971 .847 r
.74101 .29551 m .73922 .30047 L .74559 .29371 L p F P
0 g
s
.875 .971 .847 r
.74495 .29134 m .74101 .29551 L p .74559 .29371 L F P
0 g
s
.875 .971 .847 r
.74559 .29371 m .74632 .29176 L .74495 .29134 L p F P
0 g
s
.409 .506 .846 r
.76824 .14857 m .77342 .15001 L .77346 .15457 L p F P
0 g
s
.336 .441 .821 r
.77874 .15243 m .7786 .15707 L .77346 .15457 L p F P
0 g
s
.336 .441 .821 r
.77346 .15457 m .77342 .15001 L .77874 .15243 L p F P
0 g
s
.717 .829 .934 r
.62459 .37233 m .62066 .37419 L .62328 .37114 L closepath p F P
0 g
s
.714 .808 .924 r
.622 .36993 m .62328 .37114 L .62066 .37419 L p F P
0 g
s
.714 .808 .924 r
.61143 .37468 m .622 .36993 L p .62066 .37419 L F P
0 g
s
.907 .938 .818 r
.63869 .20728 m .64363 .20107 L .64322 .20579 L p F P
0 g
s
.907 .938 .818 r
.63844 .20921 m .63869 .20728 L p .64322 .20579 L F P
0 g
s
.907 .938 .818 r
.64322 .20579 m .63993 .20978 L .63844 .20921 L p F P
0 g
s
.819 .755 .793 r
.23459 .37027 m .23798 .37357 L .24454 .36677 L p F P
0 g
s
.819 .755 .793 r
.24454 .36677 m .24107 .3635 L .23459 .37027 L p F P
0 g
s
.859 .749 .74 r
.24342 .36001 m .24107 .3635 L .24454 .36677 L p F P
0 g
s
.234 .339 .767 r
.78252 .1601 m .78226 .16468 L .77844 .16168 L p F P
0 g
s
.234 .339 .767 r
.78247 .15998 m .78252 .1601 L p .77844 .16168 L F P
0 g
s
.234 .339 .767 r
.77844 .16168 m .7786 .15707 L .78247 .15998 L p F P
0 g
s
.583 .662 .892 r
.74971 .13565 m .75235 .13527 L .75293 .13967 L p F P
0 g
s
.555 .624 .876 r
.76076 .13441 m .75235 .13527 L .75293 .13967 L p F P
0 g
s
.555 .624 .876 r
.75293 .13967 m .76325 .13897 L .76076 .13441 L p F P
0 g
s
.92 .977 .755 r
.62126 .23584 m .62526 .22997 L .62429 .23485 L p F P
0 g
s
.92 .977 .755 r
.62071 .23825 m .62126 .23584 L p .62429 .23485 L F P
0 g
s
.92 .977 .755 r
.62429 .23485 m .62198 .23809 L .62071 .23825 L p F P
0 g
s
.825 .932 .902 r
.70669 .32996 m .70569 .33076 L .70331 .32944 L p F P
0 g
s
.486 .444 .736 r
.56893 .3652 m .57036 .36559 L .56937 .3666 L closepath p F P
0 g
s
.572 .536 .776 r
.57955 .36609 m .57036 .36559 L .56937 .3666 L p F P
0 g
s
.572 .536 .776 r
.58061 .36825 m .57955 .36609 L p .56937 .3666 L F P
0 g
s
.572 .536 .776 r
.57701 .37214 m .58061 .36825 L p .56937 .3666 L F P
0 g
s
.914 .945 .594 r
.77605 .24278 m .77504 .24754 L .77775 .24209 L p F P
0 g
s
.914 .945 .594 r
.77775 .24209 m .77881 .2373 L .77605 .24278 L p F P
0 g
s
.831 .94 .897 r
.70669 .32996 m .71613 .32213 L .71378 .32092 L p F P
0 g
s
.831 .94 .897 r
.71378 .32092 m .70903 .32485 L .70669 .32996 L p F P
0 g
s
.825 .932 .902 r
.70331 .32944 m .70903 .32485 L .70669 .32996 L p F P
0 g
s
0 0 0 r
.58893 .30104 m .58752 .30363 L .58854 .30066 L p F P
0 g
s
0 0 0 r
.58854 .30066 m .59121 .29574 L .58893 .30104 L p F P
0 g
s
.396 .513 .859 r
.76625 .14464 m .76824 .14857 L .77342 .15001 L p F P
0 g
s
0 0 .214 r
.57969 .32383 m .57722 .3275 L .57849 .32255 L p F P
0 g
s
0 0 .214 r
.57849 .32255 m .58015 .32008 L .57969 .32383 L p F P
0 g
s
.872 .966 .855 r
.73462 .30204 m .74101 .29551 L .73922 .30047 L p F P
0 g
s
.872 .966 .855 r
.73922 .30047 m .7369 .30283 L .73462 .30204 L p F P
0 g
s
.787 .759 .828 r
.23798 .37357 m .23608 .37513 L .23287 .3717 L p F P
0 g
s
.721 .749 .874 r
.22278 .37709 m .23287 .3717 L .23608 .37513 L p F P
0 g
s
.918 .979 .735 r
.76412 .26492 m .76815 .25898 L .76692 .2638 L p F P
0 g
s
.918 .979 .735 r
.76378 .26629 m .76412 .26492 L p .76692 .2638 L F P
0 g
s
.918 .979 .735 r
.76692 .2638 m .7653 .26617 L .76378 .26629 L p F P
0 g
s
.922 .93 .796 r
.63993 .20978 m .63826 .212 L .63844 .20921 L closepath p F P
0 g
s
.745 .854 .93 r
.6457 .36127 m .6462 .36168 L .64284 .36626 L p F P
0 g
s
.745 .854 .93 r
.63514 .36695 m .6457 .36127 L p .64284 .36626 L F P
0 g
s
.749 .871 .936 r
.64823 .36324 m .64284 .36626 L .6462 .36168 L closepath p F P
0 g
s
.787 .759 .828 r
.23287 .3717 m .23459 .37027 L .23798 .37357 L p F P
0 g
s
.865 .968 .861 r
.73219 .30745 m .7369 .30283 L .73462 .30204 L p F P
0 g
s
.738 .711 .178 r
.78596 .21242 m .78516 .21717 L .78612 .21236 L p F P
0 g
s
.738 .711 .178 r
.78603 .21206 m .78596 .21242 L p .78612 .21236 L F P
0 g
s
.738 .711 .178 r
.78612 .21236 m .78662 .20946 L .78603 .21206 L p F P
0 g
s
.648 .734 .912 r
.20965 .37694 m .21955 .37372 L .22278 .37709 L p F P
0 g
s
.147 .023 .442 r
.57662 .33675 m .57312 .34129 L .57304 .33682 L p F P
0 g
s
.147 .023 .442 r
.57304 .33682 m .57654 .33226 L .57662 .33675 L p F P
0 g
s
.838 .945 .892 r
.71614 .32214 m .71613 .32213 L .71614 .32213 L closepath p F P
0 g
s
.838 .94 .891 r
.71614 .32213 m .71613 .32213 L .71378 .32092 L p F P
0 g
s
.841 .949 .888 r
.71825 .31709 m .71614 .32213 L .72455 .31466 L p F P
0 g
s
.838 .94 .891 r
.71378 .32092 m .71825 .31709 L .71614 .32213 L p F P
0 g
s
.827 .854 .867 r
.68145 .16086 m .67869 .16322 L .67621 .16078 L p F P
0 g
s
.856 .864 .846 r
.67361 .16813 m .67869 .16322 L .67621 .16078 L p F P
0 g
s
.865 .968 .861 r
.73462 .30204 m .73424 .30242 L .73219 .30745 L p F P
0 g
s
.859 .96 .87 r
.72661 .30963 m .73424 .30242 L .73219 .30745 L p F P
0 g
s
.859 .96 .87 r
.72553 .31244 m .72661 .30963 L p .73219 .30745 L F P
0 g
s
.859 .96 .87 r
.73219 .30745 m .72654 .31283 L .72553 .31244 L p F P
0 g
s
.878 .872 .431 r
.78194 .22727 m .78116 .23198 L .78295 .22687 L p F P
0 g
s
.878 .872 .431 r
.78295 .22687 m .78375 .22214 L .78194 .22727 L p F P
0 g
s
.936 .966 .737 r
.62198 .23809 m .62026 .24073 L .62071 .23825 L closepath p F P
0 g
s
.834 .851 .858 r
.68145 .16086 m .68911 .1542 L .68664 .1515 L p F P
0 g
s
.834 .851 .858 r
.68664 .1515 m .68131 .15628 L .68145 .16086 L p F P
0 g
s
.827 .854 .867 r
.67621 .16078 m .68131 .15628 L .68145 .16086 L p F P
0 g
s
.851 .961 .877 r
.72654 .31283 m .72455 .31466 L .72553 .31244 L closepath p F P
0 g
s
.841 .949 .888 r
.72422 .31181 m .71825 .31709 L p .72455 .31466 L F P
0 g
s
.841 .949 .888 r
.72455 .31466 m .72553 .31244 L .72422 .31181 L p F P
0 g
s
.856 .864 .846 r
.67621 .16078 m .6734 .16358 L .67361 .16813 L p F P
0 g
s
.85 .873 .857 r
.66623 .17061 m .6734 .16358 L .67361 .16813 L p F P
0 g
s
.85 .873 .857 r
.66621 .17131 m .66623 .17061 L p .67361 .16813 L F P
0 g
s
.85 .873 .857 r
.67361 .16813 m .66832 .17315 L .66621 .17131 L p F P
0 g
s
.726 .831 .93 r
.63257 .36472 m .63514 .36695 L .62459 .37233 L p F P
0 g
s
.726 .831 .93 r
.62523 .36836 m .63257 .36472 L p .62459 .37233 L F P
0 g
s
.726 .831 .93 r
.62459 .37233 m .62328 .37114 L .62523 .36836 L p F P
0 g
s
.926 .932 .79 r
.63425 .2133 m .63375 .21805 L .63826 .212 L p F P
0 g
s
.926 .932 .79 r
.63744 .20886 m .63425 .2133 L p .63826 .212 L F P
0 g
s
.926 .932 .79 r
.63826 .212 m .63844 .20921 L .63744 .20886 L p F P
0 g
s
.91 .982 .742 r
.7653 .26617 m .76274 .26978 L .76378 .26629 L closepath p F P
0 g
s
.869 .871 .836 r
.66832 .17315 m .66644 .17515 L .66621 .17131 L closepath p F P
0 g
s
.801 .834 .876 r
.69049 .15314 m .68911 .1542 L .68664 .1515 L p F P
0 g
s
.784 .896 .923 r
.67397 .35067 m .67179 .35211 L .66932 .3504 L p F P
0 g
s
.873 .873 .833 r
.66013 .17724 m .66004 .18188 L .66644 .17515 L p F P
0 g
s
.873 .873 .833 r
.66584 .17099 m .66013 .17724 L p .66644 .17515 L F P
0 g
s
.873 .873 .833 r
.66644 .17515 m .66621 .17131 L .66584 .17099 L p F P
0 g
s
.754 .87 .445 r
.59646 .28478 m .59636 .28496 L .5964 .28485 L closepath p F P
0 g
s
.722 .752 .876 r
.23287 .3717 m .22278 .37709 L .21955 .37372 L p F P
0 g
s
.81 .834 .869 r
.69049 .15314 m .69958 .1461 L .69712 .14315 L p F P
0 g
s
.81 .834 .869 r
.69712 .14315 m .69039 .14854 L .69049 .15314 L p F P
0 g
s
.801 .834 .876 r
.68664 .1515 m .69039 .14854 L .69049 .15314 L p F P
0 g
s
.53 .524 .793 r
.57678 .35941 m .5761 .35927 L .57036 .36559 L p F P
0 g
s
.53 .524 .793 r
.57036 .36559 m .57955 .36609 L .57678 .35941 L p F P
0 g
s
0 0 .3 r
.78814 .18929 m .78769 .19396 L .78708 .18974 L p F P
0 g
s
0 0 .3 r
.78708 .18974 m .78753 .18507 L .78814 .18929 L p F P
0 g
s
.72 .833 .387 r
.59502 .28729 m .5937 .29038 L .59636 .28496 L p F P
0 g
s
.72 .833 .387 r
.59636 .28496 m .5964 .28485 L .59502 .28729 L p F P
0 g
s
.888 .954 .608 r
.60636 .26351 m .60456 .26864 L .60799 .26296 L p F P
0 g
s
.888 .954 .608 r
.60799 .26296 m .6095 .25793 L .60636 .26351 L p F P
0 g
s
.706 .828 .381 r
.596 .28511 m .59502 .28729 L .5964 .28485 L p F P
0 g
s
.706 .828 .381 r
.5964 .28485 m .59872 .27966 L .596 .28511 L p F P
0 g
s
.745 .779 .88 r
.71936 .13831 m .72321 .13614 L .72075 .1327 L p F P
0 g
s
.745 .779 .88 r
.72075 .1327 m .71873 .1339 L .71936 .13831 L p F P
0 g
s
.739 .786 .891 r
.71013 .13892 m .71873 .1339 L .71936 .13831 L p F P
0 g
s
.769 .883 .928 r
.66009 .358 m .65878 .35703 L .6618 .35516 L closepath p F P
0 g
s
.788 .905 .923 r
.67397 .35067 m .68231 .34498 L .67986 .34341 L p F P
0 g
s
.788 .905 .923 r
.67986 .34341 m .67699 .34535 L .67397 .35067 L p F P
0 g
s
.784 .896 .923 r
.66932 .3504 m .67699 .34535 L .67397 .35067 L p F P
0 g
s
.938 .966 .725 r
.61756 .24161 m .61655 .2465 L .62026 .24073 L p F P
0 g
s
.938 .966 .725 r
.61949 .23847 m .61756 .24161 L p .62026 .24073 L F P
0 g
s
.938 .966 .725 r
.62026 .24073 m .62071 .23825 L .61949 .23847 L p F P
0 g
s
.899 .747 .684 r
.24023 .3565 m .24116 .3545 L .24443 .35787 L p F P
0 g
s
.899 .747 .684 r
.24443 .35787 m .24342 .36001 L .24023 .3565 L p F P
0 g
s
0 0 0 r
.58662 .30677 m .58394 .31173 L .58595 .30653 L p F P
0 g
s
0 0 0 r
.58595 .30653 m .58752 .30363 L .58662 .30677 L p F P
0 g
s
.759 .873 .93 r
.65627 .35511 m .65878 .35703 L .64823 .36324 L p F P
0 g
s
.759 .873 .93 r
.64687 .36061 m .65627 .35511 L p .64823 .36324 L F P
0 g
s
.759 .873 .93 r
.64823 .36324 m .6462 .36168 L .64687 .36061 L p F P
0 g
s
.645 .732 .912 r
.585 .37571 m .59557 .37261 L .59824 .37597 L p F P
0 g
s
.62 .698 .901 r
.59557 .37261 m .585 .37571 L .58229 .37133 L p F P
0 g
s
.873 .895 .846 r
.6555 .18221 m .66013 .17724 L .66004 .18188 L p F P
0 g
s
.873 .895 .846 r
.66004 .18188 m .65799 .18402 L .6555 .18221 L p F P
0 g
s
.907 .98 .782 r
.75948 .27108 m .7581 .27593 L .76274 .26978 L p F P
0 g
s
.907 .98 .782 r
.76316 .26623 m .75948 .27108 L p .76274 .26978 L F P
0 g
s
.907 .98 .782 r
.76274 .26978 m .76378 .26629 L .76316 .26623 L p F P
0 g
s
.886 .968 .837 r
.74632 .29176 m .74495 .29134 L .74729 .28878 L closepath p F P
0 g
s
.898 .897 .818 r
.65422 .1884 m .65799 .18402 L .6555 .18221 L p F P
0 g
s
.647 .698 .883 r
.73639 .13496 m .74725 .13161 L .74971 .13565 L p F P
0 g
s
.657 .706 .884 r
.74725 .13161 m .73639 .13496 L .73394 .13125 L p F P
0 g
s
.7 .74 .883 r
.72321 .13614 m .73394 .13125 L .73639 .13496 L p F P
0 g
s
.895 .919 .83 r
.64845 .19629 m .6477 .19588 L .64859 .19486 L closepath p F P
0 g
s
.699 .807 .932 r
.622 .36993 m .61143 .37468 L .60881 .37189 L p F P
0 g
s
.682 .786 .929 r
.59824 .37597 m .60881 .37189 L .61143 .37468 L p F P
0 g
s
.593 .618 .846 r
.57701 .37214 m .58061 .36825 L .58229 .37133 L closepath p F P
0 g
s
.924 .961 .648 r
.77293 .24838 m .77605 .24278 L .77504 .24754 L p F P
0 g
s
.924 .961 .648 r
.77233 .2513 m .77293 .24838 L p .77504 .24754 L F P
0 g
s
.924 .961 .648 r
.77504 .24754 m .77313 .25098 L .77233 .2513 L p F P
0 g
s
.774 .812 .883 r
.70189 .14455 m .69958 .1461 L .69712 .14315 L p F P
0 g
s
.255 .15 .536 r
.57358 .34624 m .57303 .34691 L .57191 .34277 L p F P
0 g
s
.255 .15 .536 r
.57191 .34277 m .57312 .34129 L .57358 .34624 L p F P
0 g
s
.922 .958 .79 r
.62995 .21929 m .63425 .2133 L .63375 .21805 L p F P
0 g
s
.922 .958 .79 r
.6293 .22335 m .62995 .21929 L p .63375 .21805 L F P
0 g
s
.922 .958 .79 r
.63375 .21805 m .6297 .22341 L .6293 .22335 L p F P
0 g
s
.907 .916 .522 r
.78103 .23269 m .78074 .23297 L .78116 .23198 L closepath p F P
0 g
s
.707 .746 .882 r
.73394 .13125 m .72321 .13614 L .72075 .1327 L p F P
0 g
s
.396 .513 .859 r
.77337 .14543 m .76619 .14372 L .76625 .14464 L p F P
0 g
s
.396 .513 .859 r
.77342 .15001 m .77337 .14543 L p .76625 .14464 L F P
0 g
s
.463 .56 .868 r
.76574 .14365 m .76619 .14372 L .76625 .14464 L closepath p F P
0 g
s
.668 .766 .923 r
.60881 .37189 m .59824 .37597 L .59557 .37261 L p F P
0 g
s
.83 .933 .558 r
.60436 .26915 m .60412 .2694 L .60456 .26864 L closepath p F P
0 g
s
.782 .812 .876 r
.70189 .14455 m .71013 .13892 L .70766 .13574 L p F P
0 g
s
.782 .812 .876 r
.70766 .13574 m .70167 .13997 L .70189 .14455 L p F P
0 g
s
.774 .812 .883 r
.69712 .14315 m .70167 .13997 L .70189 .14455 L p F P
0 g
s
.865 .757 .742 r
.24107 .3635 m .24342 .36001 L .24023 .3565 L p F P
0 g
s
0 0 .46 r
.78795 .1804 m .78753 .18507 L .7863 .1811 L p F P
0 g
s
0 0 .46 r
.7863 .1811 m .7867 .17642 L .78795 .1804 L p F P
0 g
s
.898 .897 .818 r
.6555 .18221 m .65416 .18382 L .65422 .1884 L p F P
0 g
s
.897 .897 .819 r
.64886 .19016 m .64859 .19486 L .65422 .1884 L p F P
0 g
s
.897 .897 .819 r
.65422 .1884 m .65416 .18382 L .64886 .19016 L p F P
0 g
s
0 0 0 r
.78732 .20299 m .78684 .20764 L .78726 .20304 L p F P
0 g
s
0 0 0 r
.78726 .20304 m .78775 .19838 L .78732 .20299 L p F P
0 g
s
0 0 .314 r
.57947 .32789 m .57654 .33226 L .57722 .3275 L p F P
0 g
s
0 0 .314 r
.57722 .3275 m .57969 .32383 L .57947 .32789 L p F P
0 g
s
.798 .909 .917 r
.68718 .34154 m .68231 .34498 L .67986 .34341 L p F P
0 g
s
0 0 .208 r
.58104 .32176 m .57969 .32383 L .58015 .32008 L p F P
0 g
s
0 0 .208 r
.58015 .32008 m .58227 .31682 L .58104 .32176 L p F P
0 g
s
.476 .573 .874 r
.76619 .14372 m .76574 .14365 L .76325 .13897 L p F P
0 g
s
.441 .397 .713 r
.57654 .35875 m .5761 .35927 L .5706 .35664 L p F P
0 g
s
.441 .397 .713 r
.5706 .35664 m .57462 .35194 L .57654 .35875 L p F P
0 g
s
.828 .932 .556 r
.60327 .26908 m .60636 .26351 L .60456 .26864 L p F P
0 g
s
.828 .932 .556 r
.60258 .27102 m .60327 .26908 L p .60456 .26864 L F P
0 g
s
.828 .932 .556 r
.60456 .26864 m .60412 .2694 L .60258 .27102 L p F P
0 g
s
.909 .917 .525 r
.77973 .23254 m .78194 .22727 L .78116 .23198 L p F P
0 g
s
.909 .917 .525 r
.77947 .23418 m .77973 .23254 L p .78116 .23198 L F P
0 g
s
.909 .917 .525 r
.78116 .23198 m .78074 .23297 L .77947 .23418 L p F P
0 g
s
.593 .669 .892 r
.75235 .13527 m .74971 .13565 L .74725 .13161 L p F P
0 g
s
.905 .978 .795 r
.75446 .27737 m .75948 .27108 L .7581 .27593 L p F P
0 g
s
.905 .978 .795 r
.75391 .27937 m .75446 .27737 L p .7581 .27593 L F P
0 g
s
.905 .978 .795 r
.7581 .27593 m .7552 .27956 L .75391 .27937 L p F P
0 g
s
.933 .968 .694 r
.61413 .2473 m .61284 .25228 L .61655 .2465 L p F P
0 g
s
.933 .968 .694 r
.61655 .2465 m .61756 .24161 L .61413 .2473 L p F P
0 g
s
.722 .824 .929 r
.62328 .37114 m .622 .36993 L .62523 .36836 L closepath p F P
0 g
s
.83 .814 .33 r
.78451 .21741 m .78375 .22214 L .78516 .21717 L p F P
0 g
s
.83 .814 .33 r
.78516 .21717 m .78596 .21242 L .78451 .21741 L p F P
0 g
s
.916 .965 .654 r
.77313 .25098 m .77186 .25317 L .77233 .2513 L closepath p F P
0 g
s
.852 .948 .879 r
.72553 .31244 m .72422 .31181 L .72661 .30963 L closepath p F P
0 g
s
.861 .934 .558 r
.60412 .2694 m .60156 .27418 L .60258 .27102 L closepath p F P
0 g
s
.668 .756 .268 r
.59349 .29048 m .59373 .28988 L .5936 .29019 L p F P
0 g
s
.691 .801 .338 r
.59349 .29048 m .59121 .29574 L .59283 .29225 L p F P
0 g
s
0 0 0 r
.59121 .29574 m .59349 .29048 L .59144 .2957 L p F P
0 g
s
.668 .756 .268 r
.5936 .29019 m .5926 .2927 L p .59349 .29048 L F P
0 g
s
.691 .801 .338 r
.59283 .29225 m .5937 .29038 L p .59349 .29048 L F P
0 g
s
.691 .801 .338 r
.59401 .28931 m .59349 .29048 L p .5937 .29038 L F P
0 g
s
.691 .801 .338 r
.5937 .29038 m .59502 .28729 L .59401 .28931 L p F P
0 g
s
.429 .535 .863 r
.77333 .14083 m .77337 .14543 L .76619 .14372 L p F P
0 g
s
.429 .535 .863 r
.76619 .14372 m .76582 .13924 L .77333 .14083 L p F P
0 g
s
.476 .573 .874 r
.76325 .13897 m .76582 .13924 L .76619 .14372 L p F P
0 g
s
.936 .947 .768 r
.6297 .22341 m .62922 .22411 L .6293 .22335 L closepath p F P
0 g
s
.899 .92 .528 r
.78074 .23297 m .77881 .2373 L .77947 .23418 L closepath p F P
0 g
s
.901 .973 .671 r
.61244 .25358 m .6118 .25394 L .61284 .25228 L closepath p F P
0 g
s
.802 .919 .917 r
.68718 .34154 m .69282 .33745 L .6904 .33599 L p F P
0 g
s
.802 .919 .917 r
.6904 .33599 m .69002 .33627 L .68718 .34154 L p F P
0 g
s
.798 .909 .917 r
.67986 .34341 m .69002 .33627 L .68718 .34154 L p F P
0 g
s
.895 .917 .83 r
.6452 .19448 m .64886 .19016 L .64859 .19486 L p F P
0 g
s
.895 .917 .83 r
.64859 .19486 m .6477 .19588 L .6452 .19448 L p F P
0 g
s
.822 .762 .795 r
.23131 .36692 m .23459 .37027 L .24107 .3635 L p F P
0 g
s
.822 .762 .795 r
.24107 .3635 m .23777 .36015 L .23131 .36692 L p F P
0 g
s
.865 .757 .742 r
.24023 .3565 m .23777 .36015 L .24107 .3635 L p F P
0 g
s
.776 .725 .195 r
.78662 .20946 m .78603 .21206 L .78684 .20764 L closepath p F P
0 g
s
.939 .949 .76 r
.62583 .22521 m .62526 .22997 L .62922 .22411 L p F P
0 g
s
.939 .949 .76 r
.6272 .22311 m .62583 .22521 L p .62922 .22411 L F P
0 g
s
.939 .949 .76 r
.62922 .22411 m .6293 .22335 L .6272 .22311 L p F P
0 g
s
.918 .916 .8 r
.64363 .20107 m .6477 .19588 L .6452 .19448 L p F P
0 g
s
0 .086 .607 r
.78686 .17425 m .7867 .17642 L .78475 .17272 L p F P
0 g
s
0 .086 .607 r
.78525 .16833 m .78686 .17425 L p .78475 .17272 L F P
0 g
s
0 .086 .607 r
.78475 .17272 m .78509 .16805 L .78525 .16833 L p F P
0 g
s
.898 .98 .803 r
.7552 .27956 m .75297 .28226 L .75391 .27937 L closepath p F P
0 g
s
.235 .136 .532 r
.57772 .3409 m .57358 .34624 L .57312 .34129 L p F P
0 g
s
.235 .136 .532 r
.57312 .34129 m .57662 .33675 L .57772 .3409 L p F P
0 g
s
.737 .852 .934 r
.6457 .36127 m .63514 .36695 L .63257 .36472 L p F P
0 g
s
.746 .789 .888 r
.71873 .1339 m .71013 .13892 L .70766 .13574 L p F P
0 g
s
.914 .939 .808 r
.63844 .20921 m .63744 .20886 L .63869 .20728 L closepath p F P
0 g
s
.922 .975 .714 r
.76934 .25417 m .76815 .25898 L .77186 .25317 L p F P
0 g
s
.922 .975 .714 r
.77104 .25148 m .76934 .25417 L p .77186 .25317 L F P
0 g
s
.922 .975 .714 r
.77186 .25317 m .77233 .2513 L .77104 .25148 L p F P
0 g
s
0 0 .031 r
.58536 .31131 m .58227 .31682 L .58394 .31173 L p F P
0 g
s
0 0 .031 r
.58641 .30781 m .58536 .31131 L p .58394 .31173 L F P
0 g
s
0 0 .031 r
.58394 .31173 m .58662 .30677 L .58641 .30781 L p F P
0 g
s
.769 .877 .926 r
.6618 .35516 m .65878 .35703 L .65627 .35511 L p F P
0 g
s
.79 .762 .828 r
.23459 .37027 m .23287 .3717 L .22964 .36831 L p F P
0 g
s
.722 .752 .876 r
.21955 .37372 m .22964 .36831 L .23287 .3717 L p F P
0 g
s
.927 .974 .737 r
.62071 .23825 m .61949 .23847 L .62126 .23584 L closepath p F P
0 g
s
.89 .972 .829 r
.74881 .28389 m .74729 .28878 L .75297 .28226 L p F P
0 g
s
.89 .972 .829 r
.75299 .27911 m .74881 .28389 L p .75297 .28226 L F P
0 g
s
.89 .972 .829 r
.75297 .28226 m .75391 .27937 L .75299 .27911 L p F P
0 g
s
.79 .762 .828 r
.22964 .36831 m .23131 .36692 L .23459 .37027 L p F P
0 g
s
.811 .921 .91 r
.69876 .33297 m .69282 .33745 L .6904 .33599 L p F P
0 g
s
.107 .213 .692 r
.7851 .16782 m .78509 .16805 L .78226 .16468 L p F P
0 g
s
.107 .213 .692 r
.78226 .16468 m .78252 .1601 L .7851 .16782 L p F P
0 g
s
.354 .458 .828 r
.77878 .15061 m .77874 .15243 L .77342 .15001 L p F P
0 g
s
.354 .458 .828 r
.77721 .14699 m .77878 .15061 L p .77342 .15001 L F P
0 g
s
.354 .458 .828 r
.77342 .15001 m .77337 .14543 L .77721 .14699 L p F P
0 g
s
.929 .957 .777 r
.6293 .22335 m .6272 .22311 L .62995 .21929 L closepath p F P
0 g
s
0 0 .117 r
.7882 .19371 m .78775 .19838 L .78769 .19396 L p F P
0 g
s
0 0 .117 r
.78769 .19396 m .78814 .18929 L .7882 .19371 L p F P
0 g
s
.593 .669 .892 r
.74725 .13161 m .75183 .13082 L .75235 .13527 L p F P
0 g
s
.567 .637 .88 r
.75828 .12996 m .75183 .13082 L .75235 .13527 L p F P
0 g
s
.567 .637 .88 r
.75235 .13527 m .76076 .13441 L .75828 .12996 L p F P
0 g
s
.771 .886 .928 r
.6618 .35516 m .66932 .3504 L .66684 .34864 L p F P
0 g
s
.771 .886 .928 r
.66684 .34864 m .66503 .34976 L .6618 .35516 L p F P
0 g
s
.769 .877 .926 r
.65627 .35511 m .66503 .34976 L .6618 .35516 L p F P
0 g
s
.239 .34 .766 r
.77981 .15315 m .77874 .15243 L .7786 .15707 L p F P
0 g
s
.239 .34 .766 r
.7786 .15707 m .78247 .15998 L .77981 .15315 L p F P
0 g
s
.918 .916 .8 r
.6452 .19448 m .6437 .19645 L .64363 .20107 L p F P
0 g
s
.918 .917 .799 r
.63907 .20255 m .63869 .20728 L .64363 .20107 L p F P
0 g
s
.918 .917 .799 r
.64363 .20107 m .6437 .19645 L .63907 .20255 L p F P
0 g
s
.62 .698 .901 r
.58229 .37133 m .59289 .36889 L .59557 .37261 L p F P
0 g
s
.619 .63 .84 r
.58061 .36825 m .58229 .37133 L .59289 .36889 L p F P
0 g
s
.902 .973 .672 r
.61072 .25298 m .61413 .2473 L .61284 .25228 L p F P
0 g
s
.902 .973 .672 r
.61022 .2548 m .61072 .25298 L p .61284 .25228 L F P
0 g
s
.902 .973 .672 r
.61284 .25228 m .6118 .25394 L .61022 .2548 L p F P
0 g
s
.817 .931 .907 r
.70331 .32944 m .69876 .33297 L .70112 .32821 L closepath p F P
0 g
s
.811 .921 .91 r
.70092 .32809 m .70112 .32821 L .69876 .33297 L p F P
0 g
s
.811 .921 .91 r
.6904 .33599 m .70092 .32809 L p .69876 .33297 L F P
0 g
s
0 0 0 r
.5869 .30626 m .58662 .30677 L .58752 .30363 L p F P
0 g
s
0 0 0 r
.58752 .30363 m .58893 .30104 L .5869 .30626 L p F P
0 g
s
.848 .92 .525 r
.60045 .27456 m .59872 .27966 L .60156 .27418 L p F P
0 g
s
.848 .92 .525 r
.60165 .27212 m .60045 .27456 L p .60156 .27418 L F P
0 g
s
.848 .92 .525 r
.60156 .27418 m .60258 .27102 L .60165 .27212 L p F P
0 g
s
.886 .968 .837 r
.74276 .29056 m .74881 .28389 L .74729 .28878 L p F P
0 g
s
.886 .968 .837 r
.74274 .29064 m .74276 .29056 L p .74729 .28878 L F P
0 g
s
.886 .968 .837 r
.74729 .28878 m .74495 .29134 L .74274 .29064 L p F P
0 g
s
.856 .875 .853 r
.66621 .17131 m .66584 .17099 L .66623 .17061 L closepath p F P
0 g
s
.943 .955 .744 r
.62211 .23099 m .62126 .23584 L .62526 .22997 L p F P
0 g
s
.943 .955 .744 r
.62526 .22997 m .62583 .22521 L .62211 .23099 L p F P
0 g
s
.923 .951 .615 r
.77701 .23801 m .77605 .24278 L .77881 .2373 L p F P
0 g
s
.923 .951 .615 r
.77877 .23454 m .77701 .23801 L p .77881 .2373 L F P
0 g
s
.923 .951 .615 r
.77881 .2373 m .77947 .23418 L .77877 .23454 L p F P
0 g
s
.825 .931 .901 r
.70903 .32485 m .70331 .32944 L .70112 .32821 L p F P
0 g
s
.879 .97 .844 r
.74495 .29134 m .74101 .29551 L .74274 .29064 L closepath p F P
0 g
s
.924 .965 .661 r
.6118 .25394 m .6095 .25793 L .61022 .2548 L closepath p F P
0 g
s
.832 .852 .861 r
.68131 .15628 m .67621 .16078 L .67372 .1583 L p F P
0 g
s
.859 .858 .838 r
.6734 .16358 m .67621 .16078 L .67372 .1583 L p F P
0 g
s
.721 .813 .922 r
.62523 .36836 m .622 .36993 L .61939 .36734 L p F P
0 g
s
.699 .807 .932 r
.60881 .37189 m .61939 .36734 L .622 .36993 L p F P
0 g
s
0 0 0 r
.59144 .2957 m .58893 .30104 L .59121 .29574 L p F P
0 g
s
.838 .846 .851 r
.68131 .15628 m .68664 .1515 L .68415 .14877 L p F P
0 g
s
.838 .846 .851 r
.68415 .14877 m .6809 .15178 L .68131 .15628 L p F P
0 g
s
.832 .852 .861 r
.67372 .1583 m .6809 .15178 L .68131 .15628 L p F P
0 g
s
.781 .728 .199 r
.78644 .20777 m .78732 .20299 L .78684 .20764 L p F P
0 g
s
.781 .728 .199 r
.78598 .21227 m .78644 .20777 L p .78684 .20764 L F P
0 g
s
.781 .728 .199 r
.78684 .20764 m .78603 .21206 L .78598 .21227 L p F P
0 g
s
.923 .976 .743 r
.76524 .26014 m .76412 .26492 L .76815 .25898 L p F P
0 g
s
.923 .976 .743 r
.76815 .25898 m .76934 .25417 L .76524 .26014 L p F P
0 g
s
.859 .858 .838 r
.67372 .1583 m .67293 .15911 L .6734 .16358 L p F P
0 g
s
.858 .857 .839 r
.66618 .16599 m .66623 .17061 L .6734 .16358 L p F P
0 g
s
.858 .857 .839 r
.6734 .16358 m .67293 .15911 L .66618 .16599 L p F P
0 g
s
.918 .975 .77 r
.76378 .26629 m .76316 .26623 L .76412 .26492 L closepath p F P
0 g
s
.807 .833 .871 r
.69039 .14854 m .68664 .1515 L .68415 .14877 L p F P
0 g
s
.753 .863 .93 r
.6462 .36168 m .6457 .36127 L .64687 .36061 L closepath p F P
0 g
s
.083 0 .42 r
.57956 .33237 m .57662 .33675 L .57654 .33226 L p F P
0 g
s
.083 0 .42 r
.57654 .33226 m .57947 .32789 L .57956 .33237 L p F P
0 g
s
.329 .249 .613 r
.57303 .34691 m .57358 .34624 L .57391 .34825 L closepath p F P
0 g
s
.89 .881 .449 r
.78266 .22256 m .78194 .22727 L .78375 .22214 L p F P
0 g
s
.89 .881 .449 r
.78375 .22214 m .78451 .21741 L .78266 .22256 L p F P
0 g
s
.874 .963 .854 r
.7427 .29062 m .74274 .29064 L .74101 .29551 L p F P
0 g
s
.874 .963 .854 r
.73589 .29751 m .7427 .29062 L p .74101 .29551 L F P
0 g
s
.874 .963 .854 r
.73441 .30197 m .73589 .29751 L p .74101 .29551 L F P
0 g
s
.874 .963 .854 r
.74101 .29551 m .73462 .30204 L .73441 .30197 L p F P
0 g
s
.831 .939 .897 r
.70903 .32485 m .71378 .32092 L .71142 .31968 L p F P
0 g
s
.831 .939 .897 r
.71142 .31968 m .71137 .31973 L .70903 .32485 L p F P
0 g
s
.825 .931 .901 r
.7013 .32779 m .71137 .31973 L .70903 .32485 L p F P
0 g
s
.825 .931 .901 r
.70112 .32821 m .7013 .32779 L p .70903 .32485 L F P
0 g
s
.657 .706 .884 r
.73394 .13125 m .74479 .12762 L .74725 .13161 L p F P
0 g
s
.665 .714 .884 r
.74479 .12762 m .73394 .13125 L .73148 .12759 L p F P
0 g
s
.707 .746 .882 r
.72075 .1327 m .73148 .12759 L .73394 .13125 L p F P
0 g
s
.855 .874 .852 r
.66334 .16883 m .66618 .16599 L .66623 .17061 L p F P
0 g
s
.855 .874 .852 r
.66623 .17061 m .66584 .17099 L .66334 .16883 L p F P
0 g
s
.751 .779 .876 r
.71873 .1339 m .72075 .1327 L .71829 .12929 L p F P
0 g
s
.751 .779 .876 r
.71829 .12929 m .71782 .12957 L .71873 .1339 L p F P
0 g
s
.746 .789 .888 r
.70766 .13574 m .71782 .12957 L .71873 .1339 L p F P
0 g
s
.883 .882 .828 r
.66013 .17724 m .66584 .17099 L .66334 .16883 L p F P
0 g
s
.914 .936 .808 r
.63493 .20793 m .63907 .20255 L .63869 .20728 L p F P
0 g
s
.914 .936 .808 r
.63869 .20728 m .63744 .20886 L .63493 .20793 L p F P
0 g
s
.933 .969 .702 r
.77233 .2513 m .77104 .25148 L .77293 .24838 L closepath p F P
0 g
s
.814 .83 .862 r
.69039 .14854 m .69712 .14315 L .69464 .14018 L p F P
0 g
s
.814 .83 .862 r
.69464 .14018 m .68999 .14403 L .69039 .14854 L p F P
0 g
s
.807 .833 .871 r
.68415 .14877 m .68999 .14403 L .69039 .14854 L p F P
0 g
s
.839 .939 .891 r
.71825 .31709 m .71378 .32092 L .71142 .31968 L p F P
0 g
s
.49 .585 .877 r
.76582 .13924 m .76325 .13897 L .76076 .13441 L p F P
0 g
s
0 0 .294 r
.78856 .18461 m .78814 .18929 L .78753 .18507 L p F P
0 g
s
0 0 .294 r
.78753 .18507 m .78795 .1804 L .78856 .18461 L p F P
0 g
s
.782 .893 .923 r
.67699 .34535 m .66932 .3504 L .66684 .34864 L p F P
0 g
s
.866 .964 .862 r
.73462 .30204 m .73424 .30242 L .73441 .30197 L closepath p F P
0 g
s
.856 .952 .875 r
.72846 .30466 m .72661 .30963 L .73424 .30242 L p F P
0 g
s
.856 .952 .875 r
.73232 .301 m .72846 .30466 L p .73424 .30242 L F P
0 g
s
.856 .952 .875 r
.73424 .30242 m .73441 .30197 L .73232 .301 L p F P
0 g
s
.934 .931 .776 r
.63425 .2133 m .63744 .20886 L .63493 .20793 L p F P
0 g
s
.845 .947 .885 r
.71825 .31709 m .72422 .31181 L .72189 .31067 L p F P
0 g
s
.845 .947 .885 r
.72189 .31067 m .72033 .31205 L .71825 .31709 L p F P
0 g
s
.839 .939 .891 r
.71142 .31968 m .72033 .31205 L .71825 .31709 L p F P
0 g
s
.668 .766 .923 r
.59557 .37261 m .60616 .36888 L .60881 .37189 L p F P
0 g
s
.65 .742 .917 r
.60616 .36888 m .59557 .37261 L .59289 .36889 L p F P
0 g
s
.689 .792 .929 r
.61939 .36734 m .60881 .37189 L .60616 .36888 L p F P
0 g
s
.852 .946 .879 r
.72661 .30963 m .72422 .31181 L .72189 .31067 L p F P
0 g
s
.852 .946 .879 r
.72189 .31067 m .72846 .30466 L .72661 .30963 L p F P
0 g
s
.717 .82 .929 r
.62523 .36836 m .63257 .36472 L .62999 .36238 L p F P
0 g
s
.717 .82 .929 r
.62999 .36238 m .62956 .36258 L .62523 .36836 L p F P
0 g
s
.721 .813 .922 r
.61939 .36734 m .62956 .36258 L .62523 .36836 L p F P
0 g
s
.714 .751 .881 r
.73148 .12759 m .72075 .1327 L .71829 .12929 L p F P
0 g
s
.392 .293 .622 r
.5802 .34458 m .57772 .3409 L .57358 .34624 L p F P
0 g
s
.392 .293 .622 r
.57581 .35048 m .5802 .34458 L p .57358 .34624 L F P
0 g
s
.392 .293 .622 r
.57358 .34624 m .57391 .34825 L .57581 .35048 L p F P
0 g
s
.57 .583 .827 r
.57955 .36609 m .58279 .36583 L .58061 .36825 L closepath p F P
0 g
s
.619 .63 .84 r
.59018 .3647 m .58279 .36583 L .58061 .36825 L p F P
0 g
s
.619 .63 .84 r
.59289 .36889 m .59018 .3647 L p .58061 .36825 L F P
0 g
s
.78 .813 .879 r
.70167 .13997 m .69712 .14315 L .69464 .14018 L p F P
0 g
s
0 0 .175 r
.58427 .31621 m .58104 .32176 L .58227 .31682 L p F P
0 g
s
0 0 .175 r
.58227 .31682 m .58536 .31131 L .58427 .31621 L p F P
0 g
s
.753 .855 .926 r
.64687 .36061 m .6457 .36127 L .64315 .35911 L p F P
0 g
s
.737 .852 .934 r
.63257 .36472 m .64315 .35911 L .6457 .36127 L p F P
0 g
s
.883 .882 .828 r
.66334 .16883 m .65992 .17269 L .66013 .17724 L p F P
0 g
s
.877 .891 .839 r
.65401 .17926 m .65992 .17269 L .66013 .17724 L p F P
0 g
s
.877 .891 .839 r
.65398 .18108 m .65401 .17926 L p .66013 .17724 L F P
0 g
s
.877 .891 .839 r
.66013 .17724 m .6555 .18221 L .65398 .18108 L p F P
0 g
s
.603 .675 .891 r
.75183 .13082 m .74725 .13161 L .74479 .12762 L p F P
0 g
s
.674 .794 .332 r
.59502 .28729 m .59401 .28931 L .596 .28511 L closepath p F P
0 g
s
.921 .96 .64 r
.60761 .25855 m .60636 .26351 L .6095 .25793 L p F P
0 g
s
.921 .96 .64 r
.60931 .25537 m .60761 .25855 L p .6095 .25793 L F P
0 g
s
.921 .96 .64 r
.6095 .25793 m .61022 .2548 L .60931 .25537 L p F P
0 g
s
.866 .951 .865 r
.73441 .30197 m .73232 .301 L .73589 .29751 L closepath p F P
0 g
s
.928 .972 .74 r
.61836 .23679 m .62211 .23099 L .62126 .23584 L p F P
0 g
s
.928 .972 .74 r
.61798 .23871 m .61836 .23679 L p .62126 .23584 L F P
0 g
s
.928 .972 .74 r
.62126 .23584 m .61949 .23847 L .61798 .23871 L p F P
0 g
s
.753 .855 .926 r
.64315 .35911 m .65014 .35519 L .64687 .36061 L p F P
0 g
s
.753 .861 .929 r
.64687 .36061 m .65627 .35511 L .65374 .35313 L p F P
0 g
s
.753 .861 .929 r
.65374 .35313 m .65014 .35519 L .64687 .36061 L p F P
0 g
s
0 0 .31 r
.58037 .32652 m .57947 .32789 L .57969 .32383 L p F P
0 g
s
0 0 .31 r
.57969 .32383 m .58104 .32176 L .58037 .32652 L p F P
0 g
s
.795 .871 .434 r
.59797 .27993 m .596 .28511 L .59872 .27966 L p F P
0 g
s
.795 .871 .434 r
.59872 .27966 m .60045 .27456 L .59797 .27993 L p F P
0 g
s
.918 .974 .771 r
.76099 .26599 m .76524 .26014 L .76412 .26492 L p F P
0 g
s
.918 .974 .771 r
.76412 .26492 m .76316 .26623 L .76099 .26599 L p F P
0 g
s
.894 .886 .817 r
.6555 .18221 m .65416 .18382 L .65398 .18108 L closepath p F P
0 g
s
.78 .813 .879 r
.69464 .14018 m .70115 .1355 L .70167 .13997 L p F P
0 g
s
.787 .809 .87 r
.70167 .13997 m .70766 .13574 L .70519 .13255 L p F P
0 g
s
.787 .809 .87 r
.70519 .13255 m .70115 .1355 L .70167 .13997 L p F P
0 g
s
.932 .962 .663 r
.77384 .24364 m .77293 .24838 L .77605 .24278 L p F P
0 g
s
.932 .962 .663 r
.77605 .24278 m .77701 .23801 L .77384 .24364 L p F P
0 g
s
.354 .284 .639 r
.57391 .34825 m .57581 .35048 L .57462 .35194 L closepath p F P
0 g
s
.934 .931 .776 r
.63493 .20793 m .63442 .20866 L .63425 .2133 L p F P
0 g
s
.936 .932 .772 r
.63039 .21455 m .62995 .21929 L .63425 .2133 L p F P
0 g
s
.936 .932 .772 r
.63425 .2133 m .63442 .20866 L .63039 .21455 L p F P
0 g
s
.9 .968 .817 r
.75391 .27937 m .75299 .27911 L .75446 .27737 L closepath p F P
0 g
s
.528 .537 .808 r
.58279 .36583 m .57955 .36609 L .57678 .35941 L p F P
0 g
s
.912 .978 .775 r
.75948 .27108 m .76316 .26623 L .76099 .26599 L p F P
0 g
s
.898 .889 .813 r
.64882 .18556 m .64886 .19016 L .65416 .18382 L p F P
0 g
s
.898 .889 .813 r
.653 .18037 m .64882 .18556 L p .65416 .18382 L F P
0 g
s
.898 .889 .813 r
.65416 .18382 m .65398 .18108 L .653 .18037 L p F P
0 g
s
.788 .904 .923 r
.67986 .34341 m .67699 .34535 L .67857 .34255 L closepath p F P
0 g
s
.782 .893 .923 r
.6774 .3417 m .67857 .34255 L .67699 .34535 L p F P
0 g
s
.782 .893 .923 r
.66684 .34864 m .6774 .3417 L p .67699 .34535 L F P
0 g
s
0 0 .455 r
.788 .17973 m .78795 .1804 L .7867 .17642 L p F P
0 g
s
0 0 .455 r
.7867 .17642 m .78686 .17425 L .788 .17973 L p F P
0 g
s
.944 .96 .72 r
.61949 .23847 m .61756 .24161 L .61798 .23871 L closepath p F P
0 g
s
0 0 0 r
.78776 .19833 m .78732 .20299 L .78775 .19838 L p F P
0 g
s
0 0 0 r
.78775 .19838 m .7882 .19371 L .78776 .19833 L p F P
0 g
s
0 0 0 r
.58963 .30085 m .5869 .30626 L .58893 .30104 L p F P
0 g
s
0 0 0 r
.58893 .30104 m .59144 .2957 L .58963 .30085 L p F P
0 g
s
.796 .905 .917 r
.69002 .33627 m .67986 .34341 L .67857 .34255 L p F P
0 g
s
.444 .547 .866 r
.77329 .1384 m .77333 .14083 L .76582 .13924 L p F P
0 g
s
.444 .547 .866 r
.7721 .13593 m .77329 .1384 L p .76582 .13924 L F P
0 g
s
.444 .547 .866 r
.76582 .13924 m .76545 .13475 L .7721 .13593 L p F P
0 g
s
.49 .585 .877 r
.76076 .13441 m .76545 .13475 L .76582 .13924 L p F P
0 g
s
.756 .72 .188 r
.78603 .21206 m .78596 .21242 L .78598 .21227 L closepath p F P
0 g
s
.924 .921 .54 r
.78042 .22785 m .77973 .23254 L .78194 .22727 L p F P
0 g
s
.924 .921 .54 r
.78194 .22727 m .78266 .22256 L .78042 .22785 L p F P
0 g
s
.752 .791 .884 r
.71782 .12957 m .70766 .13574 L .70519 .13255 L p F P
0 g
s
.85 .826 .349 r
.78494 .21449 m .78451 .21741 L .78596 .21242 L p F P
0 g
s
.85 .826 .349 r
.78596 .21242 m .78598 .21227 L .78494 .21449 L p F P
0 g
s
.432 .392 .714 r
.58112 .35318 m .57654 .35875 L .57462 .35194 L p F P
0 g
s
.432 .392 .714 r
.57462 .35194 m .57581 .35048 L .58112 .35318 L p F P
0 g
s
.491 .47 .761 r
.5761 .35927 m .57654 .35875 L .57678 .35941 L closepath p F P
0 g
s
.912 .978 .775 r
.76099 .26599 m .76082 .26622 L .75948 .27108 L p F P
0 g
s
.906 .973 .802 r
.75571 .27256 m .75446 .27737 L .75948 .27108 L p F P
0 g
s
.906 .973 .802 r
.75948 .27108 m .76082 .26622 L .75571 .27256 L p F P
0 g
s
.873 .827 .353 r
.78513 .21272 m .78494 .21449 L .78598 .21227 L p F P
0 g
s
.873 .827 .353 r
.78598 .21227 m .78644 .20777 L .78513 .21272 L p F P
0 g
s
.83 .918 .523 r
.60258 .27102 m .60165 .27212 L .60327 .26908 L closepath p F P
0 g
s
.946 .96 .707 r
.61496 .24246 m .61413 .2473 L .61756 .24161 L p F P
0 g
s
.946 .96 .707 r
.61699 .23894 m .61496 .24246 L p .61756 .24161 L F P
0 g
s
.946 .96 .707 r
.61756 .24161 m .61798 .23871 L .61699 .23894 L p F P
0 g
s
.734 .844 .932 r
.64315 .35911 m .63257 .36472 L .62999 .36238 L p F P
0 g
s
.899 .911 .823 r
.64366 .19186 m .64882 .18556 L .64886 .19016 L p F P
0 g
s
.899 .911 .823 r
.6436 .19355 m .64366 .19186 L p .64886 .19016 L F P
0 g
s
.899 .911 .823 r
.64886 .19016 m .6452 .19448 L .6436 .19355 L p F P
0 g
s
0 .08 .605 r
.78509 .16805 m .7851 .16782 L .78525 .16833 L closepath p F P
0 g
s
.935 .944 .605 r
.77947 .23418 m .77877 .23454 L .77973 .23254 L closepath p F P
0 g
s
.898 .944 .583 r
.60478 .26404 m .60327 .26908 L .60636 .26351 L p F P
0 g
s
.898 .944 .583 r
.60636 .26351 m .60761 .25855 L .60478 .26404 L p F P
0 g
s
.929 .954 .778 r
.6263 .22047 m .63039 .21455 L .62995 .21929 L p F P
0 g
s
.929 .954 .778 r
.62598 .22293 m .6263 .22047 L p .62995 .21929 L F P
0 g
s
.929 .954 .778 r
.62995 .21929 m .6272 .22311 L .62598 .22293 L p F P
0 g
s
.019 .153 .663 r
.78508 .16349 m .7851 .16782 L .78252 .1601 L p F P
0 g
s
0 0 .536 r
.78691 .16724 m .78508 .16349 L .7851 .16782 L p F P
0 g
s
0 0 .536 r
.78691 .17181 m .78691 .16724 L p .7851 .16782 L F P
0 g
s
0 0 .536 r
.7851 .16782 m .78525 .16833 L .78691 .17181 L p F P
0 g
s
0 0 .551 r
.78525 .16833 m .78691 .17181 L .78686 .17425 L closepath p F P
0 g
s
.528 .537 .808 r
.57678 .35941 m .58733 .35993 L .58279 .36583 L p F P
0 g
s
.538 .498 .759 r
.57654 .35875 m .57678 .35941 L .58733 .35993 L p F P
0 g
s
.188 .107 .526 r
.58007 .33739 m .57772 .3409 L .57662 .33675 L p F P
0 g
s
.188 .107 .526 r
.57662 .33675 m .57956 .33237 L .58007 .33739 L p F P
0 g
s
.538 .498 .759 r
.5847 .3539 m .58112 .35318 L .57654 .35875 L p F P
0 g
s
.538 .498 .759 r
.58741 .35982 m .5847 .3539 L p .57654 .35875 L F P
0 g
s
.538 .498 .759 r
.58733 .35993 m .58741 .35982 L p .57654 .35875 L F P
0 g
s
.766 .872 .925 r
.66503 .34976 m .65627 .35511 L .65374 .35313 L p F P
0 g
s
.603 .675 .891 r
.74479 .12762 m .75141 .12632 L .75183 .13082 L p F P
0 g
s
.579 .649 .883 r
.7558 .1256 m .75141 .12632 L .75183 .13082 L p F P
0 g
s
.579 .649 .883 r
.75183 .13082 m .75828 .12996 L .7558 .1256 L p F P
0 g
s
.934 .968 .703 r
.77034 .2494 m .77384 .24364 L .77293 .24838 L p F P
0 g
s
.934 .968 .703 r
.76992 .25162 m .77034 .2494 L p .77293 .24838 L F P
0 g
s
.934 .968 .703 r
.77293 .24838 m .77104 .25148 L .76992 .25162 L p F P
0 g
s
.667 .789 .326 r
.59565 .28524 m .59797 .27993 L .596 .28511 L p F P
0 g
s
.667 .789 .326 r
.59373 .28988 m .59565 .28524 L p .596 .28511 L F P
0 g
s
.667 .789 .326 r
.596 .28511 m .59401 .28931 L .59373 .28988 L p F P
0 g
s
.358 .457 .825 r
.77464 .14129 m .77333 .14083 L .77337 .14543 L p F P
0 g
s
.358 .457 .825 r
.77337 .14543 m .77721 .14699 L .77464 .14129 L p F P
0 g
s
.914 .904 .8 r
.6452 .19448 m .6437 .19645 L .6436 .19355 L closepath p F P
0 g
s
.131 .257 .727 r
.78247 .15998 m .78251 .16002 L .78252 .1601 L closepath p F P
0 g
s
.019 .153 .663 r
.78252 .1601 m .78251 .16002 L .78508 .16349 L p F P
0 g
s
.15 .28 .744 r
.78251 .16002 m .78247 .15998 L .77981 .15315 L p F P
0 g
s
0 0 .291 r
.5837 .32093 m .58037 .32652 L .58104 .32176 L p F P
0 g
s
0 0 .291 r
.58104 .32176 m .58427 .31621 L .5837 .32093 L p F P
0 g
s
.593 .63 .858 r
.58746 .35992 m .58733 .35993 L .58279 .36583 L p F P
0 g
s
.593 .63 .858 r
.58279 .36583 m .59018 .3647 L .58746 .35992 L p F P
0 g
s
.15 .28 .744 r
.77981 .15315 m .78237 .15549 L .78251 .16002 L p F P
0 g
s
.016 .158 .669 r
.785 .15894 m .78508 .16349 L .78251 .16002 L p F P
0 g
s
.016 .158 .669 r
.78251 .16002 m .78237 .15549 L .785 .15894 L p F P
0 g
s
.503 .595 .879 r
.76545 .13475 m .76076 .13441 L .75828 .12996 L p F P
0 g
s
0 0 .105 r
.78861 .18905 m .7882 .19371 L .78814 .18929 L p F P
0 g
s
0 0 .105 r
.78814 .18929 m .78856 .18461 L .78861 .18905 L p F P
0 g
s
.802 .915 .916 r
.6904 .33599 m .69002 .33627 L .69022 .33588 L closepath p F P
0 g
s
.796 .905 .917 r
.68796 .33433 m .69022 .33588 L .69002 .33627 L p F P
0 g
s
.796 .905 .917 r
.67975 .3401 m .68796 .33433 L p .69002 .33627 L F P
0 g
s
.796 .905 .917 r
.67857 .34255 m .67975 .3401 L p .69002 .33627 L F P
0 g
s
.814 .916 .907 r
.69851 .32652 m .70092 .32809 L .6904 .33599 L p F P
0 g
s
.814 .916 .907 r
.69229 .33118 m .69851 .32652 L p .6904 .33599 L F P
0 g
s
.814 .916 .907 r
.6904 .33599 m .69022 .33588 L .69229 .33118 L p F P
0 g
s
.259 .365 .782 r
.77874 .15243 m .77878 .15061 L .77981 .15315 L closepath p F P
0 g
s
.9 .967 .818 r
.75076 .27845 m .75571 .27256 L .75446 .27737 L p F P
0 g
s
.9 .967 .818 r
.75446 .27737 m .75299 .27911 L .75076 .27845 L p F P
0 g
s
0 0 .034 r
.58662 .30677 m .58641 .30781 L .5869 .30626 L closepath p F P
0 g
s
.919 .906 .795 r
.63912 .19793 m .63907 .20255 L .6437 .19645 L p F P
0 g
s
.919 .906 .795 r
.64269 .19304 m .63912 .19793 L p .6437 .19645 L F P
0 g
s
.919 .906 .795 r
.6437 .19645 m .6436 .19355 L .64269 .19304 L p F P
0 g
s
.943 .942 .755 r
.6272 .22311 m .62583 .22521 L .62598 .22293 L closepath p F P
0 g
s
.665 .714 .884 r
.73148 .12759 m .74232 .12369 L .74479 .12762 L p F P
0 g
s
.674 .72 .884 r
.74232 .12369 m .73148 .12759 L .72901 .12394 L p F P
0 g
s
.714 .751 .881 r
.71829 .12929 m .72901 .12394 L .73148 .12759 L p F P
0 g
s
0 0 .41 r
.78807 .17581 m .788 .17973 L .78686 .17425 L p F P
0 g
s
0 0 .41 r
.78686 .17425 m .78691 .17181 L .78807 .17581 L p F P
0 g
s
.894 .97 .823 r
.74881 .28389 m .75299 .27911 L .75076 .27845 L p F P
0 g
s
.713 .799 .918 r
.62956 .36258 m .61939 .36734 L .61677 .36459 L p F P
0 g
s
.689 .792 .929 r
.60616 .36888 m .61677 .36459 L .61939 .36734 L p F P
0 g
s
.804 .904 .911 r
.69022 .33588 m .68796 .33433 L .69229 .33118 L closepath p F P
0 g
s
.65 .742 .917 r
.59289 .36889 m .6035 .36562 L .60616 .36888 L p F P
0 g
s
.626 .712 .908 r
.6035 .36562 m .59289 .36889 L .59018 .3647 L p F P
0 g
s
.387 .345 .689 r
.58324 .35017 m .58112 .35318 L .57581 .35048 L p F P
0 g
s
.387 .345 .689 r
.58188 .34584 m .58324 .35017 L p .57581 .35048 L F P
0 g
s
.387 .345 .689 r
.57581 .35048 m .5802 .34458 L .58188 .34584 L p F P
0 g
s
.927 .973 .711 r
.77104 .25148 m .76934 .25417 L .76992 .25162 L closepath p F P
0 g
s
.907 .965 .647 r
.61022 .2548 m .60931 .25537 L .61072 .25298 L closepath p F P
0 g
s
0 0 .046 r
.58814 .30589 m .58963 .30085 L .5869 .30626 L p F P
0 g
s
0 0 .046 r
.58592 .31019 m .58814 .30589 L p .5869 .30626 L F P
0 g
s
0 0 .046 r
.5869 .30626 m .58641 .30781 L .58592 .31019 L p F P
0 g
s
.836 .851 .856 r
.6809 .15178 m .67372 .1583 L .67267 .15724 L p F P
0 g
s
.856 .851 .836 r
.67372 .1583 m .67293 .15911 L .67267 .15724 L closepath p F P
0 g
s
.812 .832 .866 r
.68999 .14403 m .68415 .14877 L .68166 .14601 L p F P
0 g
s
.84 .84 .845 r
.6809 .15178 m .68415 .14877 L .68166 .14601 L p F P
0 g
s
.84 .84 .845 r
.68166 .14601 m .68025 .14735 L .6809 .15178 L p F P
0 g
s
.836 .851 .856 r
.67253 .1546 m .68025 .14735 L .6809 .15178 L p F P
0 g
s
.836 .851 .856 r
.67267 .15724 m .67253 .1546 L p .6809 .15178 L F P
0 g
s
.818 .919 .904 r
.70112 .32821 m .70092 .32809 L .7013 .32779 L closepath p F P
0 g
s
.86 .853 .834 r
.66584 .16146 m .66618 .16599 L .67293 .15911 L p F P
0 g
s
.86 .853 .834 r
.67123 .15581 m .66584 .16146 L p .67293 .15911 L F P
0 g
s
.86 .853 .834 r
.67293 .15911 m .67267 .15724 L .67123 .15581 L p F P
0 g
s
.94 .961 .675 r
.6118 .24806 m .61072 .25298 L .61413 .2473 L p F P
0 g
s
.94 .961 .675 r
.61413 .2473 m .61496 .24246 L .6118 .24806 L p F P
0 g
s
.947 .944 .746 r
.62255 .22626 m .62211 .23099 L .62583 .22521 L p F P
0 g
s
.947 .944 .746 r
.62469 .2228 m .62255 .22626 L p .62583 .22521 L F P
0 g
s
.947 .944 .746 r
.62583 .22521 m .62598 .22293 L .62469 .2228 L p F P
0 g
s
.613 .681 .891 r
.75141 .12632 m .74479 .12762 L .74232 .12369 L p F P
0 g
s
.883 .893 .834 r
.65398 .18108 m .653 .18037 L .65401 .17926 L closepath p F P
0 g
s
.937 .944 .607 r
.77782 .23328 m .78042 .22785 L .77973 .23254 L p F P
0 g
s
.937 .944 .607 r
.77755 .23515 m .77782 .23328 L p .77973 .23254 L F P
0 g
s
.937 .944 .607 r
.77973 .23254 m .77877 .23454 L .77755 .23515 L p F P
0 g
s
.751 .777 .875 r
.71829 .12929 m .71782 .12957 L .7175 .12819 L closepath p F P
0 g
s
.752 .791 .884 r
.71582 .12588 m .7175 .12819 L .71782 .12957 L p F P
0 g
s
.752 .791 .884 r
.70519 .13255 m .71582 .12588 L p .71782 .12957 L F P
0 g
s
.676 .775 .925 r
.61677 .36459 m .60616 .36888 L .6035 .36562 L p F P
0 g
s
.894 .97 .823 r
.75076 .27845 m .75028 .27901 L .74881 .28389 L p F P
0 g
s
.886 .963 .84 r
.74412 .28572 m .74276 .29056 L .74881 .28389 L p F P
0 g
s
.886 .963 .84 r
.74881 .28389 m .75028 .27901 L .74412 .28572 L p F P
0 g
s
.721 .768 .89 r
.72654 .12032 m .72901 .12394 L .71829 .12929 L p F P
0 g
s
.721 .768 .89 r
.71757 .12498 m .72654 .12032 L p .71829 .12929 L F P
0 g
s
.721 .768 .89 r
.71829 .12929 m .7175 .12819 L .71757 .12498 L p F P
0 g
s
.814 .752 .233 r
.78686 .20313 m .78644 .20777 L .78732 .20299 L p F P
0 g
s
.814 .752 .233 r
.78732 .20299 m .78776 .19833 L .78686 .20313 L p F P
0 g
s
.831 .919 .525 r
.60203 .2695 m .60478 .26404 L .60327 .26908 L p F P
0 g
s
.831 .919 .525 r
.60089 .27302 m .60203 .2695 L p .60327 .26908 L F P
0 g
s
.831 .919 .525 r
.60327 .26908 m .60165 .27212 L .60089 .27302 L p F P
0 g
s
.074 0 .418 r
.58045 .33102 m .57956 .33237 L .57947 .32789 L p F P
0 g
s
.074 0 .418 r
.57947 .32789 m .58037 .32652 L .58045 .33102 L p F P
0 g
s
.817 .826 .856 r
.68999 .14403 m .69464 .14018 L .69215 .1372 L p F P
0 g
s
.817 .826 .856 r
.69215 .1372 m .68934 .13959 L .68999 .14403 L p F P
0 g
s
.812 .832 .866 r
.68166 .14601 m .68934 .13959 L .68999 .14403 L p F P
0 g
s
.791 .894 .917 r
.67857 .34255 m .6774 .3417 L .67975 .3401 L closepath p F P
0 g
s
.818 .914 .903 r
.7013 .32779 m .70092 .32809 L .69851 .32652 L p F P
0 g
s
.821 .923 .903 r
.70334 .32276 m .7013 .32779 L .71137 .31973 L p F P
0 g
s
.818 .914 .903 r
.69851 .32652 m .70334 .32276 L .7013 .32779 L p F P
0 g
s
.12 .273 .747 r
.77878 .15061 m .77981 .15315 L .78237 .15549 L p F P
0 g
s
.859 .87 .846 r
.66084 .16662 m .66584 .16146 L .66618 .16599 L p F P
0 g
s
.859 .87 .846 r
.66618 .16599 m .66334 .16883 L .66084 .16662 L p F P
0 g
s
.904 .891 .472 r
.78333 .21785 m .78266 .22256 L .78451 .21741 L p F P
0 g
s
.904 .891 .472 r
.78422 .21537 m .78333 .21785 L p .78451 .21741 L F P
0 g
s
.904 .891 .472 r
.78451 .21741 m .78494 .21449 L .78422 .21537 L p F P
0 g
s
.924 .973 .756 r
.7663 .25535 m .76524 .26014 L .76934 .25417 L p F P
0 g
s
.924 .973 .756 r
.76892 .25154 m .7663 .25535 L p .76934 .25417 L F P
0 g
s
.924 .973 .756 r
.76934 .25417 m .76992 .25162 L .76892 .25154 L p F P
0 g
s
.771 .885 .927 r
.66684 .34864 m .66503 .34976 L .66605 .34805 L closepath p F P
0 g
s
.766 .872 .925 r
.66433 .34671 m .66605 .34805 L .66503 .34976 L p F P
0 g
s
.766 .872 .925 r
.65374 .35313 m .66433 .34671 L p .66503 .34976 L F P
0 g
s
.717 .811 .345 r
.59401 .28931 m .59349 .29048 L .59373 .28988 L closepath p F P
0 g
s
0 0 .019 r
.58641 .30781 m .58536 .31131 L .58592 .31019 L closepath p F P
0 g
s
.885 .873 .82 r
.65992 .17269 m .66334 .16883 L .66084 .16662 L p F P
0 g
s
.786 .813 .874 r
.70115 .1355 m .69464 .14018 L .69215 .1372 L p F P
0 g
s
.918 .931 .802 r
.63465 .20398 m .63912 .19793 L .63907 .20255 L p F P
0 g
s
.918 .931 .802 r
.63442 .20772 m .63465 .20398 L p .63907 .20255 L F P
0 g
s
.918 .931 .802 r
.63907 .20255 m .63493 .20793 L .63442 .20772 L p F P
0 g
s
0 0 .282 r
.78858 .18436 m .78856 .18461 L .78795 .1804 L p F P
0 g
s
0 0 .282 r
.78795 .1804 m .788 .17973 L .78858 .18436 L p F P
0 g
s
.929 .949 .614 r
.77877 .23454 m .77701 .23801 L .77755 .23515 L closepath p F P
0 g
s
.879 .956 .851 r
.74274 .29064 m .7427 .29062 L .74276 .29056 L closepath p F P
0 g
s
.783 .887 .92 r
.67492 .33987 m .6774 .3417 L .66684 .34864 L p F P
0 g
s
.783 .887 .92 r
.6678 .34451 m .67492 .33987 L p .66684 .34864 L F P
0 g
s
.783 .887 .92 r
.66684 .34864 m .66605 .34805 L .6678 .34451 L p F P
0 g
s
.879 .953 .851 r
.74042 .28961 m .74412 .28572 L .74276 .29056 L p F P
0 g
s
.879 .953 .851 r
.74276 .29056 m .7427 .29062 L .74042 .28961 L p F P
0 g
s
.873 .955 .857 r
.73589 .29751 m .7427 .29062 L .74042 .28961 L p F P
0 g
s
.749 .847 .925 r
.65014 .35519 m .64315 .35911 L .64059 .35686 L p F P
0 g
s
.734 .844 .932 r
.62999 .36238 m .64059 .35686 L .64315 .35911 L p F P
0 g
s
.668 .756 .268 r
.5926 .2927 m .59144 .2957 L .59349 .29048 L p F P
0 g
s
.885 .873 .82 r
.66084 .16662 m .65946 .16821 L .65992 .17269 L p F P
0 g
s
.884 .873 .821 r
.65386 .17467 m .65401 .17926 L .65992 .17269 L p F P
0 g
s
.884 .873 .821 r
.65992 .17269 m .65946 .16821 L .65386 .17467 L p F P
0 g
s
.254 .38 .798 r
.77721 .14699 m .77862 .14788 L .77878 .15061 L closepath p F P
0 g
s
.12 .273 .747 r
.78219 .15096 m .77862 .14788 L .77878 .15061 L p F P
0 g
s
.12 .273 .747 r
.78237 .15549 m .78219 .15096 L p .77878 .15061 L F P
0 g
s
.831 .935 .897 r
.71142 .31968 m .71137 .31973 L .71139 .31967 L closepath p F P
0 g
s
.821 .923 .903 r
.70904 .31821 m .70334 .32276 L p .71137 .31973 L F P
0 g
s
.821 .923 .903 r
.71137 .31973 m .71139 .31967 L .70904 .31821 L p F P
0 g
s
.839 .935 .89 r
.72033 .31205 m .71142 .31968 L .71139 .31967 L p F P
0 g
s
.839 .935 .89 r
.71139 .31967 m .71321 .31476 L p .72033 .31205 L F P
0 g
s
.832 .922 .894 r
.71139 .31967 m .70904 .31821 L .71321 .31476 L closepath p F P
0 g
s
.934 .969 .72 r
.61798 .23871 m .61699 .23894 L .61836 .23679 L closepath p F P
0 g
s
.873 .955 .857 r
.74042 .28961 m .73747 .2926 L .73589 .29751 L p F P
0 g
s
.866 .95 .865 r
.73024 .29969 m .73747 .2926 L .73589 .29751 L p F P
0 g
s
.866 .95 .865 r
.73015 .29999 m .73024 .29969 L p .73589 .29751 L F P
0 g
s
.866 .95 .865 r
.73589 .29751 m .73232 .301 L .73015 .29999 L p F P
0 g
s
.866 .921 .528 r
.60165 .27212 m .60045 .27456 L .60089 .27302 L closepath p F P
0 g
s
0 0 .237 r
.78867 .18004 m .78858 .18436 L .788 .17973 L p F P
0 g
s
0 0 .237 r
.788 .17973 m .78807 .17581 L .78867 .18004 L p F P
0 g
s
.722 .769 .89 r
.7175 .12819 m .71582 .12588 L .71757 .12498 L closepath p F P
0 g
s
.859 .951 .872 r
.73232 .301 m .72846 .30466 L .73015 .29999 L closepath p F P
0 g
s
.791 .807 .865 r
.70115 .1355 m .70519 .13255 L .70271 .12934 L p F P
0 g
s
.791 .807 .865 r
.70271 .12934 m .70038 .1311 L .70115 .1355 L p F P
0 g
s
.786 .813 .874 r
.69215 .1372 m .70038 .1311 L .70115 .1355 L p F P
0 g
s
.845 .944 .885 r
.72189 .31067 m .72033 .31205 L .72105 .31024 L closepath p F P
0 g
s
.839 .935 .89 r
.71954 .30936 m .72105 .31024 L .72033 .31205 L p F P
0 g
s
.839 .935 .89 r
.71321 .31476 m .71954 .30936 L p .72033 .31205 L F P
0 g
s
.853 .943 .878 r
.72846 .30466 m .72189 .31067 L .72105 .31024 L p F P
0 g
s
.853 .943 .878 r
.73001 .29991 m .73015 .29999 L .72846 .30466 L p F P
0 g
s
.853 .943 .878 r
.72212 .30709 m .73001 .29991 L p .72846 .30466 L F P
0 g
s
.853 .943 .878 r
.72105 .31024 m .72212 .30709 L p .72846 .30466 L F P
0 g
s
0 0 0 r
.59351 .2905 m .5926 .2927 L .59373 .28988 L p F P
0 g
s
0 0 0 r
.59373 .28988 m .59565 .28524 L .59351 .2905 L p F P
0 g
s
.949 .951 .729 r
.61906 .23197 m .61836 .23679 L .62211 .23099 L p F P
0 g
s
.949 .951 .729 r
.62211 .23099 m .62255 .22626 L .61906 .23197 L p F P
0 g
s
.933 .921 .778 r
.63493 .20793 m .63442 .20866 L .63442 .20772 L closepath p F P
0 g
s
.91 .965 .65 r
.60867 .25365 m .6118 .24806 L .61072 .25298 L p F P
0 g
s
.91 .965 .65 r
.60807 .25614 m .60867 .25365 L p .61072 .25298 L F P
0 g
s
.91 .965 .65 r
.61072 .25298 m .60931 .25537 L .60807 .25614 L p F P
0 g
s
.029 0 .403 r
.5838 .32544 m .58045 .33102 L .58037 .32652 L p F P
0 g
s
.029 0 .403 r
.58037 .32652 m .5837 .32093 L .5838 .32544 L p F P
0 g
s
.84 .853 .854 r
.67267 .15724 m .67123 .15581 L .67253 .1546 L closepath p F P
0 g
s
.882 .89 .833 r
.65049 .17851 m .65386 .17467 L .65401 .17926 L p F P
0 g
s
.882 .89 .833 r
.65401 .17926 m .653 .18037 L .65049 .17851 L p F P
0 g
s
.937 .923 .771 r
.63048 .20993 m .63039 .21455 L .63442 .20866 L p F P
0 g
s
.937 .923 .771 r
.63242 .207 m .63048 .20993 L p .63442 .20866 L F P
0 g
s
.937 .923 .771 r
.63442 .20866 m .63442 .20772 L .63242 .207 L p F P
0 g
s
.922 .971 .77 r
.76182 .26147 m .7663 .25535 L .76524 .26014 L p F P
0 g
s
.922 .971 .77 r
.76088 .26598 m .76182 .26147 L p .76524 .26014 L F P
0 g
s
.922 .971 .77 r
.76524 .26014 m .76099 .26599 L .76088 .26598 L p F P
0 g
s
0 0 .407 r
.7881 .17124 m .78807 .17581 L .78691 .17181 L p F P
0 g
s
0 0 .407 r
.78691 .17181 m .78691 .16724 L .7881 .17124 L p F P
0 g
s
.937 .964 .68 r
.77469 .2389 m .77384 .24364 L .77701 .23801 L p F P
0 g
s
.937 .964 .68 r
.77672 .23531 m .77469 .2389 L p .77701 .23801 L F P
0 g
s
.937 .964 .68 r
.77701 .23801 m .77755 .23515 L .77672 .23531 L p F P
0 g
s
.906 .892 .805 r
.64882 .18556 m .653 .18037 L .65049 .17851 L p F P
0 g
s
.759 .782 .871 r
.71582 .12588 m .70519 .13255 L .70271 .12934 L p F P
0 g
s
.291 .238 .624 r
.58116 .34315 m .5802 .34458 L .57772 .3409 L p F P
0 g
s
.291 .238 .624 r
.57772 .3409 m .58007 .33739 L .58116 .34315 L p F P
0 g
s
.721 .643 .084 r
.78815 .19368 m .78776 .19833 L .7882 .19371 L p F P
0 g
s
.721 .643 .084 r
.7882 .19371 m .78861 .18905 L .78815 .19368 L p F P
0 g
s
.503 .595 .879 r
.75828 .12996 m .76508 .13024 L .76545 .13475 L p F P
0 g
s
.449 .541 .858 r
.76957 .13086 m .76508 .13024 L .76545 .13475 L p F P
0 g
s
.449 .541 .858 r
.76545 .13475 m .7721 .13593 L .76957 .13086 L p F P
0 g
s
.85 .903 .489 r
.5993 .27519 m .59797 .27993 L .60045 .27456 L p F P
0 g
s
.85 .903 .489 r
.60045 .27456 m .60089 .27302 L .5993 .27519 L p F P
0 g
s
.516 .605 .881 r
.76508 .13024 m .75828 .12996 L .7558 .1256 L p F P
0 g
s
0 0 .128 r
.58543 .31389 m .58427 .31621 L .58536 .31131 L p F P
0 g
s
0 0 .128 r
.58536 .31131 m .58592 .31019 L .58543 .31389 L p F P
0 g
s
.905 .913 .816 r
.6436 .19355 m .64269 .19304 L .64366 .19186 L closepath p F P
0 g
s
.775 .876 .921 r
.66605 .34805 m .66433 .34671 L .6678 .34451 L closepath p F P
0 g
s
.272 .4 .809 r
.77862 .14788 m .77721 .14699 L .77464 .14129 L p F P
0 g
s
.936 .954 .764 r
.62598 .22293 m .62469 .2228 L .6263 .22047 L closepath p F P
0 g
s
.932 .956 .639 r
.60931 .25537 m .60761 .25855 L .60807 .25614 L closepath p F P
0 g
s
.717 .82 .929 r
.62999 .36238 m .62956 .36258 L .62983 .36222 L closepath p F P
0 g
s
.713 .799 .918 r
.62739 .35981 m .62983 .36222 L .62956 .36258 L p F P
0 g
s
.713 .799 .918 r
.61677 .36459 m .62739 .35981 L p .62956 .36258 L F P
0 g
s
.749 .847 .925 r
.6512 .35102 m .65221 .35188 L .65014 .35519 L p F P
0 g
s
.749 .847 .925 r
.64059 .35686 m .6512 .35102 L p .65014 .35519 L F P
0 g
s
.753 .864 .93 r
.65374 .35313 m .65014 .35519 L .65221 .35188 L closepath p F P
0 g
s
.79 .889 .916 r
.67975 .3401 m .6774 .3417 L .67492 .33987 L p F P
0 g
s
.728 .823 .924 r
.63801 .35452 m .64059 .35686 L .62999 .36238 L p F P
0 g
s
.728 .823 .924 r
.63265 .35721 m .63801 .35452 L p .62999 .36238 L F P
0 g
s
.728 .823 .924 r
.62999 .36238 m .62983 .36222 L .63265 .35721 L p F P
0 g
s
.931 .925 .554 r
.78105 .22316 m .78042 .22785 L .78266 .22256 L p F P
0 g
s
.931 .925 .554 r
.78266 .22256 m .78333 .21785 L .78105 .22316 L p F P
0 g
s
.626 .712 .908 r
.59018 .3647 m .60082 .36204 L .6035 .36562 L p F P
0 g
s
.595 .676 .897 r
.60082 .36204 m .59018 .3647 L .58746 .35992 L p F P
0 g
s
.886 .836 .37 r
.78552 .20809 m .78513 .21272 L .78644 .20777 L p F P
0 g
s
.886 .836 .37 r
.78644 .20777 m .78686 .20313 L .78552 .20809 L p F P
0 g
s
.925 .932 .792 r
.63442 .20772 m .63242 .207 L .63465 .20398 L closepath p F P
0 g
s
0 0 .557 r
.78687 .16268 m .78691 .16724 L .78508 .16349 L p F P
0 g
s
0 0 .557 r
.78508 .16349 m .785 .15894 L .78687 .16268 L p F P
0 g
s
.906 .892 .805 r
.65049 .17851 m .6485 .18105 L .64882 .18556 L p F P
0 g
s
.906 .892 .805 r
.64362 .18725 m .64366 .19186 L .64882 .18556 L p F P
0 g
s
.906 .892 .805 r
.64882 .18556 m .6485 .18105 L .64362 .18725 L p F P
0 g
s
.723 .816 .923 r
.62983 .36222 m .62739 .35981 L .63265 .35721 L closepath p F P
0 g
s
.794 .897 .916 r
.67975 .3401 m .68796 .33433 L .68551 .33262 L p F P
0 g
s
.794 .897 .916 r
.68551 .33262 m .68217 .33495 L .67975 .3401 L p F P
0 g
s
.79 .889 .916 r
.67492 .33987 m .68217 .33495 L .67975 .3401 L p F P
0 g
s
.933 .967 .743 r
.76992 .25162 m .76892 .25154 L .77034 .2494 L closepath p F P
0 g
s
.915 .975 .778 r
.76099 .26599 m .76082 .26622 L .76088 .26598 L closepath p F P
0 g
s
0 0 0 r
.5916 .29571 m .58963 .30085 L .59144 .2957 L p F P
0 g
s
0 0 0 r
.59144 .2957 m .5926 .2927 L .5916 .29571 L p F P
0 g
s
.674 .72 .884 r
.72901 .12394 m .73985 .1198 L .74232 .12369 L p F P
0 g
s
.681 .726 .884 r
.73985 .1198 m .72901 .12394 L .72654 .12032 L p F P
0 g
s
.936 .967 .724 r
.61556 .23769 m .61906 .23197 L .61836 .23679 L p F P
0 g
s
.936 .967 .724 r
.6153 .23927 m .61556 .23769 L p .61836 .23679 L F P
0 g
s
.936 .967 .724 r
.61836 .23679 m .61699 .23894 L .6153 .23927 L p F P
0 g
s
.906 .968 .808 r
.7569 .26774 m .75571 .27256 L .76082 .26622 L p F P
0 g
s
.906 .968 .808 r
.75878 .26539 m .7569 .26774 L p .76082 .26622 L F P
0 g
s
.906 .968 .808 r
.76082 .26622 m .76088 .26598 L .75878 .26539 L p F P
0 g
s
.613 .681 .891 r
.74232 .12369 m .75114 .12175 L .75141 .12632 L p F P
0 g
s
.591 .66 .886 r
.75332 .12133 m .75114 .12175 L .75141 .12632 L p F P
0 g
s
.591 .66 .886 r
.75141 .12632 m .7558 .1256 L .75332 .12133 L p F P
0 g
s
.184 .105 .526 r
.58154 .33518 m .58007 .33739 L .57956 .33237 L p F P
0 g
s
.184 .105 .526 r
.57956 .33237 m .58045 .33102 L .58154 .33518 L p F P
0 g
s
.765 .866 .923 r
.66182 .34468 m .66433 .34671 L .65374 .35313 L p F P
0 g
s
.765 .866 .923 r
.65327 .34981 m .66182 .34468 L p .65374 .35313 L F P
0 g
s
.765 .866 .923 r
.65374 .35313 m .65221 .35188 L .65327 .34981 L p F P
0 g
s
.942 .931 .762 r
.62663 .21576 m .6263 .22047 L .63039 .21455 L p F P
0 g
s
.942 .931 .762 r
.63039 .21455 m .63048 .20993 L .62663 .21576 L p F P
0 g
s
.845 .93 .884 r
.72105 .31024 m .71954 .30936 L .72212 .30709 L closepath p F P
0 g
s
.919 .886 .467 r
.78494 .21449 m .78422 .21537 L .78513 .21272 L closepath p F P
0 g
s
0 0 .136 r
.58704 .3108 m .58543 .31389 L .58592 .31019 L p F P
0 g
s
0 0 .136 r
.58592 .31019 m .58814 .30589 L .58704 .3108 L p F P
0 g
s
.375 .478 .837 r
.77333 .14083 m .77329 .1384 L .77464 .14129 L closepath p F P
0 g
s
.916 .963 .796 r
.76088 .26598 m .75878 .26539 L .76182 .26147 L closepath p F P
0 g
s
.02 .165 .675 r
.78487 .15439 m .785 .15894 L .78237 .15549 L p F P
0 g
s
.02 .165 .675 r
.78237 .15549 m .78219 .15096 L .78487 .15439 L p F P
0 g
s
.928 .95 .615 r
.60577 .25916 m .60478 .26404 L .60761 .25855 L p F P
0 g
s
.928 .95 .615 r
.60682 .25705 m .60577 .25916 L p .60761 .25855 L F P
0 g
s
.928 .95 .615 r
.60761 .25855 m .60807 .25614 L .60682 .25705 L p F P
0 g
s
.622 .682 .886 r
.75114 .12175 m .74232 .12369 L .73985 .1198 L p F P
0 g
s
.698 .799 .928 r
.62739 .35981 m .61677 .36459 L .61413 .36165 L p F P
0 g
s
.676 .775 .925 r
.6035 .36562 m .61413 .36165 L .61677 .36459 L p F P
0 g
s
.938 .966 .713 r
.77113 .24469 m .77034 .2494 L .77384 .24364 L p F P
0 g
s
.938 .966 .713 r
.77384 .24364 m .77469 .2389 L .77113 .24469 L p F P
0 g
s
.272 .4 .809 r
.77464 .14129 m .77831 .14338 L .77862 .14788 L p F P
0 g
s
.163 .303 .761 r
.78197 .14643 m .78219 .15096 L .77862 .14788 L p F P
0 g
s
.163 .303 .761 r
.77862 .14788 m .77831 .14338 L .78197 .14643 L p F P
0 g
s
.829 .9 .486 r
.59939 .27493 m .5993 .27519 L .60089 .27302 L p F P
0 g
s
.829 .9 .486 r
.60089 .27302 m .60203 .2695 L .59939 .27493 L p F P
0 g
s
.952 .954 .703 r
.61699 .23894 m .61496 .24246 L .6153 .23927 L closepath p F P
0 g
s
.66 .755 .92 r
.61413 .36165 m .6035 .36562 L .60082 .36204 L p F P
0 g
s
0 0 .087 r
.78867 .18824 m .78861 .18905 L .78856 .18461 L p F P
0 g
s
0 0 .087 r
.78856 .18461 m .78858 .18436 L .78867 .18824 L p F P
0 g
s
.904 .909 .815 r
.64017 .19158 m .64362 .18725 L .64366 .19186 L p F P
0 g
s
.904 .909 .815 r
.64366 .19186 m .64269 .19304 L .64017 .19158 L p F P
0 g
s
.722 .77 .89 r
.71757 .12498 m .71582 .12588 L .71334 .12249 L p F P
0 g
s
.759 .782 .871 r
.70271 .12934 m .71334 .12249 L .71582 .12588 L p F P
0 g
s
.804 .901 .91 r
.69229 .33118 m .68796 .33433 L .68551 .33262 L p F P
0 g
s
0 0 .051 r
.78875 .18446 m .78867 .18824 L .78858 .18436 L p F P
0 g
s
0 0 .051 r
.78858 .18436 m .78867 .18004 L .78875 .18446 L p F P
0 g
s
.926 .906 .784 r
.63912 .19793 m .64269 .19304 L .64017 .19158 L p F P
0 g
s
.816 .831 .861 r
.68934 .13959 m .68166 .14601 L .67953 .14364 L p F P
0 g
s
.838 .833 .842 r
.68166 .14601 m .68025 .14735 L .67953 .14364 L closepath p F P
0 g
s
.842 .835 .84 r
.67207 .15009 m .67253 .1546 L .68025 .14735 L p F P
0 g
s
.842 .835 .84 r
.67916 .14322 m .67207 .15009 L p .68025 .14735 L F P
0 g
s
.842 .835 .84 r
.68025 .14735 m .67953 .14364 L .67916 .14322 L p F P
0 g
s
.824 .872 .431 r
.59723 .28019 m .59565 .28524 L .59797 .27993 L p F P
0 g
s
.824 .872 .431 r
.59918 .2754 m .59723 .28019 L p .59797 .27993 L F P
0 g
s
.824 .872 .431 r
.59797 .27993 m .5993 .27519 L .59918 .2754 L p F P
0 g
s
.902 .964 .817 r
.75142 .27422 m .7569 .26774 L .75571 .27256 L p F P
0 g
s
.902 .964 .817 r
.75046 .27836 m .75142 .27422 L p .75571 .27256 L F P
0 g
s
.902 .964 .817 r
.75571 .27256 m .75076 .27845 L .75046 .27836 L p F P
0 g
s
.84 .851 .853 r
.66872 .15329 m .67207 .15009 L .67253 .1546 L p F P
0 g
s
.84 .851 .853 r
.67253 .1546 m .67123 .15581 L .66872 .15329 L p F P
0 g
s
.868 .859 .83 r
.66584 .16146 m .67123 .15581 L .66872 .15329 L p F P
0 g
s
.73 .771 .886 r
.71757 .12498 m .72654 .12032 L .72407 .11671 L p F P
0 g
s
.73 .771 .886 r
.72407 .11671 m .71722 .12041 L .71757 .12498 L p F P
0 g
s
.722 .77 .89 r
.71334 .12249 m .71722 .12041 L .71757 .12498 L p F P
0 g
s
.252 .4 .818 r
.77329 .1384 m .77464 .14129 L .77831 .14338 L p F P
0 g
s
.809 .91 .909 r
.69229 .33118 m .69851 .32652 L .69608 .32492 L p F P
0 g
s
.809 .91 .909 r
.69608 .32492 m .69454 .32607 L .69229 .33118 L p F P
0 g
s
.804 .901 .91 r
.68551 .33262 m .69454 .32607 L .69229 .33118 L p F P
0 g
s
.82 .822 .851 r
.68934 .13959 m .69215 .1372 L .68966 .13419 L p F P
0 g
s
.82 .822 .851 r
.68966 .13419 m .68847 .13523 L .68934 .13959 L p F P
0 g
s
.816 .831 .861 r
.67947 .14296 m .68847 .13523 L .68934 .13959 L p F P
0 g
s
.816 .831 .861 r
.67953 .14364 m .67947 .14296 L p .68934 .13959 L F P
0 g
s
.485 .485 .782 r
.58112 .35318 m .58324 .35017 L .5847 .3539 L closepath p F P
0 g
s
.138 .069 .509 r
.58477 .32964 m .58154 .33518 L .58045 .33102 L p F P
0 g
s
.138 .069 .509 r
.58045 .33102 m .5838 .32544 L .58477 .32964 L p F P
0 g
s
.791 .813 .87 r
.70038 .1311 m .69215 .1372 L .68966 .13419 L p F P
0 g
s
.946 .945 .62 r
.77841 .22861 m .77782 .23328 L .78042 .22785 L p F P
0 g
s
.946 .945 .62 r
.78042 .22785 m .78105 .22316 L .77841 .22861 L p F P
0 g
s
.936 .95 .766 r
.62275 .22161 m .62663 .21576 L .6263 .22047 L p F P
0 g
s
.936 .95 .766 r
.62266 .22253 m .62275 .22161 L p .6263 .22047 L F P
0 g
s
.936 .95 .766 r
.6263 .22047 m .62469 .2228 L .62266 .22253 L p F P
0 g
s
0 0 .244 r
.5852 .31794 m .5837 .32093 L .58427 .31621 L p F P
0 g
s
0 0 .244 r
.58427 .31621 m .58543 .31389 L .5852 .31794 L p F P
0 g
s
.83 .764 .252 r
.78722 .19848 m .78686 .20313 L .78776 .19833 L p F P
0 g
s
.83 .764 .252 r
.78776 .19833 m .78815 .19368 L .78722 .19848 L p F P
0 g
s
.947 .956 .668 r
.77755 .23515 m .77672 .23531 L .77782 .23328 L closepath p F P
0 g
s
.868 .859 .83 r
.66872 .15329 m .66526 .15701 L .66584 .16146 L p F P
0 g
s
.863 .866 .84 r
.65889 .16376 m .66526 .15701 L .66584 .16146 L p F P
0 g
s
.863 .866 .84 r
.65897 .16494 m .65889 .16376 L p .66584 .16146 L F P
0 g
s
.863 .866 .84 r
.66584 .16146 m .66084 .16662 L .65897 .16494 L p F P
0 g
s
.954 .952 .688 r
.61244 .24328 m .6118 .24806 L .61496 .24246 L p F P
0 g
s
.954 .952 .688 r
.61448 .23949 m .61244 .24328 L p .61496 .24246 L F P
0 g
s
.954 .952 .688 r
.61496 .24246 m .6153 .23927 L .61448 .23949 L p F P
0 g
s
.896 .967 .825 r
.75076 .27845 m .75028 .27901 L .75046 .27836 L closepath p F P
0 g
s
.922 .887 .471 r
.78379 .2132 m .78552 .20809 L .78513 .21272 L p F P
0 g
s
.922 .887 .471 r
.78354 .21618 m .78379 .2132 L p .78513 .21272 L F P
0 g
s
.922 .887 .471 r
.78513 .21272 m .78422 .21537 L .78354 .21618 L p F P
0 g
s
.884 .956 .845 r
.74543 .28088 m .74412 .28572 L .75028 .27901 L p F P
0 g
s
.884 .956 .845 r
.7485 .27752 m .74543 .28088 L p .75028 .27901 L F P
0 g
s
.884 .956 .845 r
.75028 .27901 m .75046 .27836 L .7485 .27752 L p F P
0 g
s
.926 .906 .784 r
.64017 .19158 m .63888 .1934 L .63912 .19793 L p F P
0 g
s
.927 .907 .783 r
.63465 .19937 m .63465 .20398 L .63912 .19793 L p F P
0 g
s
.927 .907 .783 r
.63912 .19793 m .63888 .1934 L .63465 .19937 L p F P
0 g
s
0 0 .229 r
.78871 .17547 m .78867 .18004 L .78807 .17581 L p F P
0 g
s
0 0 .229 r
.78807 .17581 m .7881 .17124 L .78871 .17547 L p F P
0 g
s
.881 .864 .818 r
.66084 .16662 m .65946 .16821 L .65897 .16494 L closepath p F P
0 g
s
.818 .912 .903 r
.70334 .32276 m .69851 .32652 L .69608 .32492 L p F P
0 g
s
.742 .846 .928 r
.6512 .35102 m .64059 .35686 L .63801 .35452 L p F P
0 g
s
.563 .59 .839 r
.58733 .35993 m .58741 .35982 L .58746 .35992 L closepath p F P
0 g
s
.934 .967 .744 r
.76726 .25059 m .77113 .24469 L .77034 .2494 L p F P
0 g
s
.934 .967 .744 r
.76713 .25139 m .76726 .25059 L p .77034 .2494 L F P
0 g
s
.934 .967 .744 r
.77034 .2494 m .76892 .25154 L .76713 .25139 L p F P
0 g
s
.95 .937 .742 r
.62469 .2228 m .62255 .22626 L .62266 .22253 L closepath p F P
0 g
s
.599 .608 .833 r
.58741 .35982 m .58746 .35992 L .59813 .35809 L p F P
0 g
s
.595 .676 .897 r
.58746 .35992 m .59813 .35809 L .60082 .36204 L p F P
0 g
s
.516 .605 .881 r
.7558 .1256 m .76472 .12571 L .76508 .13024 L p F P
0 g
s
.527 .614 .882 r
.76472 .12571 m .7558 .1256 L .75332 .12133 L p F P
0 g
s
.909 .932 .558 r
.60324 .26455 m .60203 .2695 L .60478 .26404 L p F P
0 g
s
.909 .932 .558 r
.60478 .26404 m .60577 .25916 L .60324 .26455 L p F P
0 g
s
.775 .871 .919 r
.6678 .34451 m .66433 .34671 L .66182 .34468 L p F P
0 g
s
.538 .55 .815 r
.5847 .3539 m .59187 .35401 L .58741 .35982 L closepath p F P
0 g
s
.599 .608 .833 r
.59541 .35368 m .59187 .35401 L .58741 .35982 L p F P
0 g
s
.599 .608 .833 r
.59813 .35809 m .59541 .35368 L p .58741 .35982 L F P
0 g
s
.885 .866 .815 r
.65344 .17017 m .65386 .17467 L .65946 .16821 L p F P
0 g
s
.885 .866 .815 r
.65832 .16436 m .65344 .17017 L p .65946 .16821 L F P
0 g
s
.885 .866 .815 r
.65946 .16821 m .65897 .16494 L .65832 .16436 L p F P
0 g
s
0 0 0 r
.59026 .30068 m .58814 .30589 L .58963 .30085 L p F P
0 g
s
0 0 0 r
.59159 .29575 m .59026 .30068 L p .58963 .30085 L F P
0 g
s
0 0 0 r
.58963 .30085 m .5916 .29571 L .59159 .29575 L p F P
0 g
s
.823 .92 .901 r
.70334 .32276 m .70904 .31821 L .70664 .31671 L p F P
0 g
s
.823 .92 .901 r
.70664 .31671 m .70538 .31772 L .70334 .32276 L p F P
0 g
s
.818 .912 .903 r
.69608 .32492 m .70538 .31772 L .70334 .32276 L p F P
0 g
s
.795 .805 .86 r
.70038 .1311 m .70271 .12934 L .70022 .12613 L p F P
0 g
s
.795 .805 .86 r
.70022 .12613 m .6994 .12676 L .70038 .1311 L p F P
0 g
s
.791 .813 .87 r
.68966 .13419 m .6994 .12676 L .70038 .1311 L p F P
0 g
s
.352 .474 .844 r
.7721 .13593 m .77307 .1363 L .77329 .1384 L closepath p F P
0 g
s
.252 .4 .818 r
.77795 .13888 m .77307 .1363 L .77329 .1384 L p F P
0 g
s
.252 .4 .818 r
.77831 .14338 m .77795 .13888 L p .77329 .1384 L F P
0 g
s
.291 .239 .625 r
.58404 .33886 m .58116 .34315 L .58007 .33739 L p F P
0 g
s
.291 .239 .625 r
.58007 .33739 m .58154 .33518 L .58404 .33886 L p F P
0 g
s
.894 .953 .833 r
.75046 .27836 m .7485 .27752 L .75142 .27422 L closepath p F P
0 g
s
.928 .97 .752 r
.76892 .25154 m .7663 .25535 L .76713 .25139 L closepath p F P
0 g
s
.881 .951 .85 r
.73892 .28772 m .74543 .28088 L .74412 .28572 L p F P
0 g
s
.881 .951 .85 r
.73864 .28881 m .73892 .28772 L p .74412 .28572 L F P
0 g
s
.881 .951 .85 r
.74412 .28572 m .74042 .28961 L .73864 .28881 L p F P
0 g
s
.913 .956 .622 r
.60807 .25614 m .60682 .25705 L .60867 .25365 L closepath p F P
0 g
s
.764 .783 .869 r
.71334 .12249 m .70271 .12934 L .70022 .12613 L p F P
0 g
s
.374 .345 .698 r
.5802 .34458 m .58116 .34315 L .58188 .34584 L closepath p F P
0 g
s
.758 .856 .923 r
.65221 .35188 m .6512 .35102 L .65327 .34981 L closepath p F P
0 g
s
.777 .879 .921 r
.6678 .34451 m .67492 .33987 L .67243 .33798 L p F P
0 g
s
.777 .879 .921 r
.67243 .33798 m .67039 .33929 L .6678 .34451 L p F P
0 g
s
.775 .871 .919 r
.66182 .34468 m .67039 .33929 L .6678 .34451 L p F P
0 g
s
.832 .921 .894 r
.71321 .31476 m .70904 .31821 L .70664 .31671 L p F P
0 g
s
.874 .953 .857 r
.74042 .28961 m .73747 .2926 L .73864 .28881 L closepath p F P
0 g
s
0 0 0 r
.59161 .29568 m .5916 .29571 L .5926 .2927 L p F P
0 g
s
0 0 0 r
.5926 .2927 m .59351 .2905 L .59161 .29568 L p F P
0 g
s
.838 .928 .89 r
.71321 .31476 m .71954 .30936 L .71717 .30795 L p F P
0 g
s
.838 .928 .89 r
.71717 .30795 m .71501 .30979 L .71321 .31476 L p F P
0 g
s
.832 .921 .894 r
.70664 .31671 m .71501 .30979 L .71321 .31476 L p F P
0 g
s
.913 .891 .474 r
.78422 .21537 m .78333 .21785 L .78354 .21618 L closepath p F P
0 g
s
.885 .884 .826 r
.64796 .17656 m .65344 .17017 L .65386 .17467 L p F P
0 g
s
.885 .884 .826 r
.65386 .17467 m .65049 .17851 L .64796 .17656 L p F P
0 g
s
.859 .938 .873 r
.73015 .29999 m .73001 .29991 L .73024 .29969 L closepath p F P
0 g
s
.741 .797 .314 r
.5953 .28538 m .59351 .2905 L .59565 .28524 L p F P
0 g
s
.741 .797 .314 r
.59565 .28524 m .59723 .28019 L .5953 .28538 L p F P
0 g
s
.954 .938 .732 r
.61937 .22729 m .61906 .23197 L .62255 .22626 L p F P
0 g
s
.954 .938 .732 r
.62217 .22249 m .61937 .22729 L p .62255 .22626 L F P
0 g
s
.954 .938 .732 r
.62255 .22626 m .62266 .22253 L .62217 .22249 L p F P
0 g
s
.862 .941 .87 r
.73163 .29484 m .73024 .29969 L .73747 .2926 L p F P
0 g
s
.862 .941 .87 r
.73812 .28853 m .73163 .29484 L p .73747 .2926 L F P
0 g
s
.862 .941 .87 r
.73747 .2926 m .73864 .28881 L .73812 .28853 L p F P
0 g
s
0 0 .406 r
.78807 .16668 m .7881 .17124 L .78691 .16724 L p F P
0 g
s
0 0 .406 r
.78691 .16724 m .78687 .16268 L .78807 .16668 L p F P
0 g
s
.924 .926 .792 r
.63035 .20537 m .63465 .19937 L .63465 .20398 L p F P
0 g
s
.924 .926 .792 r
.63033 .20617 m .63035 .20537 L p .63465 .20398 L F P
0 g
s
.924 .926 .792 r
.63465 .20398 m .63242 .207 L .63033 .20617 L p F P
0 g
s
.464 .558 .866 r
.76705 .12595 m .76472 .12571 L .76508 .13024 L p F P
0 g
s
.464 .558 .866 r
.76508 .13024 m .76957 .13086 L .76705 .12595 L p F P
0 g
s
.845 .928 .884 r
.72212 .30709 m .71954 .30936 L .71717 .30795 L p F P
0 g
s
.852 .935 .879 r
.72212 .30709 m .73001 .29991 L .72767 .29857 L p F P
0 g
s
.852 .935 .879 r
.72767 .29857 m .7237 .30218 L .72212 .30709 L p F P
0 g
s
.845 .928 .884 r
.71717 .30795 m .7237 .30218 L .72212 .30709 L p F P
0 g
s
.858 .933 .873 r
.72767 .29857 m .73163 .29484 L .73024 .29969 L p F P
0 g
s
.858 .933 .873 r
.73024 .29969 m .73001 .29991 L .72767 .29857 L p F P
0 g
s
.948 .952 .655 r
.60953 .24879 m .60867 .25365 L .6118 .24806 L p F P
0 g
s
.948 .952 .655 r
.6118 .24806 m .61244 .24328 L .60953 .24879 L p F P
0 g
s
.744 .659 .104 r
.7883 .19144 m .78815 .19368 L .78861 .18905 L p F P
0 g
s
.744 .659 .104 r
.78861 .18905 m .78867 .18824 L .7883 .19144 L p F P
0 g
s
.948 .955 .669 r
.77542 .23419 m .77841 .22861 L .77782 .23328 L p F P
0 g
s
.948 .955 .669 r
.77525 .23557 m .77542 .23419 L p .77782 .23328 L F P
0 g
s
.948 .955 .669 r
.77782 .23328 m .77672 .23531 L .77525 .23557 L p F P
0 g
s
.92 .966 .786 r
.76275 .25672 m .76182 .26147 L .7663 .25535 L p F P
0 g
s
.92 .966 .786 r
.76675 .25129 m .76275 .25672 L p .7663 .25535 L F P
0 g
s
.92 .966 .786 r
.7663 .25535 m .76713 .25139 L .76675 .25129 L p F P
0 g
s
.723 .806 .917 r
.63265 .35721 m .62739 .35981 L .62477 .3571 L p F P
0 g
s
.698 .799 .928 r
.61413 .36165 m .62477 .3571 L .62739 .35981 L p F P
0 g
s
.907 .882 .798 r
.6485 .18105 m .65049 .17851 L .64796 .17656 L p F P
0 g
s
.681 .726 .884 r
.72654 .12032 m .73738 .11595 L .73985 .1198 L p F P
0 g
s
.688 .731 .884 r
.73738 .11595 m .72654 .12032 L .72407 .11671 L p F P
0 g
s
.367 .49 .852 r
.77307 .1363 m .7721 .13593 L .76957 .13086 L p F P
0 g
s
.631 .689 .886 r
.75084 .11713 m .73985 .1198 L .73738 .11595 L p F P
0 g
s
.622 .682 .886 r
.7511 .11756 m .75114 .12175 L p .73985 .1198 L F P
0 g
s
.622 .682 .886 r
.73985 .1198 m .75084 .11713 L .7511 .11756 L p F P
0 g
s
.938 .916 .767 r
.63242 .207 m .63048 .20993 L .63033 .20617 L closepath p F P
0 g
s
0 0 .253 r
.58645 .31553 m .5852 .31794 L .58543 .31389 L p F P
0 g
s
0 0 .253 r
.58543 .31389 m .58704 .3108 L .58645 .31553 L p F P
0 g
s
.789 .886 .915 r
.68217 .33495 m .67492 .33987 L .67243 .33798 L p F P
0 g
s
.544 .52 .779 r
.58324 .35017 m .5847 .3539 L .59187 .35401 L p F P
0 g
s
.66 .755 .92 r
.60082 .36204 m .61148 .3585 L .61413 .36165 L p F P
0 g
s
.638 .73 .915 r
.61148 .3585 m .60082 .36204 L .59813 .35809 L p F P
0 g
s
0 .003 .56 r
.78678 .15812 m .78687 .16268 L .785 .15894 L p F P
0 g
s
0 .003 .56 r
.785 .15894 m .78487 .15439 L .78678 .15812 L p F P
0 g
s
.907 .882 .798 r
.64796 .17656 m .64793 .17661 L .6485 .18105 L p F P
0 g
s
.909 .882 .796 r
.64329 .18272 m .64362 .18725 L .6485 .18105 L p F P
0 g
s
.909 .882 .796 r
.6485 .18105 m .64793 .17661 L .64329 .18272 L p F P
0 g
s
.942 .96 .677 r
.77672 .23531 m .77469 .2389 L .77525 .23557 L closepath p F P
0 g
s
.898 .844 .387 r
.78586 .20346 m .78552 .20809 L .78686 .20313 L p F P
0 g
s
.898 .844 .387 r
.78686 .20313 m .78722 .19848 L .78586 .20346 L p F P
0 g
s
.874 .91 .504 r
.60083 .2699 m .59939 .27493 L .60203 .2695 L p F P
0 g
s
.874 .91 .504 r
.60203 .2695 m .60324 .26455 L .60083 .2699 L p F P
0 g
s
.94 .929 .571 r
.78163 .21847 m .78105 .22316 L .78333 .21785 L p F P
0 g
s
.94 .929 .571 r
.78226 .21698 m .78163 .21847 L p .78333 .21785 L F P
0 g
s
.94 .929 .571 r
.78333 .21785 m .78354 .21618 L .78226 .21698 L p F P
0 g
s
.451 .395 .704 r
.58856 .34184 m .58404 .33886 L .58116 .34315 L p F P
0 g
s
.451 .395 .704 r
.58523 .34738 m .58856 .34184 L p .58116 .34315 L F P
0 g
s
.451 .395 .704 r
.58116 .34315 m .58188 .34584 L .58523 .34738 L p F P
0 g
s
.784 .676 .126 r
.78836 .18907 m .7883 .19144 L .78867 .18824 L p F P
0 g
s
.784 .676 .126 r
.78867 .18824 m .78875 .18446 L .78836 .18907 L p F P
0 g
s
.687 .785 .925 r
.62477 .3571 m .61413 .36165 L .61148 .3585 L p F P
0 g
s
0 0 .37 r
.5853 .32242 m .5838 .32544 L .5837 .32093 L p F P
0 g
s
0 0 .37 r
.5837 .32093 m .5852 .31794 L .5853 .32242 L p F P
0 g
s
.602 .67 .888 r
.75114 .12175 m .7511 .11756 L .75332 .12133 L closepath p F P
0 g
s
.429 .407 .734 r
.58188 .34584 m .58523 .34738 L .58324 .35017 L closepath p F P
0 g
s
.757 .849 .919 r
.65327 .34981 m .6512 .35102 L .64865 .34875 L p F P
0 g
s
.742 .846 .928 r
.63801 .35452 m .64865 .34875 L .6512 .35102 L p F P
0 g
s
.367 .49 .852 r
.76957 .13086 m .77253 .13185 L .77307 .1363 L p F P
0 g
s
.288 .425 .826 r
.77756 .13438 m .77795 .13888 L .77307 .1363 L p F P
0 g
s
.288 .425 .826 r
.77307 .1363 m .77253 .13185 L .77756 .13438 L p F P
0 g
s
.819 .833 .86 r
.67953 .14364 m .67916 .14322 L .67947 .14296 L closepath p F P
0 g
s
.544 .52 .779 r
.59267 .34855 m .58523 .34738 L .58324 .35017 L p F P
0 g
s
.544 .52 .779 r
.59378 .35074 m .59267 .34855 L p .58324 .35017 L F P
0 g
s
.544 .52 .779 r
.59187 .35401 m .59378 .35074 L p .58324 .35017 L F P
0 g
s
0 0 .075 r
.58929 .30555 m .58704 .3108 L .58814 .30589 L p F P
0 g
s
0 0 .075 r
.58814 .30589 m .59026 .30068 L .58929 .30555 L p F P
0 g
s
.024 .172 .681 r
.78471 .14984 m .78487 .15439 L .78219 .15096 L p F P
0 g
s
.024 .172 .681 r
.78219 .15096 m .78197 .14643 L .78471 .14984 L p F P
0 g
s
.729 .772 .888 r
.71722 .12041 m .71334 .12249 L .71086 .11909 L p F P
0 g
s
.764 .783 .869 r
.70022 .12613 m .71086 .11909 L .71334 .12249 L p F P
0 g
s
.943 .917 .759 r
.62664 .21115 m .62663 .21576 L .63048 .20993 L p F P
0 g
s
.943 .917 .759 r
.62989 .20602 m .62664 .21115 L p .63048 .20993 L F P
0 g
s
.943 .917 .759 r
.63048 .20993 m .63033 .20617 L .62989 .20602 L p F P
0 g
s
.955 .946 .714 r
.6161 .23293 m .61556 .23769 L .61906 .23197 L p F P
0 g
s
.955 .946 .714 r
.61906 .23197 m .61937 .22729 L .6161 .23293 L p F P
0 g
s
.916 .962 .796 r
.75792 .26297 m .76275 .25672 L .76182 .26147 L p F P
0 g
s
.916 .962 .796 r
.75753 .26503 m .75792 .26297 L p .76182 .26147 L F P
0 g
s
.916 .962 .796 r
.76182 .26147 m .75878 .26539 L .75753 .26503 L p F P
0 g
s
.17 .313 .767 r
.78171 .1419 m .78197 .14643 L .77831 .14338 L p F P
0 g
s
.17 .313 .767 r
.77831 .14338 m .77795 .13888 L .78171 .1419 L p F P
0 g
s
.239 .198 .608 r
.58693 .33344 m .58404 .33886 L .58154 .33518 L p F P
0 g
s
.239 .198 .608 r
.58154 .33518 m .58477 .32964 L .58693 .33344 L p F P
0 g
s
.942 .963 .703 r
.6153 .23927 m .61448 .23949 L .61556 .23769 L closepath p F P
0 g
s
.727 .828 .927 r
.63801 .35452 m .63265 .35721 L .63578 .35239 L closepath p F P
0 g
s
.723 .806 .917 r
.63543 .35205 m .63578 .35239 L .63265 .35721 L p F P
0 g
s
.723 .806 .917 r
.62477 .3571 m .63543 .35205 L p .63265 .35721 L F P
0 g
s
.757 .849 .919 r
.64865 .34875 m .65589 .34458 L .65327 .34981 L p F P
0 g
s
.758 .856 .923 r
.65327 .34981 m .66182 .34468 L .65929 .34258 L p F P
0 g
s
.758 .856 .923 r
.65929 .34258 m .65589 .34458 L .65327 .34981 L p F P
0 g
s
0 0 .038 r
.78878 .1799 m .78875 .18446 L .78867 .18004 L p F P
0 g
s
0 0 .038 r
.78867 .18004 m .78871 .17547 L .78878 .1799 L p F P
0 g
s
.794 .897 .916 r
.68551 .33262 m .68217 .33495 L .68383 .33141 L closepath p F P
0 g
s
.789 .886 .915 r
.68304 .33081 m .68383 .33141 L .68217 .33495 L p F P
0 g
s
.789 .886 .915 r
.67243 .33798 m .68304 .33081 L p .68217 .33495 L F P
0 g
s
.939 .964 .728 r
.77187 .23998 m .77113 .24469 L .77469 .2389 L p F P
0 g
s
.939 .964 .728 r
.77461 .23554 m .77187 .23998 L p .77469 .2389 L F P
0 g
s
.939 .964 .728 r
.77469 .2389 m .77525 .23557 L .77461 .23554 L p F P
0 g
s
.907 .902 .809 r
.63853 .18889 m .64329 .18272 L .64362 .18725 L p F P
0 g
s
.907 .902 .809 r
.63859 .19061 m .63853 .18889 L p .64362 .18725 L F P
0 g
s
.907 .902 .809 r
.64362 .18725 m .64017 .19158 L .63859 .19061 L p F P
0 g
s
.819 .832 .859 r
.67947 .14296 m .67916 .14322 L .67665 .14042 L p F P
0 g
s
.849 .845 .839 r
.67207 .15009 m .67916 .14322 L .67665 .14042 L p F P
0 g
s
.918 .957 .628 r
.60669 .25429 m .60953 .24879 L .60867 .25365 L p F P
0 g
s
.918 .957 .628 r
.60601 .25761 m .60669 .25429 L p .60867 .25365 L F P
0 g
s
.918 .957 .628 r
.60867 .25365 m .60682 .25705 L .60601 .25761 L p F P
0 g
s
.822 .819 .846 r
.67888 .13848 m .67947 .14296 L .68847 .13523 L p F P
0 g
s
.819 .832 .859 r
.67665 .14042 m .67888 .13848 L .67947 .14296 L p F P
0 g
s
0 0 0 r
.59359 .2905 m .59161 .29568 L .59351 .2905 L p F P
0 g
s
0 0 0 r
.59351 .2905 m .5953 .28538 L .59359 .2905 L p F P
0 g
s
.868 .869 .836 r
.65897 .16494 m .65832 .16436 L .65889 .16376 L closepath p F P
0 g
s
.527 .614 .882 r
.75332 .12133 m .76438 .12116 L .76472 .12571 L p F P
0 g
s
.521 .629 .899 r
.7511 .11756 m .75332 .12133 L .76438 .12116 L p F P
0 g
s
.849 .845 .839 r
.67665 .14042 m .67138 .14566 L .67207 .15009 L p F P
0 g
s
.843 .847 .847 r
.6662 .15071 m .67138 .14566 L .67207 .15009 L p F P
0 g
s
.843 .847 .847 r
.67207 .15009 m .66872 .15329 L .6662 .15071 L p F P
0 g
s
.91 .965 .804 r
.75878 .26539 m .7569 .26774 L .75753 .26503 L closepath p F P
0 g
s
.869 .852 .823 r
.66526 .15701 m .66872 .15329 L .6662 .15071 L p F P
0 g
s
.803 .897 .91 r
.69454 .32607 m .68551 .33262 L .68383 .33141 L p F P
0 g
s
.818 .817 .848 r
.68966 .13419 m .68847 .13523 L .68762 .13171 L closepath p F P
0 g
s
.822 .819 .846 r
.68715 .13115 m .67888 .13848 L p .68847 .13523 L F P
0 g
s
.822 .819 .846 r
.68847 .13523 m .68762 .13171 L .68715 .13115 L p F P
0 g
s
.795 .813 .866 r
.6994 .12676 m .68966 .13419 L .68762 .13171 L p F P
0 g
s
.735 .771 .881 r
.71722 .12041 m .72407 .11671 L .72158 .1131 L p F P
0 g
s
.735 .771 .881 r
.72158 .1131 m .71646 .11598 L .71722 .12041 L p F P
0 g
s
.729 .772 .888 r
.71086 .11909 m .71646 .11598 L .71722 .12041 L p F P
0 g
s
.95 .921 .56 r
.78354 .21618 m .78226 .21698 L .78379 .2132 L closepath p F P
0 g
s
.797 .865 .424 r
.5993 .27519 m .59918 .2754 L .59939 .27493 L closepath p F P
0 g
s
.898 .956 .827 r
.75247 .26944 m .75142 .27422 L .7569 .26774 L p F P
0 g
s
.898 .956 .827 r
.75655 .26463 m .75247 .26944 L p .7569 .26774 L F P
0 g
s
.898 .956 .827 r
.7569 .26774 m .75753 .26503 L .75655 .26463 L p F P
0 g
s
.869 .852 .823 r
.6662 .15071 m .66446 .15262 L .66526 .15701 L p F P
0 g
s
.868 .851 .825 r
.65839 .15927 m .65889 .16376 L .66526 .15701 L p F P
0 g
s
.868 .851 .825 r
.66526 .15701 m .66446 .15262 L .65839 .15927 L p F P
0 g
s
.922 .894 .784 r
.64017 .19158 m .63888 .1934 L .63859 .19061 L closepath p F P
0 g
s
.803 .869 .429 r
.59855 .27521 m .60083 .2699 L .59939 .27493 L p F P
0 g
s
.803 .869 .429 r
.59787 .27757 m .59855 .27521 L p .59939 .27493 L F P
0 g
s
.803 .869 .429 r
.59939 .27493 m .59918 .2754 L .59787 .27757 L p F P
0 g
s
.846 .774 .269 r
.78752 .19401 m .78722 .19848 L .78815 .19368 L p F P
0 g
s
.846 .774 .269 r
.78815 .19368 m .7883 .19144 L .78752 .19401 L p F P
0 g
s
.95 .946 .631 r
.77893 .22394 m .77841 .22861 L .78105 .22316 L p F P
0 g
s
.95 .946 .631 r
.78105 .22316 m .78163 .21847 L .77893 .22394 L p F P
0 g
s
.947 .929 .752 r
.62298 .21693 m .62275 .22161 L .62663 .21576 L p F P
0 g
s
.947 .929 .752 r
.62663 .21576 m .62664 .21115 L .62298 .21693 L p F P
0 g
s
.848 .878 .441 r
.59918 .2754 m .59723 .28019 L .59787 .27757 L closepath p F P
0 g
s
.94 .946 .616 r
.60682 .25705 m .60577 .25916 L .60601 .25761 L closepath p F P
0 g
s
.739 .83 .921 r
.64608 .34639 m .64865 .34875 L .63801 .35452 L p F P
0 g
s
.739 .83 .921 r
.63611 .35169 m .64608 .34639 L p .63801 .35452 L F P
0 g
s
.739 .83 .921 r
.63801 .35452 m .63578 .35239 L .63611 .35169 L p F P
0 g
s
.382 .504 .858 r
.77253 .13185 m .76957 .13086 L .76705 .12595 L p F P
0 g
s
.927 .896 .778 r
.63436 .19484 m .63465 .19937 L .63888 .1934 L p F P
0 g
s
.927 .896 .778 r
.63764 .19005 m .63436 .19484 L p .63888 .1934 L F P
0 g
s
.927 .896 .778 r
.63888 .1934 m .63859 .19061 L .63764 .19005 L p F P
0 g
s
.945 .961 .707 r
.61283 .23857 m .6161 .23293 L .61556 .23769 L p F P
0 g
s
.945 .961 .707 r
.61266 .2399 m .61283 .23857 L p .61556 .23769 L F P
0 g
s
.945 .961 .707 r
.61556 .23769 m .61448 .23949 L .61266 .2399 L p F P
0 g
s
0 0 .222 r
.78869 .1709 m .78871 .17547 L .7881 .17124 L p F P
0 g
s
0 0 .222 r
.7881 .17124 m .78807 .16668 L .78869 .1709 L p F P
0 g
s
.937 .893 .491 r
.7841 .20858 m .78379 .2132 L .78552 .20809 L p F P
0 g
s
.937 .893 .491 r
.78552 .20809 m .78586 .20346 L .7841 .20858 L p F P
0 g
s
.866 .865 .835 r
.65579 .16207 m .65839 .15927 L .65889 .16376 L p F P
0 g
s
.866 .865 .835 r
.65889 .16376 m .65832 .16436 L .65579 .16207 L p F P
0 g
s
.892 .87 .809 r
.65344 .17017 m .65832 .16436 L .65579 .16207 L p F P
0 g
s
.795 .813 .866 r
.69772 .1229 m .69872 .12419 L .6994 .12676 L p F P
0 g
s
.795 .813 .866 r
.68751 .13087 m .69772 .1229 L p .6994 .12676 L F P
0 g
s
.795 .813 .866 r
.68762 .13171 m .68751 .13087 L p .6994 .12676 L F P
0 g
s
.794 .801 .858 r
.70022 .12613 m .6994 .12676 L .69872 .12419 L closepath p F P
0 g
s
.809 .907 .909 r
.69608 .32492 m .69454 .32607 L .69527 .32436 L closepath p F P
0 g
s
.803 .897 .91 r
.69364 .32316 m .69527 .32436 L .69454 .32607 L p F P
0 g
s
.803 .897 .91 r
.68443 .32983 m .69364 .32316 L p .69454 .32607 L F P
0 g
s
.803 .897 .91 r
.68383 .33141 m .68443 .32983 L p .69454 .32607 L F P
0 g
s
.766 .794 .876 r
.70836 .11567 m .71086 .11909 L .70022 .12613 L p F P
0 g
s
.766 .794 .876 r
.69849 .12238 m .70836 .11567 L p .70022 .12613 L F P
0 g
s
.766 .794 .876 r
.70022 .12613 m .69872 .12419 L .69849 .12238 L p F P
0 g
s
.772 .866 .919 r
.67039 .33929 m .66182 .34468 L .65929 .34258 L p F P
0 g
s
.817 .907 .902 r
.70538 .31772 m .69608 .32492 L .69527 .32436 L p F P
0 g
s
.937 .962 .749 r
.76794 .2459 m .76726 .25059 L .77113 .24469 L p F P
0 g
s
.937 .962 .749 r
.77113 .24469 m .77187 .23998 L .76794 .2459 L p F P
0 g
s
.943 .949 .751 r
.62266 .22253 m .62217 .22249 L .62275 .22161 L closepath p F P
0 g
s
.894 .952 .833 r
.74664 .27605 m .75247 .26944 L .75142 .27422 L p F P
0 g
s
.894 .952 .833 r
.74651 .27666 m .74664 .27605 L p .75142 .27422 L F P
0 g
s
.894 .952 .833 r
.75142 .27422 m .7485 .27752 L .74651 .27666 L p F P
0 g
s
.96 .946 .686 r
.61448 .23949 m .61244 .24328 L .61266 .2399 L closepath p F P
0 g
s
.872 .939 .86 r
.73864 .28881 m .73812 .28853 L .73892 .28772 L closepath p F P
0 g
s
.935 .938 .59 r
.60398 .25975 m .60324 .26455 L .60577 .25916 L p F P
0 g
s
.935 .938 .59 r
.60431 .25901 m .60398 .25975 L p .60577 .25916 L F P
0 g
s
.935 .938 .59 r
.60577 .25916 m .60601 .25761 L .60431 .25901 L p F P
0 g
s
0 0 .213 r
.58878 .31026 m .58645 .31553 L .58704 .3108 L p F P
0 g
s
0 0 .213 r
.58704 .3108 m .58929 .30555 L .58878 .31026 L p F P
0 g
s
.888 .954 .841 r
.7485 .27752 m .74543 .28088 L .74651 .27666 L closepath p F P
0 g
s
.638 .73 .915 r
.59813 .35809 m .60881 .3551 L .61148 .3585 L p F P
0 g
s
.611 .7 .907 r
.60881 .3551 m .59813 .35809 L .59541 .35368 L p F P
0 g
s
.074 .029 .496 r
.58584 .32748 m .58477 .32964 L .5838 .32544 L p F P
0 g
s
.074 .029 .496 r
.5838 .32544 m .5853 .32242 L .58584 .32748 L p F P
0 g
s
.631 .689 .886 r
.73738 .11595 m .74836 .11301 L .75084 .11713 L p F P
0 g
s
.639 .697 .887 r
.74836 .11301 m .73738 .11595 L .7349 .11212 L p F P
0 g
s
.688 .731 .884 r
.72407 .11671 m .7349 .11212 L .73738 .11595 L p F P
0 g
s
.694 .736 .883 r
.7349 .11212 m .72407 .11671 L .72158 .1131 L p F P
0 g
s
0 0 .379 r
.58655 .32004 m .5853 .32242 L .5852 .31794 L p F P
0 g
s
0 0 .379 r
.5852 .31794 m .58645 .31553 L .58655 .32004 L p F P
0 g
s
.888 .88 .82 r
.64753 .17209 m .65279 .16574 L .65344 .17017 L p F P
0 g
s
.888 .88 .82 r
.64791 .17653 m .64753 .17209 L p .65344 .17017 L F P
0 g
s
.888 .88 .82 r
.65344 .17017 m .64796 .17656 L .64791 .17653 L p F P
0 g
s
.892 .87 .809 r
.65579 .16207 m .65279 .16574 L .65344 .17017 L p F P
0 g
s
0 0 0 r
.5916 .29571 m .59159 .29575 L .59161 .29568 L closepath p F P
0 g
s
.929 .96 .773 r
.76713 .25139 m .76675 .25129 L .76726 .25059 L closepath p F P
0 g
s
0 0 0 r
.59218 .29552 m .59359 .2905 L .59161 .29568 L p F P
0 g
s
0 0 0 r
.59083 .29902 m .59218 .29552 L p .59161 .29568 L F P
0 g
s
0 0 0 r
.59161 .29568 m .59159 .29575 L .59083 .29902 L p F P
0 g
s
.487 .515 .811 r
.5899 .34227 m .58856 .34184 L .58523 .34738 L p F P
0 g
s
.487 .515 .811 r
.58523 .34738 m .59267 .34855 L .5899 .34227 L p F P
0 g
s
0 0 0 r
.59159 .29575 m .59026 .30068 L .59083 .29902 L closepath p F P
0 g
s
.876 .943 .856 r
.74005 .28293 m .73892 .28772 L .74543 .28088 L p F P
0 g
s
.876 .943 .856 r
.74622 .27651 m .74005 .28293 L p .74543 .28088 L F P
0 g
s
.876 .943 .856 r
.74543 .28088 m .74651 .27666 L .74622 .27651 L p F P
0 g
s
0 0 .404 r
.788 .16211 m .78807 .16668 L .78687 .16268 L p F P
0 g
s
0 0 .404 r
.78687 .16268 m .78678 .15812 L .788 .16211 L p F P
0 g
s
.708 .807 .926 r
.63543 .35205 m .62477 .3571 L .62214 .35423 L p F P
0 g
s
.687 .785 .925 r
.61148 .3585 m .62214 .35423 L .62477 .3571 L p F P
0 g
s
.478 .573 .873 r
.76454 .12117 m .76438 .12116 L .76472 .12571 L p F P
0 g
s
.478 .573 .873 r
.76472 .12571 m .76705 .12595 L .76454 .12117 L p F P
0 g
s
.823 .917 .9 r
.70664 .31671 m .70538 .31772 L .70594 .31626 L closepath p F P
0 g
s
.817 .907 .902 r
.70422 .31505 m .70594 .31626 L .70538 .31772 L p F P
0 g
s
.817 .907 .902 r
.69642 .32107 m .70422 .31505 L p .70538 .31772 L F P
0 g
s
.817 .907 .902 r
.69527 .32436 m .69642 .32107 L p .70538 .31772 L F P
0 g
s
.943 .945 .754 r
.61964 .22219 m .62298 .21693 L .62275 .22161 L p F P
0 g
s
.943 .945 .754 r
.62275 .22161 m .62217 .22249 L .61964 .22219 L p F P
0 g
s
.831 .917 .893 r
.71501 .30979 m .70664 .31671 L .70594 .31626 L p F P
0 g
s
.931 .907 .776 r
.63029 .20076 m .63035 .20537 L .63465 .19937 L p F P
0 g
s
.931 .907 .776 r
.63465 .19937 m .63436 .19484 L .63029 .20076 L p F P
0 g
s
.802 .687 .143 r
.78838 .18451 m .78836 .18907 L .78875 .18446 L p F P
0 g
s
.802 .687 .143 r
.78875 .18446 m .78878 .1799 L .78838 .18451 L p F P
0 g
s
.959 .932 .719 r
.61937 .22729 m .62217 .22249 L .61964 .22219 L p F P
0 g
s
.673 .769 .922 r
.62214 .35423 m .61148 .3585 L .60881 .3551 L p F P
0 g
s
.872 .936 .86 r
.73579 .28723 m .74005 .28293 L .73892 .28772 L p F P
0 g
s
.872 .936 .86 r
.73892 .28772 m .73812 .28853 L .73579 .28723 L p F P
0 g
s
.953 .953 .678 r
.7759 .22955 m .77542 .23419 L .77841 .22861 L p F P
0 g
s
.953 .953 .678 r
.77841 .22861 m .77893 .22394 L .7759 .22955 L p F P
0 g
s
.866 .938 .866 r
.73163 .29484 m .73812 .28853 L .73579 .28723 L p F P
0 g
s
.838 .925 .89 r
.71717 .30795 m .71501 .30979 L .71593 .30718 L closepath p F P
0 g
s
.831 .917 .893 r
.71479 .30641 m .71593 .30718 L .71501 .30979 L p F P
0 g
s
.831 .917 .893 r
.70705 .31278 m .71479 .30641 L p .71501 .30979 L F P
0 g
s
.831 .917 .893 r
.70594 .31626 m .70705 .31278 L p .71501 .30979 L F P
0 g
s
.961 .944 .669 r
.60998 .24407 m .60953 .24879 L .61244 .24328 L p F P
0 g
s
.961 .944 .669 r
.61196 .24013 m .60998 .24407 L p .61244 .24328 L F P
0 g
s
.961 .944 .669 r
.61244 .24328 m .61266 .2399 L .61196 .24013 L p F P
0 g
s
.823 .849 .39 r
.59649 .28045 m .5953 .28538 L .59723 .28019 L p F P
0 g
s
.823 .849 .39 r
.59672 .27982 m .59649 .28045 L p .59723 .28019 L F P
0 g
s
.823 .849 .39 r
.59723 .28019 m .59787 .27757 L .59672 .27982 L p F P
0 g
s
.777 .879 .921 r
.67243 .33798 m .67039 .33929 L .67143 .33719 L closepath p F P
0 g
s
.772 .866 .919 r
.66993 .33594 m .67143 .33719 L .67039 .33929 L p F P
0 g
s
.772 .866 .919 r
.65929 .34258 m .66993 .33594 L p .67039 .33929 L F P
0 g
s
.845 .925 .883 r
.7237 .30218 m .71717 .30795 L .71593 .30718 L p F P
0 g
s
.929 .958 .775 r
.76455 .2507 m .76794 .2459 L .76726 .25059 L p F P
0 g
s
.929 .958 .775 r
.76726 .25059 m .76675 .25129 L .76455 .2507 L p F P
0 g
s
.569 .612 .856 r
.59187 .35401 m .59378 .35074 L .59541 .35368 L closepath p F P
0 g
s
.562 .652 .896 r
.75084 .11713 m .75099 .11711 L .7511 .11756 L closepath p F P
0 g
s
.521 .629 .899 r
.76204 .11658 m .75099 .11711 L .7511 .11756 L p F P
0 g
s
.521 .629 .899 r
.76435 .12082 m .76204 .11658 L p .7511 .11756 L F P
0 g
s
.521 .629 .899 r
.76438 .12116 m .76435 .12082 L p .7511 .11756 L F P
0 g
s
.871 .778 .278 r
.78752 .19385 m .78752 .19401 L .7883 .19144 L p F P
0 g
s
.871 .778 .278 r
.7883 .19144 m .78836 .18907 L .78752 .19385 L p F P
0 g
s
.866 .938 .866 r
.73579 .28723 m .73296 .28999 L .73163 .29484 L p F P
0 g
s
.859 .932 .872 r
.72532 .29721 m .73296 .28999 L .73163 .29484 L p F P
0 g
s
.859 .932 .872 r
.73163 .29484 m .72767 .29857 L .72532 .29721 L p F P
0 g
s
.904 .874 .797 r
.64796 .17656 m .64793 .17661 L .64791 .17653 L closepath p F P
0 g
s
.931 .927 .781 r
.63033 .20617 m .62989 .20602 L .63035 .20537 L closepath p F P
0 g
s
.909 .876 .792 r
.64271 .17828 m .64329 .18272 L .64793 .17661 L p F P
0 g
s
.909 .876 .792 r
.64542 .17461 m .64271 .17828 L p .64793 .17661 L F P
0 g
s
.909 .876 .792 r
.64793 .17661 m .64791 .17653 L .64542 .17461 L p F P
0 g
s
.81 .896 .904 r
.69527 .32436 m .69364 .32316 L .69642 .32107 L closepath p F P
0 g
s
.852 .933 .879 r
.7237 .30218 m .72767 .29857 L .72532 .29721 L p F P
0 g
s
.852 .933 .879 r
.72532 .29721 m .72526 .29726 L .7237 .30218 L p F P
0 g
s
.845 .925 .883 r
.71659 .30487 m .72526 .29726 L .7237 .30218 L p F P
0 g
s
.845 .925 .883 r
.71593 .30718 m .71659 .30487 L p .7237 .30218 L F P
0 g
s
0 .006 .563 r
.78664 .15356 m .78678 .15812 L .78487 .15439 L p F P
0 g
s
0 .006 .563 r
.78487 .15439 m .78471 .14984 L .78664 .15356 L p F P
0 g
s
.924 .963 .779 r
.76275 .25672 m .76675 .25129 L .76455 .2507 L p F P
0 g
s
.893 .882 .815 r
.64791 .17653 m .64542 .17461 L .64753 .17209 L closepath p F P
0 g
s
.734 .774 .885 r
.71646 .11598 m .71086 .11909 L .70836 .11567 L p F P
0 g
s
.948 .957 .714 r
.77525 .23557 m .77461 .23554 L .77542 .23419 L closepath p F P
0 g
s
.789 .88 .913 r
.68056 .32884 m .68304 .33081 L .67243 .33798 L p F P
0 g
s
.789 .88 .913 r
.67261 .33418 m .68056 .32884 L p .67243 .33798 L F P
0 g
s
.789 .88 .913 r
.67243 .33798 m .67143 .33719 L .67261 .33418 L p F P
0 g
s
.908 .952 .815 r
.75753 .26503 m .75655 .26463 L .75792 .26297 L closepath p F P
0 g
s
.919 .945 .596 r
.60601 .25761 m .60431 .25901 L .60669 .25429 L closepath p F P
0 g
s
.571 .66 .898 r
.75099 .11711 m .75084 .11713 L .74836 .11301 L p F P
0 g
s
.915 .859 .417 r
.78614 .19883 m .78586 .20346 L .78722 .19848 L p F P
0 g
s
.915 .859 .417 r
.78745 .19412 m .78614 .19883 L p .78722 .19848 L F P
0 g
s
.915 .859 .417 r
.78722 .19848 m .78752 .19401 L .78745 .19412 L p F P
0 g
s
.312 .3 .685 r
.58923 .34057 m .58856 .34184 L .58404 .33886 L p F P
0 g
s
.312 .3 .685 r
.58706 .33357 m .58923 .34057 L p .58404 .33886 L F P
0 g
s
.312 .3 .685 r
.58404 .33886 m .58693 .33344 L .58706 .33357 L p F P
0 g
s
.952 .921 .563 r
.78196 .21385 m .7841 .20858 L .78379 .2132 L p F P
0 g
s
.952 .921 .563 r
.78175 .21729 m .78196 .21385 L p .78379 .2132 L F P
0 g
s
.952 .921 .563 r
.78379 .2132 m .78226 .21698 L .78175 .21729 L p F P
0 g
s
.571 .66 .898 r
.74836 .11301 m .74989 .11282 L .75099 .11711 L p F P
0 g
s
.541 .625 .884 r
.75954 .11209 m .74989 .11282 L .75099 .11711 L p F P
0 g
s
.541 .625 .884 r
.75099 .11711 m .76204 .11658 L .75954 .11209 L p F P
0 g
s
.797 .887 .91 r
.68383 .33141 m .68304 .33081 L .68443 .32983 L closepath p F P
0 g
s
.382 .504 .858 r
.76705 .12595 m .77195 .1274 L .77253 .13185 L p F P
0 g
s
.297 .434 .831 r
.77713 .12987 m .77756 .13438 L .77253 .13185 L p F P
0 g
s
.297 .434 .831 r
.77253 .13185 m .77195 .1274 L .77713 .12987 L p F P
0 g
s
.753 .842 .919 r
.65589 .34458 m .64865 .34875 L .64608 .34639 L p F P
0 g
s
.797 .815 .866 r
.68762 .13171 m .68715 .13115 L .68751 .13087 L closepath p F P
0 g
s
.032 .182 .688 r
.78452 .14593 m .78471 .14984 L .78197 .14643 L p F P
0 g
s
.032 .182 .688 r
.78413 .14481 m .78452 .14593 L p .78197 .14643 L F P
0 g
s
.032 .182 .688 r
.78197 .14643 m .78171 .1419 L .78413 .14481 L p F P
0 g
s
.769 .796 .875 r
.69872 .12419 m .69772 .1229 L .69849 .12238 L closepath p F P
0 g
s
.92 .918 .532 r
.60175 .26504 m .60083 .2699 L .60324 .26455 L p F P
0 g
s
.92 .918 .532 r
.60324 .26455 m .60398 .25975 L .60175 .26504 L p F P
0 g
s
.178 .322 .773 r
.7814 .13736 m .78171 .1419 L .77795 .13888 L p F P
0 g
s
.178 .322 .773 r
.77795 .13888 m .77756 .13438 L .7814 .13736 L p F P
0 g
s
.824 .905 .896 r
.70594 .31626 m .70422 .31505 L .70705 .31278 L closepath p F P
0 g
s
.913 .904 .801 r
.63859 .19061 m .63764 .19005 L .63853 .18889 L closepath p F P
0 g
s
.397 .518 .863 r
.77195 .1274 m .76705 .12595 L .76454 .12117 L p F P
0 g
s
.93 .923 .782 r
.62735 .20502 m .63029 .20076 L .63035 .20537 L p F P
0 g
s
.93 .923 .782 r
.63035 .20537 m .62989 .20602 L .62735 .20502 L p F P
0 g
s
.948 .914 .748 r
.62664 .21115 m .62989 .20602 L .62735 .20502 L p F P
0 g
s
.959 .932 .719 r
.61964 .22219 m .61935 .2227 L .61937 .22729 L p F P
0 g
s
.962 .932 .709 r
.61627 .22828 m .6161 .23293 L .61937 .22729 L p F P
0 g
s
.962 .932 .709 r
.61937 .22729 m .61935 .2227 L .61627 .22828 L p F P
0 g
s
.822 .829 .854 r
.67888 .13848 m .67665 .14042 L .67413 .13757 L p F P
0 g
s
.851 .839 .833 r
.67138 .14566 m .67665 .14042 L .67413 .13757 L p F P
0 g
s
0 0 .024 r
.78876 .17533 m .78878 .1799 L .78871 .17547 L p F P
0 g
s
0 0 .024 r
.78871 .17547 m .78869 .1709 L .78876 .17533 L p F P
0 g
s
.829 .829 .847 r
.67888 .13848 m .68715 .13115 L .68464 .1281 L p F P
0 g
s
.829 .829 .847 r
.68464 .1281 m .67806 .13407 L .67888 .13848 L p F P
0 g
s
.822 .829 .854 r
.67413 .13757 m .67806 .13407 L .67888 .13848 L p F P
0 g
s
.916 .957 .801 r
.75871 .25826 m .75792 .26297 L .76275 .25672 L p F P
0 g
s
.916 .957 .801 r
.76275 .25672 m .76362 .25197 L .75871 .25826 L p F P
0 g
s
.924 .963 .779 r
.76455 .2507 m .76362 .25197 L .76275 .25672 L p F P
0 g
s
.912 .884 .792 r
.63818 .18436 m .63853 .18889 L .64329 .18272 L p F P
0 g
s
.912 .884 .792 r
.64329 .18272 m .64271 .17828 L .63818 .18436 L p F P
0 g
s
.796 .813 .865 r
.68751 .13087 m .68715 .13115 L .68464 .1281 L p F P
0 g
s
.851 .839 .833 r
.67413 .13757 m .67046 .14129 L .67138 .14566 L p F P
0 g
s
.846 .844 .842 r
.66366 .14806 m .67046 .14129 L .67138 .14566 L p F P
0 g
s
.846 .844 .842 r
.67138 .14566 m .6662 .15071 L .66366 .14806 L p F P
0 g
s
.804 .815 .86 r
.68751 .13087 m .69772 .1229 L .69521 .11965 L p F P
0 g
s
.804 .815 .86 r
.69521 .11965 m .68676 .12643 L .68751 .13087 L p F P
0 g
s
.796 .813 .865 r
.68464 .1281 m .68676 .12643 L .68751 .13087 L p F P
0 g
s
.74 .771 .878 r
.71646 .11598 m .72158 .1131 L .71909 .1095 L p F P
0 g
s
.74 .771 .878 r
.71909 .1095 m .71541 .11163 L .71646 .11598 L p F P
0 g
s
.734 .774 .885 r
.70836 .11567 m .71541 .11163 L .71646 .11598 L p F P
0 g
s
0 0 .35 r
.58889 .31477 m .58655 .32004 L .58645 .31553 L p F P
0 g
s
0 0 .35 r
.58645 .31553 m .58878 .31026 L .58889 .31477 L p F P
0 g
s
.948 .956 .716 r
.77254 .23527 m .7759 .22955 L .77542 .23419 L p F P
0 g
s
.948 .956 .716 r
.77253 .23539 m .77254 .23527 L p .77542 .23419 L F P
0 g
s
.948 .956 .716 r
.77542 .23419 m .77461 .23554 L .77253 .23539 L p F P
0 g
s
.87 .846 .817 r
.66446 .15262 m .6662 .15071 L .66366 .14806 L p F P
0 g
s
0 0 .01 r
.59028 .30264 m .58929 .30555 L .59026 .30068 L p F P
0 g
s
0 0 .01 r
.59026 .30068 m .59083 .29902 L .59028 .30264 L p F P
0 g
s
.734 .823 .92 r
.63578 .35239 m .63543 .35205 L .63611 .35169 L closepath p F P
0 g
s
.956 .943 .634 r
.60733 .2495 m .60669 .25429 L .60953 .24879 L p F P
0 g
s
.956 .943 .634 r
.60953 .24879 m .60998 .24407 L .60733 .2495 L p F P
0 g
s
.87 .846 .817 r
.66366 .14806 m .66346 .14829 L .66446 .15262 L p F P
0 g
s
.87 .846 .817 r
.65765 .15484 m .65839 .15927 L .66446 .15262 L p F P
0 g
s
.87 .846 .817 r
.66446 .15262 m .66346 .14829 L .65765 .15484 L p F P
0 g
s
.611 .7 .907 r
.59541 .35368 m .60613 .3514 L .60881 .3551 L p F P
0 g
s
.613 .634 .848 r
.59378 .35074 m .59541 .35368 L .60613 .3514 L p F P
0 g
s
.796 .882 .908 r
.68443 .32983 m .68304 .33081 L .68056 .32884 L p F P
0 g
s
.946 .927 .57 r
.78226 .21698 m .78163 .21847 L .78175 .21729 L closepath p F P
0 g
s
.943 .961 .724 r
.77461 .23554 m .77187 .23998 L .77253 .23539 L closepath p F P
0 g
s
.8 .888 .908 r
.68443 .32983 m .69364 .32316 L .69118 .3213 L p F P
0 g
s
.8 .888 .908 r
.69118 .3213 m .68626 .32484 L .68443 .32983 L p F P
0 g
s
.796 .882 .908 r
.68056 .32884 m .68626 .32484 L .68443 .32983 L p F P
0 g
s
.099 .047 .505 r
.58756 .32424 m .58584 .32748 L .5853 .32242 L p F P
0 g
s
.099 .047 .505 r
.5853 .32242 m .58655 .32004 L .58756 .32424 L p F P
0 g
s
.781 .87 .914 r
.67143 .33719 m .66993 .33594 L .67261 .33418 L closepath p F P
0 g
s
.758 .858 .924 r
.65929 .34258 m .65589 .34458 L .65766 .34118 L closepath p F P
0 g
s
.753 .842 .919 r
.65675 .34036 m .65766 .34118 L .65589 .34458 L p F P
0 g
s
.753 .842 .919 r
.64608 .34639 m .65675 .34036 L p .65589 .34458 L F P
0 g
s
.759 .777 .277 r
.59494 .28552 m .59359 .2905 L .5953 .28538 L p F P
0 g
s
.759 .777 .277 r
.5953 .28538 m .59649 .28045 L .59494 .28552 L p F P
0 g
s
.733 .813 .914 r
.63611 .35169 m .63543 .35205 L .63282 .34937 L p F P
0 g
s
.708 .807 .926 r
.62214 .35423 m .63282 .34937 L .63543 .35205 L p F P
0 g
s
.205 .183 .611 r
.58699 .33332 m .58693 .33344 L .58477 .32964 L p F P
0 g
s
.205 .183 .611 r
.58477 .32964 m .58584 .32748 L .58699 .33332 L p F P
0 g
s
.769 .795 .874 r
.69849 .12238 m .69772 .1229 L .69521 .11965 L p F P
0 g
s
.887 .788 .297 r
.78754 .18929 m .78752 .19385 L .78836 .18907 L p F P
0 g
s
.887 .788 .297 r
.78836 .18907 m .78838 .18451 L .78754 .18929 L p F P
0 g
s
.908 .95 .816 r
.75429 .26368 m .75871 .25826 L .75792 .26297 L p F P
0 g
s
.908 .95 .816 r
.75792 .26297 m .75655 .26463 L .75429 .26368 L p F P
0 g
s
.729 .816 .919 r
.63611 .35169 m .64608 .34639 L .6435 .34394 L p F P
0 g
s
.729 .816 .919 r
.6435 .34394 m .63842 .34655 L .63611 .35169 L p F P
0 g
s
.733 .813 .914 r
.63282 .34937 m .63842 .34655 L .63611 .35169 L p F P
0 g
s
.95 .915 .744 r
.62289 .21235 m .62298 .21693 L .62664 .21115 L p F P
0 g
s
.95 .915 .744 r
.62664 .21115 m .62635 .20664 L .62289 .21235 L p F P
0 g
s
.948 .914 .748 r
.62735 .20502 m .62635 .20664 L .62664 .21115 L p F P
0 g
s
.776 .797 .87 r
.69849 .12238 m .70836 .11567 L .70586 .11225 L p F P
0 g
s
.776 .797 .87 r
.70586 .11225 m .69771 .11793 L .69849 .12238 L p F P
0 g
s
.769 .795 .874 r
.69521 .11965 m .69771 .11793 L .69849 .12238 L p F P
0 g
s
.912 .899 .801 r
.63509 .18848 m .63818 .18436 L .63853 .18889 L p F P
0 g
s
.912 .899 .801 r
.63853 .18889 m .63764 .19005 L .63509 .18848 L p F P
0 g
s
.955 .946 .644 r
.7794 .21928 m .77893 .22394 L .78163 .21847 L p F P
0 g
s
.955 .946 .644 r
.7802 .21764 m .7794 .21928 L p .78163 .21847 L F P
0 g
s
.955 .946 .644 r
.78163 .21847 m .78175 .21729 L .7802 .21764 L p F P
0 g
s
0 0 .213 r
.78861 .16634 m .78869 .1709 L .78807 .16668 L p F P
0 g
s
0 0 .213 r
.78807 .16668 m .788 .16211 L .78861 .16634 L p F P
0 g
s
.869 .86 .83 r
.65325 .15971 m .65765 .15484 L .65839 .15927 L p F P
0 g
s
.869 .86 .83 r
.65839 .15927 m .65579 .16207 L .65325 .15971 L p F P
0 g
s
.639 .697 .887 r
.7349 .11212 m .74587 .10894 L .74836 .11301 L p F P
0 g
s
.647 .703 .888 r
.74587 .10894 m .7349 .11212 L .73242 .10831 L p F P
0 g
s
.694 .736 .883 r
.72158 .1131 m .73242 .10831 L .7349 .11212 L p F P
0 g
s
.838 .913 .887 r
.71593 .30718 m .71479 .30641 L .71659 .30487 L closepath p F P
0 g
s
.791 .841 .379 r
.59787 .27757 m .59672 .27982 L .59855 .27521 L closepath p F P
0 g
s
.903 .954 .822 r
.75247 .26944 m .75655 .26463 L .75429 .26368 L p F P
0 g
s
.7 .74 .882 r
.73242 .10831 m .72158 .1131 L .71909 .1095 L p F P
0 g
s
.945 .898 .506 r
.78434 .20397 m .7841 .20858 L .78586 .20346 L p F P
0 g
s
.945 .898 .506 r
.78586 .20346 m .78614 .19883 L .78434 .20397 L p F P
0 g
s
.932 .895 .77 r
.63436 .19484 m .63764 .19005 L .63509 .18848 L p F P
0 g
s
.892 .861 .803 r
.65279 .16574 m .65579 .16207 L .65325 .15971 L p F P
0 g
s
.771 .86 .916 r
.66741 .33379 m .66993 .33594 L .65929 .34258 L p F P
0 g
s
.771 .86 .916 r
.65838 .33937 m .66741 .33379 L p .65929 .34258 L F P
0 g
s
.771 .86 .916 r
.65929 .34258 m .65766 .34118 L .65838 .33937 L p F P
0 g
s
.961 .941 .699 r
.61321 .23385 m .61283 .23857 L .6161 .23293 L p F P
0 g
s
.961 .941 .699 r
.6161 .23293 m .61627 .22828 L .61321 .23385 L p F P
0 g
s
.886 .894 .473 r
.59966 .27029 m .59855 .27521 L .60083 .2699 L p F P
0 g
s
.886 .894 .473 r
.60083 .2699 m .60175 .26504 L .59966 .27029 L p F P
0 g
s
.934 .958 .762 r
.76855 .24123 m .76794 .2459 L .77187 .23998 L p F P
0 g
s
.934 .958 .762 r
.77247 .23538 m .76855 .24123 L p .77187 .23998 L F P
0 g
s
.934 .958 .762 r
.77187 .23998 m .77253 .23539 L .77247 .23538 L p F P
0 g
s
.699 .795 .925 r
.63282 .34937 m .62214 .35423 L .6195 .35119 L p F P
0 g
s
.673 .769 .922 r
.60881 .3551 m .6195 .35119 L .62214 .35423 L p F P
0 g
s
.81 .893 .902 r
.69642 .32107 m .69364 .32316 L .69118 .3213 L p F P
0 g
s
.949 .956 .684 r
.61266 .2399 m .61196 .24013 L .61283 .23857 L closepath p F P
0 g
s
.655 .749 .919 r
.6195 .35119 m .60881 .3551 L .60613 .3514 L p F P
0 g
s
.903 .954 .822 r
.75429 .26368 m .75345 .26467 L .75247 .26944 L p F P
0 g
s
.894 .946 .835 r
.74753 .27132 m .74664 .27605 L .75247 .26944 L p F P
0 g
s
.894 .946 .835 r
.75247 .26944 m .75345 .26467 L .74753 .27132 L p F P
0 g
s
0 0 .035 r
.59114 .30042 m .59028 .30264 L .59083 .29902 L p F P
0 g
s
0 0 .035 r
.59083 .29902 m .59218 .29552 L .59114 .30042 L p F P
0 g
s
.555 .584 .838 r
.59267 .34855 m .59537 .34842 L .59378 .35074 L closepath p F P
0 g
s
.613 .634 .848 r
.60342 .34735 m .59537 .34842 L .59378 .35074 L p F P
0 g
s
.613 .634 .848 r
.60613 .3514 m .60342 .34735 L p .59378 .35074 L F P
0 g
s
.892 .861 .803 r
.64688 .16765 m .64753 .17209 L .65279 .16574 L p F P
0 g
s
.892 .861 .803 r
.65279 .16574 m .65191 .16138 L .64688 .16765 L p F P
0 g
s
.892 .861 .803 r
.65325 .15971 m .65191 .16138 L .65279 .16574 L p F P
0 g
s
.815 .9 .901 r
.69642 .32107 m .70422 .31505 L .70179 .31329 L p F P
0 g
s
.815 .9 .901 r
.70179 .31329 m .6981 .31613 L .69642 .32107 L p F P
0 g
s
.81 .893 .902 r
.69118 .3213 m .6981 .31613 L .69642 .32107 L p F P
0 g
s
.885 .94 .845 r
.74651 .27666 m .74622 .27651 L .74664 .27605 L closepath p F P
0 g
s
.492 .587 .878 r
.76438 .12116 m .76435 .12082 L .76454 .12117 L closepath p F P
0 g
s
0 0 .41 r
.7879 .15863 m .788 .16211 L .78678 .15812 L p F P
0 g
s
0 0 .41 r
.78709 .15497 m .7879 .15863 L p .78678 .15812 L F P
0 g
s
0 0 .41 r
.78678 .15812 m .78664 .15356 L .78709 .15497 L p F P
0 g
s
.926 .947 .605 r
.60477 .25491 m .60733 .2495 L .60669 .25429 L p F P
0 g
s
.926 .947 .605 r
.60404 .25923 m .60477 .25491 L p .60669 .25429 L F P
0 g
s
.926 .947 .605 r
.60669 .25429 m .60431 .25901 L .60404 .25923 L p F P
0 g
s
.963 .937 .631 r
.78175 .21729 m .7802 .21764 L .78196 .21385 L closepath p F P
0 g
s
.579 .667 .898 r
.74989 .11282 m .74836 .11301 L .74587 .10894 L p F P
0 g
s
.397 .518 .863 r
.76454 .12117 m .77133 .12295 L .77195 .1274 L p F P
0 g
s
.384 .525 .875 r
.76435 .12082 m .76454 .12117 L .77133 .12295 L p F P
0 g
s
.932 .895 .77 r
.63509 .18848 m .63381 .19039 L .63436 .19484 L p F P
0 g
s
.933 .895 .768 r
.62993 .19625 m .63029 .20076 L .63436 .19484 L p F P
0 g
s
.933 .895 .768 r
.63436 .19484 m .63381 .19039 L .62993 .19625 L p F P
0 g
s
.452 .57 .883 r
.76204 .11658 m .76353 .11678 L .76435 .12082 L closepath p F P
0 g
s
.384 .525 .875 r
.77068 .11849 m .76353 .11678 L .76435 .12082 L p F P
0 g
s
.384 .525 .875 r
.77133 .12295 m .77068 .11849 L p .76435 .12082 L F P
0 g
s
.739 .776 .882 r
.71541 .11163 m .70836 .11567 L .70586 .11225 L p F P
0 g
s
.947 .937 .75 r
.61941 .21807 m .62289 .21235 L .62298 .21693 L p F P
0 g
s
.947 .937 .75 r
.61932 .22214 m .61941 .21807 L p .62298 .21693 L F P
0 g
s
.947 .937 .75 r
.62298 .21693 m .61964 .22219 L .61932 .22214 L p F P
0 g
s
.818 .698 .16 r
.78835 .17995 m .78838 .18451 L .78878 .1799 L p F P
0 g
s
.818 .698 .16 r
.78878 .1799 m .78876 .17533 L .78835 .17995 L p F P
0 g
s
.885 .937 .845 r
.74391 .27523 m .74753 .27132 L .74664 .27605 L p F P
0 g
s
.885 .937 .845 r
.74664 .27605 m .74622 .27651 L .74391 .27523 L p F P
0 g
s
.88 .939 .851 r
.74005 .28293 m .74622 .27651 L .74391 .27523 L p F P
0 g
s
.824 .902 .895 r
.70705 .31278 m .70422 .31505 L .70179 .31329 L p F P
0 g
s
0 0 .144 r
.59001 .30663 m .58878 .31026 L .58929 .30555 L p F P
0 g
s
0 0 .144 r
.58929 .30555 m .59028 .30264 L .59001 .30663 L p F P
0 g
s
.508 .54 .824 r
.59537 .34842 m .59267 .34855 L .5899 .34227 L p F P
0 g
s
.829 .909 .893 r
.70705 .31278 m .71479 .30641 L .71238 .30474 L p F P
0 g
s
.829 .909 .893 r
.71238 .30474 m .70854 .30789 L .70705 .31278 L p F P
0 g
s
.824 .902 .895 r
.70179 .31329 m .70854 .30789 L .70705 .31278 L p F P
0 g
s
.955 .951 .686 r
.77632 .22491 m .7759 .22955 L .77893 .22394 L p F P
0 g
s
.955 .951 .686 r
.77893 .22394 m .7794 .21928 L .77632 .22491 L p F P
0 g
s
.891 .876 .814 r
.64287 .17256 m .64688 .16765 L .64753 .17209 L p F P
0 g
s
.891 .876 .814 r
.64753 .17209 m .64542 .17461 L .64287 .17256 L p F P
0 g
s
0 0 0 r
.59366 .2905 m .59218 .29552 L .59359 .2905 L p F P
0 g
s
0 0 0 r
.59359 .2905 m .59494 .28552 L .59366 .2905 L p F P
0 g
s
0 0 .561 r
.78661 .1529 m .78664 .15356 L .78471 .14984 L p F P
0 g
s
0 0 .561 r
.78471 .14984 m .78452 .14593 L .78661 .1529 L p F P
0 g
s
.579 .667 .898 r
.74587 .10894 m .74876 .10852 L .74989 .11282 L p F P
0 g
s
.552 .635 .887 r
.75704 .10768 m .74876 .10852 L .74989 .11282 L p F P
0 g
s
.552 .635 .887 r
.74989 .11282 m .75954 .11209 L .75704 .10768 L p F P
0 g
s
.229 .201 .618 r
.58985 .328 m .58699 .33332 L .58584 .32748 L p F P
0 g
s
.229 .201 .618 r
.58584 .32748 m .58756 .32424 L .58985 .328 L p F P
0 g
s
.027 0 .48 r
.5898 .31901 m .58756 .32424 L .58655 .32004 L p F P
0 g
s
.027 0 .48 r
.58655 .32004 m .58889 .31477 L .5898 .31901 L p F P
0 g
s
.953 .953 .69 r
.61019 .23942 m .61321 .23385 L .61283 .23857 L p F P
0 g
s
.953 .953 .69 r
.61007 .24063 m .61019 .23942 L p .61283 .23857 L F P
0 g
s
.953 .953 .69 r
.61283 .23857 m .61196 .24013 L .61007 .24063 L p F P
0 g
s
.88 .939 .851 r
.74391 .27523 m .74113 .27814 L .74005 .28293 L p F P
0 g
s
.873 .934 .859 r
.73418 .28516 m .74113 .27814 L .74005 .28293 L p F P
0 g
s
.873 .934 .859 r
.73396 .28618 m .73418 .28516 L p .74005 .28293 L F P
0 g
s
.873 .934 .859 r
.74005 .28293 m .73579 .28723 L .73396 .28618 L p F P
0 g
s
.931 .955 .773 r
.76426 .24729 m .76855 .24123 L .76794 .2459 L p F P
0 g
s
.931 .955 .773 r
.76387 .2505 m .76426 .24729 L p .76794 .2459 L F P
0 g
s
.931 .955 .773 r
.76794 .2459 m .76455 .2507 L .76387 .2505 L p F P
0 g
s
.309 .446 .836 r
.77675 .12638 m .77713 .12987 L .77195 .1274 L p F P
0 g
s
.309 .446 .836 r
.77617 .12511 m .77675 .12638 L p .77195 .1274 L F P
0 g
s
.309 .446 .836 r
.77195 .1274 m .77133 .12295 L .77617 .12511 L p F P
0 g
s
.929 .853 .415 r
.78752 .19401 m .78745 .19412 L .78752 .19385 L closepath p F P
0 g
s
.78 .865 .912 r
.67261 .33418 m .66993 .33594 L .66741 .33379 L p F P
0 g
s
.913 .874 .785 r
.64271 .17828 m .64542 .17461 L .64287 .17256 L p F P
0 g
s
.837 .91 .886 r
.71659 .30487 m .71479 .30641 L .71238 .30474 L p F P
0 g
s
.747 .841 .922 r
.65675 .34036 m .64608 .34639 L .6435 .34394 L p F P
0 g
s
.932 .855 .419 r
.78628 .19424 m .78754 .18929 L .78752 .19385 L p F P
0 g
s
.932 .855 .419 r
.78627 .1959 m .78628 .19424 L p .78752 .19385 L F P
0 g
s
.932 .855 .419 r
.78752 .19385 m .78745 .19412 L .78627 .1959 L p F P
0 g
s
.866 .935 .866 r
.73579 .28723 m .73296 .28999 L .73396 .28618 L closepath p F P
0 g
s
.84 .917 .886 r
.7179 .30003 m .71659 .30487 L .72526 .29726 L p F P
0 g
s
.837 .91 .886 r
.71238 .30474 m .7179 .30003 L .71659 .30487 L p F P
0 g
s
.961 .923 .58 r
.78218 .20926 m .78196 .21385 L .7841 .20858 L p F P
0 g
s
.961 .923 .58 r
.7841 .20858 m .78434 .20397 L .78218 .20926 L p F P
0 g
s
.802 .847 .389 r
.59774 .27549 m .59966 .27029 L .59855 .27521 L p F P
0 g
s
.802 .847 .389 r
.59656 .28013 m .59774 .27549 L p .59855 .27521 L F P
0 g
s
.802 .847 .389 r
.59855 .27521 m .59672 .27982 L .59656 .28013 L p F P
0 g
s
.439 .457 .781 r
.58856 .34184 m .58923 .34057 L .5899 .34227 L closepath p F P
0 g
s
.859 .928 .871 r
.73346 .28586 m .73396 .28618 L .73296 .28999 L p F P
0 g
s
.859 .928 .871 r
.72639 .29247 m .73346 .28586 L p .73296 .28999 L F P
0 g
s
.859 .928 .871 r
.72528 .29719 m .72639 .29247 L p .73296 .28999 L F P
0 g
s
.859 .928 .871 r
.73296 .28999 m .72532 .29721 L .72528 .29719 L p F P
0 g
s
.027 .18 .688 r
.78141 .13736 m .7814 .13736 L .78171 .1419 L p F P
0 g
s
.027 .18 .688 r
.78171 .1419 m .78413 .14481 L .78141 .13736 L p F P
0 g
s
.924 .858 .42 r
.78745 .19412 m .78614 .19883 L .78627 .1959 L closepath p F P
0 g
s
.967 .937 .668 r
.61196 .24013 m .60998 .24407 L .61007 .24063 L closepath p F P
0 g
s
.202 .345 .786 r
.7814 .13735 m .7814 .13736 L .77756 .13438 L p F P
0 g
s
.202 .345 .786 r
.77877 .13104 m .7814 .13735 L p .77756 .13438 L F P
0 g
s
.202 .345 .786 r
.77756 .13438 m .77713 .12987 L .77877 .13104 L p F P
0 g
s
.852 .929 .878 r
.72532 .29721 m .72526 .29726 L .72528 .29719 L closepath p F P
0 g
s
.84 .917 .886 r
.72294 .29561 m .7179 .30003 L p .72526 .29726 L F P
0 g
s
.84 .917 .886 r
.72526 .29726 m .72528 .29719 L .72294 .29561 L p F P
0 g
s
.851 .916 .876 r
.72528 .29719 m .72294 .29561 L .72639 .29247 L closepath p F P
0 g
s
.783 .872 .913 r
.67261 .33418 m .68056 .32884 L .67806 .32682 L p F P
0 g
s
.783 .872 .913 r
.67806 .32682 m .67455 .32915 L .67261 .33418 L p F P
0 g
s
.78 .865 .912 r
.66741 .33379 m .67455 .32915 L .67261 .33418 L p F P
0 g
s
.947 .935 .594 r
.60431 .25901 m .60398 .25975 L .60404 .25923 L closepath p F P
0 g
s
.825 .826 .849 r
.67806 .13407 m .67413 .13757 L .67159 .13466 L p F P
0 g
s
.852 .833 .827 r
.67046 .14129 m .67413 .13757 L .67159 .13466 L p F P
0 g
s
.932 .914 .777 r
.626 .20213 m .62993 .19625 L .63029 .20076 L p F P
0 g
s
.932 .914 .777 r
.62611 .20447 m .626 .20213 L p .63029 .20076 L F P
0 g
s
.932 .914 .777 r
.63029 .20076 m .62735 .20502 L .62611 .20447 L p F P
0 g
s
.831 .824 .842 r
.67806 .13407 m .68464 .1281 L .68211 .125 L p F P
0 g
s
.831 .824 .842 r
.68211 .125 m .67702 .12972 L .67806 .13407 L p F P
0 g
s
.825 .826 .849 r
.67159 .13466 m .67702 .12972 L .67806 .13407 L p F P
0 g
s
.8 .811 .861 r
.68676 .12643 m .68464 .1281 L .68211 .125 L p F P
0 g
s
.959 .923 .724 r
.61964 .22219 m .61935 .2227 L .61932 .22214 L closepath p F P
0 g
s
.852 .833 .827 r
.67159 .13466 m .66936 .13698 L .67046 .14129 L p F P
0 g
s
.848 .84 .837 r
.6626 .14389 m .66936 .13698 L .67046 .14129 L p F P
0 g
s
.848 .84 .837 r
.6633 .14768 m .6626 .14389 L p .67046 .14129 L F P
0 g
s
.848 .84 .837 r
.67046 .14129 m .66366 .14806 L .6633 .14768 L p F P
0 g
s
.709 .57 0 r
.78868 .17078 m .78876 .17533 L .78869 .1709 L p F P
0 g
s
.709 .57 0 r
.78869 .1709 m .78861 .16634 L .78868 .17078 L p F P
0 g
s
.744 .771 .874 r
.71541 .11163 m .71909 .1095 L .7166 .10589 L p F P
0 g
s
.744 .771 .874 r
.7166 .10589 m .71414 .10736 L .71541 .11163 L p F P
0 g
s
.739 .776 .882 r
.70586 .11225 m .71414 .10736 L .71541 .11163 L p F P
0 g
s
.941 .924 .56 r
.60218 .26102 m .60175 .26504 L .60398 .25975 L p F P
0 g
s
.941 .924 .56 r
.60398 .25975 m .60404 .25923 L .60218 .26102 L p F P
0 g
s
.913 .874 .785 r
.64287 .17256 m .6419 .1739 L .64271 .17828 L p F P
0 g
s
.914 .874 .784 r
.63757 .17992 m .63818 .18436 L .64271 .17828 L p F P
0 g
s
.914 .874 .784 r
.64271 .17828 m .6419 .1739 L .63757 .17992 L p F P
0 g
s
.806 .812 .855 r
.68676 .12643 m .69521 .11965 L .6927 .11638 L p F P
0 g
s
.806 .812 .855 r
.6927 .11638 m .68577 .12205 L .68676 .12643 L p F P
0 g
s
.8 .811 .861 r
.68211 .125 m .68577 .12205 L .68676 .12643 L p F P
0 g
s
.963 .923 .713 r
.61611 .22373 m .61627 .22828 L .61935 .2227 L p F P
0 g
s
.963 .923 .713 r
.61709 .2219 m .61611 .22373 L p .61935 .2227 L F P
0 g
s
.963 .923 .713 r
.61935 .2227 m .61932 .22214 L .61709 .2219 L p F P
0 g
s
.763 .851 .917 r
.65766 .34118 m .65675 .34036 L .65838 .33937 L closepath p F P
0 g
s
.925 .959 .782 r
.76455 .2507 m .76362 .25197 L .76387 .2505 L closepath p F P
0 g
s
.508 .54 .824 r
.5899 .34227 m .59835 .343 L .59537 .34842 L p F P
0 g
s
.582 .643 .877 r
.6007 .34289 m .59835 .343 L .59537 .34842 L p F P
0 g
s
.582 .643 .877 r
.59537 .34842 m .60342 .34735 L .6007 .34289 L p F P
0 g
s
.868 .84 .816 r
.66366 .14806 m .66346 .14829 L .6633 .14768 L closepath p F P
0 g
s
.872 .842 .812 r
.6567 .15049 m .65765 .15484 L .66346 .14829 L p F P
0 g
s
.872 .842 .812 r
.66112 .14539 m .6567 .15049 L p .66346 .14829 L F P
0 g
s
.872 .842 .812 r
.66346 .14829 m .6633 .14768 L .66112 .14539 L p F P
0 g
s
.913 .951 .808 r
.75944 .25355 m .75871 .25826 L .76362 .25197 L p F P
0 g
s
.913 .951 .808 r
.76232 .24986 m .75944 .25355 L p .76362 .25197 L F P
0 g
s
.913 .951 .808 r
.76362 .25197 m .76387 .2505 L .76232 .24986 L p F P
0 g
s
.302 .299 .689 r
.58693 .33344 m .58699 .33332 L .58706 .33357 L closepath p F P
0 g
s
.521 .506 .78 r
.58923 .34057 m .5899 .34227 L .59835 .343 L p F P
0 g
s
.647 .703 .888 r
.73242 .10831 m .74339 .1049 L .74587 .10894 L p F P
0 g
s
.654 .709 .888 r
.74339 .1049 m .73242 .10831 L .72993 .10452 L p F P
0 g
s
.7 .74 .882 r
.71909 .1095 m .72993 .10452 L .73242 .10831 L p F P
0 g
s
.413 .372 .703 r
.59397 .33113 m .58985 .328 L .58699 .33332 L p F P
0 g
s
.413 .372 .703 r
.59171 .33634 m .59397 .33113 L p .58699 .33332 L F P
0 g
s
.413 .372 .703 r
.58699 .33332 m .58706 .33357 L .59171 .33634 L p F P
0 g
s
.923 .932 .565 r
.6023 .2603 m .60218 .26102 L .60404 .25923 L p F P
0 g
s
.923 .932 .565 r
.60404 .25923 m .60477 .25491 L .6023 .2603 L p F P
0 g
s
.385 .378 .729 r
.58706 .33357 m .59171 .33634 L .58923 .34057 L closepath p F P
0 g
s
.951 .951 .719 r
.77291 .23065 m .77254 .23527 L .7759 .22955 L p F P
0 g
s
.951 .951 .719 r
.7759 .22955 m .77632 .22491 L .77291 .23065 L p F P
0 g
s
.953 .936 .735 r
.61932 .22214 m .61709 .2219 L .61941 .21807 L closepath p F P
0 g
s
.773 .795 .871 r
.69771 .11793 m .69521 .11965 L .6927 .11638 L p F P
0 g
s
.521 .506 .78 r
.59795 .33773 m .59171 .33634 L .58923 .34057 L p F P
0 g
s
.521 .506 .78 r
.59938 .34053 m .59795 .33773 L p .58923 .34057 L F P
0 g
s
.521 .506 .78 r
.59835 .343 m .59938 .34053 L p .58923 .34057 L F P
0 g
s
.726 .803 .912 r
.63842 .34655 m .63282 .34937 L .6302 .34657 L p F P
0 g
s
.699 .795 .925 r
.6195 .35119 m .6302 .34657 L .63282 .34937 L p F P
0 g
s
.945 .903 .75 r
.62735 .20502 m .62635 .20664 L .62611 .20447 L closepath p F P
0 g
s
.705 .743 .881 r
.72993 .10452 m .71909 .1095 L .7166 .10589 L p F P
0 g
s
.795 .878 .908 r
.68626 .32484 m .68056 .32884 L .67806 .32682 L p F P
0 g
s
.968 .934 .648 r
.60758 .24484 m .60733 .2495 L .60998 .24407 L p F P
0 g
s
.968 .934 .648 r
.60943 .24087 m .60758 .24484 L p .60998 .24407 L F P
0 g
s
.968 .934 .648 r
.60998 .24407 m .61007 .24063 L .60943 .24087 L p F P
0 g
s
.852 .843 .835 r
.6633 .14768 m .66112 .14539 L .6626 .14389 L closepath p F P
0 g
s
.773 .795 .871 r
.6927 .11638 m .69669 .11356 L .69771 .11793 L p F P
0 g
s
.779 .795 .866 r
.69771 .11793 m .70586 .11225 L .70335 .1088 L p F P
0 g
s
.779 .795 .866 r
.70335 .1088 m .69669 .11356 L .69771 .11793 L p F P
0 g
s
.655 .749 .919 r
.60613 .3514 m .61684 .34795 L .6195 .35119 L p F P
0 g
s
.632 .725 .915 r
.61684 .34795 m .60613 .3514 L .60342 .34735 L p F P
0 g
s
.464 .58 .886 r
.76353 .11678 m .76204 .11658 L .75954 .11209 L p F P
0 g
s
.9 .796 .313 r
.78748 .18475 m .78754 .18929 L .78838 .18451 L p F P
0 g
s
.9 .796 .313 r
.78838 .18451 m .78835 .17995 L .78748 .18475 L p F P
0 g
s
.87 .855 .824 r
.65088 .15705 m .6567 .15049 L .65765 .15484 L p F P
0 g
s
.87 .855 .824 r
.65095 .1575 m .65088 .15705 L p .65765 .15484 L F P
0 g
s
.87 .855 .824 r
.65765 .15484 m .65325 .15971 L .65095 .1575 L p F P
0 g
s
.95 .904 .742 r
.6225 .20786 m .62289 .21235 L .62635 .20664 L p F P
0 g
s
.95 .904 .742 r
.6248 .20395 m .6225 .20786 L p .62635 .20664 L F P
0 g
s
.95 .904 .742 r
.62635 .20664 m .62611 .20447 L .6248 .20395 L p F P
0 g
s
.85 .858 .404 r
.59672 .27982 m .59649 .28045 L .59656 .28013 L closepath p F P
0 g
s
0 0 0 r
.59274 .29536 m .59114 .30042 L .59218 .29552 L p F P
0 g
s
0 0 0 r
.59218 .29552 m .59366 .2905 L .59274 .29536 L p F P
0 g
s
.913 .891 .795 r
.63314 .18598 m .63757 .17992 L .63818 .18436 L p F P
0 g
s
.913 .891 .795 r
.63327 .18727 m .63314 .18598 L p .63818 .18436 L F P
0 g
s
.913 .891 .795 r
.63818 .18436 m .63509 .18848 L .63327 .18727 L p F P
0 g
s
0 0 .2 r
.78852 .16333 m .78861 .16634 L .788 .16211 L p F P
0 g
s
0 0 .2 r
.788 .16211 m .7879 .15863 L .78852 .16333 L p F P
0 g
s
0 0 .297 r
.59012 .31112 m .58889 .31477 L .58878 .31026 L p F P
0 g
s
0 0 .297 r
.58878 .31026 m .59001 .30663 L .59012 .31112 L p F P
0 g
s
.687 .782 .923 r
.6302 .34657 m .6195 .35119 L .61684 .34795 L p F P
0 g
s
.964 .936 .633 r
.77966 .21468 m .78218 .20926 L .78196 .21385 L p F P
0 g
s
.964 .936 .633 r
.77953 .21777 m .77966 .21468 L p .78196 .21385 L F P
0 g
s
.964 .936 .633 r
.78196 .21385 m .7802 .21764 L .77953 .21777 L p F P
0 g
s
.588 .672 .898 r
.74876 .10852 m .74587 .10894 L .74339 .1049 L p F P
0 g
s
.909 .947 .814 r
.75418 .25997 m .75944 .25355 L .75871 .25826 L p F P
0 g
s
.909 .947 .814 r
.75369 .26341 m .75418 .25997 L p .75871 .25826 L F P
0 g
s
.909 .947 .814 r
.75871 .25826 m .75429 .26368 L .75369 .26341 L p F P
0 g
s
.808 .809 .323 r
.59544 .28298 m .59494 .28552 L .59649 .28045 L p F P
0 g
s
.808 .809 .323 r
.59649 .28045 m .59656 .28013 L .59544 .28298 L p F P
0 g
s
0 0 .172 r
.59059 .30516 m .59001 .30663 L .59028 .30264 L p F P
0 g
s
0 0 .172 r
.59028 .30264 m .59114 .30042 L .59059 .30516 L p F P
0 g
s
.763 .844 .913 r
.65838 .33937 m .65675 .34036 L .65419 .33799 L p F P
0 g
s
.747 .841 .922 r
.6435 .34394 m .65419 .33799 L .65675 .34036 L p F P
0 g
s
.798 .887 .909 r
.68626 .32484 m .69118 .3213 L .68872 .3194 L p F P
0 g
s
.798 .887 .909 r
.68872 .3194 m .68812 .31983 L .68626 .32484 L p F P
0 g
s
.795 .878 .908 r
.67806 .32682 m .68812 .31983 L .68626 .32484 L p F P
0 g
s
.954 .904 .527 r
.78453 .19937 m .78434 .20397 L .78614 .19883 L p F P
0 g
s
.954 .904 .527 r
.78555 .19643 m .78453 .19937 L p .78614 .19883 L F P
0 g
s
.954 .904 .527 r
.78614 .19883 m .78627 .1959 L .78555 .19643 L p F P
0 g
s
.889 .852 .801 r
.65325 .15971 m .65191 .16138 L .65095 .1575 L closepath p F P
0 g
s
.968 .926 .695 r
.61323 .22924 m .61321 .23385 L .61627 .22828 L p F P
0 g
s
.968 .926 .695 r
.61627 .22828 m .61611 .22373 L .61323 .22924 L p F P
0 g
s
.922 .946 .795 r
.76387 .2505 m .76232 .24986 L .76426 .24729 L closepath p F P
0 g
s
.768 .795 .304 r
.59605 .28061 m .59544 .28298 L .59656 .28013 L p F P
0 g
s
.768 .795 .304 r
.59656 .28013 m .59774 .27549 L .59605 .28061 L p F P
0 g
s
.763 .85 .916 r
.65838 .33937 m .66741 .33379 L .66487 .33158 L p F P
0 g
s
.763 .85 .916 r
.66487 .33158 m .66032 .33434 L .65838 .33937 L p F P
0 g
s
.763 .844 .913 r
.65419 .33799 m .66032 .33434 L .65838 .33937 L p F P
0 g
s
.893 .854 .797 r
.646 .16327 m .64688 .16765 L .65191 .16138 L p F P
0 g
s
.893 .854 .797 r
.6507 .15726 m .646 .16327 L p .65191 .16138 L F P
0 g
s
.893 .854 .797 r
.65191 .16138 m .65095 .1575 L .6507 .15726 L p F P
0 g
s
.943 .952 .749 r
.77253 .23539 m .77247 .23538 L .77254 .23527 L closepath p F P
0 g
s
.932 .909 .518 r
.60028 .26553 m .59966 .27029 L .60175 .26504 L p F P
0 g
s
.932 .909 .518 r
.60181 .26146 m .60028 .26553 L p .60175 .26504 L F P
0 g
s
.932 .909 .518 r
.60175 .26504 m .60218 .26102 L .60181 .26146 L p F P
0 g
s
.409 .539 .876 r
.76998 .11403 m .77068 .11849 L .76353 .11678 L p F P
0 g
s
.409 .539 .876 r
.76353 .11678 m .76259 .11242 L .76998 .11403 L p F P
0 g
s
.464 .58 .886 r
.75954 .11209 m .76259 .11242 L .76353 .11678 L p F P
0 g
s
.928 .883 .769 r
.63509 .18848 m .63381 .19039 L .63327 .18727 L closepath p F P
0 g
s
.73 .824 .923 r
.6435 .34394 m .63842 .34655 L .64111 .34159 L closepath p F P
0 g
s
.726 .803 .912 r
.64091 .34139 m .64111 .34159 L .63842 .34655 L p F P
0 g
s
.726 .803 .912 r
.6302 .34657 m .64091 .34139 L p .63842 .34655 L F P
0 g
s
.744 .777 .879 r
.71414 .10736 m .70586 .11225 L .70335 .1088 L p F P
0 g
s
.809 .89 .902 r
.6981 .31613 m .69118 .3213 L .68872 .3194 L p F P
0 g
s
.156 .149 .598 r
.5918 .32287 m .58985 .328 L .58756 .32424 L p F P
0 g
s
.156 .149 .598 r
.58756 .32424 m .5898 .31901 L .5918 .32287 L p F P
0 g
s
.943 .949 .751 r
.77028 .23477 m .77291 .23065 L .77254 .23527 L p F P
0 g
s
.943 .949 .751 r
.77254 .23527 m .77247 .23538 L .77028 .23477 L p F P
0 g
s
.939 .954 .755 r
.76855 .24123 m .77247 .23538 L .77028 .23477 L p F P
0 g
s
.903 .95 .822 r
.75429 .26368 m .75345 .26467 L .75369 .26341 L closepath p F P
0 g
s
0 0 .4 r
.78664 .15356 m .78661 .1529 L .78709 .15497 L closepath p F P
0 g
s
.89 .939 .84 r
.74836 .2666 m .74753 .27132 L .75345 .26467 L p F P
0 g
s
.89 .939 .84 r
.75201 .26249 m .74836 .2666 L p .75345 .26467 L F P
0 g
s
.89 .939 .84 r
.75345 .26467 m .75369 .26341 L .75201 .26249 L p F P
0 g
s
0 .082 .626 r
.78413 .14481 m .78446 .1453 L .78452 .14593 L closepath p F P
0 g
s
0 0 .508 r
.78623 .14908 m .78661 .1529 L .78452 .14593 L p F P
0 g
s
0 0 .508 r
.78452 .14593 m .78446 .1453 L .78623 .14908 L p F P
0 g
s
.933 .885 .763 r
.62932 .19181 m .62993 .19625 L .63381 .19039 L p F P
0 g
s
.933 .885 .763 r
.63253 .18681 m .62932 .19181 L p .63381 .19039 L F P
0 g
s
.933 .885 .763 r
.63381 .19039 m .63327 .18727 L .63253 .18681 L p F P
0 g
s
0 .105 .644 r
.78446 .1453 m .78413 .14481 L .78141 .13736 L p F P
0 g
s
.959 .942 .641 r
.7802 .21764 m .7794 .21928 L .77953 .21777 L closepath p F P
0 g
s
.963 .932 .612 r
.60519 .25019 m .60477 .25491 L .60733 .2495 L p F P
0 g
s
.963 .932 .612 r
.60733 .2495 m .60758 .24484 L .60519 .25019 L p F P
0 g
s
.834 .71 .178 r
.78825 .17541 m .78835 .17995 L .78876 .17533 L p F P
0 g
s
.834 .71 .178 r
.78876 .17533 m .78868 .17078 L .78825 .17541 L p F P
0 g
s
.955 .912 .734 r
.6192 .21352 m .61941 .21807 L .62289 .21235 L p F P
0 g
s
.955 .912 .734 r
.62289 .21235 m .6225 .20786 L .6192 .21352 L p F P
0 g
s
.588 .672 .898 r
.74339 .1049 m .74763 .1042 L .74876 .10852 L p F P
0 g
s
.562 .645 .89 r
.75454 .10334 m .74763 .1042 L .74876 .10852 L p F P
0 g
s
.562 .645 .89 r
.74876 .10852 m .75704 .10768 L .75454 .10334 L p F P
0 g
s
.815 .899 .901 r
.70179 .31329 m .6981 .31613 L .6996 .31167 L closepath p F P
0 g
s
.809 .89 .902 r
.69935 .31147 m .6996 .31167 L .6981 .31613 L p F P
0 g
s
.809 .89 .902 r
.68872 .3194 m .69935 .31147 L p .6981 .31613 L F P
0 g
s
0 0 .307 r
.78738 .1531 m .78623 .14908 L .78661 .1529 L p F P
0 g
s
0 0 .307 r
.78781 .15757 m .78738 .1531 L p .78661 .1529 L F P
0 g
s
0 0 .307 r
.78661 .1529 m .78709 .15497 L .78781 .15757 L p F P
0 g
s
.893 .87 .808 r
.64102 .16953 m .646 .16327 L .64688 .16765 L p F P
0 g
s
.893 .87 .808 r
.64129 .17123 m .64102 .16953 L p .64688 .16765 L F P
0 g
s
.893 .87 .808 r
.64688 .16765 m .64287 .17256 L .64129 .17123 L p F P
0 g
s
0 .105 .644 r
.78141 .13736 m .78391 .14085 L .78446 .1453 L p F P
0 g
s
0 0 .508 r
.78571 .14462 m .78623 .14908 L .78446 .1453 L p F P
0 g
s
0 0 .508 r
.78446 .1453 m .78391 .14085 L .78571 .14462 L p F P
0 g
s
.864 .922 .866 r
.73396 .28618 m .73346 .28586 L .73418 .28516 L closepath p F P
0 g
s
.886 .935 .844 r
.74211 .27337 m .74836 .2666 L .74753 .27132 L p F P
0 g
s
.886 .935 .844 r
.74198 .27415 m .74211 .27337 L p .74753 .27132 L F P
0 g
s
.886 .935 .844 r
.74753 .27132 m .74391 .27523 L .74198 .27415 L p F P
0 g
s
.823 .899 .895 r
.70854 .30789 m .70179 .31329 L .6996 .31167 L p F P
0 g
s
.315 .445 .833 r
.77361 .11967 m .77068 .11849 L .77133 .12295 L p F P
0 g
s
.315 .445 .833 r
.77133 .12295 m .77617 .12511 L .77361 .11967 L p F P
0 g
s
.939 .915 .766 r
.62611 .20447 m .6248 .20395 L .626 .20213 L closepath p F P
0 g
s
.956 .949 .698 r
.77667 .22027 m .77632 .22491 L .7794 .21928 L p F P
0 g
s
.956 .949 .698 r
.77809 .21768 m .77667 .22027 L p .7794 .21928 L F P
0 g
s
.956 .949 .698 r
.7794 .21928 m .77953 .21777 L .77809 .21768 L p F P
0 g
s
.745 .827 .915 r
.65161 .33553 m .65419 .33799 L .6435 .34394 L p F P
0 g
s
.745 .827 .915 r
.64125 .34121 m .65161 .33553 L p .6435 .34394 L F P
0 g
s
.745 .827 .915 r
.6435 .34394 m .64111 .34159 L .64125 .34121 L p F P
0 g
s
0 0 .34 r
.78709 .15497 m .78781 .15757 L .7879 .15863 L closepath p F P
0 g
s
.777 .86 .911 r
.67455 .32915 m .66741 .33379 L .66487 .33158 L p F P
0 g
s
.88 .937 .851 r
.74391 .27523 m .74113 .27814 L .74198 .27415 L closepath p F P
0 g
s
.967 .934 .683 r
.61039 .23475 m .61019 .23942 L .61321 .23385 L p F P
0 g
s
.967 .934 .683 r
.61321 .23385 m .61323 .22924 L .61039 .23475 L p F P
0 g
s
.939 .954 .755 r
.77028 .23477 m .7691 .23655 L .76855 .24123 L p F P
0 g
s
.93 .95 .779 r
.76474 .24265 m .76426 .24729 L .76855 .24123 L p F P
0 g
s
.93 .95 .779 r
.76855 .24123 m .7691 .23655 L .76474 .24265 L p F P
0 g
s
.946 .857 .432 r
.78621 .1897 m .78628 .19424 L .78754 .18929 L p F P
0 g
s
.946 .857 .432 r
.78754 .18929 m .78748 .18475 L .78621 .1897 L p F P
0 g
s
.049 .208 .708 r
.7814 .13736 m .7814 .13735 L .78141 .13736 L closepath p F P
0 g
s
0 .087 .637 r
.7814 .13735 m .78141 .13736 L .78391 .14085 L p F P
0 g
s
.069 .246 .737 r
.77877 .13104 m .78075 .13294 L .7814 .13735 L closepath p F P
0 g
s
0 .087 .637 r
.7833 .13641 m .78075 .13294 L .7814 .13735 L p F P
0 g
s
0 .087 .637 r
.78391 .14085 m .7833 .13641 L p .7814 .13735 L F P
0 g
s
.899 .936 .828 r
.75369 .26341 m .75201 .26249 L .75418 .25997 L closepath p F P
0 g
s
.198 .345 .787 r
.77713 .12987 m .77675 .12638 L .77877 .13104 L closepath p F P
0 g
s
.829 .908 .892 r
.71238 .30474 m .70854 .30789 L .71 .30305 L closepath p F P
0 g
s
.823 .899 .895 r
.70997 .30303 m .71 .30305 L .70854 .30789 L p F P
0 g
s
.823 .899 .895 r
.69973 .31118 m .70997 .30303 L p .70854 .30789 L F P
0 g
s
.823 .899 .895 r
.6996 .31167 m .69973 .31118 L p .70854 .30789 L F P
0 g
s
0 0 .135 r
.59227 .30008 m .59059 .30516 L .59114 .30042 L p F P
0 g
s
0 0 .135 r
.59114 .30042 m .59274 .29536 L .59227 .30008 L p F P
0 g
s
.965 .924 .592 r
.78232 .20467 m .78218 .20926 L .78434 .20397 L p F P
0 g
s
.965 .924 .592 r
.78434 .20397 m .78453 .19937 L .78232 .20467 L p F P
0 g
s
.867 .925 .863 r
.73507 .28043 m .73418 .28516 L .74113 .27814 L p F P
0 g
s
.867 .925 .863 r
.74159 .2739 m .73507 .28043 L p .74113 .27814 L F P
0 g
s
.867 .925 .863 r
.74113 .27814 m .74198 .27415 L .74159 .2739 L p F P
0 g
s
.803 .81 .857 r
.68577 .12205 m .68211 .125 L .67958 .12185 L p F P
0 g
s
.832 .819 .837 r
.67702 .12972 m .68211 .125 L .67958 .12185 L p F P
0 g
s
.827 .823 .845 r
.67702 .12972 m .67159 .13466 L .66905 .13169 L p F P
0 g
s
.853 .828 .822 r
.66936 .13698 m .67159 .13466 L .66905 .13169 L p F P
0 g
s
.762 .755 .242 r
.59453 .28609 m .59366 .2905 L .59494 .28552 L p F P
0 g
s
.762 .755 .242 r
.59494 .28552 m .59544 .28298 L .59453 .28609 L p F P
0 g
s
.832 .819 .837 r
.67958 .12185 m .6758 .12542 L .67702 .12972 L p F P
0 g
s
.827 .823 .845 r
.66905 .13169 m .6758 .12542 L .67702 .12972 L p F P
0 g
s
.909 .864 .784 r
.64287 .17256 m .6419 .1739 L .64129 .17123 L closepath p F P
0 g
s
.748 .771 .871 r
.71414 .10736 m .7166 .10589 L .71409 .10228 L p F P
0 g
s
.748 .771 .871 r
.71409 .10228 m .71269 .10314 L .71414 .10736 L p F P
0 g
s
.744 .777 .879 r
.70335 .1088 m .71269 .10314 L .71414 .10736 L p F P
0 g
s
.837 .908 .886 r
.7179 .30003 m .71238 .30474 L .71 .30305 L p F P
0 g
s
.853 .828 .822 r
.66905 .13169 m .66808 .13271 L .66936 .13698 L p F P
0 g
s
.852 .827 .823 r
.66157 .13954 m .6626 .14389 L .66936 .13698 L p F P
0 g
s
.852 .827 .823 r
.66936 .13698 m .66808 .13271 L .66157 .13954 L p F P
0 g
s
.66 .714 .888 r
.7409 .1009 m .72993 .10452 L .72743 .10074 L p F P
0 g
s
.705 .743 .881 r
.7166 .10589 m .72743 .10074 L .72993 .10452 L p F P
0 g
s
.654 .709 .888 r
.72993 .10452 m .7409 .1009 L .74339 .1049 L p F P
0 g
s
.937 .894 .761 r
.62557 .19763 m .626 .20213 L .62993 .19625 L p F P
0 g
s
.937 .894 .761 r
.62993 .19625 m .62932 .19181 L .62557 .19763 L p F P
0 g
s
.808 .808 .85 r
.68577 .12205 m .6927 .11638 L .69017 .11306 L p F P
0 g
s
.808 .808 .85 r
.69017 .11306 m .68459 .11774 L .68577 .12205 L p F P
0 g
s
.803 .81 .857 r
.67958 .12185 m .68459 .11774 L .68577 .12205 L p F P
0 g
s
.475 .59 .889 r
.76259 .11242 m .75954 .11209 L .75704 .10768 L p F P
0 g
s
.632 .725 .915 r
.60342 .34735 m .61417 .34449 L .61684 .34795 L p F P
0 g
s
.603 .697 .91 r
.61417 .34449 m .60342 .34735 L .6007 .34289 L p F P
0 g
s
.914 .866 .779 r
.63672 .17554 m .63757 .17992 L .6419 .1739 L p F P
0 g
s
.914 .866 .779 r
.64031 .17043 m .63672 .17554 L p .6419 .1739 L F P
0 g
s
.914 .866 .779 r
.6419 .1739 m .64129 .17123 L .64031 .17043 L p F P
0 g
s
.843 .914 .883 r
.7179 .30003 m .72294 .29561 L .72055 .29398 L p F P
0 g
s
.843 .914 .883 r
.72055 .29398 m .71917 .29518 L .7179 .30003 L p F P
0 g
s
.837 .908 .886 r
.71002 .30298 m .71917 .29518 L .7179 .30003 L p F P
0 g
s
.837 .908 .886 r
.71 .30305 m .71002 .30298 L p .7179 .30003 L F P
0 g
s
.863 .919 .865 r
.7311 .28428 m .73507 .28043 L .73418 .28516 L p F P
0 g
s
.863 .919 .865 r
.73418 .28516 m .73346 .28586 L .7311 .28428 L p F P
0 g
s
.957 .948 .665 r
.61007 .24063 m .60943 .24087 L .61019 .23942 L closepath p F P
0 g
s
.857 .92 .871 r
.72639 .29247 m .73346 .28586 L .7311 .28428 L p F P
0 g
s
.896 .875 .439 r
.59852 .27067 m .59774 .27549 L .59966 .27029 L p F P
0 g
s
.896 .875 .439 r
.59966 .27029 m .60028 .26553 L .59852 .27067 L p F P
0 g
s
0 0 .454 r
.59072 .31626 m .5898 .31901 L .58889 .31477 L p F P
0 g
s
0 0 .454 r
.58889 .31477 m .59012 .31112 L .59072 .31626 L p F P
0 g
s
.85 .914 .876 r
.72639 .29247 m .72294 .29561 L .72055 .29398 L p F P
0 g
s
.728 .583 .007 r
.78856 .16715 m .78868 .17078 L .78861 .16634 L p F P
0 g
s
.728 .583 .007 r
.78861 .16634 m .78852 .16333 L .78856 .16715 L p F P
0 g
s
.857 .92 .871 r
.7311 .28428 m .72746 .28769 L .72639 .29247 L p F P
0 g
s
.85 .914 .876 r
.72055 .29398 m .72746 .28769 L .72639 .29247 L p F P
0 g
s
.963 .894 .517 r
.78627 .1959 m .78555 .19643 L .78628 .19424 L closepath p F P
0 g
s
.71 .746 .88 r
.72743 .10074 m .7166 .10589 L .71409 .10228 L p F P
0 g
s
.85 .838 .833 r
.65857 .14264 m .66157 .13954 L .6626 .14389 L p F P
0 g
s
.85 .838 .833 r
.6626 .14389 m .66112 .14539 L .65857 .14264 L p F P
0 g
s
.953 .93 .738 r
.6159 .21918 m .6192 .21352 L .61941 .21807 L p F P
0 g
s
.953 .93 .738 r
.61594 .22171 m .6159 .21918 L p .61941 .21807 L F P
0 g
s
.953 .93 .738 r
.61941 .21807 m .61709 .2219 L .61594 .22171 L p F P
0 g
s
.776 .794 .867 r
.69669 .11356 m .6927 .11638 L .69017 .11306 L p F P
0 g
s
.876 .843 .809 r
.6567 .15049 m .66112 .14539 L .65857 .14264 L p F P
0 g
s
0 0 .152 r
.7884 .16181 m .78852 .16333 L .7879 .15863 L p F P
0 g
s
0 0 .152 r
.7879 .15863 m .78781 .15757 L .7884 .16181 L p F P
0 g
s
.712 .804 .922 r
.64091 .34139 m .6302 .34657 L .62757 .34363 L p F P
0 g
s
.687 .782 .923 r
.61684 .34795 m .62757 .34363 L .6302 .34657 L p F P
0 g
s
.783 .873 .914 r
.67806 .32682 m .67455 .32915 L .67611 .3252 L closepath p F P
0 g
s
.777 .86 .911 r
.67555 .32472 m .67611 .3252 L .67455 .32915 L p F P
0 g
s
.777 .86 .911 r
.66487 .33158 m .67555 .32472 L p .67455 .32915 L F P
0 g
s
.951 .928 .578 r
.6029 .25552 m .6023 .2603 L .60477 .25491 L p F P
0 g
s
.951 .928 .578 r
.60477 .25491 m .60519 .25019 L .6029 .25552 L p F P
0 g
s
.963 .941 .683 r
.77953 .21777 m .77809 .21768 L .77966 .21468 L closepath p F P
0 g
s
.595 .677 .898 r
.74763 .1042 m .74339 .1049 L .7409 .1009 L p F P
0 g
s
.922 .945 .795 r
.7601 .24885 m .76474 .24265 L .76426 .24729 L p F P
0 g
s
.922 .945 .795 r
.7601 .2489 m .7601 .24885 L p .76426 .24729 L F P
0 g
s
.922 .945 .795 r
.76426 .24729 m .76232 .24986 L .7601 .2489 L p F P
0 g
s
.455 .503 .819 r
.59517 .3316 m .59397 .33113 L .59171 .33634 L p F P
0 g
s
.455 .503 .819 r
.59171 .33634 m .59795 .33773 L .59517 .3316 L p F P
0 g
s
0 0 .325 r
.59069 .30967 m .59012 .31112 L .59001 .30663 L p F P
0 g
s
0 0 .325 r
.59001 .30663 m .59059 .30516 L .59069 .30967 L p F P
0 g
s
.673 .767 .921 r
.62757 .34363 m .61684 .34795 L .61417 .34449 L p F P
0 g
s
.952 .948 .726 r
.77322 .22604 m .77291 .23065 L .77632 .22491 L p F P
0 g
s
.952 .948 .726 r
.77632 .22491 m .77667 .22027 L .77322 .22604 L p F P
0 g
s
.776 .794 .867 r
.69017 .11306 m .69547 .10925 L .69669 .11356 L p F P
0 g
s
.782 .793 .861 r
.69669 .11356 m .70335 .1088 L .70083 .10533 L p F P
0 g
s
.782 .793 .861 r
.70083 .10533 m .69547 .10925 L .69669 .11356 L p F P
0 g
s
.876 .843 .809 r
.65857 .14264 m .65555 .14618 L .6567 .15049 L p F P
0 g
s
.873 .842 .811 r
.64995 .15267 m .65088 .15705 L .6567 .15049 L p F P
0 g
s
.873 .842 .811 r
.6567 .15049 m .65555 .14618 L .64995 .15267 L p F P
0 g
s
.792 .874 .907 r
.68812 .31983 m .67806 .32682 L .67611 .3252 L p F P
0 g
s
.96 .945 .672 r
.6076 .24024 m .61039 .23475 L .61019 .23942 L p F P
0 g
s
.96 .945 .672 r
.60753 .24144 m .6076 .24024 L p .61019 .23942 L F P
0 g
s
.96 .945 .672 r
.61019 .23942 m .60943 .24087 L .60753 .24144 L p F P
0 g
s
.039 .237 .738 r
.77675 .12638 m .77877 .13104 L .78075 .13294 L p F P
0 g
s
.917 .948 .803 r
.76232 .24986 m .75944 .25355 L .7601 .2489 L closepath p F P
0 g
s
.912 .804 .33 r
.78737 .18021 m .78748 .18475 L .78835 .17995 L p F P
0 g
s
.912 .804 .33 r
.78835 .17995 m .78825 .17541 L .78737 .18021 L p F P
0 g
s
.916 .874 .781 r
.63248 .18154 m .63314 .18598 L .63757 .17992 L p F P
0 g
s
.916 .874 .781 r
.63757 .17992 m .63672 .17554 L .63248 .18154 L p F P
0 g
s
.937 .908 .767 r
.62223 .20279 m .62557 .19763 L .626 .20213 L p F P
0 g
s
.937 .908 .767 r
.626 .20213 m .6248 .20395 L .62223 .20279 L p F P
0 g
s
.919 .893 .788 r
.63327 .18727 m .63253 .18681 L .63314 .18598 L closepath p F P
0 g
s
0 0 .138 r
.78798 .15734 m .7884 .16181 L .78781 .15757 L p F P
0 g
s
0 0 .138 r
.78781 .15757 m .78738 .1531 L .78798 .15734 L p F P
0 g
s
.964 .915 .711 r
.61709 .2219 m .61611 .22373 L .61594 .22171 L closepath p F P
0 g
s
.875 .857 .821 r
.65095 .1575 m .6507 .15726 L .65088 .15705 L closepath p F P
0 g
s
.55 .606 .862 r
.59835 .343 m .59938 .34053 L .6007 .34289 L closepath p F P
0 g
s
.758 .838 .912 r
.66032 .33434 m .65419 .33799 L .65161 .33553 L p F P
0 g
s
.968 .934 .645 r
.77977 .21011 m .77966 .21468 L .78218 .20926 L p F P
0 g
s
.968 .934 .645 r
.78218 .20926 m .78232 .20467 L .77977 .21011 L p F P
0 g
s
.973 .927 .65 r
.60943 .24087 m .60758 .24484 L .60753 .24144 L closepath p F P
0 g
s
.251 .272 .688 r
.59444 .32981 m .59397 .33113 L .58985 .328 L p F P
0 g
s
.251 .272 .688 r
.59234 .32344 m .59444 .32981 L p .58985 .328 L F P
0 g
s
.251 .272 .688 r
.58985 .328 m .5918 .32287 L .59234 .32344 L p F P
0 g
s
.748 .777 .876 r
.71269 .10314 m .70335 .1088 L .70083 .10533 L p F P
0 g
s
.965 .894 .52 r
.78454 .19481 m .78621 .1897 L .78628 .19424 L p F P
0 g
s
.965 .894 .52 r
.78458 .19712 m .78454 .19481 L p .78628 .19424 L F P
0 g
s
.965 .894 .52 r
.78628 .19424 m .78555 .19643 L .78458 .19712 L p F P
0 g
s
.953 .897 .734 r
.6225 .20786 m .6248 .20395 L .62223 .20279 L p F P
0 g
s
.91 .914 .52 r
.60218 .26102 m .60181 .26146 L .6023 .2603 L closepath p F P
0 g
s
.873 .853 .819 r
.64813 .15477 m .64995 .15267 L .65088 .15705 L p F P
0 g
s
.873 .853 .819 r
.65088 .15705 m .6507 .15726 L .64813 .15477 L p F P
0 g
s
.897 .855 .793 r
.646 .16327 m .6507 .15726 L .64813 .15477 L p F P
0 g
s
.903 .939 .823 r
.75476 .25531 m .75418 .25997 L .75944 .25355 L p F P
0 g
s
.903 .939 .823 r
.76007 .24889 m .75476 .25531 L p .75944 .25355 L F P
0 g
s
.903 .939 .823 r
.75944 .25355 m .7601 .2489 L .76007 .24889 L p F P
0 g
s
.42 .549 .879 r
.76953 .11138 m .76998 .11403 L .76259 .11242 L p F P
0 g
s
.42 .549 .879 r
.76851 .10939 m .76953 .11138 L p .76259 .11242 L F P
0 g
s
.42 .549 .879 r
.76259 .11242 m .7616 .10806 L .76851 .10939 L p F P
0 g
s
.475 .59 .889 r
.75704 .10768 m .7616 .10806 L .76259 .11242 L p F P
0 g
s
.969 .915 .698 r
.61293 .22473 m .61323 .22924 L .61611 .22373 L p F P
0 g
s
.969 .915 .698 r
.61453 .22157 m .61293 .22473 L p .61611 .22373 L F P
0 g
s
.969 .915 .698 r
.61611 .22373 m .61594 .22171 L .61453 .22157 L p F P
0 g
s
0 0 0 r
.59374 .2905 m .59274 .29536 L .59366 .2905 L p F P
0 g
s
0 0 0 r
.59432 .28722 m .59374 .2905 L p .59366 .2905 L F P
0 g
s
0 0 0 r
.59366 .2905 m .59453 .28609 L .59432 .28722 L p F P
0 g
s
.711 .732 .216 r
.59458 .28592 m .59544 .28298 L p .59464 .28564 L F P
0 g
s
.711 .732 .216 r
.59544 .28298 m .59605 .28061 L .59464 .28564 L p F P
0 g
s
0 0 0 r
.59477 .28561 m .59524 .28315 L p .59464 .28564 L F P
0 g
s
.769 .758 .245 r
.5957 .28073 m .59464 .28564 L .59605 .28061 L p F P
0 g
s
0 0 0 r
.59524 .28315 m .5957 .28073 L .59464 .28564 L p F P
0 g
s
.711 .732 .216 r
.59464 .28564 m .59453 .28609 L .59458 .28592 L p F P
0 g
s
.845 .83 .355 r
.59698 .27575 m .59605 .28061 L .59774 .27549 L p F P
0 g
s
.845 .83 .355 r
.59774 .27549 m .59852 .27067 L .59698 .27575 L p F P
0 g
s
0 0 .296 r
.59238 .30459 m .59069 .30967 L .59059 .30516 L p F P
0 g
s
0 0 .296 r
.59059 .30516 m .59227 .30008 L .59238 .30459 L p F P
0 g
s
0 0 .33 r
.78688 .14864 m .78738 .1531 L .78623 .14908 L p F P
0 g
s
0 0 .33 r
.78623 .14908 m .78571 .14462 L .78688 .14864 L p F P
0 g
s
.798 .884 .908 r
.68872 .3194 m .68812 .31983 L .68837 .31913 L closepath p F P
0 g
s
.792 .874 .907 r
.68623 .31732 m .68837 .31913 L .68812 .31983 L p F P
0 g
s
.792 .874 .907 r
.67643 .32412 m .68623 .31732 L p .68812 .31983 L F P
0 g
s
.792 .874 .907 r
.67611 .3252 m .67643 .32412 L p .68812 .31983 L F P
0 g
s
.945 .947 .748 r
.76945 .23193 m .77322 .22604 L .77291 .23065 L p F P
0 g
s
.945 .947 .748 r
.7693 .23449 m .76945 .23193 L p .77291 .23065 L F P
0 g
s
.945 .947 .748 r
.77291 .23065 m .77028 .23477 L .7693 .23449 L p F P
0 g
s
.898 .872 .803 r
.64129 .17123 m .64031 .17043 L .64102 .16953 L closepath p F P
0 g
s
.811 .885 .898 r
.69689 .30947 m .69935 .31147 L .68872 .3194 L p F P
0 g
s
.811 .885 .898 r
.68948 .31497 m .69689 .30947 L p .68872 .3194 L F P
0 g
s
.811 .885 .898 r
.68872 .3194 m .68837 .31913 L .68948 .31497 L p F P
0 g
s
.921 .919 .534 r
.60075 .2608 m .6029 .25552 L .6023 .2603 L p F P
0 g
s
.921 .919 .534 r
.60045 .263 m .60075 .2608 L p .6023 .2603 L F P
0 g
s
.921 .919 .534 r
.6023 .2603 m .60181 .26146 L .60045 .263 L p F P
0 g
s
.917 .887 .787 r
.62996 .18508 m .63248 .18154 L .63314 .18598 L p F P
0 g
s
.917 .887 .787 r
.63314 .18598 m .63253 .18681 L .62996 .18508 L p F P
0 g
s
.595 .677 .898 r
.7409 .1009 m .74649 .09987 L .74763 .1042 L p F P
0 g
s
.571 .654 .892 r
.75204 .09905 m .74649 .09987 L .74763 .1042 L p F P
0 g
s
.571 .654 .892 r
.74763 .1042 m .75454 .10334 L .75204 .09905 L p F P
0 g
s
.19 .356 .8 r
.77617 .12511 m .77658 .12539 L .77675 .12638 L closepath p F P
0 g
s
.039 .237 .738 r
.78003 .12852 m .77658 .12539 L .77675 .12638 L p F P
0 g
s
.039 .237 .738 r
.78075 .13294 m .78003 .12852 L p .77675 .12638 L F P
0 g
s
.96 .901 .526 r
.78555 .19643 m .78453 .19937 L .78458 .19712 L closepath p F P
0 g
s
.936 .882 .756 r
.62932 .19181 m .63253 .18681 L .62996 .18508 L p F P
0 g
s
.758 .838 .912 r
.66233 .32929 m .6624 .32936 L .66032 .33434 L p F P
0 g
s
.758 .838 .912 r
.65161 .33553 m .66233 .32929 L p .66032 .33434 L F P
0 g
s
.764 .854 .918 r
.66487 .33158 m .66032 .33434 L .6624 .32936 L closepath p F P
0 g
s
.603 .697 .91 r
.6007 .34289 m .61148 .34077 L .61417 .34449 L p F P
0 g
s
.606 .633 .852 r
.59938 .34053 m .6007 .34289 L .61148 .34077 L p F P
0 g
s
.899 .934 .828 r
.74971 .26121 m .75476 .25531 L .75418 .25997 L p F P
0 g
s
.899 .934 .828 r
.75418 .25997 m .75201 .26249 L .74971 .26121 L p F P
0 g
s
.852 .723 .199 r
.78809 .17086 m .78825 .17541 L .78868 .17078 L p F P
0 g
s
.852 .723 .199 r
.78828 .16879 m .78809 .17086 L p .78868 .17078 L F P
0 g
s
.852 .723 .199 r
.78868 .17078 m .78856 .16715 L .78828 .16879 L p F P
0 g
s
.773 .607 .04 r
.78849 .16624 m .78856 .16715 L .78852 .16333 L p F P
0 g
s
.773 .607 .04 r
.78852 .16333 m .7884 .16181 L .78849 .16624 L p F P
0 g
s
.738 .82 .915 r
.64111 .34159 m .64091 .34139 L .64125 .34121 L closepath p F P
0 g
s
.953 .897 .734 r
.62223 .20279 m .62185 .20344 L .6225 .20786 L p F P
0 g
s
.956 .898 .727 r
.61871 .20905 m .6192 .21352 L .6225 .20786 L p F P
0 g
s
.956 .898 .727 r
.6225 .20786 m .62185 .20344 L .61871 .20905 L p F P
0 g
s
.897 .855 .793 r
.64813 .15477 m .64492 .15895 L .646 .16327 L p F P
0 g
s
.895 .855 .795 r
.64013 .16515 m .64102 .16953 L .646 .16327 L p F P
0 g
s
.895 .855 .795 r
.646 .16327 m .64492 .15895 L .64013 .16515 L p F P
0 g
s
.947 .908 .528 r
.60181 .26146 m .60028 .26553 L .60045 .263 L closepath p F P
0 g
s
.485 .598 .891 r
.7616 .10806 m .75704 .10768 L .75454 .10334 L p F P
0 g
s
0 0 .508 r
.78513 .14017 m .78571 .14462 L .78391 .14085 L p F P
0 g
s
0 0 .508 r
.78391 .14085 m .7833 .13641 L .78513 .14017 L p F P
0 g
s
.975 .923 .627 r
.60523 .24559 m .60519 .25019 L .60758 .24484 L p F P
0 g
s
.975 .923 .627 r
.60688 .24172 m .60523 .24559 L p .60758 .24484 L F P
0 g
s
.975 .923 .627 r
.60758 .24484 m .60753 .24144 L .60688 .24172 L p F P
0 g
s
.801 .875 .901 r
.68837 .31913 m .68623 .31732 L .68948 .31497 L closepath p F P
0 g
s
.329 .463 .844 r
.77105 .11442 m .76998 .11403 L .77068 .11849 L p F P
0 g
s
.329 .463 .844 r
.77068 .11849 m .77361 .11967 L .77105 .11442 L p F P
0 g
s
.816 .889 .896 r
.6996 .31167 m .69935 .31147 L .69973 .31118 L closepath p F P
0 g
s
.894 .937 .835 r
.74836 .2666 m .75201 .26249 L .74971 .26121 L p F P
0 g
s
.205 .373 .81 r
.77658 .12539 m .77617 .12511 L .77361 .11967 L p F P
0 g
s
.105 .125 .597 r
.592 .32228 m .5918 .32287 L .5898 .31901 L p F P
0 g
s
.105 .125 .597 r
.5898 .31901 m .59072 .31626 L .592 .32228 L p F P
0 g
s
.737 .811 .91 r
.64125 .34121 m .64091 .34139 L .6383 .33864 L p F P
0 g
s
.712 .804 .922 r
.62757 .34363 m .6383 .33864 L .64091 .34139 L p F P
0 g
s
.66 .714 .888 r
.72743 .10074 m .7384 .09692 L .7409 .1009 L p F P
0 g
s
.666 .718 .888 r
.7384 .09692 m .72743 .10074 L .72493 .09696 L p F P
0 g
s
.71 .746 .88 r
.71409 .10228 m .72493 .09696 L .72743 .10074 L p F P
0 g
s
.734 .813 .913 r
.64125 .34121 m .65161 .33553 L .64903 .333 L p F P
0 g
s
.734 .813 .913 r
.64903 .333 m .64283 .33628 L .64125 .34121 L p F P
0 g
s
.737 .811 .91 r
.6383 .33864 m .64283 .33628 L .64125 .34121 L p F P
0 g
s
.94 .951 .757 r
.77028 .23477 m .7691 .23655 L .7693 .23449 L closepath p F P
0 g
s
.877 .924 .853 r
.74198 .27415 m .74159 .2739 L .74211 .27337 L closepath p F P
0 g
s
0 .111 .652 r
.78263 .13198 m .7833 .13641 L .78075 .13294 L p F P
0 g
s
0 .111 .652 r
.78075 .13294 m .78003 .12852 L .78263 .13198 L p F P
0 g
s
.964 .94 .685 r
.77687 .21568 m .77977 .21011 L .77966 .21468 L p F P
0 g
s
.964 .94 .685 r
.77683 .21758 m .77687 .21568 L p .77966 .21468 L F P
0 g
s
.964 .94 .685 r
.77966 .21468 m .77809 .21768 L .77683 .21758 L p F P
0 g
s
.805 .807 .853 r
.68459 .11774 m .67958 .12185 L .67703 .11865 L p F P
0 g
s
.833 .815 .832 r
.6758 .12542 m .67958 .12185 L .67703 .11865 L p F P
0 g
s
.752 .771 .868 r
.71269 .10314 m .71409 .10228 L .71158 .09865 L p F P
0 g
s
.752 .771 .868 r
.71158 .09865 m .71109 .09896 L .71269 .10314 L p F P
0 g
s
.748 .777 .876 r
.70083 .10533 m .71109 .09896 L .71269 .10314 L p F P
0 g
s
.833 .815 .832 r
.67703 .11865 m .67441 .12118 L .6758 .12542 L p F P
0 g
s
.829 .82 .84 r
.66668 .12847 m .67441 .12118 L .6758 .12542 L p F P
0 g
s
.829 .82 .84 r
.66684 .12907 m .66668 .12847 L p .6758 .12542 L F P
0 g
s
.829 .82 .84 r
.6758 .12542 m .66905 .13169 L .66684 .12907 L p F P
0 g
s
.815 .884 .894 r
.69973 .31118 m .69935 .31147 L .69689 .30947 L p F P
0 g
s
.894 .937 .835 r
.74971 .26121 m .74912 .26187 L .74836 .2666 L p F P
0 g
s
.884 .929 .845 r
.74276 .2687 m .74211 .27337 L .74836 .2666 L p F P
0 g
s
.884 .929 .845 r
.74836 .2666 m .74912 .26187 L .74276 .2687 L p F P
0 g
s
.205 .373 .81 r
.77361 .11967 m .77573 .12101 L .77658 .12539 L p F P
0 g
s
.081 .269 .756 r
.77925 .12411 m .78003 .12852 L .77658 .12539 L p F P
0 g
s
.081 .269 .756 r
.77658 .12539 m .77573 .12101 L .77925 .12411 L p F P
0 g
s
.777 .856 .909 r
.67303 .32245 m .67555 .32472 L .66487 .33158 L p F P
0 g
s
.777 .856 .909 r
.66244 .32922 m .67303 .32245 L p .66487 .33158 L F P
0 g
s
.777 .856 .909 r
.66487 .33158 m .6624 .32936 L .66244 .32922 L p F P
0 g
s
.82 .889 .893 r
.69973 .31118 m .70997 .30303 L .70753 .3011 L p F P
0 g
s
.82 .889 .893 r
.70753 .3011 m .70088 .30638 L .69973 .31118 L p F P
0 g
s
.815 .884 .894 r
.69689 .30947 m .70088 .30638 L .69973 .31118 L p F P
0 g
s
.85 .822 .82 r
.66905 .13169 m .66808 .13271 L .66684 .12907 L closepath p F P
0 g
s
0 0 .48 r
.59167 .31389 m .59072 .31626 L .59012 .31112 L p F P
0 g
s
0 0 .48 r
.59012 .31112 m .59069 .30967 L .59167 .31389 L p F P
0 g
s
.954 .861 .446 r
.78607 .18518 m .78621 .1897 L .78748 .18475 L p F P
0 g
s
.954 .861 .446 r
.78748 .18475 m .78737 .18021 L .78607 .18518 L p F P
0 g
s
.855 .823 .817 r
.66035 .13524 m .66157 .13954 L .66808 .13271 L p F P
0 g
s
.855 .823 .817 r
.66649 .12865 m .66035 .13524 L p .66808 .13271 L F P
0 g
s
.855 .823 .817 r
.66808 .13271 m .66684 .12907 L .66649 .12865 L p F P
0 g
s
.973 .919 .68 r
.61025 .23018 m .61039 .23475 L .61323 .22924 L p F P
0 g
s
.973 .919 .68 r
.61323 .22924 m .61293 .22473 L .61025 .23018 L p F P
0 g
s
.81 .805 .846 r
.68459 .11774 m .69017 .11306 L .68763 .10971 L p F P
0 g
s
.81 .805 .846 r
.68763 .10971 m .68322 .11347 L .68459 .11774 L p F P
0 g
s
.805 .807 .853 r
.67703 .11865 m .68322 .11347 L .68459 .11774 L p F P
0 g
s
.714 .748 .879 r
.72493 .09696 m .71409 .10228 L .71158 .09865 L p F P
0 g
s
.959 .929 .721 r
.61594 .22171 m .61453 .22157 L .6159 .21918 L closepath p F P
0 g
s
.927 .944 .787 r
.76516 .23801 m .76474 .24265 L .7691 .23655 L p F P
0 g
s
.927 .944 .787 r
.76806 .23395 m .76516 .23801 L p .7691 .23655 L F P
0 g
s
.927 .944 .787 r
.7691 .23655 m .7693 .23449 L .76806 .23395 L p F P
0 g
s
.602 .682 .898 r
.74649 .09987 m .7409 .1009 L .7384 .09692 L p F P
0 g
s
.97 .925 .608 r
.7824 .20009 m .78232 .20467 L .78453 .19937 L p F P
0 g
s
.97 .925 .608 r
.78352 .19738 m .7824 .20009 L p .78453 .19937 L F P
0 g
s
.97 .925 .608 r
.78453 .19937 m .78458 .19712 L .78352 .19738 L p F P
0 g
s
.543 .581 .842 r
.59795 .33773 m .60102 .33767 L .59938 .34053 L closepath p F P
0 g
s
.606 .633 .852 r
.60878 .33675 m .60102 .33767 L .59938 .34053 L p F P
0 g
s
.606 .633 .852 r
.61148 .34077 m .60878 .33675 L p .59938 .34053 L F P
0 g
s
.896 .866 .802 r
.63773 .16822 m .64013 .16515 L .64102 .16953 L p F P
0 g
s
.896 .866 .802 r
.64102 .16953 m .64031 .17043 L .63773 .16822 L p F P
0 g
s
.936 .882 .756 r
.62996 .18508 m .62847 .18745 L .62932 .19181 L p F P
0 g
s
.937 .882 .754 r
.62488 .19321 m .62557 .19763 L .62932 .19181 L p F P
0 g
s
.937 .882 .754 r
.62932 .19181 m .62847 .18745 L .62488 .19321 L p F P
0 g
s
.78 .793 .864 r
.69547 .10925 m .69017 .11306 L .68763 .10971 L p F P
0 g
s
.917 .865 .773 r
.63672 .17554 m .64031 .17043 L .63773 .16822 L p F P
0 g
s
.703 .794 .921 r
.6383 .33864 m .62757 .34363 L .62492 .34054 L p F P
0 g
s
.673 .767 .921 r
.61417 .34449 m .62492 .34054 L .62757 .34363 L p F P
0 g
s
.876 .92 .852 r
.73925 .27234 m .74276 .2687 L .74211 .27337 L p F P
0 g
s
.876 .92 .852 r
.74211 .27337 m .74159 .2739 L .73925 .27234 L p F P
0 g
s
.655 .749 .919 r
.62492 .34054 m .61417 .34449 L .61148 .34077 L p F P
0 g
s
.852 .834 .828 r
.656 .13981 m .66035 .13524 L .66157 .13954 L p F P
0 g
s
.852 .834 .828 r
.66157 .13954 m .65857 .14264 L .656 .13981 L p F P
0 g
s
.87 .922 .859 r
.73507 .28043 m .74159 .2739 L .73925 .27234 L p F P
0 g
s
.793 .619 .058 r
.78807 .16177 m .78849 .16624 L .7884 .16181 L p F P
0 g
s
.793 .619 .058 r
.7884 .16181 m .78798 .15734 L .78807 .16177 L p F P
0 g
s
.829 .897 .888 r
.71 .30305 m .70997 .30303 L .71002 .30298 L closepath p F P
0 g
s
.828 .892 .887 r
.71002 .30298 m .70997 .30303 L .70753 .3011 L p F P
0 g
s
.831 .9 .888 r
.71102 .29822 m .71002 .30298 L .71917 .29518 L p F P
0 g
s
.828 .892 .887 r
.70753 .3011 m .71102 .29822 L .71002 .30298 L p F P
0 g
s
.769 .758 .245 r
.59605 .28061 m .59698 .27575 L .5957 .28073 L p F P
0 g
s
.786 .865 .907 r
.67611 .3252 m .67555 .32472 L .67643 .32412 L closepath p F P
0 g
s
.96 .945 .694 r
.77809 .21768 m .77667 .22027 L .77683 .21758 L closepath p F P
0 g
s
.875 .836 .804 r
.65555 .14618 m .65857 .14264 L .656 .13981 L p F P
0 g
s
0 0 .048 r
.59331 .2952 m .59227 .30008 L .59274 .29536 L p F P
0 g
s
0 0 .048 r
.59274 .29536 m .59374 .2905 L .59331 .2952 L p F P
0 g
s
.959 .907 .724 r
.61557 .21466 m .6159 .21918 L .6192 .21352 L p F P
0 g
s
.959 .907 .724 r
.6192 .21352 m .61871 .20905 L .61557 .21466 L p F P
0 g
s
.87 .922 .859 r
.73925 .27234 m .7359 .2757 L .73507 .28043 L p F P
0 g
s
.864 .917 .864 r
.72872 .28268 m .7359 .2757 L .73507 .28043 L p F P
0 g
s
.864 .917 .864 r
.73507 .28043 m .7311 .28428 L .72872 .28268 L p F P
0 g
s
.935 .89 .484 r
.59885 .266 m .59852 .27067 L .60028 .26553 L p F P
0 g
s
.935 .89 .484 r
.59931 .26463 m .59885 .266 L p .60028 .26553 L F P
0 g
s
.935 .89 .484 r
.60028 .26553 m .60045 .263 L .59931 .26463 L p F P
0 g
s
.831 .9 .888 r
.71814 .29219 m .71102 .29822 L p .71917 .29518 L F P
0 g
s
.831 .9 .888 r
.71917 .29518 m .71963 .29333 L .71814 .29219 L p F P
0 g
s
.843 .911 .882 r
.72055 .29398 m .71917 .29518 L .71963 .29333 L closepath p F P
0 g
s
.857 .918 .871 r
.72746 .28769 m .7311 .28428 L .72872 .28268 L p F P
0 g
s
.85 .91 .875 r
.72746 .28769 m .72055 .29398 L .71963 .29333 L p F P
0 g
s
.78 .793 .864 r
.68763 .10971 m .69406 .10499 L .69547 .10925 L p F P
0 g
s
.784 .79 .858 r
.69547 .10925 m .70083 .10533 L .6983 .10183 L p F P
0 g
s
.784 .79 .858 r
.6983 .10183 m .69406 .10499 L .69547 .10925 L p F P
0 g
s
.857 .918 .871 r
.72872 .28268 m .72849 .2829 L .72746 .28769 L p F P
0 g
s
.85 .91 .875 r
.72017 .29042 m .72849 .2829 L .72746 .28769 L p F P
0 g
s
.85 .91 .875 r
.71963 .29333 m .72017 .29042 L p .72746 .28769 L F P
0 g
s
.875 .836 .804 r
.656 .13981 m .65422 .14193 L .65555 .14618 L p F P
0 g
s
.874 .836 .805 r
.64881 .14836 m .64995 .15267 L .65555 .14618 L p F P
0 g
s
.874 .836 .805 r
.65555 .14618 m .65422 .14193 L .64881 .14836 L p F P
0 g
s
.97 .919 .589 r
.60309 .25087 m .6029 .25552 L .60519 .25019 L p F P
0 g
s
.97 .919 .589 r
.60519 .25019 m .60523 .24559 L .60309 .25087 L p F P
0 g
s
0 0 .452 r
.59328 .30884 m .59167 .31389 L .59069 .30967 L p F P
0 g
s
0 0 .452 r
.59069 .30967 m .59238 .30459 L .59328 .30884 L p F P
0 g
s
.493 .54 .834 r
.60102 .33767 m .59795 .33773 L .59517 .3316 L p F P
0 g
s
.922 .939 .796 r
.76046 .24424 m .7601 .24885 L .76474 .24265 L p F P
0 g
s
.922 .939 .796 r
.76474 .24265 m .76516 .23801 L .76046 .24424 L p F P
0 g
s
.95 .944 .737 r
.77345 .22144 m .77322 .22604 L .77667 .22027 L p F P
0 g
s
.95 .944 .737 r
.77592 .21732 m .77345 .22144 L p .77667 .22027 L F P
0 g
s
.95 .944 .737 r
.77667 .22027 m .77683 .21758 L .77592 .21732 L p F P
0 g
s
.917 .865 .773 r
.63773 .16822 m .63567 .17123 L .63672 .17554 L p F P
0 g
s
.917 .865 .773 r
.63158 .17717 m .63248 .18154 L .63672 .17554 L p F P
0 g
s
.917 .865 .773 r
.63672 .17554 m .63567 .17123 L .63158 .17717 L p F P
0 g
s
.786 .859 .905 r
.67643 .32412 m .67555 .32472 L .67303 .32245 L p F P
0 g
s
.752 .777 .874 r
.71109 .09896 m .70083 .10533 L .6983 .10183 L p F P
0 g
s
0 0 .127 r
.78748 .15288 m .78798 .15734 L .78738 .1531 L p F P
0 g
s
0 0 .127 r
.78738 .1531 m .78688 .14864 L .78748 .15288 L p F P
0 g
s
.924 .812 .347 r
.78718 .17568 m .78737 .18021 L .78825 .17541 L p F P
0 g
s
.924 .812 .347 r
.78825 .17541 m .78809 .17086 L .78718 .17568 L p F P
0 g
s
.789 .864 .905 r
.67643 .32412 m .68623 .31732 L .68373 .31517 L p F P
0 g
s
.789 .864 .905 r
.68373 .31517 m .67776 .31927 L .67643 .32412 L p F P
0 g
s
.786 .859 .905 r
.67303 .32245 m .67776 .31927 L .67643 .32412 L p F P
0 g
s
.221 .39 .82 r
.77573 .12101 m .77361 .11967 L .77105 .11442 L p F P
0 g
s
.938 .899 .762 r
.62125 .199 m .62488 .19321 L .62557 .19763 L p F P
0 g
s
.938 .899 .762 r
.62168 .20252 m .62125 .199 L p .62557 .19763 L F P
0 g
s
.938 .899 .762 r
.62557 .19763 m .62223 .20279 L .62168 .20252 L p F P
0 g
s
.973 .925 .667 r
.60763 .23562 m .6076 .24024 L .61039 .23475 L p F P
0 g
s
.973 .925 .667 r
.61039 .23475 m .61025 .23018 L .60763 .23562 L p F P
0 g
s
.752 .837 .916 r
.66233 .32929 m .65161 .33553 L .64903 .333 L p F P
0 g
s
.485 .598 .891 r
.75454 .10334 m .76057 .10369 L .7616 .10806 L p F P
0 g
s
.425 .544 .873 r
.76598 .10458 m .76057 .10369 L .7616 .10806 L p F P
0 g
s
.425 .544 .873 r
.7616 .10806 m .76851 .10939 L .76598 .10458 L p F P
0 g
s
.874 .847 .814 r
.64555 .15217 m .64881 .14836 L .64995 .15267 L p F P
0 g
s
.874 .847 .814 r
.64995 .15267 m .64813 .15477 L .64555 .15217 L p F P
0 g
s
.935 .939 .773 r
.7693 .23449 m .76806 .23395 L .76945 .23193 L closepath p F P
0 g
s
.97 .933 .654 r
.77981 .20555 m .77977 .21011 L .78232 .20467 L p F P
0 g
s
.97 .933 .654 r
.78232 .20467 m .7824 .20009 L .77981 .20555 L p F P
0 g
s
.165 .168 .615 r
.59388 .31768 m .592 .32228 L .59072 .31626 L p F P
0 g
s
.165 .168 .615 r
.59072 .31626 m .59167 .31389 L .59388 .31768 L p F P
0 g
s
.401 .444 .79 r
.59397 .33113 m .59444 .32981 L .59517 .3316 L closepath p F P
0 g
s
.973 .894 .533 r
.78438 .19029 m .78454 .19481 L .78621 .1897 L p F P
0 g
s
.973 .894 .533 r
.78621 .1897 m .78607 .18518 L .78438 .19029 L p F P
0 g
s
.976 .915 .594 r
.78458 .19712 m .78352 .19738 L .78454 .19481 L closepath p F P
0 g
s
.494 .606 .893 r
.76057 .10369 m .75454 .10334 L .75204 .09905 L p F P
0 g
s
.896 .847 .788 r
.64492 .15895 m .64813 .15477 L .64555 .15217 L p F P
0 g
s
.877 .729 .214 r
.78856 .16715 m .78828 .16879 L .78849 .16624 L closepath p F P
0 g
s
.959 .922 .725 r
.61244 .22028 m .61557 .21466 L .6159 .21918 L p F P
0 g
s
.959 .922 .725 r
.6125 .22122 m .61244 .22028 L p .6159 .21918 L F P
0 g
s
.959 .922 .725 r
.6159 .21918 m .61453 .22157 L .6125 .22122 L p F P
0 g
s
.912 .935 .812 r
.7601 .2489 m .76007 .24889 L .7601 .24885 L closepath p F P
0 g
s
0 0 0 r
.59453 .28609 m .59432 .28722 L .59464 .28564 L closepath p F P
0 g
s
.964 .939 .644 r
.60753 .24144 m .60688 .24172 L .6076 .24024 L closepath p F P
0 g
s
.911 .931 .812 r
.75779 .2476 m .76046 .24424 L .7601 .24885 L p F P
0 g
s
.911 .931 .812 r
.7601 .24885 m .76007 .24889 L .75779 .2476 L p F P
0 g
s
.907 .935 .818 r
.75476 .25531 m .76007 .24889 L .75779 .2476 L p F P
0 g
s
0 0 .324 r
.78631 .14419 m .78688 .14864 L .78571 .14462 L p F P
0 g
s
0 0 .324 r
.78571 .14462 m .78513 .14017 L .78631 .14419 L p F P
0 g
s
.602 .682 .898 r
.7384 .09692 m .74536 .09552 L .74649 .09987 L p F P
0 g
s
.58 .662 .894 r
.74954 .09482 m .74536 .09552 L .74649 .09987 L p F P
0 g
s
.58 .662 .894 r
.74649 .09987 m .75204 .09905 L .74954 .09482 L p F P
0 g
s
.842 .899 .879 r
.71963 .29333 m .71814 .29219 L .72017 .29042 L closepath p F P
0 g
s
.917 .878 .782 r
.62741 .18315 m .63158 .17717 L .63248 .18154 L p F P
0 g
s
.917 .878 .782 r
.62743 .18325 m .62741 .18315 L p .63248 .18154 L F P
0 g
s
.917 .878 .782 r
.63248 .18154 m .62996 .18508 L .62743 .18325 L p F P
0 g
s
.234 .268 .693 r
.5918 .32287 m .592 .32228 L .59234 .32344 L closepath p F P
0 g
s
.727 .69 .149 r
.59432 .28722 m .59374 .2905 L .59388 .28958 L closepath p F P
0 g
s
0 0 0 r
.59388 .28958 m .59477 .28561 L p .59464 .28564 L F P
0 g
s
0 0 0 r
.59464 .28564 m .59432 .28722 L .59388 .28958 L p F P
0 g
s
.666 .718 .888 r
.72493 .09696 m .7359 .09297 L .7384 .09692 L p F P
0 g
s
.671 .722 .887 r
.7359 .09297 m .72493 .09696 L .72242 .09318 L p F P
0 g
s
.714 .748 .879 r
.71158 .09865 m .72242 .09318 L .72493 .09696 L p F P
0 g
s
.944 .941 .754 r
.76964 .22735 m .76945 .23193 L .77322 .22604 L p F P
0 g
s
.944 .941 .754 r
.77322 .22604 m .77345 .22144 L .76964 .22735 L p F P
0 g
s
.8 .871 .9 r
.68948 .31497 m .68623 .31732 L .68373 .31517 L p F P
0 g
s
.493 .54 .834 r
.59517 .3316 m .60317 .33249 L .60102 .33767 L p F P
0 g
s
.573 .647 .885 r
.60605 .33239 m .60317 .33249 L .60102 .33767 L p F P
0 g
s
.573 .647 .885 r
.60102 .33767 m .60878 .33675 L .60605 .33239 L p F P
0 g
s
.905 .851 .401 r
.59742 .27104 m .59698 .27575 L .59852 .27067 L p F P
0 g
s
.905 .851 .401 r
.59852 .27067 m .59885 .266 L .59742 .27104 L p F P
0 g
s
.95 .888 .735 r
.62223 .20279 m .62185 .20344 L .62168 .20252 L closepath p F P
0 g
s
.509 .508 .791 r
.59444 .32981 m .59517 .3316 L .60317 .33249 L p F P
0 g
s
.896 .847 .788 r
.64555 .15217 m .64366 .15469 L .64492 .15895 L p F P
0 g
s
.896 .847 .788 r
.63902 .16083 m .64013 .16515 L .64492 .15895 L p F P
0 g
s
.896 .847 .788 r
.64492 .15895 m .64366 .15469 L .63902 .16083 L p F P
0 g
s
.969 .906 .697 r
.61453 .22157 m .61293 .22473 L .6125 .22122 L closepath p F P
0 g
s
.831 .822 .84 r
.66684 .12907 m .66649 .12865 L .66668 .12847 L closepath p F P
0 g
s
.882 .731 .219 r
.78769 .16639 m .78807 .16177 L .78849 .16624 L p F P
0 g
s
.882 .731 .219 r
.78805 .17012 m .78769 .16639 L p .78849 .16624 L F P
0 g
s
.882 .731 .219 r
.78849 .16624 m .78828 .16879 L .78805 .17012 L p F P
0 g
s
.911 .896 .483 r
.60045 .263 m .59931 .26463 L .60075 .2608 L closepath p F P
0 g
s
.955 .889 .726 r
.61796 .20466 m .61871 .20905 L .62185 .20344 L p F P
0 g
s
.955 .889 .726 r
.61964 .20159 m .61796 .20466 L p .62185 .20344 L F P
0 g
s
.955 .889 .726 r
.62185 .20344 m .62168 .20252 L .61964 .20159 L p F P
0 g
s
.958 .912 .55 r
.60109 .2561 m .60075 .2608 L .6029 .25552 L p F P
0 g
s
.958 .912 .55 r
.6029 .25552 m .60309 .25087 L .60109 .2561 L p F P
0 g
s
0 0 .509 r
.78448 .13573 m .78513 .14017 L .7833 .13641 L p F P
0 g
s
0 0 .509 r
.7833 .13641 m .78263 .13198 L .78448 .13573 L p F P
0 g
s
.731 .802 .908 r
.64283 .33628 m .6383 .33864 L .63567 .33578 L p F P
0 g
s
.703 .794 .921 r
.62492 .34054 m .63567 .33578 L .6383 .33864 L p F P
0 g
s
.344 .48 .853 r
.76998 .11403 m .76953 .11138 L .77105 .11442 L closepath p F P
0 g
s
.804 .877 .9 r
.68948 .31497 m .69689 .30947 L .69441 .30741 L p F P
0 g
s
.804 .877 .9 r
.69441 .30741 m .69074 .31012 L .68948 .31497 L p F P
0 g
s
.8 .871 .9 r
.68373 .31517 m .69074 .31012 L .68948 .31497 L p F P
0 g
s
0 0 .219 r
.59342 .29972 m .59238 .30459 L .59227 .30008 L p F P
0 g
s
0 0 .219 r
.59227 .30008 m .59331 .2952 L .59342 .29972 L p F P
0 g
s
.356 .372 .739 r
.59234 .32344 m .59625 .32589 L .59444 .32981 L closepath p F P
0 g
s
.509 .508 .791 r
.60331 .32755 m .59625 .32589 L .59444 .32981 L p F P
0 g
s
.509 .508 .791 r
.60407 .32897 m .60331 .32755 L p .59444 .32981 L F P
0 g
s
.509 .508 .791 r
.60317 .33249 m .60407 .32897 L p .59444 .32981 L F P
0 g
s
.608 .686 .897 r
.74536 .09552 m .7384 .09692 L .7359 .09297 L p F P
0 g
s
.907 .935 .818 r
.75779 .2476 m .75528 .25065 L .75476 .25531 L p F P
0 g
s
.9 .931 .827 r
.74961 .25723 m .75528 .25065 L .75476 .25531 L p F P
0 g
s
.9 .931 .827 r
.74925 .26094 m .74961 .25723 L p .75476 .25531 L F P
0 g
s
.9 .931 .827 r
.75476 .25531 m .74971 .26121 L .74925 .26094 L p F P
0 g
s
.387 .368 .716 r
.59787 .32086 m .59388 .31768 L .592 .32228 L p F P
0 g
s
.387 .368 .716 r
.59625 .32589 m .59787 .32086 L p .592 .32228 L F P
0 g
s
.387 .368 .716 r
.592 .32228 m .59234 .32344 L .59625 .32589 L p F P
0 g
s
.752 .769 .867 r
.71158 .09865 m .71109 .09896 L .71007 .09648 L closepath p F P
0 g
s
.752 .777 .874 r
.70906 .09501 m .71007 .09648 L .71109 .09896 L p F P
0 g
s
.752 .777 .874 r
.6983 .10183 m .70906 .09501 L p .71109 .09896 L F P
0 g
s
.807 .805 .849 r
.68322 .11347 m .67703 .11865 L .67447 .1154 L p F P
0 g
s
.834 .811 .828 r
.67441 .12118 m .67703 .11865 L .67447 .1154 L p F P
0 g
s
.717 .757 .884 r
.71991 .0894 m .72242 .09318 L .71158 .09865 L p F P
0 g
s
.717 .757 .884 r
.7097 .09468 m .71991 .0894 L p .71158 .09865 L F P
0 g
s
.717 .757 .884 r
.71158 .09865 m .71007 .09648 L .7097 .09468 L p F P
0 g
s
.834 .811 .828 r
.67447 .1154 m .67286 .11697 L .67441 .12118 L p F P
0 g
s
.832 .81 .83 r
.66539 .12418 m .66668 .12847 L .67441 .12118 L p F P
0 g
s
.832 .81 .83 r
.67441 .12118 m .67286 .11697 L .66539 .12418 L p F P
0 g
s
.931 .869 .755 r
.62996 .18508 m .62847 .18745 L .62743 .18325 L closepath p F P
0 g
s
.968 .935 .653 r
.60507 .24105 m .60763 .23562 L .6076 .24024 L p F P
0 g
s
.968 .935 .653 r
.60505 .24236 m .60507 .24105 L p .6076 .24024 L F P
0 g
s
.968 .935 .653 r
.6076 .24024 m .60688 .24172 L .60505 .24236 L p F P
0 g
s
0 .115 .657 r
.78189 .12755 m .78263 .13198 L .78003 .12852 L p F P
0 g
s
0 .115 .657 r
.78003 .12852 m .77925 .12411 L .78189 .12755 L p F P
0 g
s
.655 .749 .919 r
.61148 .34077 m .62226 .33727 L .62492 .34054 L p F P
0 g
s
.633 .729 .917 r
.62226 .33727 m .61148 .34077 L .60878 .33675 L p F P
0 g
s
.83 .818 .838 r
.66392 .12558 m .66539 .12418 L .66668 .12847 L p F P
0 g
s
.83 .818 .838 r
.66668 .12847 m .66649 .12865 L .66392 .12558 L p F P
0 g
s
.857 .826 .816 r
.66035 .13524 m .66649 .12865 L .66392 .12558 L p F P
0 g
s
.221 .39 .82 r
.77105 .11442 m .77482 .11663 L .77573 .12101 L p F P
0 g
s
.084 .277 .761 r
.77841 .1197 m .77925 .12411 L .77573 .12101 L p F P
0 g
s
.084 .277 .761 r
.77573 .12101 m .77482 .11663 L .77841 .1197 L p F P
0 g
s
.812 .802 .842 r
.68322 .11347 m .68763 .10971 L .68509 .10631 L p F P
0 g
s
.812 .802 .842 r
.68509 .10631 m .6817 .10925 L .68322 .11347 L p F P
0 g
s
.807 .805 .849 r
.67447 .1154 m .6817 .10925 L .68322 .11347 L p F P
0 g
s
.769 .847 .91 r
.6624 .32936 m .66233 .32929 L .66244 .32922 L closepath p F P
0 g
s
.957 .937 .722 r
.77683 .21758 m .77592 .21732 L .77687 .21568 L closepath p F P
0 g
s
.752 .837 .916 r
.64903 .333 m .65976 .32682 L .66233 .32929 L p F P
0 g
s
.768 .84 .907 r
.66244 .32922 m .66233 .32929 L .65976 .32682 L p F P
0 g
s
.966 .935 .691 r
.77688 .21113 m .77687 .21568 L .77977 .21011 L p F P
0 g
s
.966 .935 .691 r
.77977 .21011 m .77981 .20555 L .77688 .21113 L p F P
0 g
s
.768 .84 .907 r
.65976 .32682 m .66372 .32438 L .66244 .32922 L p F P
0 g
s
.769 .844 .908 r
.66244 .32922 m .67303 .32245 L .67049 .32012 L p F P
0 g
s
.769 .844 .908 r
.67049 .32012 m .66372 .32438 L .66244 .32922 L p F P
0 g
s
.782 .792 .86 r
.69406 .10499 m .68763 .10971 L .68509 .10631 L p F P
0 g
s
.692 .783 .921 r
.63567 .33578 m .62492 .34054 L .62226 .33727 L p F P
0 g
s
.962 .865 .461 r
.78586 .18066 m .78607 .18518 L .78737 .18021 L p F P
0 g
s
.962 .865 .461 r
.78737 .18021 m .78718 .17568 L .78586 .18066 L p F P
0 g
s
.944 .901 .752 r
.62168 .20252 m .61964 .20159 L .62125 .199 L closepath p F P
0 g
s
.814 .881 .894 r
.70088 .30638 m .69689 .30947 L .69441 .30741 L p F P
0 g
s
.98 .916 .63 r
.60688 .24172 m .60523 .24559 L .60505 .24236 L closepath p F P
0 g
s
.2 .389 .825 r
.76953 .11138 m .77105 .11442 L .77482 .11663 L p F P
0 g
s
.974 .905 .682 r
.60981 .22572 m .61025 .23018 L .61293 .22473 L p F P
0 g
s
.974 .905 .682 r
.61196 .22117 m .60981 .22572 L p .61293 .22473 L F P
0 g
s
.974 .905 .682 r
.61293 .22473 m .6125 .22122 L .61196 .22117 L p F P
0 g
s
.896 .858 .797 r
.63514 .1659 m .63902 .16083 L .64013 .16515 L p F P
0 g
s
.896 .858 .797 r
.64013 .16515 m .63773 .16822 L .63514 .1659 L p F P
0 g
s
.894 .932 .835 r
.74971 .26121 m .74912 .26187 L .74925 .26094 L closepath p F P
0 g
s
.936 .871 .748 r
.62395 .18887 m .62488 .19321 L .62847 .18745 L p F P
0 g
s
.936 .871 .748 r
.62737 .18321 m .62395 .18887 L p .62847 .18745 L F P
0 g
s
.936 .871 .748 r
.62847 .18745 m .62743 .18325 L .62737 .18321 L p F P
0 g
s
.88 .922 .849 r
.74335 .26403 m .74276 .2687 L .74912 .26187 L p F P
0 g
s
.88 .922 .849 r
.74739 .2597 m .74335 .26403 L p .74912 .26187 L F P
0 g
s
.88 .922 .849 r
.74912 .26187 m .74925 .26094 L .74739 .2597 L p F P
0 g
s
.857 .826 .816 r
.66392 .12558 m .65895 .13099 L .66035 .13524 L p F P
0 g
s
.852 .829 .824 r
.65342 .1369 m .65895 .13099 L .66035 .13524 L p F P
0 g
s
.852 .829 .824 r
.66035 .13524 m .656 .13981 L .65342 .1369 L p F P
0 g
s
.977 .914 .597 r
.78232 .19555 m .78438 .19029 L .78454 .19481 L p F P
0 g
s
.977 .914 .597 r
.7824 .19763 m .78232 .19555 L p .78454 .19481 L F P
0 g
s
.977 .914 .597 r
.78454 .19481 m .78352 .19738 L .7824 .19763 L p F P
0 g
s
.727 .81 .916 r
.64283 .33628 m .64903 .333 L .64643 .33037 L p F P
0 g
s
.727 .81 .916 r
.64643 .33037 m .64484 .33118 L .64283 .33628 L p F P
0 g
s
.731 .802 .908 r
.63567 .33578 m .64484 .33118 L .64283 .33628 L p F P
0 g
s
.091 .115 .592 r
.59525 .31272 m .59388 .31768 L .59167 .31389 L p F P
0 g
s
.091 .115 .592 r
.59167 .31389 m .59328 .30884 L .59525 .31272 L p F P
0 g
s
.935 .937 .774 r
.76581 .23294 m .76964 .22735 L .76945 .23193 L p F P
0 g
s
.935 .937 .774 r
.76945 .23193 m .76806 .23395 L .76581 .23294 L p F P
0 g
s
.819 .887 .893 r
.70088 .30638 m .70753 .3011 L .70508 .29914 L p F P
0 g
s
.819 .887 .893 r
.70508 .29914 m .702 .30157 L .70088 .30638 L p F P
0 g
s
.814 .881 .894 r
.69441 .30741 m .702 .30157 L .70088 .30638 L p F P
0 g
s
.809 .629 .073 r
.78757 .15731 m .78807 .16177 L .78798 .15734 L p F P
0 g
s
.809 .629 .073 r
.78798 .15734 m .78748 .15288 L .78757 .15731 L p F P
0 g
s
.867 .729 .21 r
.78828 .16879 m .78809 .17086 L .78805 .17012 L closepath p F P
0 g
s
.875 .83 .799 r
.65422 .14193 m .656 .13981 L .65342 .1369 L p F P
0 g
s
.786 .788 .854 r
.69406 .10499 m .6983 .10183 L .69577 .09829 L p F P
0 g
s
.786 .788 .854 r
.69577 .09829 m .69249 .10078 L .69406 .10499 L p F P
0 g
s
.782 .792 .86 r
.68509 .10631 m .69249 .10078 L .69406 .10499 L p F P
0 g
s
.915 .855 .768 r
.63567 .17123 m .63773 .16822 L .63514 .1659 L p F P
0 g
s
.931 .941 .78 r
.76516 .23801 m .76806 .23395 L .76581 .23294 L p F P
0 g
s
.876 .918 .851 r
.73689 .27075 m .74335 .26403 L .74276 .2687 L p F P
0 g
s
.876 .918 .851 r
.74276 .2687 m .73925 .27234 L .73689 .27075 L p F P
0 g
s
.96 .894 .718 r
.61496 .21023 m .61557 .21466 L .61871 .20905 L p F P
0 g
s
.96 .894 .718 r
.61871 .20905 m .61796 .20466 L .61496 .21023 L p F P
0 g
s
.828 .889 .886 r
.71102 .29822 m .70753 .3011 L .70508 .29914 L p F P
0 g
s
.875 .83 .799 r
.65342 .1369 m .65273 .13772 L .65422 .14193 L p F P
0 g
s
.875 .83 .799 r
.64748 .1441 m .64881 .14836 L .65422 .14193 L p F P
0 g
s
.875 .83 .799 r
.65422 .14193 m .65273 .13772 L .64748 .1441 L p F P
0 g
s
.87 .919 .858 r
.7359 .2757 m .73925 .27234 L .73689 .27075 L p F P
0 g
s
.833 .895 .884 r
.71102 .29822 m .71814 .29219 L .71572 .2903 L p F P
0 g
s
.833 .895 .884 r
.71572 .2903 m .71197 .29346 L .71102 .29822 L p F P
0 g
s
.828 .889 .886 r
.70508 .29914 m .71197 .29346 L .71102 .29822 L p F P
0 g
s
.889 .92 .837 r
.74925 .26094 m .74739 .2597 L .74961 .25723 L closepath p F P
0 g
s
.755 .77 .865 r
.70906 .09501 m .6983 .10183 L .69577 .09829 L p F P
0 g
s
.851 .799 .306 r
.59625 .27599 m .5957 .28073 L .59698 .27575 L p F P
0 g
s
.851 .799 .306 r
.59698 .27575 m .59742 .27104 L .59625 .27599 L p F P
0 g
s
.87 .919 .858 r
.73689 .27075 m .73667 .27097 L .7359 .2757 L p F P
0 g
s
.863 .912 .863 r
.72915 .27822 m .73667 .27097 L .7359 .2757 L p F P
0 g
s
.863 .912 .863 r
.72855 .28256 m .72915 .27822 L p .7359 .2757 L F P
0 g
s
.863 .912 .863 r
.7359 .2757 m .72872 .28268 L .72855 .28256 L p F P
0 g
s
.925 .902 .5 r
.59925 .26128 m .60109 .2561 L .60075 .2608 L p F P
0 g
s
.925 .902 .5 r
.59887 .2652 m .59925 .26128 L p .60075 .2608 L F P
0 g
s
.925 .902 .5 r
.60075 .2608 m .59931 .26463 L .59887 .2652 L p F P
0 g
s
.974 .92 .605 r
.78352 .19738 m .7824 .20009 L .7824 .19763 L closepath p F P
0 g
s
.494 .606 .893 r
.75204 .09905 m .7595 .09933 L .76057 .10369 L p F P
0 g
s
.503 .614 .895 r
.7595 .09933 m .75204 .09905 L .74954 .09482 L p F P
0 g
s
0 0 0 r
.59357 .29351 m .59331 .2952 L .59374 .2905 L p F P
0 g
s
0 0 0 r
.59374 .2905 m .59388 .28958 L .59357 .29351 L p F P
0 g
s
.841 .896 .878 r
.72017 .29042 m .71814 .29219 L .71572 .2903 L p F P
0 g
s
.915 .855 .768 r
.63514 .1659 m .63442 .16697 L .63567 .17123 L p F P
0 g
s
.917 .855 .767 r
.63047 .17286 m .63158 .17717 L .63567 .17123 L p F P
0 g
s
.917 .855 .767 r
.63567 .17123 m .63442 .16697 L .63047 .17286 L p F P
0 g
s
.844 .902 .878 r
.72096 .2857 m .72017 .29042 L .72849 .2829 L p F P
0 g
s
.841 .896 .878 r
.71572 .2903 m .72096 .2857 L .72017 .29042 L p F P
0 g
s
.856 .913 .87 r
.72872 .28268 m .72849 .2829 L .72855 .28256 L closepath p F P
0 g
s
.844 .902 .878 r
.72633 .28086 m .72096 .2857 L p .72849 .2829 L F P
0 g
s
.844 .902 .878 r
.72849 .2829 m .72855 .28256 L .72633 .28086 L p F P
0 g
s
.981 .911 .604 r
.60293 .24633 m .60309 .25087 L .60523 .24559 L p F P
0 g
s
.981 .911 .604 r
.60433 .24272 m .60293 .24633 L p .60523 .24559 L F P
0 g
s
.981 .911 .604 r
.60523 .24559 m .60505 .24236 L .60433 .24272 L p F P
0 g
s
0 0 .114 r
.78692 .14842 m .78748 .15288 L .78688 .14864 L p F P
0 g
s
0 0 .114 r
.78688 .14864 m .78631 .14419 L .78692 .14842 L p F P
0 g
s
.718 .758 .884 r
.71007 .09648 m .70906 .09501 L .7097 .09468 L closepath p F P
0 g
s
.31 .468 .856 r
.76851 .10939 m .7691 .10963 L .76953 .11138 L closepath p F P
0 g
s
.2 .389 .825 r
.77385 .11226 m .7691 .10963 L .76953 .11138 L p F P
0 g
s
.2 .389 .825 r
.77482 .11663 m .77385 .11226 L p .76953 .11138 L F P
0 g
s
.957 .936 .723 r
.77373 .21666 m .77688 .21113 L .77687 .21568 L p F P
0 g
s
.957 .936 .723 r
.77687 .21568 m .77592 .21732 L .77373 .21666 L p F P
0 g
s
.92 .935 .799 r
.76073 .23964 m .76046 .24424 L .76516 .23801 L p F P
0 g
s
.92 .935 .799 r
.76516 .23801 m .7655 .23338 L .76073 .23964 L p F P
0 g
s
.931 .941 .78 r
.76581 .23294 m .7655 .23338 L .76516 .23801 L p F P
0 g
s
.783 .855 .904 r
.67776 .31927 m .67303 .32245 L .67049 .32012 L p F P
0 g
s
.748 .832 .916 r
.65976 .32682 m .64903 .333 L .64643 .33037 L p F P
0 g
s
.936 .818 .363 r
.78699 .17226 m .78718 .17568 L .78809 .17086 L p F P
0 g
s
.936 .818 .363 r
.78809 .17086 m .78805 .17012 L .78699 .17226 L p F P
0 g
s
.94 .879 .748 r
.62047 .1946 m .62125 .199 L .62488 .19321 L p F P
0 g
s
.94 .879 .748 r
.62488 .19321 m .62395 .18887 L .62047 .1946 L p F P
0 g
s
.854 .901 .868 r
.72855 .28256 m .72633 .28086 L .72915 .27822 L closepath p F P
0 g
s
.437 .558 .879 r
.76345 .09987 m .7595 .09933 L .76057 .10369 L p F P
0 g
s
.437 .558 .879 r
.76057 .10369 m .76598 .10458 L .76345 .09987 L p F P
0 g
s
.874 .84 .809 r
.64296 .14947 m .64748 .1441 L .64881 .14836 L p F P
0 g
s
.874 .84 .809 r
.64881 .14836 m .64555 .15217 L .64296 .14947 L p F P
0 g
s
.978 .911 .665 r
.60732 .23111 m .60763 .23562 L .61025 .23018 L p F P
0 g
s
.978 .911 .665 r
.61025 .23018 m .60981 .22572 L .60732 .23111 L p F P
0 g
s
.954 .94 .728 r
.77345 .22144 m .77592 .21732 L .77373 .21666 L p F P
0 g
s
0 0 .393 r
.59423 .30401 m .59328 .30884 L .59238 .30459 L p F P
0 g
s
0 0 .393 r
.59238 .30459 m .59342 .29972 L .59423 .30401 L p F P
0 g
s
0 0 .05 r
.59429 .29033 m .59357 .29351 L .59388 .28958 L p F P
0 g
s
0 0 .05 r
.59388 .28958 m .59477 .28561 L .59429 .29033 L p F P
0 g
s
.97 .931 .668 r
.77978 .201 m .77981 .20555 L .7824 .20009 L p F P
0 g
s
.97 .931 .668 r
.78142 .19754 m .77978 .201 L p .7824 .20009 L F P
0 g
s
.97 .931 .668 r
.7824 .20009 m .7824 .19763 L .78142 .19754 L p F P
0 g
s
.978 .895 .544 r
.78415 .18579 m .78438 .19029 L .78607 .18518 L p F P
0 g
s
.978 .895 .544 r
.78607 .18518 m .78586 .18066 L .78415 .18579 L p F P
0 g
s
.671 .722 .887 r
.72242 .09318 m .73339 .08902 L .7359 .09297 L p F P
0 g
s
.676 .725 .887 r
.73339 .08902 m .72242 .09318 L .71991 .0894 L p F P
0 g
s
.786 .862 .906 r
.67776 .31927 m .68373 .31517 L .68121 .31296 L p F P
0 g
s
.786 .862 .906 r
.68121 .31296 m .67913 .31438 L .67776 .31927 L p F P
0 g
s
.783 .855 .904 r
.67049 .32012 m .67913 .31438 L .67776 .31927 L p F P
0 g
s
.895 .839 .783 r
.64366 .15469 m .64555 .15217 L .64296 .14947 L p F P
0 g
s
.947 .811 .363 r
.78689 .17117 m .78699 .17226 L .78805 .17012 L p F P
0 g
s
.947 .811 .363 r
.78805 .17012 m .78769 .16639 L .78689 .17117 L p F P
0 g
s
.608 .686 .897 r
.7359 .09297 m .74423 .09116 L .74536 .09552 L p F P
0 g
s
.588 .669 .895 r
.74703 .09063 m .74423 .09116 L .74536 .09552 L p F P
0 g
s
.588 .669 .895 r
.74536 .09552 m .74954 .09482 L .74703 .09063 L p F P
0 g
s
0 0 .318 r
.78568 .13974 m .78631 .14419 L .78513 .14017 L p F P
0 g
s
0 0 .318 r
.78513 .14017 m .78448 .13573 L .78568 .13974 L p F P
0 g
s
.963 .902 .714 r
.61199 .21579 m .61244 .22028 L .61557 .21466 L p F P
0 g
s
.963 .902 .714 r
.61557 .21466 m .61496 .21023 L .61199 .21579 L p F P
0 g
s
.614 .69 .897 r
.74423 .09116 m .7359 .09297 L .73339 .08902 L p F P
0 g
s
.633 .729 .917 r
.60878 .33675 m .61958 .33382 L .62226 .33727 L p F P
0 g
s
.605 .704 .914 r
.61958 .33382 m .60878 .33675 L .60605 .33239 L p F P
0 g
s
.322 .481 .862 r
.7691 .10963 m .76851 .10939 L .76598 .10458 L p F P
0 g
s
.918 .863 .77 r
.62645 .17879 m .62741 .18315 L .63158 .17717 L p F P
0 g
s
.918 .863 .77 r
.63158 .17717 m .63047 .17286 L .62645 .17879 L p F P
0 g
s
.952 .891 .498 r
.59931 .26463 m .59885 .266 L .59887 .2652 L closepath p F P
0 g
s
.912 .929 .81 r
.7557 .246 m .76073 .23964 L .76046 .24424 L p F P
0 g
s
.912 .929 .81 r
.75568 .24638 m .7557 .246 L p .76046 .24424 L F P
0 g
s
.912 .929 .81 r
.76046 .24424 m .75779 .2476 L .75568 .24638 L p F P
0 g
s
.895 .839 .783 r
.64296 .14947 m .64221 .15048 L .64366 .15469 L p F P
0 g
s
.896 .84 .782 r
.63772 .15657 m .63902 .16083 L .64366 .15469 L p F P
0 g
s
.896 .84 .782 r
.64366 .15469 m .64221 .15048 L .63772 .15657 L p F P
0 g
s
.723 .792 .907 r
.64484 .33118 m .63567 .33578 L .63304 .33279 L p F P
0 g
s
.692 .783 .921 r
.62226 .33727 m .63304 .33279 L .63567 .33578 L p F P
0 g
s
.718 .758 .884 r
.7097 .09468 m .70906 .09501 L .70653 .09135 L p F P
0 g
s
.755 .77 .865 r
.69577 .09829 m .70653 .09135 L .70906 .09501 L p F P
0 g
s
.434 .511 .839 r
.60053 .3219 m .59787 .32086 L .59625 .32589 L p F P
0 g
s
.434 .511 .839 r
.59625 .32589 m .60331 .32755 L .60053 .3219 L p F P
0 g
s
.798 .867 .899 r
.69074 .31012 m .68373 .31517 L .68121 .31296 L p F P
0 g
s
.322 .481 .862 r
.76598 .10458 m .76796 .10531 L .7691 .10963 L p F P
0 g
s
.23 .41 .834 r
.7728 .10789 m .77385 .11226 L .7691 .10963 L p F P
0 g
s
.23 .41 .834 r
.7691 .10963 m .76796 .10531 L .7728 .10789 L p F P
0 g
s
0 0 .508 r
.78377 .1313 m .78448 .13573 L .78263 .13198 L p F P
0 g
s
0 0 .508 r
.78263 .13198 m .78189 .12755 L .78377 .1313 L p F P
0 g
s
.723 .76 .881 r
.7097 .09468 m .71991 .0894 L .71738 .08561 L p F P
0 g
s
.723 .76 .881 r
.71738 .08561 m .70854 .0903 L .7097 .09468 L p F P
0 g
s
.718 .758 .884 r
.70653 .09135 m .70854 .0903 L .7097 .09468 L p F P
0 g
s
.954 .94 .728 r
.77373 .21666 m .77362 .21685 L .77345 .22144 L p F P
0 g
s
.943 .937 .758 r
.76975 .22278 m .76964 .22735 L .77345 .22144 L p F P
0 g
s
.943 .937 .758 r
.77345 .22144 m .77362 .21685 L .76975 .22278 L p F P
0 g
s
.809 .802 .845 r
.6817 .10925 m .67447 .1154 L .6719 .11208 L p F P
0 g
s
.835 .807 .824 r
.67286 .11697 m .67447 .1154 L .6719 .11208 L p F P
0 g
s
.904 .742 .243 r
.78719 .16193 m .78769 .16639 L .78807 .16177 L p F P
0 g
s
.904 .742 .243 r
.78807 .16177 m .78757 .15731 L .78719 .16193 L p F P
0 g
s
.835 .807 .824 r
.6719 .11208 m .67117 .11281 L .67286 .11697 L p F P
0 g
s
.833 .807 .825 r
.66391 .11994 m .66539 .12418 L .67286 .11697 L p F P
0 g
s
.833 .807 .825 r
.67286 .11697 m .67117 .11281 L .66391 .11994 L p F P
0 g
s
.941 .892 .753 r
.61704 .20022 m .62047 .1946 L .62125 .199 L p F P
0 g
s
.941 .892 .753 r
.62125 .199 m .61964 .20159 L .61704 .20022 L p F P
0 g
s
.907 .931 .818 r
.75779 .2476 m .75528 .25065 L .75568 .24638 L closepath p F P
0 g
s
.935 .865 .438 r
.59749 .26768 m .59742 .27104 L .59885 .266 L p F P
0 g
s
.935 .865 .438 r
.59885 .266 m .59887 .2652 L .59749 .26768 L p F P
0 g
s
.965 .922 .707 r
.6125 .22122 m .61196 .22117 L .61244 .22028 L closepath p F P
0 g
s
.679 .77 .92 r
.63304 .33279 m .62226 .33727 L .61958 .33382 L p F P
0 g
s
.831 .814 .834 r
.66134 .12242 m .66391 .11994 L .66539 .12418 L p F P
0 g
s
.831 .814 .834 r
.66539 .12418 m .66392 .12558 L .66134 .12242 L p F P
0 g
s
.813 .798 .838 r
.6817 .10925 m .68509 .10631 L .68253 .10287 L p F P
0 g
s
.813 .798 .838 r
.68253 .10287 m .68003 .10507 L .6817 .10925 L p F P
0 g
s
.809 .802 .845 r
.6719 .11208 m .68003 .10507 L .6817 .10925 L p F P
0 g
s
.857 .82 .812 r
.65895 .13099 m .66392 .12558 L .66134 .12242 L p F P
0 g
s
.769 .715 .18 r
.59541 .28084 m .59477 .28561 L .5957 .28073 L p F P
0 g
s
.769 .715 .18 r
.5957 .28073 m .59625 .27599 L .59541 .28084 L p F P
0 g
s
0 .119 .661 r
.78109 .12313 m .78189 .12755 L .77925 .12411 L p F P
0 g
s
0 .119 .661 r
.77925 .12411 m .77841 .1197 L .78109 .12313 L p F P
0 g
s
.087 .283 .767 r
.7775 .11531 m .77841 .1197 L .77482 .11663 L p F P
0 g
s
.087 .283 .767 r
.77482 .11663 m .77385 .11226 L .7775 .11531 L p F P
0 g
s
.976 .904 .563 r
.60105 .25152 m .60109 .2561 L .60309 .25087 L p F P
0 g
s
.976 .904 .563 r
.60309 .25087 m .60293 .24633 L .60105 .25152 L p F P
0 g
s
.784 .79 .857 r
.69249 .10078 m .68509 .10631 L .68253 .10287 L p F P
0 g
s
.892 .922 .834 r
.74997 .25262 m .74961 .25723 L .75528 .25065 L p F P
0 g
s
.892 .922 .834 r
.75549 .24626 m .74997 .25262 L p .75528 .25065 L F P
0 g
s
.892 .922 .834 r
.75528 .25065 m .75568 .24638 L .75549 .24626 L p F P
0 g
s
.225 .274 .704 r
.59858 .31748 m .59787 .32086 L .59388 .31768 L p F P
0 g
s
.225 .274 .704 r
.59772 .3152 m .59858 .31748 L p .59388 .31768 L F P
0 g
s
.225 .274 .704 r
.59388 .31768 m .59525 .31272 L .59772 .3152 L p F P
0 g
s
.979 .916 .649 r
.60492 .23648 m .60507 .24105 L .60763 .23562 L p F P
0 g
s
.979 .916 .649 r
.60763 .23562 m .60732 .23111 L .60492 .23648 L p F P
0 g
s
.765 .835 .906 r
.66372 .32438 m .65976 .32682 L .65718 .32428 L p F P
0 g
s
.748 .832 .916 r
.64643 .33037 m .65718 .32428 L .65976 .32682 L p F P
0 g
s
.955 .88 .72 r
.61796 .20466 m .61964 .20159 L .61704 .20022 L p F P
0 g
s
0 0 .169 r
.59367 .298 m .59342 .29972 L .59331 .2952 L p F P
0 g
s
0 0 .169 r
.59331 .2952 m .59357 .29351 L .59367 .298 L p F P
0 g
s
.804 .877 .9 r
.69441 .30741 m .69074 .31012 L .69198 .30536 L closepath p F P
0 g
s
.798 .867 .899 r
.69192 .30531 m .69198 .30536 L .69074 .31012 L p F P
0 g
s
.798 .867 .899 r
.68121 .31296 m .69192 .30531 L p .69074 .31012 L F P
0 g
s
.541 .611 .872 r
.60317 .33249 m .60407 .32897 L .60605 .33239 L closepath p F P
0 g
s
.923 .88 .775 r
.62743 .18325 m .62737 .18321 L .62741 .18315 L closepath p F P
0 g
s
.895 .851 .792 r
.6331 .16272 m .63772 .15657 L .63902 .16083 L p F P
0 g
s
.895 .851 .792 r
.63356 .16441 m .6331 .16272 L p .63902 .16083 L F P
0 g
s
.895 .851 .792 r
.63902 .16083 m .63514 .1659 L .63356 .16441 L p F P
0 g
s
.857 .82 .812 r
.66134 .12242 m .65739 .12679 L .65895 .13099 L p F P
0 g
s
.853 .824 .819 r
.65116 .13353 m .65739 .12679 L .65895 .13099 L p F P
0 g
s
.853 .824 .819 r
.65157 .13476 m .65116 .13353 L p .65895 .13099 L F P
0 g
s
.853 .824 .819 r
.65895 .13099 m .65342 .1369 L .65157 .13476 L p F P
0 g
s
.966 .932 .698 r
.7768 .2066 m .77688 .21113 L .77981 .20555 L p F P
0 g
s
.966 .932 .698 r
.77981 .20555 m .77978 .201 L .7768 .2066 L p F P
0 g
s
.92 .873 .774 r
.62477 .18128 m .62645 .17879 L .62741 .18315 L p F P
0 g
s
.92 .873 .774 r
.62741 .18315 m .62737 .18321 L .62477 .18128 L p F P
0 g
s
.907 .869 .432 r
.59762 .2664 m .59749 .26768 L .59887 .2652 L p F P
0 g
s
.907 .869 .432 r
.59887 .2652 m .59925 .26128 L .59762 .2664 L p F P
0 g
s
.97 .872 .483 r
.78558 .17615 m .78586 .18066 L .78718 .17568 L p F P
0 g
s
.97 .872 .483 r
.78651 .17267 m .78558 .17615 L p .78718 .17568 L F P
0 g
s
.97 .872 .483 r
.78718 .17568 m .78699 .17226 L .78651 .17267 L p F P
0 g
s
.938 .868 .743 r
.62395 .18887 m .62737 .18321 L .62477 .18128 L p F P
0 g
s
.964 .914 .711 r
.60937 .22074 m .61199 .21579 L .61244 .22028 L p F P
0 g
s
.964 .914 .711 r
.61244 .22028 m .61196 .22117 L .60937 .22074 L p F P
0 g
s
.813 .878 .893 r
.702 .30157 m .69441 .30741 L .69198 .30536 L p F P
0 g
s
.784 .79 .857 r
.68253 .10287 m .69078 .0966 L .69249 .10078 L p F P
0 g
s
.788 .786 .851 r
.69249 .10078 m .69577 .09829 L .69322 .09472 L p F P
0 g
s
.788 .786 .851 r
.69322 .09472 m .69078 .0966 L .69249 .10078 L p F P
0 g
s
.503 .614 .895 r
.74954 .09482 m .75837 .09497 L .7595 .09933 L p F P
0 g
s
.511 .621 .896 r
.75837 .09497 m .74954 .09482 L .74703 .09063 L p F P
0 g
s
.981 .91 .606 r
.78207 .19106 m .78232 .19555 L .78438 .19029 L p F P
0 g
s
.981 .91 .606 r
.78438 .19029 m .78415 .18579 L .78207 .19106 L p F P
0 g
s
.825 .638 .088 r
.78701 .15286 m .78757 .15731 L .78748 .15288 L p F P
0 g
s
.825 .638 .088 r
.78748 .15288 m .78692 .14842 L .78701 .15286 L p F P
0 g
s
.976 .921 .652 r
.7824 .19763 m .78142 .19754 L .78232 .19555 L closepath p F P
0 g
s
.97 .928 .622 r
.60505 .24236 m .60433 .24272 L .60507 .24105 L closepath p F P
0 g
s
.976 .897 .677 r
.60981 .22572 m .61196 .22117 L .60937 .22074 L p F P
0 g
s
.872 .824 .797 r
.65342 .1369 m .65273 .13772 L .65157 .13476 L closepath p F P
0 g
s
.889 .917 .837 r
.74504 .25811 m .74997 .25262 L .74961 .25723 L p F P
0 g
s
.889 .917 .837 r
.74961 .25723 m .74739 .2597 L .74504 .25811 L p F P
0 g
s
.765 .835 .906 r
.65718 .32428 m .6651 .31948 L .66372 .32438 L p F P
0 g
s
.765 .842 .91 r
.66372 .32438 m .67049 .32012 L .66794 .31773 L p F P
0 g
s
.765 .842 .91 r
.66794 .31773 m .6651 .31948 L .66372 .32438 L p F P
0 g
s
.936 .933 .772 r
.76559 .22883 m .76975 .22278 L .76964 .22735 L p F P
0 g
s
.936 .933 .772 r
.76554 .23281 m .76559 .22883 L p .76964 .22735 L F P
0 g
s
.936 .933 .772 r
.76964 .22735 m .76581 .23294 L .76554 .23281 L p F P
0 g
s
.877 .825 .793 r
.64598 .13988 m .64748 .1441 L .65273 .13772 L p F P
0 g
s
.877 .825 .793 r
.65082 .1339 m .64598 .13988 L p .65273 .13772 L F P
0 g
s
.877 .825 .793 r
.65273 .13772 m .65157 .13476 L .65082 .1339 L p F P
0 g
s
.758 .77 .863 r
.70653 .09135 m .69577 .09829 L .69322 .09472 L p F P
0 g
s
.883 .919 .844 r
.74335 .26403 m .74739 .2597 L .74504 .25811 L p F P
0 g
s
.955 .88 .72 r
.61704 .20022 m .61698 .20035 L .61796 .20466 L p F P
0 g
s
.959 .881 .712 r
.6141 .20587 m .61496 .21023 L .61796 .20466 L p F P
0 g
s
.959 .881 .712 r
.61796 .20466 m .61698 .20035 L .6141 .20587 L p F P
0 g
s
.911 .846 .767 r
.63514 .1659 m .63442 .16697 L .63356 .16441 L closepath p F P
0 g
s
.819 .886 .892 r
.70508 .29914 m .702 .30157 L .70294 .29739 L closepath p F P
0 g
s
.813 .878 .893 r
.70262 .29711 m .70294 .29739 L .702 .30157 L p F P
0 g
s
.813 .878 .893 r
.692 .30526 m .70262 .29711 L p .702 .30157 L F P
0 g
s
.813 .878 .893 r
.69198 .30536 m .692 .30526 L p .702 .30157 L F P
0 g
s
0 .018 .542 r
.59582 .30953 m .59525 .31272 L .59328 .30884 L p F P
0 g
s
0 .018 .542 r
.59483 .30545 m .59582 .30953 L p .59328 .30884 L F P
0 g
s
0 .018 .542 r
.59328 .30884 m .59423 .30401 L .59483 .30545 L p F P
0 g
s
.883 .919 .844 r
.74504 .25811 m .74388 .25936 L .74335 .26403 L p F P
0 g
s
.876 .913 .85 r
.73711 .26635 m .74388 .25936 L .74335 .26403 L p F P
0 g
s
.876 .913 .85 r
.73672 .27063 m .73711 .26635 L p .74335 .26403 L F P
0 g
s
.876 .913 .85 r
.74335 .26403 m .73689 .27075 L .73672 .27063 L p F P
0 g
s
.827 .886 .886 r
.71197 .29346 m .70508 .29914 L .70294 .29739 L p F P
0 g
s
.727 .812 .917 r
.64643 .33037 m .64484 .33118 L .64557 .32947 L closepath p F P
0 g
s
.723 .792 .907 r
.64382 .32759 m .64557 .32947 L .64484 .33118 L p F P
0 g
s
.723 .792 .907 r
.63304 .33279 m .64382 .32759 L p .64484 .33118 L F P
0 g
s
.916 .848 .761 r
.62916 .16861 m .63047 .17286 L .63442 .16697 L p F P
0 g
s
.916 .848 .761 r
.63253 .16347 m .62916 .16861 L p .63442 .16697 L F P
0 g
s
.916 .848 .761 r
.63442 .16697 m .63356 .16441 L .63253 .16347 L p F P
0 g
s
.333 .493 .868 r
.76796 .10531 m .76598 .10458 L .76345 .09987 L p F P
0 g
s
.605 .704 .914 r
.60605 .33239 m .61689 .33016 L .61958 .33382 L p F P
0 g
s
.609 .645 .861 r
.60407 .32897 m .60605 .33239 L .61689 .33016 L p F P
0 g
s
0 0 .231 r
.59441 .29485 m .59367 .298 L .59357 .29351 L p F P
0 g
s
0 0 .231 r
.59357 .29351 m .59429 .29033 L .59441 .29485 L p F P
0 g
s
0 0 .101 r
.78629 .14398 m .78692 .14842 L .78631 .14419 L p F P
0 g
s
0 0 .101 r
.78631 .14419 m .78568 .13974 L .78629 .14398 L p F P
0 g
s
.832 .893 .884 r
.71197 .29346 m .71572 .2903 L .71329 .28836 L p F P
0 g
s
.832 .893 .884 r
.71329 .28836 m .71289 .2887 L .71197 .29346 L p F P
0 g
s
.827 .886 .886 r
.70304 .29677 m .71289 .2887 L .71197 .29346 L p F P
0 g
s
.827 .886 .886 r
.70294 .29739 m .70304 .29677 L p .71197 .29346 L F P
0 g
s
.745 .816 .908 r
.6546 .32166 m .65718 .32428 L .64643 .33037 L p F P
0 g
s
.745 .816 .908 r
.64623 .32628 m .6546 .32166 L p .64643 .33037 L F P
0 g
s
.745 .816 .908 r
.64643 .33037 m .64557 .32947 L .64623 .32628 L p F P
0 g
s
.909 .828 .365 r
.59638 .27138 m .59625 .27599 L .59742 .27104 L p F P
0 g
s
.909 .828 .365 r
.59683 .26937 m .59638 .27138 L p .59742 .27104 L F P
0 g
s
.909 .828 .365 r
.59742 .27104 m .59749 .26768 L .59683 .26937 L p F P
0 g
s
.448 .57 .885 r
.76093 .09525 m .75837 .09497 L .7595 .09933 L p F P
0 g
s
.448 .57 .885 r
.7595 .09933 m .76345 .09987 L .76093 .09525 L p F P
0 g
s
.965 .894 .518 r
.59933 .25666 m .59925 .26128 L .60109 .2561 L p F P
0 g
s
.965 .894 .518 r
.60109 .2561 m .60105 .25152 L .59933 .25666 L p F P
0 g
s
.874 .834 .804 r
.64067 .14628 m .64598 .13988 L .64748 .1441 L p F P
0 g
s
.874 .834 .804 r
.64104 .14741 m .64067 .14628 L p .64748 .1441 L F P
0 g
s
.874 .834 .804 r
.64748 .1441 m .64296 .14947 L .64104 .14741 L p F P
0 g
s
.87 .915 .857 r
.73689 .27075 m .73667 .27097 L .73672 .27063 L closepath p F P
0 g
s
.939 .868 .741 r
.61945 .19027 m .62047 .1946 L .62395 .18887 L p F P
0 g
s
.939 .868 .741 r
.62395 .18887 m .62281 .18458 L .61945 .19027 L p F P
0 g
s
.938 .868 .743 r
.62477 .18128 m .62281 .18458 L .62395 .18887 L p F P
0 g
s
.856 .904 .867 r
.72971 .27356 m .72915 .27822 L .73667 .27097 L p F P
0 g
s
.856 .904 .867 r
.73451 .26894 m .72971 .27356 L p .73667 .27097 L F P
0 g
s
.856 .904 .867 r
.73667 .27097 m .73672 .27063 L .73451 .26894 L p F P
0 g
s
.676 .725 .887 r
.71991 .0894 m .73088 .08509 L .73339 .08902 L p F P
0 g
s
.68 .728 .886 r
.73088 .08509 m .71991 .0894 L .71738 .08561 L p F P
0 g
s
.78 .85 .904 r
.67913 .31438 m .67049 .32012 L .66794 .31773 L p F P
0 g
s
.975 .924 .632 r
.6026 .24183 m .60492 .23648 L .60507 .24105 L p F P
0 g
s
.975 .924 .632 r
.60264 .24339 m .6026 .24183 L p .60507 .24105 L F P
0 g
s
.975 .924 .632 r
.60507 .24105 m .60433 .24272 L .60264 .24339 L p F P
0 g
s
.956 .815 .377 r
.78638 .16672 m .78689 .17117 L .78769 .16639 L p F P
0 g
s
.956 .815 .377 r
.78769 .16639 m .78719 .16193 L .78638 .16672 L p F P
0 g
s
.841 .894 .877 r
.72096 .2857 m .71572 .2903 L .71329 .28836 L p F P
0 g
s
.959 .931 .722 r
.77352 .21233 m .7768 .2066 L .77688 .21113 L p F P
0 g
s
.959 .931 .722 r
.77362 .21662 m .77352 .21233 L p .77688 .21113 L F P
0 g
s
.959 .931 .722 r
.77688 .21113 m .77373 .21666 L .77362 .21662 L p F P
0 g
s
.931 .936 .781 r
.76581 .23294 m .7655 .23338 L .76554 .23281 L closepath p F P
0 g
s
.847 .899 .874 r
.72096 .2857 m .72633 .28086 L .72392 .27898 L p F P
0 g
s
.847 .899 .874 r
.72392 .27898 m .72169 .28099 L .72096 .2857 L p F P
0 g
s
.841 .894 .877 r
.71329 .28836 m .72169 .28099 L .72096 .2857 L p F P
0 g
s
.854 .899 .867 r
.72392 .27898 m .72971 .27356 L .72915 .27822 L p F P
0 g
s
.854 .899 .867 r
.72915 .27822 m .72633 .28086 L .72392 .27898 L p F P
0 g
s
.916 .928 .804 r
.76094 .23505 m .76073 .23964 L .7655 .23338 L p F P
0 g
s
.916 .928 .804 r
.76354 .23163 m .76094 .23505 L p .7655 .23338 L F P
0 g
s
.916 .928 .804 r
.7655 .23338 m .76554 .23281 L .76354 .23163 L p F P
0 g
s
.614 .69 .897 r
.73339 .08902 m .74311 .08677 L .74423 .09116 L p F P
0 g
s
.619 .691 .895 r
.74311 .08677 m .73339 .08902 L .73088 .08509 L p F P
0 g
s
0 0 0 r
.59499 .28554 m .59429 .29033 L .59477 .28561 L p F P
0 g
s
0 0 0 r
.59477 .28561 m .59541 .28084 L .59499 .28554 L p F P
0 g
s
.866 .903 .856 r
.73672 .27063 m .73451 .26894 L .73711 .26635 L closepath p F P
0 g
s
.976 .897 .677 r
.60937 .22074 m .60909 .22133 L .60981 .22572 L p F P
0 g
s
.98 .896 .663 r
.60673 .22668 m .60732 .23111 L .60981 .22572 L p F P
0 g
s
.98 .896 .663 r
.60981 .22572 m .60909 .22133 L .60673 .22668 L p F P
0 g
s
.596 .676 .896 r
.74452 .08648 m .74311 .08677 L .74423 .09116 L p F P
0 g
s
.596 .676 .896 r
.74423 .09116 m .74703 .09063 L .74452 .08648 L p F P
0 g
s
.981 .896 .556 r
.78384 .18129 m .78415 .18579 L .78586 .18066 L p F P
0 g
s
.981 .896 .556 r
.78586 .18066 m .78558 .17615 L .78384 .18129 L p F P
0 g
s
.985 .903 .609 r
.60433 .24272 m .60293 .24633 L .60264 .24339 L closepath p F P
0 g
s
.977 .92 .654 r
.77964 .19646 m .78207 .19106 L .78232 .19555 L p F P
0 g
s
.977 .92 .654 r
.77969 .19734 m .77964 .19646 L p .78232 .19555 L F P
0 g
s
.977 .92 .654 r
.78232 .19555 m .78142 .19754 L .77969 .19734 L p F P
0 g
s
.891 .832 .781 r
.64296 .14947 m .64221 .15048 L .64104 .14741 L closepath p F P
0 g
s
0 0 .31 r
.78498 .1353 m .78568 .13974 L .78448 .13573 L p F P
0 g
s
0 0 .31 r
.78448 .13573 m .78377 .1313 L .78498 .1353 L p F P
0 g
s
.925 .924 .791 r
.76554 .23281 m .76354 .23163 L .76559 .22883 L closepath p F P
0 g
s
.722 .758 .882 r
.70854 .0903 m .70653 .09135 L .70399 .08767 L p F P
0 g
s
.758 .77 .863 r
.69322 .09472 m .70399 .08767 L .70653 .09135 L p F P
0 g
s
.896 .833 .776 r
.63623 .15236 m .63772 .15657 L .64221 .15048 L p F P
0 g
s
.896 .833 .776 r
.64035 .14668 m .63623 .15236 L p .64221 .15048 L F P
0 g
s
.896 .833 .776 r
.64221 .15048 m .64104 .14741 L .64035 .14668 L p F P
0 g
s
.963 .888 .708 r
.61125 .21139 m .61199 .21579 L .61496 .21023 L p F P
0 g
s
.963 .888 .708 r
.61496 .21023 m .6141 .20587 L .61125 .21139 L p F P
0 g
s
.71 .795 .918 r
.64382 .32759 m .63304 .33279 L .63039 .32968 L p F P
0 g
s
.679 .77 .92 r
.61958 .33382 m .63039 .32968 L .63304 .33279 L p F P
0 g
s
.917 .853 .764 r
.62527 .1745 m .62645 .17879 L .63047 .17286 L p F P
0 g
s
.917 .853 .764 r
.63047 .17286 m .62916 .16861 L .62527 .1745 L p F P
0 g
s
0 0 .363 r
.59434 .30323 m .59423 .30401 L .59342 .29972 L p F P
0 g
s
0 0 .363 r
.59342 .29972 m .59367 .298 L .59434 .30323 L p F P
0 g
s
.663 .755 .919 r
.63039 .32968 m .61958 .33382 L .61689 .33016 L p F P
0 g
s
.739 .81 .908 r
.64557 .32947 m .64382 .32759 L .64623 .32628 L closepath p F P
0 g
s
.81 .799 .841 r
.68003 .10507 m .6719 .11208 L .66942 .10882 L p F P
0 g
s
.833 .803 .822 r
.6719 .11208 m .67117 .11281 L .66942 .10882 L closepath p F P
0 g
s
.837 .804 .819 r
.66227 .11574 m .66391 .11994 L .67117 .11281 L p F P
0 g
s
.837 .804 .819 r
.66932 .1087 m .66227 .11574 L p .67117 .11281 L F P
0 g
s
.837 .804 .819 r
.67117 .11281 m .66942 .10882 L .66932 .1087 L p F P
0 g
s
.333 .493 .868 r
.76345 .09987 m .76675 .10099 L .76796 .10531 L p F P
0 g
s
.235 .418 .839 r
.7717 .10354 m .7728 .10789 L .76796 .10531 L p F P
0 g
s
.235 .418 .839 r
.76796 .10531 m .76675 .10099 L .7717 .10354 L p F P
0 g
s
.726 .759 .879 r
.70854 .0903 m .71738 .08561 L .71485 .08181 L p F P
0 g
s
.726 .759 .879 r
.71485 .08181 m .70711 .086 L .70854 .0903 L p F P
0 g
s
.722 .758 .882 r
.70399 .08767 m .70711 .086 L .70854 .0903 L p F P
0 g
s
.786 .861 .906 r
.68121 .31296 m .67913 .31438 L .67985 .31174 L closepath p F P
0 g
s
.78 .85 .904 r
.67868 .31065 m .67985 .31174 L .67913 .31438 L p F P
0 g
s
.78 .85 .904 r
.66794 .31773 m .67868 .31065 L p .67913 .31438 L F P
0 g
s
.911 .923 .811 r
.75584 .24144 m .7557 .246 L .76073 .23964 L p F P
0 g
s
.911 .923 .811 r
.76073 .23964 m .76094 .23505 L .75584 .24144 L p F P
0 g
s
.973 .926 .663 r
.78142 .19754 m .77978 .201 L .77969 .19734 L closepath p F P
0 g
s
0 0 .507 r
.78299 .12687 m .78377 .1313 L .78189 .12755 L p F P
0 g
s
0 0 .507 r
.78189 .12755 m .78109 .12313 L .78299 .12687 L p F P
0 g
s
.814 .795 .835 r
.68003 .10507 m .68253 .10287 L .67996 .09937 L p F P
0 g
s
.814 .795 .835 r
.67996 .09937 m .67822 .10092 L .68003 .10507 L p F P
0 g
s
.81 .799 .841 r
.66936 .10867 m .67822 .10092 L .68003 .10507 L p F P
0 g
s
.81 .799 .841 r
.66942 .10882 m .66936 .10867 L p .68003 .10507 L F P
0 g
s
.976 .861 .473 r
.78699 .17226 m .78651 .17267 L .78689 .17117 L closepath p F P
0 g
s
.916 .749 .259 r
.78662 .15749 m .78719 .16193 L .78757 .15731 L p F P
0 g
s
.916 .749 .259 r
.78757 .15731 m .78701 .15286 L .78662 .15749 L p F P
0 g
s
.786 .788 .854 r
.69078 .0966 m .68253 .10287 L .67996 .09937 L p F P
0 g
s
.832 .81 .83 r
.65875 .11919 m .66227 .11574 L .66391 .11994 L p F P
0 g
s
.832 .81 .83 r
.66391 .11994 m .66134 .12242 L .65875 .11919 L p F P
0 g
s
.94 .883 .749 r
.61608 .19598 m .61945 .19027 L .62047 .1946 L p F P
0 g
s
.94 .883 .749 r
.61693 .20015 m .61608 .19598 L p .62047 .1946 L F P
0 g
s
.94 .883 .749 r
.62047 .1946 m .61704 .20022 L .61693 .20015 L p F P
0 g
s
.856 .815 .808 r
.65739 .12679 m .66134 .12242 L .65875 .11919 L p F P
0 g
s
.8 .863 .896 r
.68942 .30302 m .69192 .30531 L .68121 .31296 L p F P
0 g
s
.8 .863 .896 r
.68024 .30956 m .68942 .30302 L p .68121 .31296 L F P
0 g
s
.8 .863 .896 r
.68121 .31296 m .67985 .31174 L .68024 .30956 L p F P
0 g
s
.856 .826 .818 r
.65157 .13476 m .65082 .1339 L .65116 .13353 L closepath p F P
0 g
s
.954 .936 .731 r
.77373 .21666 m .77362 .21685 L .77362 .21662 L closepath p F P
0 g
s
.546 .595 .855 r
.60331 .32755 m .60476 .3275 L .60407 .32897 L closepath p F P
0 g
s
.609 .645 .861 r
.61419 .32627 m .60476 .3275 L .60407 .32897 L p F P
0 g
s
.609 .645 .861 r
.61689 .33016 m .61419 .32627 L p .60407 .32897 L F P
0 g
s
.089 .29 .772 r
.77652 .11092 m .7775 .11531 L .77385 .11226 L p F P
0 g
s
.089 .29 .772 r
.77385 .11226 m .7728 .10789 L .77652 .11092 L p F P
0 g
s
.941 .931 .764 r
.76978 .21822 m .76975 .22278 L .77362 .21685 L p F P
0 g
s
.941 .931 .764 r
.77149 .21558 m .76978 .21822 L p .77362 .21685 L F P
0 g
s
.941 .931 .764 r
.77362 .21685 m .77362 .21662 L .77149 .21558 L p F P
0 g
s
0 .122 .664 r
.78022 .11872 m .78109 .12313 L .77841 .1197 L p F P
0 g
s
0 .122 .664 r
.77841 .1197 m .7775 .11531 L .78022 .11872 L p F P
0 g
s
.511 .621 .896 r
.74703 .09063 m .75719 .09062 L .75837 .09497 L p F P
0 g
s
.52 .624 .894 r
.75719 .09062 m .74703 .09063 L .74452 .08648 L p F P
0 g
s
.9 .853 .788 r
.63356 .16441 m .63253 .16347 L .6331 .16272 L closepath p F P
0 g
s
.948 .925 .75 r
.77362 .21662 m .77149 .21558 L .77352 .21233 L closepath p F P
0 g
s
.901 .919 .823 r
.75568 .24638 m .75549 .24626 L .7557 .246 L closepath p F P
0 g
s
.856 .815 .808 r
.65875 .11919 m .65567 .12263 L .65739 .12679 L p F P
0 g
s
.854 .814 .81 r
.6496 .12932 m .65116 .13353 L .65739 .12679 L p F P
0 g
s
.854 .814 .81 r
.65739 .12679 m .65567 .12263 L .6496 .12932 L p F P
0 g
s
.942 .873 .457 r
.59783 .26174 m .59762 .2664 L .59925 .26128 L p F P
0 g
s
.942 .873 .457 r
.59925 .26128 m .59933 .25666 L .59783 .26174 L p F P
0 g
s
.986 .896 .579 r
.60067 .24704 m .60105 .25152 L .60293 .24633 L p F P
0 g
s
.986 .896 .579 r
.60177 .24391 m .60067 .24704 L p .60293 .24633 L F P
0 g
s
.986 .896 .579 r
.60293 .24633 m .60264 .24339 L .60177 .24391 L p F P
0 g
s
.76 .829 .905 r
.6651 .31948 m .65718 .32428 L .6546 .32166 L p F P
0 g
s
.896 .838 .781 r
.63174 .15847 m .6331 .16272 L .63772 .15657 L p F P
0 g
s
.896 .838 .781 r
.63772 .15657 m .63623 .15236 L .63174 .15847 L p F P
0 g
s
.379 .453 .811 r
.59787 .32086 m .59858 .31748 L .60053 .3219 L closepath p F P
0 g
s
.851 .758 .246 r
.5956 .27621 m .59541 .28084 L .59625 .27599 L p F P
0 g
s
.851 .758 .246 r
.59625 .27599 m .59638 .27138 L .5956 .27621 L p F P
0 g
s
.501 .556 .844 r
.60476 .3275 m .60331 .32755 L .60053 .3219 L p F P
0 g
s
.786 .788 .854 r
.67996 .09937 m .68894 .09246 L .69078 .0966 L p F P
0 g
s
.789 .784 .848 r
.69078 .0966 m .69322 .09472 L .69066 .09112 L p F P
0 g
s
.789 .784 .848 r
.69066 .09112 m .68894 .09246 L .69078 .0966 L p F P
0 g
s
.983 .901 .648 r
.60444 .23202 m .60492 .23648 L .60732 .23111 L p F P
0 g
s
.983 .901 .648 r
.60732 .23111 m .60673 .22668 L .60444 .23202 L p F P
0 g
s
.919 .864 .769 r
.62215 .17919 m .62527 .1745 L .62645 .17879 L p F P
0 g
s
.919 .864 .769 r
.62645 .17879 m .62477 .18128 L .62215 .17919 L p F P
0 g
s
.9 .915 .822 r
.75317 .24465 m .75584 .24144 L .7557 .246 L p F P
0 g
s
.9 .915 .822 r
.7557 .246 m .75549 .24626 L .75317 .24465 L p F P
0 g
s
.896 .918 .829 r
.74997 .25262 m .75549 .24626 L .75317 .24465 L p F P
0 g
s
.978 .861 .477 r
.78516 .17167 m .78638 .16672 L .78689 .17117 L p F P
0 g
s
.978 .861 .477 r
.78538 .17357 m .78516 .17167 L p .78689 .17117 L F P
0 g
s
.978 .861 .477 r
.78689 .17117 m .78651 .17267 L .78538 .17357 L p F P
0 g
s
.344 .504 .873 r
.76675 .10099 m .76345 .09987 L .76093 .09525 L p F P
0 g
s
.963 .928 .711 r
.77666 .20208 m .7768 .2066 L .77978 .201 L p F P
0 g
s
.963 .928 .711 r
.77926 .1972 m .77666 .20208 L p .77978 .201 L F P
0 g
s
.963 .928 .711 r
.77978 .201 m .77969 .19734 L .77926 .1972 L p F P
0 g
s
.759 .77 .861 r
.70399 .08767 m .69322 .09472 L .69066 .09112 L p F P
0 g
s
.964 .904 .71 r
.60844 .2169 m .61125 .21139 L .61199 .21579 L p F P
0 g
s
.964 .904 .71 r
.60895 .22063 m .60844 .2169 L p .61199 .21579 L F P
0 g
s
.964 .904 .71 r
.61199 .21579 m .60937 .22074 L .60895 .22063 L p F P
0 g
s
0 0 .424 r
.59533 .2991 m .59434 .30323 L .59367 .298 L p F P
0 g
s
0 0 .424 r
.59367 .298 m .59441 .29485 L .59533 .2991 L p F P
0 g
s
.853 .821 .816 r
.64822 .13083 m .6496 .12932 L .65116 .13353 L p F P
0 g
s
.853 .821 .816 r
.65116 .13353 m .65082 .1339 L .64822 .13083 L p F P
0 g
s
.877 .824 .792 r
.64598 .13988 m .65082 .1339 L .64822 .13083 L p F P
0 g
s
.841 .648 .105 r
.78637 .14842 m .78701 .15286 L .78692 .14842 L p F P
0 g
s
.841 .648 .105 r
.78692 .14842 m .78629 .14398 L .78637 .14842 L p F P
0 g
s
.983 .909 .614 r
.78173 .18658 m .78207 .19106 L .78415 .18579 L p F P
0 g
s
.983 .909 .614 r
.78415 .18579 m .78384 .18129 L .78173 .18658 L p F P
0 g
s
.806 .869 .894 r
.69198 .30536 m .69192 .30531 L .692 .30526 L closepath p F P
0 g
s
0 0 .171 r
.59511 .29007 m .59441 .29485 L .59429 .29033 L p F P
0 g
s
0 0 .171 r
.59429 .29033 m .59499 .28554 L .59511 .29007 L p F P
0 g
s
.805 .864 .892 r
.692 .30526 m .69192 .30531 L .68942 .30302 L p F P
0 g
s
.809 .868 .891 r
.692 .30526 m .70262 .29711 L .70013 .2949 L p F P
0 g
s
.809 .868 .891 r
.70013 .2949 m .69271 .30056 L .692 .30526 L p F P
0 g
s
.805 .864 .892 r
.68942 .30302 m .69271 .30056 L .692 .30526 L p F P
0 g
s
.188 .265 .713 r
.59525 .31272 m .59582 .30953 L .59772 .3152 L closepath p F P
0 g
s
.935 .857 .739 r
.62281 .18458 m .62477 .18128 L .62215 .17919 L p F P
0 g
s
.501 .556 .844 r
.60053 .3219 m .6066 .32239 L .60476 .3275 L p F P
0 g
s
.575 .662 .896 r
.61146 .32212 m .6066 .32239 L .60476 .3275 L p F P
0 g
s
.575 .662 .896 r
.60476 .3275 m .61419 .32627 L .61146 .32212 L p F P
0 g
s
.87 .824 .348 r
.59749 .26768 m .59683 .26937 L .59762 .2664 L closepath p F P
0 g
s
.952 .871 .721 r
.61704 .20022 m .61698 .20035 L .61693 .20015 L closepath p F P
0 g
s
.933 .927 .777 r
.76557 .22429 m .76559 .22883 L .76975 .22278 L p F P
0 g
s
.933 .927 .777 r
.76975 .22278 m .76978 .21822 L .76557 .22429 L p F P
0 g
s
.957 .871 .71 r
.61301 .20158 m .6141 .20587 L .61698 .20035 L p F P
0 g
s
.957 .871 .71 r
.61443 .19881 m .61301 .20158 L p .61698 .20035 L F P
0 g
s
.957 .871 .71 r
.61698 .20035 m .61693 .20015 L .61443 .19881 L p F P
0 g
s
.975 .868 .483 r
.78651 .17267 m .78558 .17615 L .78538 .17357 L closepath p F P
0 g
s
.896 .918 .829 r
.75317 .24465 m .75025 .24801 L .74997 .25262 L p F P
0 g
s
.889 .914 .836 r
.74419 .25476 m .75025 .24801 L .74997 .25262 L p F P
0 g
s
.889 .914 .836 r
.74406 .25742 m .74419 .25476 L p .74997 .25262 L F P
0 g
s
.889 .914 .836 r
.74997 .25262 m .74504 .25811 L .74406 .25742 L p F P
0 g
s
.819 .877 .887 r
.70294 .29739 m .70262 .29711 L .70304 .29677 L closepath p F P
0 g
s
.947 .884 .738 r
.61693 .20015 m .61443 .19881 L .61608 .19598 L closepath p F P
0 g
s
.897 .846 .786 r
.62991 .16094 m .63174 .15847 L .6331 .16272 L p F P
0 g
s
.897 .846 .786 r
.6331 .16272 m .63253 .16347 L .62991 .16094 L p F P
0 g
s
.68 .728 .886 r
.71738 .08561 m .72836 .08116 L .73088 .08509 L p F P
0 g
s
.684 .73 .886 r
.72836 .08116 m .71738 .08561 L .71485 .08181 L p F P
0 g
s
.916 .844 .758 r
.62916 .16861 m .63253 .16347 L .62991 .16094 L p F P
0 g
s
.619 .691 .895 r
.74201 .08236 m .74311 .08677 L p .73088 .08509 L F P
0 g
s
.619 .691 .895 r
.73088 .08509 m .74201 .08236 L .74201 .08236 L p F P
0 g
s
.625 .695 .895 r
.74201 .08236 m .73088 .08509 L .72836 .08116 L p F P
0 g
s
.76 .829 .905 r
.66537 .31524 m .66612 .31599 L .6651 .31948 L p F P
0 g
s
.76 .829 .905 r
.6546 .32166 m .66537 .31524 L p .6651 .31948 L F P
0 g
s
.765 .843 .91 r
.66794 .31773 m .6651 .31948 L .66612 .31599 L closepath p F P
0 g
s
.877 .836 .802 r
.64104 .14741 m .64035 .14668 L .64067 .14628 L closepath p F P
0 g
s
.874 .823 .795 r
.63913 .14207 m .64067 .14628 L .64598 .13988 L p F P
0 g
s
.874 .823 .795 r
.64598 .13988 m .64431 .13572 L .63913 .14207 L p F P
0 g
s
.877 .824 .792 r
.64822 .13083 m .64431 .13572 L .64598 .13988 L p F P
0 g
s
.738 .803 .904 r
.64623 .32628 m .64382 .32759 L .64119 .32468 L p F P
0 g
s
.71 .795 .918 r
.63039 .32968 m .64119 .32468 L .64382 .32759 L p F P
0 g
s
.458 .581 .889 r
.7584 .09072 m .75719 .09062 L .75837 .09497 L p F P
0 g
s
.458 .581 .889 r
.75837 .09497 m .76093 .09525 L .7584 .09072 L p F P
0 g
s
.883 .915 .843 r
.74504 .25811 m .74388 .25936 L .74406 .25742 L closepath p F P
0 g
s
.819 .872 .885 r
.70304 .29677 m .70262 .29711 L .70013 .2949 L p F P
0 g
s
.717 .5 0 r
.78559 .13954 m .78629 .14398 L .78568 .13974 L p F P
0 g
s
.717 .5 0 r
.78568 .13974 m .78498 .1353 L .78559 .13954 L p F P
0 g
s
.79 .854 .899 r
.67985 .31174 m .67868 .31065 L .68024 .30956 L closepath p F P
0 g
s
.82 .879 .888 r
.70365 .2921 m .70304 .29677 L .71289 .2887 L p F P
0 g
s
.819 .872 .885 r
.70013 .2949 m .70365 .2921 L .70304 .29677 L p F P
0 g
s
.935 .857 .739 r
.62215 .17919 m .62147 .18035 L .62281 .18458 L p F P
0 g
s
.938 .857 .735 r
.61822 .18601 m .61945 .19027 L .62281 .18458 L p F P
0 g
s
.938 .857 .735 r
.62281 .18458 m .62147 .18035 L .61822 .18601 L p F P
0 g
s
.869 .905 .854 r
.73745 .26174 m .73711 .26635 L .74388 .25936 L p F P
0 g
s
.869 .905 .854 r
.74268 .25636 m .73745 .26174 L p .74388 .25936 L F P
0 g
s
.869 .905 .854 r
.74388 .25936 m .74406 .25742 L .74268 .25636 L p F P
0 g
s
.964 .819 .39 r
.78579 .16229 m .78638 .16672 L .78719 .16193 L p F P
0 g
s
.964 .819 .39 r
.78719 .16193 m .78662 .15749 L .78579 .16229 L p F P
0 g
s
0 0 .534 r
.59423 .30401 m .59434 .30323 L .59483 .30545 L closepath p F P
0 g
s
.781 .846 .9 r
.67614 .3082 m .67868 .31065 L .66794 .31773 L p F P
0 g
s
.781 .846 .9 r
.66636 .31461 m .67614 .3082 L p .66794 .31773 L F P
0 g
s
.781 .846 .9 r
.66794 .31773 m .66612 .31599 L .66636 .31461 L p F P
0 g
s
.982 .886 .534 r
.59906 .25215 m .59933 .25666 L .60105 .25152 L p F P
0 g
s
.982 .886 .534 r
.60105 .25152 m .60067 .24704 L .59906 .25215 L p F P
0 g
s
.957 .925 .729 r
.77333 .20782 m .77352 .21233 L .7768 .2066 L p F P
0 g
s
.957 .925 .729 r
.7768 .2066 m .77666 .20208 L .77333 .20782 L p F P
0 g
s
.973 .887 .682 r
.60937 .22074 m .60909 .22133 L .60895 .22063 L closepath p F P
0 g
s
.735 .807 .909 r
.64623 .32628 m .6546 .32166 L .65199 .31896 L p F P
0 g
s
.735 .807 .909 r
.65199 .31896 m .64728 .32147 L .64623 .32628 L p F P
0 g
s
.738 .803 .904 r
.64119 .32468 m .64728 .32147 L .64623 .32628 L p F P
0 g
s
.984 .905 .63 r
.60226 .23732 m .6026 .24183 L .60492 .23648 L p F P
0 g
s
.984 .905 .63 r
.60492 .23648 m .60444 .23202 L .60226 .23732 L p F P
0 g
s
.895 .837 .374 r
.59658 .26673 m .59783 .26174 L .59762 .2664 L p F P
0 g
s
.895 .837 .374 r
.59636 .2705 m .59658 .26673 L p .59762 .2664 L F P
0 g
s
.895 .837 .374 r
.59762 .2664 m .59683 .26937 L .59636 .2705 L p F P
0 g
s
.725 .758 .879 r
.70711 .086 m .70399 .08767 L .70144 .08397 L p F P
0 g
s
.759 .77 .861 r
.69066 .09112 m .70144 .08397 L .70399 .08767 L p F P
0 g
s
.866 .9 .856 r
.73212 .26707 m .73745 .26174 L .73711 .26635 L p F P
0 g
s
.866 .9 .856 r
.73711 .26635 m .73451 .26894 L .73212 .26707 L p F P
0 g
s
.512 .53 .812 r
.59858 .31748 m .60053 .3219 L .6066 .32239 L p F P
0 g
s
.603 .682 .897 r
.74311 .08677 m .74201 .08236 L .74452 .08648 L closepath p F P
0 g
s
.644 .739 .918 r
.62773 .32643 m .61689 .33016 L .61419 .32627 L p F P
0 g
s
.663 .755 .919 r
.61689 .33016 m .62773 .32643 L .63039 .32968 L p F P
0 g
s
.832 .889 .883 r
.71329 .28836 m .71289 .2887 L .71299 .28812 L closepath p F P
0 g
s
.82 .879 .888 r
.71083 .28624 m .70365 .2921 L p .71289 .2887 L F P
0 g
s
.82 .879 .888 r
.71289 .2887 m .71299 .28812 L .71083 .28624 L p F P
0 g
s
.84 .889 .876 r
.72169 .28099 m .71329 .28836 L .71299 .28812 L p F P
0 g
s
.924 .922 .791 r
.76124 .23024 m .76557 .22429 L .76559 .22883 L p F P
0 g
s
.924 .922 .791 r
.76559 .22883 m .76354 .23163 L .76124 .23024 L p F P
0 g
s
.859 .901 .862 r
.72971 .27356 m .73451 .26894 L .73212 .26707 L p F P
0 g
s
.979 .886 .665 r
.60587 .22234 m .60673 .22668 L .60909 .22133 L p F P
0 g
s
.979 .886 .665 r
.60677 .22026 m .60587 .22234 L p .60909 .22133 L F P
0 g
s
.979 .886 .665 r
.60909 .22133 m .60895 .22063 L .60677 .22026 L p F P
0 g
s
.7 .786 .917 r
.64119 .32468 m .63039 .32968 L .62773 .32643 L p F P
0 g
s
.859 .901 .862 r
.73212 .26707 m .73021 .2689 L .72971 .27356 L p F P
0 g
s
.853 .896 .866 r
.72228 .27631 m .73021 .2689 L .72971 .27356 L p F P
0 g
s
.853 .896 .866 r
.72217 .27759 m .72228 .27631 L p .72971 .27356 L F P
0 g
s
.853 .896 .866 r
.72971 .27356 m .72392 .27898 L .72217 .27759 L p F P
0 g
s
.846 .896 .873 r
.72392 .27898 m .72169 .28099 L .72217 .27759 L closepath p F P
0 g
s
.84 .889 .876 r
.7215 .27702 m .72217 .27759 L .72169 .28099 L p F P
0 g
s
.84 .889 .876 r
.71342 .28405 m .7215 .27702 L p .72169 .28099 L F P
0 g
s
.84 .889 .876 r
.71299 .28812 m .71342 .28405 L p .72169 .28099 L F P
0 g
s
.875 .83 .8 r
.63773 .14379 m .63913 .14207 L .64067 .14628 L p F P
0 g
s
.875 .83 .8 r
.64067 .14628 m .64035 .14668 L .63773 .14379 L p F P
0 g
s
0 0 .308 r
.78436 .13178 m .78498 .1353 L .78377 .1313 L p F P
0 g
s
0 0 .308 r
.78371 .12919 m .78436 .13178 L p .78377 .1313 L F P
0 g
s
0 0 .308 r
.78377 .1313 m .78299 .12687 L .78371 .12919 L p F P
0 g
s
.811 .8 .842 r
.66942 .10882 m .66932 .1087 L .66936 .10867 L closepath p F P
0 g
s
.985 .897 .572 r
.78346 .1768 m .78384 .18129 L .78558 .17615 L p F P
0 g
s
.985 .897 .572 r
.78449 .17375 m .78346 .1768 L p .78558 .17615 L F P
0 g
s
.985 .897 .572 r
.78558 .17615 m .78538 .17357 L .78449 .17375 L p F P
0 g
s
.896 .831 .774 r
.63623 .15236 m .64035 .14668 L .63773 .14379 L p F P
0 g
s
.916 .844 .758 r
.62991 .16094 m .62766 .16442 L .62916 .16861 L p F P
0 g
s
.916 .844 .758 r
.62388 .17026 m .62527 .1745 L .62916 .16861 L p F P
0 g
s
.916 .844 .758 r
.62916 .16861 m .62766 .16442 L .62388 .17026 L p F P
0 g
s
.978 .914 .658 r
.77928 .192 m .77964 .19646 L .78207 .19106 L p F P
0 g
s
.978 .914 .658 r
.78207 .19106 m .78173 .18658 L .77928 .192 L p F P
0 g
s
.757 .656 .1 r
.59521 .28091 m .59499 .28554 L .59541 .28084 L p F P
0 g
s
.757 .656 .1 r
.59541 .28084 m .5956 .27621 L .59521 .28091 L p F P
0 g
s
.976 .915 .597 r
.60264 .24339 m .60177 .24391 L .6026 .24183 L closepath p F P
0 g
s
.177 .18 .623 r
.59736 .30296 m .59533 .2991 L .59434 .30323 L p F P
0 g
s
.177 .18 .623 r
.59631 .30785 m .59736 .30296 L p .59434 .30323 L F P
0 g
s
.177 .18 .623 r
.59434 .30323 m .59483 .30545 L .59631 .30785 L p F P
0 g
s
.809 .797 .84 r
.66936 .10867 m .66932 .1087 L .66673 .10527 L p F P
0 g
s
.837 .805 .821 r
.66227 .11574 m .66932 .1087 L .66673 .10527 L p F P
0 g
s
.811 .791 .834 r
.66763 .10449 m .66936 .10867 L .67822 .10092 L p F P
0 g
s
.809 .797 .84 r
.66673 .10527 m .66763 .10449 L .66936 .10867 L p F P
0 g
s
.962 .875 .703 r
.61027 .20706 m .61125 .21139 L .6141 .20587 L p F P
0 g
s
.962 .875 .703 r
.6141 .20587 m .61301 .20158 L .61027 .20706 L p F P
0 g
s
.831 .879 .878 r
.71299 .28812 m .71083 .28624 L .71342 .28405 L closepath p F P
0 g
s
.92 .925 .798 r
.76094 .23505 m .76354 .23163 L .76124 .23024 L p F P
0 g
s
.52 .624 .894 r
.75602 .08651 m .75719 .09062 L p .74452 .08648 L F P
0 g
s
.52 .624 .894 r
.74452 .08648 m .75588 .08627 L .75602 .08651 L p F P
0 g
s
.514 .637 .909 r
.74201 .08236 m .74452 .08648 L .75588 .08627 L p F P
0 g
s
.344 .504 .873 r
.76093 .09525 m .76548 .09668 L .76675 .10099 L p F P
0 g
s
.24 .425 .844 r
.77051 .09919 m .7717 .10354 L .76675 .10099 L p F P
0 g
s
.24 .425 .844 r
.76675 .10099 m .76548 .09668 L .77051 .09919 L p F P
0 g
s
.729 .758 .876 r
.70711 .086 m .71485 .08181 L .71231 .07799 L p F P
0 g
s
.729 .758 .876 r
.71231 .07799 m .70546 .08177 L .70711 .086 L p F P
0 g
s
.725 .758 .879 r
.70144 .08397 m .70546 .08177 L .70711 .086 L p F P
0 g
s
.814 .792 .832 r
.67822 .10092 m .67996 .09937 L .67738 .09582 L p F P
0 g
s
.814 .792 .832 r
.67738 .09582 m .67628 .09681 L .67822 .10092 L p F P
0 g
s
.811 .791 .834 r
.67822 .10092 m .67628 .09681 L .66763 .10449 L p F P
0 g
s
.971 .903 .693 r
.60895 .22063 m .60677 .22026 L .60844 .2169 L closepath p F P
0 g
s
.787 .786 .851 r
.68894 .09246 m .67996 .09937 L .67738 .09582 L p F P
0 g
s
.837 .805 .821 r
.66673 .10527 m .66047 .11159 L .66227 .11574 L p F P
0 g
s
.832 .806 .826 r
.65614 .11587 m .66047 .11159 L .66227 .11574 L p F P
0 g
s
.832 .806 .826 r
.66227 .11574 m .65875 .11919 L .65614 .11587 L p F P
0 g
s
0 0 .521 r
.78272 .12547 m .78299 .12687 L .78109 .12313 L p F P
0 g
s
0 0 .521 r
.78079 .11978 m .78272 .12547 L p .78109 .12313 L F P
0 g
s
0 0 .521 r
.78109 .12313 m .78022 .11872 L .78079 .11978 L p F P
0 g
s
.118 .155 .625 r
.59483 .30545 m .59631 .30785 L .59582 .30953 L closepath p F P
0 g
s
.856 .81 .804 r
.65567 .12263 m .65875 .11919 L .65614 .11587 L p F P
0 g
s
.354 .514 .878 r
.76548 .09668 m .76093 .09525 L .7584 .09072 L p F P
0 g
s
.927 .756 .275 r
.78597 .15306 m .78662 .15749 L .78701 .15286 L p F P
0 g
s
.927 .756 .275 r
.78701 .15286 m .78637 .14842 L .78597 .15306 L p F P
0 g
s
.941 .864 .735 r
.61496 .19168 m .61608 .19598 L .61945 .19027 L p F P
0 g
s
.941 .864 .735 r
.61945 .19027 m .61822 .18601 L .61496 .19168 L p F P
0 g
s
.355 .398 .767 r
.59772 .3152 m .5991 .31595 L .59858 .31748 L closepath p F P
0 g
s
.512 .53 .812 r
.60736 .31764 m .5991 .31595 L .59858 .31748 L p F P
0 g
s
.512 .53 .812 r
.6066 .32239 m .60736 .31764 L p .59858 .31748 L F P
0 g
s
.091 .296 .777 r
.77551 .10668 m .77652 .11092 L .7728 .10789 L p F P
0 g
s
.091 .296 .777 r
.77542 .1065 m .77551 .10668 L p .7728 .10789 L F P
0 g
s
.091 .296 .777 r
.7728 .10789 m .7717 .10354 L .77542 .1065 L p F P
0 g
s
0 .139 .677 r
.77993 .11735 m .78022 .11872 L .7775 .11531 L p F P
0 g
s
0 .139 .677 r
.77808 .11278 m .77993 .11735 L p .7775 .11531 L F P
0 g
s
0 .139 .677 r
.7775 .11531 m .77652 .11092 L .77808 .11278 L p F P
0 g
s
.92 .925 .798 r
.76124 .23024 m .76107 .23047 L .76094 .23505 L p F P
0 g
s
.909 .918 .813 r
.75591 .23689 m .75584 .24144 L .76094 .23505 L p F P
0 g
s
.909 .918 .813 r
.76094 .23505 m .76107 .23047 L .75591 .23689 L p F P
0 g
s
.933 .836 .389 r
.59683 .26937 m .59638 .27138 L .59636 .2705 L closepath p F P
0 g
s
0 0 .373 r
.59596 .29434 m .59533 .2991 L .59441 .29485 L p F P
0 g
s
0 0 .373 r
.59441 .29485 m .59511 .29007 L .59596 .29434 L p F P
0 g
s
.878 .903 .844 r
.74406 .25742 m .74268 .25636 L .74419 .25476 L closepath p F P
0 g
s
.789 .849 .896 r
.68024 .30956 m .67868 .31065 L .67614 .3082 L p F P
0 g
s
.856 .81 .804 r
.65614 .11587 m .6538 .11851 L .65567 .12263 L p F P
0 g
s
.854 .809 .806 r
.64786 .12516 m .6496 .12932 L .65567 .12263 L p F P
0 g
s
.854 .809 .806 r
.65567 .12263 m .6538 .11851 L .64786 .12516 L p F P
0 g
s
.382 .391 .745 r
.59582 .30953 m .59772 .3152 L .5991 .31595 L p F P
0 g
s
.948 .923 .75 r
.7697 .21368 m .77333 .20782 L .77352 .21233 L p F P
0 g
s
.948 .923 .75 r
.76975 .21471 m .7697 .21368 L p .77352 .21233 L F P
0 g
s
.948 .923 .75 r
.77352 .21233 m .77149 .21558 L .76975 .21471 L p F P
0 g
s
.969 .92 .695 r
.77969 .19734 m .77926 .1972 L .77964 .19646 L closepath p F P
0 g
s
.896 .831 .774 r
.63773 .14379 m .63457 .1482 L .63623 .15236 L p F P
0 g
s
.895 .831 .776 r
.63019 .15427 m .63174 .15847 L .63623 .15236 L p F P
0 g
s
.895 .831 .776 r
.63623 .15236 m .63457 .1482 L .63019 .15427 L p F P
0 g
s
.792 .854 .897 r
.68024 .30956 m .68942 .30302 L .6869 .30068 L p F P
0 g
s
.792 .854 .897 r
.6869 .30068 m .68098 .30485 L .68024 .30956 L p F P
0 g
s
.789 .849 .896 r
.67614 .3082 m .68098 .30485 L .68024 .30956 L p F P
0 g
s
.791 .782 .845 r
.68894 .09246 m .69066 .09112 L .68809 .08747 L p F P
0 g
s
.791 .782 .845 r
.68809 .08747 m .68698 .08835 L .68894 .09246 L p F P
0 g
s
.787 .786 .851 r
.67738 .09582 m .68698 .08835 L .68894 .09246 L p F P
0 g
s
.382 .391 .745 r
.60042 .31099 m .59631 .30785 L .59582 .30953 L p F P
0 g
s
.382 .391 .745 r
.5991 .31595 m .60042 .31099 L p .59582 .30953 L F P
0 g
s
.755 .829 .909 r
.66537 .31524 m .6546 .32166 L .65199 .31896 L p F P
0 g
s
.761 .769 .86 r
.70144 .08397 m .69066 .09112 L .68809 .08747 L p F P
0 g
s
.917 .855 .765 r
.62004 .17614 m .62388 .17026 L .62527 .1745 L p F P
0 g
s
.917 .855 .765 r
.62056 .17783 m .62004 .17614 L p .62527 .1745 L F P
0 g
s
.917 .855 .765 r
.62527 .1745 m .62215 .17919 L .62056 .17783 L p F P
0 g
s
.981 .911 .609 r
.6002 .24259 m .60226 .23732 L .6026 .24183 L p F P
0 g
s
.981 .911 .609 r
.60032 .24458 m .6002 .24259 L p .6026 .24183 L F P
0 g
s
.981 .911 .609 r
.6026 .24183 m .60177 .24391 L .60032 .24458 L p F P
0 g
s
.969 .872 .481 r
.59765 .2572 m .59783 .26174 L .59933 .25666 L p F P
0 g
s
.969 .872 .481 r
.59933 .25666 m .59906 .25215 L .59765 .2572 L p F P
0 g
s
.984 .886 .647 r
.60369 .22763 m .60444 .23202 L .60673 .22668 L p F P
0 g
s
.984 .886 .647 r
.60673 .22668 m .60587 .22234 L .60369 .22763 L p F P
0 g
s
.853 .815 .812 r
.6456 .12766 m .64786 .12516 L .6496 .12932 L p F P
0 g
s
.853 .815 .812 r
.6496 .12932 m .64822 .13083 L .6456 .12766 L p F P
0 g
s
.985 .859 .488 r
.78456 .16724 m .78516 .17167 L .78638 .16672 L p F P
0 g
s
.985 .859 .488 r
.78638 .16672 m .78579 .16229 L .78456 .16724 L p F P
0 g
s
.876 .818 .788 r
.64431 .13572 m .64822 .13083 L .6456 .12766 L p F P
0 g
s
.901 .912 .821 r
.75083 .243 m .75591 .23689 L .75584 .24144 L p F P
0 g
s
.901 .912 .821 r
.75584 .24144 m .75317 .24465 L .75083 .243 L p F P
0 g
s
.893 .782 .291 r
.59553 .27375 m .5956 .27621 L .59638 .27138 L p F P
0 g
s
.893 .782 .291 r
.59638 .27138 m .59636 .2705 L .59553 .27375 L p F P
0 g
s
.969 .917 .697 r
.77706 .19639 m .77928 .192 L .77964 .19646 L p F P
0 g
s
.969 .917 .697 r
.77964 .19646 m .77926 .1972 L .77706 .19639 L p F P
0 g
s
.943 .927 .759 r
.77149 .21558 m .76978 .21822 L .76975 .21471 L closepath p F P
0 g
s
.966 .882 .698 r
.60757 .21254 m .60844 .2169 L .61125 .21139 L p F P
0 g
s
.966 .882 .698 r
.61125 .21139 m .61027 .20706 L .60757 .21254 L p F P
0 g
s
.857 .658 .122 r
.78566 .144 m .78637 .14842 L .78629 .14398 L p F P
0 g
s
.857 .658 .122 r
.78629 .14398 m .78559 .13954 L .78566 .144 L p F P
0 g
s
.984 .907 .623 r
.78132 .18211 m .78173 .18658 L .78384 .18129 L p F P
0 g
s
.984 .907 .623 r
.78384 .18129 m .78346 .1768 L .78132 .18211 L p F P
0 g
s
.684 .73 .886 r
.71485 .08181 m .72584 .07724 L .72836 .08116 L p F P
0 g
s
.687 .732 .885 r
.72584 .07724 m .71485 .08181 L .71231 .07799 L p F P
0 g
s
.967 .923 .702 r
.77666 .20208 m .77926 .1972 L .77706 .19639 L p F P
0 g
s
.625 .695 .895 r
.72836 .08116 m .73949 .07828 L .74201 .08236 L p F P
0 g
s
.629 .699 .896 r
.73949 .07828 m .72836 .08116 L .72584 .07724 L p F P
0 g
s
.772 .838 .902 r
.66612 .31599 m .66537 .31524 L .66636 .31461 L closepath p F P
0 g
s
.41 .473 .814 r
.60752 .31562 m .60736 .31764 L .5991 .31595 L p F P
0 g
s
.41 .473 .814 r
.60597 .31277 m .60752 .31562 L p .5991 .31595 L F P
0 g
s
.41 .473 .814 r
.5991 .31595 m .60042 .31099 L .60597 .31277 L p F P
0 g
s
.803 .86 .891 r
.69271 .30056 m .68942 .30302 L .6869 .30068 L p F P
0 g
s
.989 .885 .558 r
.78538 .17357 m .78449 .17375 L .78516 .17167 L closepath p F P
0 g
s
.896 .915 .828 r
.75025 .24801 m .75317 .24465 L .75083 .243 L p F P
0 g
s
.99 .889 .587 r
.60177 .24391 m .60067 .24704 L .60032 .24458 L closepath p F P
0 g
s
.943 .874 .739 r
.6118 .19717 m .61496 .19168 L .61608 .19598 L p F P
0 g
s
.943 .874 .739 r
.61608 .19598 m .61443 .19881 L .6118 .19717 L p F P
0 g
s
.895 .838 .781 r
.62728 .15827 m .63019 .15427 L .63174 .15847 L p F P
0 g
s
.895 .838 .781 r
.63174 .15847 m .62991 .16094 L .62728 .15827 L p F P
0 g
s
.928 .92 .785 r
.76548 .21977 m .76557 .22429 L .76978 .21822 L p F P
0 g
s
.928 .92 .785 r
.76923 .21439 m .76548 .21977 L p .76978 .21822 L F P
0 g
s
.928 .92 .785 r
.76978 .21822 m .76975 .21471 L .76923 .21439 L p F P
0 g
s
.931 .847 .738 r
.62215 .17919 m .62147 .18035 L .62056 .17783 L closepath p F P
0 g
s
.807 .865 .891 r
.69271 .30056 m .70013 .2949 L .69764 .29265 L p F P
0 g
s
.807 .865 .891 r
.69764 .29265 m .69339 .29587 L .69271 .30056 L p F P
0 g
s
.803 .86 .891 r
.6869 .30068 m .69339 .29587 L .69271 .30056 L p F P
0 g
s
0 0 .085 r
.59532 .28544 m .59511 .29007 L .59499 .28554 L p F P
0 g
s
0 0 .085 r
.59499 .28554 m .59521 .28091 L .59532 .28544 L p F P
0 g
s
.876 .818 .788 r
.6456 .12766 m .64248 .1316 L .64431 .13572 L p F P
0 g
s
.874 .817 .79 r
.63741 .13792 m .63913 .14207 L .64431 .13572 L p F P
0 g
s
.874 .817 .79 r
.64431 .13572 m .64248 .1316 L .63741 .13792 L p F P
0 g
s
.731 .795 .903 r
.64728 .32147 m .64119 .32468 L .63855 .32168 L p F P
0 g
s
.7 .786 .917 r
.62773 .32643 m .63855 .32168 L .64119 .32468 L p F P
0 g
s
.843 .767 .258 r
.59567 .27161 m .59553 .27375 L .59636 .2705 L p F P
0 g
s
.843 .767 .258 r
.59636 .2705 m .59658 .26673 L .59567 .27161 L p F P
0 g
s
.896 .915 .828 r
.75083 .243 m .75047 .24342 L .75025 .24801 L p F P
0 g
s
.886 .908 .837 r
.74431 .2502 m .74419 .25476 L .75025 .24801 L p F P
0 g
s
.886 .908 .837 r
.75025 .24801 m .75047 .24342 L .74431 .2502 L p F P
0 g
s
.644 .739 .918 r
.61419 .32627 m .62505 .32303 L .62773 .32643 L p F P
0 g
s
.62 .719 .917 r
.62505 .32303 m .61419 .32627 L .61146 .32212 L p F P
0 g
s
.467 .591 .893 r
.75719 .09062 m .75602 .08651 L .7584 .09072 L closepath p F P
0 g
s
.226 .293 .724 r
.60101 .30627 m .60042 .31099 L .59631 .30785 L p F P
0 g
s
.226 .293 .724 r
.59631 .30785 m .59736 .30296 L .60101 .30627 L p F P
0 g
s
.914 .835 .754 r
.62766 .16442 m .62991 .16094 L .62728 .15827 L p F P
0 g
s
.936 .848 .73 r
.61679 .1818 m .61822 .18601 L .62147 .18035 L p F P
0 g
s
.936 .848 .73 r
.61951 .17696 m .61679 .1818 L p .62147 .18035 L F P
0 g
s
.936 .848 .73 r
.62147 .18035 m .62056 .17783 L .61951 .17696 L p F P
0 g
s
.737 .512 0 r
.78507 .13664 m .78559 .13954 L .78498 .1353 L p F P
0 g
s
.737 .512 0 r
.78498 .1353 m .78436 .13178 L .78507 .13664 L p F P
0 g
s
.727 .758 .877 r
.70546 .08177 m .70144 .08397 L .69888 .08023 L p F P
0 g
s
.761 .769 .86 r
.68809 .08747 m .69888 .08023 L .70144 .08397 L p F P
0 g
s
.844 .886 .87 r
.72217 .27759 m .7215 .27702 L .72228 .27631 L closepath p F P
0 g
s
.956 .862 .707 r
.61301 .20158 m .61443 .19881 L .6118 .19717 L p F P
0 g
s
.544 .631 .888 r
.60873 .31768 m .60736 .31764 L .6066 .32239 L p F P
0 g
s
.544 .631 .888 r
.6066 .32239 m .61146 .32212 L .60873 .31768 L p F P
0 g
s
.971 .822 .404 r
.78513 .15786 m .78579 .16229 L .78662 .15749 L p F P
0 g
s
.971 .822 .404 r
.78662 .15749 m .78597 .15306 L .78513 .15786 L p F P
0 g
s
.817 .869 .885 r
.70365 .2921 m .70013 .2949 L .69764 .29265 L p F P
0 g
s
.689 .776 .917 r
.63855 .32168 m .62773 .32643 L .62505 .32303 L p F P
0 g
s
.771 .832 .899 r
.66636 .31461 m .66537 .31524 L .66279 .31261 L p F P
0 g
s
.755 .829 .909 r
.65199 .31896 m .66279 .31261 L .66537 .31524 L p F P
0 g
s
.878 .9 .843 r
.7403 .25448 m .74431 .2502 L .74419 .25476 L p F P
0 g
s
.878 .9 .843 r
.74419 .25476 m .74268 .25636 L .7403 .25448 L p F P
0 g
s
.552 .658 .906 r
.74201 .08236 m .74201 .08236 L .74201 .08236 L closepath p F P
0 g
s
.514 .637 .909 r
.75336 .08192 m .74201 .08236 L .74201 .08236 L p F P
0 g
s
.514 .637 .909 r
.75588 .08627 m .75336 .08192 L p .74201 .08236 L F P
0 g
s
.558 .663 .907 r
.74201 .08236 m .74201 .08236 L .73949 .07828 L p F P
0 g
s
.558 .663 .907 r
.73949 .07828 m .7402 .0782 L .74201 .08236 L p F P
0 g
s
.527 .635 .9 r
.75084 .07762 m .7402 .0782 L .74201 .08236 L p F P
0 g
s
.527 .635 .9 r
.74201 .08236 m .75336 .08192 L .75084 .07762 L p F P
0 g
s
.772 .836 .901 r
.66636 .31461 m .67614 .3082 L .67358 .3057 L p F P
0 g
s
.772 .836 .901 r
.67358 .3057 m .66704 .30992 L .66636 .31461 L p F P
0 g
s
.771 .832 .899 r
.66279 .31261 m .66704 .30992 L .66636 .31461 L p F P
0 g
s
.822 .874 .883 r
.70365 .2921 m .71083 .28624 L .70836 .28406 L p F P
0 g
s
.822 .874 .883 r
.70836 .28406 m .7042 .28744 L .70365 .2921 L p F P
0 g
s
.817 .869 .885 r
.69764 .29265 m .7042 .28744 L .70365 .2921 L p F P
0 g
s
.354 .514 .878 r
.7584 .09072 m .76413 .09239 L .76548 .09668 L p F P
0 g
s
.343 .518 .885 r
.75602 .08651 m .7584 .09072 L .76413 .09239 L p F P
0 g
s
.872 .901 .85 r
.73745 .26174 m .74268 .25636 L .7403 .25448 L p F P
0 g
s
.967 .923 .702 r
.77706 .19639 m .77644 .19756 L .77666 .20208 L p F P
0 g
s
.955 .921 .733 r
.77307 .20333 m .77333 .20782 L .77666 .20208 L p F P
0 g
s
.955 .921 .733 r
.77666 .20208 m .77644 .19756 L .77307 .20333 L p F P
0 g
s
.99 .88 .551 r
.59847 .24774 m .59906 .25215 L .60067 .24704 L p F P
0 g
s
.99 .88 .551 r
.5992 .24538 m .59847 .24774 L p .60067 .24704 L F P
0 g
s
.99 .88 .551 r
.60067 .24704 m .60032 .24458 L .5992 .24538 L p F P
0 g
s
.987 .89 .63 r
.60161 .2329 m .60226 .23732 L .60444 .23202 L p F P
0 g
s
.987 .89 .63 r
.60444 .23202 m .60369 .22763 L .60161 .2329 L p F P
0 g
s
.874 .823 .796 r
.6351 .14078 m .63741 .13792 L .63913 .14207 L p F P
0 g
s
.874 .823 .796 r
.63913 .14207 m .63773 .14379 L .6351 .14078 L p F P
0 g
s
.81 .793 .837 r
.66763 .10449 m .66673 .10527 L .66413 .10177 L p F P
0 g
s
.836 .801 .817 r
.66047 .11159 m .66673 .10527 L .66413 .10177 L p F P
0 g
s
.812 .789 .831 r
.66574 .10035 m .66763 .10449 L .67628 .09681 L p F P
0 g
s
.81 .793 .837 r
.66413 .10177 m .66574 .10035 L .66763 .10449 L p F P
0 g
s
.969 .894 .697 r
.60492 .21801 m .60757 .21254 L .60844 .2169 L p F P
0 g
s
.969 .894 .697 r
.60525 .21986 m .60492 .21801 L p .60844 .2169 L F P
0 g
s
.969 .894 .697 r
.60844 .2169 m .60677 .22026 L .60525 .21986 L p F P
0 g
s
.914 .835 .754 r
.62728 .15827 m .626 .16027 L .62766 .16442 L p F P
0 g
s
.915 .836 .753 r
.62231 .16609 m .62388 .17026 L .62766 .16442 L p F P
0 g
s
.915 .836 .753 r
.62766 .16442 m .626 .16027 L .62231 .16609 L p F P
0 g
s
0 0 .293 r
.78299 .12687 m .78272 .12547 L .78371 .12919 L closepath p F P
0 g
s
.925 .917 .79 r
.76094 .22596 m .76548 .21977 L .76557 .22429 L p F P
0 g
s
.925 .917 .79 r
.76108 .23014 m .76094 .22596 L p .76557 .22429 L F P
0 g
s
.925 .917 .79 r
.76557 .22429 m .76124 .23024 L .76108 .23014 L p F P
0 g
s
.872 .901 .85 r
.7403 .25448 m .73772 .25714 L .73745 .26174 L p F P
0 g
s
.866 .897 .854 r
.73056 .26428 m .73772 .25714 L .73745 .26174 L p F P
0 g
s
.866 .897 .854 r
.7305 .26578 m .73056 .26428 L p .73745 .26174 L F P
0 g
s
.866 .897 .854 r
.73745 .26174 m .73212 .26707 L .7305 .26578 L p F P
0 g
s
.944 .843 .407 r
.59649 .26216 m .59658 .26673 L .59783 .26174 L p F P
0 g
s
.944 .843 .407 r
.59783 .26174 m .59765 .2572 L .59649 .26216 L p F P
0 g
s
.814 .79 .829 r
.67628 .09681 m .67738 .09582 L .67479 .09222 L p F P
0 g
s
.814 .79 .829 r
.67479 .09222 m .67423 .09273 L .67628 .09681 L p F P
0 g
s
.812 .789 .831 r
.67628 .09681 m .67423 .09273 L .66574 .10035 L p F P
0 g
s
.894 .824 .77 r
.63457 .1482 m .63773 .14379 L .6351 .14078 L p F P
0 g
s
.788 .783 .848 r
.68698 .08835 m .67738 .09582 L .67479 .09222 L p F P
0 g
s
.831 .876 .877 r
.71342 .28405 m .71083 .28624 L .70836 .28406 L p F P
0 g
s
.731 .758 .874 r
.70546 .08177 m .71231 .07799 L .70977 .07416 L p F P
0 g
s
.731 .758 .874 r
.70977 .07416 m .70364 .07759 L .70546 .08177 L p F P
0 g
s
.727 .758 .877 r
.69888 .08023 m .70364 .07759 L .70546 .08177 L p F P
0 g
s
0 .028 .559 r
.59781 .29827 m .59736 .30296 L .59533 .2991 L p F P
0 g
s
0 .028 .559 r
.59533 .2991 m .59596 .29434 L .59781 .29827 L p F P
0 g
s
.99 .884 .561 r
.78295 .17235 m .78456 .16724 L .78516 .17167 L p F P
0 g
s
.99 .884 .561 r
.78317 .17398 m .78295 .17235 L p .78516 .17167 L F P
0 g
s
.99 .884 .561 r
.78516 .17167 m .78449 .17375 L .78317 .17398 L p F P
0 g
s
.244 .432 .848 r
.76926 .09486 m .77051 .09919 L .76548 .09668 L p F P
0 g
s
.244 .432 .848 r
.76548 .09668 m .76413 .09239 L .76926 .09486 L p F P
0 g
s
.836 .881 .875 r
.71342 .28405 m .7215 .27702 L .71905 .27489 L p F P
0 g
s
.836 .881 .875 r
.71905 .27489 m .71384 .27942 L .71342 .28405 L p F P
0 g
s
.831 .876 .877 r
.70836 .28406 m .71384 .27942 L .71342 .28405 L p F P
0 g
s
.956 .862 .707 r
.6118 .19717 m .61171 .19735 L .61301 .20158 L p F P
0 g
s
.96 .862 .698 r
.60906 .2028 m .61027 .20706 L .61301 .20158 L p F P
0 g
s
.96 .862 .698 r
.61301 .20158 m .61171 .19735 L .60906 .2028 L p F P
0 g
s
.978 .911 .664 r
.77884 .18754 m .77928 .192 L .78173 .18658 L p F P
0 g
s
.978 .911 .664 r
.78173 .18658 m .78132 .18211 L .77884 .18754 L p F P
0 g
s
.836 .801 .817 r
.66413 .10177 m .65852 .10748 L .66047 .11159 L p F P
0 g
s
.832 .801 .822 r
.65352 .11247 m .65852 .10748 L .66047 .11159 L p F P
0 g
s
.832 .801 .822 r
.66047 .11159 m .65614 .11587 L .65352 .11247 L p F P
0 g
s
.727 .804 .912 r
.64728 .32147 m .65199 .31896 L .64938 .31618 L p F P
0 g
s
.727 .804 .912 r
.64938 .31618 m .64873 .31651 L .64728 .32147 L p F P
0 g
s
.731 .795 .903 r
.63855 .32168 m .64873 .31651 L .64728 .32147 L p F P
0 g
s
.859 .898 .861 r
.73212 .26707 m .73021 .2689 L .7305 .26578 L closepath p F P
0 g
s
.846 .888 .869 r
.72256 .27172 m .72228 .27631 L .73021 .2689 L p F P
0 g
s
.846 .888 .869 r
.72971 .2651 m .72256 .27172 L p .73021 .2689 L F P
0 g
s
.846 .888 .869 r
.73021 .2689 m .7305 .26578 L .72971 .2651 L p F P
0 g
s
.843 .882 .868 r
.72228 .27631 m .7215 .27702 L .71905 .27489 L p F P
0 g
s
.843 .882 .868 r
.71905 .27489 m .72256 .27172 L .72228 .27631 L p F P
0 g
s
.855 .805 .801 r
.6538 .11851 m .65614 .11587 L .65352 .11247 L p F P
0 g
s
.829 .702 .166 r
.59511 .27754 m .59521 .28091 L .5956 .27621 L p F P
0 g
s
.829 .702 .166 r
.5956 .27621 m .59553 .27375 L .59511 .27754 L p F P
0 g
s
0 0 .513 r
.78022 .11872 m .77993 .11735 L .78079 .11978 L closepath p F P
0 g
s
.094 .297 .777 r
.77282 .10092 m .77051 .09919 L .7717 .10354 L p F P
0 g
s
.094 .297 .777 r
.7717 .10354 m .77542 .1065 L .77282 .10092 L p F P
0 g
s
.939 .853 .73 r
.61363 .18744 m .61496 .19168 L .61822 .18601 L p F P
0 g
s
.939 .853 .73 r
.61822 .18601 m .61679 .1818 L .61363 .18744 L p F P
0 g
s
.855 .805 .801 r
.65352 .11247 m .6518 .11443 L .6538 .11851 L p F P
0 g
s
.853 .805 .802 r
.64596 .12104 m .64786 .12516 L .6538 .11851 L p F P
0 g
s
.853 .805 .802 r
.6538 .11851 m .6518 .11443 L .64596 .12104 L p F P
0 g
s
.938 .762 .291 r
.78524 .14864 m .78597 .15306 L .78637 .14842 L p F P
0 g
s
.938 .762 .291 r
.78637 .14842 m .78566 .144 L .78524 .14864 L p F P
0 g
s
0 .134 .675 r
.77652 .11092 m .77551 .10668 L .77808 .11278 L closepath p F P
0 g
s
.788 .783 .848 r
.67479 .09222 m .68491 .08426 L .68698 .08835 L p F P
0 g
s
.791 .78 .843 r
.68698 .08835 m .68809 .08747 L .68551 .08378 L p F P
0 g
s
.791 .78 .843 r
.68551 .08378 m .68491 .08426 L .68698 .08835 L p F P
0 g
s
.762 .768 .858 r
.69888 .08023 m .68809 .08747 L .68551 .08378 L p F P
0 g
s
.894 .824 .77 r
.6351 .14078 m .63276 .14409 L .63457 .1482 L p F P
0 g
s
.894 .823 .771 r
.62846 .15012 m .63019 .15427 L .63457 .1482 L p F P
0 g
s
.894 .823 .771 r
.63457 .1482 m .63276 .14409 L .62846 .15012 L p F P
0 g
s
.987 .891 .57 r
.78449 .17375 m .78346 .1768 L .78317 .17398 L closepath p F P
0 g
s
.977 .876 .667 r
.60677 .22026 m .60587 .22234 L .60525 .21986 L closepath p F P
0 g
s
.787 .845 .896 r
.68098 .30485 m .67614 .3082 L .67358 .3057 L p F P
0 g
s
.919 .92 .798 r
.76124 .23024 m .76107 .23047 L .76108 .23014 L closepath p F P
0 g
s
.904 .911 .817 r
.75589 .23235 m .75591 .23689 L .76107 .23047 L p F P
0 g
s
.904 .911 .817 r
.75892 .22857 m .75589 .23235 L p .76107 .23047 L F P
0 g
s
.904 .911 .817 r
.76107 .23047 m .76108 .23014 L .75892 .22857 L p F P
0 g
s
0 0 .425 r
.78079 .11978 m .78201 .1225 L .78272 .12547 L closepath p F P
0 g
s
0 0 .195 r
.78314 .12654 m .78201 .1225 L .78272 .12547 L p F P
0 g
s
0 0 .195 r
.78417 .13089 m .78314 .12654 L p .78272 .12547 L F P
0 g
s
0 0 .195 r
.78272 .12547 m .78371 .12919 L .78417 .13089 L p F P
0 g
s
.751 .824 .909 r
.66279 .31261 m .65199 .31896 L .64938 .31618 L p F P
0 g
s
.923 .857 .759 r
.62056 .17783 m .61951 .17696 L .62004 .17614 L closepath p F P
0 g
s
.946 .917 .752 r
.7694 .20921 m .7697 .21368 L .77333 .20782 L p F P
0 g
s
.946 .917 .752 r
.77333 .20782 m .77307 .20333 L .7694 .20921 L p F P
0 g
s
.916 .841 .755 r
.61857 .17193 m .62004 .17614 L .62388 .17026 L p F P
0 g
s
.916 .841 .755 r
.62388 .17026 m .62231 .16609 L .61857 .17193 L p F P
0 g
s
.852 .81 .808 r
.64297 .12438 m .64596 .12104 L .64786 .12516 L p F P
0 g
s
.852 .81 .808 r
.64786 .12516 m .6456 .12766 L .64297 .12438 L p F P
0 g
s
0 0 .401 r
.77993 .11735 m .78079 .11978 L .78201 .1225 L p F P
0 g
s
.912 .908 .804 r
.76108 .23014 m .75892 .22857 L .76094 .22596 L closepath p F P
0 g
s
0 0 .297 r
.5961 .28974 m .59596 .29434 L .59511 .29007 L p F P
0 g
s
0 0 .297 r
.59511 .29007 m .59532 .28544 L .5961 .28974 L p F P
0 g
s
.687 .732 .885 r
.71231 .07799 m .7233 .07331 L .72584 .07724 L p F P
0 g
s
.629 .699 .896 r
.72584 .07724 m .73697 .07421 L .73949 .07828 L p F P
0 g
s
.633 .703 .896 r
.73697 .07421 m .72584 .07724 L .7233 .07331 L p F P
0 g
s
.69 .734 .885 r
.7233 .07331 m .71231 .07799 L .70977 .07416 L p F P
0 g
s
.874 .812 .785 r
.64248 .1316 m .6456 .12766 L .64297 .12438 L p F P
0 g
s
0 .015 .588 r
.77808 .11278 m .77914 .11437 L .77993 .11735 L closepath p F P
0 g
s
0 0 .401 r
.78089 .11817 m .77914 .11437 L .77993 .11735 L p F P
0 g
s
0 0 .401 r
.78201 .1225 m .78089 .11817 L p .77993 .11735 L F P
0 g
s
0 0 .229 r
.78371 .12919 m .78417 .13089 L .78436 .13178 L closepath p F P
0 g
s
.789 .851 .897 r
.68098 .30485 m .6869 .30068 L .68437 .29828 L p F P
0 g
s
.789 .851 .897 r
.68437 .29828 m .68173 .30013 L .68098 .30485 L p F P
0 g
s
.787 .845 .896 r
.67358 .3057 m .68173 .30013 L .68098 .30485 L p F P
0 g
s
.983 .874 .648 r
.60268 .22333 m .60369 .22763 L .60587 .22234 L p F P
0 g
s
.983 .874 .648 r
.60415 .21967 m .60268 .22333 L p .60587 .22234 L F P
0 g
s
.983 .874 .648 r
.60587 .22234 m .60525 .21986 L .60415 .21967 L p F P
0 g
s
.989 .892 .608 r
.59966 .23813 m .6002 .24259 L .60226 .23732 L p F P
0 g
s
.989 .892 .608 r
.60226 .23732 m .60161 .2329 L .59966 .23813 L p F P
0 g
s
.989 .859 .499 r
.78388 .16283 m .78456 .16724 L .78579 .16229 L p F P
0 g
s
.989 .859 .499 r
.78579 .16229 m .78513 .15786 L .78388 .16283 L p F P
0 g
s
.62 .719 .917 r
.61146 .32212 m .62236 .31947 L .62505 .32303 L p F P
0 g
s
.591 .696 .916 r
.62236 .31947 m .61146 .32212 L .60873 .31768 L p F P
0 g
s
.936 .916 .771 r
.76975 .21471 m .76923 .21439 L .7697 .21368 L closepath p F P
0 g
s
.985 .865 .499 r
.59714 .25276 m .59765 .2572 L .59906 .25215 L p F P
0 g
s
.985 .865 .499 r
.59906 .25215 m .59847 .24774 L .59714 .25276 L p F P
0 g
s
.981 .9 .568 r
.60032 .24458 m .5992 .24538 L .6002 .24259 L closepath p F P
0 g
s
.872 .667 .14 r
.78499 .14028 m .78566 .144 L .78559 .13954 L p F P
0 g
s
.872 .667 .14 r
.78559 .13954 m .78507 .13664 L .78499 .14028 L p F P
0 g
s
.964 .868 .693 r
.60646 .20825 m .60757 .21254 L .61027 .20706 L p F P
0 g
s
.964 .868 .693 r
.61027 .20706 m .60906 .2028 L .60646 .20825 L p F P
0 g
s
.97 .913 .695 r
.77603 .1931 m .77884 .18754 L .77928 .192 L p F P
0 g
s
.97 .913 .695 r
.77634 .19611 m .77603 .1931 L p .77928 .192 L F P
0 g
s
.97 .913 .695 r
.77928 .192 m .77706 .19639 L .77634 .19611 L p F P
0 g
s
.901 .908 .819 r
.75041 .23889 m .75589 .23235 L .75591 .23689 L p F P
0 g
s
.901 .908 .819 r
.75048 .24275 m .75041 .23889 L p .75591 .23689 L F P
0 g
s
.901 .908 .819 r
.75591 .23689 m .75083 .243 L .75048 .24275 L p F P
0 g
s
.983 .905 .637 r
.78083 .17764 m .78132 .18211 L .78346 .1768 L p F P
0 g
s
.983 .905 .637 r
.78238 .17383 m .78083 .17764 L p .78346 .1768 L F P
0 g
s
.983 .905 .637 r
.78346 .1768 m .78317 .17398 L .78238 .17383 L p F P
0 g
s
.784 .543 0 r
.78475 .13514 m .78507 .13664 L .78436 .13178 L p F P
0 g
s
.784 .543 0 r
.78436 .13178 m .78417 .13089 L .78475 .13514 L p F P
0 g
s
.893 .83 .777 r
.62463 .15544 m .62846 .15012 L .63019 .15427 L p F P
0 g
s
.893 .83 .777 r
.63019 .15427 m .62728 .15827 L .62463 .15544 L p F P
0 g
s
.897 .789 .302 r
.59566 .26701 m .59567 .27161 L .59658 .26673 L p F P
0 g
s
.897 .789 .302 r
.59658 .26673 m .59649 .26216 L .59566 .26701 L p F P
0 g
s
.941 .864 .736 r
.61046 .19308 m .61363 .18744 L .61496 .19168 L p F P
0 g
s
.941 .864 .736 r
.6116 .19704 m .61046 .19308 L p .61496 .19168 L F P
0 g
s
.941 .864 .736 r
.61496 .19168 m .6118 .19717 L .6116 .19704 L p F P
0 g
s
.873 .811 .786 r
.63552 .13381 m .63741 .13792 L .64248 .1316 L p F P
0 g
s
.873 .811 .786 r
.64248 .1316 m .64051 .12751 L .63552 .13381 L p F P
0 g
s
.874 .812 .785 r
.64297 .12438 m .64051 .12751 L .64248 .1316 L p F P
0 g
s
.343 .518 .885 r
.7627 .08811 m .75593 .08627 L .75602 .08651 L p F P
0 g
s
.343 .518 .885 r
.76413 .09239 m .7627 .08811 L p .75602 .08651 L F P
0 g
s
.416 .566 .895 r
.75588 .08627 m .75593 .08627 L .75602 .08651 L closepath p F P
0 g
s
.723 .786 .902 r
.64873 .31651 m .63855 .32168 L .6359 .31856 L p F P
0 g
s
.689 .776 .917 r
.62505 .32303 m .6359 .31856 L .63855 .32168 L p F P
0 g
s
.802 .856 .891 r
.69339 .29587 m .6869 .30068 L .68437 .29828 L p F P
0 g
s
.729 .758 .875 r
.70364 .07759 m .69888 .08023 L .69632 .07646 L p F P
0 g
s
.762 .768 .858 r
.68551 .08378 m .69632 .07646 L .69888 .08023 L p F P
0 g
s
.423 .573 .898 r
.75593 .08627 m .75588 .08627 L .75336 .08192 L p F P
0 g
s
.423 .573 .898 r
.75336 .08192 m .7543 .08206 L .75593 .08627 L p F P
0 g
s
.362 .531 .889 r
.7612 .08383 m .7627 .08811 L .75593 .08627 L p F P
0 g
s
.362 .531 .889 r
.75593 .08627 m .7543 .08206 L .7612 .08383 L p F P
0 g
s
0 0 .574 r
.77551 .10668 m .77808 .11278 L .77914 .11437 L p F P
0 g
s
.81 .693 .152 r
.59523 .27173 m .59519 .27634 L .59567 .27161 L p F P
0 g
s
0 0 .053 r
.59519 .27634 m .59523 .27173 L .59529 .2737 L p F P
0 g
s
.751 .663 .109 r
.59516 .27708 m .59553 .27375 L p .59519 .27634 L F P
0 g
s
0 0 .053 r
.59529 .2737 m .59536 .27626 L p .59519 .27634 L F P
0 g
s
.751 .663 .109 r
.59519 .27634 m .59511 .27754 L .59516 .27708 L p F P
0 g
s
.751 .663 .109 r
.59553 .27375 m .59567 .27161 L .59519 .27634 L p F P
0 g
s
.563 .667 .908 r
.7402 .0782 m .73949 .07828 L .73697 .07421 L p F P
0 g
s
.935 .912 .772 r
.76694 .21289 m .7694 .20921 L .7697 .21368 L p F P
0 g
s
.935 .912 .772 r
.7697 .21368 m .76923 .21439 L .76694 .21289 L p F P
0 g
s
.919 .848 .758 r
.61686 .17461 m .61857 .17193 L .62004 .17614 L p F P
0 g
s
.919 .848 .758 r
.62004 .17614 m .61951 .17696 L .61686 .17461 L p F P
0 g
s
.677 .765 .917 r
.6359 .31856 m .62505 .32303 L .62236 .31947 L p F P
0 g
s
.932 .916 .778 r
.76548 .21977 m .76923 .21439 L .76694 .21289 L p F P
0 g
s
.801 .553 0 r
.78372 .13079 m .78475 .13514 L .78417 .13089 L p F P
0 g
s
.801 .553 0 r
.78417 .13089 m .78314 .12654 L .78372 .13079 L p F P
0 g
s
.895 .91 .827 r
.75083 .243 m .75047 .24342 L .75048 .24275 L closepath p F P
0 g
s
.935 .842 .728 r
.61679 .1818 m .61951 .17696 L .61686 .17461 L p F P
0 g
s
.38 .489 .845 r
.60318 .30729 m .60101 .30627 L .60042 .31099 L p F P
0 g
s
.38 .489 .845 r
.60042 .31099 m .60597 .31277 L .60318 .30729 L p F P
0 g
s
.88 .9 .84 r
.74435 .24565 m .74431 .2502 L .75047 .24342 L p F P
0 g
s
.88 .9 .84 r
.74846 .24112 m .74435 .24565 L p .75047 .24342 L F P
0 g
s
.88 .9 .84 r
.75047 .24342 m .75048 .24275 L .74846 .24112 L p F P
0 g
s
.911 .827 .751 r
.626 .16027 m .62728 .15827 L .62463 .15544 L p F P
0 g
s
.714 .569 0 r
.59521 .28204 m .59532 .28544 L .59521 .28091 L p F P
0 g
s
.714 .569 0 r
.59521 .28091 m .59511 .27754 L .59521 .28204 L p F P
0 g
s
.563 .667 .908 r
.73697 .07421 m .73834 .07405 L .7402 .0782 L p F P
0 g
s
.533 .641 .902 r
.74831 .07336 m .73834 .07405 L .7402 .0782 L p F P
0 g
s
.533 .641 .902 r
.7402 .0782 m .75084 .07762 L .74831 .07336 L p F P
0 g
s
.805 .863 .891 r
.69339 .29587 m .69764 .29265 L .69513 .29034 L p F P
0 g
s
.805 .863 .891 r
.69513 .29034 m .69404 .29116 L .69339 .29587 L p F P
0 g
s
.802 .856 .891 r
.68437 .29828 m .69404 .29116 L .69339 .29587 L p F P
0 g
s
.856 .887 .859 r
.7305 .26578 m .72971 .2651 L .73056 .26428 L closepath p F P
0 g
s
.977 .824 .418 r
.78438 .15345 m .78513 .15786 L .78597 .15306 L p F P
0 g
s
.977 .824 .418 r
.78597 .15306 m .78524 .14864 L .78438 .15345 L p F P
0 g
s
.768 .827 .899 r
.66704 .30992 m .66279 .31261 L .6602 .30991 L p F P
0 g
s
.751 .824 .909 r
.64938 .31618 m .6602 .30991 L .66279 .31261 L p F P
0 g
s
.81 .79 .834 r
.66574 .10035 m .66413 .10177 L .66151 .0982 L p F P
0 g
s
.835 .796 .814 r
.65852 .10748 m .66413 .10177 L .66151 .0982 L p F P
0 g
s
.872 .817 .792 r
.63245 .13765 m .63552 .13381 L .63741 .13792 L p F P
0 g
s
.872 .817 .792 r
.63741 .13792 m .6351 .14078 L .63245 .13765 L p F P
0 g
s
.966 .918 .705 r
.77706 .19639 m .77644 .19756 L .77634 .19611 L closepath p F P
0 g
s
.812 .786 .828 r
.6637 .09625 m .66574 .10035 L .67423 .09273 L p F P
0 g
s
.81 .79 .834 r
.66151 .0982 m .6637 .09625 L .66574 .10035 L p F P
0 g
s
.126 .23 .703 r
.60111 .30288 m .60101 .30627 L .59736 .30296 L p F P
0 g
s
.126 .23 .703 r
.60037 .30108 m .60111 .30288 L p .59736 .30296 L F P
0 g
s
.126 .23 .703 r
.59736 .30296 m .59781 .29827 L .60037 .30108 L p F P
0 g
s
.816 .866 .884 r
.7042 .28744 m .69764 .29265 L .69513 .29034 L p F P
0 g
s
.814 .787 .827 r
.67423 .09273 m .67479 .09222 L .67219 .08855 L p F P
0 g
s
.814 .787 .827 r
.67219 .08855 m .67206 .08867 L .67423 .09273 L p F P
0 g
s
.812 .786 .828 r
.67423 .09273 m .67206 .08867 L .6637 .09625 L p F P
0 g
s
.789 .781 .845 r
.68491 .08426 m .67479 .09222 L .67219 .08855 L p F P
0 g
s
.911 .827 .751 r
.62463 .15544 m .62417 .15617 L .626 .16027 L p F P
0 g
s
.913 .827 .748 r
.62056 .16196 m .62231 .16609 L .626 .16027 L p F P
0 g
s
.913 .827 .748 r
.626 .16027 m .62417 .15617 L .62056 .16196 L p F P
0 g
s
.732 .757 .872 r
.70364 .07759 m .70977 .07416 L .70721 .07031 L p F P
0 g
s
.732 .757 .872 r
.70721 .07031 m .70167 .07346 L .70364 .07759 L p F P
0 g
s
.729 .758 .875 r
.69632 .07646 m .70167 .07346 L .70364 .07759 L p F P
0 g
s
.889 .898 .829 r
.75048 .24275 m .74846 .24112 L .75041 .23889 L closepath p F P
0 g
s
.878 .897 .842 r
.73792 .25254 m .74435 .24565 L .74431 .2502 L p F P
0 g
s
.878 .897 .842 r
.73792 .25256 m .73792 .25254 L p .74431 .2502 L F P
0 g
s
.878 .897 .842 r
.74431 .2502 m .7403 .25448 L .73792 .25256 L p F P
0 g
s
.987 .876 .63 r
.60069 .22857 m .60161 .2329 L .60369 .22763 L p F P
0 g
s
.987 .876 .63 r
.60369 .22763 m .60268 .22333 L .60069 .22857 L p F P
0 g
s
0 0 .211 r
.78203 .1222 m .78314 .12654 L .78201 .1225 L p F P
0 g
s
0 0 .211 r
.78201 .1225 m .78089 .11817 L .78203 .1222 L p F P
0 g
s
.835 .796 .814 r
.66151 .0982 m .65643 .10341 L .65852 .10748 L p F P
0 g
s
.831 .797 .819 r
.65089 .10897 m .65643 .10341 L .65852 .10748 L p F P
0 g
s
.831 .797 .819 r
.65852 .10748 m .65352 .11247 L .65089 .10897 L p F P
0 g
s
.952 .916 .741 r
.77272 .19885 m .77307 .20333 L .77644 .19756 L p F P
0 g
s
.952 .916 .741 r
.77481 .19526 m .77272 .19885 L p .77644 .19756 L F P
0 g
s
.952 .916 .741 r
.77644 .19756 m .77634 .19611 L .77481 .19526 L p F P
0 g
s
.987 .896 .583 r
.59786 .24332 m .59966 .23813 L .6002 .24259 L p F P
0 g
s
.987 .896 .583 r
.59814 .24597 m .59786 .24332 L p .6002 .24259 L F P
0 g
s
.987 .896 .583 r
.6002 .24259 m .5992 .24538 L .59814 .24597 L p F P
0 g
s
.969 .875 .688 r
.60391 .21368 m .60492 .21801 L .60757 .21254 L p F P
0 g
s
.969 .875 .688 r
.60757 .21254 m .60646 .20825 L .60391 .21368 L p F P
0 g
s
.249 .44 .853 r
.7682 .09146 m .76926 .09486 L .76413 .09239 L p F P
0 g
s
.249 .44 .853 r
.76766 .0904 m .7682 .09146 L p .76413 .09239 L F P
0 g
s
.249 .44 .853 r
.76413 .09239 m .7627 .08811 L .76766 .0904 L p F P
0 g
s
.508 .599 .879 r
.60736 .31764 m .60752 .31562 L .60873 .31768 L closepath p F P
0 g
s
.892 .817 .767 r
.63276 .14409 m .6351 .14078 L .63245 .13765 L p F P
0 g
s
.952 .853 .708 r
.6118 .19717 m .61171 .19735 L .6116 .19704 L closepath p F P
0 g
s
.702 .568 .7 r
.41141 .90543 m .41382 .9032 L .41075 .90324 L closepath p F P
0 g
s
.702 .575 .71 r
.41382 .9032 m .41075 .90324 L .40853 .89633 L p F P
0 g
s
.707 .572 .7 r
.41075 .90324 m .41141 .90543 L .40606 .91059 L p F P
0 g
s
.707 .572 .7 r
.40096 .90324 m .41075 .90324 L p .40606 .91059 L F P
0 g
s
.707 .578 .708 r
.41075 .90324 m .40853 .89633 L .40096 .90324 L closepath p F P
0 g
s
.707 .572 .7 r
.39787 .90623 m .40096 .90324 L p .40606 .91059 L F P
0 g
s
.708 .573 .7 r
.39787 .90623 m .40096 .90324 L .39695 .90322 L closepath p F P
0 g
s
.708 .581 .71 r
.40832 .89571 m .40853 .89633 L .40096 .90324 L p F P
0 g
s
.708 .581 .71 r
.39668 .89566 m .40832 .89571 L p .40096 .90324 L F P
0 g
s
.708 .581 .71 r
.39499 .89722 m .39668 .89566 L p .40096 .90324 L F P
0 g
s
.708 .581 .71 r
.40096 .90324 m .39695 .90322 L .39499 .89722 L p F P
0 g
s
.713 .577 .701 r
.39695 .90322 m .39787 .90623 L .39363 .91051 L p F P
0 g
s
.713 .577 .701 r
.38885 .90307 m .39695 .90322 L p .39363 .91051 L F P
0 g
s
.713 .583 .708 r
.39695 .90322 m .39499 .89722 L .38885 .90307 L closepath p F P
0 g
s
.702 .575 .71 r
.40853 .89633 m .40925 .8957 L p .41382 .9032 L F P
0 g
s
.703 .576 .71 r
.40853 .89633 m .40925 .8957 L .40832 .89571 L closepath p F P
0 g
s
.703 .584 .719 r
.40925 .8957 m .40832 .89571 L .40565 .88796 L p F P
0 g
s
.708 .587 .717 r
.40558 .88796 m .40565 .88796 L .40832 .89571 L p F P
0 g
s
.708 .587 .717 r
.40832 .89571 m .39668 .89566 L .40558 .88796 L p F P
0 g
s
.702 .575 .71 r
.40925 .8957 m .42188 .89552 L p .41382 .9032 L F P
0 g
s
.702 .582 .717 r
.42188 .89552 m .40925 .8957 L .41881 .88782 L p F P
0 g
s
.703 .584 .719 r
.40565 .88796 m .41881 .88782 L .40925 .8957 L p F P
0 g
s
.958 .853 .696 r
.60765 .1986 m .60906 .2028 L .61171 .19735 L p F P
0 g
s
.958 .853 .696 r
.60915 .19546 m .60765 .1986 L p .61171 .19735 L F P
0 g
s
.958 .853 .696 r
.61171 .19735 m .6116 .19704 L .60915 .19546 L p F P
0 g
s
.701 .567 .7 r
.41382 .9032 m .42427 .90301 L p .41928 .91045 L F P
0 g
s
.701 .567 .7 r
.41141 .90543 m .41382 .9032 L p .41928 .91045 L F P
0 g
s
.701 .573 .708 r
.42427 .90301 m .42206 .89606 L .41382 .9032 L closepath p F P
0 g
s
.702 .575 .71 r
.42188 .89552 m .42206 .89606 L .41382 .9032 L p F P
0 g
s
.976 .893 .677 r
.60525 .21986 m .60415 .21967 L .60492 .21801 L closepath p F P
0 g
s
.821 .871 .883 r
.7042 .28744 m .70836 .28406 L .70588 .28183 L p F P
0 g
s
.821 .871 .883 r
.70588 .28183 m .70471 .28277 L .7042 .28744 L p F P
0 g
s
.816 .866 .884 r
.69513 .29034 m .70471 .28277 L .7042 .28744 L p F P
0 g
s
.706 .57 .699 r
.41295 .91057 m .41141 .90543 L .40606 .91059 L closepath p F P
0 g
s
.701 .567 .7 r
.41928 .91045 m .41295 .91057 L .41141 .90543 L p F P
0 g
s
.854 .8 .798 r
.6518 .11443 m .65352 .11247 L .65089 .10897 L p F P
0 g
s
.71 .582 .71 r
.39499 .89722 m .39668 .89566 L .39447 .89564 L closepath p F P
0 g
s
.71 .589 .719 r
.39324 .88786 m .40558 .88796 L .39668 .89566 L p F P
0 g
s
.71 .589 .719 r
.39209 .88886 m .39324 .88786 L p .39668 .89566 L F P
0 g
s
.71 .589 .719 r
.39668 .89566 m .39447 .89564 L .39209 .88886 L p F P
0 g
s
.714 .586 .71 r
.39447 .89564 m .39499 .89722 L .38885 .90307 L p F P
0 g
s
.707 .572 .7 r
.40606 .91059 m .3992 .91059 L .39787 .90623 L p F P
0 g
s
.712 .575 .699 r
.3992 .91059 m .39787 .90623 L .39363 .91051 L closepath p F P
0 g
s
.992 .88 .568 r
.78225 .16794 m .78295 .17235 L .78456 .16724 L p F P
0 g
s
.992 .88 .568 r
.78456 .16724 m .78388 .16283 L .78225 .16794 L p F P
0 g
s
.768 .833 .902 r
.66704 .30992 m .67358 .3057 L .67102 .30313 L p F P
0 g
s
.768 .833 .902 r
.67102 .30313 m .66776 .30519 L .66704 .30992 L p F P
0 g
s
.768 .827 .899 r
.6602 .30991 m .66776 .30519 L .66704 .30992 L p F P
0 g
s
.714 .586 .71 r
.38484 .89542 m .39447 .89564 L p .38885 .90307 L F P
0 g
s
.715 .592 .717 r
.39447 .89564 m .39209 .88886 L .38484 .89542 L closepath p F P
0 g
s
.871 .898 .849 r
.7403 .25448 m .73772 .25714 L .73792 .25256 L closepath p F P
0 g
s
.921 .911 .793 r
.76071 .22148 m .76094 .22596 L .76548 .21977 L p F P
0 g
s
.921 .911 .793 r
.76548 .21977 m .7653 .21525 L .76071 .22148 L p F P
0 g
s
.932 .916 .778 r
.76694 .21289 m .7653 .21525 L .76548 .21977 L p F P
0 g
s
.707 .564 .691 r
.40074 .91608 m .40606 .91059 L .3992 .91059 L closepath p F P
0 g
s
.712 .568 .691 r
.3992 .91059 m .40074 .91608 L .39919 .91774 L p F P
0 g
s
.712 .568 .691 r
.39363 .91051 m .3992 .91059 L p .39919 .91774 L F P
0 g
s
.706 .563 .691 r
.40606 .91059 m .41295 .91057 L p .41198 .91772 L F P
0 g
s
.706 .563 .691 r
.40074 .91608 m .40606 .91059 L p .41198 .91772 L F P
0 g
s
.713 .577 .701 r
.38432 .90767 m .38885 .90307 L p .39363 .91051 L F P
0 g
s
.715 .578 .701 r
.38432 .90767 m .38885 .90307 L .38285 .90294 L closepath p F P
0 g
s
.714 .586 .71 r
.38143 .89869 m .38484 .89542 L p .38885 .90307 L F P
0 g
s
.714 .586 .71 r
.38885 .90307 m .38285 .90294 L .38143 .89869 L p F P
0 g
s
.7 .559 .691 r
.41428 .91538 m .41928 .91045 L .41295 .91057 L closepath p F P
0 g
s
.706 .563 .691 r
.41295 .91057 m .41428 .91538 L .41198 .91772 L p F P
0 g
s
.977 .908 .67 r
.77832 .1831 m .77884 .18754 L .78132 .18211 L p F P
0 g
s
.977 .908 .67 r
.78132 .18211 m .78083 .17764 L .77832 .1831 L p F P
0 g
s
.971 .844 .436 r
.59605 .2577 m .59649 .26216 L .59765 .2572 L p F P
0 g
s
.971 .844 .436 r
.59765 .2572 m .59714 .25276 L .59605 .2577 L p F P
0 g
s
.697 .579 .719 r
.42273 .89549 m .42188 .89552 L .41926 .88781 L p F P
0 g
s
.702 .582 .717 r
.41881 .88782 m .41926 .88781 L .42188 .89552 L p F P
0 g
s
.697 .571 .71 r
.42206 .89606 m .42273 .89549 L .42188 .89552 L closepath p F P
0 g
s
.696 .57 .71 r
.42206 .89606 m .42273 .89549 L p .42765 .9029 L F P
0 g
s
.696 .57 .71 r
.42765 .9029 m .42427 .90301 L .42206 .89606 L p F P
0 g
s
.696 .562 .7 r
.42494 .90528 m .42765 .9029 L .42427 .90301 L closepath p F P
0 g
s
.701 .567 .7 r
.42427 .90301 m .42494 .90528 L .41928 .91045 L p F P
0 g
s
.696 .577 .717 r
.43517 .89508 m .43269 .8877 L .42273 .89549 L closepath p F P
0 g
s
.697 .579 .719 r
.43259 .88742 m .43269 .8877 L .42273 .89549 L p F P
0 g
s
.697 .579 .719 r
.41926 .88781 m .43259 .88742 L p .42273 .89549 L F P
0 g
s
.696 .57 .71 r
.42273 .89549 m .43517 .89508 L p .42765 .9029 L F P
0 g
s
.858 .889 .858 r
.73064 .25974 m .73056 .26428 L .73772 .25714 L p F P
0 g
s
.858 .889 .858 r
.73791 .25255 m .73064 .25974 L p .73772 .25714 L F P
0 g
s
.858 .889 .858 r
.73772 .25714 m .73792 .25256 L .73791 .25255 L p F P
0 g
s
.712 .568 .691 r
.38718 .91747 m .39363 .91051 L p .39919 .91774 L F P
0 g
s
.713 .569 .691 r
.38718 .91747 m .39363 .91051 L .38515 .91036 L closepath p F P
0 g
s
.713 .577 .701 r
.39363 .91051 m .38515 .91036 L .38432 .90767 L p F P
0 g
s
.83 .873 .876 r
.71384 .27942 m .70836 .28406 L .70588 .28183 L p F P
0 g
s
.854 .8 .798 r
.65089 .10897 m .64967 .11038 L .6518 .11443 L p F P
0 g
s
.853 .8 .799 r
.6439 .11697 m .64596 .12104 L .6518 .11443 L p F P
0 g
s
.853 .8 .799 r
.6518 .11443 m .64967 .11038 L .6439 .11697 L p F P
0 g
s
.947 .866 .726 r
.6116 .19704 m .60915 .19546 L .61046 .19308 L closepath p F P
0 g
s
.703 .591 .728 r
.41881 .88782 m .40565 .88796 L .40563 .88792 L p F P
0 g
s
.708 .594 .726 r
.40565 .88796 m .40563 .88792 L .40558 .88796 L closepath p F P
0 g
s
.708 .594 .726 r
.40272 .88002 m .39324 .88786 L .40558 .88796 L p F P
0 g
s
.708 .594 .726 r
.40558 .88796 m .40563 .88792 L .40272 .88002 L p F P
0 g
s
.703 .591 .728 r
.40563 .88792 m .41583 .87989 L p .41881 .88782 L F P
0 g
s
.705 .591 .726 r
.41583 .87989 m .40563 .88792 L .40272 .88002 L p F P
0 g
s
0 0 .574 r
.77914 .11437 m .77793 .11006 L p .77551 .10668 L F P
0 g
s
0 0 .419 r
.77969 .11385 m .78089 .11817 L .77914 .11437 L p F P
0 g
s
0 0 .419 r
.77914 .11437 m .77793 .11006 L .77969 .11385 L p F P
0 g
s
.699 .558 .691 r
.41928 .91045 m .42642 .9103 L p .42564 .91748 L F P
0 g
s
.699 .558 .691 r
.41428 .91538 m .41928 .91045 L p .42564 .91748 L F P
0 g
s
.699 .564 .699 r
.42642 .9103 m .42494 .90528 L .41928 .91045 L closepath p F P
0 g
s
.694 .561 .7 r
.42494 .90528 m .42765 .9029 L p .43352 .91005 L F P
0 g
s
.694 .561 .7 r
.43352 .91005 m .42642 .9103 L .42494 .90528 L p F P
0 g
s
.719 .583 .701 r
.38285 .90294 m .38432 .90767 L .38186 .91025 L p F P
0 g
s
.719 .583 .701 r
.37736 .90274 m .38285 .90294 L p .38186 .91025 L F P
0 g
s
.72 .589 .708 r
.38285 .90294 m .38143 .89869 L .37736 .90274 L closepath p F P
0 g
s
.716 .587 .71 r
.38143 .89869 m .38484 .89542 L .3803 .8953 L closepath p F P
0 g
s
.716 .594 .719 r
.39172 .88784 m .39209 .88886 L .38484 .89542 L p F P
0 g
s
.716 .594 .719 r
.3816 .88756 m .39172 .88784 L p .38484 .89542 L F P
0 g
s
.716 .594 .719 r
.37852 .89036 m .3816 .88756 L p .38484 .89542 L F P
0 g
s
.716 .594 .719 r
.38484 .89542 m .3803 .8953 L .37852 .89036 L p F P
0 g
s
.789 .781 .845 r
.67219 .08855 m .68272 .08021 L .68491 .08426 L p F P
0 g
s
.792 .778 .841 r
.68491 .08426 m .68551 .08378 L .68293 .08004 L p F P
0 g
s
.792 .778 .841 r
.68293 .08004 m .68272 .08021 L .68491 .08426 L p F P
0 g
s
.694 .561 .7 r
.42765 .9029 m .43751 .90254 L p .43352 .91005 L F P
0 g
s
.695 .568 .708 r
.43751 .90254 m .43558 .89638 L .42765 .9029 L closepath p F P
0 g
s
.696 .57 .71 r
.43517 .89508 m .43558 .89638 L .42765 .9029 L p F P
0 g
s
.711 .59 .719 r
.39209 .88886 m .39324 .88786 L .39172 .88784 L closepath p F P
0 g
s
.718 .58 .699 r
.38515 .91036 m .38432 .90767 L .38186 .91025 L closepath p F P
0 g
s
.711 .597 .728 r
.4027 .87998 m .40272 .88002 L .39324 .88786 L p F P
0 g
s
.711 .597 .728 r
.39062 .87982 m .4027 .87998 L p .39324 .88786 L F P
0 g
s
.711 .597 .728 r
.38917 .88103 m .39062 .87982 L p .39324 .88786 L F P
0 g
s
.711 .597 .728 r
.39324 .88786 m .39172 .88784 L .38917 .88103 L p F P
0 g
s
.763 .767 .857 r
.69632 .07646 m .68551 .08378 L .68293 .08004 L p F P
0 g
s
.72 .591 .711 r
.3803 .8953 m .38143 .89869 L .37736 .90274 L p F P
0 g
s
.716 .6 .726 r
.39172 .88784 m .38917 .88103 L .3816 .88756 L closepath p F P
0 g
s
.717 .572 .69 r
.38515 .91036 m .38186 .91025 L p .38709 .91758 L F P
0 g
s
.717 .572 .69 r
.38709 .91758 m .38718 .91747 L .38515 .91036 L p F P
0 g
s
.104 .314 .788 r
.77024 .09555 m .76926 .09486 L .77051 .09919 L p F P
0 g
s
.104 .314 .788 r
.77051 .09919 m .77282 .10092 L .77024 .09555 L p F P
0 g
s
.702 .589 .726 r
.41926 .88781 m .41916 .88755 L .41881 .88782 L closepath p F P
0 g
s
.703 .591 .728 r
.41638 .87988 m .41916 .88755 L .41881 .88782 L p F P
0 g
s
.703 .591 .728 r
.41583 .87989 m .41638 .87988 L p .41881 .88782 L F P
0 g
s
.935 .842 .728 r
.61686 .17461 m .61517 .17765 L .61679 .1818 L p F P
0 g
s
.937 .842 .725 r
.61209 .18326 m .61363 .18744 L .61679 .1818 L p F P
0 g
s
.937 .842 .725 r
.61679 .1818 m .61517 .17765 L .61209 .18326 L p F P
0 g
s
.698 .587 .727 r
.42978 .87958 m .43259 .88742 L .41926 .88781 L p F P
0 g
s
.698 .587 .727 r
.41926 .88781 m .41916 .88755 L .42978 .87958 L p F P
0 g
s
0 .177 .706 r
.77542 .1065 m .77547 .10654 L .77551 .10668 L closepath p F P
0 g
s
0 0 .574 r
.77793 .11006 m .77547 .10654 L .77551 .10668 L p F P
0 g
s
.706 .563 .691 r
.41198 .91772 m .40121 .91776 L .40074 .91608 L p F P
0 g
s
.711 .566 .689 r
.40121 .91776 m .40074 .91608 L .39919 .91774 L closepath p F P
0 g
s
.835 .878 .874 r
.71384 .27942 m .71905 .27489 L .7166 .27271 L p F P
0 g
s
.835 .878 .874 r
.7166 .27271 m .71419 .2748 L .71384 .27942 L p F P
0 g
s
.83 .873 .876 r
.70588 .28183 m .71419 .2748 L .71384 .27942 L p F P
0 g
s
.699 .587 .728 r
.42977 .87953 m .42978 .87958 L .41916 .88755 L p F P
0 g
s
.699 .587 .728 r
.41916 .88755 m .41638 .87988 L .42977 .87953 L p F P
0 g
s
.72 .591 .711 r
.37357 .89502 m .3803 .8953 L p .37736 .90274 L F P
0 g
s
.721 .597 .717 r
.3803 .8953 m .37852 .89036 L .37357 .89502 L closepath p F P
0 g
s
.699 .558 .691 r
.42564 .91748 m .41492 .9177 L .41428 .91538 L p F P
0 g
s
.704 .561 .689 r
.41492 .9177 m .41428 .91538 L .41198 .91772 L closepath p F P
0 g
s
.694 .553 .691 r
.4278 .91537 m .43352 .91005 L .42642 .9103 L closepath p F P
0 g
s
.699 .558 .691 r
.42642 .9103 m .4278 .91537 L .42564 .91748 L p F P
0 g
s
0 .191 .717 r
.77547 .10654 m .77542 .1065 L .77282 .10092 L p F P
0 g
s
.894 .675 .161 r
.78484 .13959 m .78499 .14028 L .78507 .13664 L p F P
0 g
s
.894 .675 .161 r
.78507 .13664 m .78475 .13514 L .78484 .13959 L p F P
0 g
s
0 0 .502 r
.5978 .29417 m .59781 .29827 L .59596 .29434 L p F P
0 g
s
0 0 .502 r
.59751 .29316 m .5978 .29417 L p .59596 .29434 L F P
0 g
s
0 0 .502 r
.59596 .29434 m .5961 .28974 L .59751 .29316 L p F P
0 g
s
.717 .572 .69 r
.38186 .91025 m .37572 .91721 L .38709 .91758 L p F P
0 g
s
.72 .574 .69 r
.37078 .90986 m .38186 .91025 L .37572 .91721 L p F P
0 g
s
.719 .583 .701 r
.37074 .90972 m .37736 .90274 L p .38186 .91025 L F P
0 g
s
.719 .583 .701 r
.38186 .91025 m .37078 .90986 L .37074 .90972 L p F P
0 g
s
.705 .554 .68 r
.40121 .91776 m .41198 .91772 L .4057 .92472 L p F P
0 g
s
.705 .554 .68 r
.4057 .92472 m .40298 .92473 L .40121 .91776 L p F P
0 g
s
.71 .557 .679 r
.39919 .91774 m .40121 .91776 L .40298 .92473 L p F P
0 g
s
.855 .883 .858 r
.72728 .26297 m .73064 .25974 L .73056 .26428 L p F P
0 g
s
.855 .883 .858 r
.73056 .26428 m .72971 .2651 L .72728 .26297 L p F P
0 g
s
.721 .584 .701 r
.37074 .90972 m .37736 .90274 L .36841 .90238 L closepath p F P
0 g
s
.72 .591 .711 r
.36785 .90073 m .37357 .89502 L p .37736 .90274 L F P
0 g
s
.72 .591 .711 r
.37736 .90274 m .36841 .90238 L .36785 .90073 L p F P
0 g
s
0 .191 .717 r
.77282 .10092 m .77414 .10225 L .77547 .10654 L p F P
0 g
s
0 .028 .599 r
.77663 .10576 m .77793 .11006 L .77547 .10654 L p F P
0 g
s
0 .028 .599 r
.77547 .10654 m .77414 .10225 L .77663 .10576 L p F P
0 g
s
.892 .817 .767 r
.63245 .13765 m .63079 .14001 L .63276 .14409 L p F P
0 g
s
.892 .817 .767 r
.62657 .14603 m .62846 .15012 L .63276 .14409 L p F P
0 g
s
.892 .817 .767 r
.63276 .14409 m .63079 .14001 L .62657 .14603 L p F P
0 g
s
.71 .557 .679 r
.40298 .92473 m .39331 .92463 L .39919 .91774 L p F P
0 g
s
.712 .559 .68 r
.38721 .91758 m .39919 .91774 L .39331 .92463 L p F P
0 g
s
.712 .568 .691 r
.39919 .91774 m .38721 .91758 L .38718 .91747 L p F P
0 g
s
.849 .883 .864 r
.72256 .27172 m .72971 .2651 L .72728 .26297 L p F P
0 g
s
.591 .696 .916 r
.60873 .31768 m .61965 .31575 L .62236 .31947 L p F P
0 g
s
.597 .643 .867 r
.60752 .31562 m .60873 .31768 L .61965 .31575 L p F P
0 g
s
.843 .879 .867 r
.72256 .27172 m .71905 .27489 L .7166 .27271 L p F P
0 g
s
.704 .552 .679 r
.41198 .91772 m .41492 .9177 L .41666 .92465 L p F P
0 g
s
.704 .552 .679 r
.41666 .92465 m .4057 .92472 L .41198 .91772 L p F P
0 g
s
.849 .883 .864 r
.72728 .26297 m .72277 .26714 L .72256 .27172 L p F P
0 g
s
.843 .879 .867 r
.7166 .27271 m .72277 .26714 L .72256 .27172 L p F P
0 g
s
.699 .549 .68 r
.41492 .9177 m .42564 .91748 L .4189 .9246 L p F P
0 g
s
.699 .549 .68 r
.4189 .9246 m .41666 .92465 L .41492 .9177 L p F P
0 g
s
.95 .771 .313 r
.78444 .14423 m .78524 .14864 L .78566 .144 L p F P
0 g
s
.95 .771 .313 r
.78473 .14106 m .78444 .14423 L p .78566 .144 L F P
0 g
s
.95 .771 .313 r
.78566 .144 m .78499 .14028 L .78473 .14106 L p F P
0 g
s
.987 .895 .621 r
.78317 .17398 m .78238 .17383 L .78295 .17235 L closepath p F P
0 g
s
.81 .693 .152 r
.59567 .27161 m .59566 .26701 L .59523 .27173 L p F P
0 g
s
.691 .574 .719 r
.43736 .89498 m .43517 .89508 L .43269 .8877 L p F P
0 g
s
.691 .566 .71 r
.43558 .89638 m .43736 .89498 L .43517 .89508 L closepath p F P
0 g
s
.717 .595 .719 r
.37852 .89036 m .3816 .88756 L .37748 .88743 L closepath p F P
0 g
s
.721 .6 .72 r
.37748 .88743 m .37852 .89036 L .37357 .89502 L p F P
0 g
s
.69 .565 .71 r
.43558 .89638 m .43736 .89498 L p .44268 .90228 L F P
0 g
s
.69 .565 .71 r
.44268 .90228 m .43751 .90254 L .43558 .89638 L p F P
0 g
s
.716 .602 .728 r
.3887 .87979 m .38917 .88103 L .3816 .88756 L p F P
0 g
s
.716 .602 .728 r
.37912 .87948 m .3887 .87979 L p .3816 .88756 L F P
0 g
s
.716 .602 .728 r
.3756 .88253 m .37912 .87948 L p .3816 .88756 L F P
0 g
s
.716 .602 .728 r
.3816 .88756 m .37748 .88743 L .3756 .88253 L p F P
0 g
s
.717 .571 .69 r
.38721 .91758 m .38718 .91747 L .38709 .91758 L closepath p F P
0 g
s
.712 .559 .68 r
.39331 .92463 m .38901 .92458 L .38721 .91758 L p F P
0 g
s
.717 .562 .678 r
.38709 .91758 m .38721 .91758 L .38901 .92458 L p F P
0 g
s
.717 .562 .678 r
.38901 .92458 m .38158 .92437 L .38709 .91758 L p F P
0 g
s
.718 .565 .68 r
.37572 .91721 m .38709 .91758 L .38158 .92437 L p F P
0 g
s
.689 .557 .701 r
.43846 .90577 m .44268 .90228 L .43751 .90254 L closepath p F P
0 g
s
.694 .561 .7 r
.43751 .90254 m .43846 .90577 L .43352 .91005 L p F P
0 g
s
.721 .6 .72 r
.37051 .88711 m .37748 .88743 L p .37357 .89502 L F P
0 g
s
.721 .6 .72 r
.36494 .89238 m .37051 .88711 L p .37357 .89502 L F P
0 g
s
.721 .6 .72 r
.37357 .89502 m .36578 .89468 L .36494 .89238 L p F P
0 g
s
.722 .592 .71 r
.36785 .90073 m .37357 .89502 L .36578 .89468 L closepath p F P
0 g
s
.693 .552 .691 r
.43352 .91005 m .43964 .9098 L p .44036 .91694 L F P
0 g
s
.693 .552 .691 r
.4278 .91537 m .43352 .91005 L p .44036 .91694 L F P
0 g
s
.693 .559 .699 r
.43964 .9098 m .43846 .90577 L .43352 .91005 L closepath p F P
0 g
s
.706 .593 .728 r
.40272 .88002 m .40278 .87998 L .4027 .87998 L closepath p F P
0 g
s
.705 .591 .726 r
.40272 .88002 m .40278 .87998 L .41583 .87989 L p F P
0 g
s
.706 .601 .736 r
.40278 .87998 m .4027 .87998 L .39979 .87256 L p F P
0 g
s
.711 .603 .735 r
.4027 .87998 m .39979 .87256 L .39062 .87982 L closepath p F P
0 g
s
.704 .598 .735 r
.41334 .872 m .40278 .87998 L .41583 .87989 L p F P
0 g
s
.706 .601 .736 r
.41323 .87171 m .41334 .872 L .40278 .87998 L p F P
0 g
s
.706 .601 .736 r
.40087 .87174 m .41323 .87171 L p .40278 .87998 L F P
0 g
s
.706 .601 .736 r
.39979 .87256 m .40087 .87174 L p .40278 .87998 L F P
0 g
s
.693 .552 .691 r
.44036 .91694 m .42836 .91741 L .4278 .91537 L p F P
0 g
s
.698 .556 .689 r
.42836 .91741 m .4278 .91537 L .42564 .91748 L closepath p F P
0 g
s
.69 .572 .718 r
.4482 .89442 m .44621 .88842 L .43736 .89498 L closepath p F P
0 g
s
.691 .574 .719 r
.44566 .88678 m .44621 .88842 L .43736 .89498 L p F P
0 g
s
.691 .574 .719 r
.43308 .8874 m .44566 .88678 L p .43736 .89498 L F P
0 g
s
.691 .574 .719 r
.43269 .8877 m .43308 .8874 L p .43736 .89498 L F P
0 g
s
.69 .565 .71 r
.43736 .89498 m .4482 .89442 L p .44268 .90228 L F P
0 g
s
.727 .804 .912 r
.64938 .31618 m .64873 .31651 L .64897 .31572 L closepath p F P
0 g
s
.723 .786 .902 r
.64675 .31325 m .64897 .31572 L .64873 .31651 L p F P
0 g
s
.723 .786 .902 r
.6359 .31856 m .64675 .31325 L p .64873 .31651 L F P
0 g
s
.633 .703 .896 r
.7233 .07331 m .73444 .07016 L .73697 .07421 L p F P
0 g
s
.637 .706 .896 r
.73444 .07016 m .7233 .07331 L .72076 .06938 L p F P
0 g
s
.69 .734 .885 r
.70977 .07416 m .72076 .06938 L .7233 .07331 L p F P
0 g
s
.722 .605 .726 r
.37748 .88743 m .3756 .88253 L .37051 .88711 L closepath p F P
0 g
s
.697 .547 .679 r
.42564 .91748 m .42836 .91741 L .43007 .92432 L p F P
0 g
s
.697 .547 .679 r
.43007 .92432 m .4189 .9246 L .42564 .91748 L p F P
0 g
s
.692 .575 .719 r
.43269 .8877 m .43308 .8874 L .43259 .88742 L closepath p F P
0 g
s
.994 .873 .561 r
.5992 .24538 m .59847 .24774 L .59814 .24597 L closepath p F P
0 g
s
.692 .583 .728 r
.43308 .8874 m .43259 .88742 L .42978 .87958 L p F P
0 g
s
.688 .557 .7 r
.43846 .90577 m .44268 .90228 L p .44904 .9093 L F P
0 g
s
.688 .557 .7 r
.44904 .9093 m .43964 .9098 L .43846 .90577 L p F P
0 g
s
.703 .597 .734 r
.41638 .87988 m .41625 .87957 L .41583 .87989 L closepath p F P
0 g
s
.704 .598 .735 r
.41583 .87989 m .41625 .87957 L .41334 .872 L p F P
0 g
s
.692 .583 .728 r
.44289 .87894 m .44331 .88014 L .43308 .8874 L p F P
0 g
s
.692 .583 .728 r
.42985 .87953 m .44289 .87894 L p .43308 .8874 L F P
0 g
s
.692 .583 .728 r
.42978 .87958 m .42985 .87953 L p .43308 .8874 L F P
0 g
s
.691 .58 .726 r
.44566 .88678 m .44331 .88014 L .43308 .8874 L closepath p F P
0 g
s
.699 .595 .736 r
.42687 .87192 m .42977 .87953 L .41638 .87988 L p F P
0 g
s
.699 .595 .736 r
.41638 .87988 m .41625 .87957 L .42687 .87192 L p F P
0 g
s
.692 .735 .884 r
.72076 .06938 m .70977 .07416 L .70721 .07031 L p F P
0 g
s
.712 .598 .728 r
.38917 .88103 m .39062 .87982 L .3887 .87979 L closepath p F P
0 g
s
.7 .594 .735 r
.42687 .87192 m .41625 .87957 L .41334 .872 L p F P
0 g
s
.692 .543 .68 r
.42836 .91741 m .44036 .91694 L .43311 .92421 L p F P
0 g
s
.692 .543 .68 r
.43311 .92421 m .43007 .92432 L .42836 .91741 L p F P
0 g
s
.725 .586 .7 r
.36841 .90238 m .36636 .90227 L p .37062 .90986 L F P
0 g
s
.725 .586 .7 r
.37062 .90986 m .37074 .90972 L .36841 .90238 L p F P
0 g
s
.726 .594 .709 r
.36841 .90238 m .36785 .90073 L .36636 .90227 L closepath p F P
0 g
s
.851 .804 .804 r
.64032 .12099 m .6439 .11697 L .64596 .12104 L p F P
0 g
s
.851 .804 .804 r
.64596 .12104 m .64297 .12438 L .64032 .12099 L p F P
0 g
s
.711 .605 .737 r
.39947 .87174 m .39979 .87256 L .39062 .87982 L p F P
0 g
s
.711 .605 .737 r
.38882 .87156 m .39947 .87174 L p .39062 .87982 L F P
0 g
s
.711 .605 .737 r
.38624 .87361 m .38882 .87156 L p .39062 .87982 L F P
0 g
s
.711 .605 .737 r
.39062 .87982 m .3887 .87979 L .38624 .87361 L p F P
0 g
s
.749 .81 .901 r
.6576 .30714 m .6602 .30991 L .64938 .31618 L p F P
0 g
s
.749 .81 .901 r
.64922 .31187 m .6576 .30714 L p .64938 .31618 L F P
0 g
s
.749 .81 .901 r
.64938 .31618 m .64897 .31572 L .64922 .31187 L p F P
0 g
s
.914 .832 .75 r
.6169 .16778 m .61857 .17193 L .62231 .16609 L p F P
0 g
s
.914 .832 .75 r
.62231 .16609 m .62056 .16196 L .6169 .16778 L p F P
0 g
s
.724 .586 .7 r
.37078 .90986 m .37074 .90972 L .37062 .90986 L closepath p F P
0 g
s
.72 .574 .69 r
.37572 .91721 m .37287 .91711 L .37078 .90986 L p F P
0 g
s
.725 .577 .689 r
.37062 .90986 m .37078 .90986 L .37287 .91711 L p F P
0 g
s
.784 .841 .895 r
.68173 .30013 m .67358 .3057 L .67102 .30313 L p F P
0 g
s
.726 .58 .691 r
.36002 .90928 m .37062 .90986 L .36485 .91671 L p F P
0 g
s
.725 .586 .7 r
.36636 .90227 m .36002 .90928 L .37062 .90986 L p F P
0 g
s
.725 .577 .689 r
.37287 .91711 m .36485 .91671 L .37062 .90986 L p F P
0 g
s
.726 .594 .709 r
.36636 .90227 m .36785 .90073 L .36578 .89468 L p F P
0 g
s
.958 .909 .726 r
.77634 .19611 m .77481 .19526 L .77603 .1931 L closepath p F P
0 g
s
.716 .608 .735 r
.3887 .87979 m .38624 .87361 L .37912 .87948 L closepath p F P
0 g
s
.687 .548 .691 r
.44133 .91606 m .44904 .9093 L .43964 .9098 L closepath p F P
0 g
s
.693 .552 .691 r
.43964 .9098 m .44133 .91606 L .44036 .91694 L p F P
0 g
s
.688 .557 .7 r
.44268 .90228 m .45051 .90185 L p .44904 .9093 L F P
0 g
s
.688 .563 .709 r
.45051 .90185 m .4491 .8973 L .44268 .90228 L closepath p F P
0 g
s
.69 .565 .71 r
.4482 .89442 m .4491 .8973 L .44268 .90228 L p F P
0 g
s
.727 .589 .701 r
.35589 .90165 m .36636 .90227 L .36002 .90928 L p F P
0 g
s
.726 .594 .709 r
.36277 .8945 m .35589 .90165 L .36636 .90227 L p F P
0 g
s
.726 .594 .709 r
.36578 .89468 m .36277 .8945 L p .36636 .90227 L F P
0 g
s
.912 .905 .804 r
.75658 .22684 m .76071 .22148 L .76094 .22596 L p F P
0 g
s
.912 .905 .804 r
.76094 .22596 m .75892 .22857 L .75658 .22684 L p F P
0 g
s
.705 .545 .669 r
.40357 .92734 m .4057 .92472 L .40298 .92473 L closepath p F P
0 g
s
.71 .549 .669 r
.40298 .92473 m .40357 .92734 L .40034 .93148 L p F P
0 g
s
.71 .549 .669 r
.39331 .92463 m .40298 .92473 L p .40034 .93148 L F P
0 g
s
.727 .602 .718 r
.36578 .89468 m .36494 .89238 L .36277 .8945 L closepath p F P
0 g
s
.718 .565 .68 r
.37359 .91984 m .37572 .91721 L p .38158 .92437 L F P
0 g
s
.72 .566 .68 r
.37359 .91984 m .37572 .91721 L .37287 .91711 L closepath p F P
0 g
s
.703 .544 .669 r
.4057 .92472 m .41666 .92465 L p .41321 .93145 L F P
0 g
s
.703 .544 .669 r
.40357 .92734 m .4057 .92472 L p .41321 .93145 L F P
0 g
s
.723 .601 .719 r
.36494 .89238 m .37051 .88711 L .36287 .88674 L closepath p F P
0 g
s
.722 .608 .728 r
.37437 .87932 m .3756 .88253 L .37051 .88711 L p F P
0 g
s
.722 .608 .728 r
.36816 .879 m .37437 .87932 L p .37051 .88711 L F P
0 g
s
.722 .608 .728 r
.36202 .88453 m .36816 .879 L p .37051 .88711 L F P
0 g
s
.722 .608 .728 r
.37051 .88711 m .36287 .88674 L .36202 .88453 L p F P
0 g
s
.944 .912 .755 r
.76901 .20475 m .7694 .20921 L .77307 .20333 L p F P
0 g
s
.944 .912 .755 r
.77307 .20333 m .77272 .19885 L .76901 .20475 L p F P
0 g
s
.698 .539 .668 r
.41712 .92668 m .4189 .9246 L .41666 .92465 L closepath p F P
0 g
s
.703 .544 .669 r
.41666 .92465 m .41712 .92668 L .41321 .93145 L p F P
0 g
s
.718 .603 .728 r
.3756 .88253 m .37912 .87948 L .37437 .87932 L closepath p F P
0 g
s
.71 .549 .669 r
.39 .92889 m .39331 .92463 L p .40034 .93148 L F P
0 g
s
.711 .551 .669 r
.39 .92889 m .39331 .92463 L .38901 .92458 L closepath p F P
0 g
s
.872 .806 .782 r
.64051 .12751 m .64297 .12438 L .64032 .12099 L p F P
0 g
s
.724 .571 .681 r
.37287 .91711 m .37359 .91984 L .37037 .92396 L p F P
0 g
s
.724 .571 .681 r
.36485 .91671 m .37287 .91711 L p .37037 .92396 L F P
0 g
s
.693 .584 .728 r
.42978 .87958 m .42985 .87953 L .42977 .87953 L closepath p F P
0 g
s
.694 .591 .736 r
.42985 .87953 m .42977 .87953 L .42687 .87192 L p F P
0 g
s
.692 .589 .735 r
.44289 .87894 m .44041 .87233 L .42985 .87953 L closepath p F P
0 g
s
.694 .591 .736 r
.43985 .87086 m .44041 .87233 L .42985 .87953 L p F P
0 g
s
.694 .591 .736 r
.42767 .87137 m .43985 .87086 L p .42985 .87953 L F P
0 g
s
.694 .591 .736 r
.42687 .87192 m .42767 .87137 L p .42985 .87953 L F P
0 g
s
.727 .602 .718 r
.36277 .8945 m .36494 .89238 L .36287 .88674 L p F P
0 g
s
.697 .538 .668 r
.4189 .9246 m .43007 .92432 L p .42695 .93118 L F P
0 g
s
.697 .538 .668 r
.41712 .92668 m .4189 .9246 L p .42695 .93118 L F P
0 g
s
.715 .553 .668 r
.38901 .92458 m .38158 .92437 L p .38818 .93133 L F P
0 g
s
.715 .553 .668 r
.38818 .93133 m .39 .92889 L .38901 .92458 L p F P
0 g
s
.717 .61 .737 r
.38539 .87148 m .38624 .87361 L .37912 .87948 L p F P
0 g
s
.717 .61 .737 r
.37741 .87119 m .38539 .87148 L p .37912 .87948 L F P
0 g
s
.717 .61 .737 r
.37267 .87512 m .37741 .87119 L p .37912 .87948 L F P
0 g
s
.717 .61 .737 r
.37912 .87948 m .37437 .87932 L .37267 .87512 L p F P
0 g
s
.728 .598 .711 r
.35244 .89384 m .36277 .8945 L .35589 .90165 L p F P
0 g
s
.727 .602 .718 r
.35986 .88654 m .35244 .89384 L .36277 .8945 L p F P
0 g
s
.727 .602 .718 r
.36287 .88674 m .35986 .88654 L p .36277 .8945 L F P
0 g
s
.684 .561 .71 r
.4491 .8973 m .45346 .89407 L .4482 .89442 L closepath p F P
0 g
s
.685 .569 .719 r
.45346 .89407 m .4482 .89442 L .44621 .88842 L p F P
0 g
s
.687 .548 .691 r
.44155 .91689 m .44133 .91606 L .44904 .9093 L p F P
0 g
s
.691 .551 .69 r
.44155 .91689 m .44133 .91606 L .44036 .91694 L closepath p F P
0 g
s
.69 .541 .678 r
.44036 .91694 m .44155 .91689 L .44324 .92378 L p F P
0 g
s
.69 .541 .678 r
.44324 .92378 m .43311 .92421 L .44036 .91694 L p F P
0 g
s
.703 .544 .669 r
.41321 .93145 m .40452 .93151 L .40357 .92734 L p F P
0 g
s
.709 .547 .667 r
.40452 .93151 m .40357 .92734 L .40034 .93148 L closepath p F P
0 g
s
.43 .58 .901 r
.7543 .08206 m .75336 .08192 L .75084 .07762 L p F P
0 g
s
.718 .565 .68 r
.38158 .92437 m .37472 .92416 L .37359 .91984 L p F P
0 g
s
.723 .568 .679 r
.37472 .92416 m .37359 .91984 L .37037 .92396 L closepath p F P
0 g
s
.683 .561 .71 r
.4491 .8973 m .45346 .89407 L p .45926 .90124 L F P
0 g
s
.683 .561 .71 r
.45926 .90124 m .45051 .90185 L .4491 .8973 L p F P
0 g
s
.742 .804 .902 r
.64897 .31572 m .64675 .31325 L .64922 .31187 L closepath p F P
0 g
s
.973 .883 .682 r
.60151 .21891 m .60391 .21368 L .60492 .21801 L p F P
0 g
s
.973 .883 .682 r
.60492 .21801 m .60415 .21967 L .60151 .21891 L p F P
0 g
s
.707 .602 .736 r
.39979 .87256 m .40087 .87174 L .39947 .87174 L closepath p F P
0 g
s
.697 .538 .668 r
.42695 .93118 m .41817 .93139 L .41712 .92668 L p F P
0 g
s
.702 .541 .667 r
.41817 .93139 m .41712 .92668 L .41321 .93145 L closepath p F P
0 g
s
.992 .859 .509 r
.78312 .15843 m .78388 .16283 L .78513 .15786 L p F P
0 g
s
.992 .859 .509 r
.78513 .15786 m .78438 .15345 L .78312 .15843 L p F P
0 g
s
.722 .613 .735 r
.37437 .87932 m .37267 .87512 L .36816 .879 L closepath p F P
0 g
s
.685 .538 .68 r
.44155 .91689 m .4545 .91615 L p .44859 .92348 L F P
0 g
s
.685 .538 .68 r
.44859 .92348 m .44324 .92378 L .44155 .91689 L p F P
0 g
s
.687 .548 .691 r
.45261 .90909 m .4545 .91615 L .44155 .91689 L p F P
0 g
s
.687 .548 .691 r
.44904 .9093 m .45261 .90909 L p .44155 .91689 L F P
0 g
s
.682 .553 .701 r
.45198 .9069 m .45926 .90124 L .45051 .90185 L closepath p F P
0 g
s
.688 .557 .7 r
.45051 .90185 m .45198 .9069 L .44904 .9093 L p F P
0 g
s
.907 .908 .811 r
.75589 .23235 m .75892 .22857 L .75658 .22684 L p F P
0 g
s
.685 .569 .719 r
.44621 .88842 m .44881 .88658 L p .45346 .89407 L F P
0 g
s
.686 .57 .719 r
.44621 .88842 m .44881 .88658 L .44566 .88678 L closepath p F P
0 g
s
.715 .553 .668 r
.38158 .92437 m .3766 .93102 L .38818 .93133 L p F P
0 g
s
.718 .556 .67 r
.37472 .92416 m .38158 .92437 L .3766 .93102 L p F P
0 g
s
.528 .591 .861 r
.60597 .31277 m .60843 .31277 L .60752 .31562 L closepath p F P
0 g
s
.597 .643 .867 r
.61693 .31184 m .60843 .31277 L .60752 .31562 L p F P
0 g
s
.597 .643 .867 r
.61965 .31575 m .61693 .31184 L p .60752 .31562 L F P
0 g
s
.686 .578 .728 r
.44881 .88658 m .44566 .88678 L .44331 .88014 L p F P
0 g
s
.705 .606 .743 r
.41323 .87171 m .41041 .86482 L .40087 .87174 L closepath p F P
0 g
s
.706 .609 .745 r
.40978 .86327 m .41041 .86482 L .40087 .87174 L p F P
0 g
s
.706 .609 .745 r
.39986 .86325 m .40978 .86327 L p .40087 .87174 L F P
0 g
s
.706 .609 .745 r
.39686 .86545 m .39986 .86325 L p .40087 .87174 L F P
0 g
s
.706 .609 .745 r
.40087 .87174 m .39947 .87174 L .39686 .86545 L p F P
0 g
s
.711 .611 .743 r
.39947 .87174 m .39686 .86545 L .38882 .87156 L closepath p F P
0 g
s
.701 .597 .736 r
.41334 .872 m .41375 .8717 L .41323 .87171 L closepath p F P
0 g
s
.7 .594 .735 r
.42668 .87141 m .42687 .87192 L p .41334 .872 L F P
0 g
s
.7 .594 .735 r
.41334 .872 m .41375 .8717 L .42668 .87141 L p F P
0 g
s
.687 .555 .7 r
.45261 .90909 m .45198 .9069 L .44904 .9093 L closepath p F P
0 g
s
.991 .878 .61 r
.59883 .23377 m .59966 .23813 L .60161 .2329 L p F P
0 g
s
.991 .878 .61 r
.60161 .2329 m .60069 .22857 L .59883 .23377 L p F P
0 g
s
.691 .534 .669 r
.43065 .92691 m .43311 .92421 L .43007 .92432 L closepath p F P
0 g
s
.697 .538 .668 r
.43007 .92432 m .43065 .92691 L .42695 .93118 L p F P
0 g
s
.701 .604 .745 r
.41375 .8717 m .41323 .87171 L .41041 .86482 L p F P
0 g
s
.727 .61 .726 r
.36287 .88674 m .36202 .88453 L .35986 .88654 L closepath p F P
0 g
s
.701 .604 .745 r
.42331 .86303 m .42396 .86464 L .41375 .8717 L p F P
0 g
s
.701 .604 .745 r
.41269 .86323 m .42331 .86303 L p .41375 .8717 L F P
0 g
s
.701 .604 .745 r
.41041 .86482 m .41269 .86323 L p .41375 .8717 L F P
0 g
s
.699 .601 .743 r
.42668 .87141 m .42396 .86464 L .41375 .8717 L closepath p F P
0 g
s
.726 .58 .691 r
.35712 .91273 m .36002 .90928 L p .36485 .91671 L F P
0 g
s
.727 .581 .691 r
.35712 .91273 m .36002 .90928 L .35603 .90905 L closepath p F P
0 g
s
.727 .589 .701 r
.35424 .90349 m .35589 .90165 L p .36002 .90928 L F P
0 g
s
.727 .589 .701 r
.36002 .90928 m .35603 .90905 L .35424 .90349 L p F P
0 g
s
.962 .856 .689 r
.60513 .20402 m .60646 .20825 L .60906 .2028 L p F P
0 g
s
.962 .856 .689 r
.60906 .2028 m .60765 .1986 L .60513 .20402 L p F P
0 g
s
.713 .606 .736 r
.38624 .87361 m .38882 .87156 L .38539 .87148 L closepath p F P
0 g
s
.907 .682 .177 r
.78382 .13524 m .78484 .13959 L .78475 .13514 L p F P
0 g
s
.907 .682 .177 r
.78475 .13514 m .78372 .13079 L .78382 .13524 L p F P
0 g
s
0 0 .24 r
.59602 .28747 m .5961 .28974 L .59532 .28544 L p F P
0 g
s
0 0 .24 r
.59532 .28544 m .59521 .28204 L .59602 .28747 L p F P
0 g
s
.891 .823 .773 r
.62224 .15208 m .62657 .14603 L .62846 .15012 L p F P
0 g
s
.891 .823 .773 r
.62285 .15346 m .62224 .15208 L p .62846 .15012 L F P
0 g
s
.891 .823 .773 r
.62846 .15012 m .62463 .15544 L .62285 .15346 L p F P
0 g
s
.724 .571 .681 r
.35996 .92294 m .36485 .91671 L p .37037 .92396 L F P
0 g
s
.726 .572 .681 r
.35996 .92294 m .36485 .91671 L .35819 .91636 L closepath p F P
0 g
s
.726 .58 .691 r
.36485 .91671 m .35819 .91636 L .35712 .91273 L p F P
0 g
s
.871 .806 .782 r
.63348 .12974 m .63552 .13381 L .64051 .12751 L p F P
0 g
s
.871 .806 .782 r
.64051 .12751 m .63839 .12347 L .63348 .12974 L p F P
0 g
s
.872 .806 .782 r
.64032 .12099 m .63839 .12347 L .64051 .12751 L p F P
0 g
s
.682 .552 .701 r
.45261 .90909 m .45198 .9069 L .45926 .90124 L p F P
0 g
s
.69 .533 .669 r
.43311 .92421 m .44324 .92378 L p .44178 .93063 L F P
0 g
s
.69 .533 .669 r
.43065 .92691 m .43311 .92421 L p .44178 .93063 L F P
0 g
s
.728 .59 .701 r
.35424 .90349 m .35589 .90165 L .3536 .90151 L closepath p F P
0 g
s
.728 .598 .711 r
.35133 .895 m .35244 .89384 L p .35589 .90165 L F P
0 g
s
.728 .598 .711 r
.35589 .90165 m .3536 .90151 L .35133 .895 L p F P
0 g
s
.993 .861 .519 r
.59634 .24841 m .59714 .25276 L .59847 .24774 L p F P
0 g
s
.993 .861 .519 r
.59663 .24732 m .59634 .24841 L p .59847 .24774 L F P
0 g
s
.993 .861 .519 r
.59847 .24774 m .59814 .24597 L .59663 .24732 L p F P
0 g
s
.712 .613 .745 r
.39594 .86323 m .39686 .86545 L .38882 .87156 L p F P
0 g
s
.712 .613 .745 r
.38784 .86305 m .39594 .86323 L p .38882 .87156 L F P
0 g
s
.712 .613 .745 r
.3833 .86653 m .38784 .86305 L p .38882 .87156 L F P
0 g
s
.712 .613 .745 r
.38882 .87156 m .38539 .87148 L .3833 .86653 L p F P
0 g
s
.731 .757 .873 r
.70167 .07346 m .69632 .07646 L .69374 .07266 L p F P
0 g
s
.763 .767 .857 r
.68293 .08004 m .69374 .07266 L .69632 .07646 L p F P
0 g
s
.567 .67 .908 r
.73834 .07405 m .73697 .07421 L .73444 .07016 L p F P
0 g
s
.685 .569 .719 r
.44881 .88658 m .4585 .88592 L p .45346 .89407 L F P
0 g
s
.685 .576 .727 r
.4585 .88592 m .45685 .88121 L .44881 .88658 L closepath p F P
0 g
s
.686 .578 .728 r
.45576 .87811 m .45685 .88121 L .44881 .88658 L p F P
0 g
s
.686 .578 .728 r
.4453 .87879 m .45576 .87811 L p .44881 .88658 L F P
0 g
s
.686 .578 .728 r
.44331 .88014 m .4453 .87879 L p .44881 .88658 L F P
0 g
s
.718 .556 .67 r
.3766 .93102 m .37634 .93102 L .37472 .92416 L p F P
0 g
s
.723 .56 .668 r
.37037 .92396 m .37472 .92416 L .37634 .93102 L p F P
0 g
s
.968 .907 .7 r
.77548 .18867 m .77603 .1931 L .77884 .18754 L p F P
0 g
s
.968 .907 .7 r
.77884 .18754 m .77832 .1831 L .77548 .18867 L p F P
0 g
s
.724 .609 .728 r
.36202 .88453 m .36816 .879 L .35967 .87854 L closepath p F P
0 g
s
.728 .61 .727 r
.35986 .88654 m .36202 .88453 L .35967 .87854 L p F P
0 g
s
.71 .549 .669 r
.40034 .93148 m .39058 .93139 L .39 .92889 L p F P
0 g
s
.715 .553 .668 r
.39058 .93139 m .39 .92889 L .38818 .93133 L closepath p F P
0 g
s
.683 .561 .71 r
.45346 .89407 m .461 .89353 L p .45926 .90124 L F P
0 g
s
.683 .567 .718 r
.461 .89353 m .45974 .88969 L .45346 .89407 L closepath p F P
0 g
s
.685 .569 .719 r
.4585 .88592 m .45974 .88969 L .45346 .89407 L p F P
0 g
s
.712 .79 .913 r
.64675 .31325 m .6359 .31856 L .63324 .31534 L p F P
0 g
s
.677 .765 .917 r
.62236 .31947 m .63324 .31534 L .6359 .31856 L p F P
0 g
s
.681 .543 .691 r
.45261 .90909 m .46537 .90818 L p .45662 .916 L F P
0 g
s
.681 .543 .691 r
.45662 .916 m .4545 .91615 L .45261 .90909 L p F P
0 g
s
.682 .552 .701 r
.46329 .90095 m .46537 .90818 L .45261 .90909 L p F P
0 g
s
.682 .552 .701 r
.45926 .90124 m .46329 .90095 L p .45261 .90909 L F P
0 g
s
.729 .606 .72 r
.34967 .88584 m .35986 .88654 L .35244 .89384 L p F P
0 g
s
.728 .61 .727 r
.35762 .87839 m .34967 .88584 L .35986 .88654 L p F P
0 g
s
.728 .61 .727 r
.35967 .87854 m .35762 .87839 L p .35986 .88654 L F P
0 g
s
.717 .616 .743 r
.38539 .87148 m .3833 .86653 L .37741 .87119 L closepath p F P
0 g
s
.723 .615 .737 r
.37096 .87093 m .37267 .87512 L .36816 .879 L p F P
0 g
s
.723 .615 .737 r
.36652 .87068 m .37096 .87093 L p .36816 .879 L F P
0 g
s
.723 .615 .737 r
.35907 .87709 m .36652 .87068 L p .36816 .879 L F P
0 g
s
.723 .615 .737 r
.36816 .879 m .35967 .87854 L .35907 .87709 L p F P
0 g
s
.687 .579 .728 r
.44331 .88014 m .4453 .87879 L .44289 .87894 L closepath p F P
0 g
s
.731 .583 .69 r
.35603 .90905 m .3498 .9086 L p .35437 .9161 L F P
0 g
s
.731 .583 .69 r
.35437 .9161 m .35712 .91273 L .35603 .90905 L p F P
0 g
s
.732 .592 .699 r
.35603 .90905 m .35424 .90349 L .3498 .9086 L closepath p F P
0 g
s
.939 .848 .725 r
.60901 .18887 m .61046 .19308 L .61363 .18744 L p F P
0 g
s
.939 .848 .725 r
.61363 .18744 m .61209 .18326 L .60901 .18887 L p F P
0 g
s
.733 .595 .702 r
.3536 .90151 m .35424 .90349 L .3498 .9086 L p F P
0 g
s
.695 .592 .737 r
.42687 .87192 m .42767 .87137 L .42668 .87141 L closepath p F P
0 g
s
.733 .595 .702 r
.34588 .90091 m .3536 .90151 L p .3498 .9086 L F P
0 g
s
.733 .6 .709 r
.3536 .90151 m .35133 .895 L .34588 .90091 L closepath p F P
0 g
s
.661 .752 .917 r
.63324 .31534 m .62236 .31947 L .61965 .31575 L p F P
0 g
s
.687 .586 .737 r
.4453 .87879 m .44289 .87894 L .44041 .87233 L p F P
0 g
s
.988 .893 .623 r
.78026 .1732 m .78225 .16794 L .78295 .17235 L p F P
0 g
s
.988 .893 .623 r
.78029 .17338 m .78026 .1732 L p .78295 .17235 L F P
0 g
s
.988 .893 .623 r
.78295 .17235 m .78238 .17383 L .78029 .17338 L p F P
0 g
s
.695 .599 .745 r
.42767 .87137 m .42668 .87141 L .42396 .86464 L p F P
0 g
s
.789 .851 .897 r
.68437 .29828 m .68173 .30013 L .68232 .2963 L closepath p F P
0 g
s
.784 .841 .895 r
.68182 .29581 m .68232 .2963 L .68173 .30013 L p F P
0 g
s
.784 .841 .895 r
.67102 .30313 m .68182 .29581 L p .68173 .30013 L F P
0 g
s
.69 .533 .669 r
.44178 .93063 m .43157 .93105 L .43065 .92691 L p F P
0 g
s
.695 .536 .667 r
.43157 .93105 m .43065 .92691 L .42695 .93118 L closepath p F P
0 g
s
0 0 .098 r
.59529 .28088 m .59521 .28204 L .59511 .27754 L p F P
0 g
s
0 0 .098 r
.59511 .27754 m .59519 .27634 L .59529 .28088 L p F P
0 g
s
.703 .534 .657 r
.40452 .93151 m .41321 .93145 L .40832 .93809 L p F P
0 g
s
.703 .534 .657 r
.40832 .93809 m .40583 .93811 L .40452 .93151 L p F P
0 g
s
.708 .538 .656 r
.40034 .93148 m .40452 .93151 L .40583 .93811 L p F P
0 g
s
.693 .597 .743 r
.43985 .87086 m .4375 .86491 L .42767 .87137 L closepath p F P
0 g
s
.695 .599 .745 r
.43655 .86253 m .4375 .86491 L .42767 .87137 L p F P
0 g
s
.695 .599 .745 r
.42654 .86292 m .43655 .86253 L p .42767 .87137 L F P
0 g
s
.695 .599 .745 r
.42396 .86464 m .42654 .86292 L p .42767 .87137 L F P
0 g
s
.719 .611 .737 r
.37267 .87512 m .37741 .87119 L .37096 .87093 L closepath p F P
0 g
s
.731 .583 .689 r
.35819 .91636 m .35712 .91273 L .35437 .9161 L closepath p F P
0 g
s
.43 .58 .901 r
.75084 .07762 m .75259 .07785 L .7543 .08206 L p F P
0 g
s
.366 .537 .892 r
.75962 .07958 m .7612 .08383 L .7543 .08206 L p F P
0 g
s
.366 .537 .892 r
.7543 .08206 m .75259 .07785 L .75962 .07958 L p F P
0 g
s
.981 .865 .649 r
.60268 .22333 m .60415 .21967 L .60151 .21891 L p F P
0 g
s
.708 .538 .656 r
.40583 .93811 m .39577 .93804 L .40034 .93148 L p F P
0 g
s
.709 .539 .657 r
.39058 .93139 m .40034 .93148 L .39577 .93804 L p F P
0 g
s
.723 .56 .668 r
.37634 .93102 m .36569 .93053 L .37037 .92396 L p F P
0 g
s
.724 .561 .669 r
.36011 .92347 m .37037 .92396 L .36569 .93053 L p F P
0 g
s
.724 .571 .681 r
.37037 .92396 m .36011 .92347 L .35996 .92294 L p F P
0 g
s
.907 .908 .811 r
.75658 .22684 m .7558 .22782 L .75589 .23235 L p F P
0 g
s
.897 .902 .821 r
.75025 .2344 m .75041 .23889 L .75589 .23235 L p F P
0 g
s
.897 .902 .821 r
.75589 .23235 m .7558 .22782 L .75025 .2344 L p F P
0 g
s
.701 .532 .656 r
.41321 .93145 m .41817 .93139 L .41947 .93797 L p F P
0 g
s
.701 .532 .656 r
.41947 .93797 m .40832 .93809 L .41321 .93145 L p F P
0 g
s
.729 .606 .72 r
.3484 .8871 m .34967 .88584 L p .35244 .89384 L F P
0 g
s
.729 .606 .72 r
.35244 .89384 m .35089 .89374 L .3484 .8871 L p F P
0 g
s
.73 .599 .71 r
.35133 .895 m .35244 .89384 L .35089 .89374 L closepath p F P
0 g
s
.686 .584 .735 r
.45576 .87811 m .45395 .87322 L .4453 .87879 L closepath p F P
0 g
s
.687 .586 .737 r
.45277 .87007 m .45395 .87322 L .4453 .87879 L p F P
0 g
s
.687 .586 .737 r
.44294 .87068 m .45277 .87007 L p .4453 .87879 L F P
0 g
s
.687 .586 .737 r
.44041 .87233 m .44294 .87068 L p .4453 .87879 L F P
0 g
s
.73 .574 .68 r
.35819 .91636 m .35437 .9161 L p .35959 .92344 L F P
0 g
s
.73 .574 .68 r
.35959 .92344 m .35996 .92294 L .35819 .91636 L p F P
0 g
s
.696 .528 .657 r
.41817 .93139 m .42695 .93118 L .42172 .93791 L p F P
0 g
s
.696 .528 .657 r
.42172 .93791 m .41947 .93797 L .41817 .93139 L p F P
0 g
s
.709 .539 .657 r
.39577 .93804 m .39191 .938 L .39058 .93139 L p F P
0 g
s
.715 .543 .655 r
.38818 .93133 m .39058 .93139 L .39191 .938 L p F P
0 g
s
.734 .603 .712 r
.35089 .89374 m .35133 .895 L .34588 .90091 L p F P
0 g
s
.715 .543 .655 r
.39191 .938 m .38388 .93781 L .38818 .93133 L p F P
0 g
s
.716 .545 .656 r
.3766 .93102 m .38818 .93133 L .38388 .93781 L p F P
0 g
s
.718 .618 .745 r
.38176 .8629 m .3833 .86653 L .37741 .87119 L p F P
0 g
s
.718 .618 .745 r
.37646 .86268 m .38176 .8629 L p .37741 .87119 L F P
0 g
s
.718 .618 .745 r
.36972 .86804 m .37646 .86268 L p .37741 .87119 L F P
0 g
s
.718 .618 .745 r
.37741 .87119 m .37096 .87093 L .36972 .86804 L p F P
0 g
s
.734 .609 .718 r
.35089 .89374 m .3484 .8871 L .3426 .89305 L closepath p F P
0 g
s
.734 .603 .712 r
.3426 .89305 m .35089 .89374 L p .34588 .90091 L F P
0 g
s
.683 .561 .71 r
.461 .89353 m .46263 .89879 L .45926 .90124 L p F P
0 g
s
.682 .559 .709 r
.46329 .90095 m .46263 .89879 L .45926 .90124 L closepath p F P
0 g
s
.684 .529 .669 r
.44418 .92803 m .44859 .92348 L .44324 .92378 L closepath p F P
0 g
s
.69 .533 .669 r
.44324 .92378 m .44418 .92803 L .44178 .93063 L p F P
0 g
s
.799 .852 .89 r
.69404 .29116 m .68437 .29828 L .68232 .2963 L p F P
0 g
s
.94 .803 .345 r
.59528 .26254 m .59566 .26701 L .59649 .26216 L p F P
0 g
s
.94 .803 .345 r
.59649 .26216 m .59605 .2577 L .59528 .26254 L p F P
0 g
s
.916 .838 .754 r
.6142 .17206 m .6169 .16778 L .61857 .17193 L p F P
0 g
s
.916 .838 .754 r
.61857 .17193 m .61686 .17461 L .6142 .17206 L p F P
0 g
s
.68 .533 .68 r
.45485 .91759 m .45662 .916 L .4545 .91615 L closepath p F P
0 g
s
.685 .538 .68 r
.4545 .91615 m .45485 .91759 L .44859 .92348 L p F P
0 g
s
.694 .526 .656 r
.42695 .93118 m .43157 .93105 L .43285 .9376 L p F P
0 g
s
.694 .526 .656 r
.43285 .9376 m .42172 .93791 L .42695 .93118 L p F P
0 g
s
.728 .618 .735 r
.35967 .87854 m .35907 .87709 L .35762 .87839 L closepath p F P
0 g
s
.567 .67 .908 r
.73444 .07016 m .7364 .0699 L .73834 .07405 L p F P
0 g
s
.539 .647 .904 r
.74578 .06914 m .7364 .0699 L .73834 .07405 L p F P
0 g
s
.539 .647 .904 r
.73834 .07405 m .74831 .07336 L .74578 .06914 L p F P
0 g
s
.708 .61 .745 r
.39686 .86545 m .39986 .86325 L .39594 .86323 L closepath p F P
0 g
s
.731 .583 .69 r
.3498 .9086 m .34426 .91539 L .35437 .9161 L p F P
0 g
s
.733 .587 .692 r
.34089 .90793 m .3498 .9086 L .34426 .91539 L p F P
0 g
s
.733 .595 .702 r
.34058 .90698 m .34588 .90091 L p .3498 .9086 L F P
0 g
s
.733 .595 .702 r
.3498 .9086 m .34089 .90793 L .34058 .90698 L p F P
0 g
s
.73 .574 .68 r
.35437 .9161 m .34939 .92275 L .35959 .92344 L p F P
0 g
s
.732 .577 .681 r
.34426 .91539 m .35437 .9161 L .34939 .92275 L p F P
0 g
s
.678 .565 .72 r
.47151 .89264 m .461 .89353 L .45974 .88969 L p F P
0 g
s
.678 .557 .711 r
.46263 .89879 m .47151 .89264 L .461 .89353 L closepath p F P
0 g
s
.985 .899 .633 r
.78238 .17383 m .78083 .17764 L .78029 .17338 L closepath p F P
0 g
s
.688 .587 .737 r
.44041 .87233 m .44294 .87068 L .43985 .87086 L closepath p F P
0 g
s
.702 .605 .745 r
.41041 .86482 m .41269 .86323 L .40978 .86327 L closepath p F P
0 g
s
0 .206 .728 r
.77414 .10225 m .77282 .10092 L .77024 .09555 L p F P
0 g
s
.678 .565 .72 r
.45974 .88969 m .4664 .88527 L p .47151 .89264 L F P
0 g
s
.679 .565 .72 r
.45974 .88969 m .4664 .88527 L .4585 .88592 L closepath p F P
0 g
s
.723 .62 .743 r
.37096 .87093 m .36972 .86804 L .36652 .87068 L closepath p F P
0 g
s
.816 .561 .005 r
.78262 .12646 m .78372 .13079 L .78314 .12654 L p F P
0 g
s
.816 .561 .005 r
.78314 .12654 m .78203 .1222 L .78262 .12646 L p F P
0 g
s
.678 .532 .68 r
.45485 .91759 m .45662 .916 L p .46571 .92232 L F P
0 g
s
.678 .532 .68 r
.46571 .92232 m .45617 .92302 L .45485 .91759 L p F P
0 g
s
.684 .536 .679 r
.45617 .92302 m .45485 .91759 L .44859 .92348 L closepath p F P
0 g
s
.677 .556 .71 r
.46329 .90095 m .46263 .89879 L .47151 .89264 L p F P
0 g
s
.689 .523 .657 r
.43157 .93105 m .44178 .93063 L .43615 .93747 L p F P
0 g
s
.689 .523 .657 r
.43615 .93747 m .43285 .9376 L .43157 .93105 L p F P
0 g
s
.935 .909 .77 r
.76502 .21076 m .76901 .20475 L .7694 .20921 L p F P
0 g
s
.935 .909 .77 r
.7651 .21166 m .76502 .21076 L p .7694 .20921 L F P
0 g
s
.935 .909 .77 r
.7694 .20921 m .76694 .21289 L .7651 .21166 L p F P
0 g
s
.68 .573 .728 r
.4664 .88527 m .4585 .88592 L .45685 .88121 L p F P
0 g
s
.678 .532 .68 r
.45662 .916 m .46722 .9152 L p .46571 .92232 L F P
0 g
s
.679 .54 .689 r
.46722 .9152 m .46551 .90869 L .45662 .916 L closepath p F P
0 g
s
.681 .543 .691 r
.46537 .90818 m .46551 .90869 L .45662 .916 L p F P
0 g
s
.729 .614 .729 r
.34759 .87764 m .35762 .87839 L .34967 .88584 L p F P
0 g
s
.728 .618 .735 r
.35603 .87005 m .34759 .87764 L .35762 .87839 L p F P
0 g
s
.728 .618 .735 r
.35616 .87006 m .35603 .87005 L p .35762 .87839 L F P
0 g
s
.728 .618 .735 r
.35762 .87839 m .35907 .87709 L .35616 .87006 L p F P
0 g
s
.714 .614 .745 r
.3833 .86653 m .38784 .86305 L .38176 .8629 L closepath p F P
0 g
s
.676 .548 .701 r
.46329 .90095 m .47586 .89984 L p .46627 .9081 L F P
0 g
s
.676 .548 .701 r
.46627 .9081 m .46537 .90818 L .46329 .90095 L p F P
0 g
s
.677 .556 .71 r
.4736 .89245 m .47586 .89984 L .46329 .90095 L p F P
0 g
s
.677 .556 .71 r
.47151 .89264 m .4736 .89245 L p .46329 .90095 L F P
0 g
s
.716 .545 .656 r
.3764 .93133 m .3766 .93102 L p .38388 .93781 L F P
0 g
s
.717 .546 .656 r
.3764 .93133 m .3766 .93102 L .37634 .93102 L closepath p F P
0 g
s
.73 .574 .68 r
.36011 .92347 m .35996 .92294 L .35959 .92344 L closepath p F P
0 g
s
.723 .551 .658 r
.37634 .93102 m .3764 .93133 L .37254 .93744 L p F P
0 g
s
.723 .551 .658 r
.36569 .93053 m .37634 .93102 L p .37254 .93744 L F P
0 g
s
.689 .594 .745 r
.44294 .87068 m .43985 .87086 L .4375 .86491 L p F P
0 g
s
.724 .616 .737 r
.35907 .87709 m .36652 .87068 L .35616 .87006 L closepath p F P
0 g
s
.684 .528 .669 r
.44859 .92348 m .45617 .92302 L p .44472 .93049 L F P
0 g
s
.684 .528 .669 r
.44472 .93049 m .44418 .92803 L .44859 .92348 L p F P
0 g
s
.734 .596 .702 r
.34058 .90698 m .34588 .90091 L .33837 .90031 L closepath p F P
0 g
s
.734 .603 .712 r
.33767 .89837 m .3426 .89305 L p .34588 .90091 L F P
0 g
s
.734 .603 .712 r
.34588 .90091 m .33837 .90031 L .33767 .89837 L p F P
0 g
s
.724 .561 .669 r
.36569 .93053 m .36174 .93035 L .36011 .92347 L p F P
0 g
s
.73 .565 .667 r
.35959 .92344 m .36011 .92347 L .36174 .93035 L p F P
0 g
s
.716 .545 .656 r
.38388 .93781 m .37769 .93765 L .3764 .93133 L p F P
0 g
s
.721 .548 .655 r
.37769 .93765 m .3764 .93133 L .37254 .93744 L closepath p F P
0 g
s
.809 .786 .831 r
.6637 .09625 m .66151 .0982 L .65889 .09455 L p F P
0 g
s
.834 .792 .811 r
.65643 .10341 m .66151 .0982 L .65889 .09455 L p F P
0 g
s
.73 .607 .72 r
.3484 .8871 m .34967 .88584 L .34788 .88571 L closepath p F P
0 g
s
.729 .614 .729 r
.34545 .87965 m .34759 .87764 L p .34967 .88584 L F P
0 g
s
.729 .614 .729 r
.34967 .88584 m .34788 .88571 L .34545 .87965 L p F P
0 g
s
.731 .567 .67 r
.34939 .92275 m .35959 .92344 L .35518 .92994 L p F P
0 g
s
.73 .565 .667 r
.36174 .93035 m .35518 .92994 L .35959 .92344 L p F P
0 g
s
.701 .612 .753 r
.41269 .86323 m .40978 .86327 L .40748 .85792 L p F P
0 g
s
.706 .614 .751 r
.40978 .86327 m .40748 .85792 L .39986 .86325 L closepath p F P
0 g
s
.817 .785 .822 r
.66152 .09219 m .6637 .09625 L .67206 .08867 L p F P
0 g
s
.809 .786 .831 r
.65889 .09455 m .66152 .09219 L .6637 .09625 L p F P
0 g
s
.707 .616 .753 r
.40602 .85455 m .40748 .85792 L .39986 .86325 L p F P
0 g
s
.707 .616 .753 r
.39974 .85451 m .40602 .85455 L p .39986 .86325 L F P
0 g
s
.707 .616 .753 r
.39392 .85861 m .39974 .85451 L p .39986 .86325 L F P
0 g
s
.707 .616 .753 r
.39986 .86325 m .39594 .86323 L .39392 .85861 L p F P
0 g
s
.734 .611 .721 r
.34788 .88571 m .3484 .8871 L .3426 .89305 L p F P
0 g
s
.907 .819 .749 r
.62463 .15544 m .62417 .15617 L .62285 .15346 L closepath p F P
0 g
s
.712 .619 .751 r
.39594 .86323 m .39392 .85861 L .38784 .86305 L closepath p F P
0 g
s
.7 .609 .751 r
.42331 .86303 m .42103 .85766 L .41269 .86323 L closepath p F P
0 g
s
.701 .612 .753 r
.41963 .85437 m .42103 .85766 L .41269 .86323 L p F P
0 g
s
.701 .612 .753 r
.41259 .85448 m .41963 .85437 L p .41269 .86323 L F P
0 g
s
.701 .612 .753 r
.40748 .85792 m .41259 .85448 L p .41269 .86323 L F P
0 g
s
.87 .81 .788 r
.62979 .13438 m .63348 .12974 L .63552 .13381 L p F P
0 g
s
.87 .81 .788 r
.63552 .13381 m .63245 .13765 L .62979 .13438 L p F P
0 g
s
.813 .784 .825 r
.67219 .08855 m .67206 .08867 L .67118 .08712 L closepath p F P
0 g
s
.817 .785 .822 r
.66958 .08484 m .66152 .09219 L p .67206 .08867 L F P
0 g
s
.817 .785 .822 r
.67206 .08867 m .67118 .08712 L .66958 .08484 L p F P
0 g
s
.789 .778 .843 r
.68272 .08021 m .67219 .08855 L .67118 .08712 L p F P
0 g
s
.696 .6 .745 r
.42396 .86464 m .42654 .86292 L .42331 .86303 L closepath p F P
0 g
s
.68 .573 .728 r
.45685 .88121 m .46255 .87756 L p .4664 .88527 L F P
0 g
s
.681 .574 .728 r
.45685 .88121 m .46255 .87756 L .45576 .87811 L closepath p F P
0 g
s
.723 .623 .745 r
.36723 .86226 m .36972 .86804 L .36652 .87068 L p F P
0 g
s
.723 .623 .745 r
.36558 .86216 m .36723 .86226 L p .36652 .87068 L F P
0 g
s
.723 .623 .745 r
.35612 .86998 m .36558 .86216 L p .36652 .87068 L F P
0 g
s
.723 .623 .745 r
.36652 .87068 m .35616 .87006 L .35612 .86998 L p F P
0 g
s
.687 .592 .744 r
.45277 .87007 m .45104 .86563 L .44294 .87068 L closepath p F P
0 g
s
.689 .594 .745 r
.44953 .86178 m .45104 .86563 L .44294 .87068 L p F P
0 g
s
.689 .594 .745 r
.44173 .86225 m .44953 .86178 L p .44294 .87068 L F P
0 g
s
.689 .594 .745 r
.4375 .86491 m .44173 .86225 L p .44294 .87068 L F P
0 g
s
.479 .559 .859 r
.60843 .31277 m .60597 .31277 L .60318 .30729 L p F P
0 g
s
.734 .611 .721 r
.33996 .88501 m .34788 .88571 L p .3426 .89305 L F P
0 g
s
.735 .617 .727 r
.34788 .88571 m .34545 .87965 L .33996 .88501 L closepath p F P
0 g
s
.688 .531 .668 r
.44472 .93049 m .44418 .92803 L .44178 .93063 L closepath p F P
0 g
s
.734 .756 .871 r
.70167 .07346 m .70721 .07031 L .70464 .06643 L p F P
0 g
s
.734 .756 .871 r
.70464 .06643 m .69956 .06935 L .70167 .07346 L p F P
0 g
s
.731 .757 .873 r
.69374 .07266 m .69956 .06935 L .70167 .07346 L p F P
0 g
s
.889 .895 .828 r
.74608 .23917 m .75025 .2344 L .75041 .23889 L p F P
0 g
s
.889 .895 .828 r
.75041 .23889 m .74846 .24112 L .74608 .23917 L p F P
0 g
s
.912 .82 .742 r
.61864 .15788 m .62056 .16196 L .62417 .15617 L p F P
0 g
s
.912 .82 .742 r
.62196 .15248 m .61864 .15788 L p .62417 .15617 L F P
0 g
s
.912 .82 .742 r
.62417 .15617 m .62285 .15346 L .62196 .15248 L p F P
0 g
s
.764 .822 .898 r
.66776 .30519 m .6602 .30991 L .6576 .30714 L p F P
0 g
s
.983 .827 .431 r
.78357 .14905 m .78438 .15345 L .78524 .14864 L p F P
0 g
s
.983 .827 .431 r
.78524 .14864 m .78444 .14423 L .78357 .14905 L p F P
0 g
s
.681 .581 .737 r
.46255 .87756 m .45576 .87811 L .45395 .87322 L p F P
0 g
s
.713 .621 .753 r
.39208 .85443 m .39392 .85861 L .38784 .86305 L p F P
0 g
s
.713 .621 .753 r
.38769 .85431 m .39208 .85443 L p .38784 .86305 L F P
0 g
s
.713 .621 .753 r
.38034 .85972 m .38769 .85431 L p .38784 .86305 L F P
0 g
s
.713 .621 .753 r
.38784 .86305 m .38176 .8629 L .38034 .85972 L p F P
0 g
s
.675 .538 .691 r
.46551 .90869 m .46627 .9081 L .46537 .90818 L closepath p F P
0 g
s
.931 .832 .725 r
.61517 .17765 m .61686 .17461 L .6142 .17206 L p F P
0 g
s
.719 .619 .745 r
.36972 .86804 m .37646 .86268 L .36723 .86226 L closepath p F P
0 g
s
.695 .607 .753 r
.42654 .86292 m .42331 .86303 L .42103 .85766 L p F P
0 g
s
.674 .537 .69 r
.46551 .90869 m .46627 .9081 L p .47498 .91451 L F P
0 g
s
.674 .537 .69 r
.47498 .91451 m .46722 .9152 L .46551 .90869 L p F P
0 g
s
.834 .792 .811 r
.65889 .09455 m .65421 .09938 L .65643 .10341 L p F P
0 g
s
.83 .793 .816 r
.64825 .10539 m .65421 .09938 L .65643 .10341 L p F P
0 g
s
.83 .793 .816 r
.65643 .10341 m .65089 .10897 L .64825 .10539 L p F P
0 g
s
.674 .537 .69 r
.46627 .9081 m .4779 .90704 L p .47498 .91451 L F P
0 g
s
.674 .545 .7 r
.4779 .90704 m .47617 .90093 L .46627 .9081 L closepath p F P
0 g
s
.676 .548 .701 r
.47586 .89984 m .47617 .90093 L .46627 .9081 L p F P
0 g
s
0 0 .053 r
.59536 .27626 m .59529 .28088 L .59519 .27634 L p F P
0 g
s
.734 .611 .721 r
.33474 .89034 m .33996 .88501 L p .3426 .89305 L F P
0 g
s
.734 .611 .721 r
.3426 .89305 m .33555 .89244 L .33474 .89034 L p F P
0 g
s
.735 .604 .711 r
.33767 .89837 m .3426 .89305 L .33555 .89244 L closepath p F P
0 g
s
.687 .52 .655 r
.44178 .93063 m .44472 .93049 L .44598 .93702 L p F P
0 g
s
.687 .52 .655 r
.44598 .93702 m .43615 .93747 L .44178 .93063 L p F P
0 g
s
.694 .605 .752 r
.43655 .86253 m .43458 .85781 L .42654 .86292 L closepath p F P
0 g
s
.695 .607 .753 r
.43295 .85393 m .43458 .85781 L .42654 .86292 L p F P
0 g
s
.695 .607 .753 r
.42647 .85416 m .43295 .85393 L p .42654 .86292 L F P
0 g
s
.695 .607 .753 r
.42103 .85766 m .42647 .85416 L p .42654 .86292 L F P
0 g
s
.718 .623 .751 r
.38176 .8629 m .38034 .85972 L .37646 .86268 L closepath p F P
0 g
s
.701 .523 .643 r
.40635 .94118 m .40832 .93809 L .40583 .93811 L closepath p F P
0 g
s
.707 .528 .644 r
.40583 .93811 m .40635 .94118 L .40433 .9445 L p F P
0 g
s
.707 .528 .644 r
.39577 .93804 m .40583 .93811 L p .40433 .9445 L F P
0 g
s
.884 .897 .835 r
.74435 .24565 m .74846 .24112 L .74608 .23917 L p F P
0 g
s
.7 .522 .643 r
.40832 .93809 m .41947 .93797 L p .41748 .94439 L F P
0 g
s
.7 .522 .643 r
.40635 .94118 m .40832 .93809 L p .41748 .94439 L F P
0 g
s
.317 .431 .82 r
.60101 .30627 m .60111 .30288 L .60318 .30729 L closepath p F P
0 g
s
.677 .524 .67 r
.45617 .92302 m .46571 .92232 L .45801 .9297 L p F P
0 g
s
.677 .524 .67 r
.45801 .9297 m .45765 .92973 L .45617 .92302 L p F P
0 g
s
.684 .528 .669 r
.45617 .92302 m .45765 .92973 L .44472 .93049 L p F P
0 g
s
.723 .551 .658 r
.36275 .93515 m .36569 .93053 L p .37254 .93744 L F P
0 g
s
.724 .552 .658 r
.36275 .93515 m .36569 .93053 L .36174 .93035 L closepath p F P
0 g
s
.707 .528 .644 r
.39276 .94296 m .39577 .93804 L p .40433 .9445 L F P
0 g
s
.708 .529 .644 r
.39276 .94296 m .39577 .93804 L .39191 .938 L closepath p F P
0 g
s
.252 .439 .852 r
.76511 .08554 m .7612 .08383 L .7627 .08811 L p F P
0 g
s
.252 .439 .852 r
.7627 .08811 m .76766 .0904 L .76511 .08554 L p F P
0 g
s
0 0 .2 r
.78084 .11788 m .78203 .1222 L .78089 .11817 L p F P
0 g
s
0 0 .2 r
.78089 .11817 m .77969 .11385 L .78084 .11788 L p F P
0 g
s
.805 .86 .89 r
.69513 .29034 m .69404 .29116 L .69424 .2895 L closepath p F P
0 g
s
.799 .852 .89 r
.69261 .2879 m .69424 .2895 L .69404 .29116 L p F P
0 g
s
.799 .852 .89 r
.68237 .29542 m .69261 .2879 L p .69404 .29116 L F P
0 g
s
.799 .852 .89 r
.68232 .2963 m .68237 .29542 L p .69404 .29116 L F P
0 g
s
.733 .587 .692 r
.34426 .91539 m .34313 .91531 L .34089 .90793 L p F P
0 g
s
.739 .59 .69 r
.33986 .90784 m .34089 .90793 L .34313 .91531 L p F P
0 g
s
.738 .597 .7 r
.34089 .90793 m .34058 .90698 L .33986 .90784 L closepath p F P
0 g
s
.682 .517 .656 r
.44472 .93049 m .45765 .92973 L p .4519 .93668 L F P
0 g
s
.682 .517 .656 r
.4519 .93668 m .44598 .93702 L .44472 .93049 L p F P
0 g
s
.738 .598 .7 r
.33986 .90784 m .34058 .90698 L .33837 .90031 L p F P
0 g
s
.713 .532 .643 r
.39191 .938 m .38388 .93781 L p .39192 .94441 L F P
0 g
s
.713 .532 .643 r
.39192 .94441 m .39276 .94296 L .39191 .938 L p F P
0 g
s
.852 .795 .795 r
.64967 .11038 m .65089 .10897 L .64825 .10539 L p F P
0 g
s
.69 .595 .745 r
.4375 .86491 m .44173 .86225 L .43655 .86253 L closepath p F P
0 g
s
.985 .882 .535 r
.59814 .24597 m .59663 .24732 L .59786 .24332 L closepath p F P
0 g
s
.682 .582 .737 r
.45395 .87322 m .45997 .86951 L .45277 .87007 L closepath p F P
0 g
s
.681 .581 .737 r
.45395 .87322 m .45997 .86951 L p .46255 .87756 L F P
0 g
s
.7 .522 .643 r
.41947 .93797 m .41991 .9406 L .41748 .94439 L p F P
0 g
s
.694 .517 .643 r
.41991 .9406 m .42172 .93791 L .41947 .93797 L closepath p F P
0 g
s
.732 .577 .681 r
.34345 .91648 m .34426 .91539 L p .34939 .92275 L F P
0 g
s
.734 .578 .68 r
.34345 .91648 m .34426 .91539 L .34313 .91531 L closepath p F P
0 g
s
.814 .861 .883 r
.70471 .28277 m .69513 .29034 L .69424 .2895 L p F P
0 g
s
.889 .81 .764 r
.63079 .14001 m .63245 .13765 L .62979 .13438 L p F P
0 g
s
.981 .865 .649 r
.60151 .21891 m .60144 .21909 L .60268 .22333 L p F P
0 g
s
.986 .862 .63 r
.59952 .22431 m .60069 .22857 L .60268 .22333 L p F P
0 g
s
.986 .862 .63 r
.60268 .22333 m .60144 .21909 L .59952 .22431 L p F P
0 g
s
.931 .911 .779 r
.76694 .21289 m .7653 .21525 L .7651 .21166 L closepath p F P
0 g
s
.739 .59 .69 r
.34313 .91531 m .33464 .91454 L .33986 .90784 L p F P
0 g
s
.739 .592 .693 r
.33041 .90694 m .33986 .90784 L .33464 .91454 L p F P
0 g
s
.738 .598 .7 r
.33613 .90009 m .33041 .90694 L .33986 .90784 L p F P
0 g
s
.738 .598 .7 r
.33837 .90031 m .33613 .90009 L p .33986 .90784 L F P
0 g
s
.678 .565 .72 r
.4664 .88527 m .47111 .88486 L p .47151 .89264 L F P
0 g
s
.678 .571 .727 r
.47111 .88486 m .47039 .88276 L .4664 .88527 L closepath p F P
0 g
s
.68 .573 .728 r
.46841 .87706 m .47039 .88276 L .4664 .88527 L p F P
0 g
s
.68 .573 .728 r
.46255 .87756 m .46841 .87706 L p .4664 .88527 L F P
0 g
s
.739 .606 .709 r
.33837 .90031 m .33767 .89837 L .33613 .90009 L closepath p F P
0 g
s
.693 .516 .643 r
.42172 .93791 m .43285 .9376 L p .43154 .94405 L F P
0 g
s
.693 .516 .643 r
.41991 .9406 m .42172 .93791 L p .43154 .94405 L F P
0 g
s
.718 .626 .753 r
.3778 .85401 m .38034 .85972 L .37646 .86268 L p F P
0 g
s
.718 .626 .753 r
.37627 .85394 m .3778 .85401 L p .37646 .86268 L F P
0 g
s
.718 .626 .753 r
.36676 .86123 m .37627 .85394 L p .37646 .86268 L F P
0 g
s
.718 .626 .753 r
.37646 .86268 m .36723 .86226 L .36676 .86123 L p F P
0 g
s
.966 .861 .684 r
.60266 .20943 m .60391 .21368 L .60646 .20825 L p F P
0 g
s
.966 .861 .684 r
.60646 .20825 m .60513 .20402 L .60266 .20943 L p F P
0 g
s
.738 .581 .679 r
.34313 .91531 m .33464 .91454 L p .3395 .92198 L F P
0 g
s
.738 .581 .679 r
.3395 .92198 m .34345 .91648 L .34313 .91531 L p F P
0 g
s
.728 .555 .656 r
.36174 .93035 m .35518 .92994 L p .36165 .93695 L F P
0 g
s
.728 .555 .656 r
.36165 .93695 m .36275 .93515 L .36174 .93035 L p F P
0 g
s
.852 .795 .795 r
.64825 .10539 m .64741 .10636 L .64967 .11038 L p F P
0 g
s
.852 .795 .796 r
.6417 .11294 m .6439 .11697 L .64967 .11038 L p F P
0 g
s
.852 .795 .796 r
.64967 .11038 m .64741 .10636 L .6417 .11294 L p F P
0 g
s
.739 .606 .71 r
.33613 .90009 m .33767 .89837 L .33555 .89244 L p F P
0 g
s
.958 .907 .727 r
.77255 .19395 m .77548 .18867 L .77603 .1931 L p F P
0 g
s
.958 .907 .727 r
.77603 .1931 m .77481 .19526 L .77255 .19395 L p F P
0 g
s
.731 .615 .729 r
.34545 .87965 m .34759 .87764 L .34455 .87741 L closepath p F P
0 g
s
.73 .622 .738 r
.34618 .86925 m .35603 .87005 L .34759 .87764 L p F P
0 g
s
.73 .622 .738 r
.34249 .87257 m .34618 .86925 L p .34759 .87764 L F P
0 g
s
.73 .622 .738 r
.34759 .87764 m .34455 .87741 L .34249 .87257 L p F P
0 g
s
.738 .58 .679 r
.34509 .92245 m .34345 .91648 L .3395 .92198 L closepath p F P
0 g
s
.732 .577 .681 r
.34939 .92275 m .34509 .92245 L .34345 .91648 L p F P
0 g
s
.943 .855 .726 r
.60649 .19351 m .60901 .18887 L .61046 .19308 L p F P
0 g
s
.943 .855 .726 r
.61046 .19308 m .60915 .19546 L .60649 .19351 L p F P
0 g
s
.713 .532 .643 r
.38388 .93781 m .38019 .94414 L .39192 .94441 L p F P
0 g
s
.715 .535 .644 r
.37769 .93765 m .38388 .93781 L .38019 .94414 L p F P
0 g
s
.735 .619 .73 r
.34455 .87741 m .34545 .87965 L .33996 .88501 L p F P
0 g
s
.731 .567 .67 r
.34628 .9273 m .34939 .92275 L p .35518 .92994 L F P
0 g
s
.732 .569 .67 r
.34628 .9273 m .34939 .92275 L .34509 .92245 L closepath p F P
0 g
s
.708 .617 .753 r
.39392 .85861 m .39974 .85451 L .39208 .85443 L closepath p F P
0 g
s
.791 .776 .839 r
.68293 .08004 m .68272 .08021 L .68122 .07756 L closepath p F P
0 g
s
.789 .778 .843 r
.68033 .07626 m .68122 .07756 L .68272 .08021 L p F P
0 g
s
.789 .778 .843 r
.66986 .08461 m .68033 .07626 L p .68272 .08021 L F P
0 g
s
.789 .778 .843 r
.67118 .08712 m .66986 .08461 L p .68272 .08021 L F P
0 g
s
.759 .767 .86 r
.69116 .06882 m .69374 .07266 L .68293 .08004 L p F P
0 g
s
.759 .767 .86 r
.68049 .07615 m .69116 .06882 L p .68293 .08004 L F P
0 g
s
.759 .767 .86 r
.68293 .08004 m .68122 .07756 L .68049 .07615 L p F P
0 g
s
.677 .563 .719 r
.4736 .89245 m .47328 .89148 L .47151 .89264 L closepath p F P
0 g
s
.678 .565 .72 r
.47111 .88486 m .47328 .89148 L .47151 .89264 L p F P
0 g
s
.673 .529 .681 r
.46838 .91997 m .47498 .91451 L .46722 .9152 L closepath p F P
0 g
s
.678 .532 .68 r
.46722 .9152 m .46838 .91997 L .46571 .92232 L p F P
0 g
s
.682 .59 .745 r
.45997 .86951 m .45277 .87007 L .45104 .86563 L p F P
0 g
s
.729 .625 .743 r
.35616 .87006 m .35612 .86998 L .35603 .87005 L closepath p F P
0 g
s
.702 .613 .753 r
.40748 .85792 m .41259 .85448 L .40602 .85455 L closepath p F P
0 g
s
.729 .627 .744 r
.35315 .86325 m .34618 .86925 L .35603 .87005 L p F P
0 g
s
.729 .627 .744 r
.35603 .87005 m .35612 .86998 L .35315 .86325 L p F P
0 g
s
.69 .602 .753 r
.44173 .86225 m .43655 .86253 L .43458 .85781 L p F P
0 g
s
.725 .624 .745 r
.36558 .86216 m .35612 .86998 L .35315 .86325 L p F P
0 g
s
.993 .878 .583 r
.59712 .23892 m .59786 .24332 L .59966 .23813 L p F P
0 g
s
.993 .878 .583 r
.59966 .23813 m .59883 .23377 L .59712 .23892 L p F P
0 g
s
.884 .897 .835 r
.74608 .23917 m .74432 .24111 L .74435 .24565 L p F P
0 g
s
.875 .892 .842 r
.73779 .24805 m .73792 .25254 L .74435 .24565 L p F P
0 g
s
.875 .892 .842 r
.74435 .24565 m .74432 .24111 L .73779 .24805 L p F P
0 g
s
.68 .579 .736 r
.46841 .87706 m .46749 .87456 L .46255 .87756 L closepath p F P
0 g
s
.681 .581 .737 r
.46546 .86905 m .46749 .87456 L .46255 .87756 L p F P
0 g
s
.681 .581 .737 r
.45997 .86951 m .46546 .86905 L p .46255 .87756 L F P
0 g
s
.077 .216 .706 r
.59781 .29827 m .5978 .29417 L .60037 .30108 L closepath p F P
0 g
s
.958 .765 .316 r
.78499 .14028 m .78473 .14106 L .78484 .13959 L closepath p F P
0 g
s
.74 .601 .702 r
.32679 .89916 m .33613 .90009 L .33041 .90694 L p F P
0 g
s
.739 .606 .71 r
.333 .89219 m .32679 .89916 L .33613 .90009 L p F P
0 g
s
.739 .606 .71 r
.33555 .89244 m .333 .89219 L p .33613 .90009 L F P
0 g
s
.993 .877 .576 r
.78147 .16355 m .78225 .16794 L .78388 .16283 L p F P
0 g
s
.993 .877 .576 r
.78388 .16283 m .78312 .15843 L .78147 .16355 L p F P
0 g
s
.736 .612 .72 r
.33474 .89034 m .33996 .88501 L .33243 .88432 L closepath p F P
0 g
s
.735 .619 .73 r
.33796 .87678 m .34455 .87741 L p .33996 .88501 L F P
0 g
s
.735 .619 .73 r
.33179 .88277 m .33796 .87678 L p .33996 .88501 L F P
0 g
s
.735 .619 .73 r
.33996 .88501 m .33243 .88432 L .33179 .88277 L p F P
0 g
s
.714 .622 .753 r
.38034 .85972 m .38769 .85431 L .3778 .85401 L closepath p F P
0 g
s
.715 .535 .644 r
.38019 .94414 m .37881 .9441 L .37769 .93765 L p F P
0 g
s
.721 .539 .643 r
.37254 .93744 m .37769 .93765 L .37881 .9441 L p F P
0 g
s
0 0 .414 r
.77841 .10954 m .77969 .11385 L .77793 .11006 L p F P
0 g
s
0 0 .414 r
.77793 .11006 m .77663 .10576 L .77841 .10954 L p F P
0 g
s
.687 .512 .644 r
.43345 .94124 m .43615 .93747 L .43285 .9376 L closepath p F P
0 g
s
.693 .516 .643 r
.43285 .9376 m .43345 .94124 L .43154 .94405 L p F P
0 g
s
.735 .624 .735 r
.34455 .87741 m .34249 .87257 L .33796 .87678 L closepath p F P
0 g
s
.672 .56 .72 r
.48394 .88489 m .48596 .89114 L .4736 .89245 L p F P
0 g
s
.672 .56 .72 r
.4736 .89245 m .47328 .89148 L .48394 .88489 L p F P
0 g
s
.671 .552 .711 r
.4736 .89245 m .48596 .89114 L p .4781 .89961 L F P
0 g
s
.671 .552 .711 r
.4781 .89961 m .47586 .89984 L .4736 .89245 L p F P
0 g
s
.74 .614 .718 r
.33555 .89244 m .33474 .89034 L .333 .89219 L closepath p F P
0 g
s
.673 .561 .72 r
.48352 .88358 m .48394 .88489 L .47328 .89148 L p F P
0 g
s
.673 .561 .72 r
.47328 .89148 m .47111 .88486 L .48352 .88358 L p F P
0 g
s
.697 .608 .753 r
.42103 .85766 m .42647 .85416 L .41963 .85437 L closepath p F P
0 g
s
.7 .522 .643 r
.41748 .94439 m .40691 .9445 L .40635 .94118 L p F P
0 g
s
.706 .525 .642 r
.40691 .9445 m .40635 .94118 L .40433 .9445 L closepath p F P
0 g
s
.931 .832 .725 r
.6142 .17206 m .61338 .17355 L .61517 .17765 L p F P
0 g
s
.934 .833 .721 r
.61037 .17913 m .61209 .18326 L .61517 .17765 L p F P
0 g
s
.934 .833 .721 r
.61517 .17765 m .61338 .17355 L .61037 .17913 L p F P
0 g
s
.974 .904 .684 r
.77772 .17866 m .77832 .1831 L .78083 .17764 L p F P
0 g
s
.974 .904 .684 r
.7802 .17334 m .77772 .17866 L p .78083 .17764 L F P
0 g
s
.974 .904 .684 r
.78083 .17764 m .78029 .17338 L .7802 .17334 L p F P
0 g
s
.915 .904 .799 r
.7604 .217 m .76071 .22148 L .7653 .21525 L p F P
0 g
s
.915 .904 .799 r
.76463 .2113 m .7604 .217 L p .7653 .21525 L F P
0 g
s
.915 .904 .799 r
.7653 .21525 m .7651 .21166 L .76463 .2113 L p F P
0 g
s
.889 .81 .764 r
.62979 .13438 m .62867 .13598 L .63079 .14001 L p F P
0 g
s
.89 .81 .763 r
.62451 .14197 m .62657 .14603 L .63079 .14001 L p F P
0 g
s
.89 .81 .763 r
.63079 .14001 m .62867 .13598 L .62451 .14197 L p F P
0 g
s
.114 .33 .799 r
.76926 .09486 m .7682 .09146 L .77024 .09555 L closepath p F P
0 g
s
.674 .569 .729 r
.48105 .8764 m .48352 .88358 L .47111 .88486 L p F P
0 g
s
.674 .569 .729 r
.47111 .88486 m .47039 .88276 L .48105 .8764 L p F P
0 g
s
.736 .571 .669 r
.34509 .92245 m .3395 .92198 L p .34499 .92925 L F P
0 g
s
.736 .571 .669 r
.34499 .92925 m .34628 .9273 L .34509 .92245 L p F P
0 g
s
.723 .628 .751 r
.36723 .86226 m .36676 .86123 L .36558 .86216 L closepath p F P
0 g
s
.699 .52 .642 r
.42054 .94435 m .41991 .9406 L .41748 .94439 L closepath p F P
0 g
s
.693 .516 .643 r
.43154 .94405 m .42054 .94435 L .41991 .9406 L p F P
0 g
s
.688 .6 .752 r
.44953 .86178 m .44813 .85839 L .44173 .86225 L closepath p F P
0 g
s
.69 .602 .753 r
.446 .85324 m .44813 .85839 L .44173 .86225 L p F P
0 g
s
.69 .602 .753 r
.44167 .85348 m .446 .85324 L p .44173 .86225 L F P
0 g
s
.69 .602 .753 r
.43458 .85781 m .44167 .85348 L p .44173 .86225 L F P
0 g
s
.686 .51 .643 r
.43615 .93747 m .44598 .93702 L p .44674 .9434 L F P
0 g
s
.686 .51 .643 r
.43345 .94124 m .43615 .93747 L p .44674 .9434 L F P
0 g
s
.692 .735 .884 r
.70721 .07031 m .71821 .06544 L .72076 .06938 L p F P
0 g
s
.637 .706 .896 r
.72076 .06938 m .7319 .06612 L .73444 .07016 L p F P
0 g
s
.64 .709 .897 r
.7319 .06612 m .72076 .06938 L .71821 .06544 L p F P
0 g
s
.731 .558 .657 r
.34679 .92939 m .35518 .92994 L .35128 .93631 L p F P
0 g
s
.731 .567 .67 r
.35518 .92994 m .34679 .92939 L .34628 .9273 L p F P
0 g
s
.728 .555 .656 r
.35518 .92994 m .35128 .93631 L .36165 .93695 L p F P
0 g
s
.67 .543 .701 r
.47617 .90093 m .4781 .89961 L .47586 .89984 L closepath p F P
0 g
s
.986 .839 .458 r
.59531 .25333 m .59605 .2577 L .59714 .25276 L p F P
0 g
s
.986 .839 .458 r
.59714 .25276 m .59634 .24841 L .59531 .25333 L p F P
0 g
s
.674 .569 .729 r
.48085 .87581 m .48105 .8764 L .47039 .88276 L p F P
0 g
s
.674 .569 .729 r
.47039 .88276 m .46841 .87706 L .48085 .87581 L p F P
0 g
s
0 .206 .728 r
.77024 .09555 m .77274 .09798 L .77414 .10225 L p F P
0 g
s
0 .027 .599 r
.77525 .10147 m .77663 .10576 L .77414 .10225 L p F P
0 g
s
0 .027 .599 r
.77414 .10225 m .77274 .09798 L .77525 .10147 L p F P
0 g
s
.723 .551 .658 r
.37254 .93744 m .36314 .93703 L .36275 .93515 L p F P
0 g
s
.721 .539 .643 r
.37881 .9441 m .36907 .94371 L .37254 .93744 L p F P
0 g
s
.722 .54 .644 r
.36314 .93703 m .37254 .93744 L .36907 .94371 L p F P
0 g
s
.74 .614 .719 r
.333 .89219 m .33474 .89034 L .33243 .88432 L p F P
0 g
s
.669 .542 .701 r
.47617 .90093 m .4781 .89961 L p .48635 .90614 L F P
0 g
s
.669 .542 .701 r
.48635 .90614 m .4779 .90704 L .47617 .90093 L p F P
0 g
s
.725 .624 .745 r
.35315 .86325 m .35529 .86147 L .36558 .86216 L p F P
0 g
s
.724 .629 .752 r
.36378 .85471 m .35529 .86147 L .36558 .86216 L p F P
0 g
s
.724 .629 .752 r
.36558 .86216 m .36676 .86123 L .36378 .85471 L p F P
0 g
s
.82 .869 .882 r
.70588 .28183 m .70471 .28277 L .70488 .28091 L closepath p F P
0 g
s
.814 .861 .883 r
.70338 .27946 m .70488 .28091 L .70471 .28277 L p F P
0 g
s
.814 .861 .883 r
.69436 .28655 m .70338 .27946 L p .70471 .28277 L F P
0 g
s
.814 .861 .883 r
.69424 .2895 m .69436 .28655 L p .70471 .28277 L F P
0 g
s
.787 .778 .844 r
.67118 .08712 m .66958 .08484 L .66986 .08461 L closepath p F P
0 g
s
.682 .59 .745 r
.45104 .86563 m .45865 .8611 L p .45997 .86951 L F P
0 g
s
.683 .59 .745 r
.45104 .86563 m .45865 .8611 L .44953 .86178 L closepath p F P
0 g
s
.694 .736 .884 r
.71821 .06544 m .70721 .07031 L .70464 .06643 L p F P
0 g
s
.676 .521 .668 r
.46571 .92232 m .46889 .92207 L .47034 .92875 L p F P
0 g
s
.676 .521 .668 r
.47034 .92875 m .45801 .9297 L .46571 .92232 L p F P
0 g
s
.677 .531 .68 r
.46889 .92207 m .46838 .91997 L .46571 .92232 L closepath p F P
0 g
s
.955 .911 .733 r
.77272 .19885 m .77481 .19526 L .77255 .19395 L p F P
0 g
s
.72 .627 .753 r
.37627 .85394 m .36676 .86123 L .36378 .85471 L p F P
0 g
s
.828 .869 .875 r
.71419 .2748 m .70588 .28183 L .70488 .28091 L p F P
0 g
s
.74 .614 .719 r
.33047 .88411 m .32379 .89121 L .333 .89219 L p F P
0 g
s
.74 .614 .719 r
.33243 .88432 m .33047 .88411 L p .333 .89219 L F P
0 g
s
.741 .61 .712 r
.32379 .89121 m .333 .89219 L .32679 .89916 L p F P
0 g
s
.479 .559 .859 r
.60318 .30729 m .60928 .30795 L .60843 .31277 L p F P
0 g
s
.563 .662 .904 r
.6142 .30775 m .60928 .30795 L .60843 .31277 L p F P
0 g
s
.563 .662 .904 r
.60843 .31277 m .61693 .31184 L .6142 .30775 L p F P
0 g
s
.672 .528 .68 r
.46889 .92207 m .46838 .91997 L .47498 .91451 L p F P
0 g
s
.867 .888 .848 r
.73792 .25256 m .73791 .25255 L .73792 .25254 L closepath p F P
0 g
s
.702 .619 .761 r
.41259 .85448 m .40602 .85455 L .40453 .85126 L p F P
0 g
s
.707 .621 .759 r
.40602 .85455 m .40453 .85126 L .39974 .85451 L closepath p F P
0 g
s
.866 .883 .847 r
.73549 .25041 m .73779 .24805 L .73792 .25254 L p F P
0 g
s
.866 .883 .847 r
.73792 .25254 m .73791 .25255 L .73549 .25041 L p F P
0 g
s
.861 .884 .853 r
.73064 .25974 m .73791 .25255 L .73549 .25041 L p F P
0 g
s
.769 .835 .903 r
.67102 .30313 m .66776 .30519 L .66853 .3006 L closepath p F P
0 g
s
.764 .822 .898 r
.66844 .3005 m .66853 .3006 L .66776 .30519 L p F P
0 g
s
.764 .822 .898 r
.6576 .30714 m .66844 .3005 L p .66776 .30519 L F P
0 g
s
.708 .624 .761 r
.40192 .84551 m .40453 .85126 L .39974 .85451 L p F P
0 g
s
.708 .624 .761 r
.4005 .8455 m .40192 .84551 L p .39974 .85451 L F P
0 g
s
.708 .624 .761 r
.39096 .852 m .4005 .8455 L p .39974 .85451 L F P
0 g
s
.708 .624 .761 r
.39974 .85451 m .39208 .85443 L .39096 .852 L p F P
0 g
s
.728 .555 .656 r
.36314 .93703 m .36275 .93515 L .36165 .93695 L closepath p F P
0 g
s
.675 .577 .737 r
.47815 .86841 m .48085 .87581 L .46841 .87706 L p F P
0 g
s
.675 .577 .737 r
.46841 .87706 m .46749 .87456 L .47815 .86841 L p F P
0 g
s
.955 .844 .694 r
.60765 .1986 m .60915 .19546 L .60649 .19351 L p F P
0 g
s
.676 .512 .656 r
.45771 .93003 m .45801 .9297 L .45765 .92973 L closepath p F P
0 g
s
.682 .517 .656 r
.45765 .92973 m .45771 .93003 L .4519 .93668 L p F P
0 g
s
.701 .617 .759 r
.41963 .85437 m .41809 .85092 L .41259 .85448 L closepath p F P
0 g
s
.702 .619 .761 r
.41563 .84542 m .41809 .85092 L .41259 .85448 L p F P
0 g
s
.702 .619 .761 r
.41346 .84544 m .41563 .84542 L p .41259 .85448 L F P
0 g
s
.702 .619 .761 r
.40453 .85126 m .41346 .84544 L p .41259 .85448 L F P
0 g
s
.961 .767 .322 r
.78346 .13986 m .78382 .13524 L .78484 .13959 L p F P
0 g
s
.961 .767 .322 r
.78413 .14271 m .78346 .13986 L p .78484 .13959 L F P
0 g
s
.961 .767 .322 r
.78484 .13959 m .78473 .14106 L .78413 .14271 L p F P
0 g
s
.669 .542 .701 r
.4781 .89961 m .4882 .89852 L p .48635 .90614 L F P
0 g
s
.67 .55 .71 r
.4882 .89852 m .48683 .894 L .4781 .89961 L closepath p F P
0 g
s
.671 .552 .711 r
.48596 .89114 m .48683 .894 L .4781 .89961 L p F P
0 g
s
.681 .587 .744 r
.46546 .86905 m .46459 .86679 L .45997 .86951 L closepath p F P
0 g
s
.682 .59 .745 r
.46227 .86081 m .46459 .86679 L .45997 .86951 L p F P
0 g
s
.682 .59 .745 r
.45865 .8611 m .46227 .86081 L p .45997 .86951 L F P
0 g
s
.674 .511 .656 r
.45801 .9297 m .47034 .92875 L p .46934 .93545 L F P
0 g
s
.674 .511 .656 r
.45771 .93003 m .45801 .9297 L p .46934 .93545 L F P
0 g
s
.85 .799 .801 r
.63766 .1175 m .6417 .11294 L .6439 .11697 L p F P
0 g
s
.85 .799 .801 r
.6439 .11697 m .64032 .12099 L .63766 .1175 L p F P
0 g
s
.712 .626 .759 r
.39208 .85443 m .39096 .852 L .38769 .85431 L closepath p F P
0 g
s
.674 .511 .656 r
.46934 .93545 m .45889 .93624 L .45771 .93003 L p F P
0 g
s
.68 .514 .655 r
.45889 .93624 m .45771 .93003 L .4519 .93668 L closepath p F P
0 g
s
.691 .603 .753 r
.43458 .85781 m .44167 .85348 L .43295 .85393 L closepath p F P
0 g
s
.707 .528 .644 r
.40433 .9445 m .39302 .94443 L .39276 .94296 L p F P
0 g
s
.713 .532 .643 r
.39302 .94443 m .39276 .94296 L .39192 .94441 L closepath p F P
0 g
s
.696 .615 .761 r
.42647 .85416 m .41963 .85437 L .41809 .85092 L p F P
0 g
s
.668 .534 .692 r
.47905 .9114 m .48635 .90614 L .4779 .90704 L closepath p F P
0 g
s
.674 .537 .69 r
.4779 .90704 m .47905 .9114 L .47498 .91451 L p F P
0 g
s
.738 .581 .679 r
.33464 .91454 m .32985 .92114 L .3395 .92198 L p F P
0 g
s
.74 .585 .682 r
.32762 .9139 m .33464 .91454 L .32985 .92114 L p F P
0 g
s
.739 .592 .693 r
.32687 .91147 m .33041 .90694 L p .33464 .91454 L F P
0 g
s
.739 .592 .693 r
.33464 .91454 m .32762 .9139 L .32687 .91147 L p F P
0 g
s
.676 .578 .737 r
.47794 .86783 m .47815 .86841 L .46749 .87456 L p F P
0 g
s
.676 .578 .737 r
.46749 .87456 m .46546 .86905 L .47794 .86783 L p F P
0 g
s
.67 .517 .669 r
.46889 .92207 m .4814 .92091 L p .47652 .92819 L F P
0 g
s
.67 .517 .669 r
.47652 .92819 m .47034 .92875 L .46889 .92207 L p F P
0 g
s
.672 .528 .68 r
.47975 .91406 m .4814 .92091 L .46889 .92207 L p F P
0 g
s
.672 .528 .68 r
.47498 .91451 m .47975 .91406 L p .46889 .92207 L F P
0 g
s
.912 .823 .746 r
.61504 .16367 m .6169 .16778 L .62056 .16196 L p F P
0 g
s
.912 .823 .746 r
.62056 .16196 m .61864 .15788 L .61504 .16367 L p F P
0 g
s
.436 .586 .904 r
.75259 .07785 m .75084 .07762 L .74831 .07336 L p F P
0 g
s
.736 .571 .668 r
.34679 .92939 m .34628 .9273 L .34499 .92925 L closepath p F P
0 g
s
.713 .628 .761 r
.388 .84558 m .39096 .852 L .38769 .85431 L p F P
0 g
s
.713 .628 .761 r
.37738 .85312 m .388 .84558 L p .38769 .85431 L F P
0 g
s
.713 .628 .761 r
.38769 .85431 m .3778 .85401 L .37738 .85312 L p F P
0 g
s
.672 .536 .69 r
.47975 .91406 m .47905 .9114 L .47498 .91451 L closepath p F P
0 g
s
.834 .876 .873 r
.7166 .27271 m .71419 .2748 L .71445 .27077 L closepath p F P
0 g
s
.828 .869 .875 r
.71413 .27047 m .71445 .27077 L .71419 .2748 L p F P
0 g
s
.828 .869 .875 r
.70494 .27818 m .71413 .27047 L p .71419 .2748 L F P
0 g
s
.828 .869 .875 r
.70488 .28091 m .70494 .27818 L p .71419 .2748 L F P
0 g
s
.741 .799 .899 r
.64922 .31187 m .64675 .31325 L .64411 .31022 L p F P
0 g
s
.712 .79 .913 r
.63324 .31534 m .64411 .31022 L .64675 .31325 L p F P
0 g
s
.861 .884 .853 r
.73549 .25041 m .73063 .25521 L .73064 .25974 L p F P
0 g
s
.855 .88 .857 r
.72483 .26079 m .73063 .25521 L .73064 .25974 L p F P
0 g
s
.855 .88 .857 r
.73064 .25974 m .72728 .26297 L .72483 .26079 L p F P
0 g
s
.684 .598 .753 r
.45865 .8611 m .44953 .86178 L .44813 .85839 L p F P
0 g
s
.741 .594 .692 r
.32687 .91147 m .33041 .90694 L .3253 .90644 L closepath p F P
0 g
s
.74 .601 .702 r
.32397 .90253 m .32679 .89916 L p .33041 .90694 L F P
0 g
s
.74 .601 .702 r
.33041 .90694 m .3253 .90644 L .32397 .90253 L p F P
0 g
s
.736 .571 .669 r
.3395 .92198 m .33526 .92844 L .34499 .92925 L p F P
0 g
s
.739 .574 .67 r
.32985 .92114 m .3395 .92198 L .33526 .92844 L p F P
0 g
s
.722 .54 .644 r
.36907 .94371 m .36427 .9435 L .36314 .93703 L p F P
0 g
s
.728 .544 .642 r
.36165 .93695 m .36314 .93703 L .36427 .9435 L p F P
0 g
s
.68 .506 .644 r
.44699 .94306 m .4519 .93668 L .44598 .93702 L closepath p F P
0 g
s
.686 .51 .643 r
.44598 .93702 m .44699 .94306 L .44674 .9434 L p F P
0 g
s
.842 .876 .866 r
.72277 .26714 m .7166 .27271 L .71445 .27077 L p F P
0 g
s
.732 .623 .737 r
.34249 .87257 m .34618 .86925 L .34088 .86881 L closepath p F P
0 g
s
.735 .627 .738 r
.34088 .86881 m .34249 .87257 L .33796 .87678 L p F P
0 g
s
.848 .88 .864 r
.72277 .26714 m .72728 .26297 L .72483 .26079 L p F P
0 g
s
.74 .622 .727 r
.33243 .88432 m .33179 .88277 L .33047 .88411 L closepath p F P
0 g
s
0 0 .48 r
.5961 .28974 m .59602 .28747 L .59751 .29316 L closepath p F P
0 g
s
.737 .62 .729 r
.33179 .88277 m .33796 .87678 L .32897 .87591 L closepath p F P
0 g
s
.735 .627 .738 r
.33658 .86837 m .34088 .86881 L p .33796 .87678 L F P
0 g
s
.735 .627 .738 r
.32883 .87557 m .33658 .86837 L p .33796 .87678 L F P
0 g
s
.735 .627 .738 r
.33796 .87678 m .32897 .87591 L .32883 .87557 L p F P
0 g
s
.73 .63 .746 r
.35226 .86126 m .35315 .86325 L .34618 .86925 L p F P
0 g
s
.73 .63 .746 r
.34544 .86066 m .35226 .86126 L p .34618 .86925 L F P
0 g
s
.73 .63 .746 r
.33951 .86577 m .34544 .86066 L p .34618 .86925 L F P
0 g
s
.73 .63 .746 r
.34618 .86925 m .34088 .86881 L .33951 .86577 L p F P
0 g
s
.848 .88 .864 r
.72483 .26079 m .72291 .26257 L .72277 .26714 L p F P
0 g
s
.842 .876 .866 r
.71445 .27019 m .72291 .26257 L .72277 .26714 L p F P
0 g
s
.842 .876 .866 r
.71445 .27077 m .71445 .27019 L p .72277 .26714 L F P
0 g
s
.699 .509 .628 r
.40691 .9445 m .41748 .94439 L .41415 .95064 L p F P
0 g
s
.699 .509 .628 r
.41415 .95064 m .40775 .95071 L .40691 .9445 L p F P
0 g
s
.704 .513 .628 r
.40433 .9445 m .40691 .9445 L .40775 .95071 L p F P
0 g
s
.704 .513 .628 r
.40775 .95071 m .4012 .95069 L .40433 .9445 L p F P
0 g
s
.706 .515 .628 r
.39302 .94443 m .40433 .9445 L .4012 .95069 L p F P
0 g
s
.695 .612 .76 r
.43295 .85393 m .43165 .85097 L .42647 .85416 L closepath p F P
0 g
s
.696 .615 .761 r
.42904 .84505 m .43165 .85097 L .42647 .85416 L p F P
0 g
s
.696 .615 .761 r
.42745 .8451 m .42904 .84505 L p .42647 .85416 L F P
0 g
s
.696 .615 .761 r
.41809 .85092 m .42745 .8451 L p .42647 .85416 L F P
0 g
s
.728 .544 .642 r
.36427 .9435 m .35837 .94316 L .36165 .93695 L p F P
0 g
s
.729 .546 .645 r
.35128 .93631 m .36165 .93695 L .35837 .94316 L p F P
0 g
s
.686 .51 .643 r
.44674 .9434 m .43391 .94397 L .43345 .94124 L p F P
0 g
s
.691 .514 .643 r
.43391 .94397 m .43345 .94124 L .43154 .94405 L closepath p F P
0 g
s
.736 .561 .656 r
.34499 .92925 m .34679 .92939 L .34822 .93611 L p F P
0 g
s
.731 .558 .657 r
.35128 .93631 m .34822 .93611 L .34679 .92939 L p F P
0 g
s
.706 .515 .628 r
.4012 .95069 m .39385 .95064 L .39302 .94443 L p F P
0 g
s
.711 .519 .627 r
.39192 .94441 m .39302 .94443 L .39385 .95064 L p F P
0 g
s
.878 .727 .213 r
.59489 .26724 m .59523 .27173 L .59566 .26701 L p F P
0 g
s
.878 .727 .213 r
.59566 .26701 m .59528 .26254 L .59489 .26724 L p F P
0 g
s
.711 .519 .627 r
.39385 .95064 m .38897 .95055 L .39192 .94441 L p F P
0 g
s
.713 .521 .629 r
.38019 .94414 m .39192 .94441 L .38897 .95055 L p F P
0 g
s
.785 .838 .892 r
.67926 .29319 m .68182 .29581 L .67102 .30313 L p F P
0 g
s
.785 .838 .892 r
.66854 .30043 m .67926 .29319 L p .67102 .30313 L F P
0 g
s
.785 .838 .892 r
.67102 .30313 m .66853 .3006 L .66854 .30043 L p F P
0 g
s
0 0 .347 r
.5962 .28514 m .59602 .28747 L .59521 .28204 L p F P
0 g
s
0 0 .347 r
.59521 .28204 m .59529 .28088 L .5962 .28514 L p F P
0 g
s
.87 .8 .779 r
.63839 .12347 m .64032 .12099 L .63766 .1175 L p F P
0 g
s
.697 .508 .628 r
.41748 .94439 m .42054 .94435 L .42137 .95054 L p F P
0 g
s
.697 .508 .628 r
.42137 .95054 m .41415 .95064 L .41748 .94439 L p F P
0 g
s
.74 .622 .727 r
.33047 .88411 m .33179 .88277 L .32897 .87591 L p F P
0 g
s
.668 .533 .691 r
.47975 .91406 m .47905 .9114 L .48635 .90614 L p F P
0 g
s
.808 .853 .884 r
.69424 .2895 m .69261 .2879 L .69436 .28655 L closepath p F P
0 g
s
.726 .626 .746 r
.35315 .86325 m .35529 .86147 L .35226 .86126 L closepath p F P
0 g
s
.691 .504 .628 r
.42054 .94435 m .43154 .94405 L .42798 .95036 L p F P
0 g
s
.691 .504 .628 r
.42798 .95036 m .42137 .95054 L .42054 .94435 L p F P
0 g
s
.718 .63 .759 r
.3778 .85401 m .37738 .85312 L .37627 .85394 L closepath p F P
0 g
s
.709 .625 .761 r
.4005 .8455 m .39096 .852 L .388 .84558 L p F P
0 g
s
.703 .62 .761 r
.40453 .85126 m .41346 .84544 L .40192 .84551 L closepath p F P
0 g
s
.677 .585 .745 r
.47525 .86083 m .47794 .86783 L .46546 .86905 L p F P
0 g
s
.677 .585 .745 r
.46546 .86905 m .46459 .86679 L .47525 .86083 L p F P
0 g
s
.742 .618 .721 r
.3214 .88309 m .33047 .88411 L .32379 .89121 L p F P
0 g
s
.74 .622 .727 r
.32853 .87586 m .3214 .88309 L .33047 .88411 L p F P
0 g
s
.74 .622 .727 r
.32897 .87591 m .32853 .87586 L p .33047 .88411 L F P
0 g
s
0 .196 .724 r
.7682 .09146 m .77024 .09555 L .77274 .09798 L p F P
0 g
s
.742 .602 .702 r
.32397 .90253 m .32679 .89916 L .32267 .89873 L closepath p F P
0 g
s
.741 .61 .712 r
.32104 .8943 m .32379 .89121 L p .32679 .89916 L F P
0 g
s
.741 .61 .712 r
.32679 .89916 m .32267 .89873 L .32104 .8943 L p F P
0 g
s
.736 .561 .656 r
.34822 .93611 m .34131 .93556 L .34499 .92925 L p F P
0 g
s
.737 .564 .658 r
.33526 .92844 m .34499 .92925 L .34131 .93556 L p F P
0 g
s
.725 .632 .754 r
.36311 .85325 m .36378 .85471 L .35529 .86147 L p F P
0 g
s
.725 .632 .754 r
.35528 .85268 m .36311 .85325 L p .35529 .86147 L F P
0 g
s
.725 .632 .754 r
.35016 .85676 m .35528 .85268 L p .35529 .86147 L F P
0 g
s
.725 .632 .754 r
.35529 .86147 m .35226 .86126 L .35016 .85676 L p F P
0 g
s
.72 .627 .753 r
.36378 .85471 m .36551 .85338 L .37627 .85394 L p F P
0 g
s
.719 .632 .76 r
.37441 .84682 m .36551 .85338 L .37627 .85394 L p F P
0 g
s
.719 .632 .76 r
.37627 .85394 m .37738 .85312 L .37441 .84682 L p F P
0 g
s
.69 .61 .761 r
.44167 .85348 m .43295 .85393 L .43165 .85097 L p F P
0 g
s
.57 .673 .909 r
.7364 .0699 m .73444 .07016 L .7319 .06612 L p F P
0 g
s
.494 .535 .828 r
.60111 .30288 m .60318 .30729 L .60928 .30795 L p F P
0 g
s
.68 .506 .644 r
.4519 .93668 m .45889 .93624 L p .44705 .94339 L F P
0 g
s
.68 .506 .644 r
.44705 .94339 m .44699 .94306 L .4519 .93668 L p F P
0 g
s
.738 .802 .903 r
.64922 .31187 m .6576 .30714 L .65498 .3043 L p F P
0 g
s
.738 .802 .903 r
.65498 .3043 m .64959 .30725 L .64922 .31187 L p F P
0 g
s
.741 .799 .899 r
.64411 .31022 m .64959 .30725 L .64922 .31187 L p F P
0 g
s
.684 .598 .753 r
.44813 .85839 m .45861 .85233 L p .45865 .8611 L F P
0 g
s
.684 .598 .754 r
.44813 .85839 m .45861 .85233 L .446 .85324 L closepath p F P
0 g
s
.715 .63 .761 r
.388 .84558 m .37738 .85312 L .37441 .84682 L p F P
0 g
s
.666 .523 .681 r
.47975 .91406 m .49208 .91273 L p .48537 .92049 L F P
0 g
s
.666 .523 .681 r
.48537 .92049 m .4814 .92091 L .47975 .91406 L p F P
0 g
s
.668 .533 .691 r
.49024 .90571 m .49208 .91273 L .47975 .91406 L p F P
0 g
s
.668 .533 .691 r
.48635 .90614 m .49024 .90571 L p .47975 .91406 L F P
0 g
s
.697 .616 .761 r
.41809 .85092 m .42745 .8451 L .41563 .84542 L closepath p F P
0 g
s
.912 .901 .802 r
.7555 .22335 m .7604 .217 L .76071 .22148 L p F P
0 g
s
.912 .901 .802 r
.75573 .22618 m .7555 .22335 L p .76071 .22148 L F P
0 g
s
.912 .901 .802 r
.76071 .22148 m .75658 .22684 L .75573 .22618 L p F P
0 g
s
.957 .77 .321 r
.78473 .14106 m .78444 .14423 L .78413 .14271 L closepath p F P
0 g
s
.677 .586 .746 r
.47477 .8596 m .47525 .86083 L .46459 .86679 L p F P
0 g
s
.677 .586 .746 r
.46459 .86679 m .46227 .86081 L .47477 .8596 L p F P
0 g
s
.713 .521 .629 r
.37912 .94636 m .38019 .94414 L p .38897 .95055 L F P
0 g
s
.714 .523 .629 r
.37912 .94636 m .38019 .94414 L .37881 .9441 L closepath p F P
0 g
s
.661 .752 .917 r
.61965 .31575 m .63056 .31201 L .63324 .31534 L p F P
0 g
s
.644 .738 .918 r
.63056 .31201 m .61965 .31575 L .61693 .31184 L p F P
0 g
s
.955 .911 .733 r
.77255 .19395 m .7723 .19438 L .77272 .19885 L p F P
0 g
s
.942 .907 .758 r
.76854 .2003 m .76901 .20475 L .77272 .19885 L p F P
0 g
s
.942 .907 .758 r
.77272 .19885 m .7723 .19438 L .76854 .2003 L p F P
0 g
s
.719 .526 .628 r
.37881 .9441 m .36907 .94371 L p .37732 .95026 L F P
0 g
s
.719 .526 .628 r
.37732 .95026 m .37912 .94636 L .37881 .9441 L p F P
0 g
s
.732 .756 .872 r
.69956 .06935 m .69374 .07266 L .69116 .06882 L p F P
0 g
s
.736 .632 .744 r
.34088 .86881 m .33951 .86577 L .33658 .86837 L closepath p F P
0 g
s
.745 .596 .691 r
.3253 .90644 m .32119 .90597 L p .32522 .91364 L F P
0 g
s
.745 .596 .691 r
.32522 .91364 m .32687 .91147 L .3253 .90644 L p F P
0 g
s
.746 .604 .7 r
.3253 .90644 m .32397 .90253 L .32119 .90597 L closepath p F P
0 g
s
.73 .634 .752 r
.35226 .86126 m .35016 .85676 L .34544 .86066 L closepath p F P
0 g
s
.87 .8 .779 r
.63128 .12572 m .63348 .12974 L .63839 .12347 L p F P
0 g
s
.87 .8 .779 r
.63839 .12347 m .63614 .11946 L .63128 .12572 L p F P
0 g
s
.87 .8 .779 r
.63766 .1175 m .63614 .11946 L .63839 .12347 L p F P
0 g
s
.69 .501 .627 r
.43154 .94405 m .43391 .94397 L .43473 .95015 L p F P
0 g
s
.69 .501 .627 r
.43473 .95015 m .42798 .95036 L .43154 .94405 L p F P
0 g
s
.889 .813 .767 r
.62025 .14801 m .62224 .15208 L .62657 .14603 L p F P
0 g
s
.889 .813 .767 r
.62657 .14603 m .62451 .14197 L .62025 .14801 L p F P
0 g
s
.745 .595 .69 r
.32762 .9139 m .32687 .91147 L .32522 .91364 L closepath p F P
0 g
s
.74 .585 .682 r
.32985 .92114 m .32967 .92113 L .32762 .9139 L p F P
0 g
s
.746 .588 .68 r
.32522 .91364 m .32762 .9139 L .32967 .92113 L p F P
0 g
s
.746 .604 .7 r
.32119 .90597 m .32397 .90253 L .32267 .89873 L p F P
0 g
s
.895 .824 .77 r
.62285 .15346 m .62196 .15248 L .62224 .15208 L closepath p F P
0 g
s
.994 .858 .519 r
.78228 .15404 m .78312 .15843 L .78438 .15345 L p F P
0 g
s
.994 .858 .519 r
.78438 .15345 m .78357 .14905 L .78228 .15404 L p F P
0 g
s
.97 .872 .683 r
.60026 .21481 m .60266 .20943 L .60391 .21368 L p F P
0 g
s
.97 .872 .683 r
.60136 .21885 m .60026 .21481 L p .60391 .21368 L F P
0 g
s
.97 .872 .683 r
.60391 .21368 m .60151 .21891 L .60136 .21885 L p F P
0 g
s
.703 .783 .913 r
.64411 .31022 m .63324 .31534 L .63056 .31201 L p F P
0 g
s
.684 .497 .628 r
.43391 .94397 m .44674 .9434 L .44292 .94979 L p F P
0 g
s
.684 .497 .628 r
.44292 .94979 m .43473 .95015 L .43391 .94397 L p F P
0 g
s
.955 .844 .694 r
.60649 .19351 m .60604 .19446 L .60765 .1986 L p F P
0 g
s
.959 .844 .686 r
.60359 .19985 m .60513 .20402 L .60765 .1986 L p F P
0 g
s
.959 .844 .686 r
.60765 .1986 m .60604 .19446 L .60359 .19985 L p F P
0 g
s
.918 .687 .191 r
.78272 .1309 m .78382 .13524 L .78372 .13079 L p F P
0 g
s
.918 .687 .191 r
.78372 .13079 m .78262 .12646 L .78272 .1309 L p F P
0 g
s
.682 .595 .752 r
.46227 .86081 m .46168 .85937 L .45865 .8611 L closepath p F P
0 g
s
.684 .598 .753 r
.4588 .85231 m .46168 .85937 L .45865 .8611 L p F P
0 g
s
.684 .598 .753 r
.45861 .85233 m .4588 .85231 L p .45865 .8611 L F P
0 g
s
.742 .618 .721 r
.31809 .8866 m .3214 .88309 L p .32379 .89121 L F P
0 g
s
.742 .618 .721 r
.32379 .89121 m .31974 .89077 L .31809 .8866 L p F P
0 g
s
.743 .611 .712 r
.32104 .8943 m .32379 .89121 L .31974 .89077 L closepath p F P
0 g
s
.746 .604 .7 r
.32267 .89873 m .31774 .89814 L p .32119 .90597 L F P
0 g
s
.746 .613 .71 r
.32267 .89873 m .32104 .8943 L .31774 .89814 L closepath p F P
0 g
s
.991 .864 .611 r
.59774 .22949 m .59883 .23377 L .60069 .22857 L p F P
0 g
s
.991 .864 .611 r
.60069 .22857 m .59952 .22431 L .59774 .22949 L p F P
0 g
s
.666 .556 .72 r
.49295 .8903 m .48596 .89114 L .48394 .88489 L p F P
0 g
s
.665 .547 .711 r
.48683 .894 m .49295 .8903 L .48596 .89114 L closepath p F P
0 g
s
.721 .629 .754 r
.36378 .85471 m .36551 .85338 L .36311 .85325 L closepath p F P
0 g
s
.69 .61 .761 r
.43165 .85097 m .44228 .84468 L p .44167 .85348 L F P
0 g
s
.691 .611 .761 r
.44217 .84441 m .44228 .84468 L .43165 .85097 L p F P
0 g
s
.691 .611 .761 r
.43165 .85097 m .42904 .84505 L .44217 .84441 L p F P
0 g
s
.73 .548 .644 r
.34902 .94056 m .35128 .93631 L .34822 .93611 L closepath p F P
0 g
s
.729 .546 .645 r
.34902 .94056 m .35128 .93631 L p .35837 .94316 L F P
0 g
s
.69 .61 .761 r
.44228 .84468 m .44521 .85141 L .44167 .85348 L p F P
0 g
s
.689 .608 .76 r
.446 .85324 m .44521 .85141 L .44167 .85348 L closepath p F P
0 g
s
.794 .845 .89 r
.68232 .2963 m .68182 .29581 L .68237 .29542 L closepath p F P
0 g
s
.666 .556 .72 r
.48394 .88489 m .48687 .88318 L p .49295 .8903 L F P
0 g
s
.667 .556 .72 r
.48394 .88489 m .48687 .88318 L .48352 .88358 L closepath p F P
0 g
s
.668 .564 .729 r
.48687 .88318 m .48352 .88358 L .48105 .8764 L p F P
0 g
s
.668 .507 .657 r
.47125 .93343 m .47652 .92819 L .47034 .92875 L closepath p F P
0 g
s
.674 .511 .656 r
.47034 .92875 m .47125 .93343 L .46934 .93545 L p F P
0 g
s
.665 .547 .711 r
.4882 .89852 m .48683 .894 L .49295 .8903 L p F P
0 g
s
.668 .541 .701 r
.49024 .90571 m .48972 .90388 L .48635 .90614 L closepath p F P
0 g
s
.669 .542 .701 r
.4882 .89852 m .48972 .90388 L .48635 .90614 L p F P
0 g
s
.436 .586 .904 r
.74831 .07336 m .7508 .07366 L .75259 .07785 L p F P
0 g
s
.37 .542 .895 r
.75795 .07534 m .75962 .07958 L .75259 .07785 L p F P
0 g
s
.37 .542 .895 r
.75259 .07785 m .7508 .07366 L .75795 .07534 L p F P
0 g
s
.673 .5 .644 r
.45889 .93624 m .46934 .93545 L .4637 .9423 L p F P
0 g
s
.673 .5 .644 r
.4637 .9423 m .45994 .94259 L .45889 .93624 L p F P
0 g
s
.68 .506 .644 r
.45889 .93624 m .45994 .94259 L .44705 .94339 L p F P
0 g
s
.937 .837 .72 r
.60736 .18472 m .60901 .18887 L .61209 .18326 L p F P
0 g
s
.937 .837 .72 r
.61209 .18326 m .61037 .17913 L .60736 .18472 L p F P
0 g
s
.746 .588 .68 r
.32967 .92113 m .32071 .92017 L .32522 .91364 L p F P
0 g
s
.746 .59 .683 r
.31618 .91263 m .32522 .91364 L .32071 .92017 L p F P
0 g
s
.745 .596 .691 r
.32119 .90597 m .31618 .91263 L .32522 .91364 L p F P
0 g
s
.72 .635 .762 r
.37343 .84476 m .37441 .84682 L .36551 .85338 L p F P
0 g
s
.72 .635 .762 r
.36632 .84435 m .37343 .84476 L p .36551 .85338 L F P
0 g
s
.72 .635 .762 r
.3608 .84844 m .36632 .84435 L p .36551 .85338 L F P
0 g
s
.72 .635 .762 r
.36551 .85338 m .36311 .85325 L .3608 .84844 L p F P
0 g
s
.739 .574 .67 r
.32972 .92134 m .32985 .92114 L p .33526 .92844 L F P
0 g
s
.74 .575 .669 r
.32972 .92134 m .32985 .92114 L .32967 .92113 L closepath p F P
0 g
s
.745 .578 .668 r
.32967 .92113 m .32071 .92017 L p .32583 .92754 L F P
0 g
s
.745 .578 .668 r
.32583 .92754 m .32972 .92134 L .32967 .92113 L p F P
0 g
s
.719 .526 .628 r
.36907 .94371 m .36621 .94982 L .37732 .95026 L p F P
0 g
s
.721 .529 .63 r
.36427 .9435 m .36907 .94371 L .36621 .94982 L p F P
0 g
s
.739 .574 .67 r
.33526 .92844 m .33141 .92811 L .32972 .92134 L p F P
0 g
s
.744 .577 .668 r
.33141 .92811 m .32972 .92134 L .32583 .92754 L closepath p F P
0 g
s
.663 .538 .702 r
.48972 .90388 m .4882 .89852 L .50038 .89702 L p F P
0 g
s
.665 .547 .711 r
.49814 .88965 m .50038 .89702 L .4882 .89852 L p F P
0 g
s
.665 .547 .711 r
.49295 .8903 m .49814 .88965 L p .4882 .89852 L F P
0 g
s
.741 .629 .736 r
.32897 .87591 m .32883 .87557 L .32853 .87586 L closepath p F P
0 g
s
.738 .628 .737 r
.33658 .86837 m .32883 .87557 L .32584 .86877 L p F P
0 g
s
.738 .628 .737 r
.32584 .86877 m .3273 .8674 L .33658 .86837 L p F P
0 g
s
.736 .632 .744 r
.33583 .85978 m .3273 .8674 L .33658 .86837 L p F P
0 g
s
.736 .632 .744 r
.33685 .85989 m .33583 .85978 L p .33658 .86837 L F P
0 g
s
.736 .632 .744 r
.33658 .86837 m .33951 .86577 L .33685 .85989 L p F P
0 g
s
.747 .613 .71 r
.31774 .89814 m .32104 .8943 L .31974 .89077 L p F P
0 g
s
.967 .903 .704 r
.77485 .18426 m .77548 .18867 L .77832 .1831 L p F P
0 g
s
.967 .903 .704 r
.77832 .1831 m .77772 .17866 L .77485 .18426 L p F P
0 g
s
.735 .551 .643 r
.34822 .93611 m .34131 .93556 L p .34801 .94252 L F P
0 g
s
.735 .551 .643 r
.34801 .94252 m .34902 .94056 L .34822 .93611 L p F P
0 g
s
.732 .631 .746 r
.33951 .86577 m .34544 .86066 L .33685 .85989 L closepath p F P
0 g
s
.678 .593 .754 r
.47234 .85359 m .47477 .8596 L .46227 .86081 L p F P
0 g
s
.678 .593 .754 r
.46227 .86081 m .46168 .85937 L .47234 .85359 L p F P
0 g
s
.991 .878 .551 r
.59562 .24401 m .59712 .23892 L .59786 .24332 L p F P
0 g
s
.991 .878 .551 r
.59616 .24764 m .59562 .24401 L p .59786 .24332 L F P
0 g
s
.991 .878 .551 r
.59786 .24332 m .59663 .24732 L .59616 .24764 L p F P
0 g
s
.741 .63 .736 r
.32853 .87586 m .32883 .87557 L .32584 .86877 L p F P
0 g
s
.713 .521 .629 r
.38897 .95055 m .37967 .95034 L .37912 .94636 L p F P
0 g
s
.718 .525 .628 r
.37967 .95034 m .37912 .94636 L .37732 .95026 L closepath p F P
0 g
s
.742 .626 .73 r
.31961 .87479 m .32853 .87586 L .3214 .88309 L p F P
0 g
s
.741 .63 .736 r
.32584 .86877 m .31961 .87479 L .32853 .87586 L p F P
0 g
s
.747 .599 .693 r
.31225 .90493 m .32119 .90597 L .31618 .91263 L p F P
0 g
s
.746 .604 .7 r
.31774 .89814 m .31225 .90493 L .32119 .90597 L p F P
0 g
s
.725 .637 .76 r
.36311 .85325 m .3608 .84844 L .35528 .85268 L closepath p F P
0 g
s
.668 .564 .729 r
.48105 .8764 m .48241 .87563 L p .48687 .88318 L F P
0 g
s
.669 .565 .729 r
.48105 .8764 m .48241 .87563 L .48085 .87581 L closepath p F P
0 g
s
.684 .605 .761 r
.45861 .85233 m .446 .85324 L .44521 .85141 L p F P
0 g
s
.821 .861 .877 r
.70488 .28091 m .70338 .27946 L .70494 .27818 L closepath p F P
0 g
s
.988 .886 .625 r
.77947 .16881 m .78026 .1732 L .78225 .16794 L p F P
0 g
s
.988 .886 .625 r
.78225 .16794 m .78147 .16355 L .77947 .16881 L p F P
0 g
s
.669 .573 .738 r
.48241 .87563 m .48085 .87581 L .47815 .86841 L p F P
0 g
s
.762 .768 .858 r
.68122 .07756 m .68033 .07626 L .68049 .07615 L closepath p F P
0 g
s
0 0 .3 r
.59622 .28054 m .5962 .28514 L .59529 .28088 L p F P
0 g
s
0 0 .3 r
.59529 .28088 m .59536 .27626 L .59622 .28054 L p F P
0 g
s
.664 .513 .669 r
.48193 .92337 m .48537 .92049 L .4814 .92091 L closepath p F P
0 g
s
.67 .517 .669 r
.4814 .92091 m .48193 .92337 L .47652 .92819 L p F P
0 g
s
.731 .637 .754 r
.348 .85213 m .35016 .85676 L .34544 .86066 L p F P
0 g
s
.731 .637 .754 r
.34536 .85188 m .348 .85213 L p .34544 .86066 L F P
0 g
s
.731 .637 .754 r
.33652 .85919 m .34536 .85188 L p .34544 .86066 L F P
0 g
s
.731 .637 .754 r
.34544 .86066 m .33685 .85989 L .33652 .85919 L p F P
0 g
s
.737 .564 .658 r
.33251 .9331 m .33526 .92844 L p .34131 .93556 L F P
0 g
s
.739 .565 .658 r
.33251 .9331 m .33526 .92844 L .33141 .92811 L closepath p F P
0 g
s
.721 .529 .63 r
.36621 .94982 m .36516 .94977 L .36427 .9435 L p F P
0 g
s
.727 .533 .629 r
.35837 .94316 m .36427 .9435 L .36516 .94977 L p F P
0 g
s
.57 .673 .909 r
.7319 .06612 m .73439 .06578 L .7364 .0699 L p F P
0 g
s
.544 .653 .906 r
.74324 .06496 m .73439 .06578 L .7364 .0699 L p F P
0 g
s
.544 .653 .906 r
.7364 .0699 m .74578 .06914 L .74324 .06496 L p F P
0 g
s
.678 .594 .754 r
.47134 .85112 m .47234 .85359 L .46168 .85937 L p F P
0 g
s
.678 .594 .754 r
.46168 .85937 m .4588 .85231 L .47134 .85112 L p F P
0 g
s
.747 .621 .719 r
.31974 .89077 m .31809 .8866 L .31486 .89015 L closepath p F P
0 g
s
.747 .613 .71 r
.31974 .89077 m .31486 .89015 L p .31774 .89814 L F P
0 g
s
.913 .829 .75 r
.61152 .16932 m .61504 .16367 L .6169 .16778 L p F P
0 g
s
.913 .829 .75 r
.6169 .16778 m .6142 .17206 L .61152 .16932 L p F P
0 g
s
.663 .538 .702 r
.49024 .90571 m .48972 .90388 L .50041 .89713 L p F P
0 g
s
.663 .538 .702 r
.50038 .89702 m .50041 .89713 L .48972 .90388 L p F P
0 g
s
.906 .903 .81 r
.75658 .22684 m .7558 .22782 L .75573 .22618 L closepath p F P
0 g
s
.684 .509 .643 r
.44705 .94339 m .44699 .94306 L .44674 .9434 L closepath p F P
0 g
s
.666 .556 .72 r
.48687 .88318 m .49571 .88209 L p .49295 .8903 L F P
0 g
s
.667 .563 .728 r
.49571 .88209 m .49462 .8789 L .48687 .88318 L closepath p F P
0 g
s
.668 .564 .729 r
.49306 .87434 m .49462 .8789 L .48687 .88318 L p F P
0 g
s
.668 .564 .729 r
.48241 .87563 m .49306 .87434 L p .48687 .88318 L F P
0 g
s
.702 .627 .769 r
.41346 .84544 m .40192 .84551 L .40158 .84479 L p F P
0 g
s
.707 .629 .767 r
.40192 .84551 m .40158 .84479 L .4005 .8455 L closepath p F P
0 g
s
.668 .571 .737 r
.49306 .87434 m .49172 .87064 L .48241 .87563 L closepath p F P
0 g
s
.669 .573 .738 r
.49018 .86637 m .49172 .87064 L .48241 .87563 L p F P
0 g
s
.669 .573 .738 r
.47955 .86764 m .49018 .86637 L p .48241 .87563 L F P
0 g
s
.669 .573 .738 r
.47815 .86841 m .47955 .86764 L p .48241 .87563 L F P
0 g
s
.709 .625 .761 r
.388 .84558 m .38839 .84532 L .4005 .8455 L p F P
0 g
s
.708 .631 .768 r
.39862 .83861 m .38839 .84532 L .4005 .8455 L p F P
0 g
s
.708 .631 .768 r
.4005 .8455 m .40158 .84479 L .39862 .83861 L p F P
0 g
s
.682 .495 .627 r
.44674 .9434 m .44705 .94339 L .44786 .94955 L p F P
0 g
s
.682 .495 .627 r
.44786 .94955 m .44292 .94979 L .44674 .9434 L p F P
0 g
s
.677 .491 .628 r
.44705 .94339 m .45994 .94259 L p .45925 .94886 L F P
0 g
s
.677 .491 .628 r
.45925 .94886 m .44786 .94955 L .44705 .94339 L p F P
0 g
s
.661 .528 .692 r
.49024 .90571 m .50239 .90419 L p .49652 .91218 L F P
0 g
s
.661 .528 .692 r
.49652 .91218 m .49208 .91273 L .49024 .90571 L p F P
0 g
s
.663 .538 .702 r
.50041 .89713 m .50239 .90419 L .49024 .90571 L p F P
0 g
s
.685 .605 .761 r
.45585 .84546 m .44521 .85141 L .44228 .84468 L p F P
0 g
s
.684 .605 .761 r
.44521 .85141 m .45585 .84546 L p .45861 .85233 L F P
0 g
s
.702 .624 .767 r
.41563 .84542 m .41515 .84438 L .41346 .84544 L closepath p F P
0 g
s
.702 .627 .769 r
.4122 .83812 m .41515 .84438 L .41346 .84544 L p F P
0 g
s
.702 .627 .769 r
.40158 .84479 m .4122 .83812 L p .41346 .84544 L F P
0 g
s
.743 .619 .721 r
.31809 .8866 m .3214 .88309 L .31647 .88252 L closepath p F P
0 g
s
.742 .626 .73 r
.31512 .87932 m .31961 .87479 L p .3214 .88309 L F P
0 g
s
.742 .626 .73 r
.3214 .88309 m .31647 .88252 L .31512 .87932 L p F P
0 g
s
.891 .895 .825 r
.75 .22991 m .75025 .2344 L .7558 .22782 L p F P
0 g
s
.891 .895 .825 r
.75422 .22491 m .75 .22991 L p .7558 .22782 L F P
0 g
s
.891 .895 .825 r
.7558 .22782 m .75573 .22618 L .75422 .22491 L p F P
0 g
s
.748 .608 .703 r
.30891 .89706 m .31774 .89814 L .31225 .90493 L p F P
0 g
s
.747 .613 .71 r
.31486 .89015 m .30891 .89706 L .31774 .89814 L p F P
0 g
s
.697 .622 .769 r
.42745 .8451 m .41563 .84542 L .41515 .84438 L p F P
0 g
s
.727 .633 .754 r
.35016 .85676 m .35528 .85268 L .348 .85213 L closepath p F P
0 g
s
.809 .782 .828 r
.66152 .09219 m .65889 .09455 L .65625 .09082 L p F P
0 g
s
.833 .788 .809 r
.65421 .09938 m .65889 .09455 L .65625 .09082 L p F P
0 g
s
.813 .783 .825 r
.66152 .09219 m .66958 .08484 L .66695 .08106 L p F P
0 g
s
.813 .783 .825 r
.66695 .08106 m .65919 .08817 L .66152 .09219 L p F P
0 g
s
.809 .782 .828 r
.65625 .09082 m .65919 .08817 L .66152 .09219 L p F P
0 g
s
.704 .628 .769 r
.4122 .83812 m .40158 .84479 L .39862 .83861 L p F P
0 g
s
.786 .775 .843 r
.66986 .08461 m .66958 .08484 L .66695 .08106 L p F P
0 g
s
.715 .63 .761 r
.38787 .84531 m .388 .84558 L p .37441 .84682 L F P
0 g
s
.71 .627 .762 r
.388 .84558 m .38839 .84532 L .38787 .84531 L closepath p F P
0 g
s
.79 .776 .84 r
.66986 .08461 m .68033 .07626 L .67772 .07243 L p F P
0 g
s
.79 .776 .84 r
.67772 .07243 m .66757 .08057 L .66986 .08461 L p F P
0 g
s
.786 .775 .843 r
.66695 .08106 m .66757 .08057 L .66986 .08461 L p F P
0 g
s
.668 .507 .657 r
.47652 .92819 m .48284 .92758 L p .4716 .93527 L F P
0 g
s
.668 .507 .657 r
.4716 .93527 m .47125 .93343 L .47652 .92819 L p F P
0 g
s
.668 .516 .668 r
.48284 .92758 m .48193 .92337 L .47652 .92819 L closepath p F P
0 g
s
.793 .84 .888 r
.68237 .29542 m .68182 .29581 L .67926 .29319 L p F P
0 g
s
.709 .633 .77 r
.3974 .8361 m .39862 .83861 L .38839 .84532 L p F P
0 g
s
.709 .633 .77 r
.39036 .83595 m .3974 .8361 L p .38839 .84532 L F P
0 g
s
.709 .633 .77 r
.38502 .83948 m .39036 .83595 L p .38839 .84532 L F P
0 g
s
.709 .633 .77 r
.38839 .84532 m .38787 .84531 L .38502 .83948 L p F P
0 g
s
.715 .63 .761 r
.37441 .84682 m .37709 .84491 L .38787 .84531 L p F P
0 g
s
.714 .635 .768 r
.38787 .84531 m .38502 .83948 L .37709 .84491 L closepath p F P
0 g
s
.868 .804 .784 r
.62711 .13098 m .63128 .12572 L .63348 .12974 L p F P
0 g
s
.868 .804 .784 r
.63348 .12974 m .62979 .13438 L .62711 .13098 L p F P
0 g
s
.831 .568 .019 r
.78144 .12213 m .78262 .12646 L .78203 .1222 L p F P
0 g
s
.831 .568 .019 r
.78203 .1222 m .78084 .11788 L .78144 .12213 L p F P
0 g
s
.795 .844 .888 r
.68237 .29542 m .69261 .2879 L .69008 .28536 L p F P
0 g
s
.795 .844 .888 r
.69008 .28536 m .68252 .29086 L .68237 .29542 L p F P
0 g
s
.793 .84 .888 r
.67926 .29319 m .68252 .29086 L .68237 .29542 L p F P
0 g
s
.664 .512 .669 r
.48284 .92758 m .48193 .92337 L .48537 .92049 L p F P
0 g
s
.67 .574 .738 r
.47815 .86841 m .47955 .86764 L .47794 .86783 L closepath p F P
0 g
s
.697 .496 .613 r
.40775 .95071 m .41415 .95064 L .41161 .95668 L p F P
0 g
s
.697 .496 .613 r
.41161 .95668 m .40835 .95672 L .40775 .95071 L p F P
0 g
s
.703 .501 .612 r
.4012 .95069 m .40775 .95071 L .40835 .95672 L p F P
0 g
s
.743 .568 .657 r
.33141 .92811 m .32583 .92754 L p .33157 .93476 L F P
0 g
s
.743 .568 .657 r
.33157 .93476 m .33251 .9331 L .33141 .92811 L p F P
0 g
s
.727 .533 .629 r
.36516 .94977 m .35567 .94923 L .35837 .94316 L p F P
0 g
s
.728 .534 .629 r
.34939 .94262 m .35837 .94316 L .35567 .94923 L p F P
0 g
s
.729 .546 .645 r
.35837 .94316 m .34939 .94262 L .34902 .94056 L p F P
0 g
s
.967 .807 .379 r
.59457 .25816 m .59528 .26254 L .59605 .2577 L p F P
0 g
s
.967 .807 .379 r
.59605 .2577 m .59531 .25333 L .59457 .25816 L p F P
0 g
s
.703 .501 .612 r
.40835 .95672 m .39881 .95669 L .4012 .95069 L p F P
0 g
s
.704 .502 .613 r
.39385 .95064 m .4012 .95069 L .39881 .95669 L p F P
0 g
s
.671 .581 .746 r
.47955 .86764 m .47794 .86783 L .47525 .86083 L p F P
0 g
s
.697 .622 .769 r
.41515 .84438 m .42577 .83801 L p .42745 .8451 L F P
0 g
s
.698 .623 .769 r
.42577 .83801 m .41515 .84438 L .4122 .83812 L p F P
0 g
s
.317 .393 .783 r
.60037 .30108 m .60134 .30162 L .60111 .30288 L closepath p F P
0 g
s
.494 .535 .828 r
.60935 .3034 m .60134 .30162 L .60111 .30288 L p F P
0 g
s
.494 .535 .828 r
.60928 .30795 m .60935 .3034 L p .60111 .30288 L F P
0 g
s
.735 .756 .869 r
.69956 .06935 m .70464 .06643 L .70207 .06254 L p F P
0 g
s
.735 .756 .869 r
.70207 .06254 m .69733 .06528 L .69956 .06935 L p F P
0 g
s
.732 .756 .872 r
.69116 .06882 m .69733 .06528 L .69956 .06935 L p F P
0 g
s
.747 .621 .719 r
.31486 .89015 m .31809 .8866 L .31647 .88252 L p F P
0 g
s
.704 .502 .613 r
.39881 .95669 m .39445 .95667 L .39385 .95064 L p F P
0 g
s
.71 .507 .612 r
.38897 .95055 m .39385 .95064 L .39445 .95667 L p F P
0 g
s
.695 .495 .612 r
.41415 .95064 m .42137 .95054 L .42197 .95654 L p F P
0 g
s
.695 .495 .612 r
.42197 .95654 m .41161 .95668 L .41415 .95064 L p F P
0 g
s
.737 .564 .658 r
.34131 .93556 m .3329 .93488 L .33251 .9331 L p F P
0 g
s
.735 .551 .643 r
.34131 .93556 m .33814 .94175 L .34801 .94252 L p F P
0 g
s
.737 .553 .644 r
.3329 .93488 m .34131 .93556 L .33814 .94175 L p F P
0 g
s
.664 .512 .669 r
.48537 .92049 m .49371 .91956 L p .48284 .92758 L F P
0 g
s
.664 .521 .68 r
.49371 .91956 m .49262 .91497 L .48537 .92049 L closepath p F P
0 g
s
.666 .523 .681 r
.49208 .91273 m .49262 .91497 L .48537 .92049 L p F P
0 g
s
.673 .51 .656 r
.4716 .93527 m .47125 .93343 L .46934 .93545 L closepath p F P
0 g
s
.716 .631 .762 r
.37441 .84682 m .37709 .84491 L .37343 .84476 L closepath p F P
0 g
s
.725 .639 .762 r
.35859 .84388 m .3608 .84844 L .35528 .85268 L p F P
0 g
s
.725 .639 .762 r
.35597 .84367 m .35859 .84388 L p .35528 .85268 L F P
0 g
s
.725 .639 .762 r
.34717 .85044 m .35597 .84367 L p .35528 .85268 L F P
0 g
s
.725 .639 .762 r
.35528 .85268 m .348 .85213 L .34717 .85044 L p F P
0 g
s
.833 .788 .809 r
.65625 .09082 m .65185 .09537 L .65421 .09938 L p F P
0 g
s
.829 .788 .813 r
.6456 .10172 m .65185 .09537 L .65421 .09938 L p F P
0 g
s
.829 .788 .813 r
.65421 .09938 m .64825 .10539 L .6456 .10172 L p F P
0 g
s
.891 .817 .768 r
.61929 .14938 m .62025 .14801 L .62224 .15208 L p F P
0 g
s
.891 .817 .768 r
.62224 .15208 m .62196 .15248 L .61929 .14938 L p F P
0 g
s
.665 .554 .72 r
.49814 .88965 m .49751 .88769 L .49295 .8903 L closepath p F P
0 g
s
.666 .556 .72 r
.49571 .88209 m .49751 .88769 L .49295 .8903 L p F P
0 g
s
.696 .62 .767 r
.42904 .84505 m .42872 .84434 L .42745 .8451 L closepath p F P
0 g
s
.697 .622 .769 r
.42577 .83801 m .42872 .84434 L .42745 .8451 L p F P
0 g
s
.71 .507 .612 r
.39445 .95667 m .38672 .95652 L .38897 .95055 L p F P
0 g
s
.711 .508 .612 r
.37967 .95034 m .38897 .95055 L .38672 .95652 L p F P
0 g
s
.933 .902 .771 r
.76451 .20633 m .76502 .21076 L .76901 .20475 L p F P
0 g
s
.933 .902 .771 r
.76901 .20475 m .76854 .2003 L .76451 .20633 L p F P
0 g
s
.689 .49 .613 r
.42137 .95054 m .42798 .95036 L .42528 .95645 L p F P
0 g
s
.689 .49 .613 r
.42528 .95645 m .42197 .95654 L .42137 .95054 L p F P
0 g
s
.909 .815 .742 r
.61864 .15788 m .62196 .15248 L .61929 .14938 L p F P
0 g
s
.691 .617 .769 r
.43935 .83827 m .44217 .84441 L .42904 .84505 L p F P
0 g
s
.691 .617 .769 r
.42904 .84505 m .42872 .84434 L .43935 .83827 L p F P
0 g
s
.671 .497 .642 r
.46934 .93545 m .4716 .93527 L .47263 .94159 L p F P
0 g
s
.671 .497 .642 r
.47263 .94159 m .4637 .9423 L .46934 .93545 L p F P
0 g
s
.67 .579 .745 r
.49018 .86637 m .48882 .86281 L .47955 .86764 L closepath p F P
0 g
s
.671 .581 .746 r
.48705 .85817 m .48882 .86281 L .47955 .86764 L p F P
0 g
s
.671 .581 .746 r
.47832 .8592 m .48705 .85817 L p .47955 .86764 L F P
0 g
s
.671 .581 .746 r
.47525 .86083 m .47832 .8592 L p .47955 .86764 L F P
0 g
s
.734 .55 .643 r
.34939 .94262 m .34902 .94056 L .34801 .94252 L closepath p F P
0 g
s
.085 .146 .63 r
.59823 .28901 m .5962 .28514 L .59602 .28747 L p F P
0 g
s
.085 .146 .63 r
.59786 .29371 m .59823 .28901 L p .59602 .28747 L F P
0 g
s
.085 .146 .63 r
.59602 .28747 m .59751 .29316 L .59786 .29371 L p F P
0 g
s
.342 .389 .766 r
.5978 .29417 m .60037 .30108 L .60134 .30162 L p F P
0 g
s
.747 .621 .719 r
.31256 .882 m .30616 .88903 L .31486 .89015 L p F P
0 g
s
.747 .621 .719 r
.31647 .88252 m .31256 .882 L p .31486 .89015 L F P
0 g
s
.748 .617 .713 r
.30616 .88903 m .31486 .89015 L .30891 .89706 L p F P
0 g
s
.758 .822 .902 r
.66844 .3005 m .6576 .30714 L .65498 .3043 L p F P
0 g
s
.659 .518 .681 r
.49262 .91497 m .49652 .91218 L .49208 .91273 L closepath p F P
0 g
s
.692 .618 .769 r
.43935 .83827 m .42872 .84434 L .42577 .83801 L p F P
0 g
s
.715 .638 .77 r
.38321 .83578 m .38502 .83948 L .37709 .84491 L p F P
0 g
s
.715 .638 .77 r
.37886 .83559 m .38321 .83578 L p .37709 .84491 L F P
0 g
s
.715 .638 .77 r
.37142 .84072 m .37886 .83559 L p .37709 .84491 L F P
0 g
s
.715 .638 .77 r
.37709 .84491 m .37343 .84476 L .37142 .84072 L p F P
0 g
s
.988 .828 .445 r
.78267 .14466 m .78357 .14905 L .78444 .14423 L p F P
0 g
s
.988 .828 .445 r
.78283 .14373 m .78267 .14466 L p .78444 .14423 L F P
0 g
s
.988 .828 .445 r
.78444 .14423 m .78413 .14271 L .78283 .14373 L p F P
0 g
s
.688 .488 .612 r
.42798 .95036 m .43473 .95015 L .43533 .95614 L p F P
0 g
s
.688 .488 .612 r
.43533 .95614 m .42528 .95645 L .42798 .95036 L p F P
0 g
s
.097 .329 .803 r
.76766 .0904 m .76788 .09056 L .7682 .09146 L closepath p F P
0 g
s
0 .196 .724 r
.77125 .09371 m .76788 .09056 L .7682 .09146 L p F P
0 g
s
0 .196 .724 r
.77274 .09798 m .77125 .09371 L p .7682 .09146 L F P
0 g
s
.711 .508 .612 r
.38672 .95652 m .38026 .95637 L .37967 .95034 L p F P
0 g
s
.717 .512 .612 r
.37732 .95026 m .37967 .95034 L .38026 .95637 L p F P
0 g
s
.851 .791 .793 r
.64741 .10636 m .64825 .10539 L .6456 .10172 L p F P
0 g
s
.665 .494 .643 r
.4716 .93527 m .48409 .93409 L p .4828 .94065 L F P
0 g
s
.665 .494 .643 r
.4828 .94065 m .47263 .94159 L .4716 .93527 L p F P
0 g
s
.668 .507 .657 r
.48284 .92758 m .48409 .93409 L .4716 .93527 L p F P
0 g
s
.748 .629 .728 r
.31647 .88252 m .31512 .87932 L .31256 .882 L closepath p F P
0 g
s
.736 .639 .752 r
.33685 .85989 m .33652 .85919 L .33583 .85978 L closepath p F P
0 g
s
.745 .578 .668 r
.32071 .92017 m .31661 .92658 L .32583 .92754 L p F P
0 g
s
.746 .582 .671 r
.31376 .91941 m .32071 .92017 L .31661 .92658 L p F P
0 g
s
.746 .59 .683 r
.31308 .91708 m .31618 .91263 L p .32071 .92017 L F P
0 g
s
.746 .59 .683 r
.32071 .92017 m .31376 .91941 L .31308 .91708 L p F P
0 g
s
.748 .591 .682 r
.31308 .91708 m .31618 .91263 L .31163 .91211 L closepath p F P
0 g
s
.747 .599 .693 r
.3102 .90765 m .31225 .90493 L p .31618 .91263 L F P
0 g
s
.747 .599 .693 r
.31618 .91263 m .31163 .91211 L .3102 .90765 L p F P
0 g
s
.26 .452 .859 r
.76255 .08079 m .75962 .07958 L .7612 .08383 L p F P
0 g
s
.26 .452 .859 r
.7612 .08383 m .76511 .08554 L .76255 .08079 L p F P
0 g
s
.739 .63 .738 r
.32584 .86877 m .3273 .8674 L .32514 .86717 L closepath p F P
0 g
s
.737 .636 .747 r
.32673 .85875 m .33583 .85978 L .3273 .8674 L p F P
0 g
s
.737 .636 .747 r
.32284 .86223 m .32673 .85875 L p .3273 .8674 L F P
0 g
s
.737 .636 .747 r
.3273 .8674 m .32514 .86717 L .32284 .86223 L p F P
0 g
s
.683 .603 .76 r
.4588 .85231 m .45877 .85224 L .45861 .85233 L closepath p F P
0 g
s
.684 .605 .761 r
.45585 .84546 m .45877 .85224 L .45861 .85233 L p F P
0 g
s
.742 .634 .739 r
.32514 .86717 m .32584 .86877 L .31961 .87479 L p F P
0 g
s
.721 .636 .762 r
.3608 .84844 m .36632 .84435 L .35859 .84388 L closepath p F P
0 g
s
.678 .601 .762 r
.46943 .84663 m .47134 .85112 L .4588 .85231 L p F P
0 g
s
.678 .601 .762 r
.4588 .85231 m .45877 .85224 L .46943 .84663 L p F P
0 g
s
.717 .512 .612 r
.38026 .95637 m .37519 .95619 L .37732 .95026 L p F P
0 g
s
.718 .514 .613 r
.36621 .94982 m .37732 .95026 L .37519 .95619 L p F P
0 g
s
.679 .6 .76 r
.46943 .84663 m .45877 .85224 L .45585 .84546 L p F P
0 g
s
.72 .64 .768 r
.37343 .84476 m .37142 .84072 L .36632 .84435 L closepath p F P
0 g
s
.851 .791 .793 r
.6456 .10172 m .64503 .10238 L .64741 .10636 L p F P
0 g
s
.85 .791 .793 r
.63935 .10894 m .6417 .11294 L .64741 .10636 L p F P
0 g
s
.85 .791 .793 r
.64741 .10636 m .64503 .10238 L .63935 .10894 L p F P
0 g
s
.761 .766 .857 r
.68049 .07615 m .68033 .07626 L .67772 .07243 L p F P
0 g
s
.689 .401 0 r
.77957 .11357 m .78084 .11788 L .77969 .11385 L p F P
0 g
s
.689 .401 0 r
.77969 .11385 m .77841 .10954 L .77957 .11357 L p F P
0 g
s
.888 .892 .827 r
.74416 .2366 m .75 .22991 L .75025 .2344 L p F P
0 g
s
.888 .892 .827 r
.74423 .23761 m .74416 .2366 L p .75025 .2344 L F P
0 g
s
.888 .892 .827 r
.75025 .2344 m .74608 .23917 L .74423 .23761 L p F P
0 g
s
.737 .641 .753 r
.33351 .85293 m .32673 .85875 L .33583 .85978 L p F P
0 g
s
.737 .641 .753 r
.33583 .85978 m .33652 .85919 L .33351 .85293 L p F P
0 g
s
.761 .766 .857 r
.67772 .07243 m .67822 .0721 L .68049 .07615 L p F P
0 g
s
.764 .767 .855 r
.68049 .07615 m .69116 .06882 L .68856 .06495 L p F P
0 g
s
.764 .767 .855 r
.68856 .06495 m .67822 .0721 L .68049 .07615 L p F P
0 g
s
.661 .501 .657 r
.48284 .92758 m .49516 .92624 L p .48953 .9335 L F P
0 g
s
.661 .501 .657 r
.48953 .9335 m .48409 .93409 L .48284 .92758 L p F P
0 g
s
.664 .512 .669 r
.49371 .91956 m .49516 .92624 L .48284 .92758 L p F P
0 g
s
.733 .638 .754 r
.34536 .85188 m .33652 .85919 L .33351 .85293 L p F P
0 g
s
.659 .518 .681 r
.49371 .91956 m .49262 .91497 L .49652 .91218 L p F P
0 g
s
.887 .803 .761 r
.62867 .13598 m .62979 .13438 L .62711 .13098 L p F P
0 g
s
.728 .534 .629 r
.35567 .94923 m .35027 .94891 L .34939 .94262 L p F P
0 g
s
.734 .539 .628 r
.34801 .94252 m .34939 .94262 L .35027 .94891 L p F P
0 g
s
.928 .823 .722 r
.61338 .17355 m .6142 .17206 L .61152 .16932 L p F P
0 g
s
.743 .567 .657 r
.3329 .93488 m .33251 .9331 L .33157 .93476 L closepath p F P
0 g
s
.682 .484 .612 r
.43473 .95015 m .44292 .94979 L .44003 .95593 L p F P
0 g
s
.682 .484 .612 r
.44003 .95593 m .43533 .95614 L .43473 .95015 L p F P
0 g
s
.743 .568 .657 r
.32583 .92754 m .32228 .93382 L .33157 .93476 L p F P
0 g
s
.745 .571 .658 r
.31661 .92658 m .32583 .92754 L .32228 .93382 L p F P
0 g
s
.744 .627 .73 r
.31512 .87932 m .31961 .87479 L .31284 .87396 L closepath p F P
0 g
s
.742 .634 .739 r
.31842 .86632 m .32514 .86717 L p .31961 .87479 L F P
0 g
s
.742 .634 .739 r
.31213 .87237 m .31842 .86632 L p .31961 .87479 L F P
0 g
s
.742 .634 .739 r
.31961 .87479 m .31284 .87396 L .31213 .87237 L p F P
0 g
s
.749 .601 .692 r
.3102 .90765 m .31225 .90493 L .3092 .90456 L closepath p F P
0 g
s
.748 .608 .703 r
.30728 .89909 m .30891 .89706 L p .31225 .90493 L F P
0 g
s
.748 .608 .703 r
.31225 .90493 m .3092 .90456 L .30728 .89909 L p F P
0 g
s
.672 .582 .747 r
.47525 .86083 m .47832 .8592 L .47477 .8596 L closepath p F P
0 g
s
.67 .487 .629 r
.46053 .9469 m .4637 .9423 L .45994 .94259 L closepath p F P
0 g
s
.677 .491 .628 r
.45994 .94259 m .46053 .9469 L .45925 .94886 L p F P
0 g
s
.923 .9 .786 r
.7651 .21166 m .76463 .2113 L .76502 .21076 L closepath p F P
0 g
s
.977 .855 .653 r
.60151 .21891 m .60144 .21909 L .60136 .21885 L closepath p F P
0 g
s
.731 .642 .76 r
.348 .85213 m .34717 .85044 L .34536 .85188 L closepath p F P
0 g
s
.735 .541 .63 r
.33814 .94175 m .34801 .94252 L .34545 .94855 L p F P
0 g
s
.734 .539 .628 r
.35027 .94891 m .34545 .94855 L .34801 .94252 L p F P
0 g
s
.743 .639 .744 r
.32514 .86717 m .32284 .86223 L .31842 .86632 L closepath p F P
0 g
s
.983 .852 .632 r
.59814 .22011 m .59952 .22431 L .60144 .21909 L p F P
0 g
s
.983 .852 .632 r
.59886 .21813 m .59814 .22011 L p .60144 .21909 L F P
0 g
s
.983 .852 .632 r
.60144 .21909 m .60136 .21885 L .59886 .21813 L p F P
0 g
s
.963 .848 .68 r
.60119 .20524 m .60266 .20943 L .60513 .20402 L p F P
0 g
s
.963 .848 .68 r
.60513 .20402 m .60359 .19985 L .60119 .20524 L p F P
0 g
s
.672 .59 .755 r
.47832 .8592 m .47477 .8596 L .47234 .85359 L p F P
0 g
s
.939 .845 .723 r
.60436 .19032 m .60736 .18472 L .60901 .18887 L p F P
0 g
s
.939 .845 .723 r
.60516 .19243 m .60436 .19032 L p .60901 .18887 L F P
0 g
s
.939 .845 .723 r
.60901 .18887 m .60649 .19351 L .60516 .19243 L p F P
0 g
s
.64 .709 .897 r
.71821 .06544 m .72936 .0621 L .7319 .06612 L p F P
0 g
s
.642 .711 .897 r
.72936 .0621 m .71821 .06544 L .71566 .0615 L p F P
0 g
s
.694 .736 .884 r
.70464 .06643 m .71566 .0615 L .71821 .06544 L p F P
0 g
s
.748 .629 .728 r
.31256 .882 m .31512 .87932 L .31284 .87396 L p F P
0 g
s
.762 .594 .024 r
.59502 .27178 m .59536 .27626 L .59523 .27173 L p F P
0 g
s
.762 .594 .024 r
.59523 .27173 m .59489 .26724 L .59502 .27178 L p F P
0 g
s
.685 .605 .761 r
.45501 .84351 m .45585 .84546 L p .44228 .84468 L F P
0 g
s
.685 .605 .761 r
.44228 .84468 m .44283 .84437 L .45501 .84351 L p F P
0 g
s
.686 .608 .763 r
.44228 .84468 m .44283 .84437 L .44217 .84441 L closepath p F P
0 g
s
.737 .553 .644 r
.33814 .94175 m .33409 .94142 L .3329 .93488 L p F P
0 g
s
.743 .557 .643 r
.33157 .93476 m .3329 .93488 L .33409 .94142 L p F P
0 g
s
.66 .551 .721 r
.50821 .88196 m .51013 .88795 L .49814 .88965 L p F P
0 g
s
.66 .551 .721 r
.49814 .88965 m .49751 .88769 L .50821 .88196 L p F P
0 g
s
.658 .543 .712 r
.49814 .88965 m .51013 .88795 L p .50067 .89698 L F P
0 g
s
.658 .543 .712 r
.50067 .89698 m .50038 .89702 L .49814 .88965 L p F P
0 g
s
.66 .552 .721 r
.50772 .88041 m .50821 .88196 L .49751 .88769 L p F P
0 g
s
.66 .552 .721 r
.49751 .88769 m .49571 .88209 L .50772 .88041 L p F P
0 g
s
.104 .34 .81 r
.76788 .09056 m .76766 .0904 L .76511 .08554 L p F P
0 g
s
.686 .615 .771 r
.44283 .84437 m .44217 .84441 L .43935 .83827 L p F P
0 g
s
.662 .56 .73 r
.50532 .87333 m .50772 .88041 L .49571 .88209 L p F P
0 g
s
.662 .56 .73 r
.49571 .88209 m .49462 .8789 L .50532 .87333 L p F P
0 g
s
.032 .124 .628 r
.59751 .29316 m .59786 .29371 L .5978 .29417 L closepath p F P
0 g
s
.807 .849 .882 r
.69436 .28655 m .69261 .2879 L .69008 .28536 L p F P
0 g
s
.887 .803 .761 r
.62711 .13098 m .62642 .13198 L .62867 .13598 L p F P
0 g
s
.888 .803 .76 r
.62229 .13796 m .62451 .14197 L .62867 .13598 L p F P
0 g
s
.888 .803 .76 r
.62867 .13598 m .62642 .13198 L .62229 .13796 L p F P
0 g
s
.685 .613 .769 r
.45501 .84351 m .45293 .8389 L .44283 .84437 L closepath p F P
0 g
s
.686 .615 .771 r
.45088 .83439 m .45293 .8389 L .44283 .84437 L p F P
0 g
s
.686 .615 .771 r
.4458 .83473 m .45088 .83439 L p .44283 .84437 L F P
0 g
s
.686 .615 .771 r
.43935 .83827 m .4458 .83473 L p .44283 .84437 L F P
0 g
s
.977 .871 .663 r
.60136 .21885 m .59886 .21813 L .60026 .21481 L closepath p F P
0 g
s
.659 .518 .681 r
.49652 .91218 m .50421 .9112 L p .49371 .91956 L F P
0 g
s
.66 .527 .691 r
.50421 .9112 m .50331 .90771 L .49652 .91218 L closepath p F P
0 g
s
.661 .528 .692 r
.50239 .90419 m .50331 .90771 L .49652 .91218 L p F P
0 g
s
.72 .642 .77 r
.36864 .83513 m .37142 .84072 L .36632 .84435 L p F P
0 g
s
.72 .642 .77 r
.36791 .83508 m .36864 .83513 L p .36632 .84435 L F P
0 g
s
.72 .642 .77 r
.3578 .84231 m .36791 .83508 L p .36632 .84435 L F P
0 g
s
.72 .642 .77 r
.36632 .84435 m .35859 .84388 L .3578 .84231 L p F P
0 g
s
.733 .638 .754 r
.33351 .85293 m .3359 .85095 L .34536 .85188 L p F P
0 g
s
.731 .643 .761 r
.34416 .84435 m .3359 .85095 L .34536 .85188 L p F P
0 g
s
.731 .643 .761 r
.34536 .85188 m .34717 .85044 L .34416 .84435 L p F P
0 g
s
.695 .737 .883 r
.71566 .0615 m .70464 .06643 L .70207 .06254 L p F P
0 g
s
.958 .902 .725 r
.77166 .18997 m .77485 .18426 L .77548 .18867 L p F P
0 g
s
.958 .902 .725 r
.77223 .19376 m .77166 .18997 L p .77548 .18867 L F P
0 g
s
.958 .902 .725 r
.77548 .18867 m .77255 .19395 L .77223 .19376 L p F P
0 g
s
.342 .389 .766 r
.60191 .29687 m .59786 .29371 L .5978 .29417 L p F P
0 g
s
.342 .389 .766 r
.60134 .30162 m .60191 .29687 L p .5978 .29417 L F P
0 g
s
.997 .855 .532 r
.59663 .24732 m .59634 .24841 L .59616 .24764 L closepath p F P
0 g
s
.67 .487 .629 r
.4637 .9423 m .47263 .94159 L p .46078 .94876 L F P
0 g
s
.67 .487 .629 r
.46078 .94876 m .46053 .9469 L .4637 .9423 L p F P
0 g
s
0 0 .407 r
.77706 .10525 m .77841 .10954 L .77663 .10576 L p F P
0 g
s
0 0 .407 r
.77663 .10576 m .77525 .10147 L .77706 .10525 L p F P
0 g
s
.662 .561 .73 r
.50509 .87267 m .50532 .87333 L .49462 .8789 L p F P
0 g
s
.662 .561 .73 r
.49462 .8789 m .49306 .87434 L .50509 .87267 L p F P
0 g
s
.743 .557 .643 r
.33409 .94142 m .32857 .94089 L .33157 .93476 L p F P
0 g
s
.744 .559 .645 r
.32228 .93382 m .33157 .93476 L .32857 .94089 L p F P
0 g
s
.749 .625 .722 r
.30399 .88083 m .31256 .882 L .30616 .88903 L p F P
0 g
s
.748 .629 .728 r
.31081 .87368 m .30399 .88083 L .31256 .882 L p F P
0 g
s
.748 .629 .728 r
.31284 .87396 m .31081 .87368 L p .31256 .882 L F P
0 g
s
.718 .514 .613 r
.36539 .95209 m .36621 .94982 L p .37519 .95619 L F P
0 g
s
.72 .516 .613 r
.36539 .95209 m .36621 .94982 L .36516 .94977 L closepath p F P
0 g
s
.75 .609 .703 r
.30728 .89909 m .30891 .89706 L .30646 .89675 L closepath p F P
0 g
s
.748 .617 .713 r
.30433 .89116 m .30616 .88903 L p .30891 .89706 L F P
0 g
s
.748 .617 .713 r
.30891 .89706 m .30646 .89675 L .30433 .89116 L p F P
0 g
s
.928 .823 .722 r
.61152 .16932 m .61142 .16949 L .61338 .17355 L p F P
0 g
s
.931 .823 .717 r
.60846 .17506 m .61037 .17913 L .61338 .17355 L p F P
0 g
s
.931 .823 .717 r
.61338 .17355 m .61142 .16949 L .60846 .17506 L p F P
0 g
s
.752 .594 .681 r
.31163 .91211 m .30737 .91155 L p .31168 .91915 L F P
0 g
s
.752 .594 .681 r
.31168 .91915 m .31308 .91708 L .31163 .91211 L p F P
0 g
s
.753 .602 .691 r
.31163 .91211 m .3102 .90765 L .30737 .91155 L closepath p F P
0 g
s
.68 .482 .611 r
.44292 .94979 m .44786 .94955 L .44846 .95553 L p F P
0 g
s
.68 .482 .611 r
.44846 .95553 m .44003 .95593 L .44292 .94979 L p F P
0 g
s
.753 .603 .691 r
.30737 .91155 m .3102 .90765 L .3092 .90456 L p F P
0 g
s
.81 .853 .881 r
.69436 .28655 m .70338 .27946 L .70087 .277 L p F P
0 g
s
.81 .853 .881 r
.70087 .277 m .69446 .282 L .69436 .28655 L p F P
0 g
s
.807 .849 .882 r
.69008 .28536 m .69446 .282 L .69436 .28655 L p F P
0 g
s
.994 .875 .583 r
.78061 .15917 m .78147 .16355 L .78312 .15843 L p F P
0 g
s
.994 .875 .583 r
.78312 .15843 m .78228 .15404 L .78061 .15917 L p F P
0 g
s
.753 .603 .691 r
.3092 .90456 m .30361 .90379 L p .30737 .91155 L F P
0 g
s
.753 .611 .701 r
.3092 .90456 m .30728 .89909 L .30361 .90379 L closepath p F P
0 g
s
.395 .486 .834 r
.60897 .29944 m .60935 .3034 L .60134 .30162 L p F P
0 g
s
.395 .486 .834 r
.6087 .29896 m .60897 .29944 L p .60134 .30162 L F P
0 g
s
.395 .486 .834 r
.60134 .30162 m .60191 .29687 L .6087 .29896 L p F P
0 g
s
.657 .533 .702 r
.50041 .89713 m .50067 .89698 L .50038 .89702 L closepath p F P
0 g
s
.44 .592 .906 r
.7508 .07366 m .74831 .07336 L .74578 .06914 L p F P
0 g
s
.882 .893 .834 r
.74608 .23917 m .74432 .24111 L .74423 .23761 L closepath p F P
0 g
s
.725 .519 .612 r
.36516 .94977 m .35567 .94923 L p .36413 .95574 L F P
0 g
s
.725 .519 .612 r
.36413 .95574 m .36539 .95209 L .36516 .94977 L p F P
0 g
s
.656 .533 .702 r
.50041 .89713 m .50067 .89698 L p .51102 .90297 L F P
0 g
s
.656 .533 .702 r
.51102 .90297 m .50239 .90419 L .50041 .89713 L p F P
0 g
s
.995 .864 .587 r
.59611 .23462 m .59712 .23892 L .59883 .23377 L p F P
0 g
s
.995 .864 .587 r
.59883 .23377 m .59774 .22949 L .59611 .23462 L p F P
0 g
s
.727 .641 .762 r
.35597 .84367 m .34717 .85044 L .34416 .84435 L p F P
0 g
s
.104 .34 .81 r
.76511 .08554 m .76628 .08633 L .76788 .09056 L p F P
0 g
s
0 .217 .738 r
.76969 .08946 m .77125 .09371 L .76788 .09056 L p F P
0 g
s
0 .217 .738 r
.76788 .09056 m .76628 .08633 L .76969 .08946 L p F P
0 g
s
.656 .533 .702 r
.50067 .89698 m .51234 .89531 L p .51102 .90297 L F P
0 g
s
.657 .541 .711 r
.51234 .89531 m .51111 .89122 L .50067 .89698 L closepath p F P
0 g
s
.658 .543 .712 r
.51013 .88795 m .51111 .89122 L .50067 .89698 L p F P
0 g
s
.9 .892 .813 r
.75573 .22618 m .75422 .22491 L .7555 .22335 L closepath p F P
0 g
s
.657 .508 .67 r
.49371 .91956 m .50585 .91804 L p .49808 .92587 L F P
0 g
s
.657 .508 .67 r
.49808 .92587 m .49516 .92624 L .49371 .91956 L p F P
0 g
s
.659 .518 .681 r
.50421 .9112 m .50585 .91804 L .49371 .91956 L p F P
0 g
s
.663 .569 .738 r
.50242 .86522 m .50509 .87267 L .49306 .87434 L p F P
0 g
s
.663 .569 .738 r
.49306 .87434 m .49172 .87064 L .50242 .86522 L p F P
0 g
s
.979 .896 .668 r
.78029 .17338 m .7802 .17334 L .78026 .1732 L closepath p F P
0 g
s
0 .026 .599 r
.7738 .0972 m .77525 .10147 L .77274 .09798 L p F P
0 g
s
0 .026 .599 r
.77274 .09798 m .77125 .09371 L .7738 .0972 L p F P
0 g
s
.704 .628 .769 r
.41124 .8361 m .4122 .83812 L p .39862 .83861 L F P
0 g
s
.704 .628 .769 r
.39862 .83861 m .40257 .83611 L .41124 .8361 L p F P
0 g
s
.705 .63 .771 r
.39862 .83861 m .40257 .83611 L .3974 .8361 L closepath p F P
0 g
s
.671 .588 .753 r
.48705 .85817 m .48592 .85534 L .47832 .8592 L closepath p F P
0 g
s
.672 .59 .755 r
.48367 .84973 m .48592 .85534 L .47832 .8592 L p F P
0 g
s
.672 .59 .755 r
.47873 .8503 m .48367 .84973 L p .47832 .8592 L F P
0 g
s
.672 .59 .755 r
.47234 .85359 m .47873 .8503 L p .47832 .8592 L F P
0 g
s
.751 .593 .68 r
.31376 .91941 m .31308 .91708 L .31168 .91915 L closepath p F P
0 g
s
.868 .884 .845 r
.73759 .24356 m .73779 .24805 L .74432 .24111 L p F P
0 g
s
.868 .884 .845 r
.74369 .23712 m .73759 .24356 L p .74432 .24111 L F P
0 g
s
.868 .884 .845 r
.74432 .24111 m .74423 .23761 L .74369 .23712 L p F P
0 g
s
.71 .634 .77 r
.38502 .83948 m .39036 .83595 L .38321 .83578 L closepath p F P
0 g
s
.848 .793 .798 r
.63499 .11389 m .63935 .10894 L .6417 .11294 L p F P
0 g
s
.848 .793 .798 r
.6417 .11294 m .63766 .1175 L .63499 .11389 L p F P
0 g
s
.754 .611 .701 r
.30361 .90379 m .30728 .89909 L .30646 .89675 L p F P
0 g
s
.978 .892 .67 r
.77796 .17223 m .77947 .16881 L .78026 .1732 L p F P
0 g
s
.978 .892 .67 r
.78026 .1732 m .7802 .17334 L .77796 .17223 L p F P
0 g
s
.746 .582 .671 r
.31661 .92658 m .31559 .92647 L .31376 .91941 L p F P
0 g
s
.752 .585 .669 r
.31168 .91915 m .31376 .91941 L .31559 .92647 L p F P
0 g
s
.698 .623 .769 r
.42475 .8358 m .42577 .83801 L p .4122 .83812 L F P
0 g
s
.698 .623 .769 r
.4122 .83812 m .41568 .83602 L .42475 .8358 L p F P
0 g
s
.699 .625 .771 r
.4122 .83812 m .41568 .83602 L .41124 .8361 L closepath p F P
0 g
s
.674 .478 .612 r
.44786 .94955 m .45925 .94886 L .45614 .95507 L p F P
0 g
s
.674 .478 .612 r
.45614 .95507 m .44846 .95553 L .44786 .94955 L p F P
0 g
s
.976 .898 .675 r
.77772 .17866 m .7802 .17334 L .77796 .17223 L p F P
0 g
s
.664 .569 .739 r
.50224 .86472 m .50242 .86522 L .49172 .87064 L p F P
0 g
s
.664 .569 .739 r
.49172 .87064 m .49018 .86637 L .50224 .86472 L p F P
0 g
s
.754 .611 .701 r
.30646 .89675 m .30042 .89588 L p .30361 .90379 L F P
0 g
s
.754 .62 .71 r
.30646 .89675 m .30433 .89116 L .30042 .89588 L closepath p F P
0 g
s
.175 .283 .736 r
.6019 .29231 m .60191 .29687 L .59786 .29371 L p F P
0 g
s
.175 .283 .736 r
.59786 .29371 m .59823 .28901 L .6019 .29231 L p F P
0 g
s
.921 .896 .786 r
.76229 .20944 m .76451 .20633 L .76502 .21076 L p F P
0 g
s
.921 .896 .786 r
.76502 .21076 m .76463 .2113 L .76229 .20944 L p F P
0 g
s
.994 .837 .48 r
.59446 .24971 m .59531 .25333 L .59634 .24841 L p F P
0 g
s
.994 .837 .48 r
.59634 .24841 m .59616 .24764 L .59446 .24971 L p F P
0 g
s
.716 .639 .77 r
.37142 .84072 m .37886 .83559 L .36864 .83513 L closepath p F P
0 g
s
.655 .524 .692 r
.50331 .90771 m .51102 .90297 L .50239 .90419 L closepath p F P
0 g
s
.725 .644 .768 r
.35859 .84388 m .3578 .84231 L .35597 .84367 L closepath p F P
0 g
s
.909 .815 .742 r
.61929 .14938 m .61656 .15384 L .61864 .15788 L p F P
0 g
s
.909 .815 .742 r
.61301 .15962 m .61504 .16367 L .61864 .15788 L p F P
0 g
s
.909 .815 .742 r
.61864 .15788 m .61656 .15384 L .61301 .15962 L p F P
0 g
s
.918 .9 .793 r
.7604 .217 m .76463 .2113 L .76229 .20944 L p F P
0 g
s
.673 .591 .755 r
.47234 .85359 m .47873 .8503 L .47134 .85112 L closepath p F P
0 g
s
.971 .767 .336 r
.78235 .13553 m .78346 .13986 L .78382 .13524 L p F P
0 g
s
.971 .767 .336 r
.78382 .13524 m .78272 .1309 L .78235 .13553 L p F P
0 g
s
.748 .636 .736 r
.31284 .87396 m .31213 .87237 L .31081 .87368 L closepath p F P
0 g
s
.99 .817 .436 r
.78413 .14271 m .78283 .14373 L .78346 .13986 L closepath p F P
0 g
s
.75 .618 .712 r
.30433 .89116 m .30616 .88903 L .30338 .88866 L closepath p F P
0 g
s
.749 .625 .722 r
.30136 .88373 m .30399 .88083 L p .30616 .88903 L F P
0 g
s
.749 .625 .722 r
.30616 .88903 m .30338 .88866 L .30136 .88373 L p F P
0 g
s
.68 .604 .763 r
.45585 .84546 m .46041 .84303 L .45501 .84351 L closepath p F P
0 g
s
.679 .6 .76 r
.46761 .84237 m .46943 .84663 L p .45585 .84546 L F P
0 g
s
.679 .6 .76 r
.45585 .84546 m .46041 .84303 L .46761 .84237 L p F P
0 g
s
.703 .783 .913 r
.63056 .31201 m .64146 .30711 L .64411 .31022 L p F P
0 g
s
.735 .792 .898 r
.64959 .30725 m .64411 .31022 L .64146 .30711 L p F P
0 g
s
.752 .585 .669 r
.31559 .92647 m .30782 .92551 L .31168 .91915 L p F P
0 g
s
.753 .588 .672 r
.30302 .91803 m .31168 .91915 L .30782 .92551 L p F P
0 g
s
.752 .594 .681 r
.30737 .91155 m .30302 .91803 L .31168 .91915 L p F P
0 g
s
.692 .618 .769 r
.43795 .83523 m .43935 .83827 L p .42577 .83801 L F P
0 g
s
.692 .618 .769 r
.42577 .83801 m .42996 .83559 L .43795 .83523 L p F P
0 g
s
.693 .621 .771 r
.42577 .83801 m .42996 .83559 L .42475 .8358 L closepath p F P
0 g
s
.665 .577 .747 r
.49952 .85754 m .50224 .86472 L .49018 .86637 L p F P
0 g
s
.665 .577 .747 r
.49018 .86637 m .48882 .86281 L .49952 .85754 L p F P
0 g
s
.735 .541 .63 r
.34545 .94855 m .33552 .9478 L .33814 .94175 L p F P
0 g
s
.737 .543 .631 r
.33409 .94142 m .33814 .94175 L .33552 .9478 L p F P
0 g
s
.834 .867 .869 r
.71445 .27077 m .71413 .27047 L .71445 .27019 L closepath p F P
0 g
s
.644 .738 .918 r
.61693 .31184 m .62787 .30856 L .63056 .31201 L p F P
0 g
s
.623 .723 .918 r
.62787 .30856 m .61693 .31184 L .6142 .30775 L p F P
0 g
s
.739 .637 .747 r
.32284 .86223 m .32673 .85875 L .3209 .85808 L closepath p F P
0 g
s
.743 .639 .745 r
.31842 .86632 m .32284 .86223 L .3209 .85808 L p F P
0 g
s
.82 .857 .875 r
.70494 .27818 m .70338 .27946 L .70087 .277 L p F P
0 g
s
.573 .676 .909 r
.73439 .06578 m .7319 .06612 L .72936 .0621 L p F P
0 g
s
.745 .634 .738 r
.31842 .86632 m .31213 .87237 L .30912 .86572 L p F P
0 g
s
.745 .634 .738 r
.30912 .86572 m .30967 .86519 L .31842 .86632 L p F P
0 g
s
.743 .639 .745 r
.31781 .85767 m .30967 .86519 L .31842 .86632 L p F P
0 g
s
.743 .639 .745 r
.3209 .85808 m .31781 .85767 L p .31842 .86632 L F P
0 g
s
.754 .597 .683 r
.2988 .9104 m .30737 .91155 L .30302 .91803 L p F P
0 g
s
.753 .603 .691 r
.30361 .90379 m .2988 .9104 L .30737 .91155 L p F P
0 g
s
.725 .519 .612 r
.35567 .94923 m .35359 .95514 L .36413 .95574 L p F P
0 g
s
.727 .522 .613 r
.35027 .94891 m .35567 .94923 L .35359 .95514 L p F P
0 g
s
.737 .644 .755 r
.33239 .85059 m .33351 .85293 L .32673 .85875 L p F P
0 g
s
.737 .644 .755 r
.32678 .84992 m .33239 .85059 L p .32673 .85875 L F P
0 g
s
.737 .644 .755 r
.31982 .85589 m .32678 .84992 L p .32673 .85875 L F P
0 g
s
.737 .644 .755 r
.32673 .85875 m .3209 .85808 L .31982 .85589 L p F P
0 g
s
.727 .641 .762 r
.34416 .84435 m .34612 .84284 L .35597 .84367 L p F P
0 g
s
.726 .646 .769 r
.3548 .83641 m .34612 .84284 L .35597 .84367 L p F P
0 g
s
.726 .646 .769 r
.35597 .84367 m .3578 .84231 L .3548 .83641 L p F P
0 g
s
.866 .88 .845 r
.73306 .24821 m .73759 .24356 L .73779 .24805 L p F P
0 g
s
.866 .88 .845 r
.73779 .24805 m .73549 .25041 L .73306 .24821 L p F P
0 g
s
.718 .514 .613 r
.37519 .95619 m .36576 .95582 L .36539 .95209 L p F P
0 g
s
.724 .519 .612 r
.36576 .95582 m .36539 .95209 L .36413 .95574 L closepath p F P
0 g
s
.745 .571 .658 r
.3159 .92786 m .31661 .92658 L p .32228 .93382 L F P
0 g
s
.747 .572 .658 r
.3159 .92786 m .31661 .92658 L .31559 .92647 L closepath p F P
0 g
s
.703 .634 .777 r
.41124 .8361 m .40924 .83205 L .40257 .83611 L closepath p F P
0 g
s
.704 .636 .778 r
.40642 .82639 m .40924 .83205 L .40257 .83611 L p F P
0 g
s
.704 .636 .778 r
.40576 .82639 m .40642 .82639 L p .40257 .83611 L F P
0 g
s
.704 .636 .778 r
.39564 .8326 m .40576 .82639 L p .40257 .83611 L F P
0 g
s
.704 .636 .778 r
.40257 .83611 m .3974 .8361 L .39564 .8326 L p F P
0 g
s
.868 .795 .776 r
.63614 .11946 m .63766 .1175 L .63499 .11389 L p F P
0 g
s
.825 .861 .873 r
.70494 .27818 m .71413 .27047 L .71164 .26806 L p F P
0 g
s
.825 .861 .873 r
.71164 .26806 m .70495 .27366 L .70494 .27818 L p F P
0 g
s
.82 .857 .875 r
.70087 .277 m .70495 .27366 L .70494 .27818 L p F P
0 g
s
.698 .632 .779 r
.41568 .83602 m .41124 .8361 L .40924 .83205 L p F P
0 g
s
.709 .638 .776 r
.3974 .8361 m .39564 .8326 L .39036 .83595 L closepath p F P
0 g
s
.694 .481 .594 r
.40835 .95672 m .41161 .95668 L .40994 .96251 L p F P
0 g
s
.694 .481 .594 r
.40994 .96251 m .40869 .96253 L .40835 .95672 L p F P
0 g
s
.701 .486 .594 r
.39881 .95669 m .40835 .95672 L .40869 .96253 L p F P
0 g
s
.675 .49 .628 r
.46078 .94876 m .46053 .9469 L .45925 .94886 L closepath p F P
0 g
s
.665 .494 .643 r
.48409 .93409 m .48481 .93841 L .4828 .94065 L p F P
0 g
s
.659 .49 .644 r
.48481 .93841 m .48953 .9335 L .48409 .93409 L closepath p F P
0 g
s
.655 .524 .692 r
.50421 .9112 m .50331 .90771 L .51102 .90297 L p F P
0 g
s
.701 .486 .594 r
.40869 .96253 m .39724 .9625 L .39881 .95669 L p F P
0 g
s
.702 .487 .594 r
.39445 .95667 m .39881 .95669 L .39724 .9625 L p F P
0 g
s
.754 .62 .71 r
.30042 .89588 m .30433 .89116 L .30338 .88866 L p F P
0 g
s
.693 .479 .594 r
.41161 .95668 m .42197 .95654 L .42232 .96234 L p F P
0 g
s
.693 .479 .594 r
.42232 .96234 m .40994 .96251 L .41161 .95668 L p F P
0 g
s
.673 .598 .763 r
.47873 .8503 m .47134 .85112 L .46943 .84663 L p F P
0 g
s
.663 .481 .629 r
.47263 .94159 m .4828 .94065 L .47777 .94736 L p F P
0 g
s
.663 .481 .629 r
.47777 .94736 m .47347 .94776 L .47263 .94159 L p F P
0 g
s
.67 .487 .629 r
.47263 .94159 m .47347 .94776 L .46078 .94876 L p F P
0 g
s
.702 .487 .594 r
.39724 .9625 m .39479 .96248 L .39445 .95667 L p F P
0 g
s
.708 .492 .594 r
.38672 .95652 m .39445 .95667 L .39479 .96248 L p F P
0 g
s
.748 .637 .737 r
.31081 .87368 m .31213 .87237 L .30912 .86572 L p F P
0 g
s
.697 .629 .777 r
.42475 .8358 m .42282 .83186 L .41568 .83602 L closepath p F P
0 g
s
.698 .632 .779 r
.42005 .82618 m .42282 .83186 L .41568 .83602 L p F P
0 g
s
.698 .632 .779 r
.4192 .8262 m .42005 .82618 L p .41568 .83602 L F P
0 g
s
.698 .632 .779 r
.40924 .83205 m .4192 .8262 L p .41568 .83602 L F P
0 g
s
.86 .881 .852 r
.73063 .25521 m .73549 .25041 L .73306 .24821 L p F P
0 g
s
.751 .575 .656 r
.31559 .92647 m .30782 .92551 L p .3132 .93283 L F P
0 g
s
.751 .575 .656 r
.3132 .93283 m .3159 .92786 L .31559 .92647 L p F P
0 g
s
.722 .644 .771 r
.36791 .83508 m .3578 .84231 L .3548 .83641 L p F P
0 g
s
.749 .633 .731 r
.30239 .87246 m .31081 .87368 L .30399 .88083 L p F P
0 g
s
.748 .637 .737 r
.30912 .86572 m .30239 .87246 L .31081 .87368 L p F P
0 g
s
.68 .61 .771 r
.46041 .84303 m .45501 .84351 L .45293 .8389 L p F P
0 g
s
.734 .64 .755 r
.33351 .85293 m .3359 .85095 L .33239 .85059 L closepath p F P
0 g
s
.709 .64 .778 r
.39266 .82669 m .39564 .8326 L .39036 .83595 L p F P
0 g
s
.709 .64 .778 r
.38204 .83349 m .39266 .82669 L p .39036 .83595 L F P
0 g
s
.709 .64 .778 r
.39036 .83595 m .38321 .83578 L .38204 .83349 L p F P
0 g
s
.776 .83 .894 r
.66853 .3006 m .66844 .3005 L .66854 .30043 L closepath p F P
0 g
s
.755 .607 .694 r
.29515 .90261 m .30361 .90379 L .2988 .9104 L p F P
0 g
s
.754 .611 .701 r
.30042 .89588 m .29515 .90261 L .30361 .90379 L p F P
0 g
s
.733 .755 .87 r
.69733 .06528 m .69116 .06882 L .68856 .06495 L p F P
0 g
s
.665 .578 .747 r
.49914 .85653 m .49952 .85754 L .48882 .86281 L p F P
0 g
s
.665 .578 .747 r
.48882 .86281 m .48705 .85817 L .49914 .85653 L p F P
0 g
s
.687 .475 .594 r
.42197 .95654 m .42528 .95645 L .42351 .96231 L p F P
0 g
s
.687 .475 .594 r
.42351 .96231 m .42232 .96234 L .42197 .95654 L p F P
0 g
s
.754 .62 .71 r
.30338 .88866 m .29777 .88781 L p .30042 .89588 L F P
0 g
s
.754 .628 .72 r
.30338 .88866 m .30136 .88373 L .29777 .88781 L closepath p F P
0 g
s
.708 .492 .594 r
.39479 .96248 m .38522 .96229 L .38672 .95652 L p F P
0 g
s
.709 .493 .594 r
.38026 .95637 m .38672 .95652 L .38522 .96229 L p F P
0 g
s
.732 .646 .763 r
.34329 .8426 m .34416 .84435 L .3359 .85095 L p F P
0 g
s
.732 .646 .763 r
.3367 .84189 m .34329 .8426 L p .3359 .85095 L F P
0 g
s
.732 .646 .763 r
.33049 .84685 m .3367 .84189 L p .3359 .85095 L F P
0 g
s
.732 .646 .763 r
.3359 .85095 m .33239 .85059 L .33049 .84685 L p F P
0 g
s
.737 .543 .631 r
.33552 .9478 m .33502 .94776 L .33409 .94142 L p F P
0 g
s
.743 .547 .629 r
.32857 .94089 m .33409 .94142 L .33502 .94776 L p F P
0 g
s
.745 .571 .658 r
.32228 .93382 m .31711 .93329 L .3159 .92786 L p F P
0 g
s
.751 .574 .656 r
.31711 .93329 m .3159 .92786 L .3132 .93283 L closepath p F P
0 g
s
.775 .825 .892 r
.66854 .30043 m .66844 .3005 L .66584 .29772 L p F P
0 g
s
.758 .822 .902 r
.65498 .3043 m .66584 .29772 L .66844 .3005 L p F P
0 g
s
.86 .881 .852 r
.73306 .24821 m .73055 .25068 L .73063 .25521 L p F P
0 g
s
.854 .877 .856 r
.72292 .25802 m .73055 .25068 L .73063 .25521 L p F P
0 g
s
.854 .877 .856 r
.72296 .25908 m .72292 .25802 L p .73063 .25521 L F P
0 g
s
.854 .877 .856 r
.73063 .25521 m .72483 .26079 L .72296 .25908 L p F P
0 g
s
.775 .825 .892 r
.66584 .29772 m .6686 .29591 L .66854 .30043 L p F P
0 g
s
.776 .827 .892 r
.66854 .30043 m .67926 .29319 L .67669 .29051 L p F P
0 g
s
.776 .827 .892 r
.67669 .29051 m .6686 .29591 L .66854 .30043 L p F P
0 g
s
.868 .795 .776 r
.62893 .12173 m .63128 .12572 L .63614 .11946 L p F P
0 g
s
.868 .795 .776 r
.63614 .11946 m .63376 .11548 L .62893 .12173 L p F P
0 g
s
.868 .795 .776 r
.63499 .11389 m .63376 .11548 L .63614 .11946 L p F P
0 g
s
.986 .858 .49 r
.59436 .24902 m .59446 .24971 L .59616 .24764 L p F P
0 g
s
.986 .858 .49 r
.59616 .24764 m .59562 .24401 L .59436 .24902 L p F P
0 g
s
.532 .636 .899 r
.61146 .30347 m .60935 .3034 L .60928 .30795 L p F P
0 g
s
.532 .636 .899 r
.60928 .30795 m .6142 .30775 L .61146 .30347 L p F P
0 g
s
.693 .627 .779 r
.42996 .83559 m .42475 .8358 L .42282 .83186 L p F P
0 g
s
.727 .522 .613 r
.35359 .95514 m .35089 .95499 L .35027 .94891 L p F P
0 g
s
.733 .527 .612 r
.34545 .94855 m .35027 .94891 L .35089 .95499 L p F P
0 g
s
.685 .473 .593 r
.42528 .95645 m .43533 .95614 L .43569 .96194 L p F P
0 g
s
.685 .473 .593 r
.43569 .96194 m .42351 .96231 L .42528 .95645 L p F P
0 g
s
.744 .559 .645 r
.32857 .94089 m .31921 .93998 L .32228 .93382 L p F P
0 g
s
.745 .561 .645 r
.31711 .93329 m .32228 .93382 L .31921 .93998 L p F P
0 g
s
.652 .514 .682 r
.50421 .9112 m .51618 .90949 L p .50927 .91755 L F P
0 g
s
.652 .514 .682 r
.50927 .91755 m .50585 .91804 L .50421 .9112 L p F P
0 g
s
.655 .524 .692 r
.51436 .90249 m .51618 .90949 L .50421 .9112 L p F P
0 g
s
.655 .524 .692 r
.51102 .90297 m .51436 .90249 L p .50421 .9112 L F P
0 g
s
.95 .834 .695 r
.60649 .19351 m .60604 .19446 L .60516 .19243 L closepath p F P
0 g
s
.714 .642 .776 r
.38321 .83578 m .38204 .83349 L .37886 .83559 L closepath p F P
0 g
s
.687 .616 .771 r
.43935 .83827 m .4458 .83473 L .43795 .83523 L closepath p F P
0 g
s
.833 .863 .867 r
.71445 .27019 m .71413 .27047 L .71164 .26806 L p F P
0 g
s
.834 .868 .869 r
.71436 .26569 m .71445 .27019 L .72291 .26257 L p F P
0 g
s
.833 .863 .867 r
.71164 .26806 m .71436 .26569 L .71445 .27019 L p F P
0 g
s
.655 .496 .657 r
.49551 .92806 m .49808 .92587 L .49516 .92624 L closepath p F P
0 g
s
.661 .501 .657 r
.49516 .92624 m .49551 .92806 L .48953 .9335 L p F P
0 g
s
.672 .475 .611 r
.45925 .94886 m .46078 .94876 L .46137 .95473 L p F P
0 g
s
.672 .475 .611 r
.46137 .95473 m .45614 .95507 L .45925 .94886 L p F P
0 g
s
.887 .806 .763 r
.61808 .14399 m .62025 .14801 L .62451 .14197 L p F P
0 g
s
.887 .806 .763 r
.62451 .14197 m .62229 .13796 L .61808 .14399 L p F P
0 g
s
.694 .774 .913 r
.64146 .30711 m .63056 .31201 L .62787 .30856 L p F P
0 g
s
.709 .493 .594 r
.38522 .96229 m .38059 .96219 L .38026 .95637 L p F P
0 g
s
.716 .498 .593 r
.37519 .95619 m .38026 .95637 L .38059 .96219 L p F P
0 g
s
.847 .877 .863 r
.72483 .26079 m .72291 .26257 L .72296 .25908 L closepath p F P
0 g
s
.834 .868 .869 r
.72237 .25852 m .71436 .26569 L p .72291 .26257 L F P
0 g
s
.834 .868 .869 r
.72291 .26257 m .72296 .25908 L .72237 .25852 L p F P
0 g
s
.925 .748 .264 r
.59421 .26286 m .59489 .26724 L .59528 .26254 L p F P
0 g
s
.925 .748 .264 r
.59528 .26254 m .59457 .25816 L .59421 .26286 L p F P
0 g
s
0 0 .539 r
.5981 .28447 m .59823 .28901 L .5962 .28514 L p F P
0 g
s
0 0 .539 r
.5962 .28514 m .59622 .28054 L .5981 .28447 L p F P
0 g
s
.666 .471 .611 r
.46078 .94876 m .47347 .94776 L p .474 .95375 L F P
0 g
s
.666 .471 .611 r
.474 .95375 m .46137 .95473 L .46078 .94876 L p F P
0 g
s
.715 .645 .778 r
.37905 .82768 m .38204 .83349 L .37886 .83559 L p F P
0 g
s
.715 .645 .778 r
.36843 .83472 m .37905 .82768 L p .37886 .83559 L F P
0 g
s
.715 .645 .778 r
.37886 .83559 m .36864 .83513 L .36843 .83472 L p F P
0 g
s
.691 .625 .777 r
.43795 .83523 m .43641 .83201 L .42996 .83559 L closepath p F P
0 g
s
.693 .627 .779 r
.43346 .8259 m .43641 .83201 L .42996 .83559 L p F P
0 g
s
.693 .627 .779 r
.42282 .83186 m .43346 .8259 L p .42996 .83559 L F P
0 g
s
.751 .626 .722 r
.30136 .88373 m .30399 .88083 L .29993 .88026 L closepath p F P
0 g
s
.749 .633 .731 r
.29836 .87668 m .30239 .87246 L p .30399 .88083 L F P
0 g
s
.749 .633 .731 r
.30399 .88083 m .29993 .88026 L .29836 .87668 L p F P
0 g
s
.954 .906 .734 r
.77255 .19395 m .7723 .19438 L .77223 .19376 L closepath p F P
0 g
s
.755 .616 .704 r
.29207 .89466 m .30042 .89588 L .29515 .90261 L p F P
0 g
s
.754 .62 .71 r
.29777 .88781 m .29207 .89466 L .30042 .89588 L p F P
0 g
s
.666 .585 .755 r
.49662 .85021 m .49914 .85653 L .48705 .85817 L p F P
0 g
s
.666 .585 .755 r
.48705 .85817 m .48592 .85534 L .49662 .85021 L p F P
0 g
s
.956 .834 .682 r
.60185 .19574 m .60359 .19985 L .60604 .19446 L p F P
0 g
s
.956 .834 .682 r
.60381 .19138 m .60185 .19574 L p .60604 .19446 L F P
0 g
s
.956 .834 .682 r
.60604 .19446 m .60516 .19243 L .60381 .19138 L p F P
0 g
s
.716 .498 .593 r
.38059 .96219 m .37377 .96194 L .37519 .95619 L p F P
0 g
s
.717 .499 .594 r
.36576 .95582 m .37519 .95619 L .37377 .96194 L p F P
0 g
s
.737 .648 .761 r
.33239 .85059 m .33049 .84685 L .32678 .84992 L closepath p F P
0 g
s
.68 .61 .771 r
.46359 .83337 m .46651 .8399 L .46041 .84303 L p F P
0 g
s
.68 .61 .771 r
.45293 .8389 m .46359 .83337 L p .46041 .84303 L F P
0 g
s
.679 .608 .769 r
.46761 .84237 m .46651 .8399 L .46041 .84303 L closepath p F P
0 g
s
.679 .468 .594 r
.43533 .95614 m .44003 .95593 L .43815 .96183 L p F P
0 g
s
.679 .468 .594 r
.43815 .96183 m .43569 .96194 L .43533 .95614 L p F P
0 g
s
.937 .901 .763 r
.76799 .19587 m .76854 .2003 L .7723 .19438 L p F P
0 g
s
.937 .901 .763 r
.77024 .1923 m .76799 .19587 L p .7723 .19438 L F P
0 g
s
.937 .901 .763 r
.7723 .19438 m .77223 .19376 L .77024 .1923 L p F P
0 g
s
.918 .9 .793 r
.76229 .20944 m .76001 .21254 L .7604 .217 L p F P
0 g
s
.908 .895 .803 r
.75505 .21891 m .7555 .22335 L .7604 .217 L p F P
0 g
s
.908 .895 .803 r
.7604 .217 m .76001 .21254 L .75505 .21891 L p F P
0 g
s
.743 .646 .753 r
.3209 .85808 m .31982 .85589 L .31781 .85767 L closepath p F P
0 g
s
.659 .489 .644 r
.48953 .9335 m .4964 .93273 L p .48514 .94042 L F P
0 g
s
.659 .489 .644 r
.48514 .94042 m .48481 .93841 L .48953 .9335 L p F P
0 g
s
.659 .499 .656 r
.4964 .93273 m .49551 .92806 L .48953 .9335 L closepath p F P
0 g
s
.44 .592 .906 r
.74578 .06914 m .74893 .06949 L .7508 .07366 L p F P
0 g
s
.372 .547 .898 r
.75619 .07112 m .75795 .07534 L .7508 .07366 L p F P
0 g
s
.372 .547 .898 r
.7508 .07366 m .74893 .06949 L .75619 .07112 L p F P
0 g
s
.968 .853 .673 r
.59887 .2106 m .60026 .21481 L .60266 .20943 L p F P
0 g
s
.968 .853 .673 r
.60266 .20943 m .60119 .20524 L .59887 .2106 L p F P
0 g
s
.654 .496 .657 r
.4964 .93273 m .49551 .92806 L .49808 .92587 L p F P
0 g
s
.928 .692 .206 r
.78153 .12658 m .78272 .1309 L .78262 .12646 L p F P
0 g
s
.928 .692 .206 r
.78262 .12646 m .78144 .12213 L .78153 .12658 L p F P
0 g
s
.728 .643 .763 r
.34416 .84435 m .34612 .84284 L .34329 .8426 L closepath p F P
0 g
s
.673 .598 .763 r
.46943 .84663 m .48011 .84127 L p .47873 .8503 L F P
0 g
s
.674 .599 .763 r
.48 .84101 m .48011 .84127 L .46943 .84663 L p F P
0 g
s
.674 .599 .763 r
.46943 .84663 m .46761 .84237 L .48 .84101 L p F P
0 g
s
.734 .528 .613 r
.33552 .9478 m .34545 .94855 L .34349 .95444 L p F P
0 g
s
.733 .527 .612 r
.35089 .95499 m .34349 .95444 L .34545 .94855 L p F P
0 g
s
.996 .857 .53 r
.78136 .14966 m .78228 .15404 L .78357 .14905 L p F P
0 g
s
.996 .857 .53 r
.78357 .14905 m .78267 .14466 L .78136 .14966 L p F P
0 g
s
.755 .628 .72 r
.29777 .88781 m .30136 .88373 L .29993 .88026 L p F P
0 g
s
.654 .496 .657 r
.49808 .92587 m .50728 .92469 L p .4964 .93273 L F P
0 g
s
.655 .505 .668 r
.50728 .92469 m .50621 .9197 L .49808 .92587 L closepath p F P
0 g
s
.657 .508 .67 r
.50585 .91804 m .50621 .9197 L .49808 .92587 L p F P
0 g
s
.933 .827 .716 r
.60551 .18063 m .60736 .18472 L .61037 .17913 L p F P
0 g
s
.933 .827 .716 r
.61037 .17913 m .60846 .17506 L .60551 .18063 L p F P
0 g
s
.726 .649 .772 r
.35359 .83407 m .3548 .83641 L .34612 .84284 L p F P
0 g
s
.726 .649 .772 r
.34779 .83354 m .35359 .83407 L p .34612 .84284 L F P
0 g
s
.726 .649 .772 r
.34114 .83848 m .34779 .83354 L p .34612 .84284 L F P
0 g
s
.726 .649 .772 r
.34612 .84284 m .34329 .8426 L .34114 .83848 L p F P
0 g
s
.705 .638 .779 r
.40576 .82639 m .39564 .8326 L .39266 .82669 L p F P
0 g
s
.743 .547 .629 r
.33502 .94776 m .32609 .9469 L .32857 .94089 L p F P
0 g
s
.743 .548 .63 r
.31921 .93998 m .32857 .94089 L .32609 .9469 L p F P
0 g
s
.989 .85 .612 r
.59641 .22527 m .59774 .22949 L .59952 .22431 L p F P
0 g
s
.989 .85 .612 r
.59952 .22431 m .59814 .22011 L .59641 .22527 L p F P
0 g
s
.732 .799 .905 r
.64959 .30725 m .65498 .3043 L .65235 .30138 L p F P
0 g
s
.732 .799 .905 r
.65235 .30138 m .65016 .30254 L .64959 .30725 L p F P
0 g
s
.735 .792 .898 r
.64146 .30711 m .65016 .30254 L .64959 .30725 L p F P
0 g
s
.677 .466 .593 r
.44003 .95593 m .44846 .95553 L .44882 .96132 L p F P
0 g
s
.677 .466 .593 r
.44882 .96132 m .43815 .96183 L .44003 .95593 L p F P
0 g
s
.666 .586 .755 r
.49578 .8481 m .49662 .85021 L .48592 .85534 L p F P
0 g
s
.666 .586 .755 r
.48592 .85534 m .48367 .84973 L .49578 .8481 L p F P
0 g
s
.711 .643 .779 r
.39266 .82669 m .38204 .83349 L .37905 .82768 L p F P
0 g
s
.745 .561 .645 r
.31921 .93998 m .31836 .93989 L .31711 .93329 L p F P
0 g
s
.751 .565 .644 r
.3132 .93283 m .31711 .93329 L .31836 .93989 L p F P
0 g
s
.687 .623 .779 r
.4458 .83473 m .43795 .83523 L .43641 .83201 L p F P
0 g
s
.672 .596 .761 r
.48367 .84973 m .48302 .84818 L .47873 .8503 L closepath p F P
0 g
s
.673 .598 .763 r
.48011 .84127 m .48302 .84818 L .47873 .8503 L p F P
0 g
s
.699 .633 .779 r
.40924 .83205 m .4192 .8262 L .40642 .82639 L closepath p F P
0 g
s
.664 .493 .643 r
.48514 .94042 m .48481 .93841 L .4828 .94065 L closepath p F P
0 g
s
.573 .676 .909 r
.72936 .0621 m .7323 .06166 L .73439 .06578 L p F P
0 g
s
.548 .658 .908 r
.74071 .0608 m .7323 .06166 L .73439 .06578 L p F P
0 g
s
.548 .658 .908 r
.73439 .06578 m .74324 .06496 L .74071 .0608 L p F P
0 g
s
.681 .611 .771 r
.46357 .83331 m .46359 .83337 L .45293 .8389 L p F P
0 g
s
.681 .611 .771 r
.45293 .8389 m .45088 .83439 L .46357 .83331 L p F P
0 g
s
.654 .547 .721 r
.50821 .88196 m .51295 .87959 L p .52069 .88628 L F P
0 g
s
.654 .547 .721 r
.52069 .88628 m .51013 .88795 L .50821 .88196 L p F P
0 g
s
.654 .548 .722 r
.50821 .88196 m .51295 .87959 L .50772 .88041 L closepath p F P
0 g
s
.656 .556 .73 r
.51295 .87959 m .50772 .88041 L .50532 .87333 L p F P
0 g
s
.652 .539 .712 r
.51111 .89122 m .52069 .88628 L .51013 .88795 L closepath p F P
0 g
s
.72 .647 .776 r
.36864 .83513 m .36843 .83472 L .36791 .83508 L closepath p F P
0 g
s
.717 .499 .594 r
.37377 .96194 m .36607 .96165 L .36576 .95582 L p F P
0 g
s
.723 .504 .593 r
.36413 .95574 m .36576 .95582 L .36607 .96165 L p F P
0 g
s
.722 .644 .771 r
.3548 .83641 m .35765 .83436 L .36791 .83508 L p F P
0 g
s
.721 .649 .777 r
.36542 .82901 m .35765 .83436 L .36791 .83508 L p F P
0 g
s
.721 .649 .777 r
.36791 .83508 m .36843 .83472 L .36542 .82901 L p F P
0 g
s
.655 .532 .702 r
.51436 .90249 m .51402 .90126 L .51102 .90297 L closepath p F P
0 g
s
.656 .533 .702 r
.51234 .89531 m .51402 .90126 L .51102 .90297 L p F P
0 g
s
.909 .82 .747 r
.60943 .16543 m .61301 .15962 L .61504 .16367 L p F P
0 g
s
.909 .82 .747 r
.6111 .16886 m .60943 .16543 L p .61504 .16367 L F P
0 g
s
.909 .82 .747 r
.61504 .16367 m .61152 .16932 L .6111 .16886 L p F P
0 g
s
.652 .538 .712 r
.51234 .89531 m .51111 .89122 L .52069 .88628 L p F P
0 g
s
.808 .778 .826 r
.65919 .08817 m .65625 .09082 L .6536 .08701 L p F P
0 g
s
.831 .783 .807 r
.65185 .09537 m .65625 .09082 L .6536 .08701 L p F P
0 g
s
.65 .503 .67 r
.50621 .9197 m .50927 .91755 L .50585 .91804 L closepath p F P
0 g
s
.732 .651 .769 r
.34329 .8426 m .34114 .83848 L .3367 .84189 L closepath p F P
0 g
s
.753 .588 .672 r
.29918 .92424 m .30302 .91803 L p .30782 .92551 L F P
0 g
s
.755 .589 .672 r
.29918 .92424 m .30302 .91803 L .29731 .91728 L closepath p F P
0 g
s
.754 .597 .683 r
.29634 .91406 m .2988 .9104 L p .30302 .91803 L F P
0 g
s
.754 .597 .683 r
.30302 .91803 m .29731 .91728 L .29634 .91406 L p F P
0 g
s
.743 .647 .753 r
.3168 .84976 m .30924 .85648 L .31781 .85767 L p F P
0 g
s
.743 .647 .753 r
.31781 .85767 m .31982 .85589 L .3168 .84976 L p F P
0 g
s
.744 .643 .748 r
.30924 .85648 m .31781 .85767 L .30967 .86519 L p F P
0 g
s
.661 .479 .627 r
.4828 .94065 m .48514 .94042 L .48596 .94657 L p F P
0 g
s
.661 .479 .627 r
.48596 .94657 m .47777 .94736 L .4828 .94065 L p F P
0 g
s
.723 .504 .593 r
.36607 .96165 m .36277 .96148 L .36413 .95574 L p F P
0 g
s
.724 .506 .594 r
.35359 .95514 m .36413 .95574 L .36277 .96148 L p F P
0 g
s
.786 .772 .84 r
.66757 .08057 m .66695 .08106 L .66432 .07722 L p F P
0 g
s
.812 .779 .823 r
.65919 .08817 m .66695 .08106 L .66432 .07722 L p F P
0 g
s
.812 .779 .823 r
.66432 .07722 m .65673 .08419 L .65919 .08817 L p F P
0 g
s
.808 .778 .826 r
.6536 .08701 m .65673 .08419 L .65919 .08817 L p F P
0 g
s
.717 .647 .779 r
.37905 .82768 m .36843 .83472 L .36542 .82901 L p F P
0 g
s
.746 .637 .739 r
.30912 .86572 m .30967 .86519 L .30883 .86507 L closepath p F P
0 g
s
.744 .643 .748 r
.30609 .8594 m .30924 .85648 L p .30967 .86519 L F P
0 g
s
.744 .643 .748 r
.30967 .86519 m .30883 .86507 L .30609 .8594 L p F P
0 g
s
.945 .896 .749 r
.77223 .19376 m .77024 .1923 L .77166 .18997 L closepath p F P
0 g
s
.739 .645 .755 r
.32678 .84992 m .31982 .85589 L .3168 .84976 L p F P
0 g
s
.755 .628 .72 r
.29566 .87959 m .28954 .88655 L .29777 .88781 L p F P
0 g
s
.755 .628 .72 r
.29993 .88026 m .29566 .87959 L p .29777 .88781 L F P
0 g
s
.756 .624 .714 r
.28954 .88655 m .29777 .88781 L .29207 .89466 L p F P
0 g
s
.976 .898 .675 r
.77796 .17223 m .77704 .17424 L .77772 .17866 L p F P
0 g
s
.965 .898 .708 r
.77413 .17985 m .77485 .18426 L .77772 .17866 L p F P
0 g
s
.965 .898 .708 r
.77772 .17866 m .77704 .17424 L .77413 .17985 L p F P
0 g
s
.749 .641 .74 r
.30883 .86507 m .30912 .86572 L .30239 .87246 L p F P
0 g
s
.755 .635 .729 r
.29993 .88026 m .29836 .87668 L .29566 .87959 L closepath p F P
0 g
s
.789 .773 .838 r
.66757 .08057 m .67772 .07243 L .6751 .06856 L p F P
0 g
s
.789 .773 .838 r
.6751 .06856 m .66513 .07657 L .66757 .08057 L p F P
0 g
s
.786 .772 .84 r
.66432 .07722 m .66513 .07657 L .66757 .08057 L p F P
0 g
s
.987 .883 .631 r
.77859 .16445 m .77947 .16881 L .78147 .16355 L p F P
0 g
s
.987 .883 .631 r
.78147 .16355 m .78061 .15917 L .77859 .16445 L p F P
0 g
s
.751 .575 .656 r
.30782 .92551 m .30439 .93175 L .3132 .93283 L p F P
0 g
s
.753 .578 .658 r
.29923 .92443 m .30782 .92551 L .30439 .93175 L p F P
0 g
s
.753 .588 .672 r
.30782 .92551 m .29923 .92443 L .29918 .92424 L p F P
0 g
s
.656 .557 .731 r
.50532 .87333 m .50742 .87231 L .50509 .87267 L closepath p F P
0 g
s
.656 .556 .73 r
.50532 .87333 m .50742 .87231 L p .51295 .87959 L F P
0 g
s
.694 .628 .779 r
.43336 .82569 m .43346 .8259 L .42282 .83186 L p F P
0 g
s
.694 .628 .779 r
.42282 .83186 m .42005 .82618 L .43336 .82569 L p F P
0 g
s
.756 .599 .683 r
.29634 .91406 m .2988 .9104 L .29508 .90989 L closepath p F P
0 g
s
.755 .607 .694 r
.29344 .90496 m .29515 .90261 L p .2988 .9104 L F P
0 g
s
.755 .607 .694 r
.2988 .9104 m .29508 .90989 L .29344 .90496 L p F P
0 g
s
.65 .529 .703 r
.51402 .90126 m .51234 .89531 L .52415 .89342 L p F P
0 g
s
.652 .538 .712 r
.52195 .88608 m .52415 .89342 L .51234 .89531 L p F P
0 g
s
.652 .538 .712 r
.52069 .88628 m .52195 .88608 L p .51234 .89531 L F P
0 g
s
.657 .565 .739 r
.50742 .87231 m .50509 .87267 L .50242 .86522 L p F P
0 g
s
.997 .86 .552 r
.59467 .23968 m .59562 .24401 L .59712 .23892 L p F P
0 g
s
.997 .86 .552 r
.59712 .23892 m .59611 .23462 L .59467 .23968 L p F P
0 g
s
.866 .797 .781 r
.62442 .12745 m .62893 .12173 L .63128 .12572 L p F P
0 g
s
.866 .797 .781 r
.63128 .12572 m .62711 .13098 L .62442 .12745 L p F P
0 g
s
.749 .641 .74 r
.30136 .86393 m .30883 .86507 L p .30239 .87246 L F P
0 g
s
.75 .645 .745 r
.30883 .86507 m .30609 .8594 L .30136 .86393 L closepath p F P
0 g
s
.735 .755 .868 r
.69733 .06528 m .70207 .06254 L .69949 .05862 L p F P
0 g
s
.735 .755 .868 r
.69949 .05862 m .69499 .06124 L .69733 .06528 L p F P
0 g
s
.733 .755 .87 r
.68856 .06495 m .69499 .06124 L .69733 .06528 L p F P
0 g
s
.739 .645 .755 r
.3168 .84976 m .31789 .84882 L .32678 .84992 L p F P
0 g
s
.738 .649 .761 r
.32746 .84089 m .31789 .84882 L .32678 .84992 L p F P
0 g
s
.738 .649 .761 r
.32747 .84089 m .32746 .84089 L p .32678 .84992 L F P
0 g
s
.738 .649 .761 r
.32678 .84992 m .33049 .84685 L .32747 .84089 L p F P
0 g
s
.674 .606 .771 r
.4772 .8347 m .48 .84101 L .46761 .84237 L p F P
0 g
s
.674 .606 .771 r
.46761 .84237 m .46651 .8399 L .4772 .8347 L p F P
0 g
s
.65 .502 .669 r
.50728 .92469 m .50621 .9197 L .50927 .91755 L p F P
0 g
s
.671 .462 .593 r
.44846 .95553 m .45614 .95507 L .45413 .961 L p F P
0 g
s
.671 .462 .593 r
.45413 .961 m .44882 .96132 L .44846 .95553 L p F P
0 g
s
.654 .474 .628 r
.48596 .94657 m .48514 .94042 L .49744 .93905 L p F P
0 g
s
.659 .489 .644 r
.4964 .93273 m .49744 .93905 L .48514 .94042 L p F P
0 g
s
.831 .783 .807 r
.6536 .08701 m .64937 .09141 L .65185 .09537 L p F P
0 g
s
.828 .783 .81 r
.64293 .09795 m .64937 .09141 L .65185 .09537 L p F P
0 g
s
.828 .783 .81 r
.65185 .09537 m .6456 .10172 L .64293 .09795 L p F P
0 g
s
.751 .634 .731 r
.29836 .87668 m .30239 .87246 L .29611 .87154 L closepath p F P
0 g
s
.749 .641 .74 r
.29535 .86992 m .30136 .86393 L p .30239 .87246 L F P
0 g
s
.749 .641 .74 r
.30239 .87246 m .29611 .87154 L .29535 .86992 L p F P
0 g
s
.751 .565 .644 r
.31836 .93989 m .3103 .93894 L .3132 .93283 L p F P
0 g
s
.752 .567 .646 r
.30439 .93175 m .3132 .93283 L .3103 .93894 L p F P
0 g
s
.686 .62 .777 r
.45088 .83439 m .45 .83252 L .4458 .83473 L closepath p F P
0 g
s
.687 .623 .779 r
.44706 .82635 m .45 .83252 L .4458 .83473 L p F P
0 g
s
.687 .623 .779 r
.43641 .83201 m .44706 .82635 L p .4458 .83473 L F P
0 g
s
.757 .608 .693 r
.29344 .90496 m .29515 .90261 L .29253 .90223 L closepath p F P
0 g
s
.755 .616 .704 r
.2905 .89667 m .29207 .89466 L p .29515 .90261 L F P
0 g
s
.755 .616 .704 r
.29515 .90261 m .29253 .90223 L .2905 .89667 L p F P
0 g
s
.845 .576 .035 r
.78017 .11782 m .78144 .12213 L .78084 .11788 L p F P
0 g
s
.845 .576 .035 r
.78084 .11788 m .77957 .11357 L .78017 .11782 L p F P
0 g
s
.734 .647 .763 r
.33049 .84685 m .3367 .84189 L .32747 .84089 L closepath p F P
0 g
s
.888 .809 .765 r
.61659 .14612 m .61808 .14399 L .62025 .14801 L p F P
0 g
s
.888 .809 .765 r
.62025 .14801 m .61929 .14938 L .61659 .14612 L p F P
0 g
s
.11 .35 .817 r
.76628 .08633 m .76511 .08554 L .76255 .08079 L p F P
0 g
s
0 0 .221 r
.59583 .27608 m .59622 .28054 L .59536 .27626 L p F P
0 g
s
0 0 .221 r
.59536 .27626 m .59502 .27178 L .59583 .27608 L p F P
0 g
s
.65 .529 .703 r
.51436 .90249 m .51402 .90126 L .52475 .89556 L p F P
0 g
s
.65 .529 .703 r
.52415 .89342 m .52475 .89556 L .51402 .90126 L p F P
0 g
s
.654 .496 .657 r
.50728 .92469 m .50853 .93119 L .4964 .93273 L p F P
0 g
s
.651 .483 .644 r
.4964 .93273 m .50853 .93119 L p .50568 .93802 L F P
0 g
s
.651 .483 .644 r
.50568 .93802 m .49744 .93905 L .4964 .93273 L p F P
0 g
s
.667 .593 .763 r
.49372 .84318 m .49578 .8481 L .48367 .84973 L p F P
0 g
s
.667 .593 .763 r
.48367 .84973 m .48302 .84818 L .49372 .84318 L p F P
0 g
s
.723 .645 .772 r
.3548 .83641 m .35765 .83436 L .35359 .83407 L closepath p F P
0 g
s
.734 .528 .613 r
.33514 .94893 m .33552 .9478 L p .34349 .95444 L F P
0 g
s
.736 .529 .613 r
.33514 .94893 m .33552 .9478 L .33502 .94776 L closepath p F P
0 g
s
.79 .837 .887 r
.68252 .29086 m .67926 .29319 L .67669 .29051 L p F P
0 g
s
.656 .556 .73 r
.50742 .87231 m .51693 .87079 L p .51295 .87959 L F P
0 g
s
.656 .563 .738 r
.51693 .87079 m .51604 .86831 L .50742 .87231 L closepath p F P
0 g
s
.657 .565 .739 r
.51409 .86285 m .51604 .86831 L .50742 .87231 L p F P
0 g
s
.657 .565 .739 r
.50409 .86443 m .51409 .86285 L p .50742 .87231 L F P
0 g
s
.657 .565 .739 r
.50242 .86522 m .50409 .86443 L p .50742 .87231 L F P
0 g
s
.648 .519 .692 r
.51436 .90249 m .52615 .90059 L p .52446 .90816 L F P
0 g
s
.648 .519 .692 r
.52446 .90816 m .51618 .90949 L .51436 .90249 L p F P
0 g
s
.65 .529 .703 r
.52475 .89556 m .52615 .90059 L .51436 .90249 L p F P
0 g
s
.899 .889 .813 r
.75184 .22286 m .75505 .21891 L .7555 .22335 L p F P
0 g
s
.899 .889 .813 r
.7555 .22335 m .75422 .22491 L .75184 .22286 L p F P
0 g
s
.66 .467 .613 r
.47408 .95361 m .47777 .94736 L .47347 .94776 L closepath p F P
0 g
s
.666 .471 .611 r
.47347 .94776 m .47408 .95361 L .474 .95375 L p F P
0 g
s
.741 .533 .612 r
.33502 .94776 m .32609 .9469 L p .33362 .95366 L F P
0 g
s
.741 .533 .612 r
.33362 .95366 m .33514 .94893 L .33502 .94776 L p F P
0 g
s
.688 .623 .779 r
.44706 .82635 m .43641 .83201 L .43346 .8259 L p F P
0 g
s
.658 .565 .739 r
.50242 .86522 m .50409 .86443 L .50224 .86472 L closepath p F P
0 g
s
.65 .502 .669 r
.50927 .91755 m .5178 .91631 L p .50728 .92469 L F P
0 g
s
.651 .512 .681 r
.5178 .91631 m .51693 .91263 L .50927 .91755 L closepath p F P
0 g
s
.652 .514 .682 r
.51618 .90949 m .51693 .91263 L .50927 .91755 L p F P
0 g
s
.659 .573 .748 r
.50409 .86443 m .50224 .86472 L .49952 .85754 L p F P
0 g
s
.755 .636 .729 r
.29566 .87959 m .29836 .87668 L .29611 .87154 L p F P
0 g
s
.849 .786 .79 r
.64503 .10238 m .6456 .10172 L .64293 .09795 L p F P
0 g
s
.667 .592 .761 r
.49372 .84318 m .48302 .84818 L .48011 .84127 L p F P
0 g
s
.984 .808 .408 r
.59359 .25387 m .59457 .25816 L .59531 .25333 L p F P
0 g
s
.984 .808 .408 r
.59407 .2506 m .59359 .25387 L p .59531 .25333 L F P
0 g
s
.984 .808 .408 r
.59531 .25333 m .59446 .24971 L .59407 .2506 L p F P
0 g
s
.76 .601 .681 r
.29508 .90989 m .29048 .90918 L p .29451 .91687 L F P
0 g
s
.76 .601 .681 r
.29451 .91687 m .29634 .91406 L .29508 .90989 L p F P
0 g
s
.76 .61 .691 r
.29508 .90989 m .29344 .90496 L .29048 .90918 L closepath p F P
0 g
s
.675 .605 .77 r
.4772 .8347 m .46651 .8399 L .46359 .83337 L p F P
0 g
s
.906 .807 .739 r
.61656 .15384 m .61929 .14938 L .61659 .14612 L p F P
0 g
s
.849 .786 .79 r
.64293 .09795 m .64252 .09843 L .64503 .10238 L p F P
0 g
s
.849 .786 .791 r
.63687 .10499 m .63935 .10894 L .64503 .10238 L p F P
0 g
s
.849 .786 .791 r
.64503 .10238 m .64252 .09843 L .63687 .10499 L p F P
0 g
s
.761 .764 .855 r
.67822 .0721 m .67772 .07243 L .6751 .06856 L p F P
0 g
s
.724 .506 .594 r
.36277 .96148 m .35219 .96089 L .35359 .95514 L p F P
0 g
s
.726 .507 .595 r
.35089 .95499 m .35359 .95514 L .35219 .96089 L p F P
0 g
s
.681 .618 .778 r
.46067 .82715 m .46357 .83331 L .45088 .83439 L p F P
0 g
s
.681 .618 .778 r
.45088 .83439 m .45 .83252 L .46067 .82715 L p F P
0 g
s
.894 .891 .819 r
.75 .22991 m .75422 .22491 L .75184 .22286 L p F P
0 g
s
.721 .651 .78 r
.3633 .82499 m .36542 .82901 L .35765 .83436 L p F P
0 g
s
.721 .651 .78 r
.36032 .82476 m .3633 .82499 L p .35765 .83436 L F P
0 g
s
.721 .651 .78 r
.35178 .83068 m .36032 .82476 L p .35765 .83436 L F P
0 g
s
.721 .651 .78 r
.35765 .83436 m .35359 .83407 L .35178 .83068 L p F P
0 g
s
.76 .61 .691 r
.29048 .90918 m .29344 .90496 L .29253 .90223 L p F P
0 g
s
.732 .653 .771 r
.33811 .83268 m .34114 .83848 L .3367 .84189 L p F P
0 g
s
.732 .653 .771 r
.32746 .84088 m .33811 .83268 L p .3367 .84189 L F P
0 g
s
.732 .653 .771 r
.3367 .84189 m .32747 .84089 L .32746 .84088 L p F P
0 g
s
.761 .764 .855 r
.6751 .06856 m .6758 .06808 L .67822 .0721 L p F P
0 g
s
.764 .765 .853 r
.67822 .0721 m .68856 .06495 L .68596 .06104 L p F P
0 g
s
.764 .765 .853 r
.68596 .06104 m .6758 .06808 L .67822 .0721 L p F P
0 g
s
.759 .601 .681 r
.29731 .91728 m .29634 .91406 L .29451 .91687 L closepath p F P
0 g
s
.743 .548 .63 r
.3186 .94147 m .31921 .93998 L p .32609 .9469 L F P
0 g
s
.745 .549 .63 r
.3186 .94147 m .31921 .93998 L .31836 .93989 L closepath p F P
0 g
s
.669 .46 .592 r
.45614 .95507 m .46137 .95473 L .46174 .96051 L p F P
0 g
s
.669 .46 .592 r
.46174 .96051 m .45413 .961 L .45614 .95507 L p F P
0 g
s
.755 .817 .901 r
.66584 .29772 m .65498 .3043 L .65235 .30138 L p F P
0 g
s
.756 .632 .723 r
.28757 .87828 m .29566 .87959 L .28954 .88655 L p F P
0 g
s
.755 .636 .729 r
.29409 .87121 m .28757 .87828 L .29566 .87959 L p F P
0 g
s
.755 .636 .729 r
.29611 .87154 m .29409 .87121 L p .29566 .87959 L F P
0 g
s
.654 .547 .721 r
.51295 .87959 m .51954 .87853 L p .52069 .88628 L F P
0 g
s
.654 .555 .73 r
.51954 .87853 m .51894 .87674 L .51295 .87959 L closepath p F P
0 g
s
.656 .556 .73 r
.51693 .87079 m .51894 .87674 L .51295 .87959 L p F P
0 g
s
.76 .61 .691 r
.29253 .90223 m .28698 .90134 L p .29048 .90918 L F P
0 g
s
.761 .618 .701 r
.29253 .90223 m .2905 .89667 L .28698 .90134 L closepath p F P
0 g
s
.267 .463 .866 r
.76 .07614 m .75795 .07534 L .75962 .07958 L p F P
0 g
s
.267 .463 .866 r
.75962 .07958 m .76255 .08079 L .76 .07614 L p F P
0 g
s
.757 .617 .703 r
.2905 .89667 m .29207 .89466 L .28963 .89429 L closepath p F P
0 g
s
.756 .624 .714 r
.28753 .88897 m .28954 .88655 L p .29207 .89466 L F P
0 g
s
.756 .624 .714 r
.29207 .89466 m .28963 .89429 L .28753 .88897 L p F P
0 g
s
.931 .897 .772 r
.76391 .20192 m .76451 .20633 L .76854 .2003 L p F P
0 g
s
.931 .897 .772 r
.76854 .2003 m .76799 .19587 L .76391 .20192 L p F P
0 g
s
.793 .841 .888 r
.68252 .29086 m .69008 .28536 L .68753 .28277 L p F P
0 g
s
.793 .841 .888 r
.68753 .28277 m .68263 .2863 L .68252 .29086 L p F P
0 g
s
.79 .837 .887 r
.67669 .29051 m .68263 .2863 L .68252 .29086 L p F P
0 g
s
.734 .528 .613 r
.34349 .95444 m .33564 .95385 L .33514 .94893 L p F P
0 g
s
.74 .532 .612 r
.33564 .95385 m .33514 .94893 L .33362 .95366 L closepath p F P
0 g
s
.759 .592 .67 r
.29731 .91728 m .29451 .91687 L p .29908 .92441 L F P
0 g
s
.759 .592 .67 r
.29908 .92441 m .29918 .92424 L .29731 .91728 L p F P
0 g
s
.658 .572 .747 r
.51409 .86285 m .51314 .86033 L .50409 .86443 L closepath p F P
0 g
s
.659 .573 .748 r
.51102 .85468 m .51314 .86033 L .50409 .86443 L p F P
0 g
s
.659 .573 .748 r
.503 .85594 m .51102 .85468 L p .50409 .86443 L F P
0 g
s
.659 .573 .748 r
.49952 .85754 m .503 .85594 L p .50409 .86443 L F P
0 g
s
.992 .816 .44 r
.78157 .14033 m .78235 .13553 L .78346 .13986 L p F P
0 g
s
.992 .816 .44 r
.78251 .14396 m .78157 .14033 L p .78346 .13986 L F P
0 g
s
.992 .816 .44 r
.78346 .13986 m .78283 .14373 L .78251 .14396 L p F P
0 g
s
.75 .553 .629 r
.31836 .93989 m .3103 .93894 L p .31681 .94597 L F P
0 g
s
.75 .553 .629 r
.31681 .94597 m .3186 .94147 L .31836 .93989 L p F P
0 g
s
.732 .513 .594 r
.34349 .95444 m .35089 .95499 L .35122 .96084 L p F P
0 g
s
.726 .507 .595 r
.35219 .96089 m .35122 .96084 L .35089 .95499 L p F P
0 g
s
.691 .463 .572 r
.40869 .96253 m .40994 .96251 L .40923 .96811 L p F P
0 g
s
.691 .463 .572 r
.40923 .96811 m .40875 .96811 L .40869 .96253 L p F P
0 g
s
.697 .468 .572 r
.39724 .9625 m .40869 .96253 L .40875 .96811 L p F P
0 g
s
.689 .461 .572 r
.40994 .96251 m .42232 .96234 L .42239 .96793 L p F P
0 g
s
.689 .461 .572 r
.42239 .96793 m .40923 .96811 L .40994 .96251 L p F P
0 g
s
.642 .711 .897 r
.71566 .0615 m .72681 .05807 L .72936 .0621 L p F P
0 g
s
.644 .713 .897 r
.72681 .05807 m .71566 .0615 L .7131 .05755 L p F P
0 g
s
.695 .737 .883 r
.70207 .06254 m .7131 .05755 L .71566 .0615 L p F P
0 g
s
.697 .468 .572 r
.40875 .96811 m .39655 .96808 L .39724 .9625 L p F P
0 g
s
.699 .469 .572 r
.39479 .96248 m .39724 .9625 L .39655 .96808 L p F P
0 g
s
.884 .797 .759 r
.62642 .13198 m .62711 .13098 L .62442 .12745 L p F P
0 g
s
.699 .469 .572 r
.39655 .96808 m .39483 .96807 L .39479 .96248 L p F P
0 g
s
.705 .474 .572 r
.38522 .96229 m .39479 .96248 L .39483 .96807 L p F P
0 g
s
.444 .597 .908 r
.74893 .06949 m .74578 .06914 L .74324 .06496 L p F P
0 g
s
.659 .467 .612 r
.47777 .94736 m .48596 .94657 L p .47409 .95374 L F P
0 g
s
.659 .467 .612 r
.47409 .95374 m .47408 .95361 L .47777 .94736 L p F P
0 g
s
.706 .409 0 r
.77822 .10927 m .77957 .11357 L .77841 .10954 L p F P
0 g
s
.706 .409 0 r
.77841 .10954 m .77706 .10525 L .77822 .10927 L p F P
0 g
s
.647 .491 .658 r
.50728 .92469 m .51924 .92298 L p .51427 .93037 L F P
0 g
s
.647 .491 .658 r
.51427 .93037 m .50853 .93119 L .50728 .92469 L p F P
0 g
s
.65 .502 .669 r
.5178 .91631 m .51924 .92298 L .50728 .92469 L p F P
0 g
s
.726 .654 .777 r
.35359 .83407 m .35178 .83068 L .34779 .83354 L closepath p F P
0 g
s
.728 .65 .771 r
.34779 .83354 m .34114 .83848 L .33811 .83268 L p F P
0 g
s
.696 .737 .883 r
.7131 .05755 m .70207 .06254 L .69949 .05862 L p F P
0 g
s
.945 .846 .713 r
.60516 .19243 m .60381 .19138 L .60436 .19032 L closepath p F P
0 g
s
.761 .619 .701 r
.28698 .90134 m .2905 .89667 L .28963 .89429 L p F P
0 g
s
.683 .456 .572 r
.42232 .96234 m .42351 .96231 L .42277 .96792 L p F P
0 g
s
.683 .456 .572 r
.42277 .96792 m .42239 .96793 L .42232 .96234 L p F P
0 g
s
.682 .618 .778 r
.46067 .82715 m .45 .83252 L .44706 .82635 L p F P
0 g
s
.646 .509 .682 r
.51693 .91263 m .52446 .90816 L .51618 .90949 L closepath p F P
0 g
s
.884 .797 .759 r
.62442 .12745 m .62403 .12801 L .62642 .13198 L p F P
0 g
s
.885 .797 .757 r
.61993 .13399 m .62229 .13796 L .62642 .13198 L p F P
0 g
s
.885 .797 .757 r
.62642 .13198 m .62403 .12801 L .61993 .13399 L p F P
0 g
s
.681 .455 .571 r
.42351 .96231 m .43569 .96194 L .43578 .96752 L p F P
0 g
s
.681 .455 .571 r
.43578 .96752 m .42277 .96792 L .42351 .96231 L p F P
0 g
s
.66 .574 .748 r
.49952 .85754 m .503 .85594 L .49914 .85653 L closepath p F P
0 g
s
.705 .474 .572 r
.39483 .96807 m .38456 .96787 L .38522 .96229 L p F P
0 g
s
.707 .476 .572 r
.38059 .96219 m .38522 .96229 L .38456 .96787 L p F P
0 g
s
.878 .883 .834 r
.74423 .23761 m .74369 .23712 L .74416 .2366 L closepath p F P
0 g
s
.663 .455 .593 r
.46137 .95473 m .474 .95375 L .47183 .95973 L p F P
0 g
s
.663 .455 .593 r
.47183 .95973 m .46174 .96051 L .46137 .95473 L p F P
0 g
s
.96 .837 .677 r
.59952 .20111 m .60119 .20524 L .60359 .19985 L p F P
0 g
s
.96 .837 .677 r
.60359 .19985 m .60185 .19574 L .59952 .20111 L p F P
0 g
s
.699 .639 .786 r
.4192 .8262 m .40642 .82639 L .40627 .82609 L p F P
0 g
s
.703 .641 .784 r
.40642 .82639 m .40627 .82609 L .40576 .82639 L closepath p F P
0 g
s
.705 .638 .779 r
.39266 .82669 m .39333 .82629 L .40576 .82639 L p F P
0 g
s
.704 .644 .786 r
.40329 .8204 m .39333 .82629 L .40576 .82639 L p F P
0 g
s
.704 .644 .786 r
.40576 .82639 m .40627 .82609 L .40329 .8204 L p F P
0 g
s
.706 .64 .781 r
.39266 .82669 m .39333 .82629 L .39245 .82628 L closepath p F P
0 g
s
.711 .643 .779 r
.39245 .82628 m .39266 .82669 L p .37905 .82768 L F P
0 g
s
.936 .831 .716 r
.60257 .18621 m .60436 .19032 L .60736 .18472 L p F P
0 g
s
.936 .831 .716 r
.60736 .18472 m .60551 .18063 L .60257 .18621 L p F P
0 g
s
.743 .548 .63 r
.32609 .9469 m .3193 .94625 L .3186 .94147 L p F P
0 g
s
.749 .552 .628 r
.3193 .94625 m .3186 .94147 L .31681 .94597 L closepath p F P
0 g
s
.761 .619 .701 r
.28963 .89429 m .28401 .89335 L p .28698 .90134 L F P
0 g
s
.761 .627 .711 r
.28963 .89429 m .28753 .88897 L .28401 .89335 L closepath p F P
0 g
s
.66 .582 .756 r
.503 .85594 m .49914 .85653 L .49662 .85021 L p F P
0 g
s
.923 .815 .721 r
.61152 .16932 m .61142 .16949 L .6111 .16886 L closepath p F P
0 g
s
.7 .641 .787 r
.4169 .82007 m .40627 .82609 L .40329 .8204 L p F P
0 g
s
.699 .639 .786 r
.40627 .82609 m .4169 .82007 L p .4192 .8262 L F P
0 g
s
.707 .476 .572 r
.38456 .96787 m .38062 .96778 L .38059 .96219 L p F P
0 g
s
.713 .481 .572 r
.37377 .96194 m .38059 .96219 L .38062 .96778 L p F P
0 g
s
.758 .591 .67 r
.29923 .92443 m .29918 .92424 L .29908 .92441 L closepath p F P
0 g
s
.973 .859 .667 r
.59664 .21594 m .59887 .2106 L .60026 .21481 L p F P
0 g
s
.973 .859 .667 r
.59709 .21738 m .59664 .21594 L p .60026 .21481 L F P
0 g
s
.973 .859 .667 r
.60026 .21481 m .59886 .21813 L .59709 .21738 L p F P
0 g
s
.894 .891 .819 r
.75184 .22286 m .74966 .22544 L .75 .22991 L p F P
0 g
s
.886 .886 .827 r
.74376 .23216 m .74416 .2366 L .75 .22991 L p F P
0 g
s
.886 .886 .827 r
.75 .22991 m .74966 .22544 L .74376 .23216 L p F P
0 g
s
.753 .578 .658 r
.30439 .93175 m .30082 .93131 L .29923 .92443 L p F P
0 g
s
.759 .582 .656 r
.29908 .92441 m .29923 .92443 L .30082 .93131 L p F P
0 g
s
.705 .646 .788 r
.40105 .81616 m .40329 .8204 L .39333 .82629 L p F P
0 g
s
.705 .646 .788 r
.398 .81611 m .40105 .81616 L p .39333 .82629 L F P
0 g
s
.705 .646 .788 r
.38967 .82107 m .398 .81611 L p .39333 .82629 L F P
0 g
s
.705 .646 .788 r
.39333 .82629 m .39245 .82628 L .38967 .82107 L p F P
0 g
s
.746 .644 .748 r
.30609 .8594 m .30924 .85648 L .30435 .85579 L closepath p F P
0 g
s
.744 .65 .757 r
.31622 .8486 m .3168 .84976 L .30924 .85648 L p F P
0 g
s
.744 .65 .757 r
.30941 .8476 m .31622 .8486 L p .30924 .85648 L F P
0 g
s
.744 .65 .757 r
.30305 .85324 m .30941 .8476 L p .30924 .85648 L F P
0 g
s
.744 .65 .757 r
.30924 .85648 m .30435 .85579 L .30305 .85324 L p F P
0 g
s
.759 .592 .67 r
.29451 .91687 m .29079 .92319 L .29908 .92441 L p F P
0 g
s
.761 .594 .671 r
.28629 .91562 m .29451 .91687 L .29079 .92319 L p F P
0 g
s
.76 .601 .681 r
.29048 .90918 m .28629 .91562 L .29451 .91687 L p F P
0 g
s
.711 .643 .779 r
.37905 .82768 m .38176 .82594 L .39245 .82628 L p F P
0 g
s
.711 .644 .78 r
.37905 .82768 m .38176 .82594 L .37808 .82581 L closepath p F P
0 g
s
.717 .647 .779 r
.37808 .82581 m .37905 .82768 L p .36542 .82901 L F P
0 g
s
.71 .648 .786 r
.39245 .82628 m .38967 .82107 L .38176 .82594 L closepath p F P
0 g
s
.75 .646 .746 r
.30136 .86393 m .30609 .8594 L .30435 .85579 L p F P
0 g
s
.929 .815 .712 r
.60639 .17103 m .60846 .17506 L .61142 .16949 L p F P
0 g
s
.929 .815 .712 r
.60882 .16643 m .60639 .17103 L p .61142 .16949 L F P
0 g
s
.929 .815 .712 r
.61142 .16949 m .6111 .16886 L .60882 .16643 L p F P
0 g
s
.759 .582 .656 r
.30082 .93131 m .29584 .93061 L .29908 .92441 L p F P
0 g
s
.76 .584 .658 r
.29079 .92319 m .29908 .92441 L .29584 .93061 L p F P
0 g
s
.755 .643 .737 r
.29611 .87154 m .29535 .86992 L .29409 .87121 L closepath p F P
0 g
s
0 0 .399 r
.77561 .10097 m .77706 .10525 L .77525 .10147 L p F P
0 g
s
0 0 .399 r
.77525 .10147 m .7738 .0972 L .77561 .10097 L p F P
0 g
s
.698 .636 .784 r
.42005 .82618 m .41987 .82582 L .4192 .8262 L closepath p F P
0 g
s
.699 .639 .786 r
.4169 .82007 m .41987 .82582 L .4192 .8262 L p F P
0 g
s
.74 .647 .756 r
.3168 .84976 m .31789 .84882 L .31622 .8486 L closepath p F P
0 g
s
.11 .35 .817 r
.76255 .08079 m .76459 .08211 L .76628 .08633 L p F P
0 g
s
0 .22 .74 r
.76804 .08523 m .76969 .08946 L .76628 .08633 L p F P
0 g
s
0 .22 .74 r
.76628 .08633 m .76459 .08211 L .76804 .08523 L p F P
0 g
s
.693 .634 .786 r
.43051 .82008 m .43336 .82569 L .42005 .82618 L p F P
0 g
s
.693 .634 .786 r
.42005 .82618 m .41987 .82582 L .43051 .82008 L p F P
0 g
s
.752 .642 .739 r
.30136 .86393 m .29535 .86992 L .29232 .86345 L p F P
0 g
s
.752 .642 .739 r
.29232 .86345 m .29311 .86265 L .30136 .86393 L p F P
0 g
s
.75 .646 .746 r
.30088 .85523 m .29311 .86265 L .30136 .86393 L p F P
0 g
s
.75 .646 .746 r
.30435 .85579 m .30088 .85523 L p .30136 .86393 L F P
0 g
s
.623 .723 .918 r
.6142 .30775 m .62517 .305 L .62787 .30856 L p F P
0 g
s
.598 .705 .919 r
.62517 .305 m .6142 .30775 L .61146 .30347 L p F P
0 g
s
.739 .653 .765 r
.31878 .83972 m .32746 .84089 L .31789 .84882 L p F P
0 g
s
.739 .653 .765 r
.31375 .84388 m .31878 .83972 L p .31789 .84882 L F P
0 g
s
.739 .653 .765 r
.31789 .84882 m .31622 .8486 L .31375 .84388 L p F P
0 g
s
.846 .788 .795 r
.63231 .11017 m .63687 .10499 L .63935 .10894 L p F P
0 g
s
.846 .788 .795 r
.63935 .10894 m .63499 .11389 L .63231 .11017 L p F P
0 g
s
.758 .625 .713 r
.28753 .88897 m .28954 .88655 L .28637 .88605 L closepath p F P
0 g
s
.756 .632 .723 r
.28454 .88173 m .28757 .87828 L p .28954 .88655 L F P
0 g
s
.756 .632 .723 r
.28954 .88655 m .28637 .88605 L .28454 .88173 L p F P
0 g
s
.761 .605 .684 r
.28235 .90789 m .29048 .90918 L .28629 .91562 L p F P
0 g
s
.76 .61 .691 r
.28698 .90134 m .28235 .90789 L .29048 .90918 L p F P
0 g
s
.645 .508 .681 r
.5178 .91631 m .51693 .91263 L .52446 .90816 L p F P
0 g
s
.741 .533 .612 r
.32609 .9469 m .32417 .95277 L .33362 .95366 L p F P
0 g
s
.743 .535 .613 r
.3193 .94625 m .32609 .9469 L .32417 .95277 L p F P
0 g
s
.694 .636 .787 r
.43051 .82008 m .41987 .82582 L .4169 .82007 L p F P
0 g
s
.733 .513 .594 r
.33564 .95385 m .34349 .95444 L .34215 .96017 L p F P
0 g
s
.732 .513 .594 r
.35122 .96084 m .34215 .96017 L .34349 .95444 L p F P
0 g
s
0 .025 .597 r
.77225 .09294 m .7738 .0972 L .77125 .09371 L p F P
0 g
s
0 .025 .597 r
.77125 .09371 m .76969 .08946 L .77225 .09294 L p F P
0 g
s
.752 .567 .646 r
.30191 .93689 m .30439 .93175 L p .3103 .93894 L F P
0 g
s
.754 .569 .646 r
.30191 .93689 m .30439 .93175 L .30082 .93131 L closepath p F P
0 g
s
.713 .481 .572 r
.38062 .96778 m .37313 .96751 L .37377 .96194 L p F P
0 g
s
.714 .482 .572 r
.36607 .96165 m .37377 .96194 L .37313 .96751 L p F P
0 g
s
.805 .846 .881 r
.69446 .282 m .69008 .28536 L .68753 .28277 L p F P
0 g
s
.675 .449 .571 r
.43569 .96194 m .43815 .96183 L .43738 .96745 L p F P
0 g
s
.675 .449 .571 r
.43738 .96745 m .43578 .96752 L .43569 .96194 L p F P
0 g
s
.955 .895 .729 r
.77092 .18558 m .77166 .18997 L .77485 .18426 L p F P
0 g
s
.955 .895 .729 r
.77485 .18426 m .77413 .17985 L .77092 .18558 L p F P
0 g
s
.717 .647 .779 r
.36542 .82901 m .37081 .82542 L .37808 .82581 L p F P
0 g
s
.717 .648 .78 r
.36542 .82901 m .37081 .82542 L .3633 .82499 L closepath p F P
0 g
s
.994 .872 .591 r
.77967 .1548 m .78061 .15917 L .78228 .15404 L p F P
0 g
s
.994 .872 .591 r
.78228 .15404 m .78136 .14966 L .77967 .1548 L p F P
0 g
s
.727 .655 .778 r
.34875 .82506 m .33818 .83263 L .34779 .83354 L p F P
0 g
s
.727 .655 .778 r
.34779 .83354 m .35178 .83068 L .34875 .82506 L p F P
0 g
s
.728 .65 .771 r
.33811 .83268 m .33818 .83263 L .34779 .83354 L p F P
0 g
s
.838 .64 .095 r
.59433 .2674 m .59502 .27178 L .59489 .26724 L p F P
0 g
s
.838 .64 .095 r
.59489 .26724 m .59421 .26286 L .59433 .2674 L p F P
0 g
s
.994 .85 .59 r
.59484 .23038 m .59611 .23462 L .59774 .22949 L p F P
0 g
s
.994 .85 .59 r
.59774 .22949 m .59641 .22527 L .59484 .23038 L p F P
0 g
s
.755 .644 .738 r
.29409 .87121 m .29535 .86992 L .29232 .86345 L p F P
0 g
s
.744 .655 .762 r
.31622 .8486 m .31375 .84388 L .30941 .8476 L closepath p F P
0 g
s
.667 .592 .761 r
.49213 .8394 m .49372 .84318 L p .48011 .84127 L F P
0 g
s
.667 .592 .761 r
.48011 .84127 m .48092 .84089 L .49213 .8394 L p F P
0 g
s
.669 .596 .765 r
.48011 .84127 m .48092 .84089 L .48 .84101 L closepath p F P
0 g
s
.71 .65 .788 r
.38692 .81592 m .38967 .82107 L .38176 .82594 L p F P
0 g
s
.71 .65 .788 r
.38599 .81589 m .38692 .81592 L p .38176 .82594 L F P
0 g
s
.71 .65 .788 r
.37604 .82205 m .38599 .81589 L p .38176 .82594 L F P
0 g
s
.71 .65 .788 r
.38176 .82594 m .37808 .82581 L .37604 .82205 L p F P
0 g
s
.576 .679 .91 r
.7323 .06166 m .72936 .0621 L .72681 .05807 L p F P
0 g
s
.673 .448 .571 r
.43815 .96183 m .44882 .96132 L .44892 .9669 L p F P
0 g
s
.673 .448 .571 r
.44892 .9669 m .43738 .96745 L .43815 .96183 L p F P
0 g
s
.669 .603 .772 r
.48092 .84089 m .48 .84101 L .4772 .8347 L p F P
0 g
s
.756 .64 .733 r
.28614 .86985 m .29409 .87121 L .28757 .87828 L p F P
0 g
s
.755 .644 .738 r
.29232 .86345 m .28614 .86985 L .29409 .87121 L p F P
0 g
s
.762 .627 .711 r
.28401 .89335 m .28753 .88897 L .28637 .88605 L p F P
0 g
s
.906 .807 .739 r
.61659 .14612 m .61432 .14985 L .61656 .15384 L p F P
0 g
s
.906 .807 .739 r
.61082 .15562 m .61301 .15962 L .61656 .15384 L p F P
0 g
s
.906 .807 .739 r
.61656 .15384 m .61432 .14985 L .61082 .15562 L p F P
0 g
s
.653 .546 .721 r
.52195 .88608 m .52184 .88572 L .52069 .88628 L closepath p F P
0 g
s
.654 .547 .721 r
.51954 .87853 m .52184 .88572 L .52069 .88628 L p F P
0 g
s
.762 .614 .695 r
.27896 .90002 m .28698 .90134 L .28235 .90789 L p F P
0 g
s
.761 .619 .701 r
.28401 .89335 m .27896 .90002 L .28698 .90134 L p F P
0 g
s
.914 .822 .742 r
.6111 .16886 m .60882 .16643 L .60943 .16543 L closepath p F P
0 g
s
.715 .652 .786 r
.37808 .82581 m .37604 .82205 L .37081 .82542 L closepath p F P
0 g
s
.668 .601 .771 r
.49213 .8394 m .49081 .83638 L .48092 .84089 L closepath p F P
0 g
s
.669 .603 .772 r
.48819 .8304 m .49081 .83638 L .48092 .84089 L p F P
0 g
s
.669 .603 .772 r
.48581 .83071 m .48819 .8304 L p .48092 .84089 L F P
0 g
s
.669 .603 .772 r
.4772 .8347 m .48581 .83071 L p .48092 .84089 L F P
0 g
s
.737 .655 .768 r
.32747 .84089 m .32746 .84088 L .32746 .84089 L closepath p F P
0 g
s
.739 .658 .77 r
.32442 .83522 m .31878 .83972 L .32746 .84089 L p F P
0 g
s
.739 .658 .77 r
.32746 .84089 m .32746 .84088 L .32442 .83522 L p F P
0 g
s
.735 .656 .772 r
.33811 .83268 m .32746 .84088 L .32442 .83522 L p F P
0 g
s
.648 .471 .629 r
.49744 .93905 m .50568 .93802 L .4993 .94509 L p F P
0 g
s
.648 .471 .629 r
.4993 .94509 m .49829 .94522 L .49744 .93905 L p F P
0 g
s
.654 .474 .628 r
.49744 .93905 m .49829 .94522 L .48596 .94657 L p F P
0 g
s
.978 .888 .668 r
.77622 .16985 m .77859 .16445 L .77947 .16881 L p F P
0 g
s
.978 .888 .668 r
.77656 .1715 m .77622 .16985 L p .77947 .16881 L F P
0 g
s
.978 .888 .668 r
.77947 .16881 m .77796 .17223 L .77656 .1715 L p F P
0 g
s
.675 .605 .77 r
.47598 .83196 m .4772 .8347 L p .46359 .83337 L F P
0 g
s
.675 .605 .77 r
.46359 .83337 m .46374 .8333 L .47598 .83196 L p F P
0 g
s
.676 .609 .773 r
.46359 .83337 m .46374 .8333 L .46357 .83331 L closepath p F P
0 g
s
.676 .616 .78 r
.46374 .8333 m .46357 .83331 L .46067 .82715 L p F P
0 g
s
.652 .46 .612 r
.48596 .94657 m .49829 .94522 L p .49502 .95162 L F P
0 g
s
.652 .46 .612 r
.49502 .95162 m .48658 .95254 L .48596 .94657 L p F P
0 g
s
.659 .467 .612 r
.48596 .94657 m .48658 .95254 L .47409 .95374 L p F P
0 g
s
.675 .613 .779 r
.47598 .83196 m .47428 .8283 L .46374 .8333 L closepath p F P
0 g
s
.676 .616 .78 r
.47161 .82258 m .47428 .8283 L .46374 .8333 L p F P
0 g
s
.676 .616 .78 r
.46979 .82277 m .47161 .82258 L p .46374 .8333 L F P
0 g
s
.676 .616 .78 r
.46067 .82715 m .46979 .82277 L p .46374 .8333 L F P
0 g
s
.659 .58 .755 r
.51102 .85468 m .51025 .85272 L .503 .85594 L closepath p F P
0 g
s
.66 .582 .756 r
.50769 .84627 m .51025 .85272 L .503 .85594 L p F P
0 g
s
.66 .582 .756 r
.50414 .84682 m .50769 .84627 L p .503 .85594 L F P
0 g
s
.66 .582 .756 r
.49662 .85021 m .50414 .84682 L p .503 .85594 L F P
0 g
s
.688 .623 .779 r
.44637 .8249 m .44706 .82635 L p .43346 .8259 L F P
0 g
s
.688 .623 .779 r
.43346 .8259 m .43391 .82566 L .44637 .8249 L p F P
0 g
s
.689 .627 .781 r
.43346 .8259 m .43391 .82566 L .43336 .82569 L closepath p F P
0 g
s
.694 .774 .913 r
.62787 .30856 m .63879 .30392 L .64146 .30711 L p F P
0 g
s
.728 .785 .898 r
.65016 .30254 m .64146 .30711 L .63879 .30392 L p F P
0 g
s
.714 .482 .572 r
.37313 .96751 m .36609 .96724 L .36607 .96165 L p F P
0 g
s
.721 .487 .572 r
.36277 .96148 m .36607 .96165 L .36609 .96724 L p F P
0 g
s
.809 .85 .881 r
.69446 .282 m .70087 .277 L .69834 .27448 L p F P
0 g
s
.809 .85 .881 r
.69834 .27448 m .69451 .27746 L .69446 .282 L p F P
0 g
s
.805 .846 .881 r
.68753 .28277 m .69451 .27746 L .69446 .282 L p F P
0 g
s
.643 .498 .67 r
.5178 .91631 m .52959 .91441 L p .52606 .92189 L F P
0 g
s
.643 .498 .67 r
.52606 .92189 m .51924 .92298 L .5178 .91631 L p F P
0 g
s
.645 .508 .681 r
.52797 .90759 m .52959 .91441 L .5178 .91631 L p F P
0 g
s
.645 .508 .681 r
.52446 .90816 m .52797 .90759 L p .5178 .91631 L F P
0 g
s
.688 .633 .789 r
.43391 .82566 m .43336 .82569 L .43051 .82008 L p F P
0 g
s
.865 .789 .774 r
.63376 .11548 m .63499 .11389 L .63231 .11017 L p F P
0 g
s
.976 .769 .349 r
.78116 .13122 m .78235 .13553 L .78272 .1309 L p F P
0 g
s
.976 .769 .349 r
.78272 .1309 m .78153 .12658 L .78116 .13122 L p F P
0 g
s
.661 .583 .756 r
.49662 .85021 m .50414 .84682 L .49578 .8481 L closepath p F P
0 g
s
.647 .543 .723 r
.52184 .88572 m .51954 .87853 L .53119 .87645 L p F P
0 g
s
.649 .552 .731 r
.52969 .87201 m .53119 .87645 L .51954 .87853 L p F P
0 g
s
.649 .552 .731 r
.51954 .87853 m .51894 .87674 L .52969 .87201 L p F P
0 g
s
.647 .543 .722 r
.52195 .88608 m .52184 .88572 L .5326 .88088 L p F P
0 g
s
.647 .543 .723 r
.53119 .87645 m .5326 .88088 L .52184 .88572 L p F P
0 g
s
.647 .543 .722 r
.5326 .88088 m .53358 .88399 L .52195 .88608 L p F P
0 g
s
.645 .533 .713 r
.52195 .88608 m .53358 .88399 L p .532 .89203 L F P
0 g
s
.645 .533 .713 r
.532 .89203 m .52415 .89342 L .52195 .88608 L p F P
0 g
s
.75 .553 .629 r
.3103 .93894 m .30789 .94493 L .31681 .94597 L p F P
0 g
s
.752 .555 .63 r
.30212 .93797 m .3103 .93894 L .30789 .94493 L p F P
0 g
s
.752 .567 .646 r
.3103 .93894 m .30212 .93797 L .30191 .93689 L p F P
0 g
s
.687 .63 .787 r
.44637 .8249 m .44412 .82041 L .43391 .82566 L closepath p F P
0 g
s
.688 .633 .789 r
.44139 .81498 m .44412 .82041 L .43391 .82566 L p F P
0 g
s
.688 .633 .789 r
.44019 .81504 m .44139 .81498 L p .43391 .82566 L F P
0 g
s
.688 .633 .789 r
.43051 .82008 m .44019 .81504 L p .43391 .82566 L F P
0 g
s
.876 .879 .833 r
.74127 .23489 m .74376 .23216 L .74416 .2366 L p F P
0 g
s
.876 .879 .833 r
.74416 .2366 m .74369 .23712 L .74127 .23489 L p F P
0 g
s
.762 .627 .711 r
.28637 .88605 m .28157 .88521 L p .28401 .89335 L F P
0 g
s
.762 .635 .72 r
.28637 .88605 m .28454 .88173 L .28157 .88521 L closepath p F P
0 g
s
.723 .654 .78 r
.36032 .82476 m .35178 .83068 L .34875 .82506 L p F P
0 g
s
.649 .552 .731 r
.52858 .86872 m .52969 .87201 L .51894 .87674 L p F P
0 g
s
.649 .552 .731 r
.51894 .87674 m .51693 .87079 L .52858 .86872 L p F P
0 g
s
.871 .88 .84 r
.73759 .24356 m .74369 .23712 L .74127 .23489 L p F P
0 g
s
.921 .893 .785 r
.75994 .20753 m .76391 .20192 L .76451 .20633 L p F P
0 g
s
.921 .893 .785 r
.76451 .20633 m .76229 .20944 L .75994 .20753 L p F P
0 g
s
.733 .753 .869 r
.69499 .06124 m .68856 .06495 L .68596 .06104 L p F P
0 g
s
.758 .572 .645 r
.30082 .93131 m .29584 .93061 L p .30145 .93788 L F P
0 g
s
.758 .572 .645 r
.30145 .93788 m .30191 .93689 L .30082 .93131 L p F P
0 g
s
.75 .653 .754 r
.30435 .85579 m .30305 .85324 L .30088 .85523 L closepath p F P
0 g
s
.995 .849 .503 r
.59349 .24467 m .59436 .24902 L .59562 .24401 L p F P
0 g
s
.995 .849 .503 r
.59562 .24401 m .59467 .23968 L .59349 .24467 L p F P
0 g
s
.356 .505 .869 r
.60592 .29403 m .6019 .29231 L .60191 .29687 L p F P
0 g
s
.356 .505 .869 r
.60191 .29687 m .6087 .29896 L .60592 .29403 L p F P
0 g
s
.721 .487 .572 r
.36609 .96724 m .36214 .96703 L .36277 .96148 L p F P
0 g
s
.722 .488 .572 r
.35219 .96089 m .36277 .96148 L .36214 .96703 L p F P
0 g
s
.845 .869 .859 r
.72296 .25908 m .72237 .25852 L .72292 .25802 L closepath p F P
0 g
s
.651 .56 .74 r
.52679 .86368 m .52858 .86872 L .51693 .87079 L p F P
0 g
s
.651 .56 .74 r
.51693 .87079 m .51604 .86831 L .52679 .86368 L p F P
0 g
s
.644 .479 .644 r
.50913 .9348 m .51427 .93037 L .50853 .93119 L closepath p F P
0 g
s
.651 .483 .644 r
.50853 .93119 m .50913 .9348 L .50568 .93802 L p F P
0 g
s
.733 .513 .594 r
.34215 .96017 m .33595 .9597 L .33564 .95385 L p F P
0 g
s
.74 .518 .593 r
.33362 .95366 m .33564 .95385 L .33595 .9597 L p F P
0 g
s
.644 .524 .703 r
.52475 .89556 m .532 .89203 L .52415 .89342 L closepath p F P
0 g
s
.865 .789 .774 r
.63231 .11017 m .63125 .11154 L .63376 .11548 L p F P
0 g
s
.865 .789 .774 r
.62643 .11779 m .62893 .12173 L .63376 .11548 L p F P
0 g
s
.865 .789 .774 r
.63376 .11548 m .63125 .11154 L .62643 .11779 L p F P
0 g
s
.662 .59 .764 r
.50414 .84682 m .49578 .8481 L .49372 .84318 L p F P
0 g
s
.716 .654 .787 r
.37303 .81653 m .37604 .82205 L .37081 .82542 L p F P
0 g
s
.716 .654 .787 r
.3624 .82337 m .37303 .81653 L p .37081 .82542 L F P
0 g
s
.716 .654 .787 r
.37081 .82542 m .3633 .82499 L .3624 .82337 L p F P
0 g
s
.758 .634 .723 r
.28454 .88173 m .28757 .87828 L .28272 .87748 L closepath p F P
0 g
s
.756 .64 .733 r
.28152 .87483 m .28614 .86985 L p .28757 .87828 L F P
0 g
s
.756 .64 .733 r
.28757 .87828 m .28272 .87748 L .28152 .87483 L p F P
0 g
s
.743 .535 .613 r
.32417 .95277 m .31994 .95237 L .3193 .94625 L p F P
0 g
s
.749 .54 .612 r
.31681 .94597 m .3193 .94625 L .31994 .95237 L p F P
0 g
s
.683 .766 .914 r
.63879 .30392 m .62787 .30856 L .62517 .305 L p F P
0 g
s
.665 .47 .612 r
.47409 .95374 m .47408 .95361 L .474 .95375 L closepath p F P
0 g
s
.763 .623 .705 r
.27611 .89199 m .28401 .89335 L .27896 .90002 L p F P
0 g
s
.762 .627 .711 r
.28157 .88521 m .27611 .89199 L .28401 .89335 L p F P
0 g
s
.667 .443 .571 r
.44882 .96132 m .45413 .961 L .45332 .96664 L p F P
0 g
s
.667 .443 .571 r
.45332 .96664 m .44892 .9669 L .44882 .96132 L p F P
0 g
s
.651 .561 .74 r
.52576 .86078 m .52679 .86368 L .51604 .86831 L p F P
0 g
s
.651 .561 .74 r
.51604 .86831 m .51409 .86285 L .52576 .86078 L p F P
0 g
s
.661 .453 .592 r
.474 .95375 m .47409 .95374 L .47446 .95952 L p F P
0 g
s
.661 .453 .592 r
.47446 .95952 m .47183 .95973 L .474 .95375 L p F P
0 g
s
.654 .447 .592 r
.47446 .95952 m .47409 .95374 L .48658 .95254 L p F P
0 g
s
.643 .524 .703 r
.52615 .90059 m .52475 .89556 L .532 .89203 L p F P
0 g
s
.884 .799 .76 r
.61575 .14001 m .61808 .14399 L .62229 .13796 L p F P
0 g
s
.884 .799 .76 r
.62229 .13796 m .61993 .13399 L .61575 .14001 L p F P
0 g
s
.819 .854 .874 r
.70495 .27366 m .70087 .277 L .69834 .27448 L p F P
0 g
s
.085 .232 .719 r
.60144 .28789 m .6019 .29231 L .59823 .28901 L p F P
0 g
s
.085 .232 .719 r
.59823 .28901 m .5981 .28447 L .60144 .28789 L p F P
0 g
s
.979 .842 .637 r
.59886 .21813 m .59814 .22011 L .59709 .21738 L closepath p F P
0 g
s
.74 .518 .593 r
.33595 .9597 m .33234 .95938 L .33362 .95366 L p F P
0 g
s
.741 .52 .594 r
.32417 .95277 m .33362 .95366 L .33234 .95938 L p F P
0 g
s
.682 .618 .778 r
.45911 .82386 m .46067 .82715 L p .44706 .82635 L F P
0 g
s
.682 .618 .778 r
.44706 .82635 m .45057 .82457 L .45911 .82386 L p F P
0 g
s
.683 .622 .781 r
.44706 .82635 m .45057 .82457 L .44637 .8249 L closepath p F P
0 g
s
.871 .88 .84 r
.74127 .23489 m .73729 .23909 L .73759 .24356 L p F P
0 g
s
.865 .877 .844 r
.73062 .24595 m .73729 .23909 L .73759 .24356 L p F P
0 g
s
.865 .877 .844 r
.73759 .24356 m .73306 .24821 L .73062 .24595 L p F P
0 g
s
.772 .821 .891 r
.6686 .29591 m .66584 .29772 L .66323 .29487 L p F P
0 g
s
.755 .817 .901 r
.65235 .30138 m .66323 .29487 L .66584 .29772 L p F P
0 g
s
.823 .858 .873 r
.70495 .27366 m .71164 .26806 L .70914 .26559 L p F P
0 g
s
.823 .858 .873 r
.70914 .26559 m .70489 .26914 L .70495 .27366 L p F P
0 g
s
.819 .854 .874 r
.69834 .27448 m .70489 .26914 L .70495 .27366 L p F P
0 g
s
.762 .635 .721 r
.28157 .88521 m .28454 .88173 L .28272 .87748 L p F P
0 g
s
.749 .54 .612 r
.31994 .95237 m .31499 .95181 L .31681 .94597 L p F P
0 g
s
.75 .542 .614 r
.30789 .94493 m .31681 .94597 L .31499 .95181 L p F P
0 g
s
.917 .896 .792 r
.76001 .21254 m .76229 .20944 L .75994 .20753 L p F P
0 g
s
.729 .652 .773 r
.33811 .83268 m .33818 .83263 L .33808 .83262 L closepath p F P
0 g
s
.735 .656 .772 r
.33808 .83262 m .33811 .83268 L p .32442 .83522 L F P
0 g
s
.991 .823 .446 r
.78283 .14373 m .78267 .14466 L .78251 .14396 L closepath p F P
0 g
s
.727 .658 .781 r
.34804 .82376 m .34875 .82506 L .33818 .83263 L p F P
0 g
s
.727 .658 .781 r
.34087 .823 m .34804 .82376 L p .33818 .83263 L F P
0 g
s
.727 .658 .781 r
.33507 .82717 m .34087 .823 L p .33818 .83263 L F P
0 g
s
.727 .658 .781 r
.33818 .83263 m .33808 .83262 L .33507 .82717 L p F P
0 g
s
.652 .569 .748 r
.52389 .85579 m .52576 .86078 L .51409 .86285 L p F P
0 g
s
.652 .569 .748 r
.51409 .86285 m .51314 .86033 L .52389 .85579 L p F P
0 g
s
.735 .656 .772 r
.32442 .83522 m .32919 .83155 L .33808 .83262 L p F P
0 g
s
.733 .66 .778 r
.33808 .83262 m .33507 .82717 L .32919 .83155 L closepath p F P
0 g
s
.646 .518 .692 r
.52797 .90759 m .52766 .90641 L .52446 .90816 L closepath p F P
0 g
s
.648 .519 .692 r
.52615 .90059 m .52766 .90641 L .52446 .90816 L p F P
0 g
s
.641 .515 .694 r
.52766 .90641 m .52615 .90059 L .53778 .89851 L p F P
0 g
s
.643 .524 .703 r
.53578 .89135 m .53778 .89851 L .52615 .90059 L p F P
0 g
s
.643 .524 .703 r
.532 .89203 m .53578 .89135 L p .52615 .90059 L F P
0 g
s
.665 .441 .57 r
.45413 .961 m .46174 .96051 L .46185 .96609 L p F P
0 g
s
.665 .441 .57 r
.46185 .96609 m .45332 .96664 L .45413 .961 L p F P
0 g
s
.746 .652 .756 r
.30941 .8476 m .30305 .85324 L .3 .84726 L p F P
0 g
s
.75 .654 .754 r
.30088 .85523 m .30305 .85324 L .3 .84726 L p F P
0 g
s
.75 .654 .754 r
.3 .84726 m .29281 .85389 L .30088 .85523 L p F P
0 g
s
.751 .65 .75 r
.29281 .85389 m .30088 .85523 L .29311 .86265 L p F P
0 g
s
.721 .656 .785 r
.3633 .82499 m .3624 .82337 L .36032 .82476 L closepath p F P
0 g
s
.76 .584 .658 r
.29584 .93061 m .28748 .92941 L .29079 .92319 L p F P
0 g
s
.761 .586 .659 r
.2825 .92196 m .29079 .92319 L .28748 .92941 L p F P
0 g
s
.761 .594 .671 r
.29079 .92319 m .2825 .92196 L .28629 .91562 L p F P
0 g
s
.444 .597 .908 r
.74324 .06496 m .74698 .06533 L .74893 .06949 L p F P
0 g
s
.374 .552 .9 r
.75434 .06692 m .75619 .07112 L .74893 .06949 L p F P
0 g
s
.374 .552 .9 r
.74893 .06949 m .74698 .06533 L .75434 .06692 L p F P
0 g
s
.859 .878 .851 r
.73055 .25068 m .73306 .24821 L .73062 .24595 L p F P
0 g
s
.762 .597 .672 r
.28024 .91468 m .28629 .91562 L .2825 .92196 L p F P
0 g
s
.761 .605 .684 r
.27949 .91228 m .28235 .90789 L p .28629 .91562 L F P
0 g
s
.761 .605 .684 r
.28629 .91562 m .28024 .91468 L .27949 .91228 L p F P
0 g
s
.94 .836 .713 r
.60111 .18905 m .60257 .18621 L .60436 .19032 L p F P
0 g
s
.94 .836 .713 r
.60436 .19032 m .60381 .19138 L .60111 .18905 L p F P
0 g
s
.746 .652 .756 r
.3 .84726 m .30104 .84634 L .30941 .8476 L p F P
0 g
s
.744 .656 .762 r
.31015 .83853 m .30104 .84634 L .30941 .8476 L p F P
0 g
s
.744 .656 .762 r
.31102 .83867 m .31015 .83853 L p .30941 .8476 L F P
0 g
s
.744 .656 .762 r
.30941 .8476 m .31375 .84388 L .31102 .83867 L p F P
0 g
s
.683 .628 .788 r
.45057 .82457 m .44637 .8249 L .44412 .82041 L p F P
0 g
s
.722 .488 .572 r
.36214 .96703 m .35153 .96646 L .35219 .96089 L p F P
0 g
s
.723 .49 .572 r
.35122 .96084 m .35219 .96089 L .35153 .96646 L p F P
0 g
s
.653 .569 .748 r
.5227 .85262 m .52389 .85579 L .51314 .86033 L p F P
0 g
s
.653 .569 .748 r
.51314 .86033 m .51102 .85468 L .5227 .85262 L p F P
0 g
s
.859 .878 .851 r
.73062 .24595 m .7304 .24617 L .73055 .25068 L p F P
0 g
s
.851 .872 .856 r
.72263 .25356 m .72292 .25802 L .73055 .25068 L p F P
0 g
s
.851 .872 .856 r
.73055 .25068 m .7304 .24617 L .72263 .25356 L p F P
0 g
s
.706 .647 .788 r
.38967 .82107 m .398 .81611 L .38692 .81592 L closepath p F P
0 g
s
.753 .644 .74 r
.29232 .86345 m .29311 .86265 L .29185 .86245 L closepath p F P
0 g
s
.751 .65 .75 r
.28927 .85728 m .29281 .85389 L p .29311 .86265 L F P
0 g
s
.751 .65 .75 r
.29311 .86265 m .29185 .86245 L .28927 .85728 L p F P
0 g
s
.67 .604 .773 r
.4772 .8347 m .48581 .83071 L .47598 .83196 L closepath p F P
0 g
s
.832 .86 .866 r
.71436 .26569 m .71164 .26806 L .70914 .26559 L p F P
0 g
s
.756 .648 .741 r
.29185 .86245 m .29232 .86345 L .28614 .86985 L p F P
0 g
s
.723 .49 .572 r
.35153 .96646 m .35123 .96644 L .35122 .96084 L p F P
0 g
s
.731 .496 .572 r
.34215 .96017 m .35122 .96084 L .35123 .96644 L p F P
0 g
s
.7 .641 .787 r
.41482 .81606 m .4169 .82007 L p .40329 .8204 L F P
0 g
s
.7 .641 .787 r
.40329 .8204 m .41084 .8161 L .41482 .81606 L p F P
0 g
s
.7 .643 .789 r
.40329 .8204 m .41084 .8161 L .40105 .81616 L closepath p F P
0 g
s
.76 .575 .647 r
.28748 .92941 m .29584 .93061 L .29303 .9367 L p F P
0 g
s
.758 .572 .645 r
.29584 .93061 m .29303 .9367 L .30145 .93788 L p F P
0 g
s
.93 .817 .713 r
.60349 .17659 m .60551 .18063 L .60846 .17506 L p F P
0 g
s
.93 .817 .713 r
.60846 .17506 m .60639 .17103 L .60349 .17659 L p F P
0 g
s
.956 .759 .306 r
.59324 .25856 m .59421 .26286 L .59457 .25816 L p F P
0 g
s
.956 .759 .306 r
.59457 .25816 m .59359 .25387 L .59324 .25856 L p F P
0 g
s
.74 .654 .764 r
.31375 .84388 m .31878 .83972 L .31102 .83867 L closepath p F P
0 g
s
.115 .359 .823 r
.76459 .08211 m .76255 .08079 L .76 .07614 L p F P
0 g
s
.837 .863 .864 r
.71436 .26569 m .72237 .25852 L .7199 .2561 L p F P
0 g
s
.837 .863 .864 r
.7199 .2561 m .71418 .2612 L .71436 .26569 L p F P
0 g
s
.832 .86 .866 r
.70914 .26559 m .71418 .2612 L .71436 .26569 L p F P
0 g
s
.937 .697 .221 r
.78026 .12228 m .78153 .12658 L .78144 .12213 L p F P
0 g
s
.937 .697 .221 r
.78144 .12213 m .78017 .11782 L .78026 .12228 L p F P
0 g
s
.772 .821 .891 r
.66323 .29487 m .66864 .29137 L .6686 .29591 L p F P
0 g
s
.773 .825 .893 r
.6686 .29591 m .67669 .29051 L .6741 .28778 L p F P
0 g
s
.773 .825 .893 r
.6741 .28778 m .66864 .29137 L .6686 .29591 L p F P
0 g
s
.965 .84 .67 r
.59726 .20645 m .59887 .2106 L .60119 .20524 L p F P
0 g
s
.965 .84 .67 r
.60119 .20524 m .59952 .20111 L .59726 .20645 L p F P
0 g
s
.975 .893 .678 r
.77796 .17223 m .77704 .17424 L .77656 .1715 L closepath p F P
0 g
s
.662 .59 .764 r
.49372 .84318 m .50444 .83845 L p .50414 .84682 L F P
0 g
s
.662 .591 .765 r
.50408 .83758 m .50444 .83845 L .49372 .84318 L p F P
0 g
s
.662 .591 .765 r
.49372 .84318 m .49213 .8394 L .50408 .83758 L p F P
0 g
s
.763 .606 .684 r
.27949 .91228 m .28235 .90789 L .27788 .90717 L closepath p F P
0 g
s
.762 .614 .695 r
.27657 .9034 m .27896 .90002 L p .28235 .90789 L F P
0 g
s
.762 .614 .695 r
.28235 .90789 m .27788 .90717 L .27657 .9034 L p F P
0 g
s
.576 .679 .91 r
.72681 .05807 m .73013 .05756 L .7323 .06166 L p F P
0 g
s
.552 .662 .909 r
.73816 .05668 m .73013 .05756 L .7323 .06166 L p F P
0 g
s
.552 .662 .909 r
.7323 .06166 m .74071 .0608 L .73816 .05668 L p F P
0 g
s
.758 .571 .644 r
.30212 .93797 m .30191 .93689 L .30145 .93788 L closepath p F P
0 g
s
.712 .653 .79 r
.38599 .81589 m .37604 .82205 L .37303 .81653 L p F P
0 g
s
.723 .654 .78 r
.34875 .82506 m .35034 .82396 L .36032 .82476 L p F P
0 g
s
.722 .659 .787 r
.35938 .81793 m .35034 .82396 L .36032 .82476 L p F P
0 g
s
.722 .659 .787 r
.36032 .82476 m .3624 .82337 L .35938 .81793 L p F P
0 g
s
.762 .635 .721 r
.27964 .87692 m .27379 .88381 L .28157 .88521 L p F P
0 g
s
.762 .635 .721 r
.28272 .87748 m .27964 .87692 L p .28157 .88521 L F P
0 g
s
.763 .632 .715 r
.27379 .88381 m .28157 .88521 L .27611 .89199 L p F P
0 g
s
.647 .491 .658 r
.51924 .92298 m .51985 .92617 L .51427 .93037 L p F P
0 g
s
.64 .486 .658 r
.51985 .92617 m .52606 .92189 L .51924 .92298 L closepath p F P
0 g
s
.498 .608 .893 r
.60935 .3034 m .60897 .29944 L .61146 .30347 L closepath p F P
0 g
s
.844 .864 .858 r
.7199 .2561 m .72263 .25356 L .72292 .25802 L p F P
0 g
s
.844 .864 .858 r
.72292 .25802 m .72237 .25852 L .7199 .2561 L p F P
0 g
s
.807 .775 .823 r
.65673 .08419 m .6536 .08701 L .65094 .08313 L p F P
0 g
s
.829 .779 .805 r
.64937 .09141 m .6536 .08701 L .65094 .08313 L p F P
0 g
s
.644 .478 .644 r
.50957 .93751 m .50913 .9348 L .51427 .93037 L p F P
0 g
s
.65 .482 .643 r
.50957 .93751 m .50913 .9348 L .50568 .93802 L closepath p F P
0 g
s
.997 .855 .541 r
.78035 .14529 m .78136 .14966 L .78267 .14466 L p F P
0 g
s
.997 .855 .541 r
.78071 .14391 m .78035 .14529 L p .78267 .14466 L F P
0 g
s
.997 .855 .541 r
.78267 .14466 m .78251 .14396 L .78071 .14391 L p F P
0 g
s
.785 .769 .838 r
.66513 .07657 m .66432 .07722 L .66167 .07331 L p F P
0 g
s
.81 .775 .821 r
.65673 .08419 m .66432 .07722 L .66167 .07331 L p F P
0 g
s
.81 .775 .821 r
.66167 .07331 m .65414 .08024 L .65673 .08419 L p F P
0 g
s
.807 .775 .823 r
.65094 .08313 m .65414 .08024 L .65673 .08419 L p F P
0 g
s
.944 .893 .749 r
.76792 .19055 m .77092 .18558 L .77166 .18997 L p F P
0 g
s
.944 .893 .749 r
.77166 .18997 m .77024 .1923 L .76792 .19055 L p F P
0 g
s
.646 .468 .628 r
.50568 .93802 m .50957 .93751 L .51041 .94366 L p F P
0 g
s
.646 .468 .628 r
.51041 .94366 m .4993 .94509 L .50568 .93802 L p F P
0 g
s
.756 .648 .741 r
.28524 .86126 m .29185 .86245 L p .28614 .86985 L F P
0 g
s
.757 .652 .746 r
.29185 .86245 m .28927 .85728 L .28524 .86126 L closepath p F P
0 g
s
.952 .826 .682 r
.60185 .19574 m .60381 .19138 L .60111 .18905 L p F P
0 g
s
.695 .639 .789 r
.4169 .82007 m .42479 .81578 L .41482 .81606 L closepath p F P
0 g
s
.694 .636 .787 r
.42826 .81566 m .43051 .82008 L p .4169 .82007 L F P
0 g
s
.694 .636 .787 r
.4169 .82007 m .42479 .81578 L .42826 .81566 L p F P
0 g
s
.788 .77 .836 r
.66513 .07657 m .6751 .06856 L .67247 .06463 L p F P
0 g
s
.788 .77 .836 r
.67247 .06463 m .66255 .07261 L .66513 .07657 L p F P
0 g
s
.785 .769 .838 r
.66167 .07331 m .66255 .07261 L .66513 .07657 L p F P
0 g
s
.752 .555 .63 r
.30789 .94493 m .30309 .94436 L .30212 .93797 L p F P
0 g
s
.758 .56 .628 r
.30145 .93788 m .30212 .93797 L .30309 .94436 L p F P
0 g
s
.986 .838 .612 r
.59487 .22112 m .59641 .22527 L .59814 .22011 L p F P
0 g
s
.986 .838 .612 r
.59619 .2171 m .59487 .22112 L p .59814 .22011 L F P
0 g
s
.986 .838 .612 r
.59814 .22011 m .59709 .21738 L .59619 .2171 L p F P
0 g
s
.738 .66 .773 r
.32196 .83067 m .32442 .83522 L .31878 .83972 L p F P
0 g
s
.738 .66 .773 r
.32029 .83043 m .32196 .83067 L p .31878 .83972 L F P
0 g
s
.738 .66 .773 r
.3107 .83808 m .32029 .83043 L p .31878 .83972 L F P
0 g
s
.738 .66 .773 r
.31878 .83972 m .31102 .83867 L .3107 .83808 L p F P
0 g
s
.917 .896 .792 r
.75994 .20753 m .75953 .20809 L .76001 .21254 L p F P
0 g
s
.906 .89 .804 r
.75451 .21449 m .75505 .21891 L .76001 .21254 L p F P
0 g
s
.906 .89 .804 r
.76001 .21254 m .75953 .20809 L .75451 .21449 L p F P
0 g
s
0 0 .481 r
.59758 .28005 m .5981 .28447 L .59622 .28054 L p F P
0 g
s
0 0 .481 r
.59622 .28054 m .59583 .27608 L .59758 .28005 L p F P
0 g
s
.906 .809 .741 r
.60727 .16141 m .60943 .16543 L .61301 .15962 L p F P
0 g
s
.906 .809 .741 r
.61301 .15962 m .61082 .15562 L .60727 .16141 L p F P
0 g
s
.762 .643 .73 r
.28272 .87748 m .28152 .87483 L .27964 .87692 L closepath p F P
0 g
s
.644 .478 .644 r
.51427 .93037 m .52048 .92947 L p .50957 .93751 L F P
0 g
s
.646 .489 .657 r
.52048 .92947 m .51985 .92617 L .51427 .93037 L closepath p F P
0 g
s
.681 .626 .787 r
.45911 .82386 m .45773 .82107 L .45057 .82457 L closepath p F P
0 g
s
.683 .628 .788 r
.45479 .81514 m .45773 .82107 L .45057 .82457 L p F P
0 g
s
.683 .628 .788 r
.44412 .82041 m .45479 .81514 L p .45057 .82457 L F P
0 g
s
.641 .514 .693 r
.52797 .90759 m .52766 .90641 L .53842 .90101 L p F P
0 g
s
.641 .515 .694 r
.53778 .89851 m .53842 .90101 L .52766 .90641 L p F P
0 g
s
.686 .44 .545 r
.40875 .96811 m .40923 .96811 L .40957 .97344 L p F P
0 g
s
.686 .44 .545 r
.40957 .97344 m .4085 .97345 L .40875 .96811 L p F P
0 g
s
.693 .446 .545 r
.39655 .96808 m .40875 .96811 L .4085 .97345 L p F P
0 g
s
.685 .439 .545 r
.40923 .96811 m .42239 .96793 L .42216 .97327 L p F P
0 g
s
.685 .439 .545 r
.42216 .97327 m .40957 .97344 L .40923 .96811 L p F P
0 g
s
.717 .658 .789 r
.37303 .81653 m .3624 .82337 L .35938 .81793 L p F P
0 g
s
.677 .617 .781 r
.46067 .82715 m .46979 .82277 L .45911 .82386 L closepath p F P
0 g
s
.758 .56 .628 r
.30309 .94436 m .29917 .94383 L .30145 .93788 L p F P
0 g
s
.759 .562 .63 r
.29303 .9367 m .30145 .93788 L .29917 .94383 L p F P
0 g
s
.863 .791 .778 r
.62172 .12378 m .62643 .11779 L .62893 .12173 L p F P
0 g
s
.863 .791 .778 r
.62893 .12173 m .62442 .12745 L .62172 .12378 L p F P
0 g
s
.758 .641 .732 r
.28152 .87483 m .28614 .86985 L .27866 .86856 L closepath p F P
0 g
s
.756 .648 .741 r
.27848 .8682 m .28524 .86126 L p .28614 .86985 L F P
0 g
s
.756 .648 .741 r
.28614 .86985 m .27866 .86856 L .27848 .8682 L p F P
0 g
s
.693 .446 .545 r
.4085 .97345 m .39684 .97342 L .39655 .96808 L p F P
0 g
s
.695 .447 .545 r
.39483 .96807 m .39655 .96808 L .39684 .97342 L p F P
0 g
s
.658 .436 .57 r
.46174 .96051 m .47183 .95973 L .47098 .96539 L p F P
0 g
s
.658 .436 .57 r
.47098 .96539 m .46185 .96609 L .46174 .96051 L p F P
0 g
s
.695 .447 .545 r
.39684 .97342 m .39456 .97341 L .39483 .96807 L p F P
0 g
s
.702 .453 .545 r
.38456 .96787 m .39483 .96807 L .39456 .97341 L p F P
0 g
s
.736 .754 .867 r
.69499 .06124 m .69949 .05862 L .6969 .05467 L p F P
0 g
s
.736 .754 .867 r
.6969 .05467 m .69254 .05723 L .69499 .06124 L p F P
0 g
s
.733 .753 .869 r
.68596 .06104 m .69254 .05723 L .69499 .06124 L p F P
0 g
s
.638 .503 .682 r
.52959 .91441 m .52797 .90759 L .53959 .90551 L p F P
0 g
s
.641 .514 .693 r
.53842 .90101 m .53959 .90551 L .52797 .90759 L p F P
0 g
s
.654 .577 .756 r
.521 .84827 m .5227 .85262 L .51102 .85468 L p F P
0 g
s
.654 .577 .756 r
.51102 .85468 m .51025 .85272 L .521 .84827 L p F P
0 g
s
.764 .616 .694 r
.27657 .9034 m .27896 .90002 L .27517 .89938 L closepath p F P
0 g
s
.763 .623 .705 r
.27362 .89528 m .27611 .89199 L p .27896 .90002 L F P
0 g
s
.763 .623 .705 r
.27896 .90002 m .27517 .89938 L .27362 .89528 L p F P
0 g
s
.829 .779 .805 r
.65094 .08313 m .64676 .08747 L .64937 .09141 L p F P
0 g
s
.826 .779 .808 r
.64025 .09409 m .64676 .08747 L .64937 .09141 L p F P
0 g
s
.826 .779 .808 r
.64937 .09141 m .64293 .09795 L .64025 .09409 L p F P
0 g
s
.67 .611 .78 r
.48581 .83071 m .47598 .83196 L .47428 .8283 L p F P
0 g
s
.678 .434 .544 r
.42239 .96793 m .42277 .96792 L .42316 .97324 L p F P
0 g
s
.678 .434 .544 r
.42316 .97324 m .42216 .97327 L .42239 .96793 L p F P
0 g
s
.676 .432 .545 r
.42277 .96792 m .43578 .96752 L .43557 .97286 L p F P
0 g
s
.676 .432 .545 r
.43557 .97286 m .42316 .97324 L .42277 .96792 L p F P
0 g
s
.689 .634 .789 r
.43051 .82008 m .44019 .81504 L .42826 .81566 L closepath p F P
0 g
s
.735 .657 .772 r
.32442 .83522 m .32919 .83155 L .32196 .83067 L closepath p F P
0 g
s
.645 .454 .611 r
.49841 .94636 m .4993 .94509 L .49829 .94522 L closepath p F P
0 g
s
.652 .46 .612 r
.49829 .94522 m .49841 .94636 L .49502 .95162 L p F P
0 g
s
.741 .52 .594 r
.33234 .95938 m .32286 .95849 L .32417 .95277 L p F P
0 g
s
.742 .521 .595 r
.31994 .95237 m .32417 .95277 L .32286 .95849 L p F P
0 g
s
.663 .598 .772 r
.50154 .83176 m .50408 .83758 L .49213 .8394 L p F P
0 g
s
.663 .598 .772 r
.49213 .8394 m .49081 .83638 L .50154 .83176 L p F P
0 g
s
.702 .453 .545 r
.39456 .97341 m .38481 .97322 L .38456 .96787 L p F P
0 g
s
.703 .454 .545 r
.38062 .96778 m .38456 .96787 L .38481 .97322 L p F P
0 g
s
.986 .879 .636 r
.77762 .16009 m .77859 .16445 L .78061 .15917 L p F P
0 g
s
.986 .879 .636 r
.78061 .15917 m .77967 .1548 L .77762 .16009 L p F P
0 g
s
.654 .578 .757 r
.5194 .84421 m .521 .84827 L .51025 .85272 L p F P
0 g
s
.654 .578 .757 r
.51025 .85272 m .50769 .84627 L .5194 .84421 L p F P
0 g
s
.96 .893 .717 r
.77333 .17546 m .77413 .17985 L .77704 .17424 L p F P
0 g
s
.96 .893 .717 r
.7757 .17091 m .77333 .17546 L p .77704 .17424 L F P
0 g
s
.96 .893 .717 r
.77704 .17424 m .77656 .1715 L .7757 .17091 L p F P
0 g
s
.885 .801 .761 r
.61388 .14269 m .61575 .14001 L .61808 .14399 L p F P
0 g
s
.885 .801 .761 r
.61808 .14399 m .61659 .14612 L .61388 .14269 L p F P
0 g
s
.64 .485 .657 r
.52048 .92947 m .51985 .92617 L .52606 .92189 L p F P
0 g
s
.999 .844 .526 r
.78251 .14396 m .78071 .14391 L .78157 .14033 L closepath p F P
0 g
s
.941 .896 .756 r
.76799 .19587 m .77024 .1923 L .76792 .19055 L p F P
0 g
s
.703 .454 .545 r
.38481 .97322 m .38032 .97312 L .38062 .96778 L p F P
0 g
s
.71 .46 .545 r
.37313 .96751 m .38062 .96778 L .38032 .97312 L p F P
0 g
s
.762 .643 .73 r
.27964 .87692 m .28152 .87483 L .27866 .86856 L p F P
0 g
s
.998 .846 .559 r
.59347 .23543 m .59467 .23968 L .59611 .23462 L p F P
0 g
s
.998 .846 .559 r
.59611 .23462 m .59484 .23038 L .59347 .23543 L p F P
0 g
s
.644 .454 .611 r
.4993 .94509 m .51041 .94366 L p .4989 .95118 L F P
0 g
s
.644 .454 .611 r
.4989 .95118 m .49841 .94636 L .4993 .94509 L p F P
0 g
s
.662 .59 .764 r
.50444 .83845 m .50735 .84543 L .50414 .84682 L p F P
0 g
s
.661 .588 .763 r
.50769 .84627 m .50735 .84543 L .50414 .84682 L closepath p F P
0 g
s
.969 .823 .404 r
.59446 .24971 m .59407 .2506 L .59436 .24902 L closepath p F P
0 g
s
.64 .463 .628 r
.51041 .94366 m .50957 .93751 L .52152 .93578 L p F P
0 g
s
.644 .478 .644 r
.52048 .92947 m .52152 .93578 L .50957 .93751 L p F P
0 g
s
.723 .655 .781 r
.34875 .82506 m .35034 .82396 L .34804 .82376 L closepath p F P
0 g
s
.847 .782 .789 r
.64252 .09843 m .64293 .09795 L .64025 .09409 L p F P
0 g
s
.731 .496 .572 r
.35123 .96644 m .34152 .96572 L .34215 .96017 L p F P
0 g
s
.731 .496 .572 r
.33595 .9597 m .34215 .96017 L .34152 .96572 L p F P
0 g
s
.732 .801 .907 r
.65235 .30138 m .65016 .30254 L .65065 .29945 L closepath p F P
0 g
s
.728 .785 .898 r
.64971 .29837 m .65065 .29945 L .65016 .30254 L p F P
0 g
s
.728 .785 .898 r
.63879 .30392 m .64971 .29837 L p .65016 .30254 L F P
0 g
s
.859 .584 .051 r
.77882 .11353 m .78017 .11782 L .77957 .11357 L p F P
0 g
s
.859 .584 .051 r
.77957 .11357 m .77822 .10927 L .77882 .11353 L p F P
0 g
s
.761 .761 .853 r
.6758 .06808 m .6751 .06856 L .67247 .06463 L p F P
0 g
s
.847 .782 .789 r
.64025 .09409 m .6399 .0945 L .64252 .09843 L p F P
0 g
s
.847 .782 .789 r
.63424 .10107 m .63687 .10499 L .64252 .09843 L p F P
0 g
s
.847 .782 .789 r
.64252 .09843 m .6399 .0945 L .63424 .10107 L p F P
0 g
s
.654 .447 .592 r
.48658 .95254 m .48697 .95833 L .47446 .95952 L p F P
0 g
s
.648 .443 .593 r
.48658 .95254 m .49502 .95162 L .49235 .95775 L p F P
0 g
s
.648 .443 .593 r
.49235 .95775 m .48697 .95833 L .48658 .95254 L p F P
0 g
s
.767 .608 .682 r
.27788 .90717 m .27442 .90656 L p .27819 .91433 L F P
0 g
s
.767 .608 .682 r
.27819 .91433 m .27949 .91228 L .27788 .90717 L p F P
0 g
s
.768 .617 .692 r
.27788 .90717 m .27657 .9034 L .27442 .90656 L closepath p F P
0 g
s
.763 .64 .725 r
.27199 .87547 m .27964 .87692 L .27379 .88381 L p F P
0 g
s
.762 .643 .73 r
.27822 .86847 m .27199 .87547 L .27964 .87692 L p F P
0 g
s
.762 .643 .73 r
.27866 .86856 m .27822 .86847 L p .27964 .87692 L F P
0 g
s
.644 .533 .713 r
.53578 .89135 m .5355 .89041 L .532 .89203 L closepath p F P
0 g
s
.645 .533 .713 r
.53358 .88399 m .5355 .89041 L .532 .89203 L p F P
0 g
s
.767 .608 .682 r
.28024 .91468 m .27949 .91228 L .27819 .91433 L closepath p F P
0 g
s
.733 .662 .78 r
.33224 .82208 m .33507 .82717 L .32919 .83155 L p F P
0 g
s
.733 .662 .78 r
.33158 .822 m .33224 .82208 L p .32919 .83155 L F P
0 g
s
.733 .662 .78 r
.32136 .8296 m .33158 .822 L p .32919 .83155 L F P
0 g
s
.733 .662 .78 r
.32919 .83155 m .32196 .83067 L .32136 .8296 L p F P
0 g
s
.761 .761 .853 r
.67247 .06463 m .67323 .06411 L .6758 .06808 L p F P
0 g
s
.763 .762 .852 r
.6758 .06808 m .68596 .06104 L .68334 .05709 L p F P
0 g
s
.763 .762 .852 r
.68334 .05709 m .67323 .06411 L .6758 .06808 L p F P
0 g
s
.75 .542 .614 r
.31499 .95181 m .30602 .95079 L .30789 .94493 L p F P
0 g
s
.751 .543 .614 r
.30309 .94436 m .30789 .94493 L .30602 .95079 L p F P
0 g
s
.762 .597 .672 r
.2825 .92196 m .28227 .92193 L .28024 .91468 L p F P
0 g
s
.768 .6 .67 r
.27819 .91433 m .28024 .91468 L .28227 .92193 L p F P
0 g
s
.448 .601 .91 r
.74698 .06533 m .74324 .06496 L .74071 .0608 L p F P
0 g
s
.65 .458 .611 r
.4989 .95118 m .49841 .94636 L .49502 .95162 L closepath p F P
0 g
s
.722 .661 .789 r
.35733 .81428 m .35938 .81793 L .35034 .82396 L p F P
0 g
s
.722 .661 .789 r
.35416 .814 m .35733 .81428 L p .35034 .82396 L F P
0 g
s
.722 .661 .789 r
.34571 .81965 m .35416 .814 L p .35034 .82396 L F P
0 g
s
.722 .661 .789 r
.35034 .82396 m .34804 .82376 L .34571 .81965 L p F P
0 g
s
.765 .624 .705 r
.27362 .89528 m .27611 .89199 L .27209 .89128 L closepath p F P
0 g
s
.763 .632 .715 r
.27063 .88772 m .27379 .88381 L p .27611 .89199 L F P
0 g
s
.763 .632 .715 r
.27611 .89199 m .27209 .89128 L .27063 .88772 L p F P
0 g
s
.768 .618 .692 r
.27442 .90656 m .27657 .9034 L .27517 .89938 L p F P
0 g
s
.644 .713 .897 r
.7131 .05755 m .72426 .05405 L .72681 .05807 L p F P
0 g
s
.645 .714 .898 r
.72426 .05405 m .7131 .05755 L .71053 .05358 L p F P
0 g
s
.696 .737 .883 r
.69949 .05862 m .71053 .05358 L .7131 .05755 L p F P
0 g
s
.67 .427 .544 r
.43578 .96752 m .43738 .96745 L .43783 .97277 L p F P
0 g
s
.67 .427 .544 r
.43783 .97277 m .43557 .97286 L .43578 .96752 L p F P
0 g
s
.71 .46 .545 r
.38032 .97312 m .37334 .97287 L .37313 .96751 L p F P
0 g
s
.71 .461 .546 r
.36609 .96724 m .37313 .96751 L .37334 .97287 L p F P
0 g
s
.677 .624 .788 r
.46979 .82277 m .45911 .82386 L .45773 .82107 L p F P
0 g
s
.742 .521 .595 r
.32286 .95849 m .32026 .95825 L .31994 .95237 L p F P
0 g
s
.749 .527 .594 r
.31499 .95181 m .31994 .95237 L .32026 .95825 L p F P
0 g
s
.683 .629 .789 r
.45422 .81399 m .45479 .81514 L .44412 .82041 L p F P
0 g
s
.683 .629 .789 r
.44412 .82041 m .44139 .81498 L .45422 .81399 L p F P
0 g
s
.788 .833 .886 r
.68263 .2863 m .67669 .29051 L .6741 .28778 L p F P
0 g
s
.902 .799 .737 r
.61432 .14985 m .61659 .14612 L .61388 .14269 L p F P
0 g
s
.668 .425 .544 r
.43738 .96745 m .44892 .9669 L .44873 .97225 L p F P
0 g
s
.668 .425 .544 r
.44873 .97225 m .43783 .97277 L .43738 .96745 L p F P
0 g
s
.663 .599 .773 r
.50015 .82858 m .50154 .83176 L .49081 .83638 L p F P
0 g
s
.663 .599 .773 r
.49081 .83638 m .48819 .8304 L .50015 .82858 L p F P
0 g
s
.768 .618 .692 r
.27517 .89938 m .27116 .89864 L p .27442 .90656 L F P
0 g
s
.768 .626 .702 r
.27517 .89938 m .27362 .89528 L .27116 .89864 L closepath p F P
0 g
s
.274 .473 .872 r
.75746 .07159 m .75619 .07112 L .75795 .07534 L p F P
0 g
s
.274 .473 .872 r
.75795 .07534 m .76 .07614 L .75746 .07159 L p F P
0 g
s
.603 .66 .879 r
.60897 .29944 m .61146 .30347 L .62245 .30131 L p F P
0 g
s
.598 .705 .919 r
.61146 .30347 m .62245 .30131 L .62517 .305 L p F P
0 g
s
.727 .663 .786 r
.34804 .82376 m .34571 .81965 L .34087 .823 L closepath p F P
0 g
s
.898 .886 .811 r
.74945 .22075 m .75451 .21449 L .75505 .21891 L p F P
0 g
s
.898 .886 .811 r
.75505 .21891 m .75184 .22286 L .74945 .22075 L p F P
0 g
s
.697 .738 .883 r
.71053 .05358 m .69949 .05862 L .6969 .05467 L p F P
0 g
s
.699 .649 .796 r
.41084 .8161 m .40105 .81616 L .4003 .81479 L p F P
0 g
s
.704 .651 .794 r
.40105 .81616 m .4003 .81479 L .398 .81611 L closepath p F P
0 g
s
.881 .791 .756 r
.62403 .12801 m .62442 .12745 L .62172 .12378 L p F P
0 g
s
.67 .611 .78 r
.47428 .8283 m .48499 .82347 L p .48581 .83071 L F P
0 g
s
.67 .612 .781 r
.48385 .82102 m .48499 .82347 L .47428 .8283 L p F P
0 g
s
.67 .612 .781 r
.47428 .8283 m .47161 .82258 L .48385 .82102 L p F P
0 g
s
.636 .493 .671 r
.53059 .91907 m .52959 .91441 L .54122 .91235 L p F P
0 g
s
.638 .503 .682 r
.53959 .90551 m .54122 .91235 L .52959 .91441 L p F P
0 g
s
.643 .498 .67 r
.52959 .91441 m .53059 .91907 L .52606 .92189 L p F P
0 g
s
0 0 .139 r
.59509 .27172 m .59583 .27608 L .59502 .27178 L p F P
0 g
s
0 0 .139 r
.59502 .27178 m .59433 .2674 L .59509 .27172 L p F P
0 g
s
.755 .807 .894 r
.66061 .29196 m .66323 .29487 L .65235 .30138 L p F P
0 g
s
.755 .807 .894 r
.65056 .29788 m .66061 .29196 L p .65235 .30138 L F P
0 g
s
.755 .807 .894 r
.65235 .30138 m .65065 .29945 L .65056 .29788 L p F P
0 g
s
.761 .586 .659 r
.28234 .92225 m .2825 .92196 L p .28748 .92941 L F P
0 g
s
.763 .587 .659 r
.28234 .92225 m .2825 .92196 L .28227 .92193 L closepath p F P
0 g
s
.705 .653 .796 r
.39731 .80939 m .4003 .81479 L .398 .81611 L p F P
0 g
s
.705 .653 .796 r
.38667 .81548 m .39731 .80939 L p .398 .81611 L F P
0 g
s
.705 .653 .796 r
.398 .81611 m .38692 .81592 L .38667 .81548 L p F P
0 g
s
.747 .654 .757 r
.3 .84726 m .30104 .84634 L .29939 .84608 L closepath p F P
0 g
s
.751 .657 .758 r
.29939 .84608 m .3 .84726 L .29281 .85389 L p F P
0 g
s
.699 .647 .794 r
.41482 .81606 m .41393 .81441 L .41084 .8161 L closepath p F P
0 g
s
.699 .649 .796 r
.41094 .80894 m .41393 .81441 L .41084 .8161 L p F P
0 g
s
.699 .649 .796 r
.4003 .81479 m .41094 .80894 L p .41084 .8161 L F P
0 g
s
.745 .66 .766 r
.302 .8372 m .31015 .83853 L .30104 .84634 L p F P
0 g
s
.745 .66 .766 r
.29693 .84153 m .302 .8372 L p .30104 .84634 L F P
0 g
s
.745 .66 .766 r
.30104 .84634 m .29939 .84608 L .29693 .84153 L p F P
0 g
s
.751 .657 .758 r
.29305 .84497 m .29939 .84608 L p .29281 .85389 L F P
0 g
s
.751 .657 .758 r
.2862 .85125 m .29305 .84497 L p .29281 .85389 L F P
0 g
s
.751 .657 .758 r
.29281 .85389 m .28709 .85293 L .2862 .85125 L p F P
0 g
s
.753 .651 .749 r
.28927 .85728 m .29281 .85389 L .28709 .85293 L closepath p F P
0 g
s
.656 .434 .57 r
.47183 .95973 m .47446 .95952 L .47458 .9651 L p F P
0 g
s
.656 .434 .57 r
.47458 .9651 m .47098 .96539 L .47183 .95973 L p F P
0 g
s
.768 .59 .657 r
.28227 .92193 m .27461 .92062 L p .27935 .92813 L F P
0 g
s
.768 .59 .657 r
.27935 .92813 m .28234 .92225 L .28227 .92193 L p F P
0 g
s
.768 .6 .67 r
.28227 .92193 m .27461 .92062 L .27819 .91433 L p F P
0 g
s
.984 .825 .431 r
.59262 .24955 m .59349 .24467 L .59436 .24902 L p F P
0 g
s
.984 .825 .431 r
.59315 .25233 m .59262 .24955 L p .59436 .24902 L F P
0 g
s
.984 .825 .431 r
.59436 .24902 m .59407 .2506 L .59315 .25233 L p F P
0 g
s
.694 .645 .796 r
.42479 .81578 m .41482 .81606 L .41393 .81441 L p F P
0 g
s
.636 .472 .644 r
.52152 .93578 m .52048 .92947 L .53226 .92756 L p F P
0 g
s
.64 .485 .657 r
.53103 .92108 m .53226 .92756 L .52048 .92947 L p F P
0 g
s
.64 .485 .657 r
.52606 .92189 m .53103 .92108 L p .52048 .92947 L F P
0 g
s
.731 .496 .572 r
.34152 .96572 m .33594 .96531 L .33595 .9597 L p F P
0 g
s
.738 .502 .572 r
.33234 .95938 m .33595 .9597 L .33594 .96531 L p F P
0 g
s
.761 .586 .659 r
.28748 .92941 m .28394 .92888 L .28234 .92225 L p F P
0 g
s
.767 .589 .657 r
.28394 .92888 m .28234 .92225 L .27935 .92813 L closepath p F P
0 g
s
.769 .602 .672 r
.2704 .91296 m .27819 .91433 L .27461 .92062 L p F P
0 g
s
.767 .608 .682 r
.27442 .90656 m .2704 .91296 L .27819 .91433 L p F P
0 g
s
.641 .496 .67 r
.53103 .92108 m .53059 .91907 L .52606 .92189 L closepath p F P
0 g
s
.881 .791 .756 r
.62172 .12378 m .6215 .12409 L .62403 .12801 L p F P
0 g
s
.882 .791 .755 r
.61742 .13007 m .61993 .13399 L .62403 .12801 L p F P
0 g
s
.882 .791 .755 r
.62403 .12801 m .6215 .12409 L .61742 .13007 L p F P
0 g
s
.71 .461 .546 r
.37334 .97287 m .36578 .97258 L .36609 .96724 L p F P
0 g
s
.718 .467 .546 r
.36214 .96703 m .36609 .96724 L .36578 .97258 L p F P
0 g
s
.757 .653 .747 r
.28524 .86126 m .28927 .85728 L .28709 .85293 L p F P
0 g
s
.655 .585 .764 r
.5181 .84106 m .5194 .84421 L .50769 .84627 L p F P
0 g
s
.655 .585 .764 r
.50769 .84627 m .50735 .84543 L .5181 .84106 L p F P
0 g
s
.996 .814 .454 r
.78037 .13602 m .78157 .14033 L .78235 .13553 L p F P
0 g
s
.996 .814 .454 r
.78235 .13553 m .78116 .13122 L .78037 .13602 L p F P
0 g
s
.76 .575 .647 r
.28508 .93452 m .28748 .92941 L p .29303 .9367 L F P
0 g
s
.762 .576 .646 r
.28508 .93452 m .28748 .92941 L .28394 .92888 L closepath p F P
0 g
s
.744 .662 .769 r
.31102 .83867 m .3107 .83808 L .31015 .83853 L closepath p F P
0 g
s
.723 .418 0 r
.77678 .10499 m .77822 .10927 L .77706 .10525 L p F P
0 g
s
.723 .418 0 r
.77706 .10525 m .77561 .10097 L .77678 .10499 L p F P
0 g
s
.729 .659 .781 r
.33507 .82717 m .34087 .823 L .33224 .82208 L closepath p F P
0 g
s
.641 .539 .723 r
.5326 .88088 m .53119 .87645 L .54267 .87419 L p F P
0 g
s
.643 .548 .732 r
.54048 .86765 m .54267 .87419 L .53119 .87645 L p F P
0 g
s
.643 .548 .732 r
.53119 .87645 m .52969 .87201 L .54048 .86765 L p F P
0 g
s
.641 .539 .723 r
.53358 .88399 m .5326 .88088 L .54338 .87644 L p F P
0 g
s
.641 .539 .723 r
.54267 .87419 m .54338 .87644 L .5326 .88088 L p F P
0 g
s
.639 .53 .714 r
.5355 .89041 m .53358 .88399 L .54505 .88173 L p F P
0 g
s
.641 .539 .723 r
.54338 .87644 m .54505 .88173 L .53358 .88399 L p F P
0 g
s
.769 .626 .703 r
.27116 .89864 m .27362 .89528 L .27209 .89128 L p F P
0 g
s
.71 .655 .793 r
.38692 .81592 m .38667 .81548 L .38599 .81589 L closepath p F P
0 g
s
.655 .583 .762 r
.5181 .84106 m .50735 .84543 L .50444 .83845 L p F P
0 g
s
.941 .896 .756 r
.76792 .19055 m .76736 .19144 L .76799 .19587 L p F P
0 g
s
.928 .892 .774 r
.76323 .19752 m .76391 .20192 L .76799 .19587 L p F P
0 g
s
.928 .892 .774 r
.76799 .19587 m .76736 .19144 L .76323 .19752 L p F P
0 g
s
.759 .649 .74 r
.28524 .86126 m .27848 .8682 L .27542 .86194 L p F P
0 g
s
.759 .649 .74 r
.27542 .86194 m .27746 .85984 L .28524 .86126 L p F P
0 g
s
.757 .653 .747 r
.28487 .85251 m .27746 .85984 L .28524 .86126 L p F P
0 g
s
.757 .653 .747 r
.28709 .85293 m .28487 .85251 L p .28524 .86126 L F P
0 g
s
.712 .653 .79 r
.37303 .81653 m .37484 .81541 L .38599 .81589 L p F P
0 g
s
.711 .658 .796 r
.38366 .81015 m .37484 .81541 L .38599 .81589 L p F P
0 g
s
.711 .658 .796 r
.38599 .81589 m .38667 .81548 L .38366 .81015 L p F P
0 g
s
.643 .548 .732 r
.54008 .86646 m .54048 .86765 L .52969 .87201 L p F P
0 g
s
.643 .548 .732 r
.52969 .87201 m .52858 .86872 L .54008 .86646 L p F P
0 g
s
.649 .428 .57 r
.47458 .9651 m .47446 .95952 L .48697 .95833 L p F P
0 g
s
.745 .664 .771 r
.30762 .83255 m .302 .8372 L .31015 .83853 L p F P
0 g
s
.745 .664 .771 r
.31015 .83853 m .3107 .83808 L .30762 .83255 L p F P
0 g
s
.751 .662 .763 r
.29939 .84608 m .29693 .84153 L .29305 .84497 L closepath p F P
0 g
s
.741 .663 .773 r
.32029 .83043 m .3107 .83808 L .30762 .83255 L p F P
0 g
s
.769 .612 .684 r
.26672 .90515 m .27442 .90656 L .2704 .91296 L p F P
0 g
s
.768 .618 .692 r
.27116 .89864 m .26672 .90515 L .27442 .90656 L p F P
0 g
s
.751 .543 .614 r
.30602 .95079 m .30376 .95052 L .30309 .94436 L p F P
0 g
s
.758 .548 .613 r
.29917 .94383 m .30309 .94436 L .30376 .95052 L p F P
0 g
s
.932 .82 .712 r
.60059 .18215 m .60257 .18621 L .60551 .18063 L p F P
0 g
s
.932 .82 .712 r
.60551 .18063 m .60349 .17659 L .60059 .18215 L p F P
0 g
s
.952 .826 .682 r
.60111 .18905 m .59994 .19168 L .60185 .19574 L p F P
0 g
s
.956 .825 .674 r
.59765 .19703 m .59952 .20111 L .60185 .19574 L p F P
0 g
s
.956 .825 .674 r
.60185 .19574 m .59994 .19168 L .59765 .19703 L p F P
0 g
s
.718 .467 .546 r
.36578 .97258 m .36231 .9724 L .36214 .96703 L p F P
0 g
s
.719 .468 .545 r
.35153 .96646 m .36214 .96703 L .36231 .9724 L p F P
0 g
s
.843 .782 .792 r
.62961 .10633 m .63424 .10107 L .63687 .10499 L p F P
0 g
s
.843 .782 .792 r
.63687 .10499 m .63231 .11017 L .62961 .10633 L p F P
0 g
s
.645 .557 .74 r
.53757 .85939 m .54008 .86646 L .52858 .86872 L p F P
0 g
s
.645 .557 .74 r
.52858 .86872 m .52679 .86368 L .53757 .85939 L p F P
0 g
s
.706 .656 .798 r
.39731 .80939 m .38667 .81548 L .38366 .81015 L p F P
0 g
s
.693 .642 .794 r
.42826 .81566 m .42755 .81433 L .42479 .81578 L closepath p F P
0 g
s
.694 .645 .796 r
.42458 .8088 m .42755 .81433 L .42479 .81578 L p F P
0 g
s
.694 .645 .796 r
.41393 .81441 m .42458 .8088 L p .42479 .81578 L F P
0 g
s
.7 .652 .798 r
.41094 .80894 m .4003 .81479 L .39731 .80939 L p F P
0 g
s
.638 .529 .714 r
.53578 .89135 m .5355 .89041 L .54629 .88589 L p F P
0 g
s
.639 .53 .714 r
.54505 .88173 m .54629 .88589 L .5355 .89041 L p F P
0 g
s
.765 .633 .714 r
.27063 .88772 m .27379 .88381 L .26862 .88286 L closepath p F P
0 g
s
.763 .64 .725 r
.26761 .88059 m .27199 .87547 L p .27379 .88381 L F P
0 g
s
.763 .64 .725 r
.27379 .88381 m .26862 .88286 L .26761 .88059 L p F P
0 g
s
.909 .813 .74 r
.60611 .16334 m .60727 .16141 L .60943 .16543 L p F P
0 g
s
.909 .813 .74 r
.60943 .16543 m .60882 .16643 L .60611 .16334 L p F P
0 g
s
.636 .519 .704 r
.53578 .89135 m .54724 .88908 L p .5486 .89639 L F P
0 g
s
.636 .519 .704 r
.5486 .89639 m .53778 .89851 L .53578 .89135 L p F P
0 g
s
.638 .529 .714 r
.54629 .88589 m .54724 .88908 L .53578 .89135 L p F P
0 g
s
.759 .562 .63 r
.29917 .94383 m .2907 .94267 L .29303 .9367 L p F P
0 g
s
.76 .563 .631 r
.28531 .93561 m .29303 .9367 L .2907 .94267 L p F P
0 g
s
.76 .575 .647 r
.29303 .9367 m .28531 .93561 L .28508 .93452 L p F P
0 g
s
.738 .502 .572 r
.33594 .96531 m .33172 .96493 L .33234 .95938 L p F P
0 g
s
.739 .503 .572 r
.32286 .95849 m .33234 .95938 L .33172 .96493 L p F P
0 g
s
.749 .527 .594 r
.32026 .95825 m .31373 .95751 L .31499 .95181 L p F P
0 g
s
.749 .528 .595 r
.30602 .95079 m .31499 .95181 L .31373 .95751 L p F P
0 g
s
.893 .887 .818 r
.74966 .22544 m .75184 .22286 L .74945 .22075 L p F P
0 g
s
.791 .838 .888 r
.68263 .2863 m .68753 .28277 L .68497 .28013 L p F P
0 g
s
.791 .838 .888 r
.68497 .28013 m .6827 .28174 L .68263 .2863 L p F P
0 g
s
.788 .833 .886 r
.6741 .28778 m .6827 .28174 L .68263 .2863 L p F P
0 g
s
.689 .64 .796 r
.44019 .81504 m .42826 .81566 L .42755 .81433 L p F P
0 g
s
.769 .626 .703 r
.27209 .89128 m .2684 .89057 L p .27116 .89864 L F P
0 g
s
.769 .634 .712 r
.27209 .89128 m .27063 .88772 L .2684 .89057 L closepath p F P
0 g
s
.712 .654 .791 r
.37303 .81653 m .37484 .81541 L .37235 .8153 L closepath p F P
0 g
s
.717 .658 .789 r
.37235 .8153 m .37303 .81653 L p .35938 .81793 L F P
0 g
s
.677 .624 .788 r
.45773 .82107 m .46843 .81608 L p .46979 .82277 L F P
0 g
s
.677 .624 .788 r
.46843 .81608 m .45773 .82107 L .45479 .81514 L p F P
0 g
s
.661 .42 .544 r
.44892 .9669 m .45332 .96664 L .45384 .97194 L p F P
0 g
s
.661 .42 .544 r
.45384 .97194 m .44873 .97225 L .44892 .9669 L p F P
0 g
s
.115 .359 .823 r
.76 .07614 m .76282 .0779 L .76459 .08211 L p F P
0 g
s
0 .221 .742 r
.7663 .08101 m .76804 .08523 L .76459 .08211 L p F P
0 g
s
0 .221 .742 r
.76459 .08211 m .76282 .0779 L .7663 .08101 L p F P
0 g
s
.578 .681 .911 r
.73013 .05756 m .72681 .05807 L .72426 .05405 L p F P
0 g
s
0 0 .391 r
.77408 .0967 m .77561 .10097 L .7738 .0972 L p F P
0 g
s
0 0 .391 r
.7738 .0972 m .77225 .09294 L .77408 .0967 L p F P
0 g
s
.762 .65 .738 r
.27866 .86856 m .27848 .8682 L .27822 .86847 L closepath p F P
0 g
s
.97 .843 .662 r
.59509 .21177 m .59664 .21594 L .59887 .2106 L p F P
0 g
s
.97 .843 .662 r
.59887 .2106 m .59726 .20645 L .59509 .21177 L p F P
0 g
s
.695 .647 .798 r
.42458 .8088 m .41393 .81441 L .41094 .80894 L p F P
0 g
s
.669 .608 .778 r
.48819 .8304 m .4879 .82978 L .48581 .83071 L closepath p F P
0 g
s
.67 .611 .78 r
.48499 .82347 m .4879 .82978 L .48581 .83071 L p F P
0 g
s
.763 .652 .739 r
.27822 .86847 m .27848 .8682 L .27542 .86194 L p F P
0 g
s
.645 .557 .741 r
.53727 .85852 m .53757 .85939 L .52679 .86368 L p F P
0 g
s
.645 .557 .741 r
.52679 .86368 m .52576 .86078 L .53727 .85852 L p F P
0 g
s
.738 .664 .777 r
.32196 .83067 m .32136 .8296 L .32029 .83043 L closepath p F P
0 g
s
.763 .648 .734 r
.2707 .86698 m .27822 .86847 L .27199 .87547 L p F P
0 g
s
.763 .652 .739 r
.27542 .86194 m .2707 .86698 L .27822 .86847 L p F P
0 g
s
.924 .808 .713 r
.60639 .17103 m .60882 .16643 L .60611 .16334 L p F P
0 g
s
0 .022 .595 r
.77063 .08869 m .77225 .09294 L .76969 .08946 L p F P
0 g
s
0 .022 .595 r
.76969 .08946 m .76804 .08523 L .77063 .08869 L p F P
0 g
s
.645 .441 .592 r
.49502 .95162 m .4989 .95118 L .4993 .95696 L p F P
0 g
s
.645 .441 .592 r
.4993 .95696 m .49235 .95775 L .49502 .95162 L p F P
0 g
s
.636 .493 .671 r
.53103 .92108 m .53059 .91907 L .54136 .913 L p F P
0 g
s
.636 .493 .671 r
.54122 .91235 m .54136 .913 L .53059 .91907 L p F P
0 g
s
.727 .665 .788 r
.34266 .81431 m .34571 .81965 L .34087 .823 L p F P
0 g
s
.727 .665 .788 r
.33202 .82168 m .34266 .81431 L p .34087 .823 L F P
0 g
s
.727 .665 .788 r
.34087 .823 m .33224 .82208 L .33202 .82168 L p F P
0 g
s
.769 .622 .696 r
.26356 .89719 m .27116 .89864 L .26672 .90515 L p F P
0 g
s
.769 .626 .703 r
.2684 .89057 m .26356 .89719 L .27116 .89864 L p F P
0 g
s
.766 .579 .645 r
.28394 .92888 m .27935 .92813 L p .28464 .9355 L F P
0 g
s
.766 .579 .645 r
.28464 .9355 m .28508 .93452 L .28394 .92888 L p F P
0 g
s
.902 .799 .737 r
.61388 .14269 m .61194 .1459 L .61432 .14985 L p F P
0 g
s
.903 .8 .736 r
.60846 .15166 m .61082 .15562 L .61432 .14985 L p F P
0 g
s
.903 .8 .736 r
.61432 .14985 m .61194 .1459 L .60846 .15166 L p F P
0 g
s
.711 .66 .798 r
.38069 .80491 m .38366 .81015 L .37484 .81541 L p F P
0 g
s
.711 .66 .798 r
.38053 .80491 m .38069 .80491 L p .37484 .81541 L F P
0 g
s
.711 .66 .798 r
.37001 .81122 m .38053 .80491 L p .37484 .81541 L F P
0 g
s
.711 .66 .798 r
.37484 .81541 m .37235 .8153 L .37001 .81122 L p F P
0 g
s
.992 .807 .429 r
.59407 .2506 m .59359 .25387 L .59315 .25233 L closepath p F P
0 g
s
.647 .565 .749 r
.53468 .85157 m .53727 .85852 L .52576 .86078 L p F P
0 g
s
.647 .565 .749 r
.52576 .86078 m .52389 .85579 L .53468 .85157 L p F P
0 g
s
.893 .887 .818 r
.74945 .22075 m .74925 .22098 L .74966 .22544 L p F P
0 g
s
.883 .881 .827 r
.74327 .22774 m .74376 .23216 L .74966 .22544 L p F P
0 g
s
.883 .881 .827 r
.74966 .22544 m .74925 .22098 L .74327 .22774 L p F P
0 g
s
.717 .658 .789 r
.35938 .81793 m .3643 .81476 L .37235 .8153 L p F P
0 g
s
.718 .658 .79 r
.35938 .81793 m .3643 .81476 L .35733 .81428 L closepath p F P
0 g
s
.659 .418 .544 r
.45332 .96664 m .46185 .96609 L .46168 .97144 L p F P
0 g
s
.659 .418 .544 r
.46168 .97144 m .45384 .97194 L .45332 .96664 L p F P
0 g
s
.634 .51 .694 r
.53842 .90101 m .5486 .89639 L .53778 .89851 L closepath p F P
0 g
s
.741 .663 .773 r
.30762 .83255 m .31186 .82918 L .32029 .83043 L p F P
0 g
s
.74 .667 .779 r
.31829 .82422 m .31186 .82918 L .32029 .83043 L p F P
0 g
s
.74 .667 .779 r
.32029 .83043 m .32136 .8296 L .31829 .82422 L p F P
0 g
s
.716 .662 .796 r
.37235 .8153 m .37001 .81122 L .3643 .81476 L closepath p F P
0 g
s
.689 .642 .797 r
.43821 .80897 m .42755 .81433 L .42458 .8088 L p F P
0 g
s
.689 .64 .796 r
.42755 .81433 m .43821 .80897 L p .44019 .81504 L F P
0 g
s
.769 .635 .712 r
.2684 .89057 m .27063 .88772 L .26862 .88286 L p F P
0 g
s
.993 .869 .598 r
.77864 .15045 m .77967 .1548 L .78136 .14966 L p F P
0 g
s
.993 .869 .598 r
.78136 .14966 m .78035 .14529 L .77864 .15045 L p F P
0 g
s
.863 .784 .772 r
.63125 .11154 m .63231 .11017 L .62961 .10633 L p F P
0 g
s
.664 .606 .78 r
.49863 .82526 m .50015 .82858 L .48819 .8304 L p F P
0 g
s
.664 .606 .78 r
.48819 .8304 m .4879 .82978 L .49863 .82526 L p F P
0 g
s
.991 .837 .592 r
.59335 .22621 m .59484 .23038 L .59641 .22527 L p F P
0 g
s
.991 .837 .592 r
.59641 .22527 m .59487 .22112 L .59335 .22621 L p F P
0 g
s
.733 .752 .867 r
.69254 .05723 m .68596 .06104 L .68334 .05709 L p F P
0 g
s
.758 .548 .613 r
.30376 .95052 m .29739 .94967 L .29917 .94383 L p F P
0 g
s
.759 .55 .614 r
.2907 .94267 m .29917 .94383 L .29739 .94967 L p F P
0 g
s
.952 .89 .731 r
.77008 .18121 m .77092 .18558 L .77413 .17985 L p F P
0 g
s
.952 .89 .731 r
.77413 .17985 m .77333 .17546 L .77008 .18121 L p F P
0 g
s
.735 .666 .782 r
.33158 .822 m .32136 .8296 L .31829 .82422 L p F P
0 g
s
.718 .789 .907 r
.64971 .29837 m .63879 .30392 L .63611 .30064 L p F P
0 g
s
.683 .766 .914 r
.62517 .305 m .63611 .30064 L .63879 .30392 L p F P
0 g
s
.676 .621 .786 r
.47161 .82258 m .47135 .82205 L .46979 .82277 L closepath p F P
0 g
s
.677 .624 .788 r
.46843 .81608 m .47135 .82205 L .46979 .82277 L p F P
0 g
s
.803 .842 .88 r
.69451 .27746 m .68753 .28277 L .68497 .28013 L p F P
0 g
s
.632 .479 .657 r
.53226 .92756 m .53103 .92108 L .54265 .919 L p F P
0 g
s
.636 .493 .671 r
.54136 .913 m .54265 .919 L .53103 .92108 L p F P
0 g
s
.719 .468 .545 r
.36231 .9724 m .3517 .97182 L .35153 .96646 L p F P
0 g
s
.72 .469 .545 r
.35123 .96644 m .35153 .96646 L .3517 .97182 L p F P
0 g
s
.664 .605 .779 r
.49863 .82526 m .4879 .82978 L .48499 .82347 L p F P
0 g
s
.72 .469 .545 r
.3517 .97182 m .35088 .97177 L .35123 .96644 L p F P
0 g
s
.728 .475 .545 r
.34152 .96572 m .35123 .96644 L .35088 .97177 L p F P
0 g
s
.756 .659 .755 r
.28709 .85293 m .2862 .85125 L .28487 .85251 L closepath p F P
0 g
s
.634 .509 .693 r
.53959 .90551 m .53842 .90101 L .5486 .89639 L p F P
0 g
s
.892 .671 .156 r
.59335 .26311 m .59433 .2674 L .59421 .26286 L p F P
0 g
s
.892 .671 .156 r
.59421 .26286 m .59324 .25856 L .59335 .26311 L p F P
0 g
s
.863 .784 .772 r
.62379 .11389 m .62643 .11779 L .63125 .11154 L p F P
0 g
s
.863 .784 .772 r
.63125 .11154 m .62861 .10763 L .62379 .11389 L p F P
0 g
s
.863 .784 .772 r
.62961 .10633 m .62861 .10763 L .63125 .11154 L p F P
0 g
s
.671 .756 .915 r
.63611 .30064 m .62517 .305 L .62245 .30131 L p F P
0 g
s
.636 .448 .612 r
.51041 .94366 m .52238 .94194 L p .52105 .94821 L F P
0 g
s
.636 .448 .612 r
.52105 .94821 m .51104 .94963 L .51041 .94366 L p F P
0 g
s
.64 .463 .628 r
.52152 .93578 m .52238 .94194 L .51041 .94366 L p F P
0 g
s
.644 .454 .611 r
.51041 .94366 m .51104 .94963 L .4989 .95118 L p F P
0 g
s
.687 .638 .794 r
.44139 .81498 m .44117 .81455 L .44019 .81504 L closepath p F P
0 g
s
.689 .64 .796 r
.43821 .80897 m .44117 .81455 L .44019 .81504 L p F P
0 g
s
.977 .881 .67 r
.77524 .16551 m .77622 .16985 L .77859 .16445 L p F P
0 g
s
.977 .881 .67 r
.77859 .16445 m .77762 .16009 L .77524 .16551 L p F P
0 g
s
.647 .566 .75 r
.53422 .85036 m .53468 .85157 L .52389 .85579 L p F P
0 g
s
.647 .566 .75 r
.52389 .85579 m .5227 .85262 L .53422 .85036 L p F P
0 g
s
.981 .858 .644 r
.59709 .21738 m .59619 .2171 L .59664 .21594 L closepath p F P
0 g
s
.67 .618 .788 r
.48207 .81734 m .48385 .82102 L .47161 .82258 L p F P
0 g
s
.67 .618 .788 r
.47161 .82258 m .47135 .82205 L .48207 .81734 L p F P
0 g
s
.638 .435 .592 r
.4993 .95696 m .4989 .95118 L .51104 .94963 L p F P
0 g
s
.982 .77 .361 r
.77988 .12691 m .78116 .13122 L .78153 .12658 L p F P
0 g
s
.982 .77 .361 r
.78153 .12658 m .78026 .12228 L .77988 .12691 L p F P
0 g
s
.655 .583 .762 r
.51582 .83554 m .5181 .84106 L p .50444 .83845 L F P
0 g
s
.655 .583 .762 r
.50444 .83845 m .50831 .83686 L .51582 .83554 L p F P
0 g
s
.657 .588 .766 r
.50444 .83845 m .50831 .83686 L .50408 .83758 L closepath p F P
0 g
s
.682 .635 .796 r
.45185 .80945 m .45422 .81399 L .44139 .81498 L p F P
0 g
s
.682 .635 .796 r
.44139 .81498 m .44117 .81455 L .45185 .80945 L p F P
0 g
s
.723 .664 .791 r
.35416 .814 m .34571 .81965 L .34266 .81431 L p F P
0 g
s
.765 .641 .724 r
.26761 .88059 m .27199 .87547 L .26472 .87408 L closepath p F P
0 g
s
.763 .648 .734 r
.26458 .87378 m .2707 .86698 L p .27199 .87547 L F P
0 g
s
.763 .648 .734 r
.27199 .87547 m .26472 .87408 L .26458 .87378 L p F P
0 g
s
.77 .631 .707 r
.26091 .88909 m .2684 .89057 L .26356 .89719 L p F P
0 g
s
.769 .635 .712 r
.26614 .88236 m .26091 .88909 L .2684 .89057 L p F P
0 g
s
.769 .635 .712 r
.26862 .88286 m .26614 .88236 L p .2684 .89057 L F P
0 g
s
.672 .62 .789 r
.48207 .81734 m .47135 .82205 L .46843 .81608 L p F P
0 g
s
.881 .792 .757 r
.61325 .13608 m .61575 .14001 L .61993 .13399 L p F P
0 g
s
.881 .792 .757 r
.61993 .13399 m .61742 .13007 L .61325 .13608 L p F P
0 g
s
.658 .595 .774 r
.50831 .83686 m .50408 .83758 L .50154 .83176 L p F P
0 g
s
.684 .638 .798 r
.45185 .80945 m .44117 .81455 L .43821 .80897 L p F P
0 g
s
.118 .367 .828 r
.76282 .0779 m .76 .07614 L .75746 .07159 L p F P
0 g
s
.648 .574 .757 r
.53178 .84412 m .53422 .85036 L .5227 .85262 L p F P
0 g
s
.648 .574 .757 r
.5227 .85262 m .521 .84827 L .53178 .84412 L p F P
0 g
s
.921 .888 .783 r
.75884 .20369 m .76323 .19752 L .76391 .20192 L p F P
0 g
s
.921 .888 .783 r
.7594 .20708 m .75884 .20369 L p .76391 .20192 L F P
0 g
s
.921 .888 .783 r
.76391 .20192 m .75994 .20753 L .7594 .20708 L p F P
0 g
s
.652 .413 .543 r
.46185 .96609 m .47098 .96539 L .47157 .97069 L p F P
0 g
s
.652 .413 .543 r
.47157 .97069 m .46168 .97144 L .46185 .96609 L p F P
0 g
s
.769 .642 .722 r
.26862 .88286 m .26761 .88059 L .26614 .88236 L closepath p F P
0 g
s
.716 .664 .797 r
.36697 .80598 m .37001 .81122 L .3643 .81476 L p F P
0 g
s
.716 .664 .797 r
.35634 .81258 m .36697 .80598 L p .3643 .81476 L F P
0 g
s
.716 .664 .797 r
.3643 .81476 m .35733 .81428 L .35634 .81258 L p F P
0 g
s
.876 .876 .832 r
.73884 .2326 m .74327 .22774 L .74376 .23216 L p F P
0 g
s
.876 .876 .832 r
.74376 .23216 m .74127 .23489 L .73884 .2326 L p F P
0 g
s
.739 .503 .572 r
.33172 .96493 m .32221 .96405 L .32286 .95849 L p F P
0 g
s
.74 .504 .572 r
.32026 .95825 m .32286 .95849 L .32221 .96405 L p F P
0 g
s
.633 .459 .629 r
.52152 .93578 m .53333 .9339 L p .52722 .94117 L F P
0 g
s
.633 .459 .629 r
.52722 .94117 m .52238 .94194 L .52152 .93578 L p F P
0 g
s
.636 .472 .644 r
.53226 .92756 m .53333 .9339 L .52152 .93578 L p F P
0 g
s
.999 .837 .514 r
.59233 .2404 m .59349 .24467 L .59467 .23968 L p F P
0 g
s
.999 .837 .514 r
.59467 .23968 m .59347 .23543 L .59233 .2404 L p F P
0 g
s
.632 .5 .683 r
.53959 .90551 m .55105 .90325 L p .5436 .91188 L F P
0 g
s
.632 .5 .683 r
.5436 .91188 m .54122 .91235 L .53959 .90551 L p F P
0 g
s
.634 .509 .693 r
.54926 .89626 m .55105 .90325 L .53959 .90551 L p F P
0 g
s
.634 .509 .693 r
.5486 .89639 m .54926 .89626 L p .53959 .90551 L F P
0 g
s
.753 .659 .757 r
.29305 .84497 m .2862 .85125 L .28312 .84545 L p F P
0 g
s
.753 .659 .757 r
.28312 .84545 m .28518 .84355 L .29305 .84497 L p F P
0 g
s
.751 .662 .763 r
.29385 .83587 m .28518 .84355 L .29305 .84497 L p F P
0 g
s
.751 .662 .763 r
.29386 .83587 m .29385 .83587 L p .29305 .84497 L F P
0 g
s
.751 .662 .763 r
.29305 .84497 m .29693 .84153 L .29386 .83587 L p F P
0 g
s
.757 .661 .755 r
.28487 .85251 m .2862 .85125 L .28312 .84545 L p F P
0 g
s
.768 .59 .657 r
.27461 .92062 m .27142 .9268 L .27935 .92813 L p F P
0 g
s
.769 .594 .661 r
.26675 .91926 m .27461 .92062 L .27142 .9268 L p F P
0 g
s
.769 .602 .672 r
.27461 .92062 m .26675 .91926 L .2704 .91296 L p F P
0 g
s
.766 .579 .645 r
.28531 .93561 m .28508 .93452 L .28464 .9355 L closepath p F P
0 g
s
.757 .661 .755 r
.28312 .84545 m .27725 .85103 L .28487 .85251 L p F P
0 g
s
.758 .657 .751 r
.27725 .85103 m .28487 .85251 L .27746 .85984 L p F P
0 g
s
.807 .848 .881 r
.69451 .27746 m .69834 .27448 L .69581 .2719 L p F P
0 g
s
.807 .848 .881 r
.69581 .2719 m .69449 .27292 L .69451 .27746 L p F P
0 g
s
.803 .842 .88 r
.68497 .28013 m .69449 .27292 L .69451 .27746 L p F P
0 g
s
.966 .886 .701 r
.77656 .1715 m .7757 .17091 L .77622 .16985 L closepath p F P
0 g
s
.747 .661 .765 r
.29693 .84153 m .302 .8372 L .29386 .83587 L closepath p F P
0 g
s
.766 .579 .645 r
.27935 .92813 m .27664 .9342 L .28464 .9355 L p F P
0 g
s
.768 .582 .646 r
.27142 .9268 m .27935 .92813 L .27664 .9342 L p F P
0 g
s
.77 .604 .673 r
.26262 .91157 m .2704 .91296 L .26675 .91926 L p F P
0 g
s
.769 .612 .684 r
.2704 .91296 m .26262 .91157 L .26672 .90515 L p F P
0 g
s
.749 .528 .595 r
.31373 .95751 m .30472 .9565 L .30602 .95079 L p F P
0 g
s
.751 .529 .595 r
.30376 .95052 m .30602 .95079 L .30472 .9565 L p F P
0 g
s
.643 .423 .57 r
.48697 .95833 m .49235 .95775 L .49131 .96346 L p F P
0 g
s
.643 .423 .57 r
.49131 .96346 m .48711 .96391 L .48697 .95833 L p F P
0 g
s
.649 .428 .57 r
.48697 .95833 m .48711 .96391 L .47458 .9651 L p F P
0 g
s
.68 .413 .511 r
.4085 .97345 m .40957 .97344 L .41109 .97849 L p F P
0 g
s
.68 .413 .511 r
.41109 .97849 m .4079 .97852 L .4085 .97345 L p F P
0 g
s
.687 .419 .512 r
.39684 .97342 m .4085 .97345 L .4079 .97852 L p F P
0 g
s
.87 .877 .838 r
.73729 .23909 m .74127 .23489 L .73884 .2326 L p F P
0 g
s
.678 .412 .512 r
.40957 .97344 m .42216 .97327 L .42159 .97834 L p F P
0 g
s
.678 .412 .512 r
.42159 .97834 m .41109 .97849 L .40957 .97344 L p F P
0 g
s
.76 .563 .631 r
.2907 .94267 m .28632 .94205 L .28531 .93561 L p F P
0 g
s
.767 .568 .629 r
.28464 .9355 m .28531 .93561 L .28632 .94205 L p F P
0 g
s
.733 .667 .785 r
.33224 .82208 m .33202 .82168 L .33158 .822 L closepath p F P
0 g
s
.687 .419 .512 r
.4079 .97852 m .39823 .97849 L .39684 .97342 L p F P
0 g
s
.688 .42 .512 r
.39456 .97341 m .39684 .97342 L .39823 .97849 L p F P
0 g
s
.745 .666 .774 r
.30518 .82817 m .30762 .83255 L .302 .8372 L p F P
0 g
s
.745 .666 .774 r
.30353 .82789 m .30518 .82817 L p .302 .8372 L F P
0 g
s
.745 .666 .774 r
.29385 .83586 m .30353 .82789 L p .302 .8372 L F P
0 g
s
.745 .666 .774 r
.302 .8372 m .29386 .83587 L .29385 .83586 L p F P
0 g
s
.688 .42 .512 r
.39823 .97849 m .39393 .97847 L .39456 .97341 L p F P
0 g
s
.696 .427 .512 r
.38481 .97322 m .39456 .97341 L .39393 .97847 L p F P
0 g
s
.376 .556 .903 r
.75246 .06289 m .75434 .06692 L .74698 .06533 L p F P
0 g
s
.376 .556 .903 r
.75236 .06273 m .75246 .06289 L p .74698 .06533 L F P
0 g
s
.376 .556 .903 r
.74698 .06533 m .74494 .06119 L .75236 .06273 L p F P
0 g
s
.448 .601 .91 r
.74071 .0608 m .74494 .06119 L .74698 .06533 L p F P
0 g
s
.74 .504 .572 r
.32221 .96405 m .32025 .96386 L .32026 .95825 L p F P
0 g
s
.748 .51 .572 r
.31373 .95751 m .32026 .95825 L .32025 .96386 L p F P
0 g
s
.295 .454 .849 r
.60312 .28882 m .60144 .28789 L .6019 .29231 L p F P
0 g
s
.295 .454 .849 r
.6019 .29231 m .60592 .29403 L .60312 .28882 L p F P
0 g
s
.769 .643 .722 r
.26614 .88236 m .26761 .88059 L .26472 .87408 L p F P
0 g
s
.769 .817 .89 r
.66864 .29137 m .66323 .29487 L .66061 .29196 L p F P
0 g
s
.76 .651 .741 r
.27542 .86194 m .27746 .85984 L .27408 .8592 L closepath p F P
0 g
s
.758 .657 .751 r
.27235 .85586 m .27725 .85103 L p .27746 .85984 L F P
0 g
s
.758 .657 .751 r
.27746 .85984 m .27408 .8592 L .27235 .85586 L p F P
0 g
s
.735 .666 .782 r
.31829 .82422 m .32287 .82082 L .33158 .822 L p F P
0 g
s
.734 .67 .787 r
.32895 .81645 m .32287 .82082 L .33158 .822 L p F P
0 g
s
.734 .67 .787 r
.33158 .822 m .33202 .82168 L .32895 .81645 L p F P
0 g
s
.767 .568 .629 r
.28632 .94205 m .28243 .94144 L .28464 .9355 L p F P
0 g
s
.768 .57 .63 r
.27664 .9342 m .28464 .9355 L .28243 .94144 L p F P
0 g
s
.817 .85 .873 r
.70489 .26914 m .69834 .27448 L .69581 .2719 L p F P
0 g
s
.729 .669 .791 r
.34266 .81431 m .33202 .82168 L .32895 .81645 L p F P
0 g
s
.728 .476 .546 r
.33594 .96531 m .34152 .96572 L .34165 .97109 L p F P
0 g
s
.728 .475 .545 r
.35088 .97177 m .34165 .97109 L .34152 .96572 L p F P
0 g
s
.578 .681 .911 r
.72426 .05405 m .72787 .05348 L .73013 .05756 L p F P
0 g
s
.554 .666 .911 r
.73561 .05258 m .72787 .05348 L .73013 .05756 L p F P
0 g
s
.554 .666 .911 r
.73013 .05756 m .73816 .05668 L .73561 .05258 L p F P
0 g
s
.648 .574 .758 r
.53093 .84195 m .53178 .84412 L .521 .84827 L p F P
0 g
s
.648 .574 .758 r
.521 .84827 m .5194 .84421 L .53093 .84195 L p F P
0 g
s
.935 .825 .711 r
.59839 .18645 m .60059 .18215 L .60257 .18621 L p F P
0 g
s
.935 .825 .711 r
.60257 .18621 m .60111 .18905 L .59839 .18645 L p F P
0 g
s
.671 .405 .511 r
.42216 .97327 m .42316 .97324 L .42482 .97826 L p F P
0 g
s
.671 .405 .511 r
.42482 .97826 m .42159 .97834 L .42216 .97327 L p F P
0 g
s
.771 .614 .685 r
.25993 .90389 m .26672 .90515 L .26262 .91157 L p F P
0 g
s
.769 .622 .696 r
.25959 .90295 m .26356 .89719 L p .26672 .90515 L F P
0 g
s
.769 .622 .696 r
.26672 .90515 m .25993 .90389 L .25959 .90295 L p F P
0 g
s
.764 .653 .739 r
.2707 .86698 m .27542 .86194 L .27408 .8592 L p F P
0 g
s
.669 .404 .511 r
.42316 .97324 m .43557 .97286 L .43503 .97795 L p F P
0 g
s
.669 .404 .511 r
.43503 .97795 m .42482 .97826 L .42316 .97324 L p F P
0 g
s
.924 .808 .713 r
.60611 .16334 m .60416 .16704 L .60639 .17103 L p F P
0 g
s
.926 .808 .71 r
.60129 .1726 m .60349 .17659 L .60639 .17103 L p F P
0 g
s
.926 .808 .71 r
.60639 .17103 m .60416 .16704 L .60129 .1726 L p F P
0 g
s
.751 .529 .595 r
.30472 .9565 m .3041 .95643 L .30376 .95052 L p F P
0 g
s
.758 .535 .594 r
.29739 .94967 m .30376 .95052 L .3041 .95643 L p F P
0 g
s
.696 .427 .512 r
.39393 .97847 m .38609 .97832 L .38481 .97322 L p F P
0 g
s
.697 .427 .512 r
.38032 .97312 m .38481 .97322 L .38609 .97832 L p F P
0 g
s
.721 .666 .795 r
.35733 .81428 m .35634 .81258 L .35416 .814 L closepath p F P
0 g
s
.87 .877 .838 r
.73884 .2326 m .73692 .23463 L .73729 .23909 L p F P
0 g
s
.864 .873 .842 r
.72995 .24174 m .73692 .23463 L .73729 .23909 L p F P
0 g
s
.864 .873 .842 r
.73037 .24572 m .72995 .24174 L p .73729 .23909 L F P
0 g
s
.864 .873 .842 r
.73729 .23909 m .73062 .24595 L .73037 .24572 L p F P
0 g
s
.677 .624 .788 r
.46677 .81274 m .46843 .81608 L p .45479 .81514 L F P
0 g
s
.677 .624 .788 r
.45479 .81514 m .45802 .81363 L .46677 .81274 L p F P
0 g
s
.678 .628 .792 r
.45479 .81514 m .45802 .81363 L .45422 .81399 L closepath p F P
0 g
s
.741 .663 .774 r
.30762 .83255 m .31186 .82918 L .30518 .82817 L closepath p F P
0 g
s
0 .166 .688 r
.6008 .2843 m .60144 .28789 L .5981 .28447 L p F P
0 g
s
0 .166 .688 r
.60031 .28325 m .6008 .2843 L p .5981 .28447 L F P
0 g
s
0 .166 .688 r
.5981 .28447 m .59758 .28005 L .60031 .28325 L p F P
0 g
s
.769 .643 .722 r
.26437 .87401 m .25877 .88084 L .26614 .88236 L p F P
0 g
s
.769 .643 .722 r
.26472 .87408 m .26437 .87401 L p .26614 .88236 L F P
0 g
s
.77 .639 .717 r
.25877 .88084 m .26614 .88236 L .26091 .88909 L p F P
0 g
s
.697 .427 .512 r
.38609 .97832 m .37967 .97818 L .38032 .97312 L p F P
0 g
s
.704 .434 .513 r
.37334 .97287 m .38032 .97312 L .37967 .97818 L p F P
0 g
s
.96 .828 .668 r
.59544 .20236 m .59726 .20645 L .59952 .20111 L p F P
0 g
s
.96 .828 .668 r
.59952 .20111 m .59765 .19703 L .59544 .20236 L p F P
0 g
s
.656 .593 .772 r
.51582 .83554 m .5152 .8341 L .50831 .83686 L closepath p F P
0 g
s
.658 .595 .774 r
.5123 .8274 m .5152 .8341 L .50831 .83686 L p F P
0 g
s
.658 .595 .774 r
.50154 .83176 m .5123 .8274 L p .50831 .83686 L F P
0 g
s
.946 .701 .235 r
.7789 .11798 m .78026 .12228 L .78017 .11782 L p F P
0 g
s
.946 .701 .235 r
.78017 .11782 m .77882 .11353 L .7789 .11798 L p F P
0 g
s
.7 .652 .798 r
.40896 .80535 m .41094 .80894 L p .39731 .80939 L F P
0 g
s
.7 .652 .798 r
.39731 .80939 m .40464 .80535 L .40896 .80535 L p F P
0 g
s
.701 .654 .799 r
.39731 .80939 m .40464 .80535 L .39502 .80531 L closepath p F P
0 g
s
.706 .656 .798 r
.39502 .80531 m .39731 .80939 L p .38366 .81015 L F P
0 g
s
.706 .656 .798 r
.38366 .81015 m .39221 .80524 L .39502 .80531 L p F P
0 g
s
.706 .657 .799 r
.38366 .81015 m .39221 .80524 L .38069 .80491 L closepath p F P
0 g
s
.748 .801 .896 r
.65065 .29945 m .64971 .29837 L .65056 .29788 L closepath p F P
0 g
s
.86 .784 .776 r
.619 .11997 m .62379 .11389 L .62643 .11779 L p F P
0 g
s
.86 .784 .776 r
.62643 .11779 m .62172 .12378 L .619 .11997 L p F P
0 g
s
.537 .615 .878 r
.6087 .29896 m .60906 .29895 L .60897 .29944 L closepath p F P
0 g
s
.603 .66 .879 r
.61973 .29751 m .60906 .29895 L .60897 .29944 L p F P
0 g
s
.603 .66 .879 r
.62245 .30131 m .61973 .29751 L p .60897 .29944 L F P
0 g
s
.735 .752 .866 r
.69254 .05723 m .6969 .05467 L .6943 .0507 L p F P
0 g
s
.735 .752 .866 r
.6943 .0507 m .68998 .05324 L .69254 .05723 L p F P
0 g
s
.733 .752 .867 r
.68334 .05709 m .68998 .05324 L .69254 .05723 L p F P
0 g
s
.903 .801 .738 r
.60494 .15744 m .60727 .16141 L .61082 .15562 L p F P
0 g
s
.903 .801 .738 r
.61082 .15562 m .60846 .15166 L .60494 .15744 L p F P
0 g
s
.822 .855 .872 r
.70489 .26914 m .70914 .26559 L .70662 .26307 L p F P
0 g
s
.822 .855 .872 r
.70662 .26307 m .70475 .26463 L .70489 .26914 L p F P
0 g
s
.817 .85 .873 r
.69581 .2719 m .70475 .26463 L .70489 .26914 L p F P
0 g
s
.739 .669 .782 r
.31579 .81985 m .31829 .82422 L .31186 .82918 L p F P
0 g
s
.739 .669 .782 r
.31424 .81961 m .31579 .81985 L p .31186 .82918 L F P
0 g
s
.739 .669 .782 r
.30454 .82708 m .31424 .81961 L p .31186 .82918 L F P
0 g
s
.739 .669 .782 r
.31186 .82918 m .30518 .82817 L .30454 .82708 L p F P
0 g
s
.629 .468 .645 r
.53226 .92756 m .5439 .9255 L p .53645 .93335 L F P
0 g
s
.629 .468 .645 r
.53645 .93335 m .53333 .9339 L .53226 .92756 L p F P
0 g
s
.632 .479 .657 r
.54265 .919 m .5439 .9255 L .53226 .92756 L p F P
0 g
s
.999 .842 .529 r
.77918 .14098 m .78037 .13602 L .78157 .14033 L p F P
0 g
s
.999 .842 .529 r
.77999 .14385 m .77918 .14098 L p .78157 .14033 L F P
0 g
s
.999 .842 .529 r
.78157 .14033 m .78071 .14391 L .77999 .14385 L p F P
0 g
s
.65 .411 .544 r
.47098 .96539 m .47458 .9651 L .47443 .97046 L p F P
0 g
s
.65 .411 .544 r
.47443 .97046 m .47157 .97069 L .47098 .96539 L p F P
0 g
s
.973 .765 .338 r
.59244 .25574 m .59324 .25856 L .59359 .25387 L p F P
0 g
s
.973 .765 .338 r
.59359 .25387 m .59315 .25233 L .59244 .25574 L p F P
0 g
s
.695 .647 .798 r
.42255 .80507 m .42458 .8088 L p .41094 .80894 L F P
0 g
s
.695 .647 .798 r
.41094 .80894 m .41809 .80517 L .42255 .80507 L p F P
0 g
s
.696 .649 .8 r
.41094 .80894 m .41809 .80517 L .40896 .80535 L closepath p F P
0 g
s
.712 .664 .801 r
.38053 .80491 m .37001 .81122 L .36697 .80598 L p F P
0 g
s
.723 .664 .791 r
.34266 .81431 m .3445 .81309 L .35416 .814 L p F P
0 g
s
.723 .669 .796 r
.35329 .80742 m .3445 .81309 L .35416 .814 L p F P
0 g
s
.723 .669 .796 r
.35416 .814 m .35634 .81258 L .35329 .80742 L p F P
0 g
s
.766 .649 .733 r
.2707 .86698 m .26458 .87378 L .26151 .86737 L p F P
0 g
s
.766 .649 .733 r
.26151 .86737 m .26321 .86548 L .2707 .86698 L p F P
0 g
s
.764 .653 .739 r
.26992 .85834 m .26321 .86548 L .2707 .86698 L p F P
0 g
s
.764 .653 .739 r
.27408 .8592 m .26992 .85834 L p .2707 .86698 L F P
0 g
s
.678 .634 .799 r
.45802 .81363 m .45422 .81399 L .45185 .80945 L p F P
0 g
s
.759 .55 .614 r
.29739 .94967 m .28887 .94851 L .2907 .94267 L p F P
0 g
s
.76 .551 .615 r
.28632 .94205 m .2907 .94267 L .28887 .94851 L p F P
0 g
s
.658 .596 .774 r
.51193 .82656 m .5123 .8274 L .50154 .83176 L p F P
0 g
s
.658 .596 .774 r
.50154 .83176 m .50015 .82858 L .51193 .82656 L p F P
0 g
s
.976 .847 .648 r
.5935 .21589 m .59509 .21177 L .59664 .21594 L p F P
0 g
s
.976 .847 .648 r
.59664 .21594 m .59619 .2171 L .5935 .21589 L p F P
0 g
s
.629 .487 .671 r
.54136 .913 m .5436 .91188 L .54122 .91235 L closepath p F P
0 g
s
.664 .605 .779 r
.49589 .81926 m .49863 .82526 L p .48499 .82347 L F P
0 g
s
.664 .605 .779 r
.48499 .82347 m .4943 .8195 L .49589 .81926 L p F P
0 g
s
.666 .61 .783 r
.48499 .82347 m .4943 .8195 L .48385 .82102 L closepath p F P
0 g
s
.831 .856 .865 r
.71418 .2612 m .70914 .26559 L .70662 .26307 L p F P
0 g
s
.65 .582 .766 r
.52888 .83697 m .53093 .84195 L .5194 .84421 L p F P
0 g
s
.65 .582 .766 r
.5194 .84421 m .5181 .84106 L .52888 .83697 L p F P
0 g
s
.772 .623 .696 r
.25959 .90295 m .26356 .89719 L .25703 .89593 L closepath p F P
0 g
s
.77 .631 .707 r
.25661 .8949 m .26091 .88909 L p .26356 .89719 L F P
0 g
s
.77 .631 .707 r
.26356 .89719 m .25703 .89593 L .25661 .8949 L p F P
0 g
s
.64 .421 .569 r
.49235 .95775 m .4993 .95696 L .49945 .96254 L p F P
0 g
s
.64 .421 .569 r
.49945 .96254 m .49131 .96346 L .49235 .95775 L p F P
0 g
s
.728 .476 .546 r
.34165 .97109 m .33558 .97064 L .33594 .96531 L p F P
0 g
s
.736 .482 .546 r
.33172 .96493 m .33594 .96531 L .33558 .97064 L p F P
0 g
s
.857 .873 .85 r
.73062 .24595 m .7304 .24617 L .73037 .24572 L closepath p F P
0 g
s
.844 .865 .858 r
.72226 .24912 m .72263 .25356 L .7304 .24617 L p F P
0 g
s
.844 .865 .858 r
.72815 .24352 m .72226 .24912 L p .7304 .24617 L F P
0 g
s
.844 .865 .858 r
.7304 .24617 m .73037 .24572 L .72815 .24352 L p F P
0 g
s
.5 .587 .873 r
.60906 .29895 m .6087 .29896 L .60592 .29403 L p F P
0 g
s
.704 .434 .513 r
.37967 .97818 m .3745 .97799 L .37334 .97287 L p F P
0 g
s
.705 .435 .513 r
.36578 .97258 m .37334 .97287 L .3745 .97799 L p F P
0 g
s
.662 .398 .51 r
.43557 .97286 m .43783 .97277 L .43964 .97775 L p F P
0 g
s
.662 .398 .51 r
.43964 .97775 m .43503 .97795 L .43557 .97286 L p F P
0 g
s
.943 .888 .747 r
.76654 .18707 m .77008 .18121 L .77092 .18558 L p F P
0 g
s
.943 .888 .747 r
.7671 .1899 m .76654 .18707 L p .77092 .18558 L F P
0 g
s
.943 .888 .747 r
.77092 .18558 m .76792 .19055 L .7671 .1899 L p F P
0 g
s
.628 .487 .67 r
.54265 .919 m .54136 .913 L .5436 .91188 L p F P
0 g
s
.835 .86 .863 r
.71418 .2612 m .7199 .2561 L .71741 .25362 L p F P
0 g
s
.835 .86 .863 r
.71741 .25362 m .71392 .25672 L .71418 .2612 L p F P
0 g
s
.831 .856 .865 r
.70662 .26307 m .71392 .25672 L .71418 .2612 L p F P
0 g
s
.916 .89 .791 r
.75994 .20753 m .75953 .20809 L .7594 .20708 L closepath p F P
0 g
s
.66 .397 .511 r
.43783 .97277 m .44873 .97225 L .44822 .97734 L p F P
0 g
s
.66 .397 .511 r
.44822 .97734 m .43964 .97775 L .43783 .97277 L p F P
0 g
s
.763 .659 .747 r
.27408 .8592 m .27235 .85586 L .26992 .85834 L closepath p F P
0 g
s
.881 .793 .758 r
.61116 .13909 m .61325 .13608 L .61575 .14001 L p F P
0 g
s
.881 .793 .758 r
.61575 .14001 m .61388 .14269 L .61116 .13909 L p F P
0 g
s
.843 .861 .857 r
.71741 .25362 m .72226 .24912 L .72263 .25356 L p F P
0 g
s
.843 .861 .857 r
.72263 .25356 m .7199 .2561 L .71741 .25362 L p F P
0 g
s
.45 .605 .913 r
.74494 .06119 m .74071 .0608 L .73816 .05668 L p F P
0 g
s
.5 .587 .873 r
.60592 .29403 m .60958 .2942 L .60906 .29895 L p F P
0 g
s
.571 .679 .913 r
.61699 .29359 m .60958 .2942 L .60906 .29895 L p F P
0 g
s
.571 .679 .913 r
.60906 .29895 m .61973 .29751 L .61699 .29359 L p F P
0 g
s
.77 .822 .893 r
.66864 .29137 m .6741 .28778 L .67151 .28498 L p F P
0 g
s
.77 .822 .893 r
.67151 .28498 m .66867 .28682 L .66864 .29137 L p F P
0 g
s
.769 .817 .89 r
.66061 .29196 m .66867 .28682 L .66864 .29137 L p F P
0 g
s
.718 .668 .8 r
.36697 .80598 m .35634 .81258 L .35329 .80742 L p F P
0 g
s
.9 .883 .808 r
.75389 .21008 m .75451 .21449 L .75953 .20809 L p F P
0 g
s
.9 .883 .808 r
.75756 .20539 m .75389 .21008 L p .75953 .20809 L F P
0 g
s
.9 .883 .808 r
.75953 .20809 m .7594 .20708 L .75756 .20539 L p F P
0 g
s
.689 .642 .797 r
.43581 .80447 m .43821 .80897 L p .42458 .8088 L F P
0 g
s
.689 .642 .797 r
.42458 .8088 m .43288 .80462 L .43581 .80447 L p F P
0 g
s
.69 .645 .8 r
.42458 .8088 m .43288 .80462 L .42255 .80507 L closepath p F P
0 g
s
.643 .405 .543 r
.47443 .97046 m .47458 .9651 L .48711 .96391 L p F P
0 g
s
.748 .51 .572 r
.32025 .96386 m .31311 .96307 L .31373 .95751 L p F P
0 g
s
.747 .511 .573 r
.30472 .9565 m .31373 .95751 L .31311 .96307 L p F P
0 g
s
.677 .631 .796 r
.46677 .81274 m .46549 .81024 L .45802 .81363 L closepath p F P
0 g
s
.678 .634 .799 r
.46255 .80457 m .46549 .81024 L .45802 .81363 L p F P
0 g
s
.678 .634 .799 r
.45185 .80945 m .46255 .80457 L p .45802 .81363 L F P
0 g
s
.635 .535 .724 r
.54338 .87644 m .54267 .87419 L .55399 .87174 L p F P
0 g
s
.637 .544 .733 r
.5514 .86401 m .55399 .87174 L .54267 .87419 L p F P
0 g
s
.637 .544 .733 r
.54891 .86455 m .5514 .86401 L p .54267 .87419 L F P
0 g
s
.637 .544 .733 r
.54267 .87419 m .54048 .86765 L .54891 .86455 L p F P
0 g
s
0 0 .412 r
.59672 .27574 m .59758 .28005 L .59583 .27608 L p F P
0 g
s
0 0 .412 r
.59583 .27608 m .59509 .27172 L .59672 .27574 L p F P
0 g
s
.634 .534 .724 r
.54505 .88173 m .54338 .87644 L .5542 .87241 L p F P
0 g
s
.635 .535 .724 r
.55399 .87174 m .5542 .87241 L .54338 .87644 L p F P
0 g
s
.735 .666 .782 r
.31829 .82422 m .32287 .82082 L .31579 .81985 L closepath p F P
0 g
s
.705 .435 .513 r
.3745 .97799 m .36509 .97764 L .36578 .97258 L p F P
0 g
s
.713 .442 .514 r
.36231 .9724 m .36578 .97258 L .36509 .97764 L p F P
0 g
s
.634 .534 .724 r
.5542 .87241 m .55637 .87928 L .54505 .88173 L p F P
0 g
s
.632 .525 .715 r
.54629 .88589 m .54505 .88173 L .55637 .87928 L p F P
0 g
s
.947 .816 .682 r
.59994 .19168 m .60111 .18905 L .59839 .18645 L p F P
0 g
s
.981 .829 .618 r
.59487 .22112 m .59619 .2171 L .5935 .21589 L p F P
0 g
s
.855 .865 .847 r
.73037 .24572 m .72815 .24352 L .72995 .24174 L closepath p F P
0 g
s
.645 .714 .898 r
.71053 .05358 m .7217 .05004 L .72426 .05405 L p F P
0 g
s
.646 .715 .898 r
.7217 .05004 m .71053 .05358 L .70795 .0496 L p F P
0 g
s
.697 .738 .883 r
.6969 .05467 m .70795 .0496 L .71053 .05358 L p F P
0 g
s
.65 .583 .766 r
.52736 .83327 m .52888 .83697 L .5181 .84106 L p F P
0 g
s
.65 .583 .766 r
.5181 .84106 m .51582 .83554 L .52736 .83327 L p F P
0 g
s
.672 .62 .789 r
.46843 .81608 m .47914 .81132 L .48207 .81734 L p F P
0 g
s
.673 .623 .791 r
.47911 .81126 m .47914 .81132 L .46843 .81608 L p F P
0 g
s
.673 .623 .791 r
.46843 .81608 m .46677 .81274 L .47911 .81126 L p F P
0 g
s
.985 .875 .641 r
.77657 .15575 m .77762 .16009 L .77967 .1548 L p F P
0 g
s
.985 .875 .641 r
.77967 .1548 m .77864 .15045 L .77657 .15575 L p F P
0 g
s
.769 .65 .731 r
.26472 .87408 m .26458 .87378 L .26437 .87401 L closepath p F P
0 g
s
.736 .482 .546 r
.33558 .97064 m .33182 .9703 L .33172 .96493 L p F P
0 g
s
.736 .483 .545 r
.32221 .96405 m .33172 .96493 L .33182 .9703 L p F P
0 g
s
.637 .544 .733 r
.54048 .86765 m .54891 .86455 L .54008 .86646 L closepath p F P
0 g
s
.638 .553 .741 r
.54891 .86455 m .54008 .86646 L .53757 .85939 L p F P
0 g
s
.632 .525 .714 r
.54724 .88908 m .54629 .88589 L .55712 .8818 L p F P
0 g
s
.632 .525 .715 r
.55637 .87928 m .55712 .8818 L .54629 .88589 L p F P
0 g
s
.77 .651 .731 r
.26437 .87401 m .26458 .87378 L .26151 .86737 L p F P
0 g
s
.666 .617 .79 r
.4943 .8195 m .48385 .82102 L .48207 .81734 L p F P
0 g
s
.964 .883 .702 r
.77339 .16925 m .77524 .16551 L .77622 .16985 L p F P
0 g
s
.964 .883 .702 r
.77622 .16985 m .7757 .17091 L .77339 .16925 L p F P
0 g
s
.628 .487 .67 r
.5436 .91188 m .55268 .91009 L p .54265 .919 L F P
0 g
s
.631 .498 .683 r
.55268 .91009 m .55216 .9079 L .5436 .91188 L closepath p F P
0 g
s
.632 .5 .683 r
.55105 .90325 m .55216 .9079 L .5436 .91188 L p F P
0 g
s
.872 .591 .067 r
.77738 .10925 m .77882 .11353 L .77822 .10927 L p F P
0 g
s
.872 .591 .067 r
.77822 .10927 m .77678 .10499 L .77738 .10925 L p F P
0 g
s
.659 .603 .782 r
.50939 .82099 m .51193 .82656 L .50015 .82858 L p F P
0 g
s
.659 .603 .782 r
.50015 .82858 m .49863 .82526 L .50939 .82099 L p F P
0 g
s
.771 .646 .724 r
.25712 .87244 m .26437 .87401 L .25877 .88084 L p F P
0 g
s
.77 .651 .731 r
.26151 .86737 m .25712 .87244 L .26437 .87401 L p F P
0 g
s
.996 .834 .563 r
.59202 .23125 m .59347 .23543 L .59484 .23038 L p F P
0 g
s
.996 .834 .563 r
.59484 .23038 m .59335 .22621 L .59202 .23125 L p F P
0 g
s
.713 .442 .514 r
.36509 .97764 m .36337 .97755 L .36231 .9724 L p F P
0 g
s
.714 .442 .512 r
.3517 .97182 m .36231 .9724 L .36337 .97755 L p F P
0 g
s
.697 .738 .883 r
.70795 .0496 m .6969 .05467 L .6943 .0507 L p F P
0 g
s
.758 .535 .594 r
.3041 .95643 m .29616 .95536 L .29739 .94967 L p F P
0 g
s
.758 .535 .595 r
.28887 .94851 m .29739 .94967 L .29616 .95536 L p F P
0 g
s
.772 .632 .706 r
.25661 .8949 m .26091 .88909 L .25372 .88764 L closepath p F P
0 g
s
.77 .639 .717 r
.25361 .88738 m .25877 .88084 L p .26091 .88909 L F P
0 g
s
.77 .639 .717 r
.26091 .88909 m .25372 .88764 L .25361 .88738 L p F P
0 g
s
.63 .516 .705 r
.54922 .89613 m .54724 .88908 L .55855 .88663 L p F P
0 g
s
.632 .525 .714 r
.55712 .8818 m .55855 .88663 L .54724 .88908 L p F P
0 g
s
.636 .519 .704 r
.54724 .88908 m .54922 .89613 L .5486 .89639 L p F P
0 g
s
.632 .431 .592 r
.51104 .94963 m .52105 .94821 L .51758 .95455 L p F P
0 g
s
.632 .431 .592 r
.51758 .95455 m .51145 .95542 L .51104 .94963 L p F P
0 g
s
.638 .435 .592 r
.51104 .94963 m .51145 .95542 L .4993 .95696 L p F P
0 g
s
.76 .551 .615 r
.28887 .94851 m .28702 .94825 L .28632 .94205 L p F P
0 g
s
.767 .556 .613 r
.28243 .94144 m .28632 .94205 L .28702 .94825 L p F P
0 g
s
.685 .64 .8 r
.44877 .80359 m .4489 .80383 L .43821 .80897 L p F P
0 g
s
.685 .64 .8 r
.43821 .80897 m .43581 .80447 L .44877 .80359 L p F P
0 g
s
.684 .638 .798 r
.43821 .80897 m .4489 .80383 L .45185 .80945 L p F P
0 g
s
.724 .665 .792 r
.34266 .81431 m .3445 .81309 L .34179 .81282 L closepath p F P
0 g
s
.729 .669 .791 r
.34179 .81282 m .34266 .81431 L p .32895 .81645 L F P
0 g
s
.898 .792 .735 r
.61194 .1459 m .61388 .14269 L .61116 .13909 L p F P
0 g
s
.878 .785 .755 r
.6215 .12409 m .62172 .12378 L .619 .11997 L p F P
0 g
s
.754 .661 .758 r
.28312 .84545 m .28518 .84355 L .28178 .84293 L closepath p F P
0 g
s
.752 .667 .767 r
.28617 .83439 m .29385 .83587 L .28518 .84355 L p F P
0 g
s
.752 .667 .767 r
.28003 .83981 m .28617 .83439 L p .28518 .84355 L F P
0 g
s
.752 .667 .767 r
.28518 .84355 m .28178 .84293 L .28003 .83981 L p F P
0 g
s
.758 .662 .756 r
.27725 .85103 m .28312 .84545 L .28178 .84293 L p F P
0 g
s
.769 .594 .661 r
.26536 .92195 m .26675 .91926 L p .27142 .9268 L F P
0 g
s
.772 .595 .66 r
.26536 .92195 m .26675 .91926 L .26458 .91888 L closepath p F P
0 g
s
.77 .604 .673 r
.26251 .91176 m .26262 .91157 L p .26675 .91926 L F P
0 g
s
.77 .604 .673 r
.26675 .91926 m .26458 .91888 L .26251 .91176 L p F P
0 g
s
.733 .671 .79 r
.32587 .81122 m .32895 .81645 L .32287 .82082 L p F P
0 g
s
.733 .671 .79 r
.31522 .81888 m .32587 .81122 L p .32287 .82082 L F P
0 g
s
.733 .671 .79 r
.32287 .82082 m .31579 .81985 L .31522 .81888 L p F P
0 g
s
.279 .482 .878 r
.75491 .06712 m .75434 .06692 L .75619 .07112 L p F P
0 g
s
.279 .482 .878 r
.75619 .07112 m .75746 .07159 L .75491 .06712 L p F P
0 g
s
.653 .391 .51 r
.44873 .97225 m .45384 .97194 L .45583 .97689 L p F P
0 g
s
.653 .391 .51 r
.45583 .97689 m .44822 .97734 L .44873 .97225 L p F P
0 g
s
.768 .582 .646 r
.27664 .9342 m .26865 .93289 L .27142 .9268 L p F P
0 g
s
.77 .584 .647 r
.26637 .92595 m .27142 .9268 L .26865 .93289 L p F P
0 g
s
.769 .594 .661 r
.27142 .9268 m .26637 .92595 L .26536 .92195 L p F P
0 g
s
.878 .785 .755 r
.619 .11997 m .61885 .12019 L .6215 .12409 L p F P
0 g
s
.879 .785 .753 r
.61476 .12618 m .61742 .13007 L .6215 .12409 L p F P
0 g
s
.879 .785 .753 r
.6215 .12409 m .61885 .12019 L .61476 .12618 L p F P
0 g
s
.629 .443 .612 r
.52282 .94603 m .52722 .94117 L .52238 .94194 L closepath p F P
0 g
s
.636 .448 .612 r
.52238 .94194 m .52282 .94603 L .52105 .94821 L p F P
0 g
s
.962 .887 .709 r
.77333 .17546 m .7757 .17091 L .77339 .16925 L p F P
0 g
s
.758 .662 .756 r
.27756 .84207 m .26966 .84954 L .27725 .85103 L p F P
0 g
s
.758 .662 .756 r
.28178 .84293 m .27756 .84207 L p .27725 .85103 L F P
0 g
s
.76 .658 .75 r
.27725 .85103 m .27235 .85586 L .26926 .84994 L p F P
0 g
s
.76 .658 .75 r
.26926 .84994 m .26966 .84954 L .27725 .85103 L p F P
0 g
s
.751 .669 .77 r
.29386 .83587 m .29385 .83586 L .29385 .83587 L closepath p F P
0 g
s
.752 .671 .772 r
.29075 .83048 m .28617 .83439 L .29385 .83587 L p F P
0 g
s
.752 .671 .772 r
.29385 .83587 m .29385 .83586 L .29075 .83048 L p F P
0 g
s
.748 .67 .775 r
.30353 .82789 m .29385 .83586 L .29075 .83048 L p F P
0 g
s
.639 .553 .742 r
.53757 .85939 m .54398 .85707 L .53727 .85852 L closepath p F P
0 g
s
.638 .553 .741 r
.53757 .85939 m .54398 .85707 L p .54891 .86455 L F P
0 g
s
.773 .606 .672 r
.26251 .91176 m .26262 .91157 L .26245 .91154 L closepath p F P
0 g
s
.771 .614 .685 r
.26262 .91157 m .26245 .91154 L .25993 .90389 L p F P
0 g
s
.722 .671 .799 r
.35056 .80284 m .35329 .80742 L .3445 .81309 L p F P
0 g
s
.722 .671 .799 r
.34956 .80274 m .35056 .80284 L p .3445 .81309 L F P
0 g
s
.722 .671 .799 r
.33959 .80917 m .34956 .80274 L p .3445 .81309 L F P
0 g
s
.722 .671 .799 r
.3445 .81309 m .34179 .81282 L .33959 .80917 L p F P
0 g
s
.636 .519 .704 r
.54926 .89626 m .54922 .89613 L .5486 .89639 L closepath p F P
0 g
s
.777 .608 .67 r
.26245 .91154 m .25521 .91007 L p .25916 .91782 L F P
0 g
s
.777 .608 .67 r
.25916 .91782 m .26251 .91176 L .26245 .91154 L p F P
0 g
s
.777 .617 .682 r
.25908 .90371 m .25993 .90389 L .26245 .91154 L p F P
0 g
s
.777 .617 .682 r
.26245 .91154 m .25521 .91007 L .25908 .90371 L p F P
0 g
s
.64 .562 .75 r
.54398 .85707 m .53727 .85852 L .53468 .85157 L p F P
0 g
s
.776 .607 .67 r
.26458 .91888 m .26251 .91176 L .25916 .91782 L closepath p F P
0 g
s
.633 .415 .569 r
.49945 .96254 m .4993 .95696 L .51145 .95542 L p F P
0 g
s
.747 .797 .893 r
.65056 .29788 m .64971 .29837 L .64705 .29525 L p F P
0 g
s
.718 .789 .907 r
.63611 .30064 m .64705 .29525 L .64971 .29837 L p F P
0 g
s
.785 .829 .886 r
.6827 .28174 m .6741 .28778 L .67151 .28498 L p F P
0 g
s
.745 .671 .778 r
.30518 .82817 m .30454 .82708 L .30353 .82789 L closepath p F P
0 g
s
.768 .57 .63 r
.28243 .94144 m .27438 .94015 L .27664 .9342 L p F P
0 g
s
.769 .571 .631 r
.26865 .93289 m .27664 .9342 L .27438 .94015 L p F P
0 g
s
.764 .66 .748 r
.26992 .85834 m .27235 .85586 L .26926 .84994 L p F P
0 g
s
.775 .625 .693 r
.25993 .90389 m .25959 .90295 L .25908 .90371 L closepath p F P
0 g
s
.908 .881 .796 r
.7594 .20708 m .75756 .20539 L .75884 .20369 L closepath p F P
0 g
s
.625 .476 .659 r
.54265 .919 m .55412 .91674 L p .55124 .92407 L F P
0 g
s
.625 .476 .659 r
.55124 .92407 m .5439 .9255 L .54265 .919 L p F P
0 g
s
.628 .487 .67 r
.55268 .91009 m .55412 .91674 L .54265 .919 L p F P
0 g
s
.629 .515 .705 r
.54926 .89626 m .54922 .89613 L .56005 .89198 L p F P
0 g
s
.63 .516 .705 r
.55855 .88663 m .56005 .89198 L .54922 .89613 L p F P
0 g
s
.776 .625 .694 r
.25908 .90371 m .25959 .90295 L .25703 .89593 L p F P
0 g
s
.627 .504 .694 r
.55105 .90325 m .54926 .89626 L .56056 .89381 L p F P
0 g
s
.629 .515 .705 r
.56005 .89198 m .56056 .89381 L .54926 .89626 L p F P
0 g
s
.695 .655 .807 r
.41809 .80517 m .40896 .80535 L .40795 .80358 L p F P
0 g
s
.699 .657 .805 r
.40896 .80535 m .40795 .80358 L .40464 .80535 L closepath p F P
0 g
s
.7 .659 .806 r
.40495 .79842 m .40795 .80358 L .40464 .80535 L p F P
0 g
s
.7 .659 .806 r
.3943 .80407 m .40495 .79842 L p .40464 .80535 L F P
0 g
s
.7 .659 .806 r
.40464 .80535 m .39502 .80531 L .3943 .80407 L p F P
0 g
s
.74 .427 0 r
.77526 .10073 m .77678 .10499 L .77561 .10097 L p F P
0 g
s
.74 .427 0 r
.77561 .10097 m .77408 .0967 L .77526 .10073 L p F P
0 g
s
.745 .798 .895 r
.65056 .29788 m .66061 .29196 L .65798 .28898 L p F P
0 g
s
.745 .798 .895 r
.65798 .28898 m .65019 .29347 L .65056 .29788 L p F P
0 g
s
.747 .797 .893 r
.64705 .29525 m .65019 .29347 L .65056 .29788 L p F P
0 g
s
.765 .657 .744 r
.26258 .85678 m .26992 .85834 L .26321 .86548 L p F P
0 g
s
.764 .66 .748 r
.26926 .84994 m .26258 .85678 L .26992 .85834 L p F P
0 g
s
.651 .39 .511 r
.45384 .97194 m .46168 .97144 L .4612 .97655 L p F P
0 g
s
.651 .39 .511 r
.4612 .97655 m .45583 .97689 L .45384 .97194 L p F P
0 g
s
.998 .813 .463 r
.77908 .13172 m .78037 .13602 L .78116 .13122 L p F P
0 g
s
.998 .813 .463 r
.78116 .13122 m .77988 .12691 L .77908 .13172 L p F P
0 g
s
.579 .683 .911 r
.72787 .05348 m .72426 .05405 L .7217 .05004 L p F P
0 g
s
.705 .661 .804 r
.39502 .80531 m .3943 .80407 L .39221 .80524 L closepath p F P
0 g
s
.897 .881 .81 r
.74859 .21659 m .75389 .21008 L .75451 .21449 L p F P
0 g
s
.897 .881 .81 r
.74919 .22052 m .74859 .21659 L p .75451 .21449 L F P
0 g
s
.897 .881 .81 r
.75451 .21449 m .74945 .22075 L .74919 .22052 L p F P
0 g
s
.776 .598 .658 r
.26458 .91888 m .25916 .91782 L p .26362 .92543 L F P
0 g
s
.776 .598 .658 r
.26362 .92543 m .26536 .92195 L .26458 .91888 L p F P
0 g
s
.928 .81 .709 r
.59843 .17815 m .60059 .18215 L .60349 .17659 L p F P
0 g
s
.928 .81 .709 r
.60349 .17659 m .60129 .1726 L .59843 .17815 L p F P
0 g
s
.952 .77 .314 r
.59216 .25429 m .59244 .25574 L .59315 .25233 L p F P
0 g
s
.952 .77 .314 r
.59315 .25233 m .59262 .24955 L .59216 .25429 L p F P
0 g
s
.729 .669 .791 r
.32895 .81645 m .33531 .81204 L .34179 .81282 L p F P
0 g
s
.728 .673 .796 r
.34179 .81282 m .33959 .80917 L .33531 .81204 L closepath p F P
0 g
s
.778 .619 .684 r
.25177 .90218 m .25908 .90371 L .25521 .91007 L p F P
0 g
s
.776 .625 .694 r
.25603 .89572 m .25177 .90218 L .25908 .90371 L p F P
0 g
s
.776 .625 .694 r
.25703 .89593 m .25603 .89572 L p .25908 .90371 L F P
0 g
s
.659 .604 .782 r
.50768 .81723 m .50939 .82099 L .49863 .82526 L p F P
0 g
s
.659 .604 .782 r
.49863 .82526 m .49589 .81926 L .50768 .81723 L p F P
0 g
s
.651 .59 .774 r
.52599 .83008 m .52736 .83327 L .51582 .83554 L p F P
0 g
s
.651 .59 .774 r
.51582 .83554 m .5152 .8341 L .52599 .83008 L p F P
0 g
s
.705 .663 .806 r
.39128 .79897 m .3943 .80407 L .39221 .80524 L p F P
0 g
s
.705 .663 .806 r
.38064 .80484 m .39128 .79897 L p .39221 .80524 L F P
0 g
s
.705 .663 .806 r
.39221 .80524 m .38069 .80491 L .38064 .80484 L p F P
0 g
s
.905 .803 .737 r
.60338 .16004 m .60494 .15744 L .60727 .16141 L p F P
0 g
s
.905 .803 .737 r
.60727 .16141 m .60611 .16334 L .60338 .16004 L p F P
0 g
s
.939 .891 .756 r
.76792 .19055 m .76736 .19144 L .7671 .1899 L closepath p F P
0 g
s
.947 .816 .682 r
.59839 .18645 m .59785 .18767 L .59994 .19168 L p F P
0 g
s
.952 .815 .672 r
.5956 .19301 m .59765 .19703 L .59994 .19168 L p F P
0 g
s
.952 .815 .672 r
.59994 .19168 m .59785 .18767 L .5956 .19301 L p F P
0 g
s
.678 .635 .8 r
.46255 .80457 m .45185 .80945 L .4489 .80383 L p F P
0 g
s
.814 .545 0 r
.59369 .26615 m .59406 .26745 L .59335 .26311 L p F P
0 g
s
0 0 .278 r
.59406 .26745 m .59369 .26615 L .59386 .2667 L p F P
0 g
s
.763 .515 0 r
.59488 .27047 m .59433 .2674 L p .59406 .26745 L F P
0 g
s
0 0 .278 r
.59386 .2667 m .59458 .26893 L .59406 .26745 L p F P
0 g
s
.763 .515 0 r
.59406 .26745 m .59509 .27172 L .59488 .27047 L p F P
0 g
s
.763 .515 0 r
.59433 .2674 m .59335 .26311 L .59406 .26745 L p F P
0 g
s
.994 .816 .447 r
.59151 .24527 m .59262 .24955 L .59349 .24467 L p F P
0 g
s
.994 .816 .447 r
.59349 .24467 m .59233 .2404 L .59151 .24527 L p F P
0 g
s
.714 .442 .512 r
.36337 .97755 m .35279 .97696 L .3517 .97182 L p F P
0 g
s
.715 .442 .512 r
.35088 .97177 m .3517 .97182 L .35279 .97696 L p F P
0 g
s
.694 .653 .805 r
.42255 .80507 m .4216 .80338 L .41809 .80517 L closepath p F P
0 g
s
.695 .655 .807 r
.41861 .79816 m .4216 .80338 L .41809 .80517 L p F P
0 g
s
.695 .655 .807 r
.40795 .80358 m .41861 .79816 L p .41809 .80517 L F P
0 g
s
.672 .629 .798 r
.47621 .80561 m .47911 .81126 L .46677 .81274 L p F P
0 g
s
.672 .629 .798 r
.46677 .81274 m .46549 .81024 L .47621 .80561 L p F P
0 g
s
.748 .67 .775 r
.29075 .83048 m .29562 .82647 L .30353 .82789 L p F P
0 g
s
.746 .673 .78 r
.30145 .82182 m .29562 .82647 L .30353 .82789 L p F P
0 g
s
.746 .673 .78 r
.30353 .82789 m .30454 .82708 L .30145 .82182 L p F P
0 g
s
.715 .442 .512 r
.35279 .97696 m .35015 .9768 L .35088 .97177 L p F P
0 g
s
.723 .45 .512 r
.34165 .97109 m .35088 .97177 L .35015 .9768 L p F P
0 g
s
.625 .453 .629 r
.53356 .9356 m .53645 .93335 L .53333 .9339 L closepath p F P
0 g
s
.633 .459 .629 r
.53333 .9339 m .53356 .9356 L .52722 .94117 L p F P
0 g
s
.729 .67 .792 r
.33531 .81204 m .32895 .81645 L .32587 .81122 L p F P
0 g
s
.742 .673 .783 r
.31424 .81961 m .30454 .82708 L .30145 .82182 L p F P
0 g
s
.118 .367 .828 r
.75746 .07159 m .76097 .07372 L .76282 .0779 L p F P
0 g
s
0 .222 .743 r
.76447 .07681 m .7663 .08101 L .76282 .0779 L p F P
0 g
s
0 .222 .743 r
.76282 .0779 m .76097 .07372 L .76447 .07681 L p F P
0 g
s
.767 .556 .613 r
.28702 .94825 m .28069 .94726 L .28243 .94144 L p F P
0 g
s
.768 .558 .614 r
.27438 .94015 m .28243 .94144 L .28069 .94726 L p F P
0 g
s
.773 .64 .715 r
.25877 .88084 m .25361 .88738 L .25057 .88039 L p F P
0 g
s
.773 .64 .715 r
.25057 .88039 m .25143 .87929 L .25877 .88084 L p F P
0 g
s
.771 .646 .724 r
.25877 .88084 m .25143 .87929 L .25712 .87244 L p F P
0 g
s
.689 .651 .807 r
.43288 .80462 m .42255 .80507 L .4216 .80338 L p F P
0 g
s
.666 .617 .79 r
.48207 .81734 m .49281 .81287 L p .4943 .8195 L F P
0 g
s
.666 .616 .789 r
.49281 .81287 m .48207 .81734 L .47914 .81132 L p F P
0 g
s
.998 .849 .538 r
.78071 .14391 m .78035 .14529 L .77999 .14385 L closepath p F P
0 g
s
.758 .669 .764 r
.28178 .84293 m .28003 .83981 L .27756 .84207 L closepath p F P
0 g
s
.922 .885 .779 r
.76246 .19313 m .76323 .19752 L .76736 .19144 L p F P
0 g
s
.922 .885 .779 r
.76557 .18856 m .76246 .19313 L p .76736 .19144 L F P
0 g
s
.922 .885 .779 r
.76736 .19144 m .7671 .1899 L .76557 .18856 L p F P
0 g
s
.775 .597 .658 r
.26637 .92595 m .26536 .92195 L .26362 .92543 L closepath p F P
0 g
s
.776 .633 .704 r
.25703 .89593 m .25661 .8949 L .25603 .89572 L closepath p F P
0 g
s
0 0 .381 r
.77247 .09246 m .77408 .0967 L .77225 .09294 L p F P
0 g
s
0 0 .381 r
.77225 .09294 m .77063 .08869 L .77247 .09246 L p F P
0 g
s
.651 .588 .771 r
.52599 .83008 m .5152 .8341 L .5123 .8274 L p F P
0 g
s
.64 .562 .75 r
.53468 .85157 m .54399 .84824 L p .54398 .85707 L F P
0 g
s
.641 .562 .751 r
.53468 .85157 m .54399 .84824 L .53422 .85036 L closepath p F P
0 g
s
.747 .511 .573 r
.30407 .96202 m .30472 .9565 L p .31311 .96307 L F P
0 g
s
.75 .513 .573 r
.30407 .96202 m .30472 .9565 L .3041 .95643 L closepath p F P
0 g
s
.898 .792 .735 r
.61116 .13909 m .60941 .14198 L .61194 .1459 L p F P
0 g
s
.899 .792 .734 r
.60594 .14775 m .60846 .15166 L .61194 .1459 L p F P
0 g
s
.899 .792 .734 r
.61194 .1459 m .60941 .14198 L .60594 .14775 L p F P
0 g
s
.736 .483 .545 r
.33182 .9703 m .3223 .96943 L .32221 .96405 L p F P
0 g
s
.737 .484 .545 r
.32025 .96386 m .32221 .96405 L .3223 .96943 L p F P
0 g
s
.965 .831 .66 r
.59332 .20767 m .59509 .21177 L .59726 .20645 L p F P
0 g
s
.965 .831 .66 r
.59726 .20645 m .59544 .20236 L .59332 .20767 L p F P
0 g
s
.776 .634 .704 r
.25603 .89572 m .25661 .8949 L .25372 .88764 L p F P
0 g
s
0 .019 .592 r
.76891 .08447 m .77063 .08869 L .76804 .08523 L p F P
0 g
s
0 .019 .592 r
.76804 .08523 m .7663 .08101 L .76891 .08447 L p F P
0 g
s
.71 .665 .803 r
.38069 .80491 m .38064 .80484 L .38053 .80491 L closepath p F P
0 g
s
.755 .517 .572 r
.3041 .95643 m .29616 .95536 L p .30407 .96206 L F P
0 g
s
.755 .517 .572 r
.30407 .96206 m .30407 .96202 L .3041 .95643 L p F P
0 g
s
.712 .664 .801 r
.36697 .80598 m .36979 .80431 L .38053 .80491 L p F P
0 g
s
.712 .669 .807 r
.37761 .7998 m .36979 .80431 L .38053 .80491 L p F P
0 g
s
.712 .669 .807 r
.38053 .80491 m .38064 .80484 L .37761 .7998 L p F P
0 g
s
.642 .57 .759 r
.54399 .84824 m .53422 .85036 L .53178 .84412 L p F P
0 g
s
.701 .663 .81 r
.40495 .79842 m .3943 .80407 L .39128 .79897 L p F P
0 g
s
.706 .667 .809 r
.39128 .79897 m .38064 .80484 L .37761 .7998 L p F P
0 g
s
.767 .651 .734 r
.26151 .86737 m .26321 .86548 L .26031 .86488 L closepath p F P
0 g
s
.765 .657 .744 r
.25843 .86118 m .26258 .85678 L p .26321 .86548 L F P
0 g
s
.765 .657 .744 r
.26321 .86548 m .26031 .86488 L .25843 .86118 L p F P
0 g
s
.12 .374 .833 r
.76097 .07372 m .75746 .07159 L .75491 .06712 L p F P
0 g
s
.636 .399 .542 r
.48711 .96391 m .49131 .96346 L .49208 .96872 L p F P
0 g
s
.636 .399 .542 r
.49208 .96872 m .48698 .96927 L .48711 .96391 L p F P
0 g
s
.643 .405 .543 r
.48711 .96391 m .48698 .96927 L .47443 .97046 L p F P
0 g
s
.778 .629 .695 r
.24882 .89415 m .25603 .89572 L .25177 .90218 L p F P
0 g
s
.776 .634 .704 r
.25346 .88758 m .24882 .89415 L .25603 .89572 L p F P
0 g
s
.776 .634 .704 r
.25372 .88764 m .25346 .88758 L p .25603 .89572 L F P
0 g
s
.629 .442 .612 r
.52722 .94117 m .53418 .94004 L p .52302 .94792 L F P
0 g
s
.629 .442 .612 r
.52302 .94792 m .52282 .94603 L .52722 .94117 L p F P
0 g
s
.631 .457 .628 r
.53418 .94004 m .53356 .9356 L .52722 .94117 L closepath p F P
0 g
s
.92 .8 .711 r
.60416 .16704 m .60611 .16334 L .60338 .16004 L p F P
0 g
s
.695 .659 .81 r
.41861 .79816 m .40795 .80358 L .40495 .79842 L p F P
0 g
s
.644 .384 .51 r
.46168 .97144 m .47157 .97069 L .47376 .97559 L p F P
0 g
s
.644 .384 .51 r
.47376 .97559 m .4612 .97655 L .46168 .97144 L p F P
0 g
s
.737 .484 .545 r
.3223 .96943 m .31985 .9692 L .32025 .96386 L p F P
0 g
s
.746 .491 .545 r
.31311 .96307 m .32025 .96386 L .31985 .9692 L p F P
0 g
s
.624 .495 .684 r
.55216 .9079 m .55105 .90325 L .56237 .90082 L p F P
0 g
s
.627 .504 .694 r
.56056 .89381 m .56237 .90082 L .55105 .90325 L p F P
0 g
s
.671 .756 .915 r
.62245 .30131 m .63343 .29727 L .63611 .30064 L p F P
0 g
s
.657 .746 .916 r
.63343 .29727 m .62245 .30131 L .61973 .29751 L p F P
0 g
s
.712 .665 .802 r
.36697 .80598 m .36979 .80431 L .36586 .80408 L closepath p F P
0 g
s
.718 .668 .8 r
.36586 .80408 m .36697 .80598 L p .35329 .80742 L F P
0 g
s
.77 .584 .647 r
.26865 .93289 m .26782 .93275 L .26637 .92595 L p F P
0 g
s
.777 .588 .645 r
.26362 .92543 m .26637 .92595 L .26782 .93275 L p F P
0 g
s
.771 .652 .731 r
.25712 .87244 m .26151 .86737 L .26031 .86488 L p F P
0 g
s
.712 .783 .908 r
.64705 .29525 m .63611 .30064 L .63343 .29727 L p F P
0 g
s
.739 .673 .787 r
.31579 .81985 m .31522 .81888 L .31424 .81961 L closepath p F P
0 g
s
.625 .452 .628 r
.53418 .94004 m .53356 .9356 L .53645 .93335 L p F P
0 g
s
.688 .648 .805 r
.43581 .80447 m .43525 .80346 L .43288 .80462 L closepath p F P
0 g
s
.689 .651 .807 r
.43227 .79818 m .43525 .80346 L .43288 .80462 L p F P
0 g
s
.689 .651 .807 r
.4216 .80338 m .43227 .79818 L p .43288 .80462 L F P
0 g
s
.79 .837 .887 r
.68497 .28013 m .6827 .28174 L .68272 .27777 L closepath p F P
0 g
s
.785 .829 .886 r
.68239 .27741 m .68272 .27777 L .6827 .28174 L p F P
0 g
s
.785 .829 .886 r
.67151 .28498 m .68239 .27741 L p .6827 .28174 L F P
0 g
s
.981 .829 .618 r
.5935 .21589 m .59313 .21702 L .59487 .22112 L p F P
0 g
s
.987 .825 .594 r
.59165 .22211 m .59335 .22621 L .59487 .22112 L p F P
0 g
s
.987 .825 .594 r
.59487 .22112 m .59313 .21702 L .59165 .22211 L p F P
0 g
s
.76 .538 .596 r
.28702 .94825 m .28887 .94851 L .2876 .95422 L p F P
0 g
s
.758 .535 .595 r
.29616 .95536 m .2876 .95422 L .28887 .94851 L p F P
0 g
s
.991 .866 .609 r
.77753 .14612 m .77864 .15045 L .78035 .14529 L p F P
0 g
s
.991 .866 .609 r
.7785 .14317 m .77753 .14612 L p .78035 .14529 L F P
0 g
s
.991 .866 .609 r
.78035 .14529 m .77999 .14385 L .7785 .14317 L p F P
0 g
s
.69 .654 .809 r
.43227 .79818 m .4216 .80338 L .41861 .79816 L p F P
0 g
s
.629 .468 .645 r
.5439 .9255 m .54434 .9281 L .53645 .93335 L p F P
0 g
s
.625 .452 .628 r
.53645 .93335 m .54496 .93182 L p .53418 .94004 L F P
0 g
s
.628 .466 .644 r
.54496 .93182 m .54434 .9281 L .53645 .93335 L closepath p F P
0 g
s
.672 .63 .798 r
.47621 .80561 m .46549 .81024 L .46255 .80457 L p F P
0 g
s
.892 .882 .817 r
.74945 .22075 m .74925 .22098 L .74919 .22052 L closepath p F P
0 g
s
.878 .785 .755 r
.61059 .1322 m .61325 .13608 L .61742 .13007 L p F P
0 g
s
.878 .785 .755 r
.61742 .13007 m .61476 .12618 L .61059 .1322 L p F P
0 g
s
.683 .646 .807 r
.44594 .79849 m .44877 .80359 L .43581 .80447 L p F P
0 g
s
.683 .646 .807 r
.43581 .80447 m .43525 .80346 L .44594 .79849 L p F P
0 g
s
.877 .874 .83 r
.74269 .22332 m .74327 .22774 L .74925 .22098 L p F P
0 g
s
.877 .874 .83 r
.74703 .21842 m .74269 .22332 L p .74925 .22098 L F P
0 g
s
.877 .874 .83 r
.74925 .22098 m .74919 .22052 L .74703 .21842 L p F P
0 g
s
.729 .67 .792 r
.32587 .81122 m .32628 .81094 L .33531 .81204 L p F P
0 g
s
.729 .675 .797 r
.33652 .80411 m .32628 .81094 L .33531 .81204 L p F P
0 g
s
.729 .675 .797 r
.33531 .81204 m .33959 .80917 L .33652 .80411 L p F P
0 g
s
.742 .673 .783 r
.30145 .82182 m .30609 .81826 L .31424 .81961 L p F P
0 g
s
.74 .676 .788 r
.31212 .81377 m .30609 .81826 L .31424 .81961 L p F P
0 g
s
.74 .676 .788 r
.31424 .81961 m .31522 .81888 L .31212 .81377 L p F P
0 g
s
.635 .447 .611 r
.52302 .94792 m .52282 .94603 L .52105 .94821 L closepath p F P
0 g
s
.962 .887 .709 r
.77339 .16925 m .77245 .17109 L .77333 .17546 L p F P
0 g
s
.95 .885 .734 r
.76916 .17685 m .77008 .18121 L .77333 .17546 L p F P
0 g
s
.95 .885 .734 r
.77333 .17546 m .77245 .17109 L .76916 .17685 L p F P
0 g
s
.718 .668 .8 r
.35329 .80742 m .35951 .80357 L .35056 .80284 L closepath p F P
0 g
s
.718 .668 .8 r
.35329 .80742 m .35951 .80357 L .36586 .80408 L p F P
0 g
s
.736 .676 .792 r
.32587 .81122 m .31522 .81888 L .31212 .81377 L p F P
0 g
s
.723 .45 .512 r
.35015 .9768 m .34264 .97625 L .34165 .97109 L p F P
0 g
s
.723 .45 .513 r
.33558 .97064 m .34165 .97109 L .34264 .97625 L p F P
0 g
s
.801 .839 .88 r
.69449 .27292 m .68497 .28013 L .68272 .27777 L p F P
0 g
s
.665 .614 .788 r
.49589 .81926 m .49572 .81891 L .4943 .8195 L closepath p F P
0 g
s
.666 .617 .79 r
.49281 .81287 m .49572 .81891 L .4943 .8195 L p F P
0 g
s
.986 .771 .373 r
.77852 .12263 m .77988 .12691 L .78026 .12228 L p F P
0 g
s
.986 .771 .373 r
.78026 .12228 m .7789 .11798 L .77852 .12263 L p F P
0 g
s
.633 .397 .543 r
.49131 .96346 m .49945 .96254 L .49933 .96791 L p F P
0 g
s
.633 .397 .543 r
.49933 .96791 m .49208 .96872 L .49131 .96346 L p F P
0 g
s
.711 .67 .809 r
.37457 .79479 m .37761 .7998 L .36979 .80431 L p F P
0 g
s
.711 .67 .809 r
.36393 .80092 m .37457 .79479 L p .36979 .80431 L F P
0 g
s
.711 .67 .809 r
.36979 .80431 m .36586 .80408 L .36393 .80092 L p F P
0 g
s
.776 .642 .713 r
.25372 .88764 m .25361 .88738 L .25346 .88758 L closepath p F P
0 g
s
.642 .57 .759 r
.53178 .84412 m .5426 .8403 L p .54399 .84824 L F P
0 g
s
.642 .571 .759 r
.54228 .83948 m .5426 .8403 L .53178 .84412 L p F P
0 g
s
.642 .571 .759 r
.53178 .84412 m .53093 .84195 L .54228 .83948 L p F P
0 g
s
.975 .877 .674 r
.77417 .16118 m .77524 .16551 L .77762 .16009 L p F P
0 g
s
.975 .877 .674 r
.77762 .16009 m .77657 .15575 L .77417 .16118 L p F P
0 g
s
.76 .538 .596 r
.2876 .95422 m .28736 .95419 L .28702 .94825 L p F P
0 g
s
.767 .543 .594 r
.28069 .94726 m .28702 .94825 L .28736 .95419 L p F P
0 g
s
.771 .652 .731 r
.26031 .86488 m .25596 .8639 L p .25712 .87244 L F P
0 g
s
.771 .659 .74 r
.26031 .86488 m .25843 .86118 L .25596 .8639 L closepath p F P
0 g
s
.776 .643 .714 r
.25346 .88758 m .25361 .88738 L .25057 .88039 L p F P
0 g
s
.622 .462 .644 r
.54434 .9281 m .55124 .92407 L .5439 .9255 L closepath p F P
0 g
s
.926 .689 .201 r
.59252 .26023 m .59335 .26311 L .59324 .25856 L p F P
0 g
s
.926 .689 .201 r
.59324 .25856 m .59244 .25574 L .59252 .26023 L p F P
0 g
s
.772 .649 .727 r
.24991 .87085 m .25712 .87244 L .25143 .87929 L p F P
0 g
s
.771 .652 .731 r
.25596 .8639 m .24991 .87085 L .25712 .87244 L p F P
0 g
s
.624 .494 .683 r
.55268 .91009 m .55216 .9079 L .563 .90346 L p F P
0 g
s
.624 .495 .684 r
.56237 .90082 m .563 .90346 L .55216 .9079 L p F P
0 g
s
.45 .563 .878 r
.60958 .2942 m .60592 .29403 L .60312 .28882 L p F P
0 g
s
.778 .637 .705 r
.24635 .88598 m .25346 .88758 L .24882 .89415 L p F P
0 g
s
.776 .643 .714 r
.25057 .88039 m .24635 .88598 L .25346 .88758 L p F P
0 g
s
.63 .428 .591 r
.52105 .94821 m .52302 .94792 L .52343 .9537 L p F P
0 g
s
.63 .428 .591 r
.52343 .9537 m .51758 .95455 L .52105 .94821 L p F P
0 g
s
.67 .377 .468 r
.4079 .97852 m .41109 .97849 L .41395 .98321 L p F P
0 g
s
.67 .377 .468 r
.41395 .98321 m .40691 .98328 L .4079 .97852 L p F P
0 g
s
.678 .385 .47 r
.39823 .97849 m .4079 .97852 L .40691 .98328 L p F P
0 g
s
.678 .385 .47 r
.40691 .98328 m .40087 .98326 L .39823 .97849 L p F P
0 g
s
.679 .385 .469 r
.39393 .97847 m .39823 .97849 L .40087 .98326 L p F P
0 g
s
.759 .667 .76 r
.27015 .84051 m .27756 .84207 L .26966 .84954 L p F P
0 g
s
.758 .67 .764 r
.27692 .83431 m .27015 .84051 L .27756 .84207 L p F P
0 g
s
.758 .67 .764 r
.27756 .84207 m .28003 .83981 L .27692 .83431 L p F P
0 g
s
.669 .377 .469 r
.41109 .97849 m .42159 .97834 L .42064 .98311 L p F P
0 g
s
.669 .377 .469 r
.42064 .98311 m .41395 .98321 L .41109 .97849 L p F P
0 g
s
.754 .668 .767 r
.28617 .83439 m .28003 .83981 L .27692 .83431 L p F P
0 g
s
.777 .59 .646 r
.25609 .92398 m .26362 .92543 L .261 .93147 L p F P
0 g
s
.777 .588 .645 r
.26782 .93275 m .261 .93147 L .26362 .92543 L p F P
0 g
s
.776 .598 .658 r
.25916 .91782 m .25609 .92398 L .26362 .92543 L p F P
0 g
s
.684 .65 .81 r
.44594 .79849 m .43525 .80346 L .43227 .79818 L p F P
0 g
s
.679 .385 .469 r
.40087 .98326 m .3929 .98322 L .39393 .97847 L p F P
0 g
s
.687 .393 .471 r
.38609 .97832 m .39393 .97847 L .3929 .98322 L p F P
0 g
s
.778 .601 .661 r
.2517 .91635 m .25916 .91782 L .25609 .92398 L p F P
0 g
s
.777 .608 .67 r
.25521 .91007 m .2517 .91635 L .25916 .91782 L p F P
0 g
s
.886 .873 .818 r
.74919 .22052 m .74703 .21842 L .74859 .21659 L closepath p F P
0 g
s
.659 .611 .789 r
.50649 .81472 m .50768 .81723 L .49589 .81926 L p F P
0 g
s
.659 .611 .789 r
.49589 .81926 m .49572 .81891 L .50649 .81472 L p F P
0 g
s
.716 .672 .806 r
.36586 .80408 m .36393 .80092 L .35951 .80357 L closepath p F P
0 g
s
.754 .668 .767 r
.27692 .83431 m .27852 .8329 L .28617 .83439 L p F P
0 g
s
.752 .672 .772 r
.28765 .8251 m .27852 .8329 L .28617 .83439 L p F P
0 g
s
.752 .672 .772 r
.28617 .83439 m .29075 .83048 L .28765 .8251 L p F P
0 g
s
.759 .667 .76 r
.26615 .8443 m .27015 .84051 L p .26966 .84954 L F P
0 g
s
.759 .667 .76 r
.26966 .84954 m .26898 .8494 L .26615 .8443 L p F P
0 g
s
.761 .661 .751 r
.26926 .84994 m .26966 .84954 L .26898 .8494 L closepath p F P
0 g
s
.764 .664 .752 r
.26898 .8494 m .26926 .84994 L .26258 .85678 L p F P
0 g
s
.644 .579 .767 r
.5397 .83319 m .54228 .83948 L .53093 .84195 L p F P
0 g
s
.644 .579 .767 r
.53093 .84195 m .52888 .83697 L .5397 .83319 L p F P
0 g
s
.769 .571 .631 r
.26808 .93436 m .26865 .93289 L p .27438 .94015 L F P
0 g
s
.771 .573 .631 r
.26808 .93436 m .26865 .93289 L .26782 .93275 L closepath p F P
0 g
s
.66 .613 .791 r
.50649 .81472 m .49572 .81891 L .49281 .81287 L p F P
0 g
s
.661 .37 .467 r
.42159 .97834 m .42482 .97826 L .42792 .98292 L p F P
0 g
s
.661 .37 .467 r
.42792 .98292 m .42064 .98311 L .42159 .97834 L p F P
0 g
s
.638 .553 .741 r
.54398 .85707 m .5486 .85606 L p .54891 .86455 L F P
0 g
s
.64 .56 .749 r
.5486 .85606 m .54839 .85551 L .54398 .85707 L closepath p F P
0 g
s
.64 .562 .75 r
.54556 .8479 m .54839 .85551 L .54398 .85707 L p F P
0 g
s
.64 .562 .75 r
.54399 .84824 m .54556 .8479 L p .54398 .85707 L F P
0 g
s
.45 .605 .913 r
.73816 .05668 m .74281 .05706 L .74494 .06119 L p F P
0 g
s
.376 .555 .902 r
.74982 .05845 m .74281 .05706 L .74494 .06119 L p F P
0 g
s
.376 .555 .902 r
.74494 .06119 m .75236 .06273 L .74982 .05845 L p F P
0 g
s
.687 .393 .471 r
.3929 .98322 m .38852 .98313 L .38609 .97832 L p F P
0 g
s
.688 .394 .47 r
.37967 .97818 m .38609 .97832 L .38852 .98313 L p F P
0 g
s
.724 .675 .802 r
.34956 .80274 m .33959 .80917 L .33652 .80411 L p F P
0 g
s
.621 .482 .671 r
.55412 .91674 m .55268 .91009 L .56399 .90765 L p F P
0 g
s
.624 .494 .683 r
.563 .90346 m .56399 .90765 L .55268 .91009 L p F P
0 g
s
.651 .588 .771 r
.5235 .82431 m .52599 .83008 L p .5123 .8274 L F P
0 g
s
.651 .588 .771 r
.5123 .8274 m .51724 .82554 L .5235 .82431 L p F P
0 g
s
.652 .594 .776 r
.5123 .8274 m .51724 .82554 L .51193 .82656 L closepath p F P
0 g
s
.778 .613 .675 r
.24784 .90856 m .25521 .91007 L .2517 .91635 L p F P
0 g
s
.778 .619 .684 r
.25521 .91007 m .24784 .90856 L .25177 .90218 L p F P
0 g
s
.748 .67 .775 r
.29562 .82647 m .29075 .83048 L .28765 .8251 L p F P
0 g
s
1 .825 .523 r
.59093 .23621 m .59233 .2404 L .59347 .23543 L p F P
0 g
s
1 .825 .523 r
.59347 .23543 m .59202 .23125 L .59093 .23621 L p F P
0 g
s
.642 .383 .511 r
.47157 .97069 m .47443 .97046 L .47399 .97557 L p F P
0 g
s
.642 .383 .511 r
.47399 .97557 m .47376 .97559 L .47157 .97069 L p F P
0 g
s
.765 .669 .756 r
.26898 .8494 m .26615 .8443 L .26244 .84794 L closepath p F P
0 g
s
.764 .664 .752 r
.26244 .84794 m .26898 .8494 L p .26258 .85678 L F P
0 g
s
.917 .882 .784 r
.75803 .19933 m .75884 .20369 L .76323 .19752 L p F P
0 g
s
.917 .882 .784 r
.76323 .19752 m .76246 .19313 L .75803 .19933 L p F P
0 g
s
.659 .369 .469 r
.42482 .97826 m .43503 .97795 L .43411 .98273 L p F P
0 g
s
.659 .369 .469 r
.43411 .98273 m .42792 .98292 L .42482 .97826 L p F P
0 g
s
.638 .552 .741 r
.5514 .86401 m .55129 .8637 L .54891 .86455 L closepath p F P
0 g
s
.638 .553 .741 r
.5486 .85606 m .55129 .8637 L .54891 .86455 L p F P
0 g
s
.579 .683 .911 r
.7217 .05004 m .72553 .04941 L .72787 .05348 L p F P
0 g
s
.556 .669 .913 r
.73306 .0485 m .72553 .04941 L .72787 .05348 L p F P
0 g
s
.556 .669 .913 r
.72787 .05348 m .73561 .05258 L .73306 .0485 L p F P
0 g
s
.622 .423 .591 r
.52343 .9537 m .52302 .94792 L .53482 .94601 L p F P
0 g
s
.629 .442 .612 r
.53418 .94004 m .53482 .94601 L .52302 .94792 L p F P
0 g
s
.93 .882 .765 r
.7671 .1899 m .76557 .18856 L .76654 .18707 L closepath p F P
0 g
s
.776 .576 .63 r
.26782 .93275 m .261 .93147 L p .26646 .93882 L F P
0 g
s
.776 .576 .63 r
.26646 .93882 m .26808 .93436 L .26782 .93275 L p F P
0 g
s
.746 .491 .545 r
.31985 .9692 m .31317 .96845 L .31311 .96307 L p F P
0 g
s
.745 .49 .545 r
.30407 .96206 m .31311 .96307 L .31317 .96845 L p F P
0 g
s
.747 .511 .573 r
.31311 .96307 m .30407 .96206 L .30407 .96202 L p F P
0 g
s
.723 .45 .513 r
.34264 .97625 m .33481 .97568 L .33558 .97064 L p F P
0 g
s
.732 .458 .514 r
.33182 .9703 m .33558 .97064 L .33481 .97568 L p F P
0 g
s
.875 .872 .83 r
.73645 .23018 m .74269 .22332 L .74327 .22774 L p F P
0 g
s
.875 .872 .83 r
.73647 .23032 m .73645 .23018 L p .74327 .22774 L F P
0 g
s
.875 .872 .83 r
.74327 .22774 m .73884 .2326 L .73647 .23032 L p F P
0 g
s
.688 .394 .47 r
.38852 .98313 m .3786 .98292 L .37967 .97818 L p F P
0 g
s
.697 .402 .472 r
.3745 .97799 m .37967 .97818 L .3786 .98292 L p F P
0 g
s
.653 .601 .783 r
.51724 .82554 m .51193 .82656 L .50939 .82099 L p F P
0 g
s
.92 .8 .711 r
.60338 .16004 m .60177 .1631 L .60416 .16704 L p F P
0 g
s
.922 .8 .708 r
.59892 .16865 m .60129 .1726 L .60416 .16704 L p F P
0 g
s
.922 .8 .708 r
.60416 .16704 m .60177 .1631 L .59892 .16865 L p F P
0 g
s
.626 .41 .569 r
.51145 .95542 m .51758 .95455 L .51625 .96035 L p F P
0 g
s
.626 .41 .569 r
.51625 .96035 m .51162 .96101 L .51145 .95542 L p F P
0 g
s
.633 .415 .569 r
.51145 .95542 m .51162 .96101 L .49945 .96254 L p F P
0 g
s
.93 .814 .709 r
.59566 .18358 m .59843 .17815 L .60059 .18215 L p F P
0 g
s
.93 .814 .709 r
.60059 .18215 m .59839 .18645 L .59566 .18358 L p F P
0 g
s
.755 .517 .572 r
.29616 .95536 m .29553 .96091 L .30407 .96206 L p F P
0 g
s
.757 .519 .572 r
.2876 .95422 m .29616 .95536 L .29553 .96091 L p F P
0 g
s
.747 .674 .78 r
.29795 .8169 m .2877 .82505 L .29562 .82647 L p F P
0 g
s
.747 .674 .78 r
.2986 .81702 m .29795 .8169 L p .29562 .82647 L F P
0 g
s
.747 .674 .78 r
.29562 .82647 m .30145 .82182 L .2986 .81702 L p F P
0 g
s
.748 .67 .775 r
.28765 .8251 m .2877 .82505 L .29562 .82647 L p F P
0 g
s
.765 .812 .89 r
.66867 .28682 m .66061 .29196 L .65798 .28898 L p F P
0 g
s
.767 .658 .743 r
.25843 .86118 m .26258 .85678 L .25539 .85523 L closepath p F P
0 g
s
.764 .664 .752 r
.25533 .85514 m .26244 .84794 L p .26258 .85678 L F P
0 g
s
.764 .664 .752 r
.26258 .85678 m .25539 .85523 L .25533 .85514 L p F P
0 g
s
.666 .616 .789 r
.49117 .80949 m .49281 .81287 L p .47914 .81132 L F P
0 g
s
.666 .616 .789 r
.47914 .81132 m .47937 .81123 L .49117 .80949 L p F P
0 g
s
.667 .621 .794 r
.47914 .81132 m .47937 .81123 L .47911 .81126 L closepath p F P
0 g
s
.768 .558 .614 r
.28069 .94726 m .2726 .94598 L .27438 .94015 L p F P
0 g
s
.769 .559 .615 r
.26889 .93926 m .27438 .94015 L .2726 .94598 L p F P
0 g
s
.769 .571 .631 r
.27438 .94015 m .26889 .93926 L .26808 .93436 L p F P
0 g
s
.667 .628 .801 r
.47937 .81123 m .47911 .81126 L .47621 .80561 L p F P
0 g
s
.621 .461 .644 r
.54496 .93182 m .54434 .9281 L .55124 .92407 L p F P
0 g
s
.634 .376 .51 r
.47399 .97557 m .47443 .97046 L .48698 .96927 L p F P
0 g
s
.68 .64 .803 r
.4489 .80383 m .44959 .80351 L .44877 .80359 L closepath p F P
0 g
s
.678 .635 .8 r
.4614 .80238 m .46255 .80457 L p .4489 .80383 L F P
0 g
s
.678 .635 .8 r
.4489 .80383 m .44959 .80351 L .4614 .80238 L p F P
0 g
s
.666 .624 .798 r
.49117 .80949 m .48989 .80695 L .47937 .81123 L closepath p F P
0 g
s
.667 .628 .801 r
.48696 .8012 m .48989 .80695 L .47937 .81123 L p F P
0 g
s
.667 .628 .801 r
.47621 .80561 m .48696 .8012 L p .47937 .81123 L F P
0 g
s
.899 .793 .735 r
.60243 .15353 m .60494 .15744 L .60846 .15166 L p F P
0 g
s
.899 .793 .735 r
.60846 .15166 m .60594 .14775 L .60243 .15353 L p F P
0 g
s
.779 .622 .686 r
.24449 .90064 m .25177 .90218 L .24784 .90856 L p F P
0 g
s
.778 .629 .695 r
.25177 .90218 m .24449 .90064 L .24882 .89415 L p F P
0 g
s
.696 .396 .464 r
.36509 .97764 m .3745 .97799 L .37674 .98285 L p F P
0 g
s
.697 .402 .472 r
.3786 .98292 m .37674 .98285 L .3745 .97799 L p F P
0 g
s
.806 .845 .88 r
.69581 .2719 m .69449 .27292 L .69444 .27048 L closepath p F P
0 g
s
.801 .839 .88 r
.69326 .26922 m .69444 .27048 L .69449 .27292 L p F P
0 g
s
.801 .839 .88 r
.68268 .2772 m .69326 .26922 L p .69449 .27292 L F P
0 g
s
.801 .839 .88 r
.68272 .27777 m .68268 .2772 L p .69449 .27292 L F P
0 g
s
.775 .576 .629 r
.26889 .93926 m .26808 .93436 L .26646 .93882 L closepath p F P
0 g
s
.679 .646 .81 r
.44959 .80351 m .44877 .80359 L .44594 .79849 L p F P
0 g
s
.62 .435 .611 r
.53482 .94601 m .53418 .94004 L .54581 .93797 L p F P
0 g
s
.625 .452 .628 r
.54496 .93182 m .54581 .93797 L .53418 .94004 L p F P
0 g
s
.651 .362 .467 r
.43503 .97795 m .43964 .97775 L .44301 .98235 L p F P
0 g
s
.651 .362 .467 r
.44301 .98235 m .43411 .98273 L .43503 .97795 L p F P
0 g
s
.716 .674 .807 r
.36087 .79597 m .36393 .80092 L .35951 .80357 L p F P
0 g
s
.716 .674 .807 r
.35023 .80231 m .36087 .79597 L p .35951 .80357 L F P
0 g
s
.716 .674 .807 r
.35951 .80357 m .35056 .80284 L .35023 .80231 L p F P
0 g
s
.956 .817 .666 r
.59342 .19833 m .59544 .20236 L .59765 .19703 L p F P
0 g
s
.956 .817 .666 r
.59765 .19703 m .5956 .19301 L .59342 .19833 L p F P
0 g
s
.816 .846 .872 r
.70475 .26463 m .69581 .2719 L .69444 .27048 L p F P
0 g
s
.679 .646 .81 r
.45665 .79373 m .4596 .79908 L .44959 .80351 L p F P
0 g
s
.679 .646 .81 r
.44594 .79849 m .45665 .79373 L p .44959 .80351 L F P
0 g
s
.678 .643 .808 r
.4614 .80238 m .4596 .79908 L .44959 .80351 L closepath p F P
0 g
s
.628 .531 .725 r
.5542 .87241 m .56181 .86989 L .55399 .87174 L closepath p F P
0 g
s
.63 .54 .734 r
.56181 .86989 m .55399 .87174 L .5514 .86401 L p F P
0 g
s
.732 .458 .514 r
.33481 .97568 m .33271 .97549 L .33182 .9703 L p F P
0 g
s
.733 .458 .511 r
.3223 .96943 m .33182 .9703 L .33271 .97549 L p F P
0 g
s
.628 .53 .724 r
.55637 .87928 m .5542 .87241 L .56181 .86989 L p F P
0 g
s
.954 .704 .25 r
.77746 .11371 m .7789 .11798 L .77882 .11353 L p F P
0 g
s
.954 .704 .25 r
.77882 .11353 m .77738 .10925 L .77746 .11371 L p F P
0 g
s
.994 .856 .592 r
.77999 .14385 m .7785 .14317 L .77918 .14098 L closepath p F P
0 g
s
.774 .642 .716 r
.25057 .88039 m .25143 .87929 L .24996 .87898 L closepath p F P
0 g
s
.772 .649 .727 r
.24751 .87375 m .24991 .87085 L p .25143 .87929 L F P
0 g
s
.772 .649 .727 r
.25143 .87929 m .24996 .87898 L .24751 .87375 L p F P
0 g
s
.451 .609 .915 r
.74281 .05706 m .73816 .05668 L .73561 .05258 L p F P
0 g
s
.224 .398 .826 r
.60144 .28789 m .6008 .2843 L .60312 .28882 L closepath p F P
0 g
s
.625 .521 .715 r
.55712 .8818 m .55637 .87928 L .56753 .87664 L p F P
0 g
s
.628 .53 .724 r
.56515 .8691 m .56753 .87664 L .55637 .87928 L p F P
0 g
s
.628 .53 .724 r
.56181 .86989 m .56515 .8691 L p .55637 .87928 L F P
0 g
s
.869 .873 .837 r
.73884 .2326 m .73692 .23463 L .73647 .23032 L closepath p F P
0 g
s
.771 .66 .74 r
.25596 .8639 m .25843 .86118 L .25539 .85523 L p F P
0 g
s
.644 .58 .768 r
.53872 .8308 m .5397 .83319 L .52888 .83697 L p F P
0 g
s
.644 .58 .768 r
.52888 .83697 m .52736 .83327 L .53872 .8308 L p F P
0 g
s
.742 .673 .783 r
.30145 .82182 m .30609 .81826 L .2986 .81702 L closepath p F P
0 g
s
.73 .672 .793 r
.32587 .81122 m .32628 .81094 L .32565 .81086 L closepath p F P
0 g
s
.736 .676 .792 r
.32565 .81086 m .32587 .81122 L p .31212 .81377 L F P
0 g
s
.625 .52 .715 r
.55855 .88663 m .55712 .8818 L .56798 .87817 L p F P
0 g
s
.625 .521 .715 r
.56753 .87664 m .56798 .87817 L .55712 .8818 L p F P
0 g
s
.728 .677 .801 r
.33464 .80107 m .33652 .80411 L .32628 .81094 L p F P
0 g
s
.728 .677 .801 r
.33123 .8006 m .33464 .80107 L p .32628 .81094 L F P
0 g
s
.728 .677 .801 r
.32278 .80624 m .33123 .8006 L p .32628 .81094 L F P
0 g
s
.728 .677 .801 r
.32628 .81094 m .32565 .81086 L .32278 .80624 L p F P
0 g
s
.65 .362 .469 r
.43964 .97775 m .44822 .97734 L .44735 .98215 L p F P
0 g
s
.65 .362 .469 r
.44735 .98215 m .44301 .98235 L .43964 .97775 L p F P
0 g
s
.63 .54 .734 r
.5514 .86401 m .56255 .86135 L p .56181 .86989 L F P
0 g
s
.632 .548 .742 r
.56215 .8602 m .56255 .86135 L .5514 .86401 L p F P
0 g
s
.632 .548 .742 r
.5514 .86401 m .55129 .8637 L .56215 .8602 L p F P
0 g
s
.877 .786 .756 r
.60842 .13532 m .61059 .1322 L .61325 .13608 L p F P
0 g
s
.877 .786 .756 r
.61325 .13608 m .61116 .13909 L .60842 .13532 L p F P
0 g
s
.632 .549 .743 r
.55975 .85339 m .56215 .8602 L .55129 .8637 L p F P
0 g
s
.632 .549 .743 r
.55129 .8637 m .5486 .85606 L .55975 .85339 L p F P
0 g
s
.778 .644 .713 r
.24635 .88598 m .25057 .88039 L .24996 .87898 L p F P
0 g
s
.856 .865 .847 r
.72939 .23734 m .72995 .24174 L .73692 .23463 L p F P
0 g
s
.856 .865 .847 r
.73639 .23024 m .72939 .23734 L p .73692 .23463 L F P
0 g
s
.856 .865 .847 r
.73692 .23463 m .73647 .23032 L .73639 .23024 L p F P
0 g
s
.626 .391 .542 r
.49933 .96791 m .49945 .96254 L .51162 .96101 L p F P
0 g
s
.999 .837 .537 r
.77789 .13669 m .77918 .14098 L .78037 .13602 L p F P
0 g
s
.999 .837 .537 r
.78037 .13602 m .77908 .13172 L .77789 .13669 L p F P
0 g
s
.736 .676 .792 r
.31212 .81377 m .31784 .80967 L .32565 .81086 L p F P
0 g
s
.734 .679 .797 r
.32565 .81086 m .32278 .80624 L .31784 .80967 L closepath p F P
0 g
s
0 .139 .679 r
.59747 .2768 m .59672 .27574 L .59758 .28005 L p F P
0 g
s
0 .139 .679 r
.59758 .28005 m .60031 .28325 L .59747 .2768 L p F P
0 g
s
.971 .834 .651 r
.59131 .21294 m .59332 .20767 L .59509 .21177 L p F P
0 g
s
.971 .834 .651 r
.59223 .21513 m .59131 .21294 L p .59509 .21177 L F P
0 g
s
.971 .834 .651 r
.59509 .21177 m .5935 .21589 L .59223 .21513 L p F P
0 g
s
.772 .657 .736 r
.24888 .86226 m .25596 .8639 L .24991 .87085 L p F P
0 g
s
.771 .66 .74 r
.25527 .85521 m .24888 .86226 L .25596 .8639 L p F P
0 g
s
.771 .66 .74 r
.25539 .85523 m .25527 .85521 L p .25596 .8639 L F P
0 g
s
.696 .396 .464 r
.36449 .9803 m .36509 .97764 L p .37674 .98285 L F P
0 g
s
.706 .412 .476 r
.36449 .9803 m .36337 .97755 L .36509 .97764 L closepath p F P
0 g
s
.623 .511 .706 r
.56005 .89198 m .55855 .88663 L .56971 .884 L p F P
0 g
s
.625 .52 .715 r
.56798 .87817 m .56971 .884 L .55855 .88663 L p F P
0 g
s
.646 .715 .898 r
.70795 .0496 m .71913 .04603 L .7217 .05004 L p F P
0 g
s
.647 .716 .899 r
.71913 .04603 m .70795 .0496 L .70536 .04561 L p F P
0 g
s
.697 .738 .883 r
.6943 .0507 m .70536 .04561 L .70795 .0496 L p F P
0 g
s
.767 .543 .594 r
.28736 .95419 m .27948 .95295 L .28069 .94726 L p F P
0 g
s
.767 .544 .595 r
.2726 .94598 m .28069 .94726 L .27948 .95295 L p F P
0 g
s
.779 .632 .698 r
.24164 .89257 m .24882 .89415 L .24449 .90064 L p F P
0 g
s
.778 .637 .705 r
.24882 .89415 m .24164 .89257 L .24635 .88598 L p F P
0 g
s
.778 .652 .723 r
.24996 .87898 m .24751 .87375 L .24437 .87766 L closepath p F P
0 g
s
.778 .644 .713 r
.24996 .87898 m .24437 .87766 L p .24635 .88598 L F P
0 g
s
.971 .772 .342 r
.59109 .25 m .59216 .25429 L .59262 .24955 L p F P
0 g
s
.971 .772 .342 r
.59262 .24955 m .59151 .24527 L .59109 .25 L p F P
0 g
s
.707 .408 .468 r
.36337 .97755 m .36449 .9803 L .36397 .98235 L p F P
0 g
s
.707 .408 .468 r
.35279 .97696 m .36337 .97755 L p .36397 .98235 L F P
0 g
s
.701 .663 .81 r
.40226 .79385 m .40495 .79842 L p .39128 .79897 L F P
0 g
s
.701 .663 .81 r
.39128 .79897 m .40095 .79383 L .40226 .79385 L p F P
0 g
s
.701 .668 .814 r
.40095 .79383 m .39128 .79897 L .38826 .7939 L p F P
0 g
s
.706 .667 .809 r
.37761 .7998 m .38826 .7939 L .39128 .79897 L p F P
0 g
s
.739 .678 .791 r
.30902 .80866 m .31212 .81377 L .30609 .81826 L p F P
0 g
s
.739 .678 .791 r
.29834 .8166 m .30902 .80866 L p .30609 .81826 L F P
0 g
s
.739 .678 .791 r
.30609 .81826 m .2986 .81702 L .29834 .8166 L p F P
0 g
s
.706 .672 .814 r
.38826 .7939 m .37761 .7998 L .37457 .79479 L p F P
0 g
s
.94 .881 .749 r
.76559 .18273 m .76654 .18707 L .77008 .18121 L p F P
0 g
s
.94 .881 .749 r
.77008 .18121 m .76916 .17685 L .76559 .18273 L p F P
0 g
s
.821 .852 .871 r
.70662 .26307 m .70475 .26463 L .70458 .26098 L closepath p F P
0 g
s
.816 .846 .872 r
.7041 .26047 m .70458 .26098 L .70475 .26463 L p F P
0 g
s
.816 .846 .872 r
.69424 .26844 m .7041 .26047 L p .70475 .26463 L F P
0 g
s
.816 .846 .872 r
.69444 .27048 m .69424 .26844 L p .70475 .26463 L F P
0 g
s
.695 .659 .81 r
.41603 .7937 m .41861 .79816 L p .40495 .79842 L F P
0 g
s
.695 .659 .81 r
.40495 .79842 m .41416 .79373 L .41603 .7937 L p F P
0 g
s
.696 .661 .811 r
.40495 .79842 m .41416 .79373 L .40226 .79385 L closepath p F P
0 g
s
.672 .63 .798 r
.47381 .80094 m .47621 .80561 L p .46255 .80457 L F P
0 g
s
.672 .63 .798 r
.46255 .80457 m .46977 .80143 L .47381 .80094 L p F P
0 g
s
.674 .635 .802 r
.46255 .80457 m .46977 .80143 L .4614 .80238 L closepath p F P
0 g
s
.829 .853 .864 r
.71392 .25672 m .70662 .26307 L .70458 .26098 L p F P
0 g
s
.618 .471 .659 r
.55514 .92203 m .55412 .91674 L .56544 .91432 L p F P
0 g
s
.621 .482 .671 r
.56399 .90765 m .56544 .91432 L .55412 .91674 L p F P
0 g
s
.625 .476 .659 r
.55412 .91674 m .55514 .92203 L .55124 .92407 L p F P
0 g
s
.634 .557 .751 r
.55925 .85203 m .55975 .85339 L .5486 .85606 L p F P
0 g
s
.634 .557 .751 r
.5486 .85606 m .54839 .85551 L .55925 .85203 L p F P
0 g
s
.854 .861 .846 r
.72567 .24101 m .72939 .23734 L .72995 .24174 L p F P
0 g
s
.854 .861 .846 r
.72995 .24174 m .72815 .24352 L .72567 .24101 L p F P
0 g
s
.645 .587 .775 r
.53681 .82633 m .53872 .8308 L .52736 .83327 L p F P
0 g
s
.645 .587 .775 r
.52736 .83327 m .52599 .83008 L .53681 .82633 L p F P
0 g
s
.634 .558 .751 r
.55672 .84522 m .55925 .85203 L .54839 .85551 L p F P
0 g
s
.634 .558 .751 r
.54839 .85551 m .54556 .8479 L .55672 .84522 L p F P
0 g
s
.712 .676 .813 r
.37457 .79479 m .36393 .80092 L .36087 .79597 L p F P
0 g
s
.847 .861 .853 r
.72226 .24912 m .72815 .24352 L .72567 .24101 L p F P
0 g
s
.623 .511 .706 r
.56056 .89381 m .56005 .89198 L .57092 .88832 L p F P
0 g
s
.623 .511 .706 r
.56971 .884 m .57092 .88832 L .56005 .89198 L p F P
0 g
s
.642 .355 .467 r
.44822 .97734 m .45583 .97689 L .45949 .98143 L p F P
0 g
s
.642 .355 .467 r
.45949 .98143 m .44735 .98215 L .44822 .97734 L p F P
0 g
s
.617 .446 .628 r
.54581 .93797 m .54496 .93182 L .55643 .92957 L p F P
0 g
s
.621 .461 .644 r
.55538 .92325 m .55643 .92957 L .54496 .93182 L p F P
0 g
s
.621 .461 .644 r
.55124 .92407 m .55538 .92325 L p .54496 .93182 L F P
0 g
s
.907 .877 .795 r
.75516 .20314 m .75803 .19933 L .75884 .20369 L p F P
0 g
s
.907 .877 .795 r
.75884 .20369 m .75756 .20539 L .75516 .20314 L p F P
0 g
s
.624 .408 .569 r
.51758 .95455 m .52343 .9537 L .52361 .95928 L p F P
0 g
s
.624 .408 .569 r
.52361 .95928 m .51625 .96035 L .51758 .95455 L p F P
0 g
s
.722 .676 .804 r
.35056 .80284 m .35023 .80231 L .34956 .80274 L closepath p F P
0 g
s
.834 .857 .862 r
.71392 .25672 m .71741 .25362 L .71491 .25109 L p F P
0 g
s
.834 .857 .862 r
.71491 .25109 m .71359 .25226 L .71392 .25672 L p F P
0 g
s
.829 .853 .864 r
.70449 .26014 m .71359 .25226 L .71392 .25672 L p F P
0 g
s
.829 .853 .864 r
.70458 .26098 m .70449 .26014 L p .71392 .25672 L F P
0 g
s
.842 .858 .855 r
.71491 .25109 m .72181 .24468 L .72226 .24912 L p F P
0 g
s
.842 .858 .855 r
.72226 .24912 m .71741 .25362 L .71491 .25109 L p F P
0 g
s
.847 .861 .853 r
.72567 .24101 m .72181 .24468 L .72226 .24912 L p F P
0 g
s
.69 .654 .809 r
.42946 .79323 m .43227 .79818 L p .41861 .79816 L F P
0 g
s
.69 .654 .809 r
.41861 .79816 m .42863 .79327 L .42946 .79323 L p F P
0 g
s
.691 .657 .812 r
.41861 .79816 m .42863 .79327 L .41603 .7937 L closepath p F P
0 g
s
.885 .598 .084 r
.77586 .10498 m .77738 .10925 L .77678 .10499 L p F P
0 g
s
.885 .598 .084 r
.77678 .10499 m .77526 .10073 L .77586 .10498 L p F P
0 g
s
.62 .5 .695 r
.56237 .90082 m .56056 .89381 L .57171 .89119 L p F P
0 g
s
.623 .511 .706 r
.57092 .88832 m .57171 .89119 L .56056 .89381 L p F P
0 g
s
.755 .517 .572 r
.30407 .96206 m .30407 .96202 L .30407 .96206 L closepath p F P
0 g
s
.652 .598 .781 r
.5235 .82431 m .52309 .82339 L .51724 .82554 L closepath p F P
0 g
s
.653 .601 .783 r
.52019 .81698 m .52309 .82339 L .51724 .82554 L p F P
0 g
s
.653 .601 .783 r
.50939 .82099 m .52019 .81698 L p .51724 .82554 L F P
0 g
s
.894 .785 .733 r
.60941 .14198 m .61116 .13909 L .60842 .13532 L p F P
0 g
s
.745 .49 .545 r
.30407 .96211 m .30407 .96206 L p .31317 .96845 L F P
0 g
s
.753 .498 .546 r
.30407 .96211 m .30407 .96206 L .30407 .96206 L closepath p F P
0 g
s
.756 .499 .545 r
.30407 .96206 m .30407 .96211 L .30364 .96739 L p F P
0 g
s
.756 .499 .545 r
.29553 .96091 m .30407 .96206 L p .30364 .96739 L F P
0 g
s
.653 .602 .784 r
.51928 .81499 m .52019 .81698 L .50939 .82099 L p F P
0 g
s
.653 .602 .784 r
.50939 .82099 m .50768 .81723 L .51928 .81499 L p F P
0 g
s
.983 .87 .646 r
.77543 .15143 m .77657 .15575 L .77864 .15045 L p F P
0 g
s
.983 .87 .646 r
.77864 .15045 m .77753 .14612 L .77543 .15143 L p F P
0 g
s
.745 .49 .545 r
.31317 .96845 m .30412 .96744 L .30407 .96211 L p F P
0 g
s
.747 .492 .545 r
.30412 .96744 m .30364 .96739 L .30407 .96211 L closepath p F P
0 g
s
.724 .675 .802 r
.33652 .80411 m .34029 .8017 L .34956 .80274 L p F P
0 g
s
.723 .68 .807 r
.34716 .79743 m .34029 .8017 L .34956 .80274 L p F P
0 g
s
.723 .68 .807 r
.34956 .80274 m .35023 .80231 L .34716 .79743 L p F P
0 g
s
.641 .569 .758 r
.54556 .8479 m .54549 .84771 L .54399 .84824 L closepath p F P
0 g
s
.642 .57 .759 r
.5426 .8403 m .54549 .84771 L .54399 .84824 L p F P
0 g
s
.769 .559 .615 r
.2726 .94598 m .26962 .9455 L .26889 .93926 L p F P
0 g
s
.776 .564 .613 r
.26646 .93882 m .26889 .93926 L .26962 .9455 L p F P
0 g
s
.624 .475 .658 r
.55538 .92325 m .55514 .92203 L .55124 .92407 L closepath p F P
0 g
s
.993 .821 .568 r
.59036 .22713 m .59202 .23125 L .59335 .22621 L p F P
0 g
s
.993 .821 .568 r
.59335 .22621 m .59165 .22211 L .59036 .22713 L p F P
0 g
s
.283 .49 .883 r
.75434 .06692 m .75246 .06289 L .75491 .06712 L closepath p F P
0 g
s
0 0 .312 r
.59626 .27394 m .59672 .27574 L .59509 .27172 L p F P
0 g
s
0 0 .312 r
.59458 .26893 m .59626 .27394 L p .59509 .27172 L F P
0 g
s
0 0 .312 r
.59509 .27172 m .59406 .26745 L .59458 .26893 L p F P
0 g
s
.964 .878 .701 r
.77144 .16674 m .77417 .16118 L .77524 .16551 L p F P
0 g
s
.964 .878 .701 r
.77176 .16801 m .77144 .16674 L p .77524 .16551 L F P
0 g
s
.964 .878 .701 r
.77524 .16551 m .77339 .16925 L .77176 .16801 L p F P
0 g
s
.66 .613 .791 r
.49281 .81287 m .50357 .80864 L .50649 .81472 L p F P
0 g
s
.661 .616 .793 r
.50303 .8075 m .50357 .80864 L .49281 .81287 L p F P
0 g
s
.661 .616 .793 r
.49281 .81287 m .49117 .80949 L .50303 .8075 L p F P
0 g
s
.718 .679 .811 r
.36087 .79597 m .35023 .80231 L .34716 .79743 L p F P
0 g
s
.765 .812 .89 r
.65798 .28898 m .66871 .28224 L .66867 .28682 L p F P
0 g
s
.766 .819 .894 r
.66867 .28682 m .67151 .28498 L .6689 .28212 L p F P
0 g
s
.766 .819 .894 r
.6689 .28212 m .66871 .28224 L .66867 .28682 L p F P
0 g
s
.903 .879 .802 r
.75389 .21008 m .75756 .20539 L .75516 .20314 L p F P
0 g
s
.777 .59 .646 r
.261 .93147 m .25342 .93004 L .25609 .92398 L p F P
0 g
s
.778 .592 .647 r
.24857 .92252 m .25609 .92398 L .25342 .93004 L p F P
0 g
s
.778 .601 .661 r
.25609 .92398 m .24857 .92252 L .2517 .91635 L p F P
0 g
s
.735 .676 .793 r
.31784 .80967 m .31212 .81377 L .30902 .80866 L p F P
0 g
s
.942 .806 .681 r
.59785 .18767 m .59839 .18645 L .59566 .18358 L p F P
0 g
s
.761 .668 .759 r
.26615 .8443 m .27015 .84051 L .26323 .83904 L closepath p F P
0 g
s
.758 .673 .768 r
.2758 .83236 m .27692 .83431 L .27015 .84051 L p F P
0 g
s
.758 .673 .768 r
.27115 .83132 m .2758 .83236 L p .27015 .84051 L F P
0 g
s
.758 .673 .768 r
.26304 .83871 m .27115 .83132 L p .27015 .84051 L F P
0 g
s
.758 .673 .768 r
.27015 .84051 m .26323 .83904 L .26304 .83871 L p F P
0 g
s
.755 .67 .768 r
.27692 .83431 m .27852 .8329 L .2758 .83236 L closepath p F P
0 g
s
.774 .651 .726 r
.24751 .87375 m .24991 .87085 L .2457 .8699 L closepath p F P
0 g
s
.772 .657 .736 r
.24443 .86735 m .24888 .86226 L p .24991 .87085 L F P
0 g
s
.772 .657 .736 r
.24991 .87085 m .2457 .8699 L .24443 .86735 L p F P
0 g
s
.779 .604 .662 r
.24606 .91521 m .2517 .91635 L .24857 .92252 L p F P
0 g
s
.778 .613 .675 r
.24537 .91295 m .24784 .90856 L p .2517 .91635 L F P
0 g
s
.778 .613 .675 r
.2517 .91635 m .24606 .91521 L .24537 .91295 L p F P
0 g
s
.752 .676 .777 r
.28761 .82504 m .28765 .8251 L .27852 .8329 L p F P
0 g
s
.752 .676 .777 r
.28027 .82349 m .28761 .82504 L p .27852 .8329 L F P
0 g
s
.752 .676 .777 r
.2738 .82899 m .28027 .82349 L p .27852 .8329 L F P
0 g
s
.752 .676 .777 r
.27852 .8329 m .2758 .83236 L .2738 .82899 L p F P
0 g
s
.733 .458 .511 r
.33271 .97549 m .32323 .9746 L .3223 .96943 L p F P
0 g
s
.733 .458 .512 r
.31985 .9692 m .3223 .96943 L .32323 .9746 L p F P
0 g
s
.779 .641 .708 r
.23929 .88436 m .24635 .88598 L .24164 .89257 L p F P
0 g
s
.778 .644 .713 r
.24437 .87766 m .23929 .88436 L .24635 .88598 L p F P
0 g
s
.58 .684 .912 r
.72553 .04941 m .7217 .05004 L .71913 .04603 L p F P
0 g
s
.765 .669 .757 r
.26244 .84794 m .26615 .8443 L .26323 .83904 L p F P
0 g
s
.776 .576 .63 r
.261 .93147 m .25882 .93741 L .26646 .93882 L p F P
0 g
s
.777 .579 .632 r
.25342 .93004 m .261 .93147 L .25882 .93741 L p F P
0 g
s
.757 .519 .572 r
.28735 .95638 m .2876 .95422 L p .29553 .96091 L F P
0 g
s
.759 .521 .572 r
.28735 .95638 m .2876 .95422 L .28736 .95419 L closepath p F P
0 g
s
.707 .408 .468 r
.36397 .98235 m .35493 .98184 L .35279 .97696 L p F P
0 g
s
.707 .408 .468 r
.35015 .9768 m .35279 .97696 L .35493 .98184 L p F P
0 g
s
.45 .563 .878 r
.60312 .28882 m .60935 .28969 L .60958 .2942 L p F P
0 g
s
.545 .661 .912 r
.61424 .28956 m .60935 .28969 L .60958 .2942 L p F P
0 g
s
.545 .661 .912 r
.60958 .2942 m .61699 .29359 L .61424 .28956 L p F P
0 g
s
.765 .525 .572 r
.28736 .95419 m .27948 .95295 L p .28696 .95977 L F P
0 g
s
.765 .525 .572 r
.28696 .95977 m .28735 .95638 L .28736 .95419 L p F P
0 g
s
.684 .65 .81 r
.43227 .79818 m .44297 .79319 L .44594 .79849 L p F P
0 g
s
.685 .652 .812 r
.44253 .79242 m .44297 .79319 L .43227 .79818 L p F P
0 g
s
.685 .652 .812 r
.43227 .79818 m .42946 .79323 L .44253 .79242 L p F P
0 g
s
.645 .588 .776 r
.53487 .82183 m .53681 .82633 L .52599 .83008 L p F P
0 g
s
.645 .588 .776 r
.52599 .83008 m .5235 .82431 L .53487 .82183 L p F P
0 g
s
.742 .792 .893 r
.65019 .29347 m .64705 .29525 L .64439 .29206 L p F P
0 g
s
.712 .783 .908 r
.63343 .29727 m .64439 .29206 L .64705 .29525 L p F P
0 g
s
.765 .669 .757 r
.26279 .83894 m .25529 .8463 L .26244 .84794 L p F P
0 g
s
.765 .669 .757 r
.26323 .83904 m .26279 .83894 L p .26244 .84794 L F P
0 g
s
.767 .667 .751 r
.26244 .84794 m .25533 .85514 L .25221 .84943 L p F P
0 g
s
.767 .667 .751 r
.25221 .84943 m .25529 .8463 L .26244 .84794 L p F P
0 g
s
.64 .355 .47 r
.45583 .97689 m .4612 .97655 L .46037 .98137 L p F P
0 g
s
.64 .355 .47 r
.46037 .98137 m .45949 .98143 L .45583 .97689 L p F P
0 g
s
.674 .641 .809 r
.46977 .80143 m .4614 .80238 L .4596 .79908 L p F P
0 g
s
.635 .566 .759 r
.55635 .84425 m .55672 .84522 L .54556 .8479 L p F P
0 g
s
.635 .566 .759 r
.54556 .8479 m .54549 .84771 L .55635 .84425 L p F P
0 g
s
.634 .376 .51 r
.48698 .96927 m .48654 .97438 L .47399 .97557 L p F P
0 g
s
.626 .369 .508 r
.48698 .96927 m .49208 .96872 L .49487 .97348 L p F P
0 g
s
.626 .369 .508 r
.49487 .97348 m .48654 .97438 L .48698 .96927 L p F P
0 g
s
.635 .562 .756 r
.55635 .84425 m .54549 .84771 L .5426 .8403 L p F P
0 g
s
.78 .614 .674 r
.24537 .91295 m .24784 .90856 L .24375 .90771 L closepath p F P
0 g
s
.779 .622 .686 r
.24244 .90396 m .24449 .90064 L p .24784 .90856 L F P
0 g
s
.779 .622 .686 r
.24784 .90856 m .24375 .90771 L .24244 .90396 L p F P
0 g
s
.9 .795 .735 r
.60063 .15652 m .60243 .15353 L .60494 .15744 L p F P
0 g
s
.9 .795 .735 r
.60494 .15744 m .60338 .16004 L .60063 .15652 L p F P
0 g
s
.12 .374 .833 r
.75491 .06712 m .75902 .06955 L .76097 .07372 L p F P
0 g
s
.105 .372 .834 r
.75246 .06289 m .75491 .06712 L .75902 .06955 L p F P
0 g
s
.923 .801 .707 r
.59608 .1742 m .59843 .17815 L .60129 .1726 L p F P
0 g
s
.923 .801 .707 r
.60129 .1726 m .59892 .16865 L .59608 .1742 L p F P
0 g
s
.707 .408 .468 r
.35493 .98184 m .34896 .9815 L .35015 .9768 L p F P
0 g
s
.716 .418 .471 r
.34264 .97625 m .35015 .9768 L .34896 .9815 L p F P
0 g
s
.749 .673 .777 r
.28765 .8251 m .2877 .82505 L .28761 .82504 L closepath p F P
0 g
s
.746 .678 .785 r
.29031 .81539 m .29795 .8169 L .2877 .82505 L p F P
0 g
s
.746 .678 .785 r
.28452 .81998 m .29031 .81539 L p .2877 .82505 L F P
0 g
s
.746 .678 .785 r
.2877 .82505 m .28761 .82504 L .28452 .81998 L p F P
0 g
s
.757 .437 0 r
.77365 .09648 m .77526 .10073 L .77408 .0967 L p F P
0 g
s
.757 .437 0 r
.77408 .0967 m .77247 .09246 L .77365 .09648 L p F P
0 g
s
.733 .458 .512 r
.32323 .9746 m .31903 .97421 L .31985 .9692 L p F P
0 g
s
.742 .466 .513 r
.31317 .96845 m .31985 .9692 L .31903 .97421 L p F P
0 g
s
.753 .68 .781 r
.28761 .82504 m .28452 .81998 L .28027 .82349 L closepath p F P
0 g
s
.783 .826 .886 r
.68239 .27741 m .67151 .28498 L .6689 .28212 L p F P
0 g
s
.778 .652 .723 r
.24437 .87766 m .24751 .87375 L .2457 .8699 L p F P
0 g
s
.776 .564 .613 r
.26962 .9455 m .26477 .94463 L .26646 .93882 L p F P
0 g
s
.777 .566 .614 r
.25882 .93741 m .26646 .93882 L .26477 .94463 L p F P
0 g
s
.466 .543 .852 r
.6008 .2843 m .60312 .28882 L .60935 .28969 L p F P
0 g
s
.942 .806 .681 r
.59566 .18358 m .5956 .1837 L .59785 .18767 L p F P
0 g
s
.947 .805 .671 r
.59338 .18903 m .5956 .19301 L .59785 .18767 L p F P
0 g
s
.947 .805 .671 r
.59785 .18767 m .5956 .1837 L .59338 .18903 L p F P
0 g
s
.999 .811 .472 r
.77771 .12744 m .77908 .13172 L .77988 .12691 L p F P
0 g
s
.999 .811 .472 r
.77988 .12691 m .77852 .12263 L .77771 .12744 L p F P
0 g
s
.668 .629 .802 r
.48594 .79922 m .48696 .8012 L .47621 .80561 L p F P
0 g
s
.668 .629 .802 r
.47621 .80561 m .47381 .80094 L .48594 .79922 L p F P
0 g
s
.617 .489 .684 r
.563 .90346 m .56237 .90082 L .57354 .8982 L p F P
0 g
s
.62 .5 .695 r
.57171 .89119 m .57354 .8982 L .56237 .90082 L p F P
0 g
s
.724 .675 .802 r
.33652 .80411 m .34029 .8017 L .33464 .80107 L closepath p F P
0 g
s
0 .222 .744 r
.76256 .07263 m .76447 .07681 L .76097 .07372 L p F P
0 g
s
0 .222 .744 r
.76097 .07372 m .75902 .06955 L .76256 .07263 L p F P
0 g
s
.77 .666 .748 r
.25539 .85523 m .25533 .85514 L .25527 .85521 L closepath p F P
0 g
s
.894 .785 .733 r
.60842 .13532 m .60673 .13811 L .60941 .14198 L p F P
0 g
s
.895 .785 .732 r
.60326 .14388 m .60594 .14775 L .60941 .14198 L p F P
0 g
s
.895 .785 .732 r
.60941 .14198 m .60673 .13811 L .60326 .14388 L p F P
0 g
s
.771 .669 .75 r
.25527 .85521 m .25533 .85514 L .25221 .84943 L p F P
0 g
s
.772 .663 .742 r
.24833 .85352 m .25527 .85521 L .24888 .86226 L p F P
0 g
s
.771 .669 .75 r
.25221 .84943 m .24833 .85352 L .25527 .85521 L p F P
0 g
s
.735 .676 .793 r
.30902 .80866 m .30941 .80839 L .31784 .80967 L p F P
0 g
s
.735 .681 .798 r
.31968 .80129 m .30941 .80839 L .31784 .80967 L p F P
0 g
s
.735 .681 .798 r
.31784 .80967 m .32278 .80624 L .31968 .80129 L p F P
0 g
s
.87 .66 .131 r
.59226 .25884 m .59252 .26023 L .59244 .25574 L p F P
0 g
s
.87 .66 .131 r
.59244 .25574 m .59216 .25429 L .59226 .25884 L p F P
0 g
s
.657 .746 .916 r
.61973 .29751 m .63073 .29382 L .63343 .29727 L p F P
0 g
s
.642 .736 .917 r
.63073 .29382 m .61973 .29751 L .61699 .29359 L p F P
0 g
s
.654 .609 .791 r
.51728 .81077 m .51928 .81499 L .50768 .81723 L p F P
0 g
s
.654 .609 .791 r
.50768 .81723 m .50649 .81472 L .51728 .81077 L p F P
0 g
s
.617 .47 .659 r
.55538 .92325 m .55514 .92203 L .56599 .91715 L p F P
0 g
s
.618 .471 .659 r
.56544 .91432 m .56599 .91715 L .55514 .92203 L p F P
0 g
s
.633 .348 .468 r
.46037 .98137 m .4612 .97655 L .47376 .97559 L p F P
0 g
s
.759 .678 .773 r
.2758 .83236 m .2738 .82899 L .27115 .83132 L closepath p F P
0 g
s
.781 .624 .686 r
.24244 .90396 m .24449 .90064 L .24103 .89989 L closepath p F P
0 g
s
.779 .632 .698 r
.23946 .89583 m .24164 .89257 L p .24449 .90064 L F P
0 g
s
.779 .632 .698 r
.24449 .90064 m .24103 .89989 L .23946 .89583 L p F P
0 g
s
0 0 .37 r
.77076 .08823 m .77247 .09246 L .77063 .08869 L p F P
0 g
s
0 0 .37 r
.77063 .08869 m .76891 .08447 L .77076 .08823 L p F P
0 g
s
.679 .648 .812 r
.45665 .79373 m .44594 .79849 L .44297 .79319 L p F P
0 g
s
.903 .879 .802 r
.75516 .20314 m .75318 .20568 L .75389 .21008 L p F P
0 g
s
.894 .875 .81 r
.74782 .21222 m .74859 .21659 L .75389 .21008 L p F P
0 g
s
.894 .875 .81 r
.75389 .21008 m .75318 .20568 L .74782 .21222 L p F P
0 g
s
.998 .808 .463 r
.59014 .24106 m .59151 .24527 L .59233 .2404 L p F P
0 g
s
.998 .808 .463 r
.59233 .2404 m .59093 .23621 L .59014 .24106 L p F P
0 g
s
.616 .402 .568 r
.52361 .95928 m .52343 .9537 L .53525 .9518 L p F P
0 g
s
.622 .423 .591 r
.53482 .94601 m .53525 .9518 L .52343 .9537 L p F P
0 g
s
0 .014 .587 r
.7671 .08026 m .76891 .08447 L .7663 .08101 L p F P
0 g
s
0 .014 .587 r
.7663 .08101 m .76447 .07681 L .7671 .08026 L p F P
0 g
s
.74 .795 .896 r
.65019 .29347 m .65798 .28898 L .65534 .28595 L p F P
0 g
s
.74 .795 .896 r
.65534 .28595 m .64984 .28903 L .65019 .29347 L p F P
0 g
s
.742 .792 .893 r
.64439 .29206 m .64984 .28903 L .65019 .29347 L p F P
0 g
s
.814 .545 0 r
.59335 .26311 m .59252 .26023 L .59369 .26615 L p F P
0 g
s
.661 .622 .8 r
.50066 .8028 m .50303 .8075 L .49117 .80949 L p F P
0 g
s
.661 .622 .8 r
.49117 .80949 m .48989 .80695 L .50066 .8028 L p F P
0 g
s
.976 .819 .622 r
.5935 .21589 m .59313 .21702 L .59223 .21513 L closepath p F P
0 g
s
.961 .818 .658 r
.59134 .20362 m .59332 .20767 L .59544 .20236 L p F P
0 g
s
.961 .818 .658 r
.59544 .20236 m .59342 .19833 L .59134 .20362 L p F P
0 g
s
.617 .489 .684 r
.56399 .90765 m .563 .90346 L .57388 .89963 L p F P
0 g
s
.617 .489 .684 r
.57354 .8982 m .57388 .89963 L .563 .90346 L p F P
0 g
s
.746 .68 .787 r
.2986 .81702 m .29834 .8166 L .29795 .8169 L closepath p F P
0 g
s
.617 .47 .659 r
.56599 .91715 m .5667 .92082 L .55538 .92325 L p F P
0 g
s
.613 .455 .644 r
.55643 .92957 m .55538 .92325 L .5667 .92082 L p F P
0 g
s
.614 .417 .591 r
.53525 .9518 m .53482 .94601 L .54647 .94395 L p F P
0 g
s
.62 .435 .611 r
.54581 .93797 m .54647 .94395 L .53482 .94601 L p F P
0 g
s
.705 .777 .908 r
.64439 .29206 m .63343 .29727 L .63073 .29382 L p F P
0 g
s
.767 .544 .595 r
.27948 .95295 m .27136 .95168 L .2726 .94598 L p F P
0 g
s
.769 .546 .595 r
.26962 .9455 m .2726 .94598 L .27136 .95168 L p F P
0 g
s
.928 .878 .765 r
.7632 .18641 m .76559 .18273 L .76654 .18707 L p F P
0 g
s
.928 .878 .765 r
.76654 .18707 m .76557 .18856 L .7632 .18641 L p F P
0 g
s
.779 .649 .719 r
.23742 .876 m .24437 .87766 L .23929 .88436 L p F P
0 g
s
.778 .652 .723 r
.24285 .86921 m .23742 .876 L .24437 .87766 L p F P
0 g
s
.778 .652 .723 r
.2457 .8699 m .24285 .86921 L p .24437 .87766 L F P
0 g
s
.624 .368 .509 r
.49208 .96872 m .49933 .96791 L .49893 .97303 L p F P
0 g
s
.624 .368 .509 r
.49893 .97303 m .49487 .97348 L .49208 .96872 L p F P
0 g
s
.809 .839 .873 r
.69444 .27048 m .69326 .26922 L .69424 .26844 L closepath p F P
0 g
s
.915 .792 .71 r
.60177 .1631 m .60338 .16004 L .60063 .15652 L p F P
0 g
s
.747 .683 .789 r
.29522 .81161 m .29031 .81539 L .29795 .8169 L p F P
0 g
s
.747 .683 .789 r
.29795 .8169 m .29834 .8166 L .29522 .81161 L p F P
0 g
s
.721 .68 .81 r
.34408 .79259 m .34716 .79743 L .34029 .8017 L p F P
0 g
s
.721 .68 .81 r
.33343 .79917 m .34408 .79259 L p .34029 .8017 L F P
0 g
s
.721 .68 .81 r
.34029 .8017 m .33464 .80107 L .33343 .79917 L p F P
0 g
s
.716 .418 .471 r
.34896 .9815 m .3446 .98117 L .34264 .97625 L p F P
0 g
s
.715 .411 .462 r
.33481 .97568 m .34264 .97625 L .3446 .98117 L p F P
0 g
s
.742 .683 .793 r
.30902 .80866 m .29834 .8166 L .29522 .81161 L p F P
0 g
s
.961 .882 .71 r
.77339 .16925 m .77245 .17109 L .77176 .16801 L closepath p F P
0 g
s
.757 .519 .572 r
.29553 .96091 m .28732 .95983 L .28735 .95638 L p F P
0 g
s
.764 .525 .572 r
.28732 .95983 m .28735 .95638 L .28696 .95977 L closepath p F P
0 g
s
.618 .385 .541 r
.51162 .96101 m .51625 .96035 L .5173 .96556 L p F P
0 g
s
.618 .385 .541 r
.5173 .96556 m .51152 .96637 L .51162 .96101 L p F P
0 g
s
.626 .391 .542 r
.51162 .96101 m .51152 .96637 L .49933 .96791 L p F P
0 g
s
.635 .562 .756 r
.55346 .83681 m .55635 .84425 L p .5426 .8403 L F P
0 g
s
.635 .562 .756 r
.5426 .8403 m .55329 .83685 L .55346 .83681 L p F P
0 g
s
.636 .568 .761 r
.5426 .8403 m .55329 .83685 L .54228 .83948 L closepath p F P
0 g
s
.778 .659 .732 r
.2457 .8699 m .24443 .86735 L .24285 .86921 L closepath p F P
0 g
s
.629 .539 .734 r
.56515 .8691 m .56506 .86884 L .56181 .86989 L closepath p F P
0 g
s
.63 .54 .734 r
.56255 .86135 m .56506 .86884 L .56181 .86989 L p F P
0 g
s
.73 .681 .803 r
.33123 .8006 m .32278 .80624 L .31968 .80129 L p F P
0 g
s
.646 .595 .783 r
.53391 .81968 m .53487 .82183 L .5235 .82431 L p F P
0 g
s
.646 .595 .783 r
.5235 .82431 m .52309 .82339 L .53391 .81968 L p F P
0 g
s
.775 .658 .734 r
.24888 .86226 m .24443 .86735 L .24132 .86119 L p F P
0 g
s
.775 .658 .734 r
.24132 .86119 m .24183 .86061 L .24888 .86226 L p F P
0 g
s
.772 .663 .742 r
.24888 .86226 m .24183 .86061 L .24833 .85352 L p F P
0 g
s
.638 .576 .768 r
.55329 .83685 m .54228 .83948 L .5397 .83319 L p F P
0 g
s
.756 .499 .545 r
.30364 .96739 m .29555 .9663 L .29553 .96091 L p F P
0 g
s
.755 .498 .544 r
.28732 .95983 m .29553 .96091 L .29555 .9663 L p F P
0 g
s
.654 .607 .79 r
.51728 .81077 m .50649 .81472 L .50357 .80864 L p F P
0 g
s
.795 .832 .88 r
.68272 .27777 m .68239 .27741 L .68268 .2772 L closepath p F P
0 g
s
.925 .881 .772 r
.76246 .19313 m .76557 .18856 L .7632 .18641 L p F P
0 g
s
.781 .633 .697 r
.23946 .89583 m .24164 .89257 L .23788 .89172 L closepath p F P
0 g
s
.779 .641 .708 r
.23645 .88832 m .23929 .88436 L p .24164 .89257 L F P
0 g
s
.779 .641 .708 r
.24164 .89257 m .23788 .89172 L .23645 .88832 L p F P
0 g
s
.984 .813 .594 r
.58975 .21806 m .59165 .22211 L .59313 .21702 L p F P
0 g
s
.984 .813 .594 r
.59079 .21445 m .58975 .21806 L p .59313 .21702 L F P
0 g
s
.984 .813 .594 r
.59313 .21702 m .59223 .21513 L .59079 .21445 L p F P
0 g
s
.696 .396 .464 r
.37674 .98285 m .36555 .98242 L .36449 .9803 L p F P
0 g
s
.697 .397 .463 r
.36555 .98242 m .36397 .98235 L .36449 .9803 L closepath p F P
0 g
s
.742 .466 .513 r
.31903 .97421 m .314 .97364 L .31317 .96845 L p F P
0 g
s
.742 .465 .511 r
.30412 .96744 m .31317 .96845 L .314 .97364 L p F P
0 g
s
.784 .616 .672 r
.24375 .90771 m .24063 .907 L p .24434 .91483 L F P
0 g
s
.784 .616 .672 r
.24434 .91483 m .24537 .91295 L .24375 .90771 L p F P
0 g
s
.785 .625 .683 r
.24375 .90771 m .24244 .90396 L .24063 .907 L closepath p F P
0 g
s
.695 .666 .818 r
.41416 .79373 m .40226 .79385 L .40194 .79332 L p F P
0 g
s
.699 .668 .816 r
.40226 .79385 m .40194 .79332 L .40095 .79383 L closepath p F P
0 g
s
.672 .637 .807 r
.47381 .80094 m .47328 .79995 L .46977 .80143 L closepath p F P
0 g
s
.674 .641 .809 r
.47033 .79455 m .47328 .79995 L .46977 .80143 L p F P
0 g
s
.674 .641 .809 r
.4596 .79908 m .47033 .79455 L p .46977 .80143 L F P
0 g
s
.701 .668 .814 r
.38826 .7939 m .38876 .79364 L .40095 .79383 L p F P
0 g
s
.701 .673 .82 r
.39892 .78847 m .38876 .79364 L .40095 .79383 L p F P
0 g
s
.701 .673 .82 r
.40095 .79383 m .40194 .79332 L .39892 .78847 L p F P
0 g
s
.673 .642 .811 r
.47033 .79455 m .4596 .79908 L .45665 .79373 L p F P
0 g
s
.993 .853 .594 r
.77632 .1418 m .77789 .13669 L .77918 .14098 L p F P
0 g
s
.993 .853 .594 r
.77642 .14213 m .77632 .1418 L p .77918 .14098 L F P
0 g
s
.993 .853 .594 r
.77918 .14098 m .7785 .14317 L .77642 .14213 L p F P
0 g
s
.614 .478 .672 r
.56544 .91432 m .56399 .90765 L .57516 .90504 L p F P
0 g
s
.617 .489 .684 r
.57388 .89963 m .57516 .90504 L .56399 .90765 L p F P
0 g
s
.784 .616 .672 r
.24606 .91521 m .24537 .91295 L .24434 .91483 L closepath p F P
0 g
s
.647 .597 .784 r
.53391 .81968 m .52309 .82339 L .52019 .81698 L p F P
0 g
s
.779 .604 .662 r
.24857 .92252 m .24799 .92241 L .24606 .91521 L p F P
0 g
s
.786 .607 .659 r
.24434 .91483 m .24606 .91521 L .24799 .92241 L p F P
0 g
s
.612 .43 .612 r
.54647 .94395 m .54581 .93797 L .55731 .93573 L p F P
0 g
s
.617 .446 .628 r
.55643 .92957 m .55731 .93573 L .54581 .93797 L p F P
0 g
s
.785 .626 .683 r
.24063 .907 m .24244 .90396 L .24103 .89989 L p F P
0 g
s
.695 .666 .818 r
.41261 .78811 m .41562 .79301 L .41416 .79373 L p F P
0 g
s
.695 .666 .818 r
.40194 .79332 m .41261 .78811 L p .41416 .79373 L F P
0 g
s
.694 .664 .816 r
.41603 .7937 m .41562 .79301 L .41416 .79373 L closepath p F P
0 g
s
.701 .669 .816 r
.38826 .7939 m .38876 .79364 L .38809 .79362 L closepath p F P
0 g
s
.706 .672 .814 r
.38809 .79362 m .38826 .7939 L p .37457 .79479 L F P
0 g
s
.69 .662 .818 r
.42863 .79327 m .41603 .7937 L .41562 .79301 L p F P
0 g
s
.776 .551 .594 r
.26477 .94463 m .26962 .9455 L .26997 .95146 L p F P
0 g
s
.769 .546 .595 r
.27136 .95168 m .26997 .95146 L .26962 .9455 L p F P
0 g
s
.707 .673 .814 r
.37457 .79479 m .37756 .79316 L .37345 .79297 L closepath p F P
0 g
s
.712 .676 .813 r
.37345 .79297 m .37457 .79479 L p .36087 .79597 L F P
0 g
s
.706 .672 .814 r
.37457 .79479 m .37756 .79316 L .38809 .79362 L p F P
0 g
s
.661 .622 .799 r
.50066 .8028 m .48989 .80695 L .48696 .8012 L p F P
0 g
s
.695 .672 .824 r
.41261 .78811 m .40194 .79332 L .39892 .78847 L p F P
0 g
s
.7 .675 .822 r
.39589 .78368 m .39892 .78847 L .38876 .79364 L p F P
0 g
s
.7 .675 .822 r
.38522 .78909 m .39589 .78368 L p .38876 .79364 L F P
0 g
s
.7 .675 .822 r
.38876 .79364 m .38809 .79362 L .38522 .78909 L p F P
0 g
s
.989 .771 .385 r
.77707 .11836 m .77852 .12263 L .7789 .11798 L p F P
0 g
s
.989 .771 .385 r
.7789 .11798 m .77746 .11371 L .77707 .11836 L p F P
0 g
s
.705 .677 .82 r
.38809 .79362 m .38522 .78909 L .37756 .79316 L closepath p F P
0 g
s
.785 .626 .683 r
.24103 .89989 m .2374 .89903 L p .24063 .907 L F P
0 g
s
.785 .634 .694 r
.24103 .89989 m .23946 .89583 L .2374 .89903 L closepath p F P
0 g
s
.944 .879 .741 r
.76816 .17251 m .76916 .17685 L .77245 .17109 L p F P
0 g
s
.944 .879 .741 r
.77107 .16741 m .76816 .17251 L p .77245 .17109 L F P
0 g
s
.944 .879 .741 r
.77245 .17109 m .77176 .16801 L .77107 .16741 L p F P
0 g
s
.885 .869 .817 r
.74459 .21601 m .74782 .21222 L .74859 .21659 L p F P
0 g
s
.885 .869 .817 r
.74859 .21659 m .74703 .21842 L .74459 .21601 L p F P
0 g
s
.765 .525 .572 r
.27948 .95295 m .27884 .95851 L .28696 .95977 L p F P
0 g
s
.766 .527 .572 r
.27136 .95168 m .27948 .95295 L .27884 .95851 L p F P
0 g
s
.378 .561 .906 r
.74727 .05423 m .74059 .05296 L .74281 .05706 L p F P
0 g
s
.378 .561 .906 r
.74281 .05706 m .74982 .05845 L .74727 .05423 L p F P
0 g
s
.451 .609 .915 r
.73561 .05258 m .74059 .05296 L .74281 .05706 L p F P
0 g
s
.794 .828 .878 r
.68268 .2772 m .68239 .27741 L .6798 .27455 L p F P
0 g
s
.783 .826 .886 r
.6689 .28212 m .6798 .27455 L .68239 .27741 L p F P
0 g
s
.972 .872 .677 r
.77301 .15687 m .77417 .16118 L .77657 .15575 L p F P
0 g
s
.972 .872 .677 r
.77657 .15575 m .77543 .15143 L .77301 .15687 L p F P
0 g
s
.764 .675 .764 r
.26323 .83904 m .26304 .83871 L .26279 .83894 L closepath p F P
0 g
s
.718 .679 .811 r
.35833 .79191 m .36087 .79597 L p .34716 .79743 L F P
0 g
s
.712 .676 .813 r
.36087 .79597 m .36693 .79251 L .37345 .79297 L p F P
0 g
s
.712 .675 .813 r
.36087 .79597 m .36693 .79251 L .35833 .79191 L closepath p F P
0 g
s
.655 .331 .412 r
.40691 .98328 m .41395 .98321 L .41833 .98755 L p F P
0 g
s
.655 .331 .412 r
.41833 .98755 m .40546 .98769 L .40691 .98328 L p F P
0 g
s
.664 .34 .415 r
.40087 .98326 m .40691 .98328 L .40546 .98769 L p F P
0 g
s
.728 .682 .806 r
.33464 .80107 m .33343 .79917 L .33123 .8006 L closepath p F P
0 g
s
.778 .66 .733 r
.24285 .86921 m .24443 .86735 L .24132 .86119 L p F P
0 g
s
.797 .831 .877 r
.68268 .2772 m .69326 .26922 L .69069 .26643 L p F P
0 g
s
.797 .831 .877 r
.69069 .26643 m .68219 .2728 L .68268 .2772 L p F P
0 g
s
.794 .828 .878 r
.6798 .27455 m .68219 .2728 L .68268 .2772 L p F P
0 g
s
.715 .411 .462 r
.33396 .97903 m .33481 .97568 L p .3446 .98117 L F P
0 g
s
.726 .428 .475 r
.33396 .97903 m .33271 .97549 L .33481 .97568 L closepath p F P
0 g
s
.664 .34 .415 r
.40546 .98769 m .40492 .98769 L .40087 .98326 L p F P
0 g
s
.66 .324 .393 r
.3929 .98322 m .40087 .98326 L .40492 .98769 L p F P
0 g
s
.58 .684 .912 r
.71913 .04603 m .72309 .04537 L .72553 .04941 L p F P
0 g
s
.558 .672 .914 r
.7305 .04445 m .72309 .04537 L .72553 .04941 L p F P
0 g
s
.558 .672 .914 r
.72553 .04941 m .73306 .0485 L .7305 .04445 L p F P
0 g
s
.778 .592 .647 r
.2482 .92335 m .24857 .92252 L p .25342 .93004 L F P
0 g
s
.781 .594 .647 r
.2482 .92335 m .24857 .92252 L .24799 .92241 L closepath p F P
0 g
s
.689 .668 .824 r
.4263 .788 m .41562 .79301 L .41261 .78811 L p F P
0 g
s
.69 .662 .818 r
.41562 .79301 m .4263 .788 L p .42863 .79327 L F P
0 g
s
.66 .324 .393 r
.39165 .98694 m .3929 .98322 L p .40492 .98769 L F P
0 g
s
.675 .351 .418 r
.39165 .98694 m .38852 .98313 L .3929 .98322 L closepath p F P
0 g
s
.654 .331 .414 r
.41395 .98321 m .42064 .98311 L .41924 .98754 L p F P
0 g
s
.654 .331 .414 r
.41924 .98754 m .41833 .98755 L .41395 .98321 L p F P
0 g
s
.761 .676 .768 r
.27115 .83132 m .26304 .83871 L .2599 .83339 L p F P
0 g
s
.766 .678 .766 r
.26279 .83894 m .26304 .83871 L .2599 .83339 L p F P
0 g
s
.765 .674 .762 r
.25581 .83725 m .26279 .83894 L .25529 .8463 L p F P
0 g
s
.766 .678 .766 r
.2599 .83339 m .25581 .83725 L .26279 .83894 L p F P
0 g
s
.777 .579 .632 r
.25882 .93741 m .25118 .93599 L .25342 .93004 L p F P
0 g
s
.779 .582 .633 r
.24952 .92929 m .25342 .93004 L .25118 .93599 L p F P
0 g
s
.778 .592 .647 r
.25342 .93004 m .24952 .92929 L .2482 .92335 L p F P
0 g
s
.88 .871 .824 r
.74269 .22332 m .74703 .21842 L .74459 .21601 L p F P
0 g
s
.905 .677 .171 r
.59121 .25454 m .59226 .25884 L .59216 .25429 L p F P
0 g
s
.905 .677 .171 r
.59216 .25429 m .59109 .25 L .59121 .25454 L p F P
0 g
s
.632 .352 .475 r
.47395 .97582 m .47376 .97559 L .47399 .97557 L closepath p F P
0 g
s
.633 .348 .468 r
.47376 .97559 m .47395 .97582 L p .46037 .98137 L F P
0 g
s
.761 .676 .768 r
.2599 .83339 m .26397 .82968 L .27115 .83132 L p F P
0 g
s
.759 .679 .773 r
.27066 .82378 m .26397 .82968 L .27115 .83132 L p F P
0 g
s
.759 .679 .773 r
.27115 .83132 m .2738 .82899 L .27066 .82378 L p F P
0 g
s
.787 .609 .66 r
.23726 .91324 m .24434 .91483 L .24138 .92096 L p F P
0 g
s
.784 .616 .672 r
.24063 .907 m .23726 .91324 L .24434 .91483 L p F P
0 g
s
.786 .607 .659 r
.24799 .92241 m .24138 .92096 L .24434 .91483 L p F P
0 g
s
.667 .635 .808 r
.48403 .79565 m .48594 .79922 L .47381 .80094 L p F P
0 g
s
.667 .635 .808 r
.47381 .80094 m .47328 .79995 L .48403 .79565 L p F P
0 g
s
.621 .337 .465 r
.47399 .97557 m .48654 .97438 L .48575 .9792 L p F P
0 g
s
.621 .337 .465 r
.47395 .97582 m .47399 .97557 L p .48575 .9792 L F P
0 g
s
.785 .596 .645 r
.24799 .92241 m .24138 .92096 L p .24601 .92855 L F P
0 g
s
.785 .596 .645 r
.24601 .92855 m .2482 .92335 L .24799 .92241 L p F P
0 g
s
.755 .678 .777 r
.28027 .82349 m .2738 .82899 L .27066 .82378 L p F P
0 g
s
.915 .792 .71 r
.60063 .15652 m .59923 .15921 L .60177 .1631 L p F P
0 g
s
.917 .791 .706 r
.59638 .16475 m .59892 .16865 L .60177 .1631 L p F P
0 g
s
.917 .791 .706 r
.60177 .1631 m .59923 .15921 L .59638 .16475 L p F P
0 g
s
.672 .339 .401 r
.38852 .98313 m .39165 .98694 L .3914 .9876 L p F P
0 g
s
.672 .339 .401 r
.3786 .98292 m .38852 .98313 L p .3914 .9876 L F P
0 g
s
.616 .383 .541 r
.51625 .96035 m .52361 .95928 L .52354 .96466 L p F P
0 g
s
.616 .383 .541 r
.52354 .96466 m .5173 .96556 L .51625 .96035 L p F P
0 g
s
.785 .635 .694 r
.2374 .89903 m .23946 .89583 L .23788 .89172 L p F P
0 g
s
.645 .323 .411 r
.42064 .98311 m .42792 .98292 L .43265 .98718 L p F P
0 g
s
.645 .323 .411 r
.43265 .98718 m .41924 .98754 L .42064 .98311 L p F P
0 g
s
.78 .656 .726 r
.23602 .8675 m .24285 .86921 L .23742 .876 L p F P
0 g
s
.778 .66 .733 r
.24132 .86119 m .23602 .8675 L .24285 .86921 L p F P
0 g
s
.689 .66 .816 r
.42946 .79323 m .42929 .79295 L .42863 .79327 L closepath p F P
0 g
s
.69 .662 .818 r
.4263 .788 m .42929 .79295 L .42863 .79327 L p F P
0 g
s
.616 .361 .508 r
.49893 .97303 m .49933 .96791 L .51152 .96637 L p F P
0 g
s
.727 .425 .468 r
.33271 .97549 m .33396 .97903 L .33359 .98036 L p F P
0 g
s
.727 .425 .468 r
.32323 .9746 m .33271 .97549 L p .33359 .98036 L F P
0 g
s
.736 .679 .794 r
.30902 .80866 m .30941 .80839 L .30879 .80829 L closepath p F P
0 g
s
.742 .683 .793 r
.30879 .80829 m .30902 .80866 L p .29522 .81161 L F P
0 g
s
.782 .642 .707 r
.23645 .88832 m .23929 .88436 L .23427 .88318 L closepath p F P
0 g
s
.779 .649 .719 r
.23339 .88126 m .23742 .876 L p .23929 .88436 L F P
0 g
s
.779 .649 .719 r
.23929 .88436 m .23427 .88318 L .23339 .88126 L p F P
0 g
s
.683 .657 .819 r
.43999 .78815 m .44253 .79242 L .42946 .79323 L p F P
0 g
s
.683 .657 .819 r
.42946 .79323 m .42929 .79295 L .43999 .78815 L p F P
0 g
s
.785 .596 .645 r
.24952 .92929 m .2482 .92335 L .24601 .92855 L closepath p F P
0 g
s
.925 .804 .707 r
.59327 .17975 m .59608 .1742 L .59843 .17815 L p F P
0 g
s
.925 .804 .707 r
.59523 .18309 m .59327 .17975 L p .59843 .17815 L F P
0 g
s
.925 .804 .707 r
.59843 .17815 m .59566 .18358 L .59523 .18309 L p F P
0 g
s
.734 .684 .802 r
.31805 .79872 m .31968 .80129 L .30941 .80839 L p F P
0 g
s
.734 .684 .802 r
.31419 .79807 m .31805 .79872 L p .30941 .80839 L F P
0 g
s
.734 .684 .802 r
.3059 .80379 m .31419 .79807 L p .30941 .80839 L F P
0 g
s
.734 .684 .802 r
.30941 .80839 m .30879 .80829 L .3059 .80379 L p F P
0 g
s
.621 .337 .465 r
.48575 .9792 m .4783 .97991 L .47395 .97582 L p F P
0 g
s
.623 .336 .462 r
.4783 .97991 m .47316 .98038 L .47395 .97582 L closepath p F P
0 g
s
.633 .348 .468 r
.47395 .97582 m .47316 .98038 L .46037 .98137 L p F P
0 g
s
.895 .785 .733 r
.59975 .14966 m .60243 .15353 L .60594 .14775 L p F P
0 g
s
.895 .785 .733 r
.60594 .14775 m .60326 .14388 L .59975 .14966 L p F P
0 g
s
.718 .679 .811 r
.34716 .79743 m .35668 .79175 L .35833 .79191 L p F P
0 g
s
.717 .683 .816 r
.35668 .79175 m .34716 .79743 L .34408 .79259 L p F P
0 g
s
.998 .814 .531 r
.5893 .23208 m .59093 .23621 L .59202 .23125 L p F P
0 g
s
.998 .814 .531 r
.59202 .23125 m .59036 .22713 L .5893 .23208 L p F P
0 g
s
.621 .526 .725 r
.56753 .87664 m .56515 .8691 L .57615 .86625 L p F P
0 g
s
.623 .535 .735 r
.57596 .8657 m .57615 .86625 L .56515 .8691 L p F P
0 g
s
.623 .535 .735 r
.56515 .8691 m .56506 .86884 L .57596 .8657 L p F P
0 g
s
.705 .678 .821 r
.38218 .78435 m .38522 .78909 L .37756 .79316 L p F P
0 g
s
.705 .678 .821 r
.37152 .78997 m .38218 .78435 L p .37756 .79316 L F P
0 g
s
.705 .678 .821 r
.37756 .79316 m .37345 .79297 L .37152 .78997 L p F P
0 g
s
.623 .536 .735 r
.57355 .85849 m .57596 .8657 L .56506 .86884 L p F P
0 g
s
.623 .536 .735 r
.56506 .86884 m .56255 .86135 L .57355 .85849 L p F P
0 g
s
.768 .668 .752 r
.25221 .84943 m .25529 .8463 L .24979 .84503 L closepath p F P
0 g
s
.765 .674 .762 r
.24908 .84379 m .25581 .83725 L p .25529 .8463 L F P
0 g
s
.765 .674 .762 r
.25529 .8463 m .24979 .84503 L .24908 .84379 L p F P
0 g
s
.638 .576 .769 r
.5499 .82811 m .55056 .82971 L .5397 .83319 L p F P
0 g
s
.638 .576 .769 r
.5397 .83319 m .53872 .8308 L .5499 .82811 L p F P
0 g
s
.638 .576 .768 r
.5397 .83319 m .55056 .82971 L p .55329 .83685 L F P
0 g
s
.684 .664 .824 r
.43999 .78815 m .42929 .79295 L .4263 .788 L p F P
0 g
s
.452 .612 .917 r
.74059 .05296 m .73561 .05258 L .73306 .0485 L p F P
0 g
s
.777 .566 .614 r
.26477 .94463 m .25709 .94323 L .25882 .93741 L p F P
0 g
s
.778 .567 .615 r
.25118 .93599 m .25882 .93741 L .25709 .94323 L p F P
0 g
s
.753 .681 .782 r
.28139 .81489 m .27286 .82191 L .28027 .82349 L p F P
0 g
s
.753 .681 .782 r
.28027 .82349 m .28452 .81998 L .28139 .81489 L p F P
0 g
s
.755 .678 .777 r
.27066 .82378 m .27286 .82191 L .28027 .82349 L p F P
0 g
s
.621 .526 .725 r
.57615 .86625 m .57853 .87381 L .56753 .87664 L p F P
0 g
s
.618 .517 .716 r
.56798 .87817 m .56753 .87664 L .57853 .87381 L p F P
0 g
s
.742 .683 .793 r
.29522 .81161 m .30152 .80694 L .30879 .80829 L p F P
0 g
s
.741 .686 .798 r
.30879 .80829 m .3059 .80379 L .30152 .80694 L closepath p F P
0 g
s
.787 .62 .674 r
.23363 .90538 m .24063 .907 L .23726 .91324 L p F P
0 g
s
.785 .626 .683 r
.2374 .89903 m .23363 .90538 L .24063 .907 L p F P
0 g
s
.262 .39 .804 r
.60031 .28325 m .60079 .28352 L .6008 .2843 L closepath p F P
0 g
s
.466 .543 .852 r
.60863 .28534 m .60079 .28352 L .6008 .2843 L p F P
0 g
s
.466 .543 .852 r
.60935 .28969 m .60863 .28534 L p .6008 .2843 L F P
0 g
s
.644 .323 .414 r
.42792 .98292 m .43411 .98273 L .43277 .98718 L p F P
0 g
s
.644 .323 .414 r
.43277 .98718 m .43265 .98718 L .42792 .98292 L p F P
0 g
s
.672 .339 .401 r
.37803 .98463 m .3786 .98292 L p .3914 .9876 L F P
0 g
s
.686 .364 .425 r
.37803 .98463 m .37674 .98285 L .3786 .98292 L closepath p F P
0 g
s
.668 .639 .812 r
.48403 .79565 m .47328 .79995 L .47033 .79455 L p F P
0 g
s
.618 .516 .716 r
.56971 .884 m .56798 .87817 L .57889 .87501 L p F P
0 g
s
.618 .517 .716 r
.57853 .87381 m .57889 .87501 L .56798 .87817 L p F P
0 g
s
.925 .881 .772 r
.7632 .18641 m .76161 .18876 L .76246 .19313 L p F P
0 g
s
.914 .877 .785 r
.75713 .19498 m .75803 .19933 L .76246 .19313 L p F P
0 g
s
.914 .877 .785 r
.76246 .19313 m .76161 .18876 L .75713 .19498 L p F P
0 g
s
.992 .859 .604 r
.7785 .14317 m .77753 .14612 L .77642 .14213 L closepath p F P
0 g
s
.762 .808 .89 r
.66871 .28224 m .65798 .28898 L .65534 .28595 L p F P
0 g
s
.772 .669 .749 r
.24833 .85352 m .25221 .84943 L .24979 .84503 L p F P
0 g
s
.73 .681 .803 r
.31968 .80129 m .32258 .79937 L .33123 .8006 L p F P
0 g
s
.729 .686 .808 r
.33033 .79439 m .32258 .79937 L .33123 .8006 L p F P
0 g
s
.729 .686 .808 r
.33123 .8006 m .33343 .79917 L .33033 .79439 L p F P
0 g
s
.625 .545 .743 r
.57305 .85706 m .57355 .85849 L .56255 .86135 L p F P
0 g
s
.625 .545 .743 r
.56255 .86135 m .56215 .8602 L .57305 .85706 L p F P
0 g
s
.684 .353 .408 r
.37674 .98285 m .37803 .98463 L .37701 .98726 L p F P
0 g
s
.684 .353 .408 r
.36555 .98242 m .37674 .98285 L p .37701 .98726 L F P
0 g
s
.785 .635 .694 r
.23788 .89172 m .23463 .89093 L p .2374 .89903 L F P
0 g
s
.785 .643 .705 r
.23788 .89172 m .23645 .88832 L .23463 .89093 L closepath p F P
0 g
s
.71 .68 .818 r
.37345 .79297 m .37152 .78997 L .36693 .79251 L closepath p F P
0 g
s
.951 .806 .665 r
.59123 .19435 m .59342 .19833 L .5956 .19301 L p F P
0 g
s
.951 .806 .665 r
.5956 .19301 m .59338 .18903 L .59123 .19435 L p F P
0 g
s
.625 .545 .744 r
.57075 .85053 m .57305 .85706 L .56215 .8602 L p F P
0 g
s
.625 .545 .744 r
.56215 .8602 m .55975 .85339 L .57075 .85053 L p F P
0 g
s
.748 .68 .785 r
.29031 .81539 m .28452 .81998 L .28139 .81489 L p F P
0 g
s
.873 .867 .83 r
.73571 .22582 m .73645 .23018 L .74269 .22332 L p F P
0 g
s
.873 .867 .83 r
.74269 .22332 m .74202 .21893 L .73571 .22582 L p F P
0 g
s
.88 .871 .824 r
.74459 .21601 m .74202 .21893 L .74269 .22332 L p F P
0 g
s
.609 .441 .629 r
.55731 .93573 m .55643 .92957 L .56777 .92715 L p F P
0 g
s
.613 .455 .644 r
.5667 .92082 m .56777 .92715 L .55643 .92957 L p F P
0 g
s
.636 .315 .411 r
.43277 .98718 m .43411 .98273 L .44301 .98235 L p F P
0 g
s
.616 .507 .707 r
.57092 .88832 m .56971 .884 L .58072 .88118 L p F P
0 g
s
.618 .516 .716 r
.57889 .87501 m .58072 .88118 L .56971 .884 L p F P
0 g
s
.172 .325 .778 r
.60079 .28352 m .60031 .28325 L .59747 .2768 L p F P
0 g
s
.639 .584 .777 r
.54766 .82287 m .5499 .82811 L .53872 .8308 L p F P
0 g
s
.639 .584 .777 r
.53872 .8308 m .53681 .82633 L .54766 .82287 L p F P
0 g
s
.61 .465 .659 r
.56599 .91715 m .56544 .91432 L .57662 .91172 L p F P
0 g
s
.614 .478 .672 r
.57516 .90504 m .57662 .91172 L .56544 .91432 L p F P
0 g
s
.961 .707 .265 r
.77593 .10945 m .77746 .11371 L .77738 .10925 L p F P
0 g
s
.961 .707 .265 r
.77738 .10925 m .77586 .10498 L .77593 .10945 L p F P
0 g
s
.647 .716 .899 r
.70536 .04561 m .71656 .04202 L .71913 .04603 L p F P
0 g
s
.773 .667 .746 r
.24143 .85181 m .24833 .85352 L .24183 .86061 L p F P
0 g
s
.772 .669 .749 r
.24825 .84464 m .24143 .85181 L .24833 .85352 L p F P
0 g
s
.772 .669 .749 r
.24979 .84503 m .24825 .84464 L p .24833 .85352 L F P
0 g
s
.742 .465 .511 r
.314 .97364 m .30497 .97263 L .30412 .96744 L p F P
0 g
s
.743 .466 .511 r
.30364 .96739 m .30412 .96744 L .30497 .97263 L p F P
0 g
s
.755 .498 .544 r
.28695 .96427 m .28732 .95983 L p .29555 .9663 L F P
0 g
s
.763 .506 .546 r
.28695 .96427 m .28696 .95977 L .28732 .95983 L closepath p F P
0 g
s
.724 .686 .814 r
.34408 .79259 m .33343 .79917 L .33033 .79439 L p F P
0 g
s
.776 .551 .594 r
.26997 .95146 m .26358 .95032 L .26477 .94463 L p F P
0 g
s
.777 .552 .595 r
.25709 .94323 m .26477 .94463 L .26358 .95032 L p F P
0 g
s
.787 .629 .686 r
.23049 .89737 m .2374 .89903 L .23363 .90538 L p F P
0 g
s
.785 .635 .694 r
.23463 .89093 m .23049 .89737 L .2374 .89903 L p F P
0 g
s
.743 .466 .511 r
.30497 .97263 m .30277 .97238 L .30364 .96739 L p F P
0 g
s
.752 .475 .512 r
.29555 .9663 m .30364 .96739 L .30277 .97238 L p F P
0 g
s
.679 .648 .812 r
.45529 .79131 m .45665 .79373 L p .44297 .79319 L F P
0 g
s
.679 .648 .812 r
.44297 .79319 m .44519 .79221 L .45529 .79131 L p F P
0 g
s
.68 .653 .816 r
.44297 .79319 m .44519 .79221 L .44253 .79242 L closepath p F P
0 g
s
.822 .846 .866 r
.70458 .26098 m .7041 .26047 L .70449 .26014 L closepath p F P
0 g
s
.765 .508 .545 r
.28696 .95977 m .28695 .96427 L .28687 .96516 L p F P
0 g
s
.765 .508 .545 r
.27884 .95851 m .28696 .95977 L p .28687 .96516 L F P
0 g
s
.627 .553 .752 r
.57014 .84889 m .57075 .85053 L .55975 .85339 L p F P
0 g
s
.627 .553 .752 r
.55975 .85339 m .55925 .85203 L .57014 .84889 L p F P
0 g
s
.808 .836 .872 r
.69424 .26844 m .69326 .26922 L .69069 .26643 L p F P
0 g
s
.785 .644 .705 r
.23463 .89093 m .23645 .88832 L .23427 .88318 L p F P
0 g
s
.616 .506 .706 r
.57171 .89119 m .57092 .88832 L .58183 .88516 L p F P
0 g
s
.616 .507 .707 r
.58072 .88118 m .58183 .88516 L .57092 .88832 L p F P
0 g
s
.748 .68 .785 r
.28139 .81489 m .28267 .81387 L .29031 .81539 L p F P
0 g
s
.747 .684 .79 r
.29209 .80664 m .28267 .81387 L .29031 .81539 L p F P
0 g
s
.747 .684 .79 r
.29031 .81539 m .29522 .81161 L .29209 .80664 L p F P
0 g
s
.647 .597 .784 r
.52019 .81698 m .53101 .81324 L .53391 .81968 L p F P
0 g
s
.648 .599 .786 r
.53069 .81252 m .53101 .81324 L .52019 .81698 L p F P
0 g
s
.648 .599 .786 r
.52019 .81698 m .51928 .81499 L .53069 .81252 L p F P
0 g
s
.999 .834 .544 r
.7765 .13241 m .77789 .13669 L .77908 .13172 L p F P
0 g
s
.999 .834 .544 r
.77908 .13172 m .77771 .12744 L .7765 .13241 L p F P
0 g
s
.654 .607 .79 r
.51466 .80527 m .51728 .81077 L p .50357 .80864 L F P
0 g
s
.654 .607 .79 r
.50357 .80864 m .5105 .80608 L .51466 .80527 L p F P
0 g
s
.656 .614 .795 r
.50357 .80864 m .5105 .80608 L .50303 .8075 L closepath p F P
0 g
s
.812 .838 .87 r
.69424 .26844 m .7041 .26047 L .70155 .25774 L p F P
0 g
s
.812 .838 .87 r
.70155 .25774 m .69372 .26404 L .69424 .26844 L p F P
0 g
s
.808 .836 .872 r
.69069 .26643 m .69372 .26404 L .69424 .26844 L p F P
0 g
s
.966 .82 .648 r
.58938 .20888 m .59131 .21294 L .59332 .20767 L p F P
0 g
s
.966 .82 .648 r
.59332 .20767 m .59134 .20362 L .58938 .20888 L p F P
0 g
s
.779 .582 .633 r
.25118 .93599 m .2507 .9359 L .24952 .92929 L p F P
0 g
s
.786 .586 .63 r
.24601 .92855 m .24952 .92929 L .2507 .9359 L p F P
0 g
s
.627 .554 .752 r
.56772 .84234 m .57014 .84889 L .55925 .85203 L p F P
0 g
s
.627 .554 .752 r
.55925 .85203 m .55672 .84522 L .56772 .84234 L p F P
0 g
s
.71 .681 .82 r
.36846 .78527 m .37152 .78997 L .36693 .79251 L p F P
0 g
s
.71 .681 .82 r
.35781 .7911 m .36846 .78527 L p .36693 .79251 L F P
0 g
s
.71 .681 .82 r
.36693 .79251 m .35833 .79191 L .35781 .7911 L p F P
0 g
s
.684 .353 .408 r
.37701 .98726 m .36917 .98694 L .36555 .98242 L p F P
0 g
s
.684 .353 .408 r
.36397 .98235 m .36555 .98242 L .36917 .98694 L p F P
0 g
s
.374 .501 .859 r
.60755 .28111 m .60863 .28534 L .60079 .28352 L p F P
0 g
s
.374 .501 .859 r
.60079 .28352 m .60046 .27902 L .60755 .28111 L p F P
0 g
s
.172 .325 .778 r
.59747 .2768 m .60046 .27902 L .60079 .28352 L p F P
0 g
s
.865 .865 .836 r
.73647 .23032 m .73639 .23024 L .73645 .23018 L closepath p F P
0 g
s
.979 .832 .626 r
.59223 .21513 m .59079 .21445 L .59131 .21294 L closepath p F P
0 g
s
.684 .353 .408 r
.36917 .98694 m .36231 .98666 L .36397 .98235 L p F P
0 g
s
.695 .364 .412 r
.35493 .98184 m .36397 .98235 L .36231 .98666 L p F P
0 g
s
.635 .318 .418 r
.44648 .98524 m .44301 .98235 L .44735 .98215 L closepath p F P
0 g
s
.636 .315 .411 r
.44301 .98235 m .44648 .98524 L p .43277 .98718 L F P
0 g
s
.782 .65 .716 r
.23742 .876 m .23339 .88126 L .23032 .87456 L p F P
0 g
s
.782 .65 .716 r
.23032 .87456 m .23051 .87431 L .23742 .876 L p F P
0 g
s
.78 .656 .726 r
.23742 .876 m .23051 .87431 L .23602 .8675 L p F P
0 g
s
.613 .496 .696 r
.57354 .8982 m .57171 .89119 L .58273 .88838 L p F P
0 g
s
.616 .506 .706 r
.58183 .88516 m .58273 .88838 L .57171 .89119 L p F P
0 g
s
.68 .659 .822 r
.44519 .79221 m .44253 .79242 L .43999 .78815 L p F P
0 g
s
.864 .86 .835 r
.73392 .2277 m .73571 .22582 L .73645 .23018 L p F P
0 g
s
.864 .86 .835 r
.73645 .23018 m .73639 .23024 L .73392 .2277 L p F P
0 g
s
.858 .861 .841 r
.72939 .23734 m .73639 .23024 L .73392 .2277 L p F P
0 g
s
0 .045 .612 r
.59672 .27574 m .59626 .27394 L .59747 .2768 L closepath p F P
0 g
s
.656 .62 .802 r
.5105 .80608 m .50303 .8075 L .50066 .8028 L p F P
0 g
s
.61 .465 .659 r
.57662 .91172 m .57688 .91304 L .56599 .91715 L p F P
0 g
s
.61 .464 .659 r
.5667 .92082 m .56599 .91715 L .57688 .91304 L p F P
0 g
s
.985 .771 .37 r
.58975 .24579 m .59109 .25 L .59151 .24527 L p F P
0 g
s
.985 .771 .37 r
.59151 .24527 m .59014 .24106 L .58975 .24579 L p F P
0 g
s
.727 .425 .468 r
.33359 .98036 m .32508 .97955 L .32323 .9746 L p F P
0 g
s
.726 .425 .469 r
.31903 .97421 m .32323 .9746 L .32508 .97955 L p F P
0 g
s
.742 .684 .794 r
.30152 .80694 m .29522 .81161 L .29209 .80664 L p F P
0 g
s
.608 .396 .568 r
.53544 .95739 m .53525 .9518 L .54692 .94975 L p F P
0 g
s
.614 .417 .591 r
.54647 .94395 m .54692 .94975 L .53525 .9518 L p F P
0 g
s
.616 .402 .568 r
.53525 .9518 m .53544 .95739 L .52361 .95928 L p F P
0 g
s
.23 .459 .874 r
.75236 .06273 m .75238 .06274 L .75246 .06289 L closepath p F P
0 g
s
.105 .372 .834 r
.75699 .06539 m .75238 .06274 L .75246 .06289 L p F P
0 g
s
.105 .372 .834 r
.75902 .06955 m .75699 .06539 L p .75246 .06289 L F P
0 g
s
.937 .876 .75 r
.76455 .1784 m .76559 .18273 L .76916 .17685 L p F P
0 g
s
.937 .876 .75 r
.76916 .17685 m .76816 .17251 L .76455 .1784 L p F P
0 g
s
.776 .661 .736 r
.24132 .86119 m .24183 .86061 L .24091 .86038 L closepath p F P
0 g
s
.773 .667 .746 r
.23819 .85535 m .24143 .85181 L p .24183 .86061 L F P
0 g
s
.773 .667 .746 r
.24183 .86061 m .24091 .86038 L .23819 .85535 L p F P
0 g
s
.678 .655 .82 r
.45529 .79131 m .45368 .78855 L .44519 .79221 L closepath p F P
0 g
s
.68 .659 .822 r
.45071 .78354 m .45368 .78855 L .44519 .79221 L p F P
0 g
s
.68 .659 .822 r
.43999 .78815 m .45071 .78354 L p .44519 .79221 L F P
0 g
s
.62 .293 .396 r
.44735 .98215 m .45949 .98143 L p .45907 .98581 L F P
0 g
s
.62 .293 .396 r
.44648 .98524 m .44735 .98215 L p .45907 .98581 L F P
0 g
s
.649 .606 .793 r
.52811 .80707 m .53069 .81252 L .51928 .81499 L p F P
0 g
s
.649 .606 .793 r
.51928 .81499 m .51728 .81077 L .52811 .80707 L p F P
0 g
s
.78 .662 .733 r
.23602 .8675 m .24132 .86119 L .24091 .86038 L p F P
0 g
s
.787 .639 .697 r
.22783 .88923 m .23463 .89093 L .23049 .89737 L p F P
0 g
s
.785 .644 .705 r
.23234 .88269 m .22783 .88923 L .23463 .89093 L p F P
0 g
s
.785 .644 .705 r
.23427 .88318 m .23234 .88269 L p .23463 .89093 L F P
0 g
s
.661 .622 .799 r
.49786 .79727 m .50066 .8028 L p .48696 .8012 L F P
0 g
s
.661 .622 .799 r
.48696 .8012 m .4965 .7975 L .49786 .79727 L p F P
0 g
s
.663 .628 .804 r
.48696 .8012 m .4965 .7975 L .48594 .79922 L closepath p F P
0 g
s
.23 .464 .877 r
.75238 .06274 m .75236 .06273 L .74982 .05845 L p F P
0 g
s
.58 .685 .913 r
.72309 .04537 m .71913 .04603 L .71656 .04202 L p F P
0 g
s
.64 .585 .777 r
.54606 .81913 m .54766 .82287 L .53681 .82633 L p F P
0 g
s
.64 .585 .777 r
.53681 .82633 m .53487 .82183 L .54606 .81913 L p F P
0 g
s
.897 .604 .1 r
.77424 .10074 m .77586 .10498 L .77526 .10073 L p F P
0 g
s
.897 .604 .1 r
.77526 .10073 m .77365 .09648 L .77424 .10074 L p F P
0 g
s
.608 .377 .541 r
.52354 .96466 m .52361 .95928 L .53544 .95739 L p F P
0 g
s
.23 .464 .877 r
.74982 .05845 m .75022 .05862 L .75238 .06274 L p F P
0 g
s
.112 .381 .84 r
.75486 .06126 m .75699 .06539 L .75238 .06274 L p F P
0 g
s
.112 .381 .84 r
.75238 .06274 m .75022 .05862 L .75486 .06126 L p F P
0 g
s
.766 .527 .572 r
.27884 .95851 m .27069 .95724 L .27136 .95168 L p F P
0 g
s
.768 .529 .573 r
.26997 .95146 m .27136 .95168 L .27069 .95724 L p F P
0 g
s
.73 .682 .804 r
.31968 .80129 m .32258 .79937 L .31805 .79872 L closepath p F P
0 g
s
.673 .642 .811 r
.4678 .78994 m .47033 .79455 L p .45665 .79373 L F P
0 g
s
.673 .642 .811 r
.45665 .79373 m .46478 .79029 L .4678 .78994 L p F P
0 g
s
.675 .648 .815 r
.45665 .79373 m .46478 .79029 L .45529 .79131 L closepath p F P
0 g
s
0 0 .153 r
.59313 .26313 m .59369 .26615 L .59252 .26023 L p F P
0 g
s
0 0 .153 r
.59252 .26023 m .59226 .25884 L .59313 .26313 L p F P
0 g
s
.821 .842 .864 r
.70449 .26014 m .7041 .26047 L .70155 .25774 L p F P
0 g
s
.629 .562 .76 r
.56724 .84111 m .56772 .84234 L .55672 .84522 L p F P
0 g
s
.629 .562 .76 r
.55672 .84522 m .55635 .84425 L .56724 .84111 L p F P
0 g
s
.821 .846 .867 r
.7039 .25576 m .70449 .26014 L .71359 .25226 L p F P
0 g
s
.821 .842 .864 r
.70155 .25774 m .7039 .25576 L .70449 .26014 L p F P
0 g
s
.613 .33 .464 r
.48575 .9792 m .48654 .97438 L .49487 .97348 L p F P
0 g
s
.858 .861 .841 r
.73392 .2277 m .72874 .23295 L .72939 .23734 L p F P
0 g
s
.853 .858 .845 r
.72318 .23845 m .72874 .23295 L .72939 .23734 L p F P
0 g
s
.853 .858 .845 r
.72939 .23734 m .72567 .24101 L .72318 .23845 L p F P
0 g
s
.906 .873 .794 r
.75275 .20082 m .75713 .19498 L .75803 .19933 L p F P
0 g
s
.906 .873 .794 r
.75803 .19933 m .75516 .20314 L .75275 .20082 L p F P
0 g
s
.785 .651 .715 r
.23427 .88318 m .23339 .88126 L .23234 .88269 L closepath p F P
0 g
s
.78 .662 .733 r
.24091 .86038 m .23509 .85886 L p .23602 .8675 L F P
0 g
s
.779 .669 .742 r
.24091 .86038 m .23819 .85535 L .23509 .85886 L closepath p F P
0 g
s
.989 .809 .571 r
.58849 .22307 m .59036 .22713 L .59165 .22211 L p F P
0 g
s
.989 .809 .571 r
.59165 .22211 m .58975 .21806 L .58849 .22307 L p F P
0 g
s
.978 .866 .658 r
.77421 .14712 m .77543 .15143 L .77753 .14612 L p F P
0 g
s
.978 .866 .658 r
.77624 .142 m .77421 .14712 L p .77753 .14612 L F P
0 g
s
.978 .866 .658 r
.77753 .14612 m .77642 .14213 L .77624 .142 L p F P
0 g
s
.607 .412 .592 r
.54647 .94395 m .55798 .94172 L p .55576 .94804 L F P
0 g
s
.607 .412 .592 r
.55576 .94804 m .54692 .94975 L .54647 .94395 L p F P
0 g
s
.612 .43 .612 r
.55731 .93573 m .55798 .94172 L .54647 .94395 L p F P
0 g
s
.629 .563 .761 r
.56445 .83392 m .56724 .84111 L .55635 .84425 L p F P
0 g
s
.629 .563 .761 r
.55635 .84425 m .55346 .83681 L .56445 .83392 L p F P
0 g
s
.716 .683 .817 r
.35833 .79191 m .35781 .7911 L .35668 .79175 L closepath p F P
0 g
s
.961 .871 .702 r
.77026 .16244 m .77144 .16674 L .77417 .16118 L p F P
0 g
s
.961 .871 .702 r
.77417 .16118 m .77301 .15687 L .77026 .16244 L p F P
0 g
s
.846 .857 .851 r
.72181 .24468 m .72567 .24101 L .72318 .23845 L p F P
0 g
s
.768 .529 .573 r
.27069 .95724 m .26993 .95712 L .26997 .95146 L p F P
0 g
s
.776 .536 .572 r
.26358 .95032 m .26997 .95146 L .26993 .95712 L p F P
0 g
s
.695 .364 .412 r
.36231 .98666 m .35826 .98643 L .35493 .98184 L p F P
0 g
s
.69 .348 .391 r
.34896 .9815 m .35493 .98184 L .35826 .98643 L p F P
0 g
s
.895 .786 .732 r
.59787 .15279 m .59975 .14966 L .60243 .15353 L p F P
0 g
s
.895 .786 .732 r
.60243 .15353 m .60063 .15652 L .59787 .15279 L p F P
0 g
s
.771 .676 .758 r
.24979 .84503 m .24908 .84379 L .24825 .84464 L closepath p F P
0 g
s
.726 .425 .469 r
.32508 .97955 m .31774 .97886 L .31903 .97421 L p F P
0 g
s
.736 .435 .471 r
.314 .97364 m .31903 .97421 L .31774 .97886 L p F P
0 g
s
.846 .857 .851 r
.72318 .23845 m .72127 .24026 L .72181 .24468 L p F P
0 g
s
.841 .854 .854 r
.71308 .24784 m .72127 .24026 L .72181 .24468 L p F P
0 g
s
.841 .854 .854 r
.71331 .24944 m .71308 .24784 L p .72181 .24468 L F P
0 g
s
.841 .854 .854 r
.72181 .24468 m .71491 .25109 L .71331 .24944 L p F P
0 g
s
.737 .786 .892 r
.64984 .28903 m .64439 .29206 L .64171 .2888 L p F P
0 g
s
.705 .777 .908 r
.63073 .29382 m .64171 .2888 L .64439 .29206 L p F P
0 g
s
.61 .484 .684 r
.57388 .89963 m .57354 .8982 L .58456 .89541 L p F P
0 g
s
.613 .496 .696 r
.58273 .88838 m .58456 .89541 L .57354 .8982 L p F P
0 g
s
.625 .725 .918 r
.62801 .29029 m .61699 .29359 L .61424 .28956 L p F P
0 g
s
.642 .736 .917 r
.61699 .29359 m .62801 .29029 L .63073 .29382 L p F P
0 g
s
.833 .854 .861 r
.71491 .25109 m .71359 .25226 L .71331 .24944 L closepath p F P
0 g
s
.821 .846 .867 r
.71239 .24845 m .7039 .25576 L p .71359 .25226 L F P
0 g
s
.821 .846 .867 r
.71359 .25226 m .71331 .24944 L .71239 .24845 L p F P
0 g
s
.7 .681 .828 r
.39589 .78368 m .38522 .78909 L .38218 .78435 L p F P
0 g
s
.919 .792 .705 r
.59356 .1703 m .59608 .1742 L .59892 .16865 L p F P
0 g
s
.919 .792 .705 r
.59892 .16865 m .59638 .16475 L .59356 .1703 L p F P
0 g
s
.787 .6 .648 r
.23425 .91938 m .24138 .92096 L .23881 .927 L p F P
0 g
s
.785 .596 .645 r
.24138 .92096 m .23881 .927 L .24601 .92855 L p F P
0 g
s
.787 .609 .66 r
.24138 .92096 m .23425 .91938 L .23726 .91324 L p F P
0 g
s
.727 .687 .811 r
.32722 .78965 m .33033 .79439 L .32258 .79937 L p F P
0 g
s
.727 .687 .811 r
.31657 .79647 m .32722 .78965 L p .32258 .79937 L F P
0 g
s
.727 .687 .811 r
.32258 .79937 m .31805 .79872 L .31657 .79647 L p F P
0 g
s
.786 .586 .63 r
.2507 .9359 m .24389 .93447 L .24601 .92855 L p F P
0 g
s
.787 .588 .632 r
.23881 .927 m .24601 .92855 L .24389 .93447 L p F P
0 g
s
.717 .683 .816 r
.34408 .79259 m .34714 .79078 L .35668 .79175 L p F P
0 g
s
.718 .687 .82 r
.35473 .78645 m .34714 .79078 L .35668 .79175 L p F P
0 g
s
.718 .687 .82 r
.35668 .79175 m .35781 .7911 L .35473 .78645 L p F P
0 g
s
.705 .684 .827 r
.38218 .78435 m .37152 .78997 L .36846 .78527 L p F P
0 g
s
.742 .684 .794 r
.29209 .80664 m .29365 .80549 L .30152 .80694 L p F P
0 g
s
.741 .688 .799 r
.30277 .79896 m .29365 .80549 L .30152 .80694 L p F P
0 g
s
.741 .688 .799 r
.30152 .80694 m .3059 .80379 L .30277 .79896 L p F P
0 g
s
.695 .672 .824 r
.39892 .78847 m .4096 .78327 L .41261 .78811 L p F P
0 g
s
.695 .677 .829 r
.4096 .78327 m .39892 .78847 L .39589 .78368 L p F P
0 g
s
.937 .797 .681 r
.59566 .18358 m .5956 .1837 L .59523 .18309 L closepath p F P
0 g
s
.785 .652 .715 r
.23234 .88269 m .23339 .88126 L .23032 .87456 L p F P
0 g
s
.762 .677 .769 r
.26397 .82968 m .2599 .83339 L .25675 .82809 L p F P
0 g
s
.766 .679 .766 r
.25581 .83725 m .2599 .83339 L .25675 .82809 L p F P
0 g
s
.672 .339 .401 r
.3914 .9876 m .38049 .98734 L .37803 .98463 L p F P
0 g
s
.673 .339 .4 r
.38049 .98734 m .37701 .98726 L .37803 .98463 L closepath p F P
0 g
s
.762 .677 .769 r
.25675 .82809 m .25681 .82803 L .26397 .82968 L p F P
0 g
s
.76 .681 .774 r
.26567 .82026 m .25681 .82803 L .26397 .82968 L p F P
0 g
s
.76 .681 .774 r
.26902 .82107 m .26567 .82026 L p .26397 .82968 L F P
0 g
s
.76 .681 .774 r
.26397 .82968 m .27066 .82378 L .26902 .82107 L p F P
0 g
s
.944 .795 .666 r
.59098 .18511 m .59338 .18903 L .5956 .1837 L p F P
0 g
s
.944 .795 .666 r
.59291 .18049 m .59098 .18511 L p .5956 .1837 L F P
0 g
s
.944 .795 .666 r
.5956 .1837 m .59523 .18309 L .59291 .18049 L p F P
0 g
s
.774 .446 0 r
.77194 .09225 m .77365 .09648 L .77247 .09246 L p F P
0 g
s
.774 .446 0 r
.77247 .09246 m .77076 .08823 L .77194 .09225 L p F P
0 g
s
.768 .676 .761 r
.25581 .83725 m .24908 .84379 L .24593 .8384 L p F P
0 g
s
.768 .676 .761 r
.24593 .8384 m .24887 .83554 L .25581 .83725 L p F P
0 g
s
.766 .679 .766 r
.25675 .82809 m .24887 .83554 L .25581 .83725 L p F P
0 g
s
.609 .484 .684 r
.57516 .90504 m .57388 .89963 L .5848 .89642 L p F P
0 g
s
.61 .484 .684 r
.58456 .89541 m .5848 .89642 L .57388 .89963 L p F P
0 g
s
.787 .612 .663 r
.2302 .91163 m .23726 .91324 L .23425 .91938 L p F P
0 g
s
.787 .62 .674 r
.23726 .91324 m .2302 .91163 L .23363 .90538 L p F P
0 g
s
.61 .464 .659 r
.57688 .91304 m .57788 .91822 L .5667 .92082 L p F P
0 g
s
.605 .45 .645 r
.56777 .92715 m .5667 .92082 L .57788 .91822 L p F P
0 g
s
.663 .634 .811 r
.4965 .7975 m .48594 .79922 L .48403 .79565 L p F P
0 g
s
.778 .567 .615 r
.25085 .93711 m .25118 .93599 L p .25709 .94323 L F P
0 g
s
.78 .569 .614 r
.25085 .93711 m .25118 .93599 L .2507 .9359 L closepath p F P
0 g
s
.71 .686 .825 r
.36846 .78527 m .35781 .7911 L .35473 .78645 L p F P
0 g
s
.756 .68 .777 r
.27066 .82378 m .27286 .82191 L .26902 .82107 L closepath p F P
0 g
s
0 .222 .744 r
.76054 .06847 m .76256 .07263 L .75902 .06955 L p F P
0 g
s
0 .222 .744 r
.75902 .06955 m .75699 .06539 L .76054 .06847 L p F P
0 g
s
.608 .353 .506 r
.51152 .96637 m .5173 .96556 L .52099 .97011 L p F P
0 g
s
.608 .353 .506 r
.52099 .97011 m .51113 .97149 L .51152 .96637 L p F P
0 g
s
.616 .361 .508 r
.51152 .96637 m .51113 .97149 L .49893 .97303 L p F P
0 g
s
.689 .668 .824 r
.41261 .78811 m .4233 .78311 L .4263 .788 L p F P
0 g
s
.689 .673 .829 r
.4233 .78311 m .41261 .78811 L .4096 .78327 L p F P
0 g
s
.753 .685 .786 r
.28048 .81342 m .28139 .81489 L .27286 .82191 L p F P
0 g
s
.753 .685 .786 r
.27538 .81225 m .28048 .81342 L p .27286 .82191 L F P
0 g
s
.753 .685 .786 r
.26751 .8187 m .27538 .81225 L p .27286 .82191 L F P
0 g
s
.753 .685 .786 r
.27286 .82191 m .26902 .82107 L .26751 .8187 L p F P
0 g
s
.781 .659 .729 r
.22924 .86577 m .23602 .8675 L .23051 .87431 L p F P
0 g
s
.78 .662 .733 r
.23509 .85886 m .22924 .86577 L .23602 .8675 L p F P
0 g
s
.752 .475 .512 r
.30277 .97238 m .29631 .97152 L .29555 .9663 L p F P
0 g
s
.752 .473 .51 r
.28695 .96517 m .29555 .9663 L .29631 .97152 L p F P
0 g
s
.755 .498 .544 r
.29555 .9663 m .28695 .96517 L .28695 .96427 L p F P
0 g
s
.785 .573 .613 r
.2507 .9359 m .24389 .93447 L p .24951 .94179 L F P
0 g
s
.785 .573 .613 r
.24951 .94179 m .25085 .93711 L .2507 .9359 L p F P
0 g
s
.788 .647 .707 r
.22564 .88095 m .23234 .88269 L .22783 .88923 L p F P
0 g
s
.785 .652 .715 r
.23032 .87456 m .22564 .88095 L .23234 .88269 L p F P
0 g
s
.766 .817 .893 r
.6689 .28212 m .66871 .28224 L .66871 .28191 L closepath p F P
0 g
s
.762 .808 .89 r
.66628 .27914 m .66871 .28191 L .66871 .28224 L p F P
0 g
s
.762 .808 .89 r
.65534 .28595 m .66628 .27914 L p .66871 .28224 L F P
0 g
s
.69 .348 .391 r
.34741 .98547 m .34896 .9815 L p .35826 .98643 L F P
0 g
s
.705 .376 .417 r
.34741 .98547 m .3446 .98117 L .34896 .9815 L closepath p F P
0 g
s
1 .809 .481 r
.77625 .12318 m .77771 .12744 L .77852 .12263 L p F P
0 g
s
1 .809 .481 r
.77852 .12263 m .77707 .11836 L .77625 .12318 L p F P
0 g
s
.773 .678 .759 r
.24825 .84464 m .24908 .84379 L .24593 .8384 L p F P
0 g
s
.197 .328 .772 r
.59626 .27394 m .59747 .2768 L .60046 .27902 L p F P
0 g
s
.785 .821 .88 r
.6772 .27164 m .6798 .27455 L .6689 .28212 L p F P
0 g
s
.785 .821 .88 r
.66816 .27786 m .6772 .27164 L p .6689 .28212 L F P
0 g
s
.785 .821 .88 r
.6689 .28212 m .66871 .28191 L .66816 .27786 L p F P
0 g
s
.773 .678 .759 r
.24593 .8384 m .2415 .84287 L .24825 .84464 L p F P
0 g
s
.773 .674 .755 r
.2415 .84287 m .24825 .84464 L .24143 .85181 L p F P
0 g
s
.641 .593 .784 r
.54477 .81624 m .54606 .81913 L .53487 .82183 L p F P
0 g
s
.641 .593 .784 r
.53487 .82183 m .53391 .81968 L .54477 .81624 L p F P
0 g
s
.902 .875 .801 r
.75318 .20568 m .75516 .20314 L .75275 .20082 L p F P
0 g
s
.627 .316 .424 r
.46021 .98199 m .45949 .98143 L .46037 .98137 L closepath p F P
0 g
s
.62 .293 .396 r
.45949 .98143 m .46021 .98199 L .45907 .98581 L p F P
0 g
s
.669 .641 .814 r
.48 .78826 m .48109 .79023 L .47033 .79455 L p F P
0 g
s
.669 .641 .814 r
.47033 .79455 m .4678 .78994 L .48 .78826 L p F P
0 g
s
.668 .639 .812 r
.47033 .79455 m .48109 .79023 L .48403 .79565 L p F P
0 g
s
0 0 .357 r
.76896 .08402 m .77076 .08823 L .76891 .08447 L p F P
0 g
s
0 0 .357 r
.76891 .08447 m .7671 .08026 L .76896 .08402 L p F P
0 g
s
.518 .642 .911 r
.61148 .28543 m .60863 .28534 L .60935 .28969 L p F P
0 g
s
.518 .642 .911 r
.60935 .28969 m .61424 .28956 L .61148 .28543 L p F P
0 g
s
.788 .623 .676 r
.22666 .90373 m .23363 .90538 L .2302 .91163 L p F P
0 g
s
.787 .629 .686 r
.23363 .90538 m .22666 .90373 L .23049 .89737 L p F P
0 g
s
.736 .688 .805 r
.31419 .79807 m .3059 .80379 L .30277 .79896 L p F P
0 g
s
.612 .292 .405 r
.46037 .98137 m .47316 .98038 L .47191 .98484 L p F P
0 g
s
.612 .292 .405 r
.46021 .98199 m .46037 .98137 L p .47191 .98484 L F P
0 g
s
0 .009 .582 r
.7652 .07607 m .7671 .08026 L .76447 .07681 L p F P
0 g
s
0 .009 .582 r
.76447 .07681 m .76256 .07263 L .7652 .07607 L p F P
0 g
s
.95 .874 .726 r
.77176 .16801 m .77107 .16741 L .77144 .16674 L closepath p F P
0 g
s
.675 .653 .821 r
.46478 .79029 m .45529 .79131 L .45368 .78855 L p F P
0 g
s
.604 .425 .612 r
.55731 .93573 m .56866 .93332 L p .56388 .94047 L F P
0 g
s
.604 .425 .612 r
.56388 .94047 m .55798 .94172 L .55731 .93573 L p F P
0 g
s
.609 .441 .629 r
.56777 .92715 m .56866 .93332 L .55731 .93573 L p F P
0 g
s
.697 .771 .908 r
.64171 .2888 m .63073 .29382 L .62801 .29029 L p F P
0 g
s
.649 .607 .794 r
.52608 .80279 m .52811 .80707 L .51728 .81077 L p F P
0 g
s
.649 .607 .794 r
.51728 .81077 m .51466 .80527 L .52608 .80279 L p F P
0 g
s
.765 .508 .545 r
.28687 .96516 m .27883 .9639 L .27884 .95851 L p F P
0 g
s
.765 .507 .545 r
.27069 .95724 m .27884 .95851 L .27883 .9639 L p F P
0 g
s
.684 .664 .824 r
.4263 .788 m .43701 .7832 L .43999 .78815 L p F P
0 g
s
.684 .668 .828 r
.43701 .7832 m .4263 .788 L .4233 .78311 L p F P
0 g
s
.955 .807 .657 r
.58917 .19963 m .59134 .20362 L .59342 .19833 L p F P
0 g
s
.955 .807 .657 r
.59342 .19833 m .59123 .19435 L .58917 .19963 L p F P
0 g
s
.717 .682 .815 r
.34408 .79259 m .34714 .79078 L .34262 .79033 L closepath p F P
0 g
s
.724 .686 .814 r
.34262 .79033 m .34408 .79259 L p .33033 .79439 L F P
0 g
s
.637 .574 .767 r
.55346 .83681 m .55345 .8368 L .55329 .83685 L closepath p F P
0 g
s
.638 .576 .768 r
.55056 .82971 m .55345 .8368 L .55329 .83685 L p F P
0 g
s
.931 .804 .698 r
.59523 .18309 m .59291 .18049 L .59327 .17975 L closepath p F P
0 g
s
.776 .815 .884 r
.66871 .28191 m .66628 .27914 L .66816 .27786 L closepath p F P
0 g
s
.778 .567 .615 r
.25709 .94323 m .25146 .94219 L .25085 .93711 L p F P
0 g
s
.785 .572 .613 r
.25146 .94219 m .25085 .93711 L .24951 .94179 L closepath p F P
0 g
s
.736 .435 .471 r
.31774 .97886 m .31569 .97863 L .314 .97364 L p F P
0 g
s
.737 .433 .466 r
.30497 .97263 m .314 .97364 L .31569 .97863 L p F P
0 g
s
.631 .571 .768 r
.56435 .83365 m .56445 .83392 L .55346 .83681 L p F P
0 g
s
.631 .571 .768 r
.55346 .83681 m .55345 .8368 L .56435 .83365 L p F P
0 g
s
.632 .572 .77 r
.56435 .83365 m .55345 .8368 L .55056 .82971 L p F P
0 g
s
.777 .552 .595 r
.26358 .95032 m .25587 .94892 L .25709 .94323 L p F P
0 g
s
.778 .554 .595 r
.25146 .94219 m .25709 .94323 L .25587 .94892 L p F P
0 g
s
.715 .411 .462 r
.3446 .98117 m .33457 .98043 L .33396 .97903 L p F P
0 g
s
.716 .412 .461 r
.33457 .98043 m .33359 .98036 L .33396 .97903 L closepath p F P
0 g
s
.911 .784 .708 r
.59923 .15921 m .60063 .15652 L .59787 .15279 L p F P
0 g
s
1 .798 .477 r
.58854 .23693 m .59014 .24106 L .59093 .23621 L p F P
0 g
s
1 .798 .477 r
.59093 .23621 m .5893 .23208 L .58854 .23693 L p F P
0 g
s
.749 .682 .786 r
.28139 .81489 m .28267 .81387 L .28048 .81342 L closepath p F P
0 g
s
.734 .689 .807 r
.31805 .79872 m .31657 .79647 L .31419 .79807 L closepath p F P
0 g
s
.705 .369 .405 r
.3446 .98117 m .34741 .98547 L .34726 .9858 L p F P
0 g
s
.705 .369 .405 r
.33457 .98043 m .3446 .98117 L p .34726 .9858 L F P
0 g
s
.656 .62 .802 r
.50066 .8028 m .51146 .79888 L p .5105 .80608 L F P
0 g
s
.656 .621 .803 r
.50952 .79503 m .51146 .79888 L .50066 .8028 L p F P
0 g
s
.656 .621 .803 r
.50066 .8028 m .49786 .79727 L .50952 .79503 L p F P
0 g
s
.902 .875 .801 r
.75275 .20082 m .75237 .2013 L .75318 .20568 L p F P
0 g
s
.891 .87 .811 r
.74696 .20787 m .74782 .21222 L .75318 .20568 L p F P
0 g
s
.891 .87 .811 r
.75318 .20568 m .75237 .2013 L .74696 .20787 L p F P
0 g
s
.746 .687 .795 r
.29104 .80499 m .29209 .80664 L .28267 .81387 L p F P
0 g
s
.746 .687 .795 r
.28613 .80392 m .29104 .80499 L p .28267 .81387 L F P
0 g
s
.746 .687 .795 r
.27824 .80997 m .28613 .80392 L p .28267 .81387 L F P
0 g
s
.746 .687 .795 r
.28267 .81387 m .28048 .81342 L .27824 .80997 L p F P
0 g
s
.64 .59 .782 r
.54477 .81624 m .53391 .81968 L .53101 .81324 L p F P
0 g
s
.612 .332 .469 r
.49841 .97649 m .49487 .97348 L .49893 .97303 L closepath p F P
0 g
s
.613 .33 .464 r
.49487 .97348 m .49841 .97649 L p .48575 .9792 L F P
0 g
s
.742 .483 0 r
.59205 .25884 m .59313 .26313 L .59226 .25884 L p F P
0 g
s
.742 .483 0 r
.59226 .25884 m .59121 .25454 L .59205 .25884 L p F P
0 g
s
.606 .473 .673 r
.57662 .91172 m .57516 .90504 L .58619 .90225 L p F P
0 g
s
.609 .484 .684 r
.5848 .89642 m .58619 .90225 L .57516 .90504 L p F P
0 g
s
.776 .668 .745 r
.23819 .85535 m .24143 .85181 L .23546 .85031 L closepath p F P
0 g
s
.773 .674 .755 r
.23506 .8496 m .2415 .84287 L p .24143 .85181 L F P
0 g
s
.773 .674 .755 r
.24143 .85181 m .23546 .85031 L .23506 .8496 L p F P
0 g
s
.928 .874 .764 r
.76081 .18418 m .76455 .1784 L .76559 .18273 L p F P
0 g
s
.928 .874 .764 r
.76559 .18273 m .7632 .18641 L .76081 .18418 L p F P
0 g
s
0 0 .549 r
.59458 .26893 m .59594 .27138 L .59626 .27394 L closepath p F P
0 g
s
.197 .328 .772 r
.59971 .27465 m .59594 .27138 L .59626 .27394 L p F P
0 g
s
.197 .328 .772 r
.60046 .27902 m .59971 .27465 L p .59626 .27394 L F P
0 g
s
.788 .633 .688 r
.22362 .89569 m .23049 .89737 L .22666 .90373 L p F P
0 g
s
.787 .639 .697 r
.23049 .89737 m .22362 .89569 L .22783 .88923 L p F P
0 g
s
.655 .617 .799 r
.51466 .80527 m .51437 .80469 L .5105 .80608 L closepath p F P
0 g
s
.656 .62 .802 r
.51146 .79888 m .51437 .80469 L .5105 .80608 L p F P
0 g
s
.612 .292 .405 r
.47191 .98484 m .46574 .98532 L .46021 .98199 L p F P
0 g
s
.613 .29 .399 r
.46574 .98532 m .45907 .98581 L .46021 .98199 L closepath p F P
0 g
s
.679 .662 .826 r
.45071 .78354 m .43999 .78815 L .43701 .7832 L p F P
0 g
s
.735 .792 .898 r
.64984 .28903 m .65534 .28595 L .65268 .28285 L p F P
0 g
s
.735 .792 .898 r
.65268 .28285 m .64956 .28455 L .64984 .28903 L p F P
0 g
s
.737 .786 .892 r
.64171 .2888 m .64956 .28455 L .64984 .28903 L p F P
0 g
s
0 0 .557 r
.59369 .26615 m .59458 .26893 L .59594 .27138 L p F P
0 g
s
.973 .82 .631 r
.58807 .2127 m .58938 .20888 L .59131 .21294 L p F P
0 g
s
.973 .82 .631 r
.59131 .21294 m .59079 .21445 L .58807 .2127 L p F P
0 g
s
0 0 .557 r
.59509 .26703 m .59313 .26313 L .59369 .26615 L p F P
0 g
s
0 0 .557 r
.59594 .27138 m .59509 .26703 L p .59369 .26615 L F P
0 g
s
.715 .687 .822 r
.35164 .78185 m .35473 .78645 L .34714 .79078 L p F P
0 g
s
.715 .687 .822 r
.34099 .78789 m .35164 .78185 L p .34714 .79078 L F P
0 g
s
.715 .687 .822 r
.34714 .79078 m .34262 .79033 L .34099 .78789 L p F P
0 g
s
.724 .686 .814 r
.33033 .79439 m .33793 .78971 L .34262 .79033 L p F P
0 g
s
.723 .688 .817 r
.33793 .78971 m .33033 .79439 L .32722 .78965 L p F P
0 g
s
.78 .67 .742 r
.23509 .85886 m .23819 .85535 L .23546 .85031 L p F P
0 g
s
.781 .659 .729 r
.22721 .86829 m .22924 .86577 L p .23051 .87431 L F P
0 g
s
.781 .659 .729 r
.23051 .87431 m .23016 .87423 L .22721 .86829 L p F P
0 g
s
.784 .652 .718 r
.23032 .87456 m .23051 .87431 L .23016 .87423 L closepath p F P
0 g
s
.606 .353 .508 r
.5173 .96556 m .52354 .96466 L .52317 .96979 L p F P
0 g
s
.606 .353 .508 r
.52317 .96979 m .52099 .97011 L .5173 .96556 L p F P
0 g
s
.759 .687 .782 r
.26902 .82107 m .26751 .8187 L .26567 .82026 L closepath p F P
0 g
s
.757 .5 .544 r
.28695 .96517 m .28687 .96516 L .28695 .96427 L closepath p F P
0 g
s
.992 .846 .596 r
.77492 .13753 m .77632 .1418 L .77789 .13669 L p F P
0 g
s
.992 .846 .596 r
.77789 .13669 m .7765 .13241 L .77492 .13753 L p F P
0 g
s
.788 .654 .715 r
.22564 .88095 m .23032 .87456 L .23016 .87423 L p F P
0 g
s
.776 .536 .572 r
.26993 .95712 m .26294 .95587 L .26358 .95032 L p F P
0 g
s
.776 .536 .572 r
.25587 .94892 m .26358 .95032 L .26294 .95587 L p F P
0 g
s
.753 .689 .79 r
.28048 .81342 m .27824 .80997 L .27538 .81225 L closepath p F P
0 g
s
.58 .685 .913 r
.71656 .04202 m .72057 .04134 L .72309 .04537 L p F P
0 g
s
.558 .674 .916 r
.72794 .04041 m .72057 .04134 L .72309 .04537 L p F P
0 g
s
.558 .674 .916 r
.72309 .04537 m .7305 .04445 L .72794 .04041 L p F P
0 g
s
.452 .612 .917 r
.73306 .0485 m .73827 .04887 L .74059 .05296 L p F P
0 g
s
.379 .566 .91 r
.74472 .05006 m .73827 .04887 L .74059 .05296 L p F P
0 g
s
.379 .566 .91 r
.74059 .05296 m .74727 .05423 L .74472 .05006 L p F P
0 g
s
.787 .661 .725 r
.23016 .87423 m .22721 .86829 L .2239 .87254 L closepath p F P
0 g
s
.788 .654 .715 r
.23016 .87423 m .2239 .87254 L p .22564 .88095 L F P
0 g
s
.663 .634 .811 r
.48403 .79565 m .49481 .79156 L p .4965 .7975 L F P
0 g
s
.663 .634 .811 r
.49481 .79156 m .48403 .79565 L .48109 .79023 L p F P
0 g
s
.992 .771 .396 r
.77553 .1141 m .77707 .11836 L .77746 .11371 L p F P
0 g
s
.992 .771 .396 r
.77746 .11371 m .77593 .10945 L .77553 .1141 L p F P
0 g
s
.6 .317 .459 r
.49893 .97303 m .51113 .97149 L .51039 .97633 L p F P
0 g
s
.6 .317 .459 r
.49841 .97649 m .49893 .97303 L p .51039 .97633 L F P
0 g
s
.736 .688 .805 r
.30277 .79896 m .30614 .79666 L .31419 .79807 L p F P
0 g
s
.735 .692 .809 r
.31344 .7918 m .30614 .79666 L .31419 .79807 L p F P
0 g
s
.735 .692 .809 r
.31419 .79807 m .31657 .79647 L .31344 .7918 L p F P
0 g
s
.911 .784 .708 r
.59787 .15279 m .59653 .15535 L .59923 .15921 L p F P
0 g
s
.913 .783 .705 r
.59369 .1609 m .59638 .16475 L .59923 .15921 L p F P
0 g
s
.913 .783 .705 r
.59923 .15921 m .59653 .15535 L .59369 .1609 L p F P
0 g
s
.78 .667 .738 r
.22844 .85708 m .23509 .85886 L .22924 .86577 L p F P
0 g
s
.78 .67 .742 r
.23461 .85008 m .22844 .85708 L .23509 .85886 L p F P
0 g
s
.78 .67 .742 r
.23546 .85031 m .23461 .85008 L p .23509 .85886 L F P
0 g
s
.743 .685 .795 r
.29209 .80664 m .29365 .80549 L .29104 .80499 L closepath p F P
0 g
s
.66 .324 .393 r
.40492 .98769 m .39234 .98761 L .39165 .98694 L p F P
0 g
s
.661 .324 .391 r
.39234 .98761 m .3914 .9876 L .39165 .98694 L closepath p F P
0 g
s
.948 .87 .727 r
.76871 .16528 m .77026 .16244 L .77144 .16674 L p F P
0 g
s
.948 .87 .727 r
.77144 .16674 m .77107 .16741 L .76871 .16528 L p F P
0 g
s
.788 .642 .699 r
.22106 .88751 m .22783 .88923 L .22362 .89569 L p F P
0 g
s
.788 .647 .707 r
.22783 .88923 m .22106 .88751 L .22564 .88095 L p F P
0 g
s
.452 .614 .919 r
.73827 .04887 m .73306 .0485 L .7305 .04445 L p F P
0 g
s
.675 .653 .821 r
.45368 .78855 m .46443 .78415 L p .46478 .79029 L F P
0 g
s
.674 .658 .826 r
.46443 .78415 m .45368 .78855 L .45071 .78354 L p F P
0 g
s
.722 .69 .819 r
.34262 .79033 m .34099 .78789 L .33793 .78971 L closepath p F P
0 g
s
.97 .867 .68 r
.77176 .15257 m .77301 .15687 L .77543 .15143 L p F P
0 g
s
.97 .867 .68 r
.77543 .15143 m .77421 .14712 L .77176 .15257 L p F P
0 g
s
.705 .369 .405 r
.34726 .9858 m .33777 .98505 L .33457 .98043 L p F P
0 g
s
.704 .369 .406 r
.33359 .98036 m .33457 .98043 L .33777 .98505 L p F P
0 g
s
.632 .573 .77 r
.56091 .82521 m .56145 .82655 L .55056 .82971 L p F P
0 g
s
.632 .573 .77 r
.55056 .82971 m .5499 .82811 L .56091 .82521 L p F P
0 g
s
.632 .572 .77 r
.55056 .82971 m .56145 .82655 L .56435 .83365 L p F P
0 g
s
.673 .65 .818 r
.4678 .78994 m .46738 .78921 L .46478 .79029 L closepath p F P
0 g
s
.675 .653 .821 r
.46443 .78415 m .46738 .78921 L .46478 .79029 L p F P
0 g
s
.74 .69 .803 r
.30062 .79569 m .30277 .79896 L .29365 .80549 L p F P
0 g
s
.74 .69 .803 r
.29823 .7952 m .30062 .79569 L p .29365 .80549 L F P
0 g
s
.74 .69 .803 r
.28894 .80183 m .29823 .7952 L p .29365 .80549 L F P
0 g
s
.74 .69 .803 r
.29365 .80549 m .29104 .80499 L .28894 .80183 L p F P
0 g
s
.978 .805 .602 r
.58975 .21806 m .59079 .21445 L .58807 .2127 L p F P
0 g
s
.92 .793 .704 r
.59076 .17585 m .59327 .17975 L .59608 .1742 L p F P
0 g
s
.92 .793 .704 r
.59608 .1742 m .59356 .1703 L .59076 .17585 L p F P
0 g
s
.792 .825 .877 r
.68219 .2728 m .6798 .27455 L .6772 .27164 L p F P
0 g
s
.884 .866 .816 r
.74215 .21354 m .74696 .20787 L .74782 .21222 L p F P
0 g
s
.884 .866 .816 r
.74782 .21222 m .74459 .21601 L .74215 .21354 L p F P
0 g
s
.601 .436 .63 r
.56866 .93332 m .56777 .92715 L .57896 .92456 L p F P
0 g
s
.605 .45 .645 r
.57788 .91822 m .57896 .92456 L .56777 .92715 L p F P
0 g
s
.753 .474 .51 r
.28687 .96516 m .28695 .96517 L .28773 .97038 L p F P
0 g
s
.752 .473 .51 r
.29631 .97152 m .28773 .97038 L .28695 .96517 L p F P
0 g
s
.604 .286 .403 r
.47191 .98484 m .47316 .98038 L .4783 .97991 L p F P
0 g
s
.753 .474 .51 r
.28773 .97038 m .28594 .97013 L .28687 .96516 L p F P
0 g
s
.763 .484 .511 r
.27883 .9639 m .28687 .96516 L .28594 .97013 L p F P
0 g
s
.924 .876 .771 r
.76161 .18876 m .7632 .18641 L .76081 .18418 L p F P
0 g
s
.946 .874 .734 r
.76816 .17251 m .77107 .16741 L .76871 .16528 L p F P
0 g
s
.704 .369 .406 r
.33777 .98505 m .33176 .98459 L .33359 .98036 L p F P
0 g
s
.716 .381 .411 r
.32508 .97955 m .33359 .98036 L .33176 .98459 L p F P
0 g
s
.614 .522 .727 r
.57853 .87381 m .57615 .86625 L .58699 .86322 L p F P
0 g
s
.616 .532 .736 r
.58691 .86296 m .58699 .86322 L .57615 .86625 L p F P
0 g
s
.616 .532 .736 r
.57615 .86625 m .57596 .8657 L .58691 .86296 L p F P
0 g
s
.73 .693 .815 r
.32722 .78965 m .31657 .79647 L .31344 .7918 L p F P
0 g
s
.616 .532 .736 r
.58439 .85544 m .58691 .86296 L .57596 .8657 L p F P
0 g
s
.616 .532 .736 r
.57596 .8657 m .57355 .85849 L .58439 .85544 L p F P
0 g
s
.614 .522 .727 r
.58699 .86322 m .58938 .87079 L .57853 .87381 L p F P
0 g
s
.611 .512 .717 r
.57889 .87501 m .57853 .87381 L .58938 .87079 L p F P
0 g
s
.611 .512 .717 r
.58072 .88118 m .57889 .87501 L .58984 .87233 L p F P
0 g
s
.611 .512 .717 r
.58938 .87079 m .58984 .87233 L .57889 .87501 L p F P
0 g
s
.633 .581 .778 r
.55856 .81971 m .56091 .82521 L .5499 .82811 L p F P
0 g
s
.633 .581 .778 r
.5499 .82811 m .54766 .82287 L .55856 .81971 L p F P
0 g
s
.788 .59 .633 r
.23162 .92543 m .23881 .927 L .23665 .93293 L p F P
0 g
s
.787 .6 .648 r
.23881 .927 m .23162 .92543 L .23425 .91938 L p F P
0 g
s
.787 .588 .632 r
.24389 .93447 m .23665 .93293 L .23881 .927 L p F P
0 g
s
.737 .433 .466 r
.31569 .97863 m .30672 .9776 L .30497 .97263 L p F P
0 g
s
.736 .432 .467 r
.30277 .97238 m .30497 .97263 L .30672 .9776 L p F P
0 g
s
.789 .603 .649 r
.22861 .91812 m .23425 .91938 L .23162 .92543 L p F P
0 g
s
.787 .612 .663 r
.22802 .91605 m .2302 .91163 L p .23425 .91938 L F P
0 g
s
.787 .612 .663 r
.23425 .91938 m .22861 .91812 L .22802 .91605 L p F P
0 g
s
.938 .692 .217 r
.58987 .25033 m .59121 .25454 L .59109 .25 L p F P
0 g
s
.938 .692 .217 r
.59109 .25 m .58975 .24579 L .58987 .25033 L p F P
0 g
s
.65 .614 .801 r
.52521 .80103 m .52608 .80279 L .51466 .80527 L p F P
0 g
s
.65 .614 .801 r
.51466 .80527 m .51437 .80469 L .52521 .80103 L p F P
0 g
s
.778 .554 .595 r
.25587 .94892 m .25183 .94818 L .25146 .94219 L p F P
0 g
s
.785 .559 .594 r
.24951 .94179 m .25146 .94219 L .25183 .94818 L p F P
0 g
s
.795 .828 .877 r
.68219 .2728 m .69069 .26643 L .68811 .26358 L p F P
0 g
s
.795 .828 .877 r
.68811 .26358 m .68163 .26841 L .68219 .2728 L p F P
0 g
s
.792 .825 .877 r
.6772 .27164 m .68163 .26841 L .68219 .2728 L p F P
0 g
s
.599 .37 .54 r
.53538 .96277 m .53544 .95739 L .54713 .95534 L p F P
0 g
s
.608 .396 .568 r
.54692 .94975 m .54713 .95534 L .53544 .95739 L p F P
0 g
s
.608 .377 .541 r
.53544 .95739 m .53538 .96277 L .52354 .96466 L p F P
0 g
s
.619 .541 .745 r
.58399 .8543 m .58439 .85544 L .57355 .85849 L p F P
0 g
s
.619 .541 .745 r
.57355 .85849 m .57305 .85706 L .58399 .8543 L p F P
0 g
s
.994 .802 .537 r
.58746 .22801 m .5893 .23208 L .59036 .22713 L p F P
0 g
s
.994 .802 .537 r
.59036 .22713 m .58849 .22307 L .58746 .22801 L p F P
0 g
s
.602 .459 .659 r
.57688 .91304 m .57662 .91172 L .58766 .90894 L p F P
0 g
s
.606 .473 .673 r
.58619 .90225 m .58766 .90894 L .57662 .91172 L p F P
0 g
s
.6 .389 .568 r
.54692 .94975 m .55576 .94804 L .5533 .95416 L p F P
0 g
s
.6 .389 .568 r
.5533 .95416 m .54713 .95534 L .54692 .94975 L p F P
0 g
s
.763 .68 .77 r
.25675 .82809 m .25681 .82803 L .2567 .82801 L closepath p F P
0 g
s
.766 .683 .771 r
.2567 .82801 m .25675 .82809 L .24887 .83554 L p F P
0 g
s
.76 .685 .779 r
.25872 .81854 m .26567 .82026 L .25681 .82803 L p F P
0 g
s
.76 .685 .779 r
.25358 .82304 m .25872 .81854 L p .25681 .82803 L F P
0 g
s
.76 .685 .779 r
.25681 .82803 m .2567 .82801 L .25358 .82304 L p F P
0 g
s
.946 .796 .664 r
.58885 .19042 m .59123 .19435 L .59338 .18903 L p F P
0 g
s
.946 .796 .664 r
.59338 .18903 m .59098 .18511 L .58885 .19042 L p F P
0 g
s
.766 .683 .771 r
.25004 .82626 m .2567 .82801 L p .24887 .83554 L F P
0 g
s
.767 .687 .775 r
.2567 .82801 m .25358 .82304 L .25004 .82626 L closepath p F P
0 g
s
.619 .541 .745 r
.58159 .84746 m .58399 .8543 L .57305 .85706 L p F P
0 g
s
.619 .541 .745 r
.57305 .85706 m .57075 .85053 L .58159 .84746 L p F P
0 g
s
.668 .647 .82 r
.47815 .78501 m .48 .78826 L .4678 .78994 L p F P
0 g
s
.668 .647 .82 r
.4678 .78994 m .46738 .78921 L .47815 .78501 L p F P
0 g
s
.785 .573 .613 r
.24389 .93447 m .24222 .94028 L .24951 .94179 L p F P
0 g
s
.787 .576 .615 r
.23665 .93293 m .24389 .93447 L .24222 .94028 L p F P
0 g
s
.65 .618 .803 r
.52521 .80103 m .51437 .80469 L .51146 .79888 L p F P
0 g
s
.79 .614 .662 r
.22802 .91605 m .2302 .91163 L .2265 .91077 L closepath p F P
0 g
s
.788 .623 .676 r
.22512 .90655 m .22666 .90373 L p .2302 .91163 L F P
0 g
s
.788 .623 .676 r
.2302 .91163 m .2265 .91077 L .22512 .90655 L p F P
0 g
s
.625 .252 .315 r
.40546 .98769 m .41833 .98755 L p .4172 .99146 L F P
0 g
s
.625 .252 .315 r
.40532 .98799 m .40546 .98769 L p .4172 .99146 L F P
0 g
s
.647 .293 .357 r
.40532 .98799 m .40492 .98769 L .40546 .98769 L closepath p F P
0 g
s
.638 .264 .318 r
.40492 .98769 m .40532 .98799 L .40335 .99158 L p F P
0 g
s
.638 .264 .318 r
.39234 .98761 m .40492 .98769 L p .40335 .99158 L F P
0 g
s
.662 .63 .808 r
.49786 .79727 m .49774 .79703 L .4965 .7975 L closepath p F P
0 g
s
.663 .634 .811 r
.49481 .79156 m .49774 .79703 L .4965 .7975 L p F P
0 g
s
.769 .678 .762 r
.24593 .8384 m .24887 .83554 L .24345 .83418 L closepath p F P
0 g
s
.766 .683 .771 r
.24277 .83307 m .25004 .82626 L p .24887 .83554 L F P
0 g
s
.766 .683 .771 r
.24887 .83554 m .24345 .83418 L .24277 .83307 L p F P
0 g
s
.608 .502 .707 r
.58183 .88516 m .58072 .88118 L .59158 .87817 L p F P
0 g
s
.611 .512 .717 r
.58984 .87233 m .59158 .87817 L .58072 .88118 L p F P
0 g
s
.765 .507 .545 r
.27883 .9639 m .27068 .96264 L .27069 .95724 L p F P
0 g
s
.766 .509 .544 r
.26993 .95712 m .27069 .95724 L .27068 .96264 L p F P
0 g
s
.758 .808 .892 r
.66628 .27914 m .65534 .28595 L .65268 .28285 L p F P
0 g
s
.879 .867 .823 r
.74202 .21893 m .74459 .21601 L .74215 .21354 L p F P
0 g
s
.642 .596 .788 r
.53101 .81324 m .5411 .81002 L .53069 .81252 L closepath p F P
0 g
s
.64 .59 .782 r
.5419 .80982 m .54477 .81624 L p .53101 .81324 L F P
0 g
s
.64 .59 .782 r
.53101 .81324 m .5411 .81002 L .5419 .80982 L p F P
0 g
s
.76 .689 .783 r
.26434 .81375 m .25872 .81854 L .26567 .82026 L p F P
0 g
s
.76 .689 .783 r
.26567 .82026 m .26751 .8187 L .26434 .81375 L p F P
0 g
s
.7 .681 .828 r
.39418 .78104 m .39589 .78368 L p .38218 .78435 L F P
0 g
s
.7 .681 .828 r
.38218 .78435 m .38909 .78088 L .39418 .78104 L p F P
0 g
s
.7 .681 .829 r
.38218 .78435 m .38909 .78088 L .37971 .78059 L closepath p F P
0 g
s
.705 .684 .827 r
.37971 .78059 m .38218 .78435 L p .36846 .78527 L F P
0 g
s
.774 .679 .759 r
.2415 .84287 m .24593 .8384 L .24345 .83418 L p F P
0 g
s
.638 .264 .318 r
.40335 .99158 m .39837 .99154 L .39234 .98761 L p F P
0 g
s
.638 .263 .316 r
.3914 .9876 m .39234 .98761 L .39837 .99154 L p F P
0 g
s
.62 .293 .396 r
.45907 .98581 m .44836 .98646 L .44648 .98524 L p F P
0 g
s
.621 .291 .391 r
.44836 .98646 m .44603 .9866 L .44648 .98524 L closepath p F P
0 g
s
.636 .315 .411 r
.44648 .98524 m .44603 .9866 L .43277 .98718 L p F P
0 g
s
.638 .263 .316 r
.39837 .99154 m .38922 .99146 L .3914 .9876 L p F P
0 g
s
.65 .276 .322 r
.38049 .98734 m .3914 .9876 L .38922 .99146 L p F P
0 g
s
.736 .432 .467 r
.30672 .9776 m .30139 .97699 L .30277 .97238 L p F P
0 g
s
.747 .443 .469 r
.29631 .97152 m .30277 .97238 L .30139 .97699 L p F P
0 g
s
.695 .679 .83 r
.39589 .78368 m .4013 .78108 L .39418 .78104 L closepath p F P
0 g
s
.695 .677 .829 r
.40821 .7811 m .4096 .78327 L p .39589 .78368 L F P
0 g
s
.695 .677 .829 r
.39589 .78368 m .4013 .78108 L .40821 .7811 L p F P
0 g
s
.924 .876 .771 r
.76081 .18418 m .76066 .18441 L .76161 .18876 L p F P
0 g
s
.912 .872 .785 r
.75614 .19065 m .75713 .19498 L .76161 .18876 L p F P
0 g
s
.912 .872 .785 r
.76161 .18876 m .76066 .18441 L .75614 .19065 L p F P
0 g
s
.756 .688 .787 r
.27538 .81225 m .26751 .8187 L .26434 .81375 L p F P
0 g
s
.747 .692 .799 r
.29104 .80499 m .28894 .80183 L .28613 .80392 L closepath p F P
0 g
s
.602 .458 .659 r
.57788 .91822 m .57688 .91304 L .58782 .90976 L p F P
0 g
s
.602 .459 .659 r
.58766 .90894 m .58782 .90976 L .57688 .91304 L p F P
0 g
s
.705 .684 .827 r
.36846 .78527 m .37764 .78046 L .37971 .78059 L p F P
0 g
s
.704 .689 .833 r
.37764 .78046 m .36846 .78527 L .36539 .78063 L p F P
0 g
s
.71 .686 .825 r
.35473 .78645 m .36539 .78063 L .36846 .78527 L p F P
0 g
s
.625 .252 .315 r
.41833 .98755 m .41902 .98803 L .4172 .99146 L p F P
0 g
s
.636 .282 .354 r
.41902 .98803 m .41833 .98755 L .41924 .98754 L closepath p F P
0 g
s
.766 .509 .544 r
.27068 .96264 m .26944 .96245 L .26993 .95712 L p F P
0 g
s
.775 .517 .544 r
.26294 .95587 m .26993 .95712 L .26944 .96245 L p F P
0 g
s
.614 .242 .314 r
.41924 .98754 m .43265 .98718 L p .43078 .99112 L F P
0 g
s
.614 .242 .314 r
.41902 .98803 m .41924 .98754 L p .43078 .99112 L F P
0 g
s
.723 .688 .817 r
.32722 .78965 m .32904 .78855 L .33793 .78971 L p F P
0 g
s
.723 .694 .821 r
.33788 .78333 m .32904 .78855 L .33793 .78971 L p F P
0 g
s
.723 .694 .821 r
.33793 .78971 m .34099 .78789 L .33788 .78333 L p F P
0 g
s
.967 .709 .279 r
.77431 .10521 m .77593 .10945 L .77586 .10498 L p F P
0 g
s
.967 .709 .279 r
.77586 .10498 m .77424 .10074 L .77431 .10521 L p F P
0 g
s
.603 .289 .41 r
.48467 .98337 m .4783 .97991 L .48575 .9792 L closepath p F P
0 g
s
.604 .286 .403 r
.4783 .97991 m .48467 .98337 L p .47191 .98484 L F P
0 g
s
.643 .604 .795 r
.5411 .81002 m .53069 .81252 L .52811 .80707 L p F P
0 g
s
.669 .653 .826 r
.47815 .78501 m .46738 .78921 L .46443 .78415 L p F P
0 g
s
.783 .661 .728 r
.22721 .86829 m .22924 .86577 L .22545 .86478 L closepath p F P
0 g
s
.78 .667 .738 r
.22408 .86221 m .22844 .85708 L p .22924 .86577 L F P
0 g
s
.78 .667 .738 r
.22924 .86577 m .22545 .86478 L .22408 .86221 L p F P
0 g
s
.597 .345 .506 r
.52317 .96979 m .52354 .96466 L .53538 .96277 L p F P
0 g
s
.656 .628 .81 r
.50855 .79318 m .50952 .79503 L .49786 .79727 L p F P
0 g
s
.656 .628 .81 r
.49786 .79727 m .49774 .79703 L .50855 .79318 L p F P
0 g
s
.621 .55 .753 r
.58108 .8461 m .58159 .84746 L .57075 .85053 L p F P
0 g
s
.621 .55 .753 r
.57075 .85053 m .57014 .84889 L .58108 .8461 L p F P
0 g
s
.608 .502 .707 r
.58273 .88838 m .58183 .88516 L .59279 .88251 L p F P
0 g
s
.608 .502 .707 r
.59158 .87817 m .59279 .88251 L .58183 .88516 L p F P
0 g
s
.788 .651 .71 r
.21898 .87919 m .22564 .88095 L .22106 .88751 L p F P
0 g
s
.788 .654 .715 r
.2239 .87254 m .21898 .87919 L .22564 .88095 L p F P
0 g
s
.833 .847 .857 r
.71331 .24944 m .71239 .24845 L .71308 .24784 L closepath p F P
0 g
s
.689 .673 .829 r
.42184 .78079 m .4233 .78311 L p .4096 .78327 L F P
0 g
s
.689 .673 .829 r
.4096 .78327 m .41456 .78098 L .42184 .78079 L p F P
0 g
s
.69 .675 .831 r
.4096 .78327 m .41456 .78098 L .40821 .7811 L closepath p F P
0 g
s
.785 .559 .594 r
.25183 .94818 m .24834 .94748 L .24951 .94179 L p F P
0 g
s
.787 .561 .594 r
.24222 .94028 m .24951 .94179 L .24834 .94748 L p F P
0 g
s
.774 .679 .759 r
.24203 .83379 m .2348 .84109 L .2415 .84287 L p F P
0 g
s
.774 .679 .759 r
.24345 .83418 m .24203 .83379 L p .2415 .84287 L F P
0 g
s
.776 .676 .754 r
.2415 .84287 m .23506 .8496 L .23189 .84413 L p F P
0 g
s
.776 .676 .754 r
.23189 .84413 m .2348 .84109 L .2415 .84287 L p F P
0 g
s
.791 .624 .675 r
.22512 .90655 m .22666 .90373 L .22397 .90308 L closepath p F P
0 g
s
.788 .633 .688 r
.22214 .89815 m .22362 .89569 L p .22666 .90373 L F P
0 g
s
.788 .633 .688 r
.22666 .90373 m .22397 .90308 L .22214 .89815 L p F P
0 g
s
.625 .252 .315 r
.4172 .99146 m .41138 .99152 L .40532 .98799 L p F P
0 g
s
.626 .25 .311 r
.41138 .99152 m .40335 .99158 L .40532 .98799 L closepath p F P
0 g
s
.657 .632 .813 r
.50855 .79318 m .49774 .79703 L .49481 .79156 L p F P
0 g
s
.879 .867 .823 r
.74215 .21354 m .74126 .21455 L .74202 .21893 L p F P
0 g
s
.87 .862 .829 r
.73488 .22147 m .73571 .22582 L .74202 .21893 L p F P
0 g
s
.87 .862 .829 r
.74202 .21893 m .74126 .21455 L .73488 .22147 L p F P
0 g
s
.71 .693 .832 r
.36539 .78063 m .35473 .78645 L .35164 .78185 L p F P
0 g
s
.598 .405 .591 r
.55827 .94533 m .56388 .94047 L .55798 .94172 L closepath p F P
0 g
s
.607 .412 .592 r
.55798 .94172 m .55827 .94533 L .55576 .94804 L p F P
0 g
s
.621 .55 .754 r
.57856 .83926 m .58108 .8461 L .57014 .84889 L p F P
0 g
s
.621 .55 .754 r
.57014 .84889 m .56772 .84234 L .57856 .83926 L p F P
0 g
s
.96 .808 .647 r
.58724 .20489 m .58938 .20888 L .59134 .20362 L p F P
0 g
s
.96 .808 .647 r
.59134 .20362 m .58917 .19963 L .58724 .20489 L p F P
0 g
s
.65 .276 .322 r
.38922 .99146 m .38606 .99139 L .38049 .98734 L p F P
0 g
s
.65 .275 .321 r
.37701 .98726 m .38049 .98734 L .38606 .99139 L p F P
0 g
s
.229 .468 .88 r
.75022 .05862 m .74982 .05845 L .74727 .05423 L p F P
0 g
s
.606 .491 .697 r
.58456 .89541 m .58273 .88838 L .59359 .88538 L p F P
0 g
s
.608 .502 .707 r
.59279 .88251 m .59359 .88538 L .58273 .88838 L p F P
0 g
s
.998 .83 .55 r
.77503 .12815 m .7765 .13241 L .77771 .12744 L p F P
0 g
s
.998 .83 .55 r
.77771 .12744 m .77625 .12318 L .77503 .12815 L p F P
0 g
s
.779 .676 .75 r
.23546 .85031 m .23506 .8496 L .23461 .85008 L closepath p F P
0 g
s
.756 .688 .787 r
.26434 .81375 m .26824 .81057 L .27538 .81225 L p F P
0 g
s
.754 .691 .791 r
.27508 .80514 m .26824 .81057 L .27538 .81225 L p F P
0 g
s
.754 .691 .791 r
.27538 .81225 m .27824 .80997 L .27508 .80514 L p F P
0 g
s
.736 .688 .805 r
.30277 .79896 m .30614 .79666 L .30062 .79569 L closepath p F P
0 g
s
.65 .275 .321 r
.38606 .99139 m .3748 .99111 L .37701 .98726 L p F P
0 g
s
.662 .289 .328 r
.36917 .98694 m .37701 .98726 L .3748 .99111 L p F P
0 g
s
.787 .662 .725 r
.2239 .87254 m .22721 .86829 L .22545 .86478 L p F P
0 g
s
.684 .668 .828 r
.43511 .78013 m .43701 .7832 L p .4233 .78311 L F P
0 g
s
.684 .668 .828 r
.4233 .78311 m .4293 .78044 L .43511 .78013 L p F P
0 g
s
.685 .671 .831 r
.4233 .78311 m .4293 .78044 L .42184 .78079 L closepath p F P
0 g
s
.806 .832 .871 r
.69372 .26404 m .69069 .26643 L .68811 .26358 L p F P
0 g
s
.626 .275 .356 r
.43274 .98724 m .43265 .98718 L .43277 .98718 L closepath p F P
0 g
s
.614 .242 .314 r
.43265 .98718 m .43274 .98724 L .43078 .99112 L p F P
0 g
s
.604 .236 .318 r
.43277 .98718 m .44603 .9866 L .44413 .99057 L p F P
0 g
s
.604 .236 .318 r
.43274 .98724 m .43277 .98718 L p .44413 .99057 L F P
0 g
s
.716 .381 .411 r
.33176 .98459 m .32801 .98423 L .32508 .97955 L p F P
0 g
s
.713 .371 .396 r
.31774 .97886 m .32508 .97955 L .32801 .98423 L p F P
0 g
s
.604 .236 .318 r
.44413 .99057 m .44024 .99075 L .43274 .98724 L p F P
0 g
s
.605 .233 .311 r
.44024 .99075 m .43078 .99112 L .43274 .98724 L closepath p F P
0 g
s
.634 .582 .779 r
.55707 .81621 m .55856 .81971 L .54766 .82287 L p F P
0 g
s
.634 .582 .779 r
.54766 .82287 m .54606 .81913 L .55707 .81621 L p F P
0 g
s
.716 .695 .828 r
.35164 .78185 m .34099 .78789 L .33788 .78333 L p F P
0 g
s
.614 .242 .314 r
.43078 .99112 m .42526 .99127 L .41902 .98803 L p F P
0 g
s
.615 .24 .309 r
.42526 .99127 m .4172 .99146 L .41902 .98803 L closepath p F P
0 g
s
.749 .691 .796 r
.28613 .80392 m .27824 .80997 L .27508 .80514 L p F P
0 g
s
.78 .678 .752 r
.23461 .85008 m .23506 .8496 L .23189 .84413 L p F P
0 g
s
.229 .468 .88 r
.74727 .05423 m .74798 .05452 L .75022 .05862 L p F P
0 g
s
.107 .382 .841 r
.75264 .05715 m .75486 .06126 L .75022 .05862 L p F P
0 g
s
.107 .382 .841 r
.75022 .05862 m .74798 .05452 L .75264 .05715 L p F P
0 g
s
.781 .673 .744 r
.22809 .84825 m .23461 .85008 L .22844 .85708 L p F P
0 g
s
.78 .678 .752 r
.23189 .84413 m .22809 .84825 L .23461 .85008 L p F P
0 g
s
.625 .725 .918 r
.61424 .28956 m .62529 .28669 L .62801 .29029 L p F P
0 g
s
.606 .713 .92 r
.62529 .28669 m .61424 .28956 L .61148 .28543 L p F P
0 g
s
.81 .835 .87 r
.69372 .26404 m .70155 .25774 L .699 .25494 L p F P
0 g
s
.81 .835 .87 r
.699 .25494 m .69311 .25966 L .69372 .26404 L p F P
0 g
s
.806 .832 .871 r
.68811 .26358 m .69311 .25966 L .69372 .26404 L p F P
0 g
s
.791 .634 .687 r
.22214 .89815 m .22362 .89569 L .22098 .89503 L closepath p F P
0 g
s
.788 .642 .699 r
.21912 .8905 m .22106 .88751 L p .22362 .89569 L F P
0 g
s
.788 .642 .699 r
.22362 .89569 m .22098 .89503 L .21912 .8905 L p F P
0 g
s
.777 .537 .572 r
.25183 .94818 m .25587 .94892 L .25521 .95448 L p F P
0 g
s
.776 .536 .572 r
.26294 .95587 m .25521 .95448 L .25587 .94892 L p F P
0 g
s
.908 .61 .117 r
.77254 .09651 m .77424 .10074 L .77365 .09648 L p F P
0 g
s
.908 .61 .117 r
.77365 .09648 m .77194 .09225 L .77254 .09651 L p F P
0 g
s
.623 .559 .762 r
.57818 .83829 m .57856 .83926 L .56772 .84234 L p F P
0 g
s
.623 .559 .762 r
.56772 .84234 m .56724 .84111 L .57818 .83829 L p F P
0 g
s
.982 .858 .641 r
.77642 .14213 m .77624 .142 L .77632 .1418 L closepath p F P
0 g
s
.662 .289 .328 r
.3748 .99111 m .3743 .99109 L .36917 .98694 L p F P
0 g
s
.652 .261 .29 r
.36231 .98666 m .36917 .98694 L .3743 .99109 L p F P
0 g
s
.992 .766 .393 r
.58816 .24165 m .58975 .24579 L .59014 .24106 L p F P
0 g
s
.992 .766 .393 r
.59014 .24106 m .58854 .23693 L .58816 .24165 L p F P
0 g
s
.733 .693 .812 r
.3103 .78716 m .31344 .7918 L .30614 .79666 L p F P
0 g
s
.733 .693 .812 r
.29963 .79423 m .3103 .78716 L p .30614 .79666 L F P
0 g
s
.733 .693 .812 r
.30614 .79666 m .30062 .79569 L .29963 .79423 L p F P
0 g
s
.863 .857 .833 r
.73144 .22509 m .73488 .22147 L .73571 .22582 L p F P
0 g
s
.863 .857 .833 r
.73571 .22582 m .73392 .2277 L .73144 .22509 L p F P
0 g
s
.946 .874 .734 r
.76871 .16528 m .76706 .16818 L .76816 .17251 L p F P
0 g
s
.934 .871 .751 r
.76342 .17409 m .76455 .1784 L .76816 .17251 L p F P
0 g
s
.934 .871 .751 r
.76816 .17251 m .76706 .16818 L .76342 .17409 L p F P
0 g
s
.794 .616 .66 r
.2265 .91077 m .22331 .90997 L p .2272 .91778 L F P
0 g
s
.794 .616 .66 r
.2272 .91778 m .22802 .91605 L .2265 .91077 L p F P
0 g
s
.794 .626 .673 r
.2265 .91077 m .22512 .90655 L .22331 .90997 L closepath p F P
0 g
s
.679 .662 .826 r
.44807 .77916 m .45071 .78354 L p .43701 .7832 L F P
0 g
s
.679 .662 .826 r
.43701 .7832 m .44607 .77933 L .44807 .77916 L p F P
0 g
s
.68 .667 .83 r
.43701 .7832 m .44607 .77933 L .43511 .78013 L closepath p F P
0 g
s
.326 .479 .859 r
.60646 .27776 m .60755 .28111 L .60046 .27902 L p F P
0 g
s
.326 .479 .859 r
.60592 .27689 m .60646 .27776 L p .60046 .27902 L F P
0 g
s
.326 .479 .859 r
.60046 .27902 m .59971 .27465 L .60592 .27689 L p F P
0 g
s
.024 .231 .736 r
.59862 .27038 m .59971 .27465 L .59594 .27138 L p F P
0 g
s
.024 .231 .736 r
.59594 .27138 m .59509 .26703 L .59862 .27038 L p F P
0 g
s
.795 .626 .673 r
.22331 .90997 m .22512 .90655 L .22397 .90308 L p F P
0 g
s
.623 .559 .762 r
.57529 .83082 m .57818 .83829 L .56724 .84111 L p F P
0 g
s
.623 .559 .762 r
.56724 .84111 m .56445 .83392 L .57529 .83082 L p F P
0 g
s
.587 .264 .389 r
.48575 .9792 m .49818 .97787 L .49698 .98234 L p F P
0 g
s
.587 .264 .389 r
.48467 .98337 m .48575 .9792 L p .49698 .98234 L F P
0 g
s
.613 .33 .464 r
.49841 .97649 m .49818 .97787 L .48575 .9792 L p F P
0 g
s
.984 .798 .574 r
.58643 .21907 m .58849 .22307 L .58975 .21806 L p F P
0 g
s
.984 .798 .574 r
.58975 .21806 m .58767 .21405 L .58643 .21907 L p F P
0 g
s
.978 .805 .602 r
.58807 .2127 m .58767 .21405 L .58975 .21806 L p F P
0 g
s
.857 .857 .84 r
.72874 .23295 m .73392 .2277 L .73144 .22509 L p F P
0 g
s
.795 .626 .673 r
.22397 .90308 m .2199 .90203 L p .22331 .90997 L F P
0 g
s
.795 .635 .684 r
.22397 .90308 m .22214 .89815 L .2199 .90203 L closepath p F P
0 g
s
.914 .783 .704 r
.59086 .16645 m .59356 .1703 L .59638 .16475 L p F P
0 g
s
.914 .783 .704 r
.59638 .16475 m .59369 .1609 L .59086 .16645 L p F P
0 g
s
.663 .634 .811 r
.492 .78635 m .49481 .79156 L p .48109 .79023 L F P
0 g
s
.663 .634 .811 r
.48109 .79023 m .49075 .78656 L .492 .78635 L p F P
0 g
s
.664 .641 .817 r
.48109 .79023 m .49075 .78656 L .48 .78826 L closepath p F P
0 g
s
.602 .479 .685 r
.5848 .89642 m .58456 .89541 L .59543 .89242 L p F P
0 g
s
.606 .491 .697 r
.59359 .88538 m .59543 .89242 L .58456 .89541 L p F P
0 g
s
.763 .484 .511 r
.28594 .97013 m .27953 .96913 L .27883 .9639 L p F P
0 g
s
.762 .482 .51 r
.27068 .96264 m .27883 .9639 L .27953 .96913 L p F P
0 g
s
.747 .443 .469 r
.30139 .97699 m .2979 .97652 L .29631 .97152 L p F P
0 g
s
.747 .441 .465 r
.28773 .97038 m .29631 .97152 L .2979 .97652 L p F P
0 g
s
.598 .445 .645 r
.57896 .92456 m .57788 .91822 L .58892 .91545 L p F P
0 g
s
.602 .458 .659 r
.58782 .90976 m .58892 .91545 L .57788 .91822 L p F P
0 g
s
.723 .689 .817 r
.32722 .78965 m .32904 .78855 L .32624 .78817 L closepath p F P
0 g
s
.73 .693 .815 r
.32624 .78817 m .32722 .78965 L p .31344 .7918 L F P
0 g
s
.98 .854 .643 r
.77392 .14021 m .77492 .13753 L .77632 .1418 L p F P
0 g
s
.98 .854 .643 r
.77632 .1418 m .77624 .142 L .77392 .14021 L p F P
0 g
s
.787 .662 .725 r
.22261 .86399 m .21736 .87073 L .2239 .87254 L p F P
0 g
s
.787 .662 .725 r
.22545 .86478 m .22261 .86399 L p .2239 .87254 L F P
0 g
s
.788 .659 .721 r
.21736 .87073 m .2239 .87254 L .21898 .87919 L p F P
0 g
s
.732 .781 .892 r
.64956 .28455 m .64171 .2888 L .63902 .28548 L p F P
0 g
s
.697 .771 .908 r
.62801 .29029 m .63902 .28548 L .64171 .2888 L p F P
0 g
s
.593 .313 .461 r
.51039 .97633 m .51113 .97149 L .52099 .97011 L p F P
0 g
s
.794 .616 .66 r
.22861 .91812 m .22802 .91605 L .2272 .91778 L closepath p F P
0 g
s
.979 .859 .65 r
.77421 .14712 m .77624 .142 L .77392 .14021 L p F P
0 g
s
.652 .261 .29 r
.361 .98898 m .36231 .98666 L p .3743 .99109 L F P
0 g
s
.676 .309 .342 r
.361 .98898 m .35826 .98643 L .36231 .98666 L closepath p F P
0 g
s
.905 .869 .792 r
.75138 .19698 m .75614 .19065 L .75713 .19498 L p F P
0 g
s
.905 .869 .792 r
.75215 .20023 m .75138 .19698 L p .75713 .19498 L F P
0 g
s
.905 .869 .792 r
.75713 .19498 m .75275 .20082 L .75215 .20023 L p F P
0 g
s
.925 .793 .697 r
.59014 .17712 m .59076 .17585 L .59327 .17975 L p F P
0 g
s
.925 .793 .697 r
.59327 .17975 m .59291 .18049 L .59014 .17712 L p F P
0 g
s
.819 .838 .863 r
.7039 .25576 m .70155 .25774 L .699 .25494 L p F P
0 g
s
.602 .479 .685 r
.58619 .90225 m .5848 .89642 L .59577 .89385 L p F P
0 g
s
.602 .479 .685 r
.59543 .89242 m .59577 .89385 L .5848 .89642 L p F P
0 g
s
.689 .68 .837 r
.41456 .78098 m .40821 .7811 L .40657 .77862 L p F P
0 g
s
.693 .682 .835 r
.40821 .7811 m .40657 .77862 L .4013 .78108 L closepath p F P
0 g
s
.789 .603 .649 r
.23162 .92543 m .23028 .92514 L .22861 .91812 L p F P
0 g
s
.796 .606 .646 r
.2272 .91778 m .22861 .91812 L .23028 .92514 L p F P
0 g
s
.959 .866 .704 r
.76899 .15816 m .77026 .16244 L .77301 .15687 L p F P
0 g
s
.959 .866 .704 r
.77301 .15687 m .77176 .15257 L .76899 .15816 L p F P
0 g
s
.693 .684 .836 r
.40353 .77415 m .40657 .77862 L .4013 .78108 L p F P
0 g
s
.693 .684 .836 r
.39285 .77905 m .40353 .77415 L p .4013 .78108 L F P
0 g
s
.693 .684 .836 r
.4013 .78108 m .39418 .78104 L .39285 .77905 L p F P
0 g
s
.749 .691 .796 r
.27508 .80514 m .27881 .80229 L .28613 .80392 L p F P
0 g
s
.748 .694 .8 r
.28578 .79712 m .27881 .80229 L .28613 .80392 L p F P
0 g
s
.748 .694 .8 r
.28613 .80392 m .28894 .80183 L .28578 .79712 L p F P
0 g
s
.596 .418 .612 r
.5691 .9372 m .56866 .93332 L .57986 .93074 L p F P
0 g
s
.601 .436 .63 r
.57896 .92456 m .57986 .93074 L .56866 .93332 L p F P
0 g
s
.604 .425 .612 r
.56866 .93332 m .5691 .9372 L .56388 .94047 L p F P
0 g
s
.635 .59 .786 r
.55567 .81307 m .55707 .81621 L .54606 .81913 L p F P
0 g
s
.635 .59 .786 r
.54606 .81913 m .54477 .81624 L .55567 .81307 L p F P
0 g
s
.595 .226 .313 r
.44603 .9866 m .44836 .98646 L .45657 .98988 L p F P
0 g
s
.595 .226 .313 r
.45657 .98988 m .44413 .99057 L .44603 .9866 L p F P
0 g
s
.857 .857 .84 r
.73144 .22509 m .728 .22858 L .72874 .23295 L p F P
0 g
s
.852 .854 .843 r
.72068 .23582 m .728 .22858 L .72874 .23295 L p F P
0 g
s
.852 .854 .843 r
.72874 .23295 m .72318 .23845 L .72068 .23582 L p F P
0 g
s
.698 .685 .834 r
.39418 .78104 m .39285 .77905 L .38909 .78088 L closepath p F P
0 g
s
.786 .669 .734 r
.22545 .86478 m .22408 .86221 L .22261 .86399 L closepath p F P
0 g
s
.824 .841 .862 r
.7039 .25576 m .71239 .24845 L .70986 .24569 L p F P
0 g
s
.824 .841 .862 r
.70986 .24569 m .70322 .25139 L .7039 .25576 L p F P
0 g
s
.819 .838 .863 r
.699 .25494 m .70322 .25139 L .7039 .25576 L p F P
0 g
s
.795 .636 .685 r
.2199 .90203 m .22214 .89815 L .22098 .89503 L p F P
0 g
s
0 .22 .743 r
.75844 .06433 m .76054 .06847 L .75699 .06539 L p F P
0 g
s
0 .22 .743 r
.75699 .06539 m .75486 .06126 L .75844 .06433 L p F P
0 g
s
.791 .455 0 r
.77014 .08804 m .77194 .09225 L .77076 .08823 L p F P
0 g
s
.791 .455 0 r
.77076 .08823 m .76896 .08402 L .77014 .08804 L p F P
0 g
s
.688 .678 .835 r
.42184 .78079 m .42029 .7784 L .41456 .78098 L closepath p F P
0 g
s
.689 .68 .837 r
.41727 .77389 m .42029 .7784 L .41456 .78098 L p F P
0 g
s
.689 .68 .837 r
.40657 .77862 m .41727 .77389 L p .41456 .78098 L F P
0 g
s
.783 .668 .737 r
.22844 .85708 m .22408 .86221 L .22093 .85634 L p F P
0 g
s
.783 .668 .737 r
.22093 .85634 m .22183 .85528 L .22844 .85708 L p F P
0 g
s
.781 .673 .744 r
.22844 .85708 m .22183 .85528 L .22809 .84825 L p F P
0 g
s
.72 .694 .824 r
.33476 .77883 m .33788 .78333 L .32904 .78855 L p F P
0 g
s
.72 .694 .824 r
.3241 .78508 m .33476 .77883 L p .32904 .78855 L F P
0 g
s
.72 .694 .824 r
.32904 .78855 m .32624 .78817 L .3241 .78508 L p F P
0 g
s
.791 .643 .698 r
.21912 .8905 m .22106 .88751 L .2175 .88659 L closepath p F P
0 g
s
.788 .651 .71 r
.21605 .88338 m .21898 .87919 L p .22106 .88751 L F P
0 g
s
.788 .651 .71 r
.22106 .88751 m .2175 .88659 L .21605 .88338 L p F P
0 g
s
.713 .371 .396 r
.3169 .98087 m .31774 .97886 L p .32801 .98423 L F P
0 g
s
.727 .398 .422 r
.3169 .98087 m .31569 .97863 L .31774 .97886 L closepath p F P
0 g
s
.594 .231 .322 r
.44836 .98646 m .45907 .98581 L .45725 .98984 L p F P
0 g
s
.594 .231 .322 r
.45725 .98984 m .45657 .98988 L .44836 .98646 L p F P
0 g
s
.937 .788 .67 r
.59098 .18511 m .59291 .18049 L .59014 .17712 L p F P
0 g
s
.643 .604 .795 r
.52811 .80707 m .53898 .80363 L p .5411 .81002 L F P
0 g
s
.643 .605 .796 r
.53729 .80007 m .53898 .80363 L .52811 .80707 L p F P
0 g
s
.643 .605 .796 r
.52811 .80707 m .52608 .80279 L .53729 .80007 L p F P
0 g
s
.772 .685 .767 r
.24345 .83418 m .24277 .83307 L .24203 .83379 L closepath p F P
0 g
s
.698 .686 .835 r
.3898 .77462 m .39285 .77905 L .38909 .78088 L p F P
0 g
s
.698 .686 .835 r
.37912 .77971 m .3898 .77462 L p .38909 .78088 L F P
0 g
s
.698 .686 .835 r
.38909 .78088 m .37971 .78059 L .37912 .77971 L p F P
0 g
s
.67 .288 .312 r
.35826 .98643 m .361 .98898 L .35998 .99045 L p F P
0 g
s
.67 .288 .312 r
.34769 .98582 m .35826 .98643 L p .35998 .99045 L F P
0 g
s
.69 .348 .391 r
.35826 .98643 m .34769 .98582 L .34741 .98547 L p F P
0 g
s
.674 .658 .826 r
.45071 .78354 m .46146 .77914 L .46443 .78415 L p F P
0 g
s
.675 .661 .829 r
.46067 .77784 m .46146 .77914 L .45071 .78354 L p F P
0 g
s
.675 .661 .829 r
.45071 .78354 m .44807 .77916 L .46067 .77784 L p F P
0 g
s
.743 .695 .806 r
.29823 .7952 m .28894 .80183 L .28578 .79712 L p F P
0 g
s
.844 .854 .85 r
.72127 .24026 m .72318 .23845 L .72068 .23582 L p F P
0 g
s
0 0 .436 r
.59392 .26278 m .59509 .26703 L .59313 .26313 L p F P
0 g
s
0 0 .436 r
.59313 .26313 m .59205 .25884 L .59392 .26278 L p F P
0 g
s
.795 .636 .685 r
.22098 .89503 m .21695 .89395 L p .2199 .90203 L F P
0 g
s
.795 .645 .696 r
.22098 .89503 m .21912 .8905 L .21695 .89395 L closepath p F P
0 g
s
.838 .85 .854 r
.71232 .24349 m .71308 .24784 L .72127 .24026 L p F P
0 g
s
.838 .85 .854 r
.72127 .24026 m .72063 .23586 L .71232 .24349 L p F P
0 g
s
.844 .854 .85 r
.72068 .23582 m .72063 .23586 L .72127 .24026 L p F P
0 g
s
.689 .764 .909 r
.63902 .28548 m .62801 .29029 L .62529 .28669 L p F P
0 g
s
.65 .618 .803 r
.51146 .79888 m .5223 .7952 L .52521 .80103 L p F P
0 g
s
.651 .62 .805 r
.52097 .79256 m .5223 .7952 L .51146 .79888 L p F P
0 g
s
.651 .62 .805 r
.51146 .79888 m .50952 .79503 L .52097 .79256 L p F P
0 g
s
.832 .843 .855 r
.71308 .24784 m .71239 .24845 L .70986 .24569 L p F P
0 g
s
.832 .843 .855 r
.70986 .24569 m .71232 .24349 L .71308 .24784 L p F P
0 g
s
.684 .677 .837 r
.4293 .78044 m .42184 .78079 L .42029 .7784 L p F P
0 g
s
.788 .59 .633 r
.23078 .92775 m .23162 .92543 L p .23665 .93293 L F P
0 g
s
.79 .592 .633 r
.23078 .92775 m .23162 .92543 L .23028 .92514 L closepath p F P
0 g
s
1 .807 .489 r
.7747 .11893 m .77625 .12318 L .77707 .11836 L p F P
0 g
s
1 .807 .489 r
.77707 .11836 m .77553 .1141 L .7747 .11893 L p F P
0 g
s
.775 .517 .544 r
.26944 .96245 m .26289 .96128 L .26294 .95587 L p F P
0 g
s
.775 .516 .544 r
.25521 .95448 m .26294 .95587 L .26289 .96128 L p F P
0 g
s
0 0 .344 r
.76706 .07983 m .76896 .08402 L .7671 .08026 L p F P
0 g
s
0 0 .344 r
.7671 .08026 m .7652 .07607 L .76706 .07983 L p F P
0 g
s
.796 .606 .646 r
.23028 .92514 m .22471 .92379 L .2272 .91778 L p F P
0 g
s
.797 .609 .647 r
.22042 .91609 m .2272 .91778 L .22471 .92379 L p F P
0 g
s
.794 .616 .66 r
.22331 .90997 m .22042 .91609 L .2272 .91778 L p F P
0 g
s
0 .003 .575 r
.7632 .07191 m .7652 .07607 L .76256 .07263 L p F P
0 g
s
0 .003 .575 r
.76256 .07263 m .76054 .06847 L .7632 .07191 L p F P
0 g
s
.6 .317 .459 r
.51039 .97633 m .50017 .97763 L .49841 .97649 L p F P
0 g
s
.602 .315 .454 r
.50017 .97763 m .49818 .97787 L .49841 .97649 L closepath p F P
0 g
s
.598 .405 .591 r
.55844 .94752 m .55827 .94533 L .56388 .94047 L p F P
0 g
s
.605 .41 .591 r
.55844 .94752 m .55827 .94533 L .55576 .94804 L closepath p F P
0 g
s
.775 .811 .882 r
.66816 .27786 m .66628 .27914 L .66364 .27608 L p F P
0 g
s
.758 .808 .892 r
.65268 .28285 m .66364 .27608 L .66628 .27914 L p F P
0 g
s
.777 .537 .572 r
.25521 .95448 m .25177 .95386 L .25183 .94818 L p F P
0 g
s
.786 .544 .571 r
.24834 .94748 m .25183 .94818 L .25177 .95386 L p F P
0 g
s
.727 .389 .406 r
.31569 .97863 m .3169 .98087 L .31584 .98306 L p F P
0 g
s
.727 .389 .406 r
.30672 .9776 m .31569 .97863 L p .31584 .98306 L F P
0 g
s
.95 .796 .656 r
.58682 .1957 m .58917 .19963 L .59123 .19435 L p F P
0 g
s
.95 .796 .656 r
.59123 .19435 m .58885 .19042 L .58682 .1957 L p F P
0 g
s
.789 .578 .616 r
.23154 .93183 m .23665 .93293 L .23493 .93875 L p F P
0 g
s
.788 .59 .633 r
.23665 .93293 m .23154 .93183 L .23078 .92775 L p F P
0 g
s
.787 .576 .615 r
.24222 .94028 m .23493 .93875 L .23665 .93293 L p F P
0 g
s
.664 .647 .823 r
.49075 .78656 m .48 .78826 L .47815 .78501 L p F P
0 g
s
.625 .568 .77 r
.57528 .83081 m .57529 .83082 L .56445 .83392 L p F P
0 g
s
.625 .568 .77 r
.56445 .83392 m .56435 .83365 L .57528 .83081 L p F P
0 g
s
.704 .688 .832 r
.37971 .78059 m .37912 .77971 L .37764 .78046 L closepath p F P
0 g
s
.625 .569 .771 r
.57528 .83081 m .56435 .83365 L .56145 .82655 L p F P
0 g
s
.769 .686 .771 r
.25004 .82626 m .24277 .83307 L .23959 .82797 L p F P
0 g
s
.769 .686 .771 r
.23959 .82797 m .24332 .82447 L .25004 .82626 L p F P
0 g
s
.767 .688 .776 r
.2504 .81803 m .24332 .82447 L .25004 .82626 L p F P
0 g
s
.767 .688 .776 r
.25004 .82626 m .25358 .82304 L .2504 .81803 L p F P
0 g
s
.73 .693 .815 r
.31344 .7918 m .32061 .78724 L .32624 .78817 L p F P
0 g
s
.728 .695 .818 r
.32061 .78724 m .31344 .7918 L .3103 .78716 L p F P
0 g
s
.598 .405 .591 r
.56388 .94047 m .56934 .93931 L p .55844 .94752 L F P
0 g
s
.603 .423 .611 r
.56934 .93931 m .5691 .9372 L .56388 .94047 L closepath p F P
0 g
s
.763 .687 .779 r
.25872 .81854 m .25358 .82304 L .2504 .81803 L p F P
0 g
s
.728 .696 .82 r
.32624 .78817 m .3241 .78508 L .32061 .78724 L closepath p F P
0 g
s
.635 .591 .787 r
.55291 .80689 m .55567 .81307 L .54477 .81624 L p F P
0 g
s
.635 .591 .787 r
.54477 .81624 m .5419 .80982 L .55291 .80689 L p F P
0 g
s
.598 .388 .567 r
.55576 .94804 m .55844 .94752 L .55866 .95312 L p F P
0 g
s
.598 .388 .567 r
.55866 .95312 m .5533 .95416 L .55576 .94804 L p F P
0 g
s
.797 .62 .662 r
.21661 .90825 m .22331 .90997 L .22042 .91609 L p F P
0 g
s
.795 .626 .673 r
.2199 .90203 m .21661 .90825 L .22331 .90997 L p F P
0 g
s
.774 .687 .768 r
.24203 .83379 m .24277 .83307 L .23959 .82797 L p F P
0 g
s
.773 .684 .764 r
.23548 .83195 m .24203 .83379 L .2348 .84109 L p F P
0 g
s
.774 .687 .768 r
.23959 .82797 m .23548 .83195 L .24203 .83379 L p F P
0 g
s
.706 .695 .837 r
.37605 .7753 m .36701 .7798 L .37764 .78046 L p F P
0 g
s
.706 .695 .837 r
.37764 .78046 m .37912 .77971 L .37605 .7753 L p F P
0 g
s
.704 .689 .833 r
.36539 .78063 m .36701 .7798 L .37764 .78046 L p F P
0 g
s
.761 .69 .784 r
.26112 .80888 m .25181 .81679 L .25872 .81854 L p F P
0 g
s
.761 .69 .784 r
.26122 .80891 m .26112 .80888 L p .25872 .81854 L F P
0 g
s
.761 .69 .784 r
.25872 .81854 m .26434 .81375 L .26122 .80891 L p F P
0 g
s
.763 .687 .779 r
.2504 .81803 m .25181 .81679 L .25872 .81854 L p F P
0 g
s
.74 .695 .808 r
.30062 .79569 m .29963 .79423 L .29823 .7952 L closepath p F P
0 g
s
.691 .348 .389 r
.34769 .98582 m .34726 .9858 L .34741 .98547 L closepath p F P
0 g
s
.776 .814 .883 r
.66816 .27786 m .6772 .27164 L .67459 .26868 L p F P
0 g
s
.776 .814 .883 r
.67459 .26868 m .66749 .2735 L .66816 .27786 L p F P
0 g
s
.775 .811 .882 r
.66364 .27608 m .66749 .2735 L .66816 .27786 L p F P
0 g
s
.795 .595 .631 r
.23028 .92514 m .22471 .92379 L p .22951 .93135 L F P
0 g
s
.795 .595 .631 r
.22951 .93135 m .23078 .92775 L .23028 .92514 L p F P
0 g
s
.683 .674 .834 r
.43511 .78013 m .43401 .7784 L .4293 .78044 L closepath p F P
0 g
s
.684 .677 .837 r
.43101 .77384 m .43401 .7784 L .4293 .78044 L p F P
0 g
s
.684 .677 .837 r
.42029 .7784 m .43101 .77384 L p .4293 .78044 L F P
0 g
s
.787 .67 .735 r
.22261 .86399 m .22408 .86221 L .22093 .85634 L p F P
0 g
s
.599 .468 .674 r
.58766 .90894 m .58619 .90225 L .59707 .89928 L p F P
0 g
s
.602 .479 .685 r
.59577 .89385 m .59707 .89928 L .58619 .90225 L p F P
0 g
s
.998 .788 .488 r
.58672 .23286 m .58854 .23693 L .5893 .23208 L p F P
0 g
s
.998 .788 .488 r
.5893 .23208 m .58746 .22801 L .58672 .23286 L p F P
0 g
s
.795 .645 .696 r
.21695 .89395 m .21912 .8905 L .2175 .88659 L p F P
0 g
s
.787 .561 .594 r
.24834 .94748 m .24103 .94596 L .24222 .94028 L p F P
0 g
s
.787 .562 .595 r
.23493 .93875 m .24222 .94028 L .24103 .94596 L p F P
0 g
s
.487 .621 .909 r
.60871 .28122 m .60755 .28111 L .60863 .28534 L p F P
0 g
s
.487 .621 .909 r
.60863 .28534 m .61148 .28543 L .60871 .28122 L p F P
0 g
s
.657 .632 .813 r
.49481 .79156 m .50563 .78769 L .50855 .79318 L p F P
0 g
s
.657 .634 .815 r
.5037 .78412 m .50563 .78769 L .49481 .79156 L p F P
0 g
s
.657 .634 .815 r
.49481 .79156 m .492 .78635 L .5037 .78412 L p F P
0 g
s
.756 .689 .787 r
.26434 .81375 m .26824 .81057 L .26122 .80891 L closepath p F P
0 g
s
.669 .653 .826 r
.46443 .78415 m .4752 .77994 L .47815 .78501 L p F P
0 g
s
.669 .656 .828 r
.4752 .77994 m .46443 .78415 L .46146 .77914 L p F P
0 g
s
.9 .87 .8 r
.75275 .20082 m .75237 .2013 L .75215 .20023 L closepath p F P
0 g
s
.789 .666 .728 r
.21618 .86214 m .22261 .86399 L .21736 .87073 L p F P
0 g
s
.787 .67 .735 r
.22093 .85634 m .21618 .86214 L .22261 .86399 L p F P
0 g
s
.67 .288 .314 r
.34726 .9858 m .34769 .98582 L .35268 .99 L p F P
0 g
s
.67 .288 .312 r
.35998 .99045 m .35268 .99 L .34769 .98582 L p F P
0 g
s
.697 .696 .845 r
.3898 .77462 m .37912 .77971 L .37605 .7753 L p F P
0 g
s
.791 .652 .709 r
.21605 .88338 m .21898 .87919 L .21349 .87771 L closepath p F P
0 g
s
.788 .659 .721 r
.21296 .87663 m .21736 .87073 L p .21898 .87919 L F P
0 g
s
.788 .659 .721 r
.21898 .87919 m .21349 .87771 L .21296 .87663 L p F P
0 g
s
.585 .221 .317 r
.45725 .98984 m .45907 .98581 L .46574 .98532 L p F P
0 g
s
.59 .362 .539 r
.54713 .95534 m .5533 .95416 L .55529 .95915 L p F P
0 g
s
.59 .362 .539 r
.55529 .95915 m .54708 .96072 L .54713 .95534 L p F P
0 g
s
.599 .37 .54 r
.54713 .95534 m .54708 .96072 L .53538 .96277 L p F P
0 g
s
.797 .63 .675 r
.21329 .90027 m .2199 .90203 L .21661 .90825 L p F P
0 g
s
.795 .636 .685 r
.21695 .89395 m .21329 .90027 L .2199 .90203 L p F P
0 g
s
.773 .684 .764 r
.22872 .83873 m .23548 .83195 L p .2348 .84109 L F P
0 g
s
.773 .684 .764 r
.2348 .84109 m .22924 .83959 L .22872 .83873 L p F P
0 g
s
.777 .678 .754 r
.23189 .84413 m .2348 .84109 L .22924 .83959 L closepath p F P
0 g
s
.67 .288 .314 r
.35268 .99 m .34482 .98953 L .34726 .9858 L p F P
0 g
s
.684 .305 .322 r
.33777 .98505 m .34726 .9858 L .34482 .98953 L p F P
0 g
s
.884 .863 .814 r
.74601 .20354 m .74696 .20787 L .75237 .2013 L p F P
0 g
s
.884 .863 .814 r
.75031 .19831 m .74601 .20354 L p .75237 .2013 L F P
0 g
s
.884 .863 .814 r
.75237 .2013 m .75215 .20023 L .75031 .19831 L p F P
0 g
s
.692 .693 .846 r
.40353 .77415 m .39285 .77905 L .3898 .77462 L p F P
0 g
s
.679 .672 .836 r
.44607 .77933 m .43511 .78013 L .43401 .7784 L p F P
0 g
s
.966 .808 .634 r
.58545 .21009 m .58724 .20489 L .58938 .20888 L p F P
0 g
s
.966 .808 .634 r
.5859 .21094 m .58545 .21009 L p .58938 .20888 L F P
0 g
s
.966 .808 .634 r
.58938 .20888 m .58807 .2127 L .5859 .21094 L p F P
0 g
s
.704 .69 .833 r
.36539 .78063 m .36701 .7798 L .36472 .77966 L closepath p F P
0 g
s
.71 .693 .832 r
.36472 .77966 m .36539 .78063 L p .35164 .78185 L F P
0 g
s
.926 .869 .762 r
.75951 .18011 m .76342 .17409 L .76455 .1784 L p F P
0 g
s
.926 .869 .762 r
.76054 .18392 m .75951 .18011 L p .76455 .1784 L F P
0 g
s
.926 .869 .762 r
.76455 .1784 m .76081 .18418 L .76054 .18392 L p F P
0 g
s
.753 .694 .795 r
.27223 .80083 m .27508 .80514 L .26824 .81057 L p F P
0 g
s
.753 .694 .795 r
.27152 .80065 m .27223 .80083 L p .26824 .81057 L F P
0 g
s
.753 .694 .795 r
.26117 .80884 m .27152 .80065 L p .26824 .81057 L F P
0 g
s
.753 .694 .795 r
.26824 .81057 m .26122 .80891 L .26117 .80884 L p F P
0 g
s
.809 .525 0 r
.59069 .25464 m .59205 .25884 L .59121 .25454 L p F P
0 g
s
.809 .525 0 r
.59121 .25454 m .58987 .25033 L .59069 .25464 L p F P
0 g
s
.452 .614 .919 r
.7305 .04445 m .73585 .04481 L .73827 .04887 L p F P
0 g
s
.378 .57 .913 r
.74216 .04595 m .73585 .04481 L .73827 .04887 L p F P
0 g
s
.378 .57 .913 r
.73827 .04887 m .74472 .05006 L .74216 .04595 L p F P
0 g
s
.795 .594 .631 r
.23154 .93183 m .23078 .92775 L .22951 .93135 L closepath p F P
0 g
s
.687 .69 .847 r
.41727 .77389 m .40657 .77862 L .40353 .77415 L p F P
0 g
s
.781 .679 .752 r
.22809 .84825 m .23189 .84413 L .22924 .83959 L p F P
0 g
s
.743 .695 .806 r
.28578 .79712 m .29074 .79361 L .29823 .7952 L p F P
0 g
s
.742 .698 .81 r
.29647 .78966 m .29074 .79361 L .29823 .7952 L p F P
0 g
s
.742 .698 .81 r
.29823 .7952 m .29963 .79423 L .29647 .78966 L p F P
0 g
s
.588 .337 .504 r
.53503 .9679 m .53538 .96277 L .54708 .96072 L p F P
0 g
s
.597 .345 .506 r
.53538 .96277 m .53503 .9679 L .52317 .96979 L p F P
0 g
s
.795 .645 .696 r
.2175 .88659 m .21445 .88574 L p .21695 .89395 L F P
0 g
s
.794 .653 .706 r
.2175 .88659 m .21605 .88338 L .21445 .88574 L closepath p F P
0 g
s
.747 .441 .465 r
.28594 .97013 m .28773 .97038 L .28938 .97537 L p F P
0 g
s
.747 .441 .465 r
.2979 .97652 m .28938 .97537 L .28773 .97038 L p F P
0 g
s
.589 .381 .567 r
.55866 .95312 m .55844 .94752 L .5698 .94511 L p F P
0 g
s
.598 .405 .591 r
.56934 .93931 m .5698 .94511 L .55844 .94752 L p F P
0 g
s
.644 .612 .803 r
.53608 .7976 m .53729 .80007 L .52608 .80279 L p F P
0 g
s
.644 .612 .803 r
.52608 .80279 m .52521 .80103 L .53608 .7976 L p F P
0 g
s
.45 .617 .921 r
.73585 .04481 m .7305 .04445 L .72794 .04041 L p F P
0 g
s
.595 .418 .611 r
.56934 .93931 m .5691 .9372 L .58 .9319 L p F P
0 g
s
.596 .418 .612 r
.57986 .93074 m .58 .9319 L .5691 .9372 L p F P
0 g
s
.716 .695 .828 r
.34915 .77822 m .35164 .78185 L p .33788 .78333 L F P
0 g
s
.71 .693 .832 r
.35164 .78185 m .3571 .77893 L .36472 .77966 L p F P
0 g
s
.71 .691 .83 r
.35164 .78185 m .3571 .77893 L .34915 .77822 L closepath p F P
0 g
s
.786 .544 .571 r
.25177 .95386 m .24769 .95303 L .24834 .94748 L p F P
0 g
s
.787 .545 .571 r
.24103 .94596 m .24834 .94748 L .24769 .95303 L p F P
0 g
s
.99 .842 .601 r
.77344 .13328 m .77492 .13753 L .7765 .13241 L p F P
0 g
s
.99 .842 .601 r
.7765 .13241 m .77503 .12815 L .77344 .13328 L p F P
0 g
s
.593 .43 .63 r
.57986 .93074 m .57896 .92456 L .59001 .9218 L p F P
0 g
s
.598 .445 .645 r
.58892 .91545 m .59001 .9218 L .57896 .92456 L p F P
0 g
s
.736 .7 .816 r
.3103 .78716 m .29963 .79423 L .29647 .78966 L p F P
0 g
s
.762 .482 .51 r
.27953 .96913 m .27139 .96786 L .27068 .96264 L p F P
0 g
s
.763 .483 .509 r
.26944 .96245 m .27068 .96264 L .27139 .96786 L p F P
0 g
s
.994 .77 .407 r
.7739 .10986 m .77553 .1141 L .77593 .10945 L p F P
0 g
s
.994 .77 .407 r
.77593 .10945 m .77431 .10521 L .7739 .10986 L p F P
0 g
s
.582 .265 .397 r
.49818 .97787 m .50017 .97763 L .50909 .98087 L p F P
0 g
s
.582 .265 .397 r
.50909 .98087 m .49698 .98234 L .49818 .97787 L p F P
0 g
s
.702 .694 .84 r
.37297 .77099 m .37605 .7753 L .36701 .7798 L p F P
0 g
s
.702 .694 .84 r
.3623 .77621 m .37297 .77099 L p .36701 .7798 L F P
0 g
s
.702 .694 .84 r
.36701 .7798 m .36472 .77966 L .3623 .77621 L p F P
0 g
s
.651 .626 .812 r
.51939 .78954 m .52097 .79256 L .50952 .79503 L p F P
0 g
s
.651 .626 .812 r
.50952 .79503 m .50855 .79318 L .51939 .78954 L p F P
0 g
s
.915 .784 .702 r
.58806 .172 m .59076 .17585 L .59356 .1703 L p F P
0 g
s
.915 .784 .702 r
.59356 .1703 m .59086 .16645 L .58806 .172 L p F P
0 g
s
.682 .686 .847 r
.43101 .77384 m .42029 .7784 L .41727 .77389 L p F P
0 g
s
.73 .789 .9 r
.64956 .28455 m .65268 .28285 L .65001 .27968 L p F P
0 g
s
.73 .789 .9 r
.65001 .27968 m .64941 .28001 L .64956 .28455 L p F P
0 g
s
.732 .781 .892 r
.63902 .28548 m .64941 .28001 L .64956 .28455 L p F P
0 g
s
.749 .691 .796 r
.27508 .80514 m .27881 .80229 L .27223 .80083 L closepath p F P
0 g
s
.782 .677 .748 r
.22162 .8464 m .22809 .84825 L .22183 .85528 L p F P
0 g
s
.781 .679 .752 r
.22818 .83928 m .22162 .8464 L .22809 .84825 L p F P
0 g
s
.781 .679 .752 r
.22924 .83959 m .22818 .83928 L p .22809 .84825 L F P
0 g
s
.797 .64 .687 r
.21043 .89216 m .21695 .89395 L .21329 .90027 L p F P
0 g
s
.795 .645 .696 r
.21445 .88574 m .21043 .89216 L .21695 .89395 L p F P
0 g
s
.747 .441 .465 r
.28938 .97537 m .28447 .97471 L .28594 .97013 L p F P
0 g
s
.758 .452 .468 r
.27953 .96913 m .28594 .97013 L .28447 .97471 L p F P
0 g
s
.625 .569 .771 r
.56145 .82655 m .57239 .82369 L .57528 .83081 L p F P
0 g
s
.625 .57 .772 r
.57174 .82209 m .57239 .82369 L .56145 .82655 L p F P
0 g
s
.625 .57 .772 r
.56145 .82655 m .56091 .82521 L .57174 .82209 L p F P
0 g
s
.709 .696 .836 r
.36472 .77966 m .3623 .77621 L .3571 .77893 L closepath p F P
0 g
s
.593 .318 .469 r
.52297 .9713 m .52099 .97011 L .52317 .96979 L closepath p F P
0 g
s
.593 .313 .461 r
.52099 .97011 m .52297 .9713 L p .51039 .97633 L F P
0 g
s
.588 .233 .334 r
.4709 .98729 m .46574 .98532 L .47191 .98484 L closepath p F P
0 g
s
.585 .221 .317 r
.46574 .98532 m .4709 .98729 L p .45725 .98984 L F P
0 g
s
.728 .695 .818 r
.3103 .78716 m .31235 .78588 L .32061 .78724 L p F P
0 g
s
.729 .7 .822 r
.32097 .78062 m .31235 .78588 L .32061 .78724 L p F P
0 g
s
.729 .7 .822 r
.32061 .78724 m .3241 .78508 L .32097 .78062 L p F P
0 g
s
.763 .483 .509 r
.27139 .96786 m .26845 .9674 L .26944 .96245 L p F P
0 g
s
.773 .493 .511 r
.26289 .96128 m .26944 .96245 L .26845 .9674 L p F P
0 g
s
.716 .695 .828 r
.33788 .78333 m .34736 .778 L .34915 .77822 L p F P
0 g
s
.715 .699 .834 r
.34736 .778 m .33788 .78333 L .33476 .77883 L p F P
0 g
s
.947 .866 .725 r
.76633 .16306 m .76899 .15816 L .77026 .16244 L p F P
0 g
s
.947 .866 .725 r
.77026 .16244 m .76871 .16528 L .76633 .16306 L p F P
0 g
s
.643 .604 .795 r
.53898 .80363 m .54187 .80977 L .5411 .81002 L p F P
0 g
s
.642 .601 .792 r
.5419 .80982 m .54187 .80977 L .5411 .81002 L closepath p F P
0 g
s
.581 .269 .405 r
.50017 .97763 m .51039 .97633 L .50927 .98085 L p F P
0 g
s
.581 .269 .405 r
.50927 .98085 m .50909 .98087 L .50017 .97763 L p F P
0 g
s
.664 .647 .823 r
.47815 .78501 m .48894 .781 L p .49075 .78656 L F P
0 g
s
.664 .652 .828 r
.48894 .781 m .47815 .78501 L .4752 .77994 L p F P
0 g
s
.727 .389 .406 r
.31584 .98306 m .30951 .98231 L .30672 .9776 L p F P
0 g
s
.722 .374 .39 r
.30139 .97699 m .30672 .9776 L .30951 .98231 L p F P
0 g
s
.645 .615 .805 r
.53608 .7976 m .52521 .80103 L .5223 .7952 L p F P
0 g
s
.979 .859 .65 r
.77392 .14021 m .77289 .14283 L .77421 .14712 L p F P
0 g
s
.967 .862 .683 r
.77042 .14829 m .77176 .15257 L .77421 .14712 L p F P
0 g
s
.967 .862 .683 r
.77421 .14712 m .77289 .14283 L .77042 .14829 L p F P
0 g
s
.627 .578 .779 r
.5695 .81683 m .57174 .82209 L .56091 .82521 L p F P
0 g
s
.627 .578 .779 r
.56091 .82521 m .55856 .81971 L .5695 .81683 L p F P
0 g
s
.795 .654 .707 r
.21445 .88574 m .21605 .88338 L .21349 .87771 L p F P
0 g
s
.789 .578 .616 r
.23493 .93875 m .23238 .9382 L .23154 .93183 L p F P
0 g
s
.796 .583 .613 r
.22951 .93135 m .23154 .93183 L .23238 .9382 L p F P
0 g
s
.746 .696 .804 r
.28262 .79245 m .28578 .79712 L .27881 .80229 L p F P
0 g
s
.746 .696 .804 r
.2719 .80035 m .28262 .79245 L p .27881 .80229 L F P
0 g
s
.746 .696 .804 r
.27881 .80229 m .27223 .80083 L .2719 .80035 L p F P
0 g
s
.79 .821 .876 r
.68163 .26841 m .6772 .27164 L .67459 .26868 L p F P
0 g
s
.94 .787 .663 r
.5863 .18654 m .58885 .19042 L .59098 .18511 L p F P
0 g
s
.94 .787 .663 r
.59098 .18511 m .58843 .18123 L .5863 .18654 L p F P
0 g
s
.937 .788 .67 r
.59014 .17712 m .58843 .18123 L .59098 .18511 L p F P
0 g
s
.594 .453 .66 r
.58782 .90976 m .58766 .90894 L .59855 .90598 L p F P
0 g
s
.599 .468 .674 r
.59707 .89928 m .59855 .90598 L .58766 .90894 L p F P
0 g
s
.607 .518 .728 r
.58938 .87079 m .58699 .86322 L .59019 .86226 L p F P
0 g
s
.61 .528 .737 r
.58699 .86322 m .58691 .86296 L .59019 .86226 L closepath p F P
0 g
s
.61 .528 .737 r
.59019 .86226 m .58691 .86296 L .58439 .85544 L p F P
0 g
s
.679 .672 .836 r
.43401 .7784 m .44475 .774 L p .44607 .77933 L F P
0 g
s
.678 .681 .846 r
.44475 .774 m .43401 .7784 L .43101 .77384 L p F P
0 g
s
.607 .518 .728 r
.5979 .86066 m .60009 .86758 L .58938 .87079 L p F P
0 g
s
.607 .518 .728 r
.59019 .86226 m .5979 .86066 L p .58938 .87079 L F P
0 g
s
.604 .508 .718 r
.58984 .87233 m .58938 .87079 L .60009 .86758 L p F P
0 g
s
.883 .862 .814 r
.74033 .21021 m .74601 .20354 L .74696 .20787 L p F P
0 g
s
.883 .862 .814 r
.74078 .21212 m .74033 .21021 L p .74696 .20787 L F P
0 g
s
.883 .862 .814 r
.74696 .20787 m .74215 .21354 L .74078 .21212 L p F P
0 g
s
.636 .598 .794 r
.55278 .8066 m .55291 .80689 L .5419 .80982 L p F P
0 g
s
.636 .598 .794 r
.5419 .80982 m .54187 .80977 L .55278 .8066 L p F P
0 g
s
.637 .601 .796 r
.55278 .8066 m .54187 .80977 L .53898 .80363 L p F P
0 g
s
.893 .862 .802 r
.75215 .20023 m .75031 .19831 L .75138 .19698 L closepath p F P
0 g
s
.678 .668 .833 r
.44807 .77916 m .44774 .77863 L .44607 .77933 L closepath p F P
0 g
s
.679 .672 .836 r
.44475 .774 m .44774 .77863 L .44607 .77933 L p F P
0 g
s
.99 .791 .543 r
.58542 .224 m .58746 .22801 L .58849 .22307 L p F P
0 g
s
.99 .791 .543 r
.58849 .22307 m .58643 .21907 L .58542 .224 L p F P
0 g
s
.684 .305 .322 r
.34482 .98953 m .34234 .98933 L .33777 .98505 L p F P
0 g
s
.674 .279 .288 r
.33176 .98459 m .33777 .98505 L .34234 .98933 L p F P
0 g
s
.604 .507 .718 r
.59158 .87817 m .58984 .87233 L .60084 .87011 L p F P
0 g
s
.604 .508 .718 r
.60009 .86758 m .60084 .87011 L .58984 .87233 L p F P
0 g
s
.581 .303 .459 r
.52317 .96979 m .53503 .9679 L .53436 .97276 L p F P
0 g
s
.581 .303 .459 r
.52297 .9713 m .52317 .96979 L p .53436 .97276 L F P
0 g
s
.588 .397 .59 r
.5698 .94511 m .56934 .93931 L .58055 .93673 L p F P
0 g
s
.595 .418 .611 r
.58 .9319 m .58055 .93673 L .56934 .93931 L p F P
0 g
s
.789 .666 .728 r
.21736 .87073 m .21086 .86891 L .21618 .86214 L p F P
0 g
s
.791 .66 .719 r
.21736 .87073 m .21296 .87663 L .20983 .87029 L p F P
0 g
s
.791 .66 .719 r
.20983 .87029 m .21086 .86891 L .21736 .87073 L p F P
0 g
s
.594 .453 .659 r
.58892 .91545 m .58782 .90976 L .59881 .90731 L p F P
0 g
s
.594 .453 .66 r
.59855 .90598 m .59881 .90731 L .58782 .90976 L p F P
0 g
s
.652 .63 .815 r
.51939 .78954 m .50855 .79318 L .50563 .78769 L p F P
0 g
s
.61 .528 .737 r
.58439 .85544 m .59509 .8522 L p .59019 .86226 L F P
0 g
s
.612 .537 .746 r
.59498 .85189 m .59509 .8522 L .58439 .85544 L p F P
0 g
s
.612 .537 .746 r
.58439 .85544 m .58399 .8543 L .59498 .85189 L p F P
0 g
s
.776 .517 .544 r
.25177 .95386 m .25521 .95448 L .25516 .95989 L p F P
0 g
s
.775 .516 .544 r
.26289 .96128 m .25516 .95989 L .25521 .95448 L p F P
0 g
s
.959 .699 .256 r
.58829 .2462 m .58987 .25033 L .58975 .24579 L p F P
0 g
s
.959 .699 .256 r
.58975 .24579 m .58816 .24165 L .58829 .2462 L p F P
0 g
s
.612 .537 .746 r
.59227 .8442 m .59498 .85189 L .58399 .8543 L p F P
0 g
s
.612 .537 .746 r
.58399 .8543 m .58159 .84746 L .59227 .8442 L p F P
0 g
s
.673 .666 .835 r
.45849 .77439 m .46067 .77784 L .44807 .77916 L p F P
0 g
s
.673 .666 .835 r
.44807 .77916 m .44774 .77863 L .45849 .77439 L p F P
0 g
s
.713 .371 .396 r
.32801 .98423 m .31857 .98332 L .3169 .98087 L p F P
0 g
s
.713 .371 .396 r
.31857 .98332 m .31584 .98306 L .3169 .98087 L closepath p F P
0 g
s
.227 .471 .883 r
.74798 .05452 m .74727 .05423 L .74472 .05006 L p F P
0 g
s
.756 .804 .891 r
.66364 .27608 m .65268 .28285 L .65001 .27968 L p F P
0 g
s
.722 .702 .831 r
.33476 .77883 m .3241 .78508 L .32097 .78062 L p F P
0 g
s
.601 .498 .709 r
.59279 .88251 m .59158 .87817 L .60229 .87498 L p F P
0 g
s
.604 .507 .718 r
.60084 .87011 m .60229 .87498 L .59158 .87817 L p F P
0 g
s
.563 .191 .295 r
.47191 .98484 m .48457 .9837 L .48279 .98772 L p F P
0 g
s
.563 .191 .295 r
.4709 .98729 m .47191 .98484 L p .48279 .98772 L F P
0 g
s
.604 .286 .403 r
.48467 .98337 m .48457 .9837 L .47191 .98484 L p F P
0 g
s
.785 .671 .738 r
.22093 .85634 m .22183 .85528 L .22009 .85479 L closepath p F P
0 g
s
.782 .677 .748 r
.21776 .85073 m .22162 .8464 L p .22183 .85528 L F P
0 g
s
.782 .677 .748 r
.22183 .85528 m .22009 .85479 L .21776 .85073 L p F P
0 g
s
.797 .649 .698 r
.20803 .88391 m .21445 .88574 L .21043 .89216 L p F P
0 g
s
.795 .654 .707 r
.2124 .8774 m .20803 .88391 L .21445 .88574 L p F P
0 g
s
.795 .654 .707 r
.21349 .87771 m .2124 .8774 L p .21445 .88574 L F P
0 g
s
.793 .825 .877 r
.68163 .26841 m .68811 .26358 L .68552 .26068 L p F P
0 g
s
.793 .825 .877 r
.68552 .26068 m .68099 .26403 L .68163 .26841 L p F P
0 g
s
.79 .821 .876 r
.67459 .26868 m .68099 .26403 L .68163 .26841 L p F P
0 g
s
.972 .711 .293 r
.7726 .10098 m .77431 .10521 L .77424 .10074 L p F P
0 g
s
.972 .711 .293 r
.77424 .10074 m .77254 .09651 L .7726 .10098 L p F P
0 g
s
.606 .713 .92 r
.61148 .28543 m .62256 .28301 L .62529 .28669 L p F P
0 g
s
.586 .7 .922 r
.62256 .28301 m .61148 .28543 L .60871 .28122 L p F P
0 g
s
.795 .595 .631 r
.22471 .92379 m .22263 .9297 L .22951 .93135 L p F P
0 g
s
.798 .599 .633 r
.2179 .92211 m .22471 .92379 L .22263 .9297 L p F P
0 g
s
.797 .609 .647 r
.22471 .92379 m .2179 .92211 L .22042 .91609 L p F P
0 g
s
.789 .672 .735 r
.21618 .86214 m .22093 .85634 L .22009 .85479 L p F P
0 g
s
.673 .676 .844 r
.45849 .77439 m .44774 .77863 L .44475 .774 L p F P
0 g
s
.922 .871 .77 r
.76081 .18418 m .76066 .18441 L .76054 .18392 L closepath p F P
0 g
s
.663 .643 .82 r
.492 .78635 m .49188 .78613 L .49075 .78656 L closepath p F P
0 g
s
.664 .647 .823 r
.48894 .781 m .49188 .78613 L .49075 .78656 L p F P
0 g
s
.707 .696 .837 r
.3592 .77191 m .3623 .77621 L .3571 .77893 L p F P
0 g
s
.707 .696 .837 r
.34854 .77735 m .3592 .77191 L p .3571 .77893 L F P
0 g
s
.707 .696 .837 r
.3571 .77893 m .34915 .77822 L .34854 .77735 L p F P
0 g
s
.796 .583 .613 r
.23238 .9382 m .22788 .93715 L .22951 .93135 L p F P
0 g
s
.797 .585 .614 r
.22263 .9297 m .22951 .93135 L .22788 .93715 L p F P
0 g
s
.798 .611 .649 r
.21367 .91438 m .22042 .91609 L .2179 .92211 L p F P
0 g
s
.797 .62 .662 r
.22042 .91609 m .21367 .91438 L .21661 .90825 L p F P
0 g
s
.905 .865 .789 r
.75505 .18633 m .75614 .19065 L .76066 .18441 L p F P
0 g
s
.905 .865 .789 r
.7584 .18171 m .75505 .18633 L p .76066 .18441 L F P
0 g
s
.905 .865 .789 r
.76066 .18441 m .76054 .18392 L .7584 .18171 L p F P
0 g
s
.954 .796 .646 r
.5849 .20095 m .58724 .20489 L .58917 .19963 L p F P
0 g
s
.954 .796 .646 r
.58917 .19963 m .58682 .1957 L .5849 .20095 L p F P
0 g
s
.614 .546 .754 r
.59207 .84365 m .59227 .8442 L .58159 .84746 L p F P
0 g
s
.614 .546 .754 r
.58159 .84746 m .58108 .8461 L .59207 .84365 L p F P
0 g
s
.589 .362 .539 r
.5533 .95416 m .55866 .95312 L .55863 .9585 L p F P
0 g
s
.589 .362 .539 r
.55863 .9585 m .55529 .95915 L .5533 .95416 L p F P
0 g
s
.742 .696 .807 r
.29074 .79361 m .28578 .79712 L .28262 .79245 L p F P
0 g
s
.945 .869 .732 r
.76706 .16818 m .76871 .16528 L .76633 .16306 L p F P
0 g
s
.601 .497 .708 r
.59359 .88538 m .59279 .88251 L .60381 .88036 L p F P
0 g
s
.601 .498 .709 r
.60229 .87498 m .60381 .88036 L .59279 .88251 L p F P
0 g
s
.722 .374 .39 r
.29986 .9803 m .30139 .97699 L p .30951 .98231 L F P
0 g
s
.738 .404 .417 r
.29986 .9803 m .2979 .97652 L .30139 .97699 L closepath p F P
0 g
s
.674 .279 .288 r
.33037 .9868 m .33176 .98459 L p .34234 .98933 L F P
0 g
s
.699 .328 .341 r
.33037 .9868 m .32801 .98423 L .33176 .98459 L closepath p F P
0 g
s
.972 .795 .605 r
.58807 .2127 m .58767 .21405 L .5859 .21094 L closepath p F P
0 g
s
.614 .547 .755 r
.58924 .83597 m .59207 .84365 L .58108 .8461 L p F P
0 g
s
.614 .547 .755 r
.58108 .8461 m .57856 .83926 L .58924 .83597 L p F P
0 g
s
.77 .687 .771 r
.24332 .82447 m .23959 .82797 L .23639 .82288 L p F P
0 g
s
.77 .687 .771 r
.23639 .82288 m .23664 .82265 L .24332 .82447 L p F P
0 g
s
.769 .691 .777 r
.24514 .81497 m .23664 .82265 L .24332 .82447 L p F P
0 g
s
.769 .691 .777 r
.24917 .81611 m .24514 .81497 L p .24332 .82447 L F P
0 g
s
.769 .691 .777 r
.24332 .82447 m .2504 .81803 L .24917 .81611 L p F P
0 g
s
.658 .64 .821 r
.5027 .78233 m .5037 .78412 L .492 .78635 L p F P
0 g
s
.658 .64 .821 r
.492 .78635 m .49188 .78613 L .5027 .78233 L p F P
0 g
s
.877 .862 .822 r
.74215 .21354 m .74126 .21455 L .74078 .21212 L closepath p F P
0 g
s
.764 .689 .78 r
.2504 .81803 m .25181 .81679 L .24917 .81611 L closepath p F P
0 g
s
.996 .826 .556 r
.77347 .12391 m .77503 .12815 L .77625 .12318 L p F P
0 g
s
.996 .826 .556 r
.77625 .12318 m .7747 .11893 L .77347 .12391 L p F P
0 g
s
.775 .688 .768 r
.23548 .83195 m .23959 .82797 L .23639 .82288 L p F P
0 g
s
.76 .694 .789 r
.25444 .80706 m .26112 .80888 L .25181 .81679 L p F P
0 g
s
.76 .694 .789 r
.24721 .81316 m .25444 .80706 L p .25181 .81679 L F P
0 g
s
.76 .694 .789 r
.25181 .81679 m .24917 .81611 L .24721 .81316 L p F P
0 g
s
.787 .562 .595 r
.24103 .94596 m .23371 .94445 L .23493 .93875 L p F P
0 g
s
.789 .565 .596 r
.23238 .9382 m .23493 .93875 L .23371 .94445 L p F P
0 g
s
.598 .487 .698 r
.59543 .89242 m .59359 .88538 L .60432 .88221 L p F P
0 g
s
.601 .497 .708 r
.60381 .88036 m .60432 .88221 L .59359 .88538 L p F P
0 g
s
.227 .471 .883 r
.74472 .05006 m .74565 .05043 L .74798 .05452 L p F P
0 g
s
.1 .383 .843 r
.75033 .05305 m .75264 .05715 L .74798 .05452 L p F P
0 g
s
.1 .383 .843 r
.74798 .05452 m .74565 .05043 L .75033 .05305 L p F P
0 g
s
.798 .623 .665 r
.20995 .90651 m .21661 .90825 L .21367 .91438 L p F P
0 g
s
.797 .63 .675 r
.21661 .90825 m .20995 .90651 L .21329 .90027 L p F P
0 g
s
.659 .647 .827 r
.5027 .78233 m .49188 .78613 L .48894 .781 L p F P
0 g
s
.627 .579 .78 r
.56789 .81307 m .5695 .81683 L .55856 .81971 L p F P
0 g
s
.627 .579 .78 r
.55856 .81971 m .55707 .81621 L .56789 .81307 L p F P
0 g
s
.863 .855 .832 r
.73395 .21714 m .73488 .22147 L .74126 .21455 L p F P
0 g
s
.863 .855 .832 r
.73968 .21094 m .73395 .21714 L p .74126 .21455 L F P
0 g
s
.863 .855 .832 r
.74126 .21455 m .74078 .21212 L .73968 .21094 L p F P
0 g
s
.652 .261 .29 r
.3743 .99109 m .36328 .9906 L .361 .98898 L p F P
0 g
s
.652 .261 .291 r
.36328 .9906 m .35998 .99045 L .361 .98898 L closepath p F P
0 g
s
.794 .661 .717 r
.21349 .87771 m .21296 .87663 L .2124 .8774 L closepath p F P
0 g
s
.78 .685 .76 r
.22924 .83959 m .22872 .83873 L .22818 .83928 L closepath p F P
0 g
s
.777 .686 .763 r
.23548 .83195 m .22872 .83873 L .22552 .83357 L p F P
0 g
s
.777 .686 .763 r
.22552 .83357 m .22899 .83009 L .23548 .83195 L p F P
0 g
s
.775 .688 .768 r
.23639 .82288 m .22899 .83009 L .23548 .83195 L p F P
0 g
s
.789 .672 .735 r
.22009 .85479 m .21545 .8534 L p .21618 .86214 L F P
0 g
s
.788 .679 .744 r
.22009 .85479 m .21776 .85073 L .21545 .8534 L closepath p F P
0 g
s
.758 .452 .468 r
.28447 .97471 m .28101 .97416 L .27953 .96913 L p F P
0 g
s
.758 .45 .464 r
.27139 .96786 m .27953 .96913 L .28101 .97416 L p F P
0 g
s
.729 .695 .818 r
.3103 .78716 m .31235 .78588 L .30904 .78532 L closepath p F P
0 g
s
.736 .7 .816 r
.30904 .78532 m .3103 .78716 L p .29647 .78966 L F P
0 g
s
.914 .863 .776 r
.76054 .18392 m .7584 .18171 L .75951 .18011 L closepath p F P
0 g
s
.776 .517 .544 r
.25516 .95989 m .25124 .95918 L .25177 .95386 L p F P
0 g
s
.785 .525 .544 r
.24769 .95303 m .25177 .95386 L .25124 .95918 L p F P
0 g
s
.805 .829 .87 r
.69311 .25966 m .68811 .26358 L .68552 .26068 L p F P
0 g
s
.76 .696 .791 r
.26122 .80891 m .26117 .80884 L .26112 .80888 L closepath p F P
0 g
s
.795 .663 .717 r
.2124 .8774 m .21296 .87663 L .20983 .87029 L p F P
0 g
s
.607 .518 .728 r
.5979 .86066 m .59019 .86226 L .59769 .85999 L closepath p F P
0 g
s
.61 .528 .737 r
.59509 .8522 m .59769 .85999 L .59019 .86226 L p F P
0 g
s
.918 .615 .134 r
.77074 .09232 m .77254 .09651 L .77194 .09225 L p F P
0 g
s
.918 .615 .134 r
.77073 .09226 m .77074 .09232 L p .77194 .09225 L F P
0 g
s
.918 .615 .134 r
.77194 .09225 m .77014 .08804 L .77073 .09226 L p F P
0 g
s
.694 .308 .312 r
.32801 .98423 m .33037 .9868 L .32923 .98828 L p F P
0 g
s
.694 .308 .312 r
.31857 .98332 m .32801 .98423 L p .32923 .98828 L F P
0 g
s
.761 .699 .792 r
.25798 .80415 m .25444 .80706 L .26112 .80888 L p F P
0 g
s
.761 .699 .792 r
.26112 .80888 m .26117 .80884 L .25798 .80415 L p F P
0 g
s
.756 .699 .797 r
.27152 .80065 m .26117 .80884 L .25798 .80415 L p F P
0 g
s
.669 .656 .828 r
.473 .77624 m .4752 .77994 L p .46146 .77914 L F P
0 g
s
.669 .656 .828 r
.46146 .77914 m .46677 .77708 L .473 .77624 L p F P
0 g
s
.671 .663 .834 r
.46146 .77914 m .46677 .77708 L .46067 .77784 L closepath p F P
0 g
s
.742 .696 .807 r
.28262 .79245 m .28321 .79203 L .29074 .79361 L p F P
0 g
s
.742 .7 .812 r
.29331 .78513 m .28321 .79203 L .29074 .79361 L p F P
0 g
s
.742 .7 .812 r
.29074 .79361 m .29647 .78966 L .29331 .78513 L p F P
0 g
s
.582 .3 .454 r
.52862 .97368 m .52246 .97463 L .52297 .9713 L closepath p F P
0 g
s
.593 .313 .461 r
.52297 .9713 m .52246 .97463 L .51039 .97633 L p F P
0 g
s
.581 .303 .459 r
.53436 .97276 m .52862 .97368 L .52297 .9713 L p F P
0 g
s
.781 .688 .761 r
.22818 .83928 m .22872 .83873 L .22552 .83357 L p F P
0 g
s
.738 .397 .403 r
.2979 .97652 m .29986 .9803 L .29941 .98115 L p F P
0 g
s
.738 .397 .403 r
.28938 .97537 m .2979 .97652 L p .29941 .98115 L F P
0 g
s
.773 .493 .511 r
.26845 .9674 m .26352 .96652 L .26289 .96128 L p F P
0 g
s
.773 .492 .509 r
.25516 .95989 m .26289 .96128 L .26352 .96652 L p F P
0 g
s
.797 .658 .708 r
.20608 .87553 m .2124 .8774 L .20803 .88391 L p F P
0 g
s
.795 .663 .717 r
.20983 .87029 m .20608 .87553 L .2124 .8774 L p F P
0 g
s
.782 .682 .754 r
.22186 .83737 m .22818 .83928 L .22162 .8464 L p F P
0 g
s
.781 .688 .761 r
.22552 .83357 m .22186 .83737 L .22818 .83928 L p F P
0 g
s
.798 .634 .678 r
.20671 .89849 m .21329 .90027 L .20995 .90651 L p F P
0 g
s
.797 .64 .687 r
.21329 .90027 m .20671 .89849 L .21043 .89216 L p F P
0 g
s
.79 .67 .731 r
.20981 .86027 m .21618 .86214 L .21086 .86891 L p F P
0 g
s
.789 .672 .735 r
.21545 .8534 m .20981 .86027 L .21618 .86214 L p F P
0 g
s
.617 .555 .763 r
.58916 .83579 m .58924 .83597 L .57856 .83926 L p F P
0 g
s
.617 .555 .763 r
.57856 .83926 m .57818 .83829 L .58916 .83579 L p F P
0 g
s
.587 .411 .611 r
.58 .9319 m .57986 .93074 L .59093 .92799 L p F P
0 g
s
.593 .43 .63 r
.59001 .9218 m .59093 .92799 L .57986 .93074 L p F P
0 g
s
.98 .787 .573 r
.58419 .21511 m .58643 .21907 L .58767 .21405 L p F P
0 g
s
.98 .787 .573 r
.58532 .21054 m .58419 .21511 L p .58767 .21405 L F P
0 g
s
.98 .787 .573 r
.58767 .21405 m .5859 .21094 L .58532 .21054 L p F P
0 g
s
.995 .76 .412 r
.58635 .23757 m .58816 .24165 L .58854 .23693 L p F P
0 g
s
.995 .76 .412 r
.58854 .23693 m .58672 .23286 L .58635 .23757 L p F P
0 g
s
.725 .7 .826 r
.31782 .77621 m .32097 .78062 L .31235 .78588 L p F P
0 g
s
.725 .7 .826 r
.30715 .78267 m .31782 .77621 L p .31235 .78588 L F P
0 g
s
.725 .7 .826 r
.31235 .78588 m .30904 .78532 L .30715 .78267 L p F P
0 g
s
.787 .545 .571 r
.24769 .95303 m .24036 .95152 L .24103 .94596 L p F P
0 g
s
.787 .546 .572 r
.23371 .94445 m .24103 .94596 L .24036 .95152 L p F P
0 g
s
.715 .698 .833 r
.34915 .77822 m .34854 .77735 L .34736 .778 L closepath p F P
0 g
s
.594 .453 .659 r
.59881 .90731 m .59983 .9125 L .58892 .91545 L p F P
0 g
s
.589 .439 .646 r
.59001 .9218 m .58892 .91545 L .59983 .9125 L p F P
0 g
s
.918 .783 .696 r
.58736 .17345 m .58806 .172 L .59076 .17585 L p F P
0 g
s
.918 .783 .696 r
.59076 .17585 m .59014 .17712 L .58736 .17345 L p F P
0 g
s
.726 .776 .892 r
.64941 .28001 m .63902 .28548 L .63632 .28209 L p F P
0 g
s
.689 .764 .909 r
.62529 .28669 m .63632 .28209 L .63902 .28548 L p F P
0 g
s
.617 .556 .763 r
.58627 .82832 m .58916 .83579 L .57818 .83829 L p F P
0 g
s
.617 .556 .763 r
.57545 .83077 m .58627 .82832 L p .57818 .83829 L F P
0 g
s
.617 .556 .763 r
.57818 .83829 m .57529 .83082 L .57545 .83077 L p F P
0 g
s
.945 .869 .732 r
.76633 .16306 m .76587 .16387 L .76706 .16818 L p F P
0 g
s
.932 .866 .752 r
.7622 .1698 m .76342 .17409 L .76706 .16818 L p F P
0 g
s
.932 .866 .752 r
.76706 .16818 m .76587 .16387 L .7622 .1698 L p F P
0 g
s
.808 .832 .869 r
.69311 .25966 m .699 .25494 L .69643 .25208 L p F P
0 g
s
.808 .832 .869 r
.69643 .25208 m .69241 .25529 L .69311 .25966 L p F P
0 g
s
.805 .829 .87 r
.68552 .26068 m .69241 .25529 L .69311 .25966 L p F P
0 g
s
.862 .853 .832 r
.72895 .22241 m .73395 .21714 L .73488 .22147 L p F P
0 g
s
.862 .853 .832 r
.73488 .22147 m .73144 .22509 L .72895 .22241 L p F P
0 g
s
.629 .587 .787 r
.56661 .81017 m .56789 .81307 L .55707 .81621 L p F P
0 g
s
.629 .587 .787 r
.55707 .81621 m .55567 .81307 L .56661 .81017 L p F P
0 g
s
.587 .264 .389 r
.49698 .98234 m .48532 .98363 L .48467 .98337 L p F P
0 g
s
.587 .259 .381 r
.48532 .98363 m .48457 .9837 L .48467 .98337 L closepath p F P
0 g
s
.572 .26 .402 r
.50927 .98085 m .51039 .97633 L .52246 .97463 L p F P
0 g
s
.552 .095 .121 r
.40335 .99158 m .41138 .99152 L p .41434 .99473 L F P
0 g
s
.552 .095 .121 r
.40207 .99319 m .40335 .99158 L p .41434 .99473 L F P
0 g
s
.601 .181 .217 r
.40207 .99319 m .39837 .99154 L .40335 .99158 L closepath p F P
0 g
s
.789 .565 .596 r
.23371 .94445 m .23279 .94425 L .23238 .9382 L p F P
0 g
s
.797 .57 .594 r
.22788 .93715 m .23238 .9382 L .23279 .94425 L p F P
0 g
s
.979 .849 .642 r
.77158 .1383 m .77344 .13328 L .77492 .13753 L p F P
0 g
s
.979 .849 .642 r
.77492 .13753 m .77392 .14021 L .77158 .1383 L p F P
0 g
s
.594 .474 .686 r
.59577 .89385 m .59543 .89242 L .60616 .88925 L p F P
0 g
s
.598 .487 .698 r
.60432 .88221 m .60616 .88925 L .59543 .89242 L p F P
0 g
s
.57 .116 .134 r
.39837 .99154 m .40207 .99319 L .4004 .9948 L p F P
0 g
s
.57 .116 .134 r
.38922 .99146 m .39837 .99154 L p .4004 .9948 L F P
0 g
s
.697 .696 .845 r
.37605 .7753 m .38673 .77029 L .3898 .77462 L p F P
0 g
s
.696 .702 .852 r
.38673 .77029 m .37605 .7753 L .37297 .77099 L p F P
0 g
s
0 .218 .742 r
.75623 .06021 m .75844 .06433 L .75486 .06126 L p F P
0 g
s
0 .218 .742 r
.75486 .06126 m .75264 .05715 L .75623 .06021 L p F P
0 g
s
.588 .168 .213 r
.41582 .99326 m .41138 .99152 L .4172 .99146 L closepath p F P
0 g
s
.552 .095 .121 r
.41138 .99152 m .41582 .99326 L .41434 .99473 L p F P
0 g
s
.645 .615 .805 r
.5223 .7952 m .53318 .79175 L .53608 .7976 L p F P
0 g
s
.645 .618 .807 r
.53221 .78984 m .53318 .79175 L .5223 .7952 L p F P
0 g
s
.645 .618 .807 r
.5223 .7952 m .52097 .79256 L .53221 .78984 L p F P
0 g
s
.715 .699 .834 r
.33476 .77883 m .33838 .77684 L .34736 .778 L p F P
0 g
s
.716 .704 .837 r
.34542 .77307 m .33838 .77684 L .34736 .778 L p F P
0 g
s
.716 .704 .837 r
.34736 .778 m .34854 .77735 L .34542 .77307 L p F P
0 g
s
.692 .693 .846 r
.3898 .77462 m .40049 .76979 L .40353 .77415 L p F P
0 g
s
.691 .7 .854 r
.40049 .76979 m .3898 .77462 L .38673 .77029 L p F P
0 g
s
.767 .696 .784 r
.24917 .81611 m .24721 .81316 L .24514 .81497 L closepath p F P
0 g
s
.637 .601 .796 r
.53898 .80363 m .54988 .80044 L .55278 .8066 L p F P
0 g
s
.637 .602 .798 r
.54832 .79712 m .54988 .80044 L .53898 .80363 L p F P
0 g
s
.637 .602 .798 r
.53898 .80363 m .53729 .80007 L .54832 .79712 L p F P
0 g
s
.701 .704 .849 r
.37297 .77099 m .3623 .77621 L .3592 .77191 L p F P
0 g
s
.68 .758 .91 r
.63632 .28209 m .62529 .28669 L .62256 .28301 L p F P
0 g
s
.753 .698 .799 r
.27223 .80083 m .2719 .80035 L .27152 .80065 L closepath p F P
0 g
s
.801 .457 0 r
.76944 .08648 m .77014 .08804 L .76896 .08402 L p F P
0 g
s
.801 .457 0 r
.7677 .08193 m .76944 .08648 L p .76896 .08402 L F P
0 g
s
.801 .457 0 r
.76896 .08402 m .76706 .07983 L .7677 .08193 L p F P
0 g
s
0 .183 .712 r
.59725 .2662 m .59862 .27038 L .59509 .26703 L p F P
0 g
s
0 .183 .712 r
.59509 .26703 m .59392 .26278 L .59725 .2662 L p F P
0 g
s
.57 .116 .134 r
.38835 .99256 m .38922 .99146 L p .4004 .9948 L F P
0 g
s
.617 .2 .229 r
.38835 .99256 m .38606 .99139 L .38922 .99146 L closepath p F P
0 g
s
.538 .083 .119 r
.4172 .99146 m .42526 .99127 L p .428 .99442 L F P
0 g
s
.538 .083 .119 r
.41582 .99326 m .4172 .99146 L p .428 .99442 L F P
0 g
s
.284 .489 .882 r
.60313 .27238 m .59862 .27038 L .59971 .27465 L p F P
0 g
s
.284 .489 .882 r
.59971 .27465 m .60592 .27689 L .60313 .27238 L p F P
0 g
s
.586 .411 .61 r
.58055 .93673 m .58 .9319 L .59095 .92821 L p F P
0 g
s
.587 .411 .611 r
.59093 .92799 m .59095 .92821 L .58 .9319 L p F P
0 g
s
.956 .861 .705 r
.76763 .15389 m .76899 .15816 L .77176 .15257 L p F P
0 g
s
.956 .861 .705 r
.77176 .15257 m .77042 .14829 L .76763 .15389 L p F P
0 g
s
.594 .474 .686 r
.59707 .89928 m .59577 .89385 L .6068 .89192 L p F P
0 g
s
.594 .474 .686 r
.60616 .88925 m .6068 .89192 L .59577 .89385 L p F P
0 g
s
.687 .69 .847 r
.40353 .77415 m .41424 .76949 L .41727 .77389 L p F P
0 g
s
.686 .697 .855 r
.41424 .76949 m .40353 .77415 L .40049 .76979 L p F P
0 g
s
.856 .853 .839 r
.728 .22858 m .73144 .22509 L .72895 .22241 L p F P
0 g
s
.591 .143 .155 r
.38606 .99139 m .38835 .99256 L .38617 .99464 L p F P
0 g
s
.591 .143 .155 r
.3748 .99111 m .38606 .99139 L p .38617 .99464 L F P
0 g
s
.902 .862 .792 r
.75025 .19268 m .75138 .19698 L .75614 .19065 L p F P
0 g
s
.902 .862 .792 r
.75614 .19065 m .75505 .18633 L .75025 .19268 L p F P
0 g
s
.67 .668 .84 r
.46677 .77708 m .46067 .77784 L .45849 .77439 L p F P
0 g
s
.931 .779 .67 r
.58843 .18123 m .59014 .17712 L .58736 .17345 L p F P
0 g
s
.818 .835 .862 r
.70322 .25139 m .699 .25494 L .69643 .25208 L p F P
0 g
s
.558 .193 .303 r
.48279 .98772 m .48457 .9837 L .48532 .98363 L p F P
0 g
s
.706 .705 .847 r
.3592 .77191 m .34854 .77735 L .34542 .77307 L p F P
0 g
s
.756 .699 .797 r
.25798 .80415 m .26469 .79886 L .27152 .80065 L p F P
0 g
s
.755 .701 .801 r
.26871 .79577 m .26469 .79886 L .27152 .80065 L p F P
0 g
s
.755 .701 .801 r
.27152 .80065 m .2719 .80035 L .26871 .79577 L p F P
0 g
s
.798 .643 .69 r
.20395 .89034 m .21043 .89216 L .20671 .89849 L p F P
0 g
s
.797 .649 .698 r
.21043 .89216 m .20395 .89034 L .20803 .88391 L p F P
0 g
s
.785 .678 .747 r
.22162 .8464 m .21776 .85073 L .21457 .84523 L p F P
0 g
s
.785 .678 .747 r
.21457 .84523 m .2152 .84452 L .22162 .8464 L p F P
0 g
s
.782 .682 .754 r
.22162 .8464 m .2152 .84452 L .22186 .83737 L p F P
0 g
s
.736 .7 .816 r
.29647 .78966 m .30446 .7844 L .30904 .78532 L p F P
0 g
s
.735 .702 .819 r
.30446 .7844 m .29647 .78966 L .29331 .78513 L p F P
0 g
s
.75 .702 .807 r
.28262 .79245 m .2719 .80035 L .26871 .79577 L p F P
0 g
s
0 0 .568 r
.7611 .06776 m .7632 .07191 L .76054 .06847 L p F P
0 g
s
0 0 .568 r
.76054 .06847 m .75844 .06433 L .7611 .06776 L p F P
0 g
s
.577 .16 .214 r
.42958 .99277 m .42526 .99127 L .43078 .99112 L closepath p F P
0 g
s
.538 .083 .119 r
.42526 .99127 m .42958 .99277 L .428 .99442 L p F P
0 g
s
0 0 .331 r
.76535 .07624 m .76706 .07983 L .7652 .07607 L p F P
0 g
s
0 0 .331 r
.76498 .07546 m .76535 .07624 L p .7652 .07607 L F P
0 g
s
0 0 .331 r
.7652 .07607 m .7632 .07191 L .76498 .07546 L p F P
0 g
s
.56 .203 .319 r
.49548 .98606 m .48532 .98363 L .49698 .98234 L closepath p F P
0 g
s
.558 .193 .303 r
.48532 .98363 m .49548 .98606 L p .48279 .98772 L F P
0 g
s
.58 .354 .538 r
.55863 .9585 m .55866 .95312 L .57003 .95071 L p F P
0 g
s
.589 .381 .567 r
.5698 .94511 m .57003 .95071 L .55866 .95312 L p F P
0 g
s
.734 .702 .821 r
.30904 .78532 m .30715 .78267 L .30446 .7844 L closepath p F P
0 g
s
.856 .853 .839 r
.72895 .22241 m .72716 .22422 L .728 .22858 L p F P
0 g
s
.85 .85 .842 r
.71971 .23154 m .72716 .22422 L .728 .22858 L p F P
0 g
s
.85 .85 .842 r
.72061 .23575 m .71971 .23154 L p .728 .22858 L F P
0 g
s
.85 .85 .842 r
.728 .22858 m .72068 .23582 L .72061 .23575 L p F P
0 g
s
.578 .328 .502 r
.54675 .96585 m .54708 .96072 L .55529 .95915 L p F P
0 g
s
.588 .337 .504 r
.54708 .96072 m .54675 .96585 L .53503 .9679 L p F P
0 g
s
.944 .786 .656 r
.58428 .19182 m .58682 .1957 L .58885 .19042 L p F P
0 g
s
.944 .786 .656 r
.58885 .19042 m .5863 .18654 L .58428 .19182 L p F P
0 g
s
.664 .652 .828 r
.4752 .77994 m .486 .77593 L .48894 .781 L p F P
0 g
s
.665 .656 .831 r
.48505 .77435 m .486 .77593 L .4752 .77994 L p F P
0 g
s
.665 .656 .831 r
.4752 .77994 m .473 .77624 L .48505 .77435 L p F P
0 g
s
.822 .838 .861 r
.70322 .25139 m .70986 .24569 L .70731 .24287 L p F P
0 g
s
.822 .838 .861 r
.70731 .24287 m .70244 .24704 L .70322 .25139 L p F P
0 g
s
.818 .835 .862 r
.69643 .25208 m .70244 .24704 L .70322 .25139 L p F P
0 g
s
.999 .803 .497 r
.77306 .1147 m .7747 .11893 L .77553 .1141 L p F P
0 g
s
.999 .803 .497 r
.77553 .1141 m .7739 .10986 L .77306 .1147 L p F P
0 g
s
.682 .686 .847 r
.41727 .77389 m .428 .76939 L .43101 .77384 L p F P
0 g
s
.681 .692 .854 r
.428 .76939 m .41727 .77389 L .41424 .76949 L p F P
0 g
s
.785 .525 .544 r
.25124 .95918 m .24761 .95845 L .24769 .95303 L p F P
0 g
s
.786 .526 .543 r
.24036 .95152 m .24769 .95303 L .24761 .95845 L p F P
0 g
s
.652 .63 .815 r
.50563 .78769 m .51648 .78403 L .51939 .78954 L p F P
0 g
s
.653 .633 .818 r
.51519 .78165 m .51648 .78403 L .50563 .78769 L p F P
0 g
s
.653 .633 .818 r
.50563 .78769 m .5037 .78412 L .51519 .78165 L p F P
0 g
s
.529 .078 .126 r
.43078 .99112 m .44024 .99075 L p .44142 .99391 L F P
0 g
s
.529 .078 .126 r
.42958 .99277 m .43078 .99112 L p .44142 .99391 L F P
0 g
s
.591 .143 .155 r
.37465 .99129 m .3748 .99111 L p .38617 .99464 L F P
0 g
s
.635 .223 .245 r
.37465 .99129 m .3743 .99109 L .3748 .99111 L closepath p F P
0 g
s
.61 .166 .171 r
.3743 .99109 m .37465 .99129 L .37163 .99423 L p F P
0 g
s
.61 .166 .171 r
.36328 .9906 m .3743 .99109 L p .37163 .99423 L F P
0 g
s
.772 .808 .881 r
.66749 .2735 m .66364 .27608 L .66099 .27298 L p F P
0 g
s
.756 .804 .891 r
.65001 .27968 m .66099 .27298 L .66364 .27608 L p F P
0 g
s
.629 .587 .788 r
.56374 .80373 m .56661 .81017 L .55567 .81307 L p F P
0 g
s
.629 .587 .788 r
.55567 .81307 m .55291 .80689 L .56374 .80373 L p F P
0 g
s
0 0 .372 r
.59248 .25861 m .59392 .26278 L .59205 .25884 L p F P
0 g
s
0 0 .372 r
.59205 .25884 m .59069 .25464 L .59248 .25861 L p F P
0 g
s
.715 .698 .833 r
.33476 .77883 m .33838 .77684 L .33288 .77617 L closepath p F P
0 g
s
.722 .702 .831 r
.33288 .77617 m .33476 .77883 L p .32097 .78062 L F P
0 g
s
.83 .84 .854 r
.71232 .24349 m .70986 .24569 L .70731 .24287 L p F P
0 g
s
.843 .85 .849 r
.72068 .23582 m .72063 .23586 L .72061 .23575 L closepath p F P
0 g
s
.831 .843 .856 r
.71146 .23915 m .71232 .24349 L .72063 .23586 L p F P
0 g
s
.831 .843 .856 r
.71816 .23303 m .71146 .23915 L p .72063 .23586 L F P
0 g
s
.831 .843 .856 r
.72063 .23586 m .72061 .23575 L .71816 .23303 L p F P
0 g
s
.83 .84 .854 r
.70731 .24287 m .71146 .23915 L .71232 .24349 L p F P
0 g
s
.619 .564 .771 r
.57529 .83082 m .57528 .83081 L .57545 .83077 L closepath p F P
0 g
s
.619 .566 .773 r
.57545 .83077 m .57528 .83081 L .57239 .82369 L p F P
0 g
s
.789 .68 .744 r
.21545 .8534 m .21776 .85073 L .21457 .84523 L p F P
0 g
s
.79 .67 .731 r
.20668 .86425 m .20981 .86027 L p .21086 .86891 L F P
0 g
s
.79 .67 .731 r
.21086 .86891 m .20886 .86833 L .20668 .86425 L p F P
0 g
s
.793 .663 .72 r
.20983 .87029 m .21086 .86891 L .20886 .86833 L closepath p F P
0 g
s
.617 .557 .765 r
.58627 .82832 m .57545 .83077 L .58595 .8275 L closepath p F P
0 g
s
.619 .566 .773 r
.58337 .82116 m .58595 .8275 L .57545 .83077 L p F P
0 g
s
.619 .566 .773 r
.57239 .82369 m .58337 .82116 L p .57545 .83077 L F P
0 g
s
.694 .308 .312 r
.32923 .98828 m .32296 .98764 L .31857 .98332 L p F P
0 g
s
.679 .275 .272 r
.31584 .98306 m .31857 .98332 L .32296 .98764 L p F P
0 g
s
.842 .844 .846 r
.72061 .23575 m .71816 .23303 L .71971 .23154 L closepath p F P
0 g
s
.678 .681 .846 r
.43101 .77384 m .44175 .76949 L .44475 .774 L p F P
0 g
s
.677 .688 .853 r
.44175 .76949 m .43101 .77384 L .428 .76939 L p F P
0 g
s
.646 .624 .814 r
.53027 .78611 m .53221 .78984 L .52097 .79256 L p F P
0 g
s
.646 .624 .814 r
.52097 .79256 m .51939 .78954 L .53027 .78611 L p F P
0 g
s
.591 .143 .155 r
.38617 .99464 m .38231 .99453 L .37465 .99129 L p F P
0 g
s
.591 .143 .156 r
.38231 .99453 m .37163 .99423 L .37465 .99129 L closepath p F P
0 g
s
.58 .374 .566 r
.57003 .95071 m .5698 .94511 L .58102 .94253 L p F P
0 g
s
.588 .397 .59 r
.58055 .93673 m .58102 .94253 L .5698 .94511 L p F P
0 g
s
.995 .778 .497 r
.58469 .22884 m .58672 .23286 L .58746 .22801 L p F P
0 g
s
.995 .778 .497 r
.58746 .22801 m .58542 .224 L .58469 .22884 L p F P
0 g
s
.591 .463 .675 r
.59855 .90598 m .59707 .89928 L .60782 .89613 L p F P
0 g
s
.594 .474 .686 r
.6068 .89192 m .60782 .89613 L .59707 .89928 L p F P
0 g
s
.639 .609 .804 r
.54699 .79441 m .54832 .79712 L .53729 .80007 L p F P
0 g
s
.639 .609 .804 r
.53729 .80007 m .53608 .7976 L .54699 .79441 L p F P
0 g
s
.377 .573 .916 r
.73961 .04189 m .73334 .04077 L .73585 .04481 L p F P
0 g
s
.377 .573 .916 r
.73585 .04481 m .74216 .04595 L .73961 .04189 L p F P
0 g
s
.45 .617 .921 r
.72794 .04041 m .73334 .04077 L .73585 .04481 L p F P
0 g
s
.572 .296 .459 r
.53436 .97276 m .53503 .9679 L .54675 .96585 L p F P
0 g
s
.797 .664 .717 r
.20608 .87553 m .20983 .87029 L .20886 .86833 L p F P
0 g
s
.978 .854 .649 r
.77289 .14283 m .77392 .14021 L .77158 .1383 L p F P
0 g
s
.798 .599 .633 r
.22263 .9297 m .21577 .92804 L .2179 .92211 L p F P
0 g
s
.799 .601 .634 r
.2111 .92042 m .2179 .92211 L .21577 .92804 L p F P
0 g
s
.798 .611 .649 r
.2179 .92211 m .2111 .92042 L .21367 .91438 L p F P
0 g
s
.758 .45 .464 r
.28101 .97416 m .27292 .97288 L .27139 .96786 L p F P
0 g
s
.757 .45 .465 r
.26845 .9674 m .27139 .96786 L .27292 .97288 L p F P
0 g
s
.568 .157 .223 r
.44335 .99172 m .44024 .99075 L .44413 .99057 L closepath p F P
0 g
s
.529 .078 .126 r
.44024 .99075 m .44335 .99172 L .44142 .99391 L p F P
0 g
s
.797 .585 .614 r
.22788 .93715 m .22097 .93551 L .22263 .9297 L p F P
0 g
s
.798 .587 .616 r
.21577 .92804 m .22263 .9297 L .22097 .93551 L p F P
0 g
s
.789 .677 .741 r
.2092 .85149 m .21545 .8534 L .20981 .86027 L p F P
0 g
s
.789 .68 .744 r
.21457 .84523 m .2092 .85149 L .21545 .8534 L p F P
0 g
s
.798 .653 .702 r
.20166 .88206 m .20803 .88391 L .20395 .89034 L p F P
0 g
s
.797 .658 .708 r
.20803 .88391 m .20166 .88206 L .20608 .87553 L p F P
0 g
s
.668 .663 .836 r
.473 .77624 m .47224 .77501 L .46677 .77708 L closepath p F P
0 g
s
.67 .668 .84 r
.46928 .77033 m .47224 .77501 L .46677 .77708 L p F P
0 g
s
.67 .668 .84 r
.45849 .77439 m .46928 .77033 L p .46677 .77708 L F P
0 g
s
.96 .795 .634 r
.58313 .20615 m .58545 .21009 L .58724 .20489 L p F P
0 g
s
.96 .795 .634 r
.58724 .20489 m .5849 .20095 L .58313 .20615 L p F P
0 g
s
.679 .275 .272 r
.31332 .98656 m .31584 .98306 L p .32296 .98764 L F P
0 g
s
.708 .328 .327 r
.31332 .98656 m .30951 .98231 L .31584 .98306 L closepath p F P
0 g
s
.8 .613 .65 r
.20797 .91291 m .21367 .91438 L .2111 .92042 L p F P
0 g
s
.798 .623 .665 r
.20753 .9115 m .20995 .90651 L p .21367 .91438 L F P
0 g
s
.798 .623 .665 r
.21367 .91438 m .20797 .91291 L .20753 .9115 L p F P
0 g
s
.774 .811 .883 r
.66749 .2735 m .67459 .26868 L .67196 .26565 L p F P
0 g
s
.774 .811 .883 r
.67196 .26565 m .66676 .26915 L .66749 .2735 L p F P
0 g
s
.772 .808 .881 r
.66099 .27298 m .66676 .26915 L .66749 .2735 L p F P
0 g
s
.454 .6 .907 r
.60755 .28111 m .60646 .27776 L .60871 .28122 L closepath p F P
0 g
s
.722 .702 .831 r
.32097 .78062 m .32956 .77564 L .33288 .77617 L p F P
0 g
s
.72 .705 .835 r
.32956 .77564 m .32097 .78062 L .31782 .77621 L p F P
0 g
s
.733 .383 .387 r
.28447 .97471 m .28938 .97537 L .29201 .98012 L p F P
0 g
s
.738 .397 .403 r
.29941 .98115 m .29201 .98012 L .28938 .97537 L p F P
0 g
s
.61 .166 .171 r
.37163 .99423 m .37068 .99419 L .36328 .9906 L p F P
0 g
s
.573 .094 .079 r
.35998 .99045 m .36328 .9906 L .37068 .99419 L p F P
0 g
s
.523 .082 .142 r
.44413 .99057 m .45657 .98988 L p .4546 .99319 L F P
0 g
s
.523 .082 .142 r
.44335 .99172 m .44413 .99057 L p .4546 .99319 L F P
0 g
s
.797 .57 .594 r
.23279 .94425 m .22671 .94284 L .22788 .93715 L p F P
0 g
s
.798 .572 .595 r
.22097 .93551 m .22788 .93715 L .22671 .94284 L p F P
0 g
s
.673 .676 .844 r
.44475 .774 m .45551 .7698 L .45849 .77439 L p F P
0 g
s
.673 .682 .851 r
.45551 .7698 m .44475 .774 L .44175 .76949 L p F P
0 g
s
.771 .69 .773 r
.23639 .82288 m .23664 .82265 L .23617 .82252 L closepath p F P
0 g
s
.768 .695 .782 r
.23867 .81309 m .24514 .81497 L .23664 .82265 L p F P
0 g
s
.768 .695 .782 r
.23318 .81803 m .23867 .81309 L p .23664 .82265 L F P
0 g
s
.768 .695 .782 r
.23664 .82265 m .23617 .82252 L .23318 .81803 L p F P
0 g
s
.923 .862 .763 r
.75826 .17583 m .75951 .18011 L .76342 .17409 L p F P
0 g
s
.923 .862 .763 r
.76342 .17409 m .7622 .1698 L .75826 .17583 L p F P
0 g
s
.776 .691 .769 r
.22899 .83009 m .23639 .82288 L .23617 .82252 L p F P
0 g
s
.892 .858 .801 r
.74786 .19569 m .75025 .19268 L .75138 .19698 L p F P
0 g
s
.892 .858 .801 r
.75138 .19698 m .75031 .19831 L .74786 .19569 L p F P
0 g
s
.712 .702 .839 r
.3423 .76886 m .34542 .77307 L .33838 .77684 L p F P
0 g
s
.712 .702 .839 r
.33163 .77446 m .3423 .76886 L p .33838 .77684 L F P
0 g
s
.712 .702 .839 r
.33838 .77684 m .33288 .77617 L .33163 .77446 L p F P
0 g
s
.659 .647 .827 r
.48894 .781 m .49977 .77719 L .5027 .78233 L p F P
0 g
s
.659 .647 .828 r
.49977 .77719 m .48894 .781 L .486 .77593 L p F P
0 g
s
.75 .702 .807 r
.28217 .79181 m .28262 .79245 L p .26871 .79577 L F P
0 g
s
.742 .698 .809 r
.28262 .79245 m .28321 .79203 L .28217 .79181 L closepath p F P
0 g
s
.859 .557 .029 r
.58908 .25051 m .59069 .25464 L .58987 .25033 L p F P
0 g
s
.859 .557 .029 r
.58987 .25033 m .58829 .2462 L .58908 .25051 L p F P
0 g
s
.584 .424 .63 r
.59093 .92799 m .59001 .9218 L .60093 .91886 L p F P
0 g
s
.589 .439 .646 r
.59983 .9125 m .60093 .91886 L .59001 .9218 L p F P
0 g
s
.768 .698 .785 r
.244 .80841 m .23867 .81309 L .24514 .81497 L p F P
0 g
s
.768 .698 .785 r
.24514 .81497 m .24721 .81316 L .244 .80841 L p F P
0 g
s
.573 .094 .079 r
.35764 .99282 m .35998 .99045 L p .37068 .99419 L F P
0 g
s
.631 .197 .197 r
.35764 .99282 m .35268 .99 L .35998 .99045 L closepath p F P
0 g
s
.8 .625 .664 r
.20753 .9115 m .20995 .90651 L .20563 .90536 L closepath p F P
0 g
s
.798 .634 .678 r
.20459 .90244 m .20671 .89849 L p .20995 .90651 L F P
0 g
s
.798 .634 .678 r
.20995 .90651 m .20563 .90536 L .20459 .90244 L p F P
0 g
s
.873 .855 .822 r
.74078 .21212 m .73968 .21094 L .74033 .21021 L closepath p F P
0 g
s
.763 .698 .789 r
.25444 .80706 m .24721 .81316 L .244 .80841 L p F P
0 g
s
.739 .702 .816 r
.29083 .78164 m .29331 .78513 L .28321 .79203 L p F P
0 g
s
.739 .702 .816 r
.28925 .78126 m .29083 .78164 L p .28321 .79203 L F P
0 g
s
.739 .702 .816 r
.27943 .78796 m .28925 .78126 L p .28321 .79203 L F P
0 g
s
.739 .702 .816 r
.28321 .79203 m .28217 .79181 L .27943 .78796 L p F P
0 g
s
.735 .702 .819 r
.29331 .78513 m .29682 .78284 L .30446 .7844 L p F P
0 g
s
.735 .706 .823 r
.30399 .7783 m .29682 .78284 L .30446 .7844 L p F P
0 g
s
.735 .706 .823 r
.30446 .7844 m .30715 .78267 L .30399 .7783 L p F P
0 g
s
.796 .672 .727 r
.20886 .86833 m .20668 .86425 L .20457 .86702 L closepath p F P
0 g
s
.797 .664 .717 r
.20886 .86833 m .20457 .86702 L p .20608 .87553 L F P
0 g
s
.988 .837 .605 r
.77187 .12905 m .77344 .13328 L .77503 .12815 L p F P
0 g
s
.988 .837 .605 r
.77503 .12815 m .77347 .12391 L .77187 .12905 L p F P
0 g
s
.773 .492 .509 r
.26352 .96652 m .2558 .96513 L .25516 .95989 L p F P
0 g
s
.773 .492 .509 r
.25124 .95918 m .25516 .95989 L .2558 .96513 L p F P
0 g
s
.776 .691 .769 r
.23617 .82252 m .23029 .82074 L p .22899 .83009 L F P
0 g
s
.775 .697 .777 r
.23617 .82252 m .23318 .81803 L .23029 .82074 L closepath p F P
0 g
s
.996 .768 .417 r
.77218 .10565 m .7739 .10986 L .77431 .10521 L p F P
0 g
s
.996 .768 .417 r
.77431 .10521 m .7726 .10098 L .77218 .10565 L p F P
0 g
s
.563 .191 .295 r
.48279 .98772 m .47523 .98842 L .4709 .98729 L p F P
0 g
s
.562 .183 .281 r
.47523 .98842 m .47011 .98887 L .4709 .98729 L closepath p F P
0 g
s
.585 .221 .317 r
.4709 .98729 m .47011 .98887 L .45725 .98984 L p F P
0 g
s
.887 .859 .808 r
.74601 .20354 m .75031 .19831 L .74786 .19569 L p F P
0 g
s
.778 .687 .764 r
.22899 .83009 m .22552 .83357 L .22231 .82843 L p F P
0 g
s
.778 .687 .764 r
.22231 .82843 m .22254 .8282 L .22899 .83009 L p F P
0 g
s
.776 .691 .769 r
.23029 .82074 m .22254 .8282 L .22899 .83009 L p F P
0 g
s
.757 .45 .465 r
.27292 .97288 m .2669 .97194 L .26845 .9674 L p F P
0 g
s
.768 .462 .468 r
.26352 .96652 m .26845 .9674 L .2669 .97194 L p F P
0 g
s
.639 .612 .806 r
.54699 .79441 m .53608 .7976 L .53318 .79175 L p F P
0 g
s
.789 .548 .572 r
.23279 .94425 m .23371 .94445 L .23302 .95002 L p F P
0 g
s
.787 .546 .572 r
.24036 .95152 m .23302 .95002 L .23371 .94445 L p F P
0 g
s
.75 .702 .807 r
.26871 .79577 m .27616 .7903 L .28217 .79181 L p F P
0 g
s
.748 .705 .811 r
.28217 .79181 m .27943 .78796 L .27616 .7903 L closepath p F P
0 g
s
.763 .698 .789 r
.244 .80841 m .24779 .80521 L .25444 .80706 L p F P
0 g
s
.762 .7 .794 r
.25477 .7995 m .24779 .80521 L .25444 .80706 L p F P
0 g
s
.762 .7 .794 r
.25444 .80706 m .25798 .80415 L .25477 .7995 L p F P
0 g
s
.782 .689 .761 r
.22186 .83737 m .22552 .83357 L .22231 .82843 L p F P
0 g
s
.619 .566 .773 r
.58239 .81875 m .58337 .82116 L .57239 .82369 L p F P
0 g
s
.619 .566 .773 r
.57239 .82369 m .57174 .82209 L .58239 .81875 L p F P
0 g
s
.934 .778 .663 r
.58359 .1827 m .5863 .18654 L .58843 .18123 L p F P
0 g
s
.934 .778 .663 r
.58843 .18123 m .58571 .17739 L .58359 .1827 L p F P
0 g
s
.931 .779 .67 r
.58736 .17345 m .58571 .17739 L .58843 .18123 L p F P
0 g
s
.653 .639 .824 r
.51356 .77872 m .51519 .78165 L .5037 .78412 L p F P
0 g
s
.653 .639 .824 r
.5037 .78412 m .5027 .78233 L .51356 .77872 L p F P
0 g
s
.586 .411 .61 r
.59095 .92821 m .59162 .93398 L .58055 .93673 L p F P
0 g
s
.579 .39 .59 r
.58102 .94253 m .58055 .93673 L .59162 .93398 L p F P
0 g
s
.586 .7 .922 r
.60871 .28122 m .61981 .27927 L .62256 .28301 L p F P
0 g
s
.591 .669 .893 r
.60646 .27776 m .60871 .28122 L .61981 .27927 L p F P
0 g
s
.647 .627 .817 r
.53027 .78611 m .51939 .78954 L .51648 .78403 L p F P
0 g
s
.728 .708 .832 r
.31782 .77621 m .30715 .78267 L .30399 .7783 L p F P
0 g
s
.57 .116 .134 r
.4004 .9948 m .39445 .99474 L .38835 .99256 L p F P
0 g
s
.57 .114 .131 r
.39445 .99474 m .38617 .99464 L .38835 .99256 L closepath p F P
0 g
s
.223 .472 .885 r
.74565 .05043 m .74472 .05006 L .74216 .04595 L p F P
0 g
s
.801 .635 .677 r
.20459 .90244 m .20671 .89849 L .20279 .89741 L closepath p F P
0 g
s
.798 .643 .69 r
.20158 .89438 m .20395 .89034 L p .20671 .89849 L F P
0 g
s
.798 .643 .69 r
.20671 .89849 m .20279 .89741 L .20158 .89438 L p F P
0 g
s
.756 .7 .798 r
.26469 .79886 m .25798 .80415 L .25477 .7995 L p F P
0 g
s
.669 .677 .848 r
.46928 .77033 m .45849 .77439 L .45551 .7698 L p F P
0 g
s
.946 .861 .724 r
.76453 .1596 m .76763 .15389 L .76899 .15816 L p F P
0 g
s
.946 .861 .724 r
.76533 .16209 m .76453 .1596 L p .76899 .15816 L F P
0 g
s
.946 .861 .724 r
.76899 .15816 m .76633 .16306 L .76533 .16209 L p F P
0 g
s
.631 .595 .795 r
.56372 .80368 m .56374 .80373 L .55291 .80689 L p F P
0 g
s
.631 .595 .795 r
.55291 .80689 m .55278 .8066 L .56372 .80368 L p F P
0 g
s
.789 .548 .572 r
.23302 .95002 m .23273 .94995 L .23279 .94425 L p F P
0 g
s
.798 .555 .571 r
.22671 .94284 m .23279 .94425 L .23273 .94995 L p F P
0 g
s
.978 .854 .649 r
.77158 .1383 m .77149 .13855 L .77289 .14283 L p F P
0 g
s
.964 .856 .685 r
.76899 .14403 m .77042 .14829 L .77289 .14283 L p F P
0 g
s
.964 .856 .685 r
.77289 .14283 m .77149 .13855 L .76899 .14403 L p F P
0 g
s
.782 .689 .761 r
.22231 .82843 m .21558 .83544 L .22186 .83737 L p F P
0 g
s
.783 .687 .758 r
.21558 .83544 m .22186 .83737 L .2152 .84452 L p F P
0 g
s
.792 .671 .73 r
.20668 .86425 m .20981 .86027 L .20354 .85839 L closepath p F P
0 g
s
.789 .677 .741 r
.20351 .85834 m .2092 .85149 L p .20981 .86027 L F P
0 g
s
.789 .677 .741 r
.20981 .86027 m .20354 .85839 L .20351 .85834 L p F P
0 g
s
.798 .662 .713 r
.19982 .87364 m .20608 .87553 L .20166 .88206 L p F P
0 g
s
.797 .664 .717 r
.20457 .86702 m .19982 .87364 L .20608 .87553 L p F P
0 g
s
.631 .598 .798 r
.56372 .80368 m .55278 .8066 L .54988 .80044 L p F P
0 g
s
.621 .575 .781 r
.58048 .81424 m .58239 .81875 L .57174 .82209 L p F P
0 g
s
.621 .575 .781 r
.57174 .82209 m .5695 .81683 L .58048 .81424 L p F P
0 g
s
.606 .141 .124 r
.35268 .99 m .35764 .99282 L .3567 .99351 L p F P
0 g
s
.606 .141 .124 r
.34482 .98953 m .35268 .99 L p .3567 .99351 L F P
0 g
s
.674 .279 .288 r
.34234 .98933 m .33247 .98854 L .33037 .9868 L p F P
0 g
s
.674 .279 .289 r
.33247 .98854 m .32923 .98828 L .33037 .9868 L closepath p F P
0 g
s
.534 .161 .279 r
.49698 .98234 m .50909 .98087 L p .50758 .98489 L F P
0 g
s
.534 .161 .279 r
.49548 .98606 m .49698 .98234 L p .50758 .98489 L F P
0 g
s
.733 .383 .387 r
.28286 .97796 m .28447 .97471 L p .29201 .98012 L F P
0 g
s
.749 .413 .415 r
.28286 .97796 m .28101 .97416 L .28447 .97471 L closepath p F P
0 g
s
.985 .781 .548 r
.58319 .22004 m .58542 .224 L .58643 .21907 L p F P
0 g
s
.985 .781 .548 r
.58643 .21907 m .58419 .21511 L .58319 .22004 L p F P
0 g
s
.663 .661 .838 r
.48305 .77111 m .48505 .77435 L .473 .77624 L p F P
0 g
s
.663 .661 .838 r
.473 .77624 m .47224 .77501 L .48305 .77111 L p F P
0 g
s
.705 .313 .304 r
.30951 .98231 m .31332 .98656 L .3132 .9867 L p F P
0 g
s
.705 .313 .304 r
.30051 .98128 m .30951 .98231 L p .3132 .9867 L F P
0 g
s
.722 .374 .39 r
.30951 .98231 m .30051 .98128 L .29986 .9803 L p F P
0 g
s
.586 .448 .66 r
.59881 .90731 m .59855 .90598 L .6093 .90284 L p F P
0 g
s
.591 .463 .675 r
.60782 .89613 m .6093 .90284 L .59855 .90598 L p F P
0 g
s
.788 .818 .875 r
.68099 .26403 m .67459 .26868 L .67196 .26565 L p F P
0 g
s
.56 .246 .394 r
.52134 .97913 m .52246 .97463 L .52862 .97368 L p F P
0 g
s
.572 .26 .402 r
.52246 .97463 m .52134 .97913 L .50927 .98085 L p F P
0 g
s
.72 .705 .835 r
.33288 .77617 m .33163 .77446 L .32956 .77564 L closepath p F P
0 g
s
.73 .789 .899 r
.65001 .27968 m .64941 .28001 L .64936 .27889 L closepath p F P
0 g
s
.726 .776 .892 r
.64734 .27642 m .64936 .27889 L .64941 .28001 L p F P
0 g
s
.726 .776 .892 r
.63632 .28209 m .64734 .27642 L p .64941 .28001 L F P
0 g
s
.562 .159 .237 r
.45713 .99003 m .45657 .98988 L .45725 .98984 L closepath p F P
0 g
s
.523 .082 .142 r
.45657 .98988 m .45713 .99003 L .4546 .99319 L p F P
0 g
s
.549 .145 .229 r
.45713 .99003 m .45725 .98984 L .47011 .98887 L p F P
0 g
s
.887 .859 .808 r
.74786 .19569 m .74496 .19922 L .74601 .20354 L p F P
0 g
s
.88 .856 .814 r
.73924 .20592 m .74033 .21021 L .74601 .20354 L p F P
0 g
s
.88 .856 .814 r
.74601 .20354 m .74496 .19922 L .73924 .20592 L p F P
0 g
s
.757 .796 .885 r
.65834 .26981 m .66099 .27298 L .65001 .27968 L p F P
0 g
s
.757 .796 .885 r
.64856 .27569 m .65834 .26981 L p .65001 .27968 L F P
0 g
s
.757 .796 .885 r
.65001 .27968 m .64936 .27889 L .64856 .27569 L p F P
0 g
s
.599 .514 .729 r
.5979 .86066 m .59769 .85999 L .60823 .85655 L p F P
0 g
s
.603 .524 .738 r
.60602 .84994 m .60823 .85655 L .59769 .85999 L p F P
0 g
s
.603 .524 .738 r
.5974 .85145 m .60602 .84994 L p .59769 .85999 L F P
0 g
s
.603 .524 .738 r
.59769 .85999 m .59509 .8522 L .5974 .85145 L p F P
0 g
s
.599 .513 .729 r
.60009 .86758 m .5979 .86066 L .60895 .85883 L p F P
0 g
s
.599 .514 .729 r
.60823 .85655 m .60895 .85883 L .5979 .86066 L p F P
0 g
s
.972 .702 .288 r
.58647 .24212 m .58829 .2462 L .58816 .24165 L p F P
0 g
s
.972 .702 .288 r
.58816 .24165 m .58635 .23757 L .58647 .24212 L p F P
0 g
s
.586 .448 .66 r
.59983 .9125 m .59881 .90731 L .60986 .90568 L p F P
0 g
s
.586 .448 .66 r
.6093 .90284 m .60986 .90568 L .59881 .90731 L p F P
0 g
s
.597 .504 .72 r
.60084 .87011 m .60009 .86758 L .61064 .86417 L p F P
0 g
s
.599 .513 .729 r
.60895 .85883 m .61064 .86417 L .60009 .86758 L p F P
0 g
s
.773 .492 .509 r
.2558 .96513 m .2502 .96412 L .25124 .95918 L p F P
0 g
s
.783 .502 .511 r
.24761 .95845 m .25124 .95918 L .2502 .96412 L p F P
0 g
s
.756 .7 .798 r
.25477 .7995 m .25787 .79706 L .26469 .79886 L p F P
0 g
s
.755 .703 .803 r
.26551 .79122 m .25787 .79706 L .26469 .79886 L p F P
0 g
s
.755 .703 .803 r
.26469 .79886 m .26871 .79577 L .26551 .79122 L p F P
0 g
s
.786 .526 .543 r
.24761 .95845 m .24028 .95694 L .24036 .95152 L p F P
0 g
s
.786 .526 .543 r
.23302 .95002 m .24036 .95152 L .24028 .95694 L p F P
0 g
s
.978 .714 .31 r
.77079 .09678 m .7726 .10098 L .77254 .09651 L p F P
0 g
s
.978 .714 .31 r
.77073 .09233 m .77079 .09678 L p .77254 .09651 L F P
0 g
s
.978 .714 .31 r
.77254 .09651 m .77074 .09232 L .77073 .09233 L p F P
0 g
s
.578 .331 .506 r
.5585 .96096 m .55529 .95915 L .55863 .9585 L closepath p F P
0 g
s
.578 .328 .502 r
.55529 .95915 m .5585 .96096 L p .54675 .96585 L F P
0 g
s
.948 .785 .646 r
.58237 .19706 m .5849 .20095 L .58682 .1957 L p F P
0 g
s
.948 .785 .646 r
.58682 .1957 m .58428 .19182 L .58237 .19706 L p F P
0 g
s
.597 .503 .719 r
.60229 .87498 m .60084 .87011 L .6119 .86837 L p F P
0 g
s
.597 .504 .72 r
.61064 .86417 m .6119 .86837 L .60084 .87011 L p F P
0 g
s
.654 .645 .829 r
.51356 .77872 m .5027 .78233 L .49977 .77719 L p F P
0 g
s
.976 .804 .606 r
.5859 .21094 m .58532 .21054 L .58545 .21009 L closepath p F P
0 g
s
.549 .145 .229 r
.47011 .98887 m .46787 .99196 L .45713 .99003 L p F P
0 g
s
.518 .08 .146 r
.4546 .99319 m .45713 .99003 L .46787 .99196 L p F P
0 g
s
.605 .533 .747 r
.59509 .8522 m .59498 .85189 L .5974 .85145 L closepath p F P
0 g
s
.605 .534 .748 r
.5974 .85145 m .59498 .85189 L .59227 .8442 L p F P
0 g
s
.696 .702 .852 r
.37297 .77099 m .38366 .76607 L .38673 .77029 L p F P
0 g
s
.693 .712 .863 r
.38366 .76607 m .37297 .77099 L .36988 .76679 L p F P
0 g
s
.701 .704 .849 r
.3592 .77191 m .36988 .76679 L .37297 .77099 L p F P
0 g
s
.801 .645 .689 r
.20158 .89438 m .20395 .89034 L .19943 .88905 L closepath p F P
0 g
s
.798 .653 .702 r
.19852 .88699 m .20166 .88206 L p .20395 .89034 L F P
0 g
s
.798 .653 .702 r
.20395 .89034 m .19943 .88905 L .19852 .88699 L p F P
0 g
s
.552 .095 .121 r
.41434 .99473 m .40725 .99477 L .40207 .99319 L p F P
0 g
s
.551 .091 .115 r
.40725 .99477 m .4004 .9948 L .40207 .99319 L closepath p F P
0 g
s
.786 .681 .748 r
.21457 .84523 m .2152 .84452 L .21394 .84415 L closepath p F P
0 g
s
.783 .687 .758 r
.21136 .83997 m .21558 .83544 L p .2152 .84452 L F P
0 g
s
.783 .687 .758 r
.2152 .84452 m .21394 .84415 L .21136 .83997 L p F P
0 g
s
.691 .7 .854 r
.39777 .76603 m .40049 .76979 L p .38673 .77029 L F P
0 g
s
.691 .7 .854 r
.38673 .77029 m .39644 .766 L .39777 .76603 L p F P
0 g
s
.687 .709 .865 r
.39644 .766 m .38673 .77029 L .38366 .76607 L p F P
0 g
s
.796 .672 .727 r
.20457 .86702 m .20668 .86425 L .20354 .85839 L p F P
0 g
s
.723 .375 .388 r
.30051 .98128 m .29941 .98115 L .29986 .9803 L closepath p F P
0 g
s
.699 .712 .859 r
.36988 .76679 m .3592 .77191 L .35609 .76771 L p F P
0 g
s
.706 .705 .847 r
.34542 .77307 m .35609 .76771 L .3592 .77191 L p F P
0 g
s
.606 .141 .124 r
.34397 .99043 m .34482 .98953 L p .3567 .99351 L F P
0 g
s
.654 .232 .23 r
.34397 .99043 m .34234 .98933 L .34482 .98953 L closepath p F P
0 g
s
.79 .682 .745 r
.2092 .85149 m .21457 .84523 L .21394 .84415 L p F P
0 g
s
.223 .472 .885 r
.74216 .04595 m .74323 .04637 L .74565 .05043 L p F P
0 g
s
.093 .383 .843 r
.74792 .04898 m .75033 .05305 L .74565 .05043 L p F P
0 g
s
.093 .383 .843 r
.74565 .05043 m .74323 .04637 L .74792 .04898 L p F P
0 g
s
.664 .67 .846 r
.48305 .77111 m .47224 .77501 L .46928 .77033 L p F P
0 g
s
.594 .493 .71 r
.60381 .88036 m .60229 .87498 L .61287 .87159 L p F P
0 g
s
.597 .503 .719 r
.6119 .86837 m .61287 .87159 L .60229 .87498 L p F P
0 g
s
.686 .697 .855 r
.41172 .76597 m .41424 .76949 L p .40049 .76979 L F P
0 g
s
.686 .697 .855 r
.40049 .76979 m .40944 .76599 L .41172 .76597 L p F P
0 g
s
.686 .698 .856 r
.40049 .76979 m .40944 .76599 L .39777 .76603 L closepath p F P
0 g
s
.749 .704 .809 r
.27616 .7903 m .26871 .79577 L .26551 .79122 L p F P
0 g
s
.912 .859 .776 r
.75597 .17913 m .75826 .17583 L .75951 .18011 L p F P
0 g
s
.912 .859 .776 r
.75951 .18011 m .7584 .18171 L .75597 .17913 L p F P
0 g
s
.735 .701 .819 r
.29331 .78513 m .29682 .78284 L .29083 .78164 L closepath p F P
0 g
s
.75 .407 .402 r
.28101 .97416 m .28286 .97796 L .28237 .97881 L p F P
0 g
s
.75 .407 .402 r
.27292 .97288 m .28101 .97416 L p .28237 .97881 L F P
0 g
s
.722 .71 .839 r
.32849 .77026 m .32123 .77428 L .32956 .77564 L p F P
0 g
s
.722 .71 .839 r
.32956 .77564 m .33163 .77446 L .32849 .77026 L p F P
0 g
s
.72 .705 .835 r
.31782 .77621 m .32123 .77428 L .32956 .77564 L p F P
0 g
s
.768 .462 .468 r
.2669 .97194 m .26489 .97158 L .26352 .96652 L p F P
0 g
s
.77 .461 .463 r
.2558 .96513 m .26352 .96652 L .26489 .97158 L p F P
0 g
s
.791 .822 .876 r
.68099 .26403 m .68552 .26068 L .68292 .25772 L p F P
0 g
s
.791 .822 .876 r
.68292 .25772 m .68026 .25966 L .68099 .26403 L p F P
0 g
s
.788 .818 .875 r
.67196 .26565 m .68026 .25966 L .68099 .26403 L p F P
0 g
s
.995 .822 .561 r
.77182 .11969 m .77347 .12391 L .7747 .11893 L p F P
0 g
s
.995 .822 .561 r
.7747 .11893 m .77306 .1147 L .77182 .11969 L p F P
0 g
s
.705 .711 .853 r
.35609 .76771 m .34542 .77307 L .3423 .76886 L p F P
0 g
s
.804 .627 .662 r
.20563 .90536 m .20341 .90472 L p .207 .91264 L F P
0 g
s
.804 .627 .662 r
.207 .91264 m .20753 .9115 L .20563 .90536 L p F P
0 g
s
.804 .636 .674 r
.20563 .90536 m .20459 .90244 L .20341 .90472 L closepath p F P
0 g
s
.632 .181 .161 r
.34234 .98933 m .34397 .99043 L .3414 .99251 L p F P
0 g
s
.632 .181 .161 r
.33247 .98854 m .34234 .98933 L p .3414 .99251 L F P
0 g
s
.804 .626 .661 r
.20797 .91291 m .20753 .9115 L .207 .91264 L closepath p F P
0 g
s
.605 .534 .748 r
.59227 .8442 m .59656 .84279 L p .5974 .85145 L F P
0 g
s
.608 .543 .756 r
.59227 .8442 m .59207 .84365 L .59656 .84279 L closepath p F P
0 g
s
.621 .575 .782 r
.57855 .8097 m .58048 .81424 L .5695 .81683 L p F P
0 g
s
.621 .575 .782 r
.5695 .81683 m .56789 .81307 L .57855 .8097 L p F P
0 g
s
.681 .692 .854 r
.42529 .76554 m .428 .76939 L p .41424 .76949 L F P
0 g
s
.681 .692 .854 r
.41424 .76949 m .42372 .7656 L .42529 .76554 L p F P
0 g
s
.682 .695 .856 r
.41424 .76949 m .42372 .7656 L .41172 .76597 L closepath p F P
0 g
s
.8 .613 .65 r
.2111 .92042 m .20983 .92009 L .20797 .91291 L p F P
0 g
s
.806 .617 .646 r
.207 .91264 m .20797 .91291 L .20983 .92009 L p F P
0 g
s
.523 .082 .142 r
.4546 .99319 m .45163 .99337 L .44335 .99172 L p F P
0 g
s
.519 .07 .124 r
.45163 .99337 m .44142 .99391 L .44335 .99172 L closepath p F P
0 g
s
.538 .083 .119 r
.428 .99442 m .4209 .99459 L .41582 .99326 L p F P
0 g
s
.536 .076 .108 r
.4209 .99459 m .41434 .99473 L .41582 .99326 L closepath p F P
0 g
s
.608 .543 .756 r
.59656 .84279 m .59207 .84365 L .58924 .83597 L p F P
0 g
s
.805 .637 .674 r
.20341 .90472 m .20459 .90244 L .20279 .89741 L p F P
0 g
s
.79 .682 .745 r
.21394 .84415 m .20902 .84257 L p .2092 .85149 L F P
0 g
s
.789 .688 .753 r
.21394 .84415 m .21136 .83997 L .20902 .84257 L closepath p F P
0 g
s
.594 .493 .709 r
.60432 .88221 m .60381 .88036 L .61487 .87871 L p F P
0 g
s
.594 .493 .71 r
.61287 .87159 m .61487 .87871 L .60381 .88036 L p F P
0 g
s
.798 .668 .72 r
.19841 .86508 m .20457 .86702 L .19982 .87364 L p F P
0 g
s
.796 .672 .727 r
.20348 .85837 m .19841 .86508 L .20457 .86702 L p F P
0 g
s
.796 .672 .727 r
.20354 .85839 m .20348 .85837 L p .20457 .86702 L F P
0 g
s
.908 .861 .782 r
.75505 .18633 m .7584 .18171 L .75597 .17913 L p F P
0 g
s
.529 .078 .126 r
.44142 .99391 m .43561 .99415 L .42958 .99277 L p F P
0 g
s
.525 .069 .111 r
.43561 .99415 m .428 .99442 L .42958 .99277 L closepath p F P
0 g
s
.927 .619 .151 r
.77014 .08804 m .76944 .08648 L .77073 .09226 L closepath p F P
0 g
s
.799 .601 .634 r
.21034 .92256 m .2111 .92042 L p .21577 .92804 L F P
0 g
s
.801 .603 .633 r
.21034 .92256 m .2111 .92042 L .20983 .92009 L closepath p F P
0 g
s
.871 .851 .82 r
.7372 .2082 m .73924 .20592 L .74033 .21021 L p F P
0 g
s
.871 .851 .82 r
.74033 .21021 m .73968 .21094 L .7372 .2082 L p F P
0 g
s
.798 .587 .616 r
.22097 .93551 m .21408 .93386 L .21577 .92804 L p F P
0 g
s
.8 .589 .616 r
.21122 .92691 m .21577 .92804 L .21408 .93386 L p F P
0 g
s
.799 .601 .634 r
.21577 .92804 m .21122 .92691 L .21034 .92256 L p F P
0 g
s
.711 .712 .849 r
.3423 .76886 m .33163 .77446 L .32849 .77026 L p F P
0 g
s
.59 .482 .698 r
.60616 .88925 m .60432 .88221 L .61491 .87885 L p F P
0 g
s
.594 .493 .709 r
.61487 .87871 m .61491 .87885 L .60432 .88221 L p F P
0 g
s
.749 .791 .887 r
.64936 .27889 m .64734 .27642 L .64856 .27569 L closepath p F P
0 g
s
.866 .851 .826 r
.73395 .21714 m .73968 .21094 L .7372 .2082 L p F P
0 g
s
.577 .404 .61 r
.59095 .92821 m .59093 .92799 L .60185 .92506 L p F P
0 g
s
.584 .424 .63 r
.60093 .91886 m .60185 .92506 L .59093 .92799 L p F P
0 g
s
.969 .792 .609 r
.58255 .2081 m .58313 .20615 L .58545 .21009 L p F P
0 g
s
.969 .792 .609 r
.58545 .21009 m .58532 .21054 L .58255 .2081 L p F P
0 g
s
.805 .637 .674 r
.20279 .89741 m .20028 .89667 L p .20341 .90472 L F P
0 g
s
.804 .646 .686 r
.20279 .89741 m .20158 .89438 L .20028 .89667 L closepath p F P
0 g
s
.566 .32 .501 r
.55863 .9585 m .57002 .9561 L .56974 .96126 L p F P
0 g
s
.566 .32 .501 r
.5585 .96096 m .55863 .9585 L p .56974 .96126 L F P
0 g
s
.58 .354 .538 r
.57003 .95071 m .57002 .9561 L .55863 .9585 L p F P
0 g
s
.731 .705 .826 r
.30081 .77399 m .30399 .7783 L .29682 .78284 L p F P
0 g
s
.731 .705 .826 r
.29013 .78067 m .30081 .77399 L p .29682 .78284 L F P
0 g
s
.731 .705 .826 r
.29682 .78284 m .29083 .78164 L .29013 .78067 L p F P
0 g
s
.803 .825 .868 r
.69241 .25529 m .68552 .26068 L .68292 .25772 L p F P
0 g
s
.719 .78 .9 r
.64734 .27642 m .63632 .28209 L .63361 .27864 L p F P
0 g
s
.68 .758 .91 r
.62256 .28301 m .63361 .27864 L .63632 .28209 L p F P
0 g
s
.577 .404 .61 r
.59162 .93398 m .59095 .92821 L .60199 .92621 L p F P
0 g
s
.577 .404 .61 r
.60185 .92506 m .60199 .92621 L .59095 .92821 L p F P
0 g
s
.804 .627 .662 r
.20341 .90472 m .20059 .91083 L .207 .91264 L p F P
0 g
s
.808 .62 .648 r
.20059 .91083 m .207 .91264 L .20457 .91865 L p F P
0 g
s
.806 .617 .646 r
.20983 .92009 m .20457 .91865 L .207 .91264 L p F P
0 g
s
.677 .688 .853 r
.428 .76939 m .43875 .76511 L .44175 .76949 L p F P
0 g
s
.678 .691 .856 r
.43846 .76472 m .43875 .76511 L .428 .76939 L p F P
0 g
s
.678 .691 .856 r
.428 .76939 m .42529 .76554 L .43846 .76472 L p F P
0 g
s
.783 .502 .511 r
.2502 .96412 m .24817 .96371 L .24761 .95845 L p F P
0 g
s
.785 .502 .508 r
.24028 .95694 m .24761 .95845 L .24817 .96371 L p F P
0 g
s
.801 .654 .701 r
.19852 .88699 m .20166 .88206 L .1955 .88024 L closepath p F P
0 g
s
.798 .662 .713 r
.19541 .88006 m .19982 .87364 L p .20166 .88206 L F P
0 g
s
.798 .662 .713 r
.20166 .88206 m .1955 .88024 L .19541 .88006 L p F P
0 g
s
.942 .863 .732 r
.76633 .16306 m .76587 .16387 L .76533 .16209 L closepath p F P
0 g
s
.798 .572 .595 r
.22671 .94284 m .21978 .9412 L .22097 .93551 L p F P
0 g
s
.798 .573 .596 r
.21408 .93386 m .22097 .93551 L .21978 .9412 L p F P
0 g
s
.995 .753 .427 r
.58433 .23356 m .58635 .23757 L .58672 .23286 L p F P
0 g
s
.995 .753 .427 r
.58672 .23286 m .58469 .22884 L .58433 .23356 L p F P
0 g
s
.793 .679 .739 r
.2092 .85149 m .20351 .85834 L .20031 .8528 L p F P
0 g
s
.793 .679 .739 r
.20031 .8528 m .203 .84954 L .2092 .85149 L p F P
0 g
s
.79 .682 .745 r
.20902 .84257 m .203 .84954 L .2092 .85149 L p F P
0 g
s
.671 .752 .911 r
.63361 .27864 m .62256 .28301 L .61981 .27927 L p F P
0 g
s
.56 .246 .394 r
.52862 .97368 m .5339 .97482 L p .52134 .97913 L F P
0 g
s
.562 .257 .409 r
.5339 .97482 m .52862 .97368 L .53436 .97276 L closepath p F P
0 g
s
0 .215 .739 r
.75393 .05611 m .75623 .06021 L .75264 .05715 L p F P
0 g
s
0 .215 .739 r
.75264 .05715 m .75033 .05305 L .75393 .05611 L p F P
0 g
s
.639 .612 .806 r
.53318 .79175 m .54409 .78854 L .54699 .79441 L p F P
0 g
s
.64 .615 .809 r
.54325 .78688 m .54409 .78854 L .53318 .79175 L p F P
0 g
s
.64 .615 .809 r
.53318 .79175 m .53221 .78984 L .54325 .78688 L p F P
0 g
s
.602 .524 .739 r
.60602 .84994 m .5974 .85145 L .60562 .84874 L closepath p F P
0 g
s
.605 .534 .748 r
.60311 .8416 m .60562 .84874 L .5974 .85145 L p F P
0 g
s
.605 .534 .748 r
.59656 .84279 m .60311 .8416 L p .5974 .85145 L F P
0 g
s
.705 .313 .304 r
.3132 .9867 m .30471 .98565 L .30051 .98128 L p F P
0 g
s
.703 .315 .31 r
.29941 .98115 m .30051 .98128 L .30471 .98565 L p F P
0 g
s
.973 .779 .582 r
.58419 .21511 m .58532 .21054 L .58255 .2081 L p F P
0 g
s
.57 .346 .537 r
.57002 .9561 m .57003 .95071 L .58127 .94814 L p F P
0 g
s
.58 .374 .566 r
.58102 .94253 m .58127 .94814 L .57003 .95071 L p F P
0 g
s
.749 .704 .809 r
.26551 .79122 m .2692 .78854 L .27616 .7903 L p F P
0 g
s
.749 .707 .813 r
.27623 .78354 m .2692 .78854 L .27616 .7903 L p F P
0 g
s
.749 .707 .813 r
.27616 .7903 m .27943 .78796 L .27623 .78354 L p F P
0 g
s
.581 .434 .646 r
.60093 .91886 m .59983 .9125 L .6106 .90938 L p F P
0 g
s
.586 .448 .66 r
.60986 .90568 m .6106 .90938 L .59983 .9125 L p F P
0 g
s
.469 .011 .08 r
.47011 .98887 m .47523 .98842 L p .48027 .99114 L F P
0 g
s
.469 .011 .08 r
.46787 .99196 m .47011 .98887 L p .48027 .99114 L F P
0 g
s
.659 .647 .828 r
.49689 .77221 m .49977 .77719 L p .486 .77593 L F P
0 g
s
.659 .647 .828 r
.486 .77593 m .49621 .77234 L .49689 .77221 L p F P
0 g
s
.66 .657 .835 r
.486 .77593 m .49621 .77234 L .48505 .77435 L closepath p F P
0 g
s
.806 .606 .631 r
.20983 .92009 m .20457 .91865 L p .20903 .92633 L F P
0 g
s
.806 .606 .631 r
.20903 .92633 m .21034 .92256 L .20983 .92009 L p F P
0 g
s
.805 .647 .686 r
.20028 .89667 m .20158 .89438 L .19943 .88905 L p F P
0 g
s
.631 .598 .798 r
.54988 .80044 m .56083 .7975 L .56372 .80368 L p F P
0 g
s
.631 .599 .799 r
.55915 .79394 m .56083 .7975 L .54988 .80044 L p F P
0 g
s
.631 .599 .799 r
.54988 .80044 m .54832 .79712 L .55915 .79394 L p F P
0 g
s
.925 .86 .757 r
.76089 .16552 m .7622 .1698 L .76587 .16387 L p F P
0 g
s
.925 .86 .757 r
.76393 .16061 m .76089 .16552 L p .76587 .16387 L F P
0 g
s
.925 .86 .757 r
.76587 .16387 m .76533 .16209 L .76393 .16061 L p F P
0 g
s
.771 .697 .782 r
.23867 .81309 m .23318 .81803 L .22996 .81323 L p F P
0 g
s
.776 .698 .778 r
.23029 .82074 m .23318 .81803 L .22996 .81323 L p F P
0 g
s
.817 .466 0 r
.76706 .07983 m .76535 .07624 L .7677 .08193 L closepath p F P
0 g
s
.703 .315 .31 r
.30471 .98565 m .2966 .9847 L .29941 .98115 L p F P
0 g
s
.719 .335 .321 r
.29201 .98012 m .29941 .98115 L .2966 .9847 L p F P
0 g
s
.978 .844 .641 r
.76991 .13432 m .77187 .12905 L .77344 .13328 L p F P
0 g
s
.978 .844 .641 r
.77132 .13807 m .76991 .13432 L p .77344 .13328 L F P
0 g
s
.978 .844 .641 r
.77344 .13328 m .77158 .1383 L .77132 .13807 L p F P
0 g
s
.775 .696 .775 r
.22402 .81879 m .23029 .82074 L .22254 .8282 L p F P
0 g
s
.776 .698 .778 r
.22996 .81323 m .22402 .81879 L .23029 .82074 L p F P
0 g
s
.769 .7 .786 r
.24078 .80369 m .23223 .81118 L .23867 .81309 L p F P
0 g
s
.769 .7 .786 r
.23867 .81309 m .244 .80841 L .24078 .80369 L p F P
0 g
s
.771 .697 .782 r
.22996 .81323 m .23223 .81118 L .23867 .81309 L p F P
0 g
s
.561 .285 .455 r
.54608 .97071 m .54675 .96585 L .55832 .96364 L p F P
0 g
s
.578 .328 .502 r
.5585 .96096 m .55832 .96364 L .54675 .96585 L p F P
0 g
s
.572 .296 .459 r
.54675 .96585 m .54608 .97071 L .53436 .97276 L p F P
0 g
s
.623 .583 .789 r
.57759 .80754 m .57855 .8097 L .56789 .81307 L p F P
0 g
s
.623 .583 .789 r
.56789 .81307 m .56661 .81017 L .57759 .80754 L p F P
0 g
s
.808 .631 .662 r
.19708 .90288 m .20341 .90472 L .20059 .91083 L p F P
0 g
s
.805 .637 .674 r
.20028 .89667 m .19708 .90288 L .20341 .90472 L p F P
0 g
s
.608 .543 .756 r
.58924 .83597 m .5907 .83549 L p .59656 .84279 L F P
0 g
s
.61 .552 .764 r
.58924 .83597 m .58916 .83579 L .5907 .83549 L closepath p F P
0 g
s
.61 .553 .765 r
.5907 .83549 m .58916 .83579 L .58627 .82832 L p F P
0 g
s
.72 .703 .834 r
.31782 .77621 m .32123 .77428 L .31579 .77343 L closepath p F P
0 g
s
.728 .708 .832 r
.31579 .77343 m .31782 .77621 L p .30399 .7783 L F P
0 g
s
.764 .699 .79 r
.24779 .80521 m .244 .80841 L .24078 .80369 L p F P
0 g
s
.866 .851 .826 r
.7372 .2082 m .73292 .21283 L .73395 .21714 L p F P
0 g
s
.861 .849 .831 r
.72644 .21967 m .73292 .21283 L .73395 .21714 L p F P
0 g
s
.861 .849 .831 r
.73395 .21714 m .72895 .22241 L .72644 .21967 L p F P
0 g
s
.798 .555 .571 r
.23273 .94995 m .22605 .9484 L .22671 .94284 L p F P
0 g
s
.798 .556 .571 r
.21978 .9412 m .22671 .94284 L .22605 .9484 L p F P
0 g
s
.673 .682 .851 r
.44175 .76949 m .45252 .76534 L .45551 .7698 L p F P
0 g
s
.671 .691 .86 r
.45252 .76534 m .44175 .76949 L .43875 .76511 L p F P
0 g
s
.647 .627 .817 r
.51648 .78403 m .52736 .78059 L .53027 .78611 L p F P
0 g
s
.647 .632 .82 r
.52647 .77893 m .52736 .78059 L .51648 .78403 L p F P
0 g
s
.647 .632 .82 r
.51648 .78403 m .51519 .78165 L .52647 .77893 L p F P
0 g
s
0 0 .559 r
.75891 .06363 m .7611 .06776 L .75844 .06433 L p F P
0 g
s
0 0 .559 r
.75844 .06433 m .75623 .06021 L .75891 .06363 L p F P
0 g
s
.938 .777 .656 r
.58156 .18799 m .58428 .19182 L .5863 .18654 L p F P
0 g
s
.938 .777 .656 r
.5863 .18654 m .58359 .1827 L .58156 .18799 L p F P
0 g
s
.806 .829 .868 r
.69241 .25529 m .69643 .25208 L .69385 .24917 L p F P
0 g
s
.806 .829 .868 r
.69385 .24917 m .69163 .25093 L .69241 .25529 L p F P
0 g
s
.803 .825 .868 r
.68292 .25772 m .69163 .25093 L .69241 .25529 L p F P
0 g
s
.779 .69 .766 r
.22231 .82843 m .22254 .8282 L .22208 .82806 L closepath p F P
0 g
s
.775 .696 .775 r
.21908 .82354 m .22402 .81879 L p .22254 .8282 L F P
0 g
s
.775 .696 .775 r
.22254 .8282 m .22208 .82806 L .21908 .82354 L p F P
0 g
s
.784 .691 .762 r
.21558 .83544 m .22231 .82843 L .22208 .82806 L p F P
0 g
s
0 0 .317 r
.76236 .07022 m .7611 .06776 L .7632 .07191 L p F P
0 g
s
0 0 .317 r
.7632 .07191 m .76498 .07546 L .76236 .07022 L p F P
0 g
s
.742 .709 .82 r
.28925 .78126 m .27943 .78796 L .27623 .78354 L p F P
0 g
s
.953 .855 .707 r
.76617 .14964 m .76763 .15389 L .77042 .14829 L p F P
0 g
s
.953 .855 .707 r
.77042 .14829 m .76899 .14403 L .76617 .14964 L p F P
0 g
s
.586 .47 .687 r
.6068 .89192 m .60616 .88925 L .61675 .8859 L p F P
0 g
s
.59 .482 .698 r
.61491 .87885 m .61675 .8859 L .60616 .88925 L p F P
0 g
s
.764 .699 .79 r
.24078 .80369 m .24118 .80336 L .24779 .80521 L p F P
0 g
s
.762 .702 .795 r
.25113 .79523 m .24118 .80336 L .24779 .80521 L p F P
0 g
s
.762 .702 .795 r
.25198 .79549 m .25113 .79523 L p .24779 .80521 L F P
0 g
s
.762 .702 .795 r
.24779 .80521 m .25477 .7995 L .25198 .79549 L p F P
0 g
s
.805 .605 .631 r
.21122 .92691 m .21034 .92256 L .20903 .92633 L closepath p F P
0 g
s
0 .133 .68 r
.59564 .26209 m .59725 .2662 L .59392 .26278 L p F P
0 g
s
0 .133 .68 r
.59392 .26278 m .59248 .25861 L .59564 .26209 L p F P
0 g
s
.632 .181 .161 r
.3414 .99251 m .33906 .99231 L .33247 .98854 L p F P
0 g
s
.599 .116 .079 r
.32923 .98828 m .33247 .98854 L .33906 .99231 L p F P
0 g
s
.559 .216 .344 r
.50925 .98091 m .50909 .98087 L .50927 .98085 L closepath p F P
0 g
s
.534 .161 .279 r
.50909 .98087 m .50925 .98091 L .50758 .98489 L p F P
0 g
s
.225 .45 .868 r
.60033 .26781 m .59725 .2662 L .59862 .27038 L p F P
0 g
s
.225 .45 .868 r
.59862 .27038 m .60313 .27238 L .60033 .26781 L p F P
0 g
s
.908 .861 .782 r
.75597 .17913 m .75388 .18203 L .75505 .18633 L p F P
0 g
s
.899 .858 .792 r
.74903 .1884 m .75025 .19268 L .75505 .18633 L p F P
0 g
s
.899 .858 .792 r
.75505 .18633 m .75388 .18203 L .74903 .1884 L p F P
0 g
s
.784 .691 .762 r
.22208 .82806 m .2164 .82622 L p .21558 .83544 L F P
0 g
s
.782 .697 .77 r
.22208 .82806 m .21908 .82354 L .2164 .82622 L closepath p F P
0 g
s
.546 .204 .339 r
.50925 .98091 m .50927 .98085 L .52134 .97913 L p F P
0 g
s
.641 .622 .816 r
.54119 .7829 m .54325 .78688 L .53221 .78984 L p F P
0 g
s
.641 .622 .816 r
.53221 .78984 m .53027 .78611 L .54119 .7829 L p F P
0 g
s
.999 .8 .504 r
.77133 .11048 m .77306 .1147 L .7739 .10986 L p F P
0 g
s
.999 .8 .504 r
.7739 .10986 m .77218 .10565 L .77133 .11048 L p F P
0 g
s
.546 .204 .339 r
.52134 .97913 m .52015 .98228 L .50925 .98091 L p F P
0 g
s
.534 .17 .296 r
.50758 .98489 m .50925 .98091 L .52015 .98228 L p F P
0 g
s
.817 .831 .861 r
.70244 .24704 m .69643 .25208 L .69385 .24917 L p F P
0 g
s
.524 .112 .202 r
.48168 .98946 m .47523 .98842 L .48279 .98772 L closepath p F P
0 g
s
.469 .011 .08 r
.47523 .98842 m .48168 .98946 L .48027 .99114 L p F P
0 g
s
.805 .647 .686 r
.19943 .88905 m .19759 .88849 L p .20028 .89667 L F P
0 g
s
.804 .655 .698 r
.19943 .88905 m .19852 .88699 L .19759 .88849 L closepath p F P
0 g
s
.571 .367 .565 r
.58127 .94814 m .58102 .94253 L .5921 .93979 L p F P
0 g
s
.579 .39 .59 r
.59162 .93398 m .5921 .93979 L .58102 .94253 L p F P
0 g
s
.854 .849 .837 r
.72716 .22422 m .72895 .22241 L .72644 .21967 L p F P
0 g
s
.808 .641 .676 r
.19403 .89479 m .20028 .89667 L .19708 .90288 L p F P
0 g
s
.805 .647 .686 r
.19759 .88849 m .19403 .89479 L .20028 .89667 L p F P
0 g
s
.524 .627 .895 r
.60592 .27689 m .6064 .27688 L .60646 .27776 L closepath p F P
0 g
s
.591 .669 .893 r
.61706 .27547 m .6064 .27688 L .60646 .27776 L p F P
0 g
s
.591 .669 .893 r
.61981 .27927 m .61706 .27547 L p .60646 .27776 L F P
0 g
s
.606 .141 .124 r
.3567 .99351 m .34932 .99301 L .34397 .99043 L p F P
0 g
s
.606 .145 .132 r
.34932 .99301 m .3414 .99251 L .34397 .99043 L closepath p F P
0 g
s
.77 .804 .881 r
.66676 .26915 m .66099 .27298 L .65834 .26981 L p F P
0 g
s
.61 .553 .765 r
.5973 .82616 m .59974 .83246 L .5907 .83549 L p F P
0 g
s
.61 .553 .765 r
.58627 .82832 m .5973 .82616 L p .5907 .83549 L F P
0 g
s
.608 .543 .756 r
.5907 .83549 m .6002 .83369 L p .59656 .84279 L F P
0 g
s
.607 .544 .757 r
.6002 .83369 m .5907 .83549 L .59974 .83246 L closepath p F P
0 g
s
.854 .849 .837 r
.72644 .21967 m .72623 .21988 L .72716 .22422 L p F P
0 g
s
.847 .846 .842 r
.71869 .22724 m .71971 .23154 L .72716 .22422 L p F P
0 g
s
.847 .846 .842 r
.72716 .22422 m .72623 .21988 L .71869 .22724 L p F P
0 g
s
.586 .469 .687 r
.60782 .89613 m .6068 .89192 L .61789 .89059 L p F P
0 g
s
.586 .47 .687 r
.61675 .8859 m .61789 .89059 L .6068 .89192 L p F P
0 g
s
.66 .662 .841 r
.49621 .77234 m .48505 .77435 L .48305 .77111 L p F P
0 g
s
.795 .679 .736 r
.20354 .85839 m .20351 .85834 L .20348 .85837 L closepath p F P
0 g
s
.623 .584 .79 r
.5747 .80104 m .57759 .80754 L .56661 .81017 L p F P
0 g
s
.623 .584 .79 r
.5645 .80349 m .5747 .80104 L p .56661 .81017 L F P
0 g
s
.623 .584 .79 r
.56661 .81017 m .56374 .80373 L .5645 .80349 L p F P
0 g
s
.599 .116 .079 r
.32692 .99034 m .32923 .98828 L p .33906 .99231 L F P
0 g
s
.657 .221 .2 r
.32692 .99034 m .32296 .98764 L .32923 .98828 L closepath p F P
0 g
s
.757 .701 .799 r
.25477 .7995 m .25787 .79706 L .25198 .79549 L closepath p F P
0 g
s
.797 .681 .737 r
.20348 .85837 m .20351 .85834 L .20031 .8528 L p F P
0 g
s
.799 .676 .729 r
.19743 .85639 m .20348 .85837 L .19841 .86508 L p F P
0 g
s
.797 .681 .737 r
.20031 .8528 m .19743 .85639 L .20348 .85837 L p F P
0 g
s
.784 .691 .762 r
.2164 .82622 m .20936 .83349 L .21558 .83544 L p F P
0 g
s
.786 .688 .757 r
.21558 .83544 m .21136 .83997 L .20814 .8348 L p F P
0 g
s
.786 .688 .757 r
.20814 .8348 m .20936 .83349 L .21558 .83544 L p F P
0 g
s
.801 .663 .711 r
.19982 .87364 m .19541 .88006 L .19227 .87367 L p F P
0 g
s
.801 .663 .711 r
.19227 .87367 m .1936 .87172 L .19982 .87364 L p F P
0 g
s
.798 .668 .72 r
.19982 .87364 m .1936 .87172 L .19841 .86508 L p F P
0 g
s
.669 .677 .848 r
.45551 .7698 m .4663 .76579 L .46928 .77033 L p F P
0 g
s
.668 .683 .855 r
.4663 .76579 m .45551 .7698 L .45252 .76534 L p F P
0 g
s
.717 .708 .841 r
.32533 .76614 m .32849 .77026 L .32123 .77428 L p F P
0 g
s
.717 .708 .841 r
.31466 .77192 m .32533 .76614 L p .32123 .77428 L F P
0 g
s
.717 .708 .841 r
.32123 .77428 m .31579 .77343 L .31466 .77192 L p F P
0 g
s
.821 .835 .86 r
.70244 .24704 m .70731 .24287 L .70475 .23999 L p F P
0 g
s
.821 .835 .86 r
.70475 .23999 m .70157 .2427 L .70244 .24704 L p F P
0 g
s
.817 .831 .861 r
.69385 .24917 m .70157 .2427 L .70244 .24704 L p F P
0 g
s
.788 .528 .543 r
.23273 .94995 m .23302 .95002 L .23293 .95543 L p F P
0 g
s
.786 .526 .543 r
.24028 .95694 m .23293 .95543 L .23302 .95002 L p F P
0 g
s
0 0 .306 r
.5908 .25451 m .59248 .25861 L .59069 .25464 L p F P
0 g
s
0 0 .306 r
.59069 .25464 m .58908 .25051 L .5908 .25451 L p F P
0 g
s
.728 .708 .832 r
.30399 .7783 m .31303 .77288 L .31579 .77343 L p F P
0 g
s
.726 .711 .836 r
.31303 .77288 m .30399 .7783 L .30081 .77399 L p F P
0 g
s
.75 .407 .402 r
.28237 .97881 m .2754 .97767 L .27292 .97288 L p F P
0 g
s
.746 .396 .39 r
.2669 .97194 m .27292 .97288 L .2754 .97767 L p F P
0 g
s
.788 .528 .543 r
.23293 .95543 m .23216 .95527 L .23273 .94995 L p F P
0 g
s
.797 .536 .543 r
.22605 .9484 m .23273 .94995 L .23216 .95527 L p F P
0 g
s
.94 .63 .179 r
.76877 .08814 m .76821 .08387 L .76944 .08648 L p F P
0 g
s
.94 .63 .179 r
.77073 .0923 m .76877 .08814 L p .76944 .08648 L F P
0 g
s
.94 .63 .179 r
.76944 .08648 m .77073 .09226 L .77073 .0923 L p F P
0 g
s
.846 .504 0 r
.7677 .08193 m .76821 .08387 L .76944 .08648 L closepath p F P
0 g
s
.633 .607 .806 r
.55794 .79145 m .55915 .79394 L .54832 .79712 L p F P
0 g
s
.633 .607 .806 r
.54832 .79712 m .54699 .79441 L .55794 .79145 L p F P
0 g
s
.99 .768 .505 r
.58248 .22488 m .58469 .22884 L .58542 .224 L p F P
0 g
s
.99 .768 .505 r
.58542 .224 m .58319 .22004 L .58248 .22488 L p F P
0 g
s
.804 .656 .698 r
.19759 .88849 m .19852 .88699 L .1955 .88024 L p F P
0 g
s
.753 .705 .807 r
.26237 .78681 m .26551 .79122 L .25787 .79706 L p F P
0 g
s
.753 .705 .807 r
.26223 .78677 m .26237 .78681 L p .25787 .79706 L F P
0 g
s
.753 .705 .807 r
.25155 .7949 m .26223 .78677 L p .25787 .79706 L F P
0 g
s
.753 .705 .807 r
.25787 .79706 m .25198 .79549 L .25155 .7949 L p F P
0 g
s
.829 .836 .853 r
.71146 .23915 m .70731 .24287 L .70475 .23999 L p F P
0 g
s
.841 .84 .844 r
.71562 .23017 m .71869 .22724 L .71971 .23154 L p F P
0 g
s
.841 .84 .844 r
.71971 .23154 m .71816 .23303 L .71562 .23017 L p F P
0 g
s
.953 .784 .634 r
.58061 .20226 m .58313 .20615 L .5849 .20095 L p F P
0 g
s
.953 .784 .634 r
.5849 .20095 m .58237 .19706 L .58061 .20226 L p F P
0 g
s
.61 .553 .766 r
.59644 .82396 m .5973 .82616 L .58627 .82832 L p F P
0 g
s
.61 .553 .766 r
.58627 .82832 m .58595 .8275 L .59644 .82396 L p F P
0 g
s
.834 .839 .851 r
.71146 .23915 m .71816 .23303 L .71562 .23017 L p F P
0 g
s
.834 .839 .851 r
.71562 .23017 m .71051 .23484 L .71146 .23915 L p F P
0 g
s
.829 .836 .853 r
.70475 .23999 m .71051 .23484 L .71146 .23915 L p F P
0 g
s
.77 .461 .463 r
.26489 .97158 m .25722 .97018 L .2558 .96513 L p F P
0 g
s
.767 .454 .456 r
.2502 .96412 m .2558 .96513 L .25722 .97018 L p F P
0 g
s
.8 .589 .616 r
.21408 .93386 m .21215 .93338 L .21122 .92691 L p F P
0 g
s
.807 .594 .614 r
.20903 .92633 m .21122 .92691 L .21215 .93338 L p F P
0 g
s
.545 .235 .392 r
.53436 .97276 m .54608 .97071 L .54504 .97525 L p F P
0 g
s
.545 .235 .392 r
.5339 .97482 m .53436 .97276 L p .54504 .97525 L F P
0 g
s
.654 .645 .829 r
.49977 .77719 m .51063 .77357 L .51356 .77872 L p F P
0 g
s
.654 .648 .832 r
.5084 .76973 m .51063 .77357 L .49977 .77719 L p F P
0 g
s
.654 .648 .832 r
.49977 .77719 m .49689 .77221 L .5084 .76973 L p F P
0 g
s
.648 .638 .826 r
.52445 .7753 m .52647 .77893 L .51519 .78165 L p F P
0 g
s
.648 .638 .826 r
.51519 .78165 m .51356 .77872 L .52445 .7753 L p F P
0 g
s
.605 .534 .748 r
.60311 .8416 m .59656 .84279 L .6028 .84072 L closepath p F P
0 g
s
.608 .543 .756 r
.6002 .83369 m .6028 .84072 L .59656 .84279 L p F P
0 g
s
.612 .562 .774 r
.5944 .81893 m .59644 .82396 L .58595 .8275 L p F P
0 g
s
.612 .562 .774 r
.58595 .8275 m .58337 .82116 L .5944 .81893 L p F P
0 g
s
.79 .69 .754 r
.20902 .84257 m .21136 .83997 L .20814 .8348 L p F P
0 g
s
.74 .708 .821 r
.29083 .78164 m .29013 .78067 L .28925 .78126 L closepath p F P
0 g
s
.495 .611 .897 r
.6064 .27688 m .60592 .27689 L .60313 .27238 L p F P
0 g
s
.566 .32 .501 r
.56974 .96126 m .56373 .96252 L .5585 .96096 L p F P
0 g
s
.567 .318 .498 r
.56373 .96252 m .55832 .96364 L .5585 .96096 L closepath p F P
0 g
s
.808 .651 .688 r
.19144 .88657 m .19759 .88849 L .19403 .89479 L p F P
0 g
s
.804 .656 .698 r
.19533 .88018 m .19144 .88657 L .19759 .88849 L p F P
0 g
s
.804 .656 .698 r
.1955 .88024 m .19533 .88018 L p .19759 .88849 L F P
0 g
s
.582 .457 .675 r
.6093 .90284 m .60782 .89613 L .61843 .8928 L p F P
0 g
s
.586 .469 .687 r
.61789 .89059 m .61843 .8928 L .60782 .89613 L p F P
0 g
s
.79 .687 .751 r
.20296 .84058 m .20902 .84257 L .203 .84954 L p F P
0 g
s
.79 .69 .754 r
.20814 .8348 m .20296 .84058 L .20902 .84257 L p F P
0 g
s
.719 .335 .321 r
.2966 .9847 m .2958 .98459 L .29201 .98012 L p F P
0 g
s
.716 .322 .3 r
.28347 .97896 m .29201 .98012 L .2958 .98459 L p F P
0 g
s
.733 .383 .387 r
.29201 .98012 m .28347 .97896 L .28286 .97796 L p F P
0 g
s
.478 .04 .127 r
.48279 .98772 m .4953 .98642 L .49284 .98985 L p F P
0 g
s
.478 .04 .127 r
.48168 .98946 m .48279 .98772 L p .49284 .98985 L F P
0 g
s
.558 .193 .303 r
.49548 .98606 m .4953 .98642 L .48279 .98772 L p F P
0 g
s
.495 .611 .897 r
.60313 .27238 m .60576 .27245 L .6064 .27688 L p F P
0 g
s
.565 .685 .921 r
.61429 .27162 m .60576 .27245 L .6064 .27688 L p F P
0 g
s
.565 .685 .921 r
.6064 .27688 m .61706 .27547 L .61429 .27162 L p F P
0 g
s
.664 .677 .852 r
.48009 .76646 m .46928 .77033 L .4663 .76579 L p F P
0 g
s
.664 .67 .846 r
.46928 .77033 m .48009 .76646 L .48305 .77111 L p F P
0 g
s
.684 .702 .861 r
.40944 .76599 m .39777 .76603 L .39743 .76558 L p F P
0 g
s
.689 .704 .859 r
.39777 .76603 m .39743 .76558 L .39644 .766 L closepath p F P
0 g
s
.92 .857 .763 r
.75691 .17157 m .75826 .17583 L .7622 .1698 L p F P
0 g
s
.92 .857 .763 r
.7622 .1698 m .76089 .16552 L .75691 .17157 L p F P
0 g
s
.687 .709 .865 r
.38366 .76607 m .38458 .76568 L .39644 .766 L p F P
0 g
s
.691 .715 .867 r
.39436 .76165 m .38458 .76568 L .39644 .766 L p F P
0 g
s
.691 .715 .867 r
.39644 .766 m .39743 .76558 L .39436 .76165 L p F P
0 g
s
.771 .808 .883 r
.66676 .26915 m .67196 .26565 L .66933 .26257 L p F P
0 g
s
.771 .808 .883 r
.66933 .26257 m .66595 .26481 L .66676 .26915 L p F P
0 g
s
.77 .804 .881 r
.65834 .26981 m .66595 .26481 L .66676 .26915 L p F P
0 g
s
.996 .766 .427 r
.77037 .10145 m .77218 .10565 L .7726 .10098 L p F P
0 g
s
.996 .766 .427 r
.7726 .10098 m .77079 .09678 L .77037 .10145 L p F P
0 g
s
.985 .832 .608 r
.7702 .12483 m .77187 .12905 L .77347 .12391 L p F P
0 g
s
.985 .832 .608 r
.77347 .12391 m .77182 .11969 L .7702 .12483 L p F P
0 g
s
.684 .701 .86 r
.41172 .76597 m .4112 .76526 L .40944 .76599 L closepath p F P
0 g
s
.684 .702 .861 r
.40815 .76131 m .4112 .76526 L .40944 .76599 L p F P
0 g
s
.684 .702 .861 r
.39743 .76558 m .40815 .76131 L p .40944 .76599 L F P
0 g
s
.575 .418 .631 r
.60185 .92506 m .60093 .91886 L .6117 .91574 L p F P
0 g
s
.581 .434 .646 r
.6106 .90938 m .6117 .91574 L .60093 .91886 L p F P
0 g
s
.894 .579 .081 r
.58724 .24645 m .58908 .25051 L .58829 .2462 L p F P
0 g
s
.894 .579 .081 r
.58829 .2462 m .58647 .24212 L .58724 .24645 L p F P
0 g
s
.742 .709 .82 r
.27623 .78354 m .2822 .77952 L .28925 .78126 L p F P
0 g
s
.742 .712 .823 r
.28693 .77639 m .2822 .77952 L .28925 .78126 L p F P
0 g
s
.742 .712 .823 r
.28925 .78126 m .29013 .78067 L .28693 .77639 L p F P
0 g
s
.891 .854 .8 r
.7454 .193 m .74903 .1884 L .75025 .19268 L p F P
0 g
s
.891 .854 .8 r
.75025 .19268 m .74786 .19569 L .7454 .193 L p F P
0 g
s
.639 .177 .14 r
.32296 .98764 m .32692 .99034 L .32565 .99117 L p F P
0 g
s
.639 .177 .14 r
.31352 .98673 m .32296 .98764 L p .32565 .99117 L F P
0 g
s
.679 .275 .272 r
.32296 .98764 m .31352 .98673 L .31332 .98656 L p F P
0 g
s
.68 .7 .861 r
.42372 .7656 m .41172 .76597 L .4112 .76526 L p F P
0 g
s
.932 .856 .744 r
.76533 .16209 m .76393 .16061 L .76453 .1596 L closepath p F P
0 g
s
.749 .704 .809 r
.26551 .79122 m .2692 .78854 L .26237 .78681 L closepath p F P
0 g
s
.217 .473 .886 r
.74323 .04637 m .74216 .04595 L .73961 .04189 L p F P
0 g
s
.692 .709 .861 r
.36988 .76679 m .37385 .76503 L .36831 .76473 L closepath p F P
0 g
s
.699 .712 .859 r
.36831 .76473 m .36988 .76679 L p .35609 .76771 L F P
0 g
s
.693 .712 .863 r
.38333 .76565 m .38366 .76607 L p .36988 .76679 L F P
0 g
s
.693 .712 .863 r
.36988 .76679 m .37385 .76503 L .38333 .76565 L p F P
0 g
s
.687 .709 .865 r
.38366 .76607 m .38458 .76568 L .38333 .76565 L closepath p F P
0 g
s
.861 .512 .004 r
.76535 .07624 m .7677 .08193 L .76821 .08387 L p F P
0 g
s
.633 .609 .808 r
.55794 .79145 m .54699 .79441 L .54409 .78854 L p F P
0 g
s
.734 .713 .831 r
.30081 .77399 m .29013 .78067 L .28693 .77639 L p F P
0 g
s
.699 .712 .859 r
.35609 .76771 m .3635 .76427 L .36831 .76473 L p F P
0 g
s
.694 .716 .866 r
.3635 .76427 m .35609 .76771 L .35297 .76361 L p F P
0 g
s
.705 .711 .853 r
.3423 .76886 m .35297 .76361 L .35609 .76771 L p F P
0 g
s
.785 .502 .508 r
.24817 .96371 m .24085 .9622 L .24028 .95694 L p F P
0 g
s
.785 .501 .507 r
.23293 .95543 m .24028 .95694 L .24085 .9622 L p F P
0 g
s
.641 .625 .818 r
.54119 .7829 m .53027 .78611 L .52736 .78059 L p F P
0 g
s
.577 .404 .61 r
.60199 .92621 m .60256 .93106 L .59162 .93398 L p F P
0 g
s
.57 .384 .589 r
.5921 .93979 m .59162 .93398 L .60256 .93106 L p F P
0 g
s
.807 .594 .614 r
.21215 .93338 m .20743 .93213 L .20903 .92633 L p F P
0 g
s
.809 .596 .615 r
.20253 .92456 m .20903 .92633 L .20743 .93213 L p F P
0 g
s
.806 .606 .631 r
.20457 .91865 m .20253 .92456 L .20903 .92633 L p F P
0 g
s
.726 .71 .835 r
.31579 .77343 m .31466 .77192 L .31303 .77288 L closepath p F P
0 g
s
.677 .721 .883 r
.40815 .76131 m .39743 .76558 L .39436 .76165 L p F P
0 g
s
.809 .61 .633 r
.19813 .91684 m .20457 .91865 L .20253 .92456 L p F P
0 g
s
.808 .62 .648 r
.20457 .91865 m .19813 .91684 L .20059 .91083 L p F P
0 g
s
.799 .672 .724 r
.19231 .86312 m .19841 .86508 L .1936 .87172 L p F P
0 g
s
.799 .676 .729 r
.19841 .86508 m .19231 .86312 L .19743 .85639 L p F P
0 g
s
.685 .713 .87 r
.39127 .7579 m .39436 .76165 L .38458 .76568 L p F P
0 g
s
.685 .713 .87 r
.38057 .76213 m .39127 .7579 L p .38458 .76568 L F P
0 g
s
.685 .713 .87 r
.38458 .76568 m .38333 .76565 L .38057 .76213 L p F P
0 g
s
.702 .721 .864 r
.35297 .76361 m .3423 .76886 L .33916 .76475 L p F P
0 g
s
.711 .712 .849 r
.32849 .77026 m .33916 .76475 L .3423 .76886 L p F P
0 g
s
.798 .573 .596 r
.21978 .9412 m .21286 .93956 L .21408 .93386 L p F P
0 g
s
.801 .576 .596 r
.21215 .93338 m .21408 .93386 L .21286 .93956 L p F P
0 g
s
.691 .715 .867 r
.38333 .76565 m .38057 .76213 L .37385 .76503 L closepath p F P
0 g
s
.745 .708 .816 r
.27302 .77916 m .27623 .78354 L .2692 .78854 L p F P
0 g
s
.745 .708 .816 r
.2623 .78672 m .27302 .77916 L p .2692 .78854 L F P
0 g
s
.745 .708 .816 r
.2692 .78854 m .26237 .78681 L .2623 .78672 L p F P
0 g
s
.68 .697 .859 r
.42529 .76554 m .42497 .7651 L .42372 .7656 L closepath p F P
0 g
s
.68 .7 .861 r
.42194 .76111 m .42497 .7651 L .42372 .7656 L p F P
0 g
s
.68 .7 .861 r
.4112 .76526 m .42194 .76111 L p .42372 .7656 L F P
0 g
s
.976 .848 .651 r
.77158 .1383 m .77149 .13855 L .77132 .13807 L closepath p F P
0 g
s
.973 .779 .582 r
.58255 .2081 m .58178 .2112 L .58419 .21511 L p F P
0 g
s
.979 .771 .552 r
.58079 .21614 m .58319 .22004 L .58419 .21511 L p F P
0 g
s
.979 .771 .552 r
.58419 .21511 m .58178 .2112 L .58079 .21614 L p F P
0 g
s
.673 .718 .883 r
.42194 .76111 m .4112 .76526 L .40815 .76131 L p F P
0 g
s
.808 .631 .662 r
.20059 .91083 m .19422 .90899 L .19708 .90288 L p F P
0 g
s
.809 .622 .649 r
.19422 .90899 m .20059 .91083 L .19813 .91684 L p F P
0 g
s
.886 .855 .806 r
.74496 .19922 m .74786 .19569 L .7454 .193 L p F P
0 g
s
.804 .664 .709 r
.1955 .88024 m .19541 .88006 L .19533 .88018 L closepath p F P
0 g
s
.943 .854 .724 r
.76306 .15536 m .76453 .1596 L .76763 .15389 L p F P
0 g
s
.943 .854 .724 r
.76763 .15389 m .76617 .14964 L .76306 .15536 L p F P
0 g
s
.672 .694 .862 r
.43573 .76105 m .43846 .76472 L .42529 .76554 L p F P
0 g
s
.672 .694 .862 r
.42529 .76554 m .42497 .7651 L .43573 .76105 L p F P
0 g
s
.612 .563 .775 r
.59288 .81518 m .5944 .81893 L .58337 .82116 L p F P
0 g
s
.612 .563 .775 r
.58337 .82116 m .58239 .81875 L .59288 .81518 L p F P
0 g
s
.805 .665 .709 r
.19533 .88018 m .19541 .88006 L .19227 .87367 L p F P
0 g
s
.959 .851 .692 r
.76746 .13979 m .76899 .14403 L .77149 .13855 L p F P
0 g
s
.959 .851 .692 r
.7692 .13596 m .76746 .13979 L p .77149 .13855 L F P
0 g
s
.959 .851 .692 r
.77149 .13855 m .77132 .13807 L .7692 .13596 L p F P
0 g
s
.734 .383 .386 r
.28347 .97896 m .28237 .97881 L .28286 .97796 L closepath p F P
0 g
s
.761 .426 .418 r
.2659 .97387 m .26489 .97158 L .2669 .97194 L closepath p F P
0 g
s
.746 .396 .39 r
.2659 .97387 m .2669 .97194 L p .2754 .97767 L F P
0 g
s
.625 .592 .797 r
.56374 .80373 m .56372 .80368 L .5645 .80349 L closepath p F P
0 g
s
.808 .66 .699 r
.18928 .87823 m .19533 .88018 L .19144 .88657 L p F P
0 g
s
.805 .665 .709 r
.19227 .87367 m .18928 .87823 L .19533 .88018 L p F P
0 g
s
.625 .595 .8 r
.5645 .80349 m .56372 .80368 L .56083 .7975 L p F P
0 g
s
.794 .681 .74 r
.20031 .8528 m .203 .84954 L .19737 .84774 L closepath p F P
0 g
s
.79 .687 .751 r
.1971 .84731 m .20296 .84058 L p .203 .84954 L F P
0 g
s
.79 .687 .751 r
.203 .84954 m .19737 .84774 L .1971 .84731 L p F P
0 g
s
.369 0 0 r
.4004 .9948 m .40725 .99477 L p .41011 .9969 L F P
0 g
s
.369 0 0 r
.39886 .99581 m .4004 .9948 L p .41011 .9969 L F P
0 g
s
.499 0 0 r
.39886 .99581 m .39445 .99474 L .4004 .9948 L closepath p F P
0 g
s
.71 .719 .856 r
.33916 .76475 m .32849 .77026 L .32533 .76614 L p F P
0 g
s
.48 0 0 r
.41265 .99587 m .40725 .99477 L .41434 .99473 L closepath p F P
0 g
s
.369 0 0 r
.40725 .99477 m .41265 .99587 L .41011 .9969 L p F P
0 g
s
.649 .643 .831 r
.52445 .7753 m .51356 .77872 L .51063 .77357 L p F P
0 g
s
.574 .095 .082 r
.35978 .99366 m .3567 .99351 L .35764 .99282 L closepath p F P
0 g
s
.573 .094 .079 r
.37068 .99419 m .35978 .99366 L .35764 .99282 L p F P
0 g
s
.786 .814 .875 r
.68026 .25966 m .67196 .26565 L .66933 .26257 L p F P
0 g
s
.66 .662 .841 r
.48305 .77111 m .49389 .76738 L p .49621 .77234 L F P
0 g
s
.66 .67 .849 r
.49389 .76738 m .48305 .77111 L .48009 .76646 L p F P
0 g
s
.399 0 0 r
.39445 .99474 m .39886 .99581 L .39605 .99692 L p F P
0 g
s
.399 0 0 r
.38617 .99464 m .39445 .99474 L p .39605 .99692 L F P
0 g
s
.798 .556 .571 r
.22605 .9484 m .2191 .94677 L .21978 .9412 L p F P
0 g
s
.799 .557 .572 r
.21286 .93956 m .21978 .9412 L .2191 .94677 L p F P
0 g
s
.35 0 0 r
.41434 .99473 m .4209 .99459 L p .42389 .99666 L F P
0 g
s
.35 0 0 r
.41265 .99587 m .41434 .99473 L p .42389 .99666 L F P
0 g
s
.748 .788 .885 r
.64856 .27569 m .64734 .27642 L .64464 .2731 L p F P
0 g
s
.719 .78 .9 r
.63361 .27864 m .64464 .2731 L .64734 .27642 L p F P
0 g
s
.772 .699 .783 r
.22996 .81323 m .23223 .81118 L .22762 .80978 L closepath p F P
0 g
s
.777 .7 .779 r
.22402 .81879 m .22996 .81323 L .22762 .80978 L p F P
0 g
s
.942 .775 .647 r
.57965 .19324 m .58237 .19706 L .58428 .19182 L p F P
0 g
s
.942 .775 .647 r
.58428 .19182 m .58156 .18799 L .57965 .19324 L p F P
0 g
s
.767 .454 .456 r
.24905 .96734 m .2502 .96412 L p .25722 .97018 L F P
0 g
s
.779 .473 .47 r
.24905 .96734 m .24817 .96371 L .2502 .96412 L closepath p F P
0 g
s
.768 .704 .792 r
.24038 .80313 m .24078 .80369 L .23223 .81118 L p F P
0 g
s
.768 .704 .792 r
.23491 .80138 m .24038 .80313 L p .23223 .81118 L F P
0 g
s
.768 .704 .792 r
.22672 .80851 m .23491 .80138 L p .23223 .81118 L F P
0 g
s
.768 .704 .792 r
.23223 .81118 m .22762 .80978 L .22672 .80851 L p F P
0 g
s
.671 .714 .881 r
.43573 .76105 m .42497 .7651 L .42194 .76111 L p F P
0 g
s
.779 .698 .774 r
.22402 .81879 m .21908 .82354 L .21584 .8187 L p F P
0 g
s
.779 .698 .774 r
.21584 .8187 m .2178 .81682 L .22402 .81879 L p F P
0 g
s
.777 .7 .779 r
.22592 .80923 m .2178 .81682 L .22402 .81879 L p F P
0 g
s
.777 .7 .779 r
.22762 .80978 m .22592 .80923 L p .22402 .81879 L F P
0 g
s
.93 .626 .159 r
.77073 .09226 m .77073 .0923 L .77074 .09232 L closepath p F P
0 g
s
.623 .587 .792 r
.5747 .80104 m .5645 .80349 L .57438 .80032 L closepath p F P
0 g
s
.625 .595 .8 r
.57182 .79483 m .57438 .80032 L .5645 .80349 L p F P
0 g
s
.625 .595 .8 r
.56083 .7975 m .57182 .79483 L p .5645 .80349 L F P
0 g
s
.978 .709 .31 r
.77074 .09232 m .77073 .09233 L .77073 .0923 L closepath p F P
0 g
s
.98 .709 .318 r
.76886 .0926 m .76877 .08814 L .77073 .0923 L p F P
0 g
s
.98 .709 .318 r
.76984 .0947 m .76886 .0926 L p .77073 .0923 L F P
0 g
s
.98 .709 .318 r
.77073 .0923 m .77073 .09233 L .76984 .0947 L p F P
0 g
s
.728 .715 .839 r
.31149 .76779 m .30536 .77131 L .31303 .77288 L p F P
0 g
s
.728 .715 .839 r
.31303 .77288 m .31466 .77192 L .31149 .76779 L p F P
0 g
s
.726 .711 .836 r
.30081 .77399 m .30536 .77131 L .31303 .77288 L p F P
0 g
s
.809 .633 .664 r
.19079 .90101 m .19708 .90288 L .19422 .90899 L p F P
0 g
s
.808 .641 .676 r
.19708 .90288 m .19079 .90101 L .19403 .89479 L p F P
0 g
s
.399 0 0 r
.3851 .99534 m .38617 .99464 L p .39605 .99692 L F P
0 g
s
.523 .021 .004 r
.3851 .99534 m .38231 .99453 L .38617 .99464 L closepath p F P
0 g
s
.98 .712 .319 r
.77073 .09233 m .77079 .09678 L .76984 .0947 L closepath p F P
0 g
s
.979 .702 .315 r
.58445 .23811 m .58647 .24212 L .58635 .23757 L p F P
0 g
s
.979 .702 .315 r
.58635 .23757 m .58433 .23356 L .58445 .23811 L p F P
0 g
s
.614 .571 .782 r
.59151 .81195 m .59288 .81518 L .58239 .81875 L p F P
0 g
s
.614 .571 .782 r
.58239 .81875 m .58048 .81424 L .59151 .81195 L p F P
0 g
s
.217 .473 .886 r
.73961 .04189 m .74072 .04232 L .74323 .04637 L p F P
0 g
s
.084 .382 .844 r
.74542 .04493 m .74792 .04898 L .74323 .04637 L p F P
0 g
s
.084 .382 .844 r
.74323 .04637 m .74072 .04232 L .74542 .04493 L p F P
0 g
s
.577 .443 .661 r
.60986 .90568 m .6093 .90284 L .61991 .89951 L p F P
0 g
s
.582 .457 .675 r
.61843 .8928 m .61991 .89951 L .6093 .90284 L p F P
0 g
s
.467 0 0 r
.42645 .99554 m .4209 .99459 L .428 .99442 L closepath p F P
0 g
s
.35 0 0 r
.4209 .99459 m .42645 .99554 L .42389 .99666 L p F P
0 g
s
.964 .845 .676 r
.77132 .13807 m .7692 .13596 L .76991 .13432 L closepath p F P
0 g
s
.783 .699 .771 r
.2164 .82622 m .21908 .82354 L .21584 .8187 L p F P
0 g
s
.801 .576 .596 r
.21286 .93956 m .21261 .9395 L .21215 .93338 L p F P
0 g
s
.809 .581 .594 r
.20743 .93213 m .21215 .93338 L .21261 .9395 L p F P
0 g
s
.765 .701 .792 r
.24078 .80369 m .24118 .80336 L .24038 .80313 L closepath p F P
0 g
s
.886 .855 .806 r
.7454 .193 m .74382 .19492 L .74496 .19922 L p F P
0 g
s
.877 .851 .813 r
.73804 .20164 m .73924 .20592 L .74496 .19922 L p F P
0 g
s
.877 .851 .813 r
.74496 .19922 m .74382 .19492 L .73804 .20164 L p F P
0 g
s
.747 .789 .887 r
.64856 .27569 m .65834 .26981 L .65567 .26659 L p F P
0 g
s
.747 .789 .887 r
.65567 .26659 m .64743 .27147 L .64856 .27569 L p F P
0 g
s
.748 .788 .885 r
.64464 .2731 m .64743 .27147 L .64856 .27569 L p F P
0 g
s
.761 .706 .8 r
.24478 .79328 m .25113 .79523 L .24118 .80336 L p F P
0 g
s
.761 .706 .8 r
.23754 .79916 m .24478 .79328 L p .24118 .80336 L F P
0 g
s
.761 .706 .8 r
.24118 .80336 m .24038 .80313 L .23754 .79916 L p F P
0 g
s
.53 .032 .018 r
.38231 .99453 m .3851 .99534 L p .37135 .99442 L F P
0 g
s
.53 .032 .018 r
.37135 .99442 m .37163 .99423 L .38231 .99453 L p F P
0 g
s
.762 .418 .402 r
.26489 .97158 m .2659 .97387 L .26464 .97595 L p F P
0 g
s
.762 .418 .402 r
.25722 .97018 m .26489 .97158 L p .26464 .97595 L F P
0 g
s
.68 .273 .268 r
.31352 .98673 m .3132 .9867 L .31332 .98656 L closepath p F P
0 g
s
.798 .683 .737 r
.19743 .85639 m .20031 .8528 L .19737 .84774 L p F P
0 g
s
.783 .696 .768 r
.21033 .82421 m .2164 .82622 L .20936 .83349 L p F P
0 g
s
.783 .699 .771 r
.21584 .8187 m .21033 .82421 L .2164 .82622 L p F P
0 g
s
.69 .713 .866 r
.37746 .75837 m .38057 .76213 L .37385 .76503 L p F P
0 g
s
.69 .713 .866 r
.36677 .76278 m .37746 .75837 L p .37385 .76503 L F P
0 g
s
.69 .713 .866 r
.37385 .76503 m .36831 .76473 L .36677 .76278 L p F P
0 g
s
.512 .146 .282 r
.52134 .97913 m .53327 .97727 L .53167 .98136 L p F P
0 g
s
.512 .146 .282 r
.52015 .98228 m .52134 .97913 L p .53167 .98136 L F P
0 g
s
.56 .246 .394 r
.5339 .97482 m .53327 .97727 L .52134 .97913 L p F P
0 g
s
.344 0 0 r
.428 .99442 m .43561 .99415 L p .43742 .99621 L F P
0 g
s
.344 0 0 r
.42645 .99554 m .428 .99442 L p .43742 .99621 L F P
0 g
s
.534 .161 .279 r
.50758 .98489 m .49679 .98624 L .49548 .98606 L p F P
0 g
s
.53 .147 .26 r
.49679 .98624 m .4953 .98642 L .49548 .98606 L closepath p F P
0 g
s
.716 .717 .85 r
.32533 .76614 m .31466 .77192 L .31149 .76779 L p F P
0 g
s
.672 .698 .866 r
.43875 .76511 m .44018 .76458 L .43846 .76472 L closepath p F P
0 g
s
.671 .691 .86 r
.45122 .7635 m .45252 .76534 L p .43875 .76511 L F P
0 g
s
.671 .691 .86 r
.43875 .76511 m .44018 .76458 L .45122 .7635 L p F P
0 g
s
.639 .177 .14 r
.32565 .99117 m .31989 .99055 L .31352 .98673 L p F P
0 g
s
.598 .105 .053 r
.3132 .9867 m .31352 .98673 L .31989 .99055 L p F P
0 g
s
.741 .71 .822 r
.2822 .77952 m .27623 .78354 L .27302 .77916 L p F P
0 g
s
.761 .707 .802 r
.25198 .79549 m .25155 .7949 L .25113 .79523 L closepath p F P
0 g
s
.598 .105 .053 r
.30985 .98926 m .3132 .9867 L p .31989 .99055 L F P
0 g
s
.664 .216 .178 r
.30985 .98926 m .30471 .98565 L .3132 .9867 L closepath p F P
0 g
s
.57 .346 .537 r
.58127 .94814 m .58127 .95354 L .57002 .9561 L p F P
0 g
s
.557 .312 .501 r
.56974 .96126 m .57002 .9561 L .58127 .95354 L p F P
0 g
s
.769 .708 .795 r
.24038 .80313 m .23754 .79916 L .23491 .80138 L closepath p F P
0 g
s
.544 .226 .38 r
.54247 .9757 m .53327 .97727 L .5339 .97482 L closepath p F P
0 g
s
.545 .235 .392 r
.54504 .97525 m .54247 .9757 L .5339 .97482 L p F P
0 g
s
.782 .471 .463 r
.24817 .96371 m .24905 .96734 L .24854 .96861 L p F P
0 g
s
.782 .471 .463 r
.24085 .9622 m .24817 .96371 L p .24854 .96861 L F P
0 g
s
.797 .536 .543 r
.23216 .95527 m .22593 .95382 L .22605 .9484 L p F P
0 g
s
.798 .537 .542 r
.2191 .94677 m .22605 .9484 L .22593 .95382 L p F P
0 g
s
.992 .818 .566 r
.77008 .11548 m .77182 .11969 L .77306 .1147 L p F P
0 g
s
.992 .818 .566 r
.77306 .1147 m .77133 .11048 L .77008 .11548 L p F P
0 g
s
.716 .322 .3 r
.2958 .98459 m .28745 .98337 L .28347 .97896 L p F P
0 g
s
.714 .323 .307 r
.28237 .97881 m .28347 .97896 L .28745 .98337 L p F P
0 g
s
.911 .855 .774 r
.75352 .17647 m .75691 .17157 L .75826 .17583 L p F P
0 g
s
.911 .855 .774 r
.75826 .17583 m .75597 .17913 L .75352 .17647 L p F P
0 g
s
.549 .274 .451 r
.55767 .9685 m .55832 .96364 L .56373 .96252 L p F P
0 g
s
.561 .285 .455 r
.55832 .96364 m .55767 .9685 L .54608 .97071 L p F P
0 g
s
.592 .51 .731 r
.60895 .85883 m .60823 .85655 L .61863 .85292 L p F P
0 g
s
.595 .52 .74 r
.61712 .84841 m .61863 .85292 L .60823 .85655 L p F P
0 g
s
.595 .52 .74 r
.60823 .85655 m .60602 .84994 L .61712 .84841 L p F P
0 g
s
.552 .058 .037 r
.37135 .99442 m .37068 .99419 L .37163 .99423 L closepath p F P
0 g
s
.809 .644 .678 r
.18784 .89289 m .19403 .89479 L .19079 .90101 L p F P
0 g
s
.808 .651 .688 r
.19403 .89479 m .18784 .89289 L .19144 .88657 L p F P
0 g
s
.592 .51 .73 r
.61064 .86417 m .60895 .85883 L .62006 .85741 L p F P
0 g
s
.592 .51 .731 r
.61863 .85292 m .62006 .85741 L .60895 .85883 L p F P
0 g
s
.697 .715 .863 r
.36831 .76473 m .36677 .76278 L .3635 .76427 L closepath p F P
0 g
s
.592 .51 .73 r
.62006 .85741 m .62106 .86056 L .61064 .86417 L p F P
0 g
s
.589 .5 .721 r
.6119 .86837 m .61064 .86417 L .62106 .86056 L p F P
0 g
s
.671 .702 .87 r
.44018 .76458 m .43846 .76472 L .43573 .76105 L p F P
0 g
s
.486 0 0 r
.37068 .99419 m .37135 .99442 L .36808 .99588 L p F P
0 g
s
.486 0 0 r
.36808 .99588 m .35978 .99366 L .37068 .99419 L p F P
0 g
s
.659 .656 .836 r
.49689 .77221 m .49683 .77213 L .49621 .77234 L closepath p F P
0 g
s
.66 .662 .841 r
.49389 .76738 m .49683 .77213 L .49621 .77234 L p F P
0 g
s
.713 .343 0 r
.76498 .07546 m .76506 .07566 L .76535 .07624 L closepath p F P
0 g
s
.861 .512 .004 r
.76615 .07972 m .76506 .07566 L .76535 .07624 L p F P
0 g
s
.861 .512 .004 r
.76821 .08387 m .76615 .07972 L p .76535 .07624 L F P
0 g
s
.577 .443 .661 r
.61991 .89951 m .62099 .90485 L .60986 .90568 L p F P
0 g
s
.578 .443 .661 r
.6106 .90938 m .60986 .90568 L .62099 .90485 L p F P
0 g
s
.344 0 0 r
.43561 .99415 m .44025 .99482 L .43742 .99621 L p F P
0 g
s
.46 0 0 r
.44025 .99482 m .43561 .99415 L .44142 .99391 L closepath p F P
0 g
s
.942 .629 .184 r
.76672 .08399 m .76877 .08814 L .76821 .08387 L p F P
0 g
s
.942 .629 .184 r
.76821 .08387 m .76615 .07972 L .76672 .08399 L p F P
0 g
s
.783 .696 .768 r
.2049 .8298 m .21033 .82421 L p .20936 .83349 L F P
0 g
s
.783 .696 .768 r
.20936 .83349 m .20679 .83267 L .2049 .8298 L p F P
0 g
s
.787 .691 .758 r
.20814 .8348 m .20936 .83349 L .20679 .83267 L closepath p F P
0 g
s
.762 .711 .803 r
.24832 .79048 m .24478 .79328 L .25113 .79523 L p F P
0 g
s
.762 .711 .803 r
.25113 .79523 m .25155 .7949 L .24832 .79048 L p F P
0 g
s
.671 .752 .911 r
.61981 .27927 m .63089 .27514 L .63361 .27864 L p F P
0 g
s
.662 .746 .912 r
.63089 .27514 m .61981 .27927 L .61706 .27547 L p F P
0 g
s
.803 .666 .712 r
.19227 .87367 m .1936 .87172 L .19087 .87086 L closepath p F P
0 g
s
.799 .672 .724 r
.1891 .86754 m .19231 .86312 L p .1936 .87172 L F P
0 g
s
.799 .672 .724 r
.1936 .87172 m .19087 .87086 L .1891 .86754 L p F P
0 g
s
.595 .52 .74 r
.616 .84508 m .61712 .84841 L .60602 .84994 L p F P
0 g
s
.595 .52 .74 r
.60602 .84994 m .60562 .84874 L .616 .84508 L p F P
0 g
s
.714 .323 .307 r
.28745 .98337 m .2794 .98226 L .28237 .97881 L p F P
0 g
s
.731 .345 .319 r
.2754 .97767 m .28237 .97881 L .2794 .98226 L p F P
0 g
s
.757 .711 .809 r
.26223 .78677 m .25155 .7949 L .24832 .79048 L p F P
0 g
s
.8 .679 .731 r
.19145 .85439 m .19743 .85639 L .19231 .86312 L p F P
0 g
s
.798 .683 .737 r
.19687 .84757 m .19145 .85439 L .19743 .85639 L p F P
0 g
s
.798 .683 .737 r
.19737 .84774 m .19687 .84757 L p .19743 .85639 L F P
0 g
s
.598 .529 .749 r
.6142 .83996 m .616 .84508 L .60562 .84874 L p F P
0 g
s
.598 .529 .749 r
.60562 .84874 m .60311 .8416 L .6142 .83996 L p F P
0 g
s
.59 .499 .72 r
.61287 .87159 m .6119 .86837 L .62302 .86707 L p F P
0 g
s
.589 .5 .721 r
.62106 .86056 m .62302 .86707 L .6119 .86837 L p F P
0 g
s
.671 .702 .87 r
.44651 .75722 m .44952 .76115 L .44018 .76458 L p F P
0 g
s
.671 .702 .87 r
.43573 .76105 m .44651 .75722 L p .44018 .76458 L F P
0 g
s
.67 .697 .866 r
.45122 .7635 m .44952 .76115 L .44018 .76458 L closepath p F P
0 g
s
.477 .045 .14 r
.49284 .98985 m .4953 .98642 L .49679 .98624 L p F P
0 g
s
.961 .78 .613 r
.57976 .20511 m .58061 .20226 L .58313 .20615 L p F P
0 g
s
.961 .78 .613 r
.58313 .20615 m .58255 .2081 L .57976 .20511 L p F P
0 g
s
.715 .776 .9 r
.64464 .2731 m .63361 .27864 L .63089 .27514 L p F P
0 g
s
.654 .654 .838 r
.5077 .76856 m .5084 .76973 L .49689 .77221 L p F P
0 g
s
.654 .654 .838 r
.49689 .77221 m .49683 .77213 L .5077 .76856 L p F P
0 g
s
.792 .692 .755 r
.20296 .84058 m .20814 .8348 L .20679 .83267 L p F P
0 g
s
.789 .819 .876 r
.68026 .25966 m .68292 .25772 L .6803 .25469 L p F P
0 g
s
.789 .819 .876 r
.6803 .25469 m .67946 .2553 L .68026 .25966 L p F P
0 g
s
.786 .814 .875 r
.66933 .26257 m .67946 .2553 L .68026 .25966 L p F P
0 g
s
.56 .338 .536 r
.58127 .95354 m .58127 .94814 L .59237 .9454 L p F P
0 g
s
.571 .367 .565 r
.5921 .93979 m .59237 .9454 L .58127 .94814 L p F P
0 g
s
.655 .663 .846 r
.5077 .76856 m .49683 .77213 L .49389 .76738 L p F P
0 g
s
.614 .572 .783 r
.58904 .80611 m .59151 .81195 L .58048 .81424 L p F P
0 g
s
.614 .572 .783 r
.58048 .81424 m .57855 .8097 L .58904 .80611 L p F P
0 g
s
0 .211 .736 r
.75153 .05203 m .75393 .05611 L .75033 .05305 L p F P
0 g
s
0 .211 .736 r
.75033 .05305 m .74792 .04898 L .75153 .05203 L p F P
0 g
s
.587 .49 .711 r
.61287 .87159 m .6233 .86802 L p .61551 .87864 L F P
0 g
s
.587 .49 .711 r
.61551 .87864 m .61487 .87871 L .61287 .87159 L p F P
0 g
s
.59 .499 .72 r
.62302 .86707 m .6233 .86802 L .61287 .87159 L p F P
0 g
s
.668 .683 .855 r
.46376 .76204 m .4663 .76579 L p .45252 .76534 L F P
0 g
s
.668 .683 .855 r
.45252 .76534 m .46037 .76248 L .46376 .76204 L p F P
0 g
s
.669 .691 .862 r
.45252 .76534 m .46037 .76248 L .45122 .7635 L closepath p F P
0 g
s
.87 .847 .819 r
.7347 .2054 m .73804 .20164 L .73924 .20592 L p F P
0 g
s
.87 .847 .819 r
.73924 .20592 m .7372 .2082 L .7347 .2054 L p F P
0 g
s
.568 .398 .611 r
.60199 .92621 m .60185 .92506 L .61264 .92195 L p F P
0 g
s
.575 .418 .631 r
.6117 .91574 m .61264 .92195 L .60185 .92506 L p F P
0 g
s
.723 .345 0 r
.76506 .07566 m .76498 .07546 L .76236 .07022 L p F P
0 g
s
.445 0 0 r
.44025 .99482 m .44142 .99391 L .45163 .99337 L p F P
0 g
s
.992 .745 .441 r
.58212 .2296 m .58433 .23356 L .58469 .22884 L p F P
0 g
s
.992 .745 .441 r
.58469 .22884 m .58248 .22488 L .58212 .2296 L p F P
0 g
s
.726 .709 .834 r
.30081 .77399 m .30536 .77131 L .29772 .76985 L closepath p F P
0 g
s
.734 .713 .831 r
.29772 .76985 m .30081 .77399 L p .28693 .77639 L F P
0 g
s
.494 .082 .188 r
.50635 .98689 m .49679 .98624 L .50758 .98489 L closepath p F P
0 g
s
.477 .045 .14 r
.49679 .98624 m .50635 .98689 L p .49284 .98985 L F P
0 g
s
.633 .609 .808 r
.54409 .78854 m .55504 .78558 L .55794 .79145 L p F P
0 g
s
.634 .612 .811 r
.55408 .78366 m .55504 .78558 L .54409 .78854 L p F P
0 g
s
.634 .612 .811 r
.54409 .78854 m .54325 .78688 L .55408 .78366 L p F P
0 g
s
.53 .032 .018 r
.3851 .99534 m .38187 .99665 L .37135 .99442 L p F P
0 g
s
.299 0 0 r
.37135 .99442 m .38187 .99665 L .38168 .99668 L p F P
0 g
s
.299 0 0 r
.36808 .99588 m .37135 .99442 L p .38168 .99668 L F P
0 g
s
.801 .822 .867 r
.69163 .25093 m .68292 .25772 L .6803 .25469 L p F P
0 g
s
.807 .667 .709 r
.18928 .87823 m .19227 .87367 L .19087 .87086 L p F P
0 g
s
.694 .716 .866 r
.35297 .76361 m .3534 .76342 L .3635 .76427 L p F P
0 g
s
.699 .725 .87 r
.36365 .75898 m .3534 .76342 L .3635 .76427 L p F P
0 g
s
.699 .725 .87 r
.3635 .76427 m .36677 .76278 L .36365 .75898 L p F P
0 g
s
.723 .345 0 r
.76236 .07022 m .76292 .07153 L .76506 .07566 L p F P
0 g
s
.864 .51 .006 r
.76401 .07559 m .76615 .07972 L .76506 .07566 L p F P
0 g
s
.864 .51 .006 r
.76506 .07566 m .76292 .07153 L .76401 .07559 L p F P
0 g
s
.598 .53 .75 r
.61316 .83702 m .6142 .83996 L .60311 .8416 L p F P
0 g
s
.598 .53 .75 r
.60311 .8416 m .6028 .84072 L .61316 .83702 L p F P
0 g
s
.741 .71 .822 r
.27302 .77916 m .2751 .77778 L .2822 .77952 L p F P
0 g
s
.741 .714 .826 r
.28373 .77216 m .2751 .77778 L .2822 .77952 L p F P
0 g
s
.741 .714 .826 r
.2822 .77952 m .28693 .77639 L .28373 .77216 L p F P
0 g
s
.6 .539 .758 r
.61129 .83196 m .61316 .83702 L .6028 .84072 L p F P
0 g
s
.6 .539 .758 r
.6028 .84072 m .6002 .83369 L .61129 .83196 L p F P
0 g
s
.864 .847 .825 r
.73292 .21283 m .7372 .2082 L .7347 .2054 L p F P
0 g
s
.906 .856 .781 r
.75388 .18203 m .75597 .17913 L .75352 .17647 L p F P
0 g
s
.641 .625 .818 r
.52736 .78059 m .53828 .77737 L .54119 .7829 L p F P
0 g
s
.642 .63 .822 r
.53752 .77595 m .53828 .77737 L .52736 .78059 L p F P
0 g
s
.642 .63 .822 r
.52736 .78059 m .52647 .77893 L .53752 .77595 L p F P
0 g
s
.809 .653 .69 r
.18533 .88463 m .19144 .88657 L .18784 .89289 L p F P
0 g
s
.808 .66 .699 r
.19144 .88657 m .18533 .88463 L .18928 .87823 L p F P
0 g
s
.785 .501 .507 r
.24085 .9622 m .23351 .96069 L .23293 .95543 L p F P
0 g
s
.786 .502 .507 r
.23216 .95527 m .23293 .95543 L .23351 .96069 L p F P
0 g
s
0 0 .549 r
.75661 .05953 m .75891 .06363 L .75623 .06021 L p F P
0 g
s
0 0 .549 r
.75623 .06021 m .75393 .05611 L .75661 .05953 L p F P
0 g
s
.975 .837 .644 r
.76823 .13011 m .76991 .13432 L .77187 .12905 L p F P
0 g
s
.975 .837 .644 r
.77187 .12905 m .7702 .12483 L .76823 .13011 L p F P
0 g
s
.625 .596 .801 r
.56979 .79051 m .57182 .79483 L .56083 .7975 L p F P
0 g
s
.625 .596 .801 r
.56083 .7975 m .55915 .79394 L .56979 .79051 L p F P
0 g
s
.536 .229 .393 r
.54504 .97525 m .54608 .97071 L .55767 .9685 L p F P
0 g
s
.366 0 0 r
.35978 .99366 m .36808 .99588 L .36692 .99614 L p F P
0 g
s
.366 0 0 r
.3567 .99351 m .35978 .99366 L p .36692 .99614 L F P
0 g
s
.93 .852 .743 r
.7615 .15798 m .76306 .15536 L .76453 .1596 L p F P
0 g
s
.93 .852 .743 r
.76453 .1596 m .76393 .16061 L .7615 .15798 L p F P
0 g
s
.587 .489 .711 r
.61491 .87885 m .61487 .87871 L .61551 .87864 L closepath p F P
0 g
s
.645 .26 0 r
.75976 .06527 m .75891 .06363 L .7611 .06776 L p F P
0 g
s
.645 .26 0 r
.7611 .06776 m .76236 .07022 L .75976 .06527 L p F P
0 g
s
.582 .476 .699 r
.61675 .8859 m .61491 .87885 L .61551 .87864 L p F P
0 g
s
.794 .69 .75 r
.20296 .84058 m .1971 .84731 L .19386 .84212 L p F P
0 g
s
.794 .69 .75 r
.19386 .84212 m .19695 .83856 L .20296 .84058 L p F P
0 g
s
.792 .692 .755 r
.20333 .83148 m .19695 .83856 L .20296 .84058 L p F P
0 g
s
.792 .692 .755 r
.20679 .83267 m .20333 .83148 L p .20296 .84058 L F P
0 g
s
.568 .398 .61 r
.60256 .93106 m .60199 .92621 L .61311 .92584 L p F P
0 g
s
.568 .398 .611 r
.61264 .92195 m .61311 .92584 L .60199 .92621 L p F P
0 g
s
.578 .443 .661 r
.62099 .90485 m .62123 .90608 L .6106 .90938 L p F P
0 g
s
.572 .427 .646 r
.6117 .91574 m .6106 .90938 L .62123 .90608 L p F P
0 g
s
.786 .502 .507 r
.23351 .96069 m .23101 .96017 L .23216 .95527 L p F P
0 g
s
.796 .513 .508 r
.22593 .95382 m .23216 .95527 L .23101 .96017 L p F P
0 g
s
.366 0 0 r
.35432 .99468 m .3567 .99351 L p .36692 .99614 L F P
0 g
s
.527 .005 0 r
.35432 .99468 m .34932 .99301 L .3567 .99351 L closepath p F P
0 g
s
.664 .677 .852 r
.4663 .76579 m .47713 .76195 L .48009 .76646 L p F P
0 g
s
.664 .683 .858 r
.4759 .76018 m .47713 .76195 L .4663 .76579 L p F P
0 g
s
.664 .683 .858 r
.4663 .76579 m .46376 .76204 L .4759 .76018 L p F P
0 g
s
.635 .62 .818 r
.55215 .77991 m .55408 .78366 L .54325 .78688 L p F P
0 g
s
.635 .62 .818 r
.54325 .78688 m .54119 .7829 L .55215 .77991 L p F P
0 g
s
.95 .85 .708 r
.76463 .1454 m .76617 .14964 L .76899 .14403 L p F P
0 g
s
.95 .85 .708 r
.76899 .14403 m .76746 .13979 L .76463 .1454 L p F P
0 g
s
.775 .706 .786 r
.22762 .80978 m .22672 .80851 L .22592 .80923 L closepath p F P
0 g
s
.927 .854 .75 r
.76089 .16552 m .76393 .16061 L .7615 .15798 L p F P
0 g
s
.754 .71 .811 r
.26237 .78681 m .2623 .78672 L .26223 .78677 L closepath p F P
0 g
s
.582 .476 .699 r
.61551 .87864 m .62601 .8778 L p .61675 .8859 L F P
0 g
s
.582 .477 .7 r
.62601 .8778 m .61551 .87864 L .62535 .87527 L closepath p F P
0 g
s
.587 .49 .711 r
.6233 .86802 m .62535 .87527 L .61551 .87864 L p F P
0 g
s
.809 .596 .615 r
.20743 .93213 m .20089 .93036 L .20253 .92456 L p F P
0 g
s
.81 .598 .616 r
.19605 .92276 m .20253 .92456 L .20089 .93036 L p F P
0 g
s
.809 .61 .633 r
.20253 .92456 m .19605 .92276 L .19813 .91684 L p F P
0 g
s
.461 .598 .902 r
.60576 .27245 m .60313 .27238 L .60033 .26781 L p F P
0 g
s
.967 .77 .586 r
.58178 .2112 m .58255 .2081 L .57976 .20511 L p F P
0 g
s
.864 .847 .825 r
.7347 .2054 m .7318 .20853 L .73292 .21283 L p F P
0 g
s
.859 .845 .829 r
.72507 .21561 m .7318 .20853 L .73292 .21283 L p F P
0 g
s
.859 .845 .829 r
.72608 .21926 m .72507 .21561 L p .73292 .21283 L F P
0 g
s
.859 .845 .829 r
.73292 .21283 m .72644 .21967 L .72608 .21926 L p F P
0 g
s
.478 .04 .127 r
.49284 .98985 m .49043 .99011 L .48168 .98946 L p F P
0 g
s
.468 .017 .094 r
.49043 .99011 m .48027 .99114 L .48168 .98946 L closepath p F P
0 g
s
.757 .711 .809 r
.24832 .79048 m .25577 .78484 L .26223 .78677 L p F P
0 g
s
.756 .714 .813 r
.25907 .7824 m .25577 .78484 L .26223 .78677 L p F P
0 g
s
.756 .714 .813 r
.26223 .78677 m .2623 .78672 L .25907 .7824 L p F P
0 g
s
.749 .715 .82 r
.27302 .77916 m .2623 .78672 L .25907 .7824 L p F P
0 g
s
.997 .796 .511 r
.7695 .10629 m .77133 .11048 L .77218 .10565 L p F P
0 g
s
.997 .796 .511 r
.77218 .10565 m .77037 .10145 L .7695 .10629 L p F P
0 g
s
.79 .698 .763 r
.20679 .83267 m .2049 .8298 L .20333 .83148 L closepath p F P
0 g
s
.617 .58 .79 r
.58862 .80518 m .58904 .80611 L .57855 .8097 L p F P
0 g
s
.617 .58 .79 r
.57855 .8097 m .57759 .80754 L .58862 .80518 L p F P
0 g
s
.81 .612 .635 r
.19172 .91502 m .19813 .91684 L .19605 .92276 L p F P
0 g
s
.809 .622 .649 r
.19813 .91684 m .19172 .91502 L .19422 .90899 L p F P
0 g
s
.46 0 .01 r
.45406 .99367 m .45163 .99337 L .4546 .99319 L closepath p F P
0 g
s
.445 0 0 r
.45163 .99337 m .45406 .99367 L p .44025 .99482 L F P
0 g
s
.561 .359 .565 r
.59237 .9454 m .5921 .93979 L .60306 .93688 L p F P
0 g
s
.57 .384 .589 r
.60256 .93106 m .60306 .93688 L .5921 .93979 L p F P
0 g
s
.809 .581 .594 r
.21261 .9395 m .20626 .93782 L .20743 .93213 L p F P
0 g
s
.81 .583 .595 r
.20089 .93036 m .20743 .93213 L .20626 .93782 L p F P
0 g
s
0 .082 .642 r
.59382 .25804 m .59564 .26209 L .59248 .25861 L p F P
0 g
s
0 .082 .642 r
.59248 .25861 m .5908 .25451 L .59382 .25804 L p F P
0 g
s
.807 .667 .709 r
.19087 .87086 m .18754 .86975 L p .18928 .87823 L F P
0 g
s
.805 .674 .719 r
.19087 .87086 m .1891 .86754 L .18754 .86975 L closepath p F P
0 g
s
.805 .826 .868 r
.69163 .25093 m .69385 .24917 L .69126 .24619 L p F P
0 g
s
.805 .826 .868 r
.69126 .24619 m .69075 .24659 L .69163 .25093 L p F P
0 g
s
.801 .822 .867 r
.6803 .25469 m .69075 .24659 L .69163 .25093 L p F P
0 g
s
.646 .175 .12 r
.30471 .98565 m .30985 .98926 L .30944 .98949 L p F P
0 g
s
.646 .175 .12 r
.2966 .9847 m .30471 .98565 L p .30944 .98949 L F P
0 g
s
.906 .856 .781 r
.75352 .17647 m .7526 .17775 L .75388 .18203 L p F P
0 g
s
.896 .853 .792 r
.74772 .18414 m .74903 .1884 L .75388 .18203 L p F P
0 g
s
.896 .853 .792 r
.75388 .18203 m .7526 .17775 L .74772 .18414 L p F P
0 g
s
.162 .409 .851 r
.59751 .26322 m .59564 .26209 L .59725 .2662 L p F P
0 g
s
.162 .409 .851 r
.59725 .2662 m .60033 .26781 L .59751 .26322 L p F P
0 g
s
.6 .54 .759 r
.61009 .82874 m .61129 .83196 L .6002 .83369 L p F P
0 g
s
.6 .54 .759 r
.6002 .83369 m .59974 .83246 L .61009 .82874 L p F P
0 g
s
.722 .713 .841 r
.3083 .76373 m .31149 .76779 L .30536 .77131 L p F P
0 g
s
.722 .713 .841 r
.29762 .76973 m .3083 .76373 L p .30536 .77131 L F P
0 g
s
.722 .713 .841 r
.30536 .77131 m .29772 .76985 L .29762 .76973 L p F P
0 g
s
.734 .713 .831 r
.28693 .77639 m .29751 .7698 L .29772 .76985 L p F P
0 g
s
.734 .718 .836 r
.29751 .7698 m .28693 .77639 L .28373 .77216 L p F P
0 g
s
.643 .636 .829 r
.53538 .77208 m .53752 .77595 L .52647 .77893 L p F P
0 g
s
.643 .636 .829 r
.52647 .77893 m .52445 .7753 L .53538 .77208 L p F P
0 g
s
.746 .396 .39 r
.2754 .97767 m .26731 .97638 L .2659 .97387 L p F P
0 g
s
.746 .396 .389 r
.26731 .97638 m .26464 .97595 L .2659 .97387 L closepath p F P
0 g
s
.803 .674 .721 r
.19231 .86312 m .1891 .86754 L .18591 .86161 L p F P
0 g
s
.803 .674 .721 r
.18591 .86161 m .18625 .86114 L .19231 .86312 L p F P
0 g
s
.8 .679 .731 r
.19231 .86312 m .18625 .86114 L .19145 .85439 L p F P
0 g
s
.399 0 0 r
.39605 .99692 m .3946 .9969 L .3851 .99534 L p F P
0 g
s
.4 0 0 r
.3946 .9969 m .3851 .99534 L .38187 .99665 L p F P
0 g
s
.767 .801 .88 r
.66595 .26481 m .65834 .26981 L .65567 .26659 L p F P
0 g
s
.444 0 0 r
.45406 .99367 m .4546 .99319 L .46756 .99228 L p F P
0 g
s
.518 .08 .146 r
.46787 .99196 m .46756 .99228 L .4546 .99319 L p F P
0 g
s
.603 .549 .767 r
.60838 .82432 m .61009 .82874 L .59974 .83246 L p F P
0 g
s
.603 .549 .767 r
.59974 .83246 m .5973 .82616 L .60838 .82432 L p F P
0 g
s
.81 .625 .652 r
.18789 .90714 m .19422 .90899 L .19172 .91502 L p F P
0 g
s
.809 .633 .664 r
.19422 .90899 m .18789 .90714 L .19079 .90101 L p F P
0 g
s
.815 .828 .86 r
.70157 .2427 m .69385 .24917 L .69126 .24619 L p F P
0 g
s
.681 .733 .89 r
.37746 .75837 m .36677 .76278 L .36365 .75898 L p F P
0 g
s
.796 .689 .746 r
.19737 .84774 m .1971 .84731 L .19687 .84757 L closepath p F P
0 g
s
.694 .716 .867 r
.35297 .76361 m .3534 .76342 L .35278 .76337 L closepath p F P
0 g
s
.702 .721 .864 r
.35278 .76337 m .35297 .76361 L p .33916 .76475 L F P
0 g
s
.649 .643 .831 r
.51063 .77357 m .52153 .77015 L .52445 .7753 L p F P
0 g
s
.649 .647 .835 r
.5197 .76699 m .52153 .77015 L .51063 .77357 L p F P
0 g
s
.649 .647 .835 r
.51063 .77357 m .5084 .76973 L .5197 .76699 L p F P
0 g
s
.76 .412 .395 r
.24949 .96878 m .25722 .97018 L .25953 .975 L p F P
0 g
s
.767 .454 .456 r
.25722 .97018 m .24949 .96878 L .24905 .96734 L p F P
0 g
s
.762 .418 .402 r
.26464 .97595 m .25953 .975 L .25722 .97018 L p F P
0 g
s
.799 .557 .572 r
.21259 .94172 m .21286 .93956 L p .2191 .94677 L F P
0 g
s
.802 .559 .572 r
.21259 .94172 m .21286 .93956 L .21261 .9395 L closepath p F P
0 g
s
.551 .282 .461 r
.56954 .96293 m .56373 .96252 L .56974 .96126 L closepath p F P
0 g
s
.549 .274 .451 r
.56373 .96252 m .56954 .96293 L p .55767 .9685 L F P
0 g
s
.675 .734 .895 r
.39127 .7579 m .38057 .76213 L .37746 .75837 L p F P
0 g
s
.668 .696 .867 r
.46037 .76248 m .45122 .7635 L .44952 .76115 L p F P
0 g
s
.985 .759 .512 r
.58008 .22097 m .58248 .22488 L .58319 .22004 L p F P
0 g
s
.985 .759 .512 r
.58319 .22004 m .58079 .21614 L .58008 .22097 L p F P
0 g
s
.946 .773 .635 r
.57789 .19844 m .58061 .20226 L .58237 .19706 L p F P
0 g
s
.946 .773 .635 r
.58237 .19706 m .57965 .19324 L .57789 .19844 L p F P
0 g
s
.807 .564 .571 r
.21261 .9395 m .20626 .93782 L p .21217 .94513 L F P
0 g
s
.807 .564 .571 r
.21217 .94513 m .21259 .94172 L .21261 .9395 L p F P
0 g
s
.579 .466 .688 r
.61675 .8859 m .62721 .88236 L p .62674 .89001 L F P
0 g
s
.579 .466 .688 r
.62674 .89001 m .61789 .89059 L .61675 .8859 L p F P
0 g
s
.582 .476 .699 r
.62601 .8778 m .62721 .88236 L .61675 .8859 L p F P
0 g
s
.691 .72 .872 r
.36051 .75534 m .36365 .75898 L .3534 .76342 L p F P
0 g
s
.691 .72 .872 r
.34983 .75976 m .36051 .75534 L p .3534 .76342 L F P
0 g
s
.691 .72 .872 r
.3534 .76342 m .35278 .76337 L .34983 .75976 L p F P
0 g
s
.809 .662 .701 r
.18327 .87624 m .18928 .87823 L .18533 .88463 L p F P
0 g
s
.807 .667 .709 r
.18754 .86975 m .18327 .87624 L .18928 .87823 L p F P
0 g
s
.798 .691 .747 r
.19687 .84757 m .1971 .84731 L .19386 .84212 L p F P
0 g
s
.616 .582 .792 r
.58862 .80518 m .57759 .80754 L .5747 .80104 L p F P
0 g
s
.853 .845 .836 r
.72644 .21967 m .72623 .21988 L .72608 .21926 L closepath p F P
0 g
s
.685 .331 0 r
.5889 .25047 m .5908 .25451 L .58908 .25051 L p F P
0 g
s
.685 .331 0 r
.58908 .25051 m .58724 .24645 L .5889 .25047 L p F P
0 g
s
.8 .686 .739 r
.191 .84552 m .19687 .84757 L .19145 .85439 L p F P
0 g
s
.798 .691 .747 r
.19386 .84212 m .191 .84552 L .19687 .84757 L p F P
0 g
s
.702 .721 .864 r
.33916 .76475 m .34454 .76221 L .35278 .76337 L p F P
0 g
s
.7 .723 .867 r
.35278 .76337 m .34983 .75976 L .34454 .76221 L closepath p F P
0 g
s
.84 .839 .844 r
.71757 .22297 m .71869 .22724 L .72623 .21988 L p F P
0 g
s
.84 .839 .844 r
.72392 .21677 m .71757 .22297 L p .72623 .21988 L F P
0 g
s
.84 .839 .844 r
.72623 .21988 m .72608 .21926 L .72392 .21677 L p F P
0 g
s
.438 0 0 r
.34932 .99301 m .35432 .99468 L .35183 .99534 L p F P
0 g
s
.438 0 0 r
.3414 .99251 m .34932 .99301 L p .35183 .99534 L F P
0 g
s
.677 .721 .883 r
.39436 .76165 m .40508 .75756 L .40815 .76131 L p F P
0 g
s
.671 .734 .898 r
.40508 .75756 m .39436 .76165 L .39127 .7579 L p F P
0 g
s
.701 .715 .859 r
.33916 .76475 m .34454 .76221 L .33643 .76129 L closepath p F P
0 g
s
.71 .719 .856 r
.33643 .76129 m .33916 .76475 L p .32533 .76614 L F P
0 g
s
.731 .345 .319 r
.2794 .98226 m .27897 .98219 L .2754 .97767 L p F P
0 g
s
.729 .333 .298 r
.26731 .97638 m .2754 .97767 L .27897 .98219 L p F P
0 g
s
.627 .604 .807 r
.56893 .78873 m .56979 .79051 L .55915 .79394 L p F P
0 g
s
.627 .604 .807 r
.55915 .79394 m .55794 .79145 L .56893 .78873 L p F P
0 g
s
.776 .708 .788 r
.22346 .80396 m .21989 .80719 L .22592 .80923 L p F P
0 g
s
.776 .708 .788 r
.22592 .80923 m .22672 .80851 L .22346 .80396 L p F P
0 g
s
.776 .705 .785 r
.21989 .80719 m .22592 .80923 L .2178 .81682 L p F P
0 g
s
.772 .708 .792 r
.23491 .80138 m .22672 .80851 L .22346 .80396 L p F P
0 g
s
.66 .678 .856 r
.49094 .76275 m .48009 .76646 L .47713 .76195 L p F P
0 g
s
.66 .67 .849 r
.48009 .76646 m .49094 .76275 L .49389 .76738 L p F P
0 g
s
.819 .831 .859 r
.70157 .2427 m .70475 .23999 L .70218 .23705 L p F P
0 g
s
.819 .831 .859 r
.70218 .23705 m .70061 .23838 L .70157 .2427 L p F P
0 g
s
.815 .828 .86 r
.69126 .24619 m .70061 .23838 L .70157 .2427 L p F P
0 g
s
.78 .7 .775 r
.21584 .8187 m .2178 .81682 L .21365 .81547 L closepath p F P
0 g
s
.776 .705 .785 r
.21259 .81396 m .21989 .80719 L p .2178 .81682 L F P
0 g
s
.776 .705 .785 r
.2178 .81682 m .21365 .81547 L .21259 .81396 L p F P
0 g
s
.81 .636 .666 r
.18455 .89912 m .19079 .90101 L .18789 .90714 L p F P
0 g
s
.809 .644 .678 r
.19079 .90101 m .18455 .89912 L .18784 .89289 L p F P
0 g
s
.785 .701 .772 r
.21033 .82421 m .21584 .8187 L .21365 .81547 L p F P
0 g
s
.673 .718 .883 r
.40815 .76131 m .41889 .75733 L .42194 .76111 L p F P
0 g
s
.667 .732 .898 r
.41889 .75733 m .40815 .76131 L .40508 .75756 L p F P
0 g
s
.828 .833 .851 r
.71051 .23484 m .70475 .23999 L .70218 .23705 L p F P
0 g
s
.782 .471 .463 r
.24854 .96861 m .24216 .96727 L .24085 .9622 L p F P
0 g
s
.781 .469 .46 r
.23351 .96069 m .24085 .9622 L .24216 .96727 L p F P
0 g
s
.839 .836 .843 r
.71307 .22725 m .71757 .22297 L .71869 .22724 L p F P
0 g
s
.839 .836 .843 r
.71869 .22724 m .71562 .23017 L .71307 .22725 L p F P
0 g
s
.599 .116 .079 r
.33906 .99231 m .32931 .99148 L .32692 .99034 L p F P
0 g
s
.6 .119 .084 r
.32931 .99148 m .32565 .99117 L .32692 .99034 L closepath p F P
0 g
s
.772 .708 .792 r
.22346 .80396 m .22875 .79938 L .23491 .80138 L p F P
0 g
s
.77 .71 .796 r
.23429 .79469 m .22875 .79938 L .23491 .80138 L p F P
0 g
s
.77 .71 .796 r
.23491 .80138 m .23754 .79916 L .23429 .79469 L p F P
0 g
s
.832 .835 .849 r
.71051 .23484 m .71562 .23017 L .71307 .22725 L p F P
0 g
s
.832 .835 .849 r
.71307 .22725 m .70946 .23054 L .71051 .23484 L p F P
0 g
s
.828 .833 .851 r
.70218 .23705 m .70946 .23054 L .71051 .23484 L p F P
0 g
s
.469 .011 .08 r
.48027 .99114 m .46956 .99211 L .46787 .99196 L p F P
0 g
s
.459 0 .048 r
.46956 .99211 m .46756 .99228 L .46787 .99196 L closepath p F P
0 g
s
.365 0 0 r
.40755 .99691 m .39605 .99692 L .39886 .99581 L closepath p F P
0 g
s
.369 0 0 r
.41011 .9969 m .40755 .99691 L .39886 .99581 L p F P
0 g
s
.71 .719 .856 r
.32533 .76614 m .33532 .7611 L .33643 .76129 L p F P
0 g
s
.706 .726 .865 r
.33532 .7611 m .32533 .76614 L .32216 .7621 L p F P
0 g
s
.716 .717 .85 r
.31149 .76779 m .32216 .7621 L .32533 .76614 L p F P
0 g
s
.798 .537 .542 r
.22593 .95382 m .21898 .9522 L .2191 .94677 L p F P
0 g
s
.798 .536 .542 r
.21255 .94522 m .2191 .94677 L .21898 .9522 L p F P
0 g
s
.799 .557 .572 r
.2191 .94677 m .21255 .94522 L .21259 .94172 L p F P
0 g
s
.764 .71 .801 r
.24478 .79328 m .23754 .79916 L .23429 .79469 L p F P
0 g
s
.787 .699 .767 r
.21033 .82421 m .2049 .8298 L .20164 .82494 L p F P
0 g
s
.787 .699 .767 r
.20164 .82494 m .20432 .82218 L .21033 .82421 L p F P
0 g
s
.785 .701 .772 r
.21171 .8148 m .20432 .82218 L .21033 .82421 L p F P
0 g
s
.785 .701 .772 r
.21365 .81547 m .21171 .8148 L p .21033 .82421 L F P
0 g
s
.603 .55 .767 r
.60678 .8202 m .60838 .82432 L .5973 .82616 L p F P
0 g
s
.603 .55 .767 r
.5973 .82616 m .59644 .82396 L .60678 .8202 L p F P
0 g
s
.806 .675 .72 r
.18754 .86975 m .1891 .86754 L .18591 .86161 L p F P
0 g
s
.671 .714 .881 r
.42194 .76111 m .4327 .75721 L .43573 .76105 L p F P
0 g
s
.665 .728 .896 r
.4327 .75721 m .42194 .76111 L .41889 .75733 L p F P
0 g
s
.996 .765 .44 r
.76845 .09727 m .77037 .10145 L .77079 .09678 L p F P
0 g
s
.996 .765 .44 r
.76872 .09436 m .76845 .09727 L p .77079 .09678 L F P
0 g
s
.996 .765 .44 r
.77079 .09678 m .76984 .0947 L .76872 .09436 L p F P
0 g
s
.85 .839 .834 r
.72608 .21926 m .72392 .21677 L .72507 .21561 L closepath p F P
0 g
s
.508 .15 .294 r
.53167 .98136 m .53327 .97727 L .54247 .9757 L p F P
0 g
s
.579 .465 .688 r
.61843 .8928 m .61789 .89059 L .62674 .89001 L closepath p F P
0 g
s
.983 .827 .612 r
.76845 .12063 m .7702 .12483 L .77182 .11969 L p F P
0 g
s
.983 .827 .612 r
.77182 .11969 m .77008 .11548 L .76845 .12063 L p F P
0 g
s
.448 .012 .117 r
.50758 .98489 m .51972 .98322 L .51737 .9867 L p F P
0 g
s
.448 .012 .117 r
.50635 .98689 m .50758 .98489 L p .51737 .9867 L F P
0 g
s
.534 .17 .296 r
.52015 .98228 m .51972 .98322 L .50758 .98489 L p F P
0 g
s
.919 .594 .125 r
.5852 .24245 m .58724 .24645 L .58647 .24212 L p F P
0 g
s
.919 .594 .125 r
.58647 .24212 m .58445 .23811 L .5852 .24245 L p F P
0 g
s
.438 0 0 r
.3406 .99295 m .3414 .99251 L p .35183 .99534 L F P
0 g
s
.57 .066 .017 r
.3406 .99295 m .33906 .99231 L .3414 .99251 L closepath p F P
0 g
s
.769 .455 .455 r
.24949 .96878 m .24854 .96861 L .24905 .96734 L closepath p F P
0 g
s
.927 .854 .75 r
.7615 .15798 m .75947 .16126 L .76089 .16552 L p F P
0 g
s
.917 .852 .763 r
.75547 .16733 m .75691 .17157 L .76089 .16552 L p F P
0 g
s
.917 .852 .763 r
.76089 .16552 m .75947 .16126 L .75547 .16733 L p F P
0 g
s
.635 .622 .82 r
.55215 .77991 m .54119 .7829 L .53828 .77737 L p F P
0 g
s
.889 .85 .798 r
.74292 .19022 m .74772 .18414 L .74903 .1884 L p F P
0 g
s
.889 .85 .798 r
.74903 .1884 m .7454 .193 L .74292 .19022 L p F P
0 g
s
.741 .71 .822 r
.27302 .77916 m .2751 .77778 L .27129 .77684 L closepath p F P
0 g
s
.749 .715 .82 r
.27129 .77684 m .27302 .77916 L p .25907 .7824 L F P
0 g
s
.35 0 0 r
.42389 .99666 m .42131 .99671 L .41265 .99587 L p F P
0 g
s
.342 0 0 r
.42131 .99671 m .41011 .9969 L .41265 .99587 L closepath p F P
0 g
s
.81 .647 .68 r
.18168 .89096 m .18784 .89289 L .18455 .89912 L p F P
0 g
s
.809 .653 .69 r
.18784 .89289 m .18168 .89096 L .18533 .88463 L p F P
0 g
s
.605 .558 .775 r
.60549 .817 m .60678 .8202 L .59644 .82396 L p F P
0 g
s
.605 .558 .775 r
.59644 .82396 m .5944 .81893 L .60549 .817 L p F P
0 g
s
.627 .606 .81 r
.56893 .78873 m .55794 .79145 L .55504 .78558 L p F P
0 g
s
.444 0 0 r
.46756 .99228 m .46484 .99416 L .45406 .99367 L p F P
0 g
s
.211 0 0 r
.45406 .99367 m .46484 .99416 L .46369 .99461 L p F P
0 g
s
.211 0 0 r
.451 .99543 m .45406 .99367 L p .46369 .99461 L F P
0 g
s
.445 0 0 r
.45406 .99367 m .451 .99543 L .44025 .99482 L p F P
0 g
s
.791 .7 .764 r
.20333 .83148 m .2049 .8298 L .20164 .82494 L p F P
0 g
s
.715 .724 .857 r
.32216 .7621 m .31149 .76779 L .3083 .76373 L p F P
0 g
s
.764 .71 .801 r
.23429 .79469 m .23847 .79131 L .24478 .79328 L p F P
0 g
s
.763 .713 .805 r
.24507 .7861 m .23847 .79131 L .24478 .79328 L p F P
0 g
s
.763 .713 .805 r
.24478 .79328 m .24832 .79048 L .24507 .7861 L p F P
0 g
s
.646 .175 .12 r
.29627 .985 m .2966 .9847 L p .30944 .98949 L F P
0 g
s
.694 .269 .235 r
.29627 .985 m .2958 .98459 L .2966 .9847 L closepath p F P
0 g
s
.807 .564 .571 r
.21255 .94522 m .21259 .94172 L .21217 .94513 L closepath p F P
0 g
s
.574 .451 .675 r
.61991 .89951 m .61843 .8928 L .62674 .89001 L p F P
0 g
s
.664 .722 .892 r
.44651 .75722 m .43573 .76105 L .4327 .75721 L p F P
0 g
s
.967 .77 .586 r
.57976 .20511 m .5792 .20734 L .58178 .2112 L p F P
0 g
s
.973 .761 .556 r
.57821 .21228 m .58079 .21614 L .58178 .2112 L p F P
0 g
s
.973 .761 .556 r
.58178 .2112 m .5792 .20734 L .57821 .21228 L p F P
0 g
s
.768 .805 .883 r
.66595 .26481 m .66933 .26257 L .66668 .25942 L p F P
0 g
s
.768 .805 .883 r
.66668 .25942 m .66508 .26047 L .66595 .26481 L p F P
0 g
s
.767 .801 .88 r
.65567 .26659 m .66508 .26047 L .66595 .26481 L p F P
0 g
s
.566 .411 .63 r
.61264 .92195 m .6117 .91574 L .62235 .91245 L p F P
0 g
s
.572 .427 .646 r
.62123 .90608 m .62235 .91245 L .6117 .91574 L p F P
0 g
s
.568 .398 .61 r
.61311 .92584 m .61337 .92797 L .60256 .93106 L p F P
0 g
s
.561 .377 .589 r
.60306 .93688 m .60256 .93106 L .61337 .92797 L p F P
0 g
s
.461 .598 .902 r
.60033 .26781 m .60466 .26817 L .60576 .27245 L p F P
0 g
s
.547 .675 .922 r
.61152 .26774 m .60466 .26817 L .60576 .27245 L p F P
0 g
s
.547 .675 .922 r
.60576 .27245 m .61429 .27162 L .61152 .26774 L p F P
0 g
s
.508 0 0 r
.33906 .99231 m .3406 .99295 L .33726 .99408 L p F P
0 g
s
.508 0 0 r
.33726 .99408 m .32931 .99148 L .33906 .99231 L p F P
0 g
s
.792 .695 .758 r
.19745 .8294 m .20333 .83148 L .19695 .83856 L p F P
0 g
s
.791 .7 .764 r
.20164 .82494 m .19745 .8294 L .20333 .83148 L p F P
0 g
s
.809 .671 .711 r
.18164 .86773 m .18754 .86975 L .18327 .87624 L p F P
0 g
s
.806 .675 .72 r
.18591 .86161 m .18164 .86773 L .18754 .86975 L p F P
0 g
s
.247 0 0 r
.46756 .99228 m .46956 .99211 L p .47652 .99353 L F P
0 g
s
.247 0 0 r
.46484 .99416 m .46756 .99228 L p .47652 .99353 L F P
0 g
s
.344 0 0 r
.43742 .99621 m .43611 .99626 L .42645 .99554 L p F P
0 g
s
.331 0 0 r
.43611 .99626 m .42389 .99666 L .42645 .99554 L closepath p F P
0 g
s
.333 0 0 r
.43742 .99621 m .44025 .99482 L .451 .99543 L p F P
0 g
s
.655 .663 .846 r
.49389 .76738 m .50477 .76382 L .5077 .76856 L p F P
0 g
s
.655 .669 .852 r
.50477 .76382 m .49389 .76738 L .49094 .76275 L p F P
0 g
s
.674 .221 .169 r
.2958 .98459 m .29627 .985 L .29276 .98734 L p F P
0 g
s
.674 .221 .169 r
.29276 .98734 m .28745 .98337 L .2958 .98459 L p F P
0 g
s
.801 .683 .735 r
.18551 .85236 m .19145 .85439 L .18625 .86114 L p F P
0 g
s
.8 .686 .739 r
.19145 .85439 m .18551 .85236 L .191 .84552 L p F P
0 g
s
.667 .689 .861 r
.46376 .76204 m .46332 .76142 L .46037 .76248 L closepath p F P
0 g
s
.668 .696 .867 r
.46033 .75738 m .46332 .76142 L .46037 .76248 L p F P
0 g
s
.668 .696 .867 r
.44952 .76115 m .46033 .75738 L p .46037 .76248 L F P
0 g
s
.737 .714 .83 r
.28051 .76798 m .28373 .77216 L .2751 .77778 L p F P
0 g
s
.737 .714 .83 r
.2698 .77489 m .28051 .76798 L p .2751 .77778 L F P
0 g
s
.737 .714 .83 r
.2751 .77778 m .27129 .77684 L .2698 .77489 L p F P
0 g
s
.757 .713 .811 r
.25577 .78484 m .24832 .79048 L .24507 .7861 L p F P
0 g
s
.643 .64 .832 r
.53538 .77208 m .52445 .7753 L .52153 .77015 L p F P
0 g
s
.962 .841 .677 r
.7668 .13345 m .76823 .13011 L .76991 .13432 L p F P
0 g
s
.962 .841 .677 r
.76991 .13432 m .7692 .13596 L .7668 .13345 L p F P
0 g
s
.94 .849 .725 r
.76149 .15114 m .76306 .15536 L .76617 .14964 L p F P
0 g
s
.94 .849 .725 r
.76617 .14964 m .76463 .1454 L .76149 .15114 L p F P
0 g
s
.796 .513 .508 r
.23101 .96017 m .22643 .9591 L .22593 .95382 L p F P
0 g
s
.797 .513 .506 r
.21898 .9522 m .22593 .95382 L .22643 .9591 L p F P
0 g
s
.398 0 0 r
.47869 .99244 m .46956 .99211 L .48027 .99114 L closepath p F P
0 g
s
.247 0 0 r
.46956 .99211 m .47869 .99244 L .47652 .99353 L p F P
0 g
s
.745 .784 .885 r
.64743 .27147 m .64464 .2731 L .64194 .26972 L p F P
0 g
s
.715 .776 .9 r
.63089 .27514 m .64194 .26972 L .64464 .2731 L p F P
0 g
s
.698 .718 .865 r
.34668 .75606 m .34983 .75976 L .34454 .76221 L p F P
0 g
s
.698 .718 .865 r
.33601 .76076 m .34668 .75606 L p .34454 .76221 L F P
0 g
s
.698 .718 .865 r
.34454 .76221 m .33643 .76129 L .33601 .76076 L p F P
0 g
s
.734 .349 0 r
.76292 .07153 m .76236 .07022 L .75976 .06527 L p F P
0 g
s
.982 .706 .328 r
.7668 .08846 m .76886 .0926 L .76877 .08814 L p F P
0 g
s
.982 .706 .328 r
.76877 .08814 m .76672 .08399 L .7668 .08846 L p F P
0 g
s
.663 .714 .886 r
.46033 .75738 m .44952 .76115 L .44651 .75722 L p F P
0 g
s
.732 .715 .835 r
.29772 .76985 m .29762 .76973 L .29751 .7698 L closepath p F P
0 g
s
.617 .584 .794 r
.58483 .79667 m .58574 .79869 L .5747 .80104 L p F P
0 g
s
.617 .584 .794 r
.5747 .80104 m .57438 .80032 L .58483 .79667 L p F P
0 g
s
.616 .582 .792 r
.5747 .80104 m .58574 .79869 L .58862 .80518 L p F P
0 g
s
.784 .81 .874 r
.67946 .2553 m .66933 .26257 L .66668 .25942 L p F P
0 g
s
.734 .718 .836 r
.28373 .77216 m .29047 .76803 L .29751 .7698 L p F P
0 g
s
.734 .721 .838 r
.29442 .76566 m .29047 .76803 L .29751 .7698 L p F P
0 g
s
.734 .721 .838 r
.29751 .7698 m .29762 .76973 L .29442 .76566 L p F P
0 g
s
.722 .722 .85 r
.3083 .76373 m .29762 .76973 L .29442 .76566 L p F P
0 g
s
.646 .182 .138 r
.30182 .98849 m .29627 .985 L .29276 .98734 L p F P
0 g
s
.646 .175 .12 r
.30944 .98949 m .30182 .98849 L .29627 .985 L p F P
0 g
s
.982 .699 .337 r
.58224 .23416 m .58445 .23811 L .58433 .23356 L p F P
0 g
s
.982 .699 .337 r
.58433 .23356 m .58212 .2296 L .58224 .23416 L p F P
0 g
s
.54 .273 .459 r
.56954 .96293 m .56974 .96126 L .581 .95869 L p F P
0 g
s
.557 .312 .501 r
.58127 .95354 m .581 .95869 L .56974 .96126 L p F P
0 g
s
.884 .85 .805 r
.74382 .19492 m .7454 .193 L .74292 .19022 L p F P
0 g
s
.649 .653 .84 r
.51861 .76516 m .5197 .76699 L .5084 .76973 L p F P
0 g
s
.649 .653 .84 r
.5084 .76973 m .5077 .76856 L .51861 .76516 L p F P
0 g
s
.81 .657 .693 r
.17928 .88267 m .18533 .88463 L .18168 .89096 L p F P
0 g
s
.809 .662 .701 r
.18533 .88463 m .17928 .88267 L .18327 .87624 L p F P
0 g
s
.662 .687 .863 r
.47415 .75772 m .4759 .76018 L .46376 .76204 L p F P
0 g
s
.662 .687 .863 r
.46376 .76204 m .46332 .76142 L .47415 .75772 L p F P
0 g
s
.605 .559 .776 r
.60321 .81139 m .60549 .817 L .5944 .81893 L p F P
0 g
s
.605 .559 .776 r
.5944 .81893 m .59288 .81518 L .60321 .81139 L p F P
0 g
s
.546 .303 .499 r
.581 .95869 m .58127 .95354 L .59239 .9508 L p F P
0 g
s
.56 .338 .536 r
.59237 .9454 m .59239 .9508 L .58127 .95354 L p F P
0 g
s
.619 .592 .801 r
.58285 .79241 m .58483 .79667 L .57438 .80032 L p F P
0 g
s
.619 .592 .801 r
.57438 .80032 m .57182 .79483 L .58285 .79241 L p F P
0 g
s
.512 .146 .282 r
.53167 .98136 m .52469 .98246 L .52015 .98228 L p F P
0 g
s
.506 .128 .258 r
.52469 .98246 m .51972 .98322 L .52015 .98228 L closepath p F P
0 g
s
.795 .691 .75 r
.19695 .83856 m .19386 .84212 L .19061 .83696 L p F P
0 g
s
.795 .691 .75 r
.19061 .83696 m .19099 .83652 L .19695 .83856 L p F P
0 g
s
.792 .695 .758 r
.19695 .83856 m .19099 .83652 L .19745 .8294 L p F P
0 g
s
.76 .412 .395 r
.25953 .975 m .25189 .97359 L .24949 .96878 L p F P
0 g
s
.759 .412 .396 r
.24854 .96861 m .24949 .96878 L .25189 .97359 L p F P
0 g
s
.81 .598 .616 r
.20089 .93036 m .19438 .92858 L .19605 .92276 L p F P
0 g
s
.811 .6 .617 r
.1896 .92096 m .19605 .92276 L .19438 .92858 L p F P
0 g
s
.81 .612 .635 r
.19605 .92276 m .1896 .92096 L .19172 .91502 L p F P
0 g
s
.729 .333 .298 r
.27897 .98219 m .27105 .98085 L .26731 .97638 L p F P
0 g
s
.716 .304 .265 r
.26464 .97595 m .26731 .97638 L .27105 .98085 L p F P
0 g
s
.757 .713 .811 r
.24507 .7861 m .24933 .7829 L .25577 .78484 L p F P
0 g
s
.756 .716 .815 r
.25583 .77813 m .24933 .7829 L .25577 .78484 L p F P
0 g
s
.756 .716 .815 r
.25577 .78484 m .25907 .7824 L .25583 .77813 L p F P
0 g
s
.96 .844 .684 r
.76746 .13979 m .7692 .13596 L .7668 .13345 L p F P
0 g
s
.884 .85 .805 r
.74292 .19022 m .74258 .19064 L .74382 .19492 L p F P
0 g
s
.875 .847 .813 r
.73675 .19739 m .73804 .20164 L .74382 .19492 L p F P
0 g
s
.875 .847 .813 r
.74382 .19492 m .74258 .19064 L .73675 .19739 L p F P
0 g
s
.783 .706 .779 r
.21365 .81547 m .21259 .81396 L .21171 .8148 L closepath p F P
0 g
s
.662 .746 .912 r
.61706 .27547 m .62815 .27158 L .63089 .27514 L p F P
0 g
s
.652 .74 .914 r
.62815 .27158 m .61706 .27547 L .61429 .27162 L p F P
0 g
s
.811 .585 .596 r
.19438 .92858 m .20089 .93036 L .19971 .93606 L p F P
0 g
s
.81 .583 .595 r
.20626 .93782 m .19971 .93606 L .20089 .93036 L p F P
0 g
s
.812 .615 .635 r
.18779 .91388 m .19172 .91502 L .1896 .92096 L p F P
0 g
s
.81 .625 .652 r
.18669 .91004 m .18789 .90714 L p .19172 .91502 L F P
0 g
s
.81 .625 .652 r
.19172 .91502 m .18779 .91388 L .18669 .91004 L p F P
0 g
s
.744 .786 .887 r
.64743 .27147 m .65567 .26659 L .65299 .26331 L p F P
0 g
s
.744 .786 .887 r
.65299 .26331 m .64623 .26724 L .64743 .27147 L p F P
0 g
s
.745 .784 .885 r
.64194 .26972 m .64623 .26724 L .64743 .27147 L p F P
0 g
s
.759 .412 .396 r
.25189 .97359 m .24611 .97253 L .24854 .96861 L p F P
0 g
s
.773 .43 .404 r
.24216 .96727 m .24854 .96861 L .24611 .97253 L p F P
0 g
s
.99 .813 .571 r
.76824 .1113 m .77008 .11548 L .77133 .11048 L p F P
0 g
s
.99 .813 .571 r
.77133 .11048 m .7695 .10629 L .76824 .1113 L p F P
0 g
s
.661 .705 .88 r
.47415 .75772 m .46332 .76142 L .46033 .75738 L p F P
0 g
s
.438 0 0 r
.35183 .99534 m .34936 .99516 L .3406 .99295 L p F P
0 g
s
.451 0 0 r
.34936 .99516 m .3406 .99295 L .33726 .99408 L p F P
0 g
s
.947 .631 .197 r
.76458 .07986 m .76672 .08399 L .76615 .07972 L p F P
0 g
s
.947 .631 .197 r
.76615 .07972 m .76401 .07559 L .76458 .07986 L p F P
0 g
s
.523 .215 .387 r
.55664 .97303 m .55767 .9685 L .56911 .96612 L p F P
0 g
s
.549 .274 .451 r
.56954 .96293 m .56911 .96612 L .55767 .9685 L p F P
0 g
s
.536 .229 .393 r
.55767 .9685 m .55664 .97303 L .54504 .97525 L p F P
0 g
s
.397 0 0 r
.32931 .99148 m .33726 .99408 L .33632 .99422 L p F P
0 g
s
.397 0 0 r
.32565 .99117 m .32931 .99148 L p .33632 .99422 L F P
0 g
s
.953 .768 .616 r
.57694 .20158 m .57789 .19844 L .58061 .20226 L p F P
0 g
s
.953 .768 .616 r
.58061 .20226 m .57976 .20511 L .57694 .20158 L p F P
0 g
s
.65 .662 .848 r
.51861 .76516 m .5077 .76856 L .50477 .76382 L p F P
0 g
s
.799 .693 .747 r
.191 .84552 m .19386 .84212 L .19061 .83696 L p F P
0 g
s
.57 .439 .662 r
.61991 .89951 m .6304 .89601 L p .62502 .90482 L F P
0 g
s
.57 .439 .662 r
.62502 .90482 m .62099 .90485 L .61991 .89951 L p F P
0 g
s
.574 .451 .675 r
.62905 .88994 m .6304 .89601 L .61991 .89951 L p F P
0 g
s
.574 .451 .675 r
.62674 .89001 m .62905 .88994 L p .61991 .89951 L F P
0 g
s
.71 .771 .9 r
.64194 .26972 m .63089 .27514 L .62815 .27158 L p F P
0 g
s
.807 .564 .571 r
.20626 .93782 m .20558 .94339 L .21217 .94513 L p F P
0 g
s
.811 .567 .571 r
.19971 .93606 m .20626 .93782 L .20558 .94339 L p F P
0 g
s
.749 .715 .82 r
.25907 .7824 m .26824 .77596 L .27129 .77684 L p F P
0 g
s
.749 .717 .823 r
.26824 .77596 m .25907 .7824 L .25583 .77813 L p F P
0 g
s
0 .206 .731 r
.74903 .04798 m .75153 .05203 L .74792 .04898 L p F P
0 g
s
0 .206 .731 r
.74792 .04898 m .74542 .04493 L .74903 .04798 L p F P
0 g
s
.909 .85 .773 r
.75121 .17349 m .75547 .16733 L .75691 .17157 L p F P
0 g
s
.909 .85 .773 r
.75144 .17415 m .75121 .17349 L p .75691 .17157 L F P
0 g
s
.909 .85 .773 r
.75691 .17157 m .75352 .17647 L .75144 .17415 L p F P
0 g
s
.813 .627 .651 r
.18669 .91004 m .18789 .90714 L .18566 .90647 L closepath p F P
0 g
s
.81 .636 .666 r
.18374 .90084 m .18455 .89912 L p .18789 .90714 L F P
0 g
s
.81 .636 .666 r
.18789 .90714 m .18566 .90647 L .18374 .90084 L p F P
0 g
s
.608 .568 .784 r
.60259 .80994 m .60321 .81139 L .59288 .81518 L p F P
0 g
s
.608 .568 .784 r
.59288 .81518 m .59151 .81195 L .60259 .80994 L p F P
0 g
s
.805 .677 .723 r
.18591 .86161 m .18625 .86114 L .18551 .86089 L closepath p F P
0 g
s
.801 .683 .735 r
.18268 .85604 m .18551 .85236 L p .18625 .86114 L F P
0 g
s
.801 .683 .735 r
.18625 .86114 m .18551 .86089 L .18268 .85604 L p F P
0 g
s
.747 .717 .823 r
.27129 .77684 m .2698 .77489 L .26824 .77596 L closepath p F P
0 g
s
.55 .33 .535 r
.59239 .9508 m .59237 .9454 L .60333 .9425 L p F P
0 g
s
.561 .359 .565 r
.60306 .93688 m .60333 .9425 L .59237 .9454 L p F P
0 g
s
.781 .469 .46 r
.23101 .96017 m .23351 .96069 L .23486 .96575 L p F P
0 g
s
.781 .469 .46 r
.24216 .96727 m .23486 .96575 L .23351 .96069 L p F P
0 g
s
.808 .678 .72 r
.18164 .86773 m .18591 .86161 L .18551 .86089 L p F P
0 g
s
.424 .582 .905 r
.60466 .26817 m .60033 .26781 L .59751 .26322 L p F P
0 g
s
.995 .757 .429 r
.76984 .0947 m .76872 .09436 L .76886 .0926 L closepath p F P
0 g
s
.716 .304 .265 r
.26217 .97868 m .26464 .97595 L p .27105 .98085 L F P
0 g
s
.745 .36 .325 r
.26217 .97868 m .25953 .975 L .26464 .97595 L closepath p F P
0 g
s
.731 .719 .839 r
.29047 .76803 m .28373 .77216 L .28051 .76798 L p F P
0 g
s
.989 .737 .452 r
.57972 .22569 m .58212 .2296 L .58248 .22488 L p F P
0 g
s
.989 .737 .452 r
.58248 .22488 m .58008 .22097 L .57972 .22569 L p F P
0 g
s
.798 .536 .542 r
.21204 .94966 m .21255 .94522 L p .21898 .9522 L F P
0 g
s
.807 .545 .543 r
.21204 .94966 m .21217 .94513 L .21255 .94522 L closepath p F P
0 g
s
.81 .666 .705 r
.17732 .87424 m .18327 .87624 L .17928 .88267 L p F P
0 g
s
.809 .671 .711 r
.18327 .87624 m .17732 .87424 L .18164 .86773 L p F P
0 g
s
.708 .721 .86 r
.33643 .76129 m .33601 .76076 L .33532 .7611 L closepath p F P
0 g
s
.397 0 0 r
.32353 .99208 m .32565 .99117 L p .33632 .99422 L F P
0 g
s
.562 .04 0 r
.32353 .99208 m .31989 .99055 L .32565 .99117 L closepath p F P
0 g
s
.808 .678 .72 r
.18551 .86089 m .18043 .85908 L p .18164 .86773 L F P
0 g
s
.807 .685 .73 r
.18551 .86089 m .18268 .85604 L .18043 .85908 L closepath p F P
0 g
s
.734 .349 0 r
.75976 .06527 m .76068 .06742 L .76292 .07153 L p F P
0 g
s
.874 .515 .022 r
.76178 .07148 m .76401 .07559 L .76292 .07153 L p F P
0 g
s
.874 .515 .022 r
.76292 .07153 m .76068 .06742 L .76178 .07148 L p F P
0 g
s
.385 0 0 r
.47869 .99244 m .48027 .99114 L .49043 .99011 L p F P
0 g
s
.801 .689 .741 r
.18519 .84344 m .191 .84552 L .18551 .85236 L p F P
0 g
s
.799 .693 .747 r
.19061 .83696 m .18519 .84344 L .191 .84552 L p F P
0 g
s
.777 .71 .789 r
.22019 .79945 m .21391 .80512 L .21989 .80719 L p F P
0 g
s
.777 .71 .789 r
.21989 .80719 m .22346 .80396 L .22019 .79945 L p F P
0 g
s
.779 .708 .784 r
.21989 .80719 m .21259 .81396 L .20931 .80938 L p F P
0 g
s
.779 .708 .784 r
.20931 .80938 m .21391 .80512 L .21989 .80719 L p F P
0 g
s
.81 .548 .542 r
.21217 .94513 m .21204 .94966 L .21193 .95054 L p F P
0 g
s
.81 .548 .542 r
.20558 .94339 m .21217 .94513 L p .21193 .95054 L F P
0 g
s
0 0 .537 r
.75421 .05545 m .75661 .05953 L .75393 .05611 L p F P
0 g
s
0 0 .537 r
.75393 .05611 m .75153 .05203 L .75421 .05545 L p F P
0 g
s
.772 .709 .793 r
.22875 .79938 m .22346 .80396 L .22019 .79945 L p F P
0 g
s
.627 .606 .81 r
.55504 .78558 m .56604 .78285 L .56893 .78873 L p F P
0 g
s
.628 .609 .813 r
.56471 .78019 m .56604 .78285 L .55504 .78558 L p F P
0 g
s
.628 .609 .813 r
.55504 .78558 m .55408 .78366 L .56471 .78019 L p F P
0 g
s
.813 .638 .665 r
.18374 .90084 m .18455 .89912 L .18299 .89864 L closepath p F P
0 g
s
.81 .647 .68 r
.1807 .89284 m .18168 .89096 L p .18455 .89912 L F P
0 g
s
.81 .647 .68 r
.18455 .89912 m .18299 .89864 L .1807 .89284 L p F P
0 g
s
.784 .709 .781 r
.21171 .8148 m .21259 .81396 L .20931 .80938 L p F P
0 g
s
.783 .705 .778 r
.20586 .8127 m .21171 .8148 L .20432 .82218 L p F P
0 g
s
.784 .709 .781 r
.20931 .80938 m .20586 .8127 L .21171 .8148 L p F P
0 g
s
.788 .816 .874 r
.6803 .25469 m .67946 .2553 L .67902 .25318 L closepath p F P
0 g
s
.784 .81 .874 r
.67767 .25158 m .67902 .25318 L .67946 .2553 L p F P
0 g
s
.784 .81 .874 r
.66668 .25942 m .67767 .25158 L p .67946 .2553 L F P
0 g
s
.869 .843 .817 r
.73219 .20252 m .73675 .19739 L .73804 .20164 L p F P
0 g
s
.869 .843 .817 r
.73804 .20164 m .7347 .2054 L .73219 .20252 L p F P
0 g
s
.66 .678 .856 r
.47713 .76195 m .48798 .75828 L .49094 .76275 L p F P
0 g
s
.661 .687 .864 r
.48788 .75813 m .48798 .75828 L .47713 .76195 L p F P
0 g
s
.661 .687 .864 r
.47713 .76195 m .4759 .76018 L .48788 .75813 L p F P
0 g
s
.659 .185 .115 r
.28745 .98337 m .29276 .98734 L .29265 .98739 L p F P
0 g
s
.659 .185 .115 r
.2794 .98226 m .28745 .98337 L p .29265 .98739 L F P
0 g
s
.521 .18 .33 r
.54488 .97576 m .54247 .9757 L .54504 .97525 L closepath p F P
0 g
s
.508 .15 .294 r
.54247 .9757 m .54488 .97576 L p .53167 .98136 L F P
0 g
s
.706 .726 .865 r
.32216 .7621 m .32724 .75964 L .33532 .7611 L p F P
0 g
s
.71 .73 .866 r
.33284 .75698 m .32724 .75964 L .33532 .7611 L p F P
0 g
s
.71 .73 .866 r
.33532 .7611 m .33601 .76076 L .33284 .75698 L p F P
0 g
s
.659 .265 0 r
.75717 .0606 m .75661 .05953 L .75891 .06363 L p F P
0 g
s
.659 .265 0 r
.75891 .06363 m .75976 .06527 L .75717 .0606 L p F P
0 g
s
.681 .733 .89 r
.36365 .75898 m .37434 .75479 L .37746 .75837 L p F P
0 g
s
.672 .745 .905 r
.37434 .75479 m .36365 .75898 L .36051 .75534 L p F P
0 g
s
.635 .622 .82 r
.53828 .77737 m .54925 .77437 L .55215 .77991 L p F P
0 g
s
.636 .627 .824 r
.54835 .7727 m .54925 .77437 L .53828 .77737 L p F P
0 g
s
.636 .627 .824 r
.53828 .77737 m .53752 .77595 L .54835 .7727 L p F P
0 g
s
.681 .741 .897 r
.36051 .75534 m .34983 .75976 L .34668 .75606 L p F P
0 g
s
.799 .818 .866 r
.69075 .24659 m .6803 .25469 L .67902 .25318 L p F P
0 g
s
.772 .709 .793 r
.22019 .79945 m .22262 .79735 L .22875 .79938 L p F P
0 g
s
.771 .712 .797 r
.23102 .79026 m .22262 .79735 L .22875 .79938 L p F P
0 g
s
.771 .712 .797 r
.22875 .79938 m .23429 .79469 L .23102 .79026 L p F P
0 g
s
.54 .273 .459 r
.581 .95869 m .5806 .96219 L .56954 .96293 L p F P
0 g
s
.536 .261 .445 r
.56911 .96612 m .56954 .96293 L .5806 .96219 L p F P
0 g
s
.608 .568 .784 r
.5997 .80313 m .60259 .80994 L .59151 .81195 L p F P
0 g
s
.608 .568 .784 r
.59462 .80405 m .5997 .80313 L p .59151 .81195 L F P
0 g
s
.608 .568 .784 r
.59151 .81195 m .58904 .80611 L .59462 .80405 L p F P
0 g
s
.675 .734 .895 r
.37746 .75837 m .38817 .75438 L .39127 .7579 L p F P
0 g
s
.665 .748 .912 r
.38817 .75438 m .37746 .75837 L .37434 .75479 L p F P
0 g
s
.972 .832 .647 r
.76647 .12592 m .76823 .13011 L .7702 .12483 L p F P
0 g
s
.972 .832 .647 r
.7702 .12483 m .76845 .12063 L .76647 .12592 L p F P
0 g
s
.56 .392 .611 r
.61264 .92195 m .62329 .91866 L p .61849 .9264 L F P
0 g
s
.56 .392 .611 r
.61849 .9264 m .61311 .92584 L .61264 .92195 L p F P
0 g
s
.566 .411 .63 r
.62235 .91245 m .62329 .91866 L .61264 .92195 L p F P
0 g
s
.69 .737 .887 r
.34668 .75606 m .33601 .76076 L .33284 .75698 L p F P
0 g
s
.585 .506 .732 r
.62006 .85741 m .61863 .85292 L .62889 .84908 L p F P
0 g
s
.588 .516 .741 r
.62828 .84726 m .62889 .84908 L .61863 .85292 L p F P
0 g
s
.588 .516 .741 r
.61863 .85292 m .61712 .84841 L .62828 .84726 L p F P
0 g
s
.448 .02 .133 r
.51737 .9867 m .51972 .98322 L .52469 .98246 L p F P
0 g
s
.585 .506 .732 r
.62106 .86056 m .62006 .85741 L .63123 .8564 L p F P
0 g
s
.585 .506 .732 r
.62889 .84908 m .63123 .8564 L .62006 .85741 L p F P
0 g
s
.582 .496 .722 r
.62106 .86056 m .63134 .85676 L p .62665 .86679 L F P
0 g
s
.582 .496 .722 r
.62665 .86679 m .62302 .86707 L .62106 .86056 L p F P
0 g
s
.585 .506 .732 r
.63123 .8564 m .63134 .85676 L .62106 .86056 L p F P
0 g
s
.929 .847 .742 r
.75906 .15525 m .76149 .15114 L .76306 .15536 L p F P
0 g
s
.929 .847 .742 r
.76306 .15536 m .7615 .15798 L .75906 .15525 L p F P
0 g
s
.781 .469 .46 r
.23486 .96575 m .22921 .96458 L .23101 .96017 L p F P
0 g
s
.792 .482 .464 r
.22643 .9591 m .23101 .96017 L .22921 .96458 L p F P
0 g
s
.764 .711 .803 r
.23847 .79131 m .23429 .79469 L .23102 .79026 L p F P
0 g
s
.671 .734 .898 r
.39127 .7579 m .402 .75406 L .40508 .75756 L p F P
0 g
s
.66 .75 .917 r
.402 .75406 m .39127 .7579 L .38817 .75438 L p F P
0 g
s
.788 .701 .768 r
.20164 .82494 m .20432 .82218 L .19838 .82012 L closepath p F P
0 g
s
.783 .705 .778 r
.19837 .82011 m .20586 .8127 L p .20432 .82218 L F P
0 g
s
.783 .705 .778 r
.20432 .82218 m .19838 .82012 L .19837 .82011 L p F P
0 g
s
.588 .516 .742 r
.62624 .84121 m .62828 .84726 L .61712 .84841 L p F P
0 g
s
.588 .516 .742 r
.61712 .84841 m .616 .84508 L .62624 .84121 L p F P
0 g
s
.817 .629 .648 r
.18566 .90647 m .18175 .90523 L p .18544 .91316 L F P
0 g
s
.817 .629 .648 r
.18544 .91316 m .18669 .91004 L .18566 .90647 L p F P
0 g
s
.817 .639 .662 r
.18566 .90647 m .18374 .90084 L .18175 .90523 L closepath p F P
0 g
s
.619 .593 .802 r
.58025 .78684 m .58285 .79241 L .57182 .79483 L p F P
0 g
s
.619 .593 .802 r
.57182 .79483 m .56979 .79051 L .58025 .78684 L p F P
0 g
s
.863 .843 .824 r
.7318 .20853 m .7347 .2054 L .73219 .20252 L p F P
0 g
s
.591 .526 .75 r
.62535 .83868 m .62624 .84121 L .616 .84508 L p F P
0 g
s
.591 .526 .75 r
.616 .84508 m .6142 .83996 L .62535 .83868 L p F P
0 g
s
.96 .844 .684 r
.7668 .13345 m .76584 .13556 L .76746 .13979 L p F P
0 g
s
.947 .845 .709 r
.76299 .14119 m .76463 .1454 L .76746 .13979 L p F P
0 g
s
.947 .845 .709 r
.76746 .13979 m .76584 .13556 L .76299 .14119 L p F P
0 g
s
.582 .496 .722 r
.6233 .86802 m .62302 .86707 L .62665 .86679 L closepath p F P
0 g
s
.995 .792 .517 r
.76758 .10212 m .7695 .10629 L .77037 .10145 L p F P
0 g
s
.995 .792 .517 r
.77037 .10145 m .76845 .09727 L .76758 .10212 L p F P
0 g
s
.792 .701 .764 r
.19745 .8294 m .20164 .82494 L .19838 .82012 L p F P
0 g
s
.817 .628 .648 r
.18779 .91388 m .18669 .91004 L .18544 .91316 L closepath p F P
0 g
s
.817 .64 .662 r
.18175 .90523 m .18374 .90084 L .18299 .89864 L p F P
0 g
s
.705 .719 .861 r
.32216 .7621 m .32724 .75964 L .31923 .75846 L closepath p F P
0 g
s
.715 .724 .857 r
.31923 .75846 m .32216 .7621 L p .3083 .76373 L F P
0 g
s
.578 .484 .711 r
.62535 .87527 m .6233 .86802 L .62665 .86679 L p F P
0 g
s
.667 .732 .898 r
.40508 .75756 m .41582 .75381 L .41889 .75733 L p F P
0 g
s
.657 .749 .918 r
.41582 .75381 m .40508 .75756 L .402 .75406 L p F P
0 g
s
.904 .851 .78 r
.75352 .17647 m .7526 .17775 L .75144 .17415 L closepath p F P
0 g
s
.629 .617 .819 r
.56314 .77714 m .56471 .78019 L .55408 .78366 L p F P
0 g
s
.629 .617 .819 r
.55408 .78366 m .55215 .77991 L .56314 .77714 L p F P
0 g
s
.817 .64 .662 r
.18299 .89864 m .17851 .89717 L p .18175 .90523 L F P
0 g
s
.817 .65 .675 r
.18299 .89864 m .1807 .89284 L .17851 .89717 L closepath p F P
0 g
s
.764 .711 .803 r
.23102 .79026 m .2322 .78932 L .23847 .79131 L p F P
0 g
s
.763 .715 .807 r
.24181 .78176 m .2322 .78932 L .23847 .79131 L p F P
0 g
s
.763 .715 .807 r
.23847 .79131 m .24507 .7861 L .24181 .78176 L p F P
0 g
s
.813 .649 .678 r
.1807 .89284 m .18168 .89096 L .17971 .89033 L closepath p F P
0 g
s
.81 .657 .693 r
.17761 .88558 m .17928 .88267 L p .18168 .89096 L F P
0 g
s
.81 .657 .693 r
.18168 .89096 m .17971 .89033 L .17761 .88558 L p F P
0 g
s
.749 .717 .823 r
.25583 .77813 m .26173 .77403 L .26824 .77596 L p F P
0 g
s
.749 .72 .826 r
.26656 .77075 m .26173 .77403 L .26824 .77596 L p F P
0 g
s
.749 .72 .826 r
.26824 .77596 m .2698 .77489 L .26656 .77075 L p F P
0 g
s
.57 .438 .662 r
.62123 .90608 m .62099 .90485 L .62502 .90482 L closepath p F P
0 g
s
.637 .634 .83 r
.54634 .76905 m .54835 .7727 L .53752 .77595 L p F P
0 g
s
.637 .634 .83 r
.53752 .77595 m .53538 .77208 L .54634 .76905 L p F P
0 g
s
.507 .167 .325 r
.54488 .97576 m .54504 .97525 L .55664 .97303 L p F P
0 g
s
.366 0 0 r
.36692 .99614 m .36005 .99576 L .35432 .99468 L p F P
0 g
s
.376 0 0 r
.36005 .99576 m .35183 .99534 L .35432 .99468 L closepath p F P
0 g
s
.489 0 0 r
.31989 .99055 m .32353 .99208 L .32037 .99277 L p F P
0 g
s
.489 0 0 r
.31055 .9896 m .31989 .99055 L p .32037 .99277 L F P
0 g
s
.598 .105 .053 r
.31989 .99055 m .31055 .9896 L .30985 .98926 L p F P
0 g
s
.812 .615 .635 r
.1896 .92096 m .18939 .9209 L .18779 .91388 L p F P
0 g
s
.819 .619 .632 r
.18544 .91316 m .18779 .91388 L .18939 .9209 L p F P
0 g
s
.551 .352 .564 r
.60333 .9425 m .60306 .93688 L .61388 .93379 L p F P
0 g
s
.561 .377 .589 r
.61337 .92797 m .61388 .93379 L .60306 .93688 L p F P
0 g
s
.863 .843 .824 r
.73219 .20252 m .73058 .20426 L .7318 .20853 L p F P
0 g
s
.856 .84 .829 r
.72378 .21137 m .72507 .21561 L .7318 .20853 L p F P
0 g
s
.856 .84 .829 r
.7318 .20853 m .73058 .20426 L .72378 .21137 L p F P
0 g
s
.797 .513 .506 r
.22643 .9591 m .2195 .95747 L .21898 .9522 L p F P
0 g
s
.797 .512 .505 r
.21202 .95056 m .21898 .9522 L .2195 .95747 L p F P
0 g
s
.798 .536 .542 r
.21898 .9522 m .21202 .95056 L .21204 .94966 L p F P
0 g
s
.96 .76 .589 r
.5792 .20734 m .57976 .20511 L .57694 .20158 L p F P
0 g
s
.643 .64 .832 r
.52153 .77015 m .53246 .76691 L .53538 .77208 L p F P
0 g
s
.644 .646 .837 r
.53077 .76398 m .53246 .76691 L .52153 .77015 L p F P
0 g
s
.644 .646 .837 r
.52153 .77015 m .5197 .76699 L .53077 .76398 L p F P
0 g
s
0 .033 .601 r
.59181 .25404 m .59382 .25804 L .5908 .25451 L p F P
0 g
s
0 .033 .601 r
.5908 .25451 m .5889 .25047 L .59181 .25404 L p F P
0 g
s
.59 .526 .751 r
.62338 .83312 m .62535 .83868 L .6142 .83996 L p F P
0 g
s
.59 .526 .751 r
.6142 .83996 m .61316 .83702 L .62338 .83312 L p F P
0 g
s
.98 .749 .519 r
.5775 .21712 m .58008 .22097 L .58079 .21614 L p F P
0 g
s
.98 .749 .519 r
.58079 .21614 m .57821 .21228 L .5775 .21712 L p F P
0 g
s
.741 .723 .835 r
.28051 .76798 m .2698 .77489 L .26656 .77075 L p F P
0 g
s
.096 .366 .831 r
.5947 .25863 m .59382 .25804 L .59564 .26209 L p F P
0 g
s
.096 .366 .831 r
.59564 .26209 m .59751 .26322 L .5947 .25863 L p F P
0 g
s
.889 .846 .796 r
.7463 .1799 m .74772 .18414 L .7526 .17775 L p F P
0 g
s
.889 .846 .796 r
.75106 .17371 m .7463 .1799 L p .7526 .17775 L F P
0 g
s
.889 .846 .796 r
.7526 .17775 m .75144 .17415 L .75106 .17371 L p F P
0 g
s
.764 .797 .88 r
.66508 .26047 m .65567 .26659 L .65299 .26331 L p F P
0 g
s
.665 .728 .896 r
.41889 .75733 m .42966 .75363 L .4327 .75721 L p F P
0 g
s
.656 .746 .916 r
.42966 .75363 m .41889 .75733 L .41582 .75381 L p F P
0 g
s
.563 .421 .646 r
.62235 .91245 m .62123 .90608 L .62502 .90482 L p F P
0 g
s
.793 .7 .762 r
.19164 .82731 m .19745 .8294 L .19099 .83652 L p F P
0 g
s
.792 .701 .764 r
.19836 .82012 m .19164 .82731 L .19745 .8294 L p F P
0 g
s
.792 .701 .764 r
.19838 .82012 m .19836 .82012 L p .19745 .8294 L F P
0 g
s
.655 .675 .857 r
.50182 .75921 m .49094 .76275 L .48798 .75828 L p F P
0 g
s
.655 .669 .852 r
.49094 .76275 m .50182 .75921 L .50477 .76382 L p F P
0 g
s
.81 .674 .713 r
.1758 .86568 m .18164 .86773 L .17732 .87424 L p F P
0 g
s
.808 .678 .72 r
.18043 .85908 m .1758 .86568 L .18164 .86773 L p F P
0 g
s
.733 .724 .842 r
.2912 .76167 m .28333 .76629 L .29047 .76803 L p F P
0 g
s
.733 .724 .842 r
.29047 .76803 m .29442 .76566 L .2912 .76167 L p F P
0 g
s
.731 .719 .839 r
.28051 .76798 m .28333 .76629 L .29047 .76803 L p F P
0 g
s
.593 .536 .759 r
.62243 .83056 m .62338 .83312 L .61316 .83702 L p F P
0 g
s
.593 .536 .759 r
.61316 .83702 m .61129 .83196 L .62243 .83056 L p F P
0 g
s
.804 .684 .732 r
.18551 .85236 m .18268 .85604 L .17945 .85054 L p F P
0 g
s
.804 .684 .732 r
.17945 .85054 m .17963 .8503 L .18551 .85236 L p F P
0 g
s
.801 .689 .741 r
.18551 .85236 m .17963 .8503 L .18519 .84344 L p F P
0 g
s
.804 .823 .866 r
.69126 .24619 m .69075 .24659 L .69044 .24523 L closepath p F P
0 g
s
.799 .818 .866 r
.68865 .2431 m .69044 .24523 L .69075 .24659 L p F P
0 g
s
.799 .818 .866 r
.67841 .25102 m .68865 .2431 L p .69075 .24659 L F P
0 g
s
.799 .818 .866 r
.67902 .25318 m .67841 .25102 L p .69075 .24659 L F P
0 g
s
.743 .346 .3 r
.25953 .975 m .26217 .97868 L .26147 .9793 L p F P
0 g
s
.743 .346 .3 r
.25189 .97359 m .25953 .975 L p .26147 .9793 L F P
0 g
s
.925 .849 .749 r
.75947 .16126 m .7615 .15798 L .75906 .15525 L p F P
0 g
s
.712 .731 .865 r
.31864 .75833 m .3083 .76373 L .3051 .75975 L p F P
0 g
s
.722 .722 .85 r
.29442 .76566 m .3051 .75975 L .3083 .76373 L p F P
0 g
s
.715 .724 .857 r
.3083 .76373 m .31864 .75833 L .31923 .75846 L p F P
0 g
s
.448 .012 .117 r
.51737 .9867 m .51636 .98685 L .50635 .98689 L p F P
0 g
s
.432 0 .074 r
.51636 .98685 m .50517 .98834 L .50635 .98689 L closepath p F P
0 g
s
.477 .045 .14 r
.50635 .98689 m .50517 .98834 L .49284 .98985 L p F P
0 g
s
.813 .824 .858 r
.70061 .23838 m .69126 .24619 L .69044 .24523 L p F P
0 g
s
.574 .472 .701 r
.62601 .8778 m .62535 .87527 L .63565 .87151 L p F P
0 g
s
.578 .484 .711 r
.63421 .8664 m .63565 .87151 L .62535 .87527 L p F P
0 g
s
.578 .484 .711 r
.62665 .86679 m .63421 .8664 L p .62535 .87527 L F P
0 g
s
.773 .43 .404 r
.24611 .97253 m .2443 .97215 L .24216 .96727 L p F P
0 g
s
.774 .425 .394 r
.23486 .96575 m .24216 .96727 L .2443 .97215 L p F P
0 g
s
.756 .714 .813 r
.24933 .7829 m .24507 .7861 L .24181 .78176 L p F P
0 g
s
.741 .37 0 r
.58681 .24648 m .5889 .25047 L .58724 .24645 L p F P
0 g
s
.741 .37 0 r
.58724 .24645 m .5852 .24245 L .58681 .24648 L p F P
0 g
s
.658 .691 .869 r
.48502 .75416 m .48788 .75813 L .4759 .76018 L p F P
0 g
s
.658 .691 .869 r
.4759 .76018 m .47415 .75772 L .48502 .75416 L p F P
0 g
s
.817 .65 .676 r
.17851 .89717 m .1807 .89284 L .17971 .89033 L p F P
0 g
s
.491 .128 .278 r
.54345 .97932 m .54488 .97576 L .55589 .97523 L p F P
0 g
s
.508 .15 .294 r
.54488 .97576 m .54345 .97932 L .53167 .98136 L p F P
0 g
s
.507 .167 .325 r
.55664 .97303 m .55589 .97523 L .54488 .97576 L p F P
0 g
s
.664 .722 .892 r
.4327 .75721 m .44349 .75354 L .44651 .75722 L p F P
0 g
s
.657 .739 .911 r
.44349 .75354 m .4327 .75721 L .42966 .75363 L p F P
0 g
s
.61 .577 .792 r
.58904 .80611 m .58862 .80518 L .59462 .80405 L closepath p F P
0 g
s
.849 .836 .832 r
.72138 .2138 m .72378 .21137 L .72507 .21561 L p F P
0 g
s
.849 .836 .832 r
.72507 .21561 m .72392 .21677 L .72138 .2138 L p F P
0 g
s
.474 .072 .197 r
.5311 .98239 m .52469 .98246 L .53167 .98136 L closepath p F P
0 g
s
.448 .02 .133 r
.52469 .98246 m .5311 .98239 L p .51737 .9867 L F P
0 g
s
.417 0 .003 r
.49252 .99016 m .49043 .99011 L .49284 .98985 L closepath p F P
0 g
s
.385 0 0 r
.49043 .99011 m .49252 .99016 L p .47869 .99244 L F P
0 g
s
.574 .472 .7 r
.62721 .88236 m .62601 .8778 L .63722 .87742 L p F P
0 g
s
.574 .472 .701 r
.63565 .87151 m .63722 .87742 L .62601 .8778 L p F P
0 g
s
.843 .835 .839 r
.71757 .22297 m .72392 .21677 L .72138 .2138 L p F P
0 g
s
.813 .659 .691 r
.17761 .88558 m .17928 .88267 L .17578 .88151 L closepath p F P
0 g
s
.81 .666 .705 r
.17446 .87882 m .17732 .87424 L p .17928 .88267 L F P
0 g
s
.81 .666 .705 r
.17928 .88267 m .17578 .88151 L .17446 .87882 L p F P
0 g
s
.593 .536 .76 r
.62029 .8248 m .62243 .83056 L .61129 .83196 L p F P
0 g
s
.593 .536 .76 r
.61129 .83196 m .61009 .82874 L .62029 .8248 L p F P
0 g
s
.817 .65 .676 r
.17971 .89033 m .17572 .88898 L p .17851 .89717 L F P
0 g
s
.816 .659 .688 r
.17971 .89033 m .17761 .88558 L .17572 .88898 L closepath p F P
0 g
s
.61 .579 .793 r
.59462 .80405 m .58862 .80518 L .58574 .79869 L p F P
0 g
s
.598 .103 .049 r
.31055 .9896 m .30944 .98949 L .30985 .98926 L closepath p F P
0 g
s
.811 .6 .617 r
.18947 .9214 m .1896 .92096 L p .19438 .92858 L F P
0 g
s
.814 .602 .616 r
.18947 .9214 m .1896 .92096 L .18939 .9209 L closepath p F P
0 g
s
.817 .828 .858 r
.70061 .23838 m .70218 .23705 L .6996 .23404 L p F P
0 g
s
.817 .828 .858 r
.6996 .23404 m .69954 .23408 L .70061 .23838 L p F P
0 g
s
.813 .824 .858 r
.6896 .24233 m .69954 .23408 L .70061 .23838 L p F P
0 g
s
.813 .824 .858 r
.69044 .24523 m .6896 .24233 L p .70061 .23838 L F P
0 g
s
.756 .714 .813 r
.24181 .78176 m .24291 .78095 L .24933 .7829 L p F P
0 g
s
.756 .718 .817 r
.25257 .77391 m .24291 .78095 L .24933 .7829 L p F P
0 g
s
.756 .718 .817 r
.24933 .7829 m .25583 .77813 L .25257 .77391 L p F P
0 g
s
.995 .754 .434 r
.76644 .09311 m .7668 .08846 L .76886 .0926 L p F P
0 g
s
.995 .754 .434 r
.76656 .09334 m .76644 .09311 L p .76886 .0926 L F P
0 g
s
.995 .754 .434 r
.76886 .0926 m .76872 .09436 L .76656 .09334 L p F P
0 g
s
.811 .585 .596 r
.19971 .93606 m .19317 .93428 L .19438 .92858 L p F P
0 g
s
.813 .587 .596 r
.19043 .92748 m .19438 .92858 L .19317 .93428 L p F P
0 g
s
.811 .6 .617 r
.19438 .92858 m .19043 .92748 L .18947 .9214 L p F P
0 g
s
.826 .829 .85 r
.70946 .23054 m .70218 .23705 L .6996 .23404 L p F P
0 g
s
.659 .185 .115 r
.27921 .98242 m .2794 .98226 L p .29265 .98739 L F P
0 g
s
.707 .281 .234 r
.27921 .98242 m .27897 .98219 L .2794 .98226 L closepath p F P
0 g
s
.843 .835 .839 r
.72138 .2138 m .71634 .21871 L .71757 .22297 L p F P
0 g
s
.838 .833 .841 r
.71051 .22426 m .71634 .21871 L .71757 .22297 L p F P
0 g
s
.838 .833 .841 r
.71757 .22297 m .71307 .22725 L .71051 .22426 L p F P
0 g
s
.819 .605 .614 r
.18939 .9209 m .18343 .91906 L p .188 .92675 L F P
0 g
s
.819 .605 .614 r
.188 .92675 m .18947 .9214 L .18939 .9209 L p F P
0 g
s
.819 .619 .632 r
.18939 .9209 m .18343 .91906 L .18544 .91316 L p F P
0 g
s
.746 .354 0 r
.76068 .06742 m .75976 .06527 L .75717 .0606 L p F P
0 g
s
.621 .601 .809 r
.57996 .78624 m .58025 .78684 L .56979 .79051 L p F P
0 g
s
.621 .601 .809 r
.56979 .79051 m .56893 .78873 L .57996 .78624 L p F P
0 g
s
.797 .694 .752 r
.19061 .83696 m .19099 .83652 L .19013 .83621 L closepath p F P
0 g
s
.793 .7 .762 r
.18733 .83205 m .19164 .82731 L p .19099 .83652 L F P
0 g
s
.793 .7 .762 r
.19099 .83652 m .19013 .83621 L .18733 .83205 L p F P
0 g
s
.808 .686 .73 r
.18043 .85908 m .18268 .85604 L .17945 .85054 L p F P
0 g
s
.56 .392 .611 r
.61337 .92797 m .61311 .92584 L .61849 .9264 L closepath p F P
0 g
s
.801 .695 .748 r
.18519 .84344 m .19061 .83696 L .19013 .83621 L p F P
0 g
s
.663 .714 .886 r
.44651 .75722 m .45733 .75357 L .46033 .75738 L p F P
0 g
s
.658 .73 .903 r
.45733 .75357 m .44651 .75722 L .44349 .75354 L p F P
0 g
s
.689 .235 .17 r
.27897 .98219 m .27921 .98242 L .27566 .9846 L p F P
0 g
s
.689 .235 .17 r
.27566 .9846 m .27105 .98085 L .27897 .98219 L p F P
0 g
s
.831 .832 .848 r
.70946 .23054 m .71307 .22725 L .71051 .22426 L p F P
0 g
s
.831 .832 .848 r
.71051 .22426 m .70831 .22626 L .70946 .23054 L p F P
0 g
s
.826 .829 .85 r
.6996 .23404 m .70831 .22626 L .70946 .23054 L p F P
0 g
s
.821 .621 .633 r
.17935 .91123 m .18544 .91316 L .18343 .91906 L p F P
0 g
s
.817 .629 .648 r
.18175 .90523 m .17935 .91123 L .18544 .91316 L p F P
0 g
s
.721 .726 .854 r
.3051 .75975 m .29442 .76566 L .2912 .76167 L p F P
0 g
s
.98 .822 .615 r
.7666 .11645 m .76845 .12063 L .77008 .11548 L p F P
0 g
s
.98 .822 .615 r
.77008 .11548 m .76824 .1113 L .7666 .11645 L p F P
0 g
s
.398 0 0 r
.49252 .99016 m .49284 .98985 L .50517 .98834 L p F P
0 g
s
.818 .605 .614 r
.19043 .92748 m .18947 .9214 L .188 .92675 L closepath p F P
0 g
s
.307 0 0 r
.37102 .99628 m .36692 .99614 L .36808 .99588 L closepath p F P
0 g
s
.299 0 0 r
.38168 .99668 m .37102 .99628 L .36808 .99588 L p F P
0 g
s
.596 .545 .768 r
.61952 .82281 m .62029 .8248 L .61009 .82874 L p F P
0 g
s
.596 .545 .768 r
.61009 .82874 m .60838 .82432 L .61952 .82281 L p F P
0 g
s
.935 .604 .162 r
.58297 .2385 m .5852 .24245 L .58445 .23811 L p F P
0 g
s
.935 .604 .162 r
.58445 .23811 m .58224 .23416 L .58297 .2385 L p F P
0 g
s
.792 .482 .464 r
.22921 .96458 m .22762 .96421 L .22643 .9591 L p F P
0 g
s
.795 .482 .459 r
.2195 .95747 m .22643 .9591 L .22762 .96421 L p F P
0 g
s
.702 .723 .866 r
.32965 .75333 m .33284 .75698 L .32724 .75964 L p F P
0 g
s
.702 .723 .866 r
.31898 .75816 m .32965 .75333 L p .32724 .75964 L F P
0 g
s
.702 .723 .866 r
.32724 .75964 m .31923 .75846 L .31898 .75816 L p F P
0 g
s
.811 .567 .571 r
.20558 .94339 m .19901 .94163 L .19971 .93606 L p F P
0 g
s
.811 .568 .571 r
.19317 .93428 m .19971 .93606 L .19901 .94163 L p F P
0 g
s
.57 .461 .69 r
.62891 .88928 m .62721 .88236 L .63754 .87863 L p F P
0 g
s
.579 .466 .688 r
.62721 .88236 m .62891 .88928 L .62674 .89001 L p F P
0 g
s
.574 .472 .7 r
.63722 .87742 m .63754 .87863 L .62721 .88236 L p F P
0 g
s
.96 .76 .589 r
.57694 .20158 m .57646 .20353 L .5792 .20734 L p F P
0 g
s
.967 .752 .56 r
.57546 .20846 m .57821 .21228 L .5792 .20734 L p F P
0 g
s
.967 .752 .56 r
.5792 .20734 m .57646 .20353 L .57546 .20846 L p F P
0 g
s
.573 .451 .675 r
.62905 .88994 m .62674 .89001 L .62891 .88928 L closepath p F P
0 g
s
.925 .849 .749 r
.75906 .15525 m .75797 .15703 L .75947 .16126 L p F P
0 g
s
.914 .847 .763 r
.75394 .16311 m .75547 .16733 L .75947 .16126 L p F P
0 g
s
.914 .847 .763 r
.75947 .16126 m .75797 .15703 L .75394 .16311 L p F P
0 g
s
.63 .619 .821 r
.56314 .77714 m .55215 .77991 L .54925 .77437 L p F P
0 g
s
.659 .185 .115 r
.29265 .98739 m .28471 .98616 L .27921 .98242 L p F P
0 g
s
.659 .193 .137 r
.28471 .98616 m .27921 .98242 L .27566 .9846 L p F P
0 g
s
.65 .662 .848 r
.50477 .76382 m .51568 .76042 L .51861 .76516 L p F P
0 g
s
.651 .668 .854 r
.51568 .76042 m .50477 .76382 L .50182 .75921 L p F P
0 g
s
.801 .695 .748 r
.19013 .83621 m .18527 .8344 L p .18519 .84344 L F P
0 g
s
.799 .701 .757 r
.19013 .83621 m .18733 .83205 L .18527 .8344 L closepath p F P
0 g
s
.82 .633 .649 r
.17574 .90327 m .18175 .90523 L .17935 .91123 L p F P
0 g
s
.817 .64 .662 r
.17851 .89717 m .17574 .90327 L .18175 .90523 L p F P
0 g
s
.888 .845 .796 r
.74116 .1864 m .7463 .1799 L .74772 .18414 L p F P
0 g
s
.888 .845 .796 r
.74217 .18937 m .74116 .1864 L p .74772 .18414 L F P
0 g
s
.888 .845 .796 r
.74772 .18414 m .74292 .19022 L .74217 .18937 L p F P
0 g
s
.794 .814 .867 r
.67902 .25318 m .67767 .25158 L .67841 .25102 L closepath p F P
0 g
s
.489 0 0 r
.32037 .99277 m .31979 .99271 L .31055 .9896 L p F P
0 g
s
.373 0 0 r
.30944 .98949 m .31055 .9896 L .31979 .99271 L p F P
0 g
s
.577 .484 .712 r
.63421 .8664 m .62665 .86679 L .63359 .86423 L closepath p F P
0 g
s
.582 .496 .722 r
.63134 .85676 m .63359 .86423 L .62665 .86679 L p F P
0 g
s
.621 .604 .812 r
.57996 .78624 m .56893 .78873 L .56604 .78285 L p F P
0 g
s
.808 .686 .73 r
.17945 .85054 m .17469 .85699 L .18043 .85908 L p F P
0 g
s
.81 .682 .723 r
.17469 .85699 m .18043 .85908 L .1758 .86568 L p F P
0 g
s
.658 .72 .894 r
.47117 .75376 m .46033 .75738 L .45733 .75357 L p F P
0 g
s
.661 .705 .88 r
.46033 .75738 m .47117 .75376 L .47415 .75772 L p F P
0 g
s
.373 0 0 r
.30643 .99051 m .30944 .98949 L p .31979 .99271 L F P
0 g
s
.561 .028 0 r
.30643 .99051 m .30182 .98849 L .30944 .98949 L closepath p F P
0 g
s
.645 .652 .843 r
.52955 .76193 m .53077 .76398 L .5197 .76699 L p F P
0 g
s
.645 .652 .843 r
.5197 .76699 m .51861 .76516 L .52955 .76193 L p F P
0 g
s
.748 .719 .825 r
.26173 .77403 m .25583 .77813 L .25257 .77391 L p F P
0 g
s
.817 .66 .688 r
.17572 .88898 m .17761 .88558 L .17578 .88151 L p F P
0 g
s
.638 .638 .834 r
.54634 .76905 m .53538 .77208 L .53246 .76691 L p F P
0 g
s
.808 .819 .86 r
.69044 .24523 m .68865 .2431 L .6896 .24233 L closepath p F P
0 g
s
.81 .548 .542 r
.21193 .95054 m .20543 .94882 L .20558 .94339 L p F P
0 g
s
.811 .548 .541 r
.19901 .94163 m .20558 .94339 L .20543 .94882 L p F P
0 g
s
.596 .546 .769 r
.61697 .81623 m .61952 .82281 L .60838 .82432 L p F P
0 g
s
.596 .546 .769 r
.60838 .82432 m .60678 .8202 L .61697 .81623 L p F P
0 g
s
.96 .836 .676 r
.76437 .13081 m .76647 .12592 L .76823 .13011 L p F P
0 g
s
.96 .836 .676 r
.76823 .13011 m .7668 .13345 L .76437 .13081 L p F P
0 g
s
.528 .261 .454 r
.5806 .96219 m .581 .95869 L .59213 .95596 L p F P
0 g
s
.546 .303 .499 r
.59239 .9508 m .59213 .95596 L .581 .95869 L p F P
0 g
s
.741 .781 .885 r
.64623 .26724 m .64194 .26972 L .63923 .26628 L p F P
0 g
s
.71 .771 .9 r
.62815 .27158 m .63923 .26628 L .64194 .26972 L p F P
0 g
s
.424 .582 .905 r
.59751 .26322 m .60321 .264 L .60466 .26817 L p F P
0 g
s
.528 .665 .924 r
.60874 .26383 m .60321 .264 L .60466 .26817 L p F P
0 g
s
.528 .665 .924 r
.60466 .26817 m .61152 .26774 L .60874 .26383 L p F P
0 g
s
.398 0 0 r
.50517 .98834 m .50342 .98982 L .49252 .99016 L p F P
0 g
s
.183 0 0 r
.49252 .99016 m .50342 .98982 L .50155 .99078 L p F P
0 g
s
.183 0 0 r
.48956 .99213 m .49252 .99016 L p .50155 .99078 L F P
0 g
s
.385 0 0 r
.49252 .99016 m .48956 .99213 L .47869 .99244 L p F P
0 g
s
.937 .843 .725 r
.75983 .14694 m .76149 .15114 L .76463 .1454 L p F P
0 g
s
.937 .843 .725 r
.76463 .1454 m .76299 .14119 L .75983 .14694 L p F P
0 g
s
.551 .369 .588 r
.61388 .93379 m .61337 .92797 L .61849 .9264 L p F P
0 g
s
.768 .804 .882 r
.66668 .25942 m .66508 .26047 L .66421 .25645 L closepath p F P
0 g
s
.764 .797 .88 r
.66402 .25622 m .66421 .25645 L .66508 .26047 L p F P
0 g
s
.764 .797 .88 r
.65299 .26331 m .66402 .25622 L p .66508 .26047 L F P
0 g
s
.983 .705 .338 r
.76466 .08433 m .7668 .08846 L .76672 .08399 L p F P
0 g
s
.983 .705 .338 r
.76672 .08399 m .76458 .07986 L .76466 .08433 L p F P
0 g
s
.813 .667 .702 r
.17732 .87424 m .17446 .87882 L .17129 .87242 L p F P
0 g
s
.813 .667 .702 r
.17129 .87242 m .17142 .87221 L .17732 .87424 L p F P
0 g
s
.81 .674 .713 r
.17732 .87424 m .17142 .87221 L .1758 .86568 L p F P
0 g
s
.801 .539 .542 r
.21202 .95056 m .21193 .95054 L .21204 .94966 L closepath p F P
0 g
s
.778 .712 .79 r
.21658 .79528 m .20798 .80303 L .21391 .80512 L p F P
0 g
s
.778 .712 .79 r
.21733 .79556 m .21658 .79528 L p .21391 .80512 L F P
0 g
s
.778 .712 .79 r
.21391 .80512 m .22019 .79945 L .21733 .79556 L p F P
0 g
s
.78 .71 .786 r
.21391 .80512 m .20931 .80938 L .20602 .80484 L p F P
0 g
s
.78 .71 .786 r
.20602 .80484 m .20798 .80303 L .21391 .80512 L p F P
0 g
s
.785 .711 .781 r
.20586 .8127 m .20931 .80938 L .20602 .80484 L p F P
0 g
s
.239 0 0 r
.39567 .997 m .39605 .99692 L .40755 .99691 L p F P
0 g
s
.269 0 0 r
.39567 .997 m .3946 .9969 L .39605 .99692 L closepath p F P
0 g
s
.82 .644 .664 r
.17258 .89517 m .17851 .89717 L .17574 .90327 L p F P
0 g
s
.817 .65 .676 r
.17572 .88898 m .17258 .89517 L .17851 .89717 L p F P
0 g
s
.239 0 0 r
.40755 .99691 m .40949 .99705 L p .39567 .997 L F P
0 g
s
.24 0 0 r
.40949 .99705 m .40755 .99691 L .41011 .9969 L closepath p F P
0 g
s
.731 .718 .838 r
.28051 .76798 m .28333 .76629 L .27822 .76507 L closepath p F P
0 g
s
.741 .723 .835 r
.27822 .76507 m .28051 .76798 L p .26656 .77075 L F P
0 g
s
.213 0 0 r
.40949 .99705 m .41011 .9969 L .42131 .99671 L p F P
0 g
s
.773 .711 .794 r
.22019 .79945 m .22262 .79735 L .21733 .79556 L closepath p F P
0 g
s
.4 0 0 r
.38187 .99665 m .38239 .9967 L .3946 .9969 L p F P
0 g
s
.246 0 0 r
.38239 .9967 m .38168 .99668 L .38187 .99665 L closepath p F P
0 g
s
.802 .693 .746 r
.17944 .84134 m .18519 .84344 L .17963 .8503 L p F P
0 g
s
.801 .695 .748 r
.18527 .8344 m .17944 .84134 L .18519 .84344 L p F P
0 g
s
.57 .439 .662 r
.6304 .89601 m .63173 .90258 L .62502 .90482 L p F P
0 g
s
.563 .422 .647 r
.6322 .90522 m .62502 .90482 L .63173 .90258 L closepath p F P
0 g
s
.563 .421 .646 r
.62502 .90482 m .6322 .90522 L p .62235 .91245 L F P
0 g
s
.098 0 0 r
.3946 .9969 m .39567 .997 L .39249 .99712 L p F P
0 g
s
.098 0 0 r
.39249 .99712 m .38239 .9967 L .3946 .9969 L p F P
0 g
s
.983 .695 .357 r
.57983 .23025 m .58224 .23416 L .58212 .2296 L p F P
0 g
s
.983 .695 .357 r
.58212 .2296 m .57972 .22569 L .57983 .23025 L p F P
0 g
s
.996 .759 .441 r
.76872 .09436 m .76845 .09727 L .76656 .09334 L closepath p F P
0 g
s
.652 .74 .914 r
.61429 .27162 m .62541 .26798 L .62815 .27158 L p F P
0 g
s
.643 .734 .915 r
.62541 .26798 m .61429 .27162 L .61152 .26774 L p F P
0 g
s
.387 .566 .907 r
.60321 .264 m .59751 .26322 L .5947 .25863 L p F P
0 g
s
.788 .709 .777 r
.20586 .8127 m .19837 .82011 L .19507 .81552 L p F P
0 g
s
.788 .709 .777 r
.19507 .81552 m .20007 .81057 L .20586 .8127 L p F P
0 g
s
.785 .711 .781 r
.20602 .80484 m .20007 .81057 L .20586 .8127 L p F P
0 g
s
.557 .405 .63 r
.62329 .91866 m .62235 .91245 L .63287 .90897 L p F P
0 g
s
.563 .421 .646 r
.6322 .90522 m .63287 .90897 L .62235 .91245 L p F P
0 g
s
.768 .715 .803 r
.22971 .78851 m .23102 .79026 L .22262 .79735 L p F P
0 g
s
.768 .715 .803 r
.22617 .78724 m .22971 .78851 L p .22262 .79735 L F P
0 g
s
.768 .715 .803 r
.21691 .795 m .22617 .78724 L p .22262 .79735 L F P
0 g
s
.768 .715 .803 r
.22262 .79735 m .21733 .79556 L .21691 .795 L p F P
0 g
s
.535 .294 .497 r
.59213 .95596 m .59239 .9508 L .60337 .9479 L p F P
0 g
s
.55 .33 .535 r
.60333 .9425 m .60337 .9479 L .59239 .9508 L p F P
0 g
s
.788 .808 .869 r
.67503 .24838 m .67767 .25158 L .66668 .25942 L p F P
0 g
s
.788 .808 .869 r
.66411 .25615 m .67503 .24838 L p .66668 .25942 L F P
0 g
s
.788 .808 .869 r
.66668 .25942 m .66421 .25645 L .66411 .25615 L p F P
0 g
s
.509 .201 .38 r
.56809 .97064 m .56911 .96612 L .58041 .96357 L p F P
0 g
s
.536 .261 .445 r
.5806 .96219 m .58041 .96357 L .56911 .96612 L p F P
0 g
s
.523 .215 .387 r
.56911 .96612 m .56809 .97064 L .55664 .97303 L p F P
0 g
s
.657 .708 .885 r
.48502 .75416 m .47415 .75772 L .47117 .75376 L p F P
0 g
s
.225 0 0 r
.42332 .99681 m .42131 .99671 L .42389 .99666 L closepath p F P
0 g
s
.213 0 0 r
.42131 .99671 m .42332 .99681 L p .40949 .99705 L F P
0 g
s
.564 .445 .676 r
.62905 .88994 m .62891 .88928 L .63923 .88555 L p F P
0 g
s
.57 .461 .69 r
.63754 .87863 m .63923 .88555 L .62891 .88928 L p F P
0 g
s
.459 .057 .19 r
.5311 .98239 m .53167 .98136 L .54345 .97932 L p F P
0 g
s
.599 .555 .777 r
.61662 .81537 m .61697 .81623 L .60678 .8202 L p F P
0 g
s
.599 .555 .777 r
.60678 .8202 m .60549 .817 L .61662 .81537 L p F P
0 g
s
.104 0 0 r
.38239 .9967 m .39249 .99712 L p .37865 .99685 L F P
0 g
s
.104 0 0 r
.37865 .99685 m .38168 .99668 L .38239 .9967 L p F P
0 g
s
.144 0 0 r
.37865 .99685 m .37102 .99628 L .38168 .99668 L closepath p F P
0 g
s
.201 0 0 r
.42332 .99681 m .42389 .99666 L .43611 .99626 L p F P
0 g
s
.79 .707 .772 r
.19838 .82012 m .19837 .82011 L .19836 .82012 L closepath p F P
0 g
s
.565 .445 .675 r
.6304 .89601 m .62905 .88994 L .6403 .89027 L p F P
0 g
s
.564 .445 .676 r
.63923 .88555 m .6403 .89027 L .62905 .88994 L p F P
0 g
s
.792 .71 .774 r
.19836 .82012 m .19837 .82011 L .19507 .81552 L p F P
0 g
s
.794 .705 .767 r
.19269 .81796 m .19836 .82012 L .19164 .82731 L p F P
0 g
s
.792 .71 .774 r
.19507 .81552 m .19269 .81796 L .19836 .82012 L p F P
0 g
s
.817 .66 .688 r
.17578 .88151 m .17336 .88066 L p .17572 .88898 L F P
0 g
s
.816 .668 .7 r
.17578 .88151 m .17446 .87882 L .17336 .88066 L closepath p F P
0 g
s
.797 .512 .505 r
.2195 .95747 m .21254 .95583 L .21202 .95056 L p F P
0 g
s
.799 .513 .505 r
.21193 .95054 m .21202 .95056 L .21254 .95583 L p F P
0 g
s
.743 .346 .3 r
.26147 .9793 m .25539 .97812 L .25189 .97359 L p F P
0 g
s
.735 .329 .278 r
.24611 .97253 m .25189 .97359 L .25539 .97812 L p F P
0 g
s
.61 .579 .793 r
.58574 .79869 m .59682 .79661 L p .59462 .80405 L F P
0 g
s
.61 .58 .795 r
.59511 .79279 m .59682 .79661 L .58574 .79869 L p F P
0 g
s
.61 .58 .795 r
.58574 .79869 m .58483 .79667 L .59511 .79279 L p F P
0 g
s
.748 .719 .825 r
.25257 .77391 m .2552 .7721 L .26173 .77403 L p F P
0 g
s
.748 .723 .828 r
.26331 .76665 m .2552 .7721 L .26173 .77403 L p F P
0 g
s
.748 .723 .828 r
.26173 .77403 m .26656 .77075 L .26331 .76665 L p F P
0 g
s
.765 .713 .804 r
.23102 .79026 m .2322 .78932 L .22971 .78851 L closepath p F P
0 g
s
.799 .513 .505 r
.21254 .95583 m .21068 .95539 L .21193 .95054 L p F P
0 g
s
.809 .524 .506 r
.20543 .94882 m .21193 .95054 L .21068 .95539 L p F P
0 g
s
.813 .587 .596 r
.19317 .93428 m .19095 .93367 L .19043 .92748 L p F P
0 g
s
.82 .592 .594 r
.188 .92675 m .19043 .92748 L .19095 .93367 L p F P
0 g
s
.987 .808 .575 r
.76631 .10713 m .76824 .1113 L .7695 .10629 L p F P
0 g
s
.987 .808 .575 r
.7695 .10629 m .76758 .10212 L .76631 .10713 L p F P
0 g
s
.952 .632 .209 r
.76234 .07575 m .76458 .07986 L .76401 .07559 L p F P
0 g
s
.952 .632 .209 r
.76401 .07559 m .76178 .07148 L .76234 .07575 L p F P
0 g
s
.882 .846 .803 r
.74292 .19022 m .74258 .19064 L .74217 .18937 L closepath p F P
0 g
s
.705 .768 .901 r
.63923 .26628 m .62815 .27158 L .62541 .26798 L p F P
0 g
s
.761 .718 .812 r
.24065 .78024 m .24181 .78176 L .2322 .78932 L p F P
0 g
s
.761 .718 .812 r
.23679 .7789 m .24065 .78024 L p .2322 .78932 L F P
0 g
s
.761 .718 .812 r
.22774 .78596 m .23679 .7789 L p .2322 .78932 L F P
0 g
s
.761 .718 .812 r
.2322 .78932 m .22971 .78851 L .22774 .78596 L p F P
0 g
s
.727 .721 .845 r
.28797 .75773 m .2912 .76167 L .28333 .76629 L p F P
0 g
s
.727 .721 .845 r
.27728 .76389 m .28797 .75773 L p .28333 .76629 L F P
0 g
s
.727 .721 .845 r
.28333 .76629 m .27822 .76507 L .27728 .76389 L p F P
0 g
s
.645 .66 .85 r
.52955 .76193 m .51861 .76516 L .51568 .76042 L p F P
0 g
s
.868 .84 .816 r
.73535 .19315 m .73675 .19739 L .74258 .19064 L p F P
0 g
s
.868 .84 .816 r
.74042 .18729 m .73535 .19315 L p .74258 .19064 L F P
0 g
s
.868 .84 .816 r
.74258 .19064 m .74217 .18937 L .74042 .18729 L p F P
0 g
s
.239 0 0 r
.40949 .99705 m .40634 .99714 L .39567 .997 L p F P
0 g
s
.216 .725 .892 r
.40634 .99714 m .39567 .997 L .39249 .99712 L p F P
0 g
s
.254 0 0 r
.47652 .99353 m .47869 .99244 L .48956 .99213 L p F P
0 g
s
.681 .741 .897 r
.34668 .75606 m .35736 .7519 L .36051 .75534 L p F P
0 g
s
.67 .753 .913 r
.35736 .7519 m .34668 .75606 L .34351 .7525 L p F P
0 g
s
.69 .737 .887 r
.33284 .75698 m .34351 .7525 L .34668 .75606 L p F P
0 g
s
.774 .425 .394 r
.2443 .97215 m .23708 .9706 L .23486 .96575 L p F P
0 g
s
.771 .416 .384 r
.22921 .96458 m .23486 .96575 L .23708 .9706 L p F P
0 g
s
.672 .745 .905 r
.36051 .75534 m .37121 .75145 L .37434 .75479 L p F P
0 g
s
.658 .76 .925 r
.37121 .75145 m .36051 .75534 L .35736 .7519 L p F P
0 g
s
.82 .655 .678 r
.16988 .88695 m .17572 .88898 L .17258 .89517 L p F P
0 g
s
.817 .66 .688 r
.17336 .88066 m .16988 .88695 L .17572 .88898 L p F P
0 g
s
.74 .784 .888 r
.64623 .26724 m .65299 .26331 L .65029 .25998 L p F P
0 g
s
.74 .784 .888 r
.65029 .25998 m .64496 .26303 L .64623 .26724 L p F P
0 g
s
.741 .781 .885 r
.63923 .26628 m .64496 .26303 L .64623 .26724 L p F P
0 g
s
.714 .726 .86 r
.31923 .75846 m .31898 .75816 L .31864 .75833 L closepath p F P
0 g
s
.682 .747 .9 r
.34351 .7525 m .33284 .75698 L .32965 .75333 L p F P
0 g
s
.665 .748 .912 r
.37434 .75479 m .38505 .75112 L .38817 .75438 L p F P
0 g
s
.647 .766 .935 r
.38505 .75112 m .37434 .75479 L .37121 .75145 L p F P
0 g
s
.599 .556 .777 r
.61373 .80825 m .61662 .81537 L .60549 .817 L p F P
0 g
s
.599 .556 .777 r
.60972 .80883 m .61373 .80825 L p .60549 .817 L F P
0 g
s
.599 .556 .777 r
.60549 .817 m .60321 .81139 L .60972 .80883 L p F P
0 g
s
.906 .844 .772 r
.74965 .16929 m .75121 .17349 L .75547 .16733 L p F P
0 g
s
.906 .844 .772 r
.75547 .16733 m .75394 .16311 L .74965 .16929 L p F P
0 g
s
.397 0 0 r
.33632 .99422 m .32953 .99356 L .32353 .99208 L p F P
0 g
s
.413 0 0 r
.32953 .99356 m .32037 .99277 L .32353 .99208 L closepath p F P
0 g
s
.712 .731 .865 r
.3051 .75975 m .31127 .75666 L .31864 .75833 L p F P
0 g
s
.715 .734 .865 r
.31578 .75443 m .31127 .75666 L .31864 .75833 L p F P
0 g
s
.715 .734 .865 r
.31864 .75833 m .31898 .75816 L .31578 .75443 L p F P
0 g
s
.169 0 0 r
.37102 .99628 m .37865 .99685 L p .36483 .99631 L F P
0 g
s
.169 0 0 r
.36483 .99631 m .36692 .99614 L .37102 .99628 L p F P
0 g
s
.224 0 0 r
.43716 .99629 m .43611 .99626 L .43742 .99621 L closepath p F P
0 g
s
.201 0 0 r
.43611 .99626 m .43716 .99629 L p .42332 .99681 L F P
0 g
s
.984 .729 .463 r
.57715 .22184 m .57972 .22569 L .58008 .22097 L p F P
0 g
s
.984 .729 .463 r
.58008 .22097 m .5775 .21712 L .57715 .22184 L p F P
0 g
s
.612 .588 .802 r
.59393 .79024 m .59511 .79279 L .58483 .79667 L p F P
0 g
s
.612 .588 .802 r
.58483 .79667 m .58285 .79241 L .59393 .79024 L p F P
0 g
s
.746 .354 0 r
.75717 .0606 m .75836 .06333 L .76068 .06742 L p F P
0 g
s
.883 .52 .037 r
.75945 .06739 m .76178 .07148 L .76068 .06742 L p F P
0 g
s
.883 .52 .037 r
.76068 .06742 m .75836 .06333 L .75945 .06739 L p F P
0 g
s
.694 .741 .888 r
.32965 .75333 m .31898 .75816 L .31578 .75443 L p F P
0 g
s
.539 .322 .533 r
.60337 .9479 m .60333 .9425 L .61417 .93942 L p F P
0 g
s
.551 .352 .564 r
.61388 .93379 m .61417 .93942 L .60333 .9425 L p F P
0 g
s
0 0 .524 r
.75171 .0514 m .75421 .05545 L .75153 .05203 L p F P
0 g
s
0 0 .524 r
.75153 .05203 m .74903 .04798 L .75171 .0514 L p F P
0 g
s
.66 .75 .917 r
.38817 .75438 m .3989 .75085 L .402 .75406 L p F P
0 g
s
.64 .77 .942 r
.3989 .75085 m .38817 .75438 L .38505 .75112 L p F P
0 g
s
.333 0 0 r
.451 .99543 m .45069 .99552 L .43742 .99621 L p F P
0 g
s
.2 0 0 r
.43716 .99629 m .43742 .99621 L .45069 .99552 L p F P
0 g
s
.675 .201 .119 r
.27105 .98085 m .27566 .9846 L .2752 .98479 L p F P
0 g
s
.675 .201 .119 r
.263 .97955 m .27105 .98085 L p .2752 .98479 L F P
0 g
s
.716 .304 .265 r
.27105 .98085 m .263 .97955 L .26217 .97868 L p F P
0 g
s
.794 .705 .767 r
.19164 .82731 m .18589 .82518 L .19269 .81796 L p F P
0 g
s
.796 .702 .761 r
.19164 .82731 m .18733 .83205 L .18404 .82722 L p F P
0 g
s
.796 .702 .761 r
.18404 .82722 m .18589 .82518 L .19164 .82731 L p F P
0 g
s
.655 .675 .857 r
.49946 .75566 m .50182 .75921 L p .48798 .75828 L F P
0 g
s
.655 .675 .857 r
.48798 .75828 m .48936 .75784 L .49946 .75566 L p F P
0 g
s
.656 .69 .87 r
.48798 .75828 m .48936 .75784 L .48788 .75813 L closepath p F P
0 g
s
.811 .678 .717 r
.17 .86361 m .1758 .86568 L .17142 .87221 L p F P
0 g
s
.81 .682 .723 r
.1758 .86568 m .17 .86361 L .17469 .85699 L p F P
0 g
s
.817 .67 .7 r
.17336 .88066 m .17446 .87882 L .17129 .87242 L p F P
0 g
s
.213 0 0 r
.42332 .99681 m .4202 .99695 L .40949 .99705 L p F P
0 g
s
.236 .739 .898 r
.4202 .99695 m .40949 .99705 L .40634 .99714 L p F P
0 g
s
.49 0 0 r
.30182 .98849 m .30643 .99051 L .30384 .99089 L p F P
0 g
s
.49 0 0 r
.29292 .98742 m .30182 .98849 L p .30384 .99089 L F P
0 g
s
.646 .182 .138 r
.29276 .98734 m .29292 .98742 L .30182 .98849 L p F P
0 g
s
.958 .839 .684 r
.76584 .13556 m .7668 .13345 L .76437 .13081 L p F P
0 g
s
.806 .687 .734 r
.17945 .85054 m .17963 .8503 L .17921 .85015 L closepath p F P
0 g
s
.802 .693 .746 r
.17618 .84537 m .17944 .84134 L p .17963 .8503 L F P
0 g
s
.802 .693 .746 r
.17963 .8503 m .17921 .85015 L .17618 .84537 L p F P
0 g
s
.214 0 0 r
.36483 .99631 m .36005 .99576 L .36692 .99614 L closepath p F P
0 g
s
.81 .688 .73 r
.17469 .85699 m .17945 .85054 L .17921 .85015 L p F P
0 g
s
.656 .694 .874 r
.48936 .75784 m .48788 .75813 L .48502 .75416 L p F P
0 g
s
.741 .723 .835 r
.26656 .77075 m .2763 .76451 L .27822 .76507 L p F P
0 g
s
.74 .726 .839 r
.2763 .76451 m .26656 .77075 L .26331 .76665 L p F P
0 g
s
.674 .27 0 r
.7546 .05618 m .75421 .05545 L .75661 .05953 L p F P
0 g
s
.674 .27 0 r
.75661 .05953 m .75717 .0606 L .7546 .05618 L p F P
0 g
s
.247 0 0 r
.47652 .99353 m .4709 .99403 L .46484 .99416 L p F P
0 g
s
.211 0 0 r
.4709 .99403 m .46369 .99461 L .46484 .99416 L closepath p F P
0 g
s
.489 .144 .308 r
.55589 .97523 m .55664 .97303 L .56809 .97064 L p F P
0 g
s
.637 .772 .945 r
.41275 .7506 m .402 .75406 L .3989 .75085 L p F P
0 g
s
.657 .749 .918 r
.402 .75406 m .41275 .7506 L .41582 .75381 L p F P
0 g
s
.342 0 0 r
.50342 .98982 m .50517 .98834 L .51636 .98685 L p F P
0 g
s
.81 .688 .73 r
.17921 .85015 m .17399 .84817 L p .17469 .85699 L F P
0 g
s
.808 .695 .74 r
.17921 .85015 m .17618 .84537 L .17399 .84817 L closepath p F P
0 g
s
.757 .716 .814 r
.24181 .78176 m .24291 .78095 L .24065 .78024 L closepath p F P
0 g
s
.607 .57 .787 r
.5997 .80313 m .59462 .80405 L .59934 .80228 L closepath p F P
0 g
s
.61 .579 .793 r
.59682 .79661 m .59934 .80228 L .59462 .80405 L p F P
0 g
s
.201 0 0 r
.43716 .99629 m .43406 .99655 L .42332 .99681 L p F P
0 g
s
.234 .741 .889 r
.43406 .99655 m .42332 .99681 L .4202 .99695 L p F P
0 g
s
.752 .72 .822 r
.24994 .77054 m .25257 .77391 L .24291 .78095 L p F P
0 g
s
.752 .72 .822 r
.24876 .77014 m .24994 .77054 L p .24291 .78095 L F P
0 g
s
.752 .72 .822 r
.23854 .77756 m .24876 .77014 L p .24291 .78095 L F P
0 g
s
.752 .72 .822 r
.24291 .78095 m .24065 .78024 L .23854 .77756 L p F P
0 g
s
.179 0 0 r
.45244 .99541 m .45069 .99552 L .451 .99543 L closepath p F P
0 g
s
.211 0 0 r
.46369 .99461 m .45244 .99541 L .451 .99543 L p F P
0 g
s
.705 .73 .87 r
.31127 .75666 m .3051 .75975 L .30189 .75585 L p F P
0 g
s
.721 .726 .854 r
.2912 .76167 m .30189 .75585 L .3051 .75975 L p F P
0 g
s
.969 .827 .649 r
.7646 .12175 m .76647 .12592 L .76845 .12063 L p F P
0 g
s
.969 .827 .649 r
.76845 .12063 m .7666 .11645 L .7646 .12175 L p F P
0 g
s
.63 .619 .821 r
.54925 .77437 m .56025 .77159 L .56314 .77714 L p F P
0 g
s
.63 .624 .826 r
.55897 .76918 m .56025 .77159 L .54925 .77437 L p F P
0 g
s
.63 .624 .826 r
.54925 .77437 m .54835 .7727 L .55897 .76918 L p F P
0 g
s
.867 .839 .816 r
.72967 .19956 m .73535 .19315 L .73675 .19739 L p F P
0 g
s
.867 .839 .816 r
.73675 .19739 m .73219 .20252 L .72967 .19956 L p F P
0 g
s
.2 0 0 r
.45069 .99552 m .44793 .99591 L .43716 .99629 L p F P
0 g
s
.211 .73 .863 r
.44793 .99591 m .43716 .99629 L .43406 .99655 L p F P
0 g
s
.621 .604 .812 r
.56604 .78285 m .57708 .78036 L .57996 .78624 L p F P
0 g
s
.622 .606 .814 r
.57515 .77646 m .57708 .78036 L .56604 .78285 L p F P
0 g
s
.622 .606 .814 r
.56604 .78285 m .56471 .78019 L .57515 .77646 L p F P
0 g
s
.795 .482 .459 r
.22762 .96421 m .22072 .96257 L .2195 .95747 L p F P
0 g
s
.794 .479 .456 r
.21254 .95583 m .2195 .95747 L .22072 .96257 L p F P
0 g
s
.793 .81 .865 r
.67841 .25102 m .67767 .25158 L .67503 .24838 L p F P
0 g
s
.819 .605 .614 r
.18343 .91906 m .18183 .92487 L .188 .92675 L p F P
0 g
s
.82 .592 .594 r
.19095 .93367 m .18684 .93245 L .188 .92675 L p F P
0 g
s
.822 .595 .594 r
.18183 .92487 m .188 .92675 L .18684 .93245 L p F P
0 g
s
.655 .683 .865 r
.49946 .75566 m .49888 .7548 L .48936 .75784 L closepath p F P
0 g
s
.656 .694 .874 r
.49592 .75072 m .49888 .7548 L .48936 .75784 L p F P
0 g
s
.656 .694 .874 r
.48502 .75416 m .49592 .75072 L p .48936 .75784 L F P
0 g
s
.8 .703 .758 r
.18527 .8344 m .18733 .83205 L .18404 .82722 L p F P
0 g
s
.822 .61 .615 r
.17732 .91714 m .18343 .91906 L .18183 .92487 L p F P
0 g
s
.821 .621 .633 r
.18343 .91906 m .17732 .91714 L .17935 .91123 L p F P
0 g
s
.82 .664 .69 r
.16761 .87859 m .17336 .88066 L .16988 .88695 L p F P
0 g
s
.817 .67 .7 r
.17129 .87242 m .16761 .87859 L .17336 .88066 L p F P
0 g
s
.56 .432 .663 r
.63173 .90258 m .6304 .89601 L .64076 .89231 L p F P
0 g
s
.565 .445 .675 r
.6403 .89027 m .64076 .89231 L .6304 .89601 L p F P
0 g
s
.656 .746 .916 r
.41582 .75381 m .4266 .75037 L .42966 .75363 L p F P
0 g
s
.638 .769 .942 r
.4266 .75037 m .41582 .75381 L .41275 .7506 L p F P
0 g
s
.77 .719 .806 r
.22971 .78851 m .22774 .78596 L .22617 .78724 L closepath p F P
0 g
s
.796 .812 .864 r
.67841 .25102 m .68865 .2431 L .68603 .23994 L p F P
0 g
s
.796 .812 .864 r
.68603 .23994 m .6771 .24681 L .67841 .25102 L p F P
0 g
s
.793 .81 .865 r
.67503 .24838 m .6771 .24681 L .67841 .25102 L p F P
0 g
s
.927 .843 .74 r
.7566 .15242 m .75983 .14694 L .76149 .15114 L p F P
0 g
s
.927 .843 .74 r
.76149 .15114 m .75906 .15525 L .7566 .15242 L p F P
0 g
s
.247 0 0 r
.36005 .99576 m .36483 .99631 L p .35103 .99544 L F P
0 g
s
.247 0 0 r
.35103 .99544 m .35183 .99534 L .36005 .99576 L p F P
0 g
s
.897 .845 .784 r
.75144 .17415 m .75106 .17371 L .75121 .17349 L closepath p F P
0 g
s
.811 .568 .571 r
.19901 .94163 m .19245 .93987 L .19317 .93428 L p F P
0 g
s
.814 .571 .571 r
.19095 .93367 m .19317 .93428 L .19245 .93987 L p F P
0 g
s
.822 .623 .634 r
.1733 .90928 m .17935 .91123 L .17732 .91714 L p F P
0 g
s
.82 .633 .649 r
.17935 .91123 m .1733 .90928 L .17574 .90327 L p F P
0 g
s
.601 .564 .785 r
.60321 .81139 m .60259 .80994 L .60972 .80883 L closepath p F P
0 g
s
.992 .79 .531 r
.76556 .09796 m .76758 .10212 L .76845 .09727 L p F P
0 g
s
.992 .79 .531 r
.76642 .09322 m .76556 .09796 L p .76845 .09727 L F P
0 g
s
.992 .79 .531 r
.76845 .09727 m .76656 .09334 L .76642 .09322 L p F P
0 g
s
.877 .84 .805 r
.74217 .18937 m .74042 .18729 L .74116 .1864 L closepath p F P
0 g
s
.802 .699 .751 r
.17964 .83224 m .18527 .8344 L .17944 .84134 L p F P
0 g
s
.8 .703 .758 r
.18404 .82722 m .17964 .83224 L .18527 .8344 L p F P
0 g
s
.958 .839 .684 r
.76437 .13081 m .76413 .13135 L .76584 .13556 L p F P
0 g
s
.944 .839 .71 r
.76125 .13699 m .76299 .14119 L .76584 .13556 L p F P
0 g
s
.944 .839 .71 r
.76584 .13556 m .76413 .13135 L .76125 .13699 L p F P
0 g
s
.459 .057 .19 r
.54345 .97932 m .54209 .98164 L .5311 .98239 L p F P
0 g
s
.415 0 .091 r
.52934 .98483 m .5311 .98239 L .54209 .98164 L p F P
0 g
s
.448 .02 .133 r
.5311 .98239 m .52934 .98483 L .51737 .9867 L p F P
0 g
s
.657 .739 .911 r
.42966 .75363 m .44046 .75017 L .44349 .75354 L p F P
0 g
s
.643 .763 .936 r
.44046 .75017 m .42966 .75363 L .4266 .75037 L p F P
0 g
s
.973 .74 .525 r
.57475 .21331 m .5775 .21712 L .57821 .21228 L p F P
0 g
s
.973 .74 .525 r
.57821 .21228 m .57546 .20846 L .57475 .21331 L p F P
0 g
s
.717 .304 .263 r
.263 .97955 m .26147 .9793 L .26217 .97868 L closepath p F P
0 g
s
.735 .329 .278 r
.24518 .97354 m .24611 .97253 L p .25539 .97812 L F P
0 g
s
.76 .381 .337 r
.24518 .97354 m .2443 .97215 L .24611 .97253 L closepath p F P
0 g
s
.035 0 0 r
.44793 .99591 m .45069 .99552 L .45244 .99541 L p F P
0 g
s
.56 .392 .611 r
.62329 .91866 m .62404 .92469 L .61849 .9264 L p F P
0 g
s
.551 .369 .588 r
.61849 .9264 m .62437 .92833 L p .61388 .93379 L F P
0 g
s
.55 .37 .589 r
.62437 .92833 m .61849 .9264 L .62404 .92469 L closepath p F P
0 g
s
.651 .668 .854 r
.50182 .75921 m .51274 .75582 L .51568 .76042 L p F P
0 g
s
.651 .677 .861 r
.5108 .75291 m .51274 .75582 L .50182 .75921 L p F P
0 g
s
.651 .677 .861 r
.50182 .75921 m .49946 .75566 L .5108 .75291 L p F P
0 g
s
.638 .638 .834 r
.53246 .76691 m .54344 .76387 L .54634 .76905 L p F P
0 g
s
.639 .644 .839 r
.54161 .7607 m .54344 .76387 L .53246 .76691 L p F P
0 g
s
.639 .644 .839 r
.53246 .76691 m .53077 .76398 L .54161 .7607 L p F P
0 g
s
.601 .566 .786 r
.60972 .80883 m .60259 .80994 L .5997 .80313 L p F P
0 g
s
.739 .724 .838 r
.27822 .76507 m .27728 .76389 L .2763 .76451 L closepath p F P
0 g
s
.861 .839 .822 r
.73058 .20426 m .73219 .20252 L .72967 .19956 L p F P
0 g
s
.55 .386 .612 r
.62404 .92469 m .62329 .91866 L .63381 .91519 L p F P
0 g
s
.557 .405 .63 r
.63287 .90897 m .63381 .91519 L .62329 .91866 L p F P
0 g
s
.719 .734 .863 r
.30189 .75585 m .2912 .76167 L .28797 .75773 L p F P
0 g
s
.613 .589 .803 r
.59105 .78405 m .59393 .79024 L .58285 .79241 L p F P
0 g
s
.613 .589 .803 r
.58393 .78544 m .59105 .78405 L p .58285 .79241 L F P
0 g
s
.613 .589 .803 r
.58285 .79241 m .58025 .78684 L .58393 .78544 L p F P
0 g
s
.822 .636 .651 r
.16977 .90129 m .17574 .90327 L .1733 .90928 L p F P
0 g
s
.82 .644 .664 r
.17574 .90327 m .16977 .90129 L .17258 .89517 L p F P
0 g
s
0 0 .545 r
.59159 .25365 m .59181 .25404 L .5889 .25047 L p F P
0 g
s
0 0 .545 r
.58904 .24941 m .59159 .25365 L p .5889 .25047 L F P
0 g
s
0 0 .545 r
.5889 .25047 m .58681 .24648 L .58904 .24941 L p F P
0 g
s
.632 .631 .832 r
.55735 .76622 m .55897 .76918 L .54835 .7727 L p F P
0 g
s
.632 .631 .832 r
.54835 .7727 m .54634 .76905 L .55735 .76622 L p F P
0 g
s
.035 0 0 r
.45244 .99541 m .46181 .99501 L p .44793 .99591 L F P
0 g
s
.086 0 0 r
.46181 .99501 m .45244 .99541 L .46369 .99461 L closepath p F P
0 g
s
.761 .796 .881 r
.66402 .25622 m .65299 .26331 L .65029 .25998 L p F P
0 g
s
.811 .548 .541 r
.20543 .94882 m .19885 .94707 L .19901 .94163 L p F P
0 g
s
.811 .549 .541 r
.19245 .93987 m .19901 .94163 L .19885 .94707 L p F P
0 g
s
.759 .36 0 r
.75836 .06333 m .75717 .0606 L .7546 .05618 L p F P
0 g
s
.027 .322 .808 r
.59187 .25409 m .59181 .25404 L .59382 .25804 L p F P
0 g
s
.027 .322 .808 r
.59382 .25804 m .5947 .25863 L .59187 .25409 L p F P
0 g
s
.861 .839 .822 r
.72967 .19956 m .72925 .20001 L .73058 .20426 L p F P
0 g
s
.854 .836 .828 r
.72239 .20714 m .72378 .21137 L .73058 .20426 L p F P
0 g
s
.854 .836 .828 r
.73058 .20426 m .72925 .20001 L .72239 .20714 L p F P
0 g
s
.295 0 0 r
.35103 .99544 m .34936 .99516 L .35183 .99534 L closepath p F P
0 g
s
.895 .841 .783 r
.74857 .17075 m .74965 .16929 L .75121 .17349 L p F P
0 g
s
.895 .841 .783 r
.75121 .17349 m .75106 .17371 L .74857 .17075 L p F P
0 g
s
.658 .73 .903 r
.44349 .75354 m .45431 .75005 L .45733 .75357 L p F P
0 g
s
.648 .752 .926 r
.45431 .75005 m .44349 .75354 L .44046 .75017 L p F P
0 g
s
.771 .416 .384 r
.22831 .96602 m .22921 .96458 L p .23708 .9706 L F P
0 g
s
.786 .447 .413 r
.22831 .96602 m .22762 .96421 L .22921 .96458 L closepath p F P
0 g
s
.762 .722 .815 r
.24065 .78024 m .23854 .77756 L .23679 .7789 L closepath p F P
0 g
s
.891 .842 .789 r
.7463 .1799 m .75106 .17371 L .74857 .17075 L p F P
0 g
s
.777 .717 .797 r
.21733 .79556 m .21691 .795 L .21658 .79528 L closepath p F P
0 g
s
.451 0 0 r
.33726 .99408 m .33921 .99442 L .34936 .99516 L p F P
0 g
s
.312 0 0 r
.33921 .99442 m .33632 .99422 L .33726 .99408 L closepath p F P
0 g
s
.623 .614 .82 r
.57419 .77459 m .57515 .77646 L .56471 .78019 L p F P
0 g
s
.623 .614 .82 r
.56471 .78019 m .56314 .77714 L .57419 .77459 L p F P
0 g
s
.81 .686 .728 r
.16901 .85487 m .17469 .85699 L .17 .86361 L p F P
0 g
s
.81 .688 .73 r
.17399 .84817 m .16901 .85487 L .17469 .85699 L p F P
0 g
s
.541 .344 .563 r
.61417 .93942 m .61388 .93379 L .62457 .93053 L p F P
0 g
s
.551 .369 .588 r
.62437 .92833 m .62457 .93053 L .61388 .93379 L p F P
0 g
s
.784 .4 0 r
.58454 .24255 m .58681 .24648 L .5852 .24245 L p F P
0 g
s
.784 .4 0 r
.5852 .24245 m .58297 .2385 L .58454 .24255 L p F P
0 g
s
.604 .101 .031 r
.29292 .98742 m .29265 .98739 L .29276 .98734 L closepath p F P
0 g
s
.757 .362 .305 r
.2443 .97215 m .24518 .97354 L .24269 .97572 L p F P
0 g
s
.757 .362 .305 r
.23708 .9706 m .2443 .97215 L p .24269 .97572 L F P
0 g
s
.139 0 0 r
.34936 .99516 m .35103 .99544 L .34775 .9953 L p F P
0 g
s
.139 0 0 r
.34775 .9953 m .33921 .99442 L .34936 .99516 L p F P
0 g
s
.806 .816 .858 r
.6896 .24233 m .68865 .2431 L .68603 .23994 L p F P
0 g
s
.748 .719 .825 r
.25257 .77391 m .2552 .7721 L .24994 .77054 L closepath p F P
0 g
s
.814 .571 .571 r
.19245 .93987 m .1909 .93944 L .19095 .93367 L p F P
0 g
s
.822 .578 .57 r
.18684 .93245 m .19095 .93367 L .1909 .93944 L p F P
0 g
s
.528 .261 .454 r
.59213 .95596 m .59167 .96005 L .5806 .96219 L p F P
0 g
s
.522 .247 .439 r
.58041 .96357 m .5806 .96219 L .59167 .96005 L p F P
0 g
s
.805 .818 .861 r
.68827 .23812 m .6896 .24233 L .69954 .23408 L p F P
0 g
s
.806 .816 .858 r
.68603 .23994 m .68827 .23812 L .6896 .24233 L p F P
0 g
s
.815 .671 .703 r
.17129 .87242 m .17142 .87221 L .17113 .87211 L closepath p F P
0 g
s
.811 .678 .717 r
.16807 .86651 m .17 .86361 L p .17142 .87221 L F P
0 g
s
.811 .678 .717 r
.17142 .87221 m .17113 .87211 L .16807 .86651 L p F P
0 g
s
.49 0 0 r
.30384 .99089 m .30179 .99061 L .29292 .98742 L p F P
0 g
s
.375 0 0 r
.29265 .98739 m .29292 .98742 L .30179 .99061 L p F P
0 g
s
.819 .672 .7 r
.16761 .87859 m .17129 .87242 L .17113 .87211 L p F P
0 g
s
.777 .716 .796 r
.21086 .79312 m .21658 .79528 L .20798 .80303 L p F P
0 g
s
.777 .716 .796 r
.20272 .80039 m .21086 .79312 L p .20798 .80303 L F P
0 g
s
.777 .716 .796 r
.20798 .80303 m .2035 .80141 L .20272 .80039 L p F P
0 g
s
.781 .712 .787 r
.20602 .80484 m .20798 .80303 L .2035 .80141 L closepath p F P
0 g
s
.375 0 0 r
.2893 .98832 m .29265 .98739 L p .30179 .99061 L F P
0 g
s
.571 .033 0 r
.2893 .98832 m .28471 .98616 L .29265 .98739 L closepath p F P
0 g
s
.787 .713 .783 r
.20007 .81057 m .20602 .80484 L .2035 .80141 L p F P
0 g
s
.578 .503 .734 r
.62889 .84908 m .63453 .84683 L p .63243 .85633 L F P
0 g
s
.578 .503 .734 r
.63243 .85633 m .63123 .8564 L .62889 .84908 L p F P
0 g
s
.581 .512 .743 r
.62889 .84908 m .62828 .84726 L .63453 .84683 L closepath p F P
0 g
s
.822 .647 .666 r
.1667 .89316 m .17258 .89517 L .16977 .90129 L p F P
0 g
s
.82 .655 .678 r
.17258 .89517 m .1667 .89316 L .16988 .88695 L p F P
0 g
s
.578 .502 .733 r
.63134 .85676 m .63123 .8564 L .63243 .85633 L closepath p F P
0 g
s
.574 .491 .723 r
.63359 .86423 m .63134 .85676 L .63243 .85633 L p F P
0 g
s
.819 .672 .7 r
.17113 .87211 m .16575 .87011 L p .16761 .87859 L F P
0 g
s
.818 .68 .711 r
.17113 .87211 m .16807 .86651 L .16575 .87011 L closepath p F P
0 g
s
.778 .72 .798 r
.21361 .79072 m .21086 .79312 L .21658 .79528 L p F P
0 g
s
.778 .72 .798 r
.21658 .79528 m .21691 .795 L .21361 .79072 L p F P
0 g
s
.773 .72 .803 r
.22617 .78724 m .21691 .795 L .21361 .79072 L p F P
0 g
s
.581 .513 .743 r
.63453 .84683 m .62828 .84726 L .62624 .84121 L p F P
0 g
s
.658 .72 .894 r
.45733 .75357 m .46818 .75007 L .47117 .75376 L p F P
0 g
s
.652 .739 .914 r
.46818 .75007 m .45733 .75357 L .45431 .75005 L p F P
0 g
s
.805 .695 .743 r
.17944 .84134 m .17618 .84537 L .17289 .84026 L p F P
0 g
s
.805 .695 .743 r
.17289 .84026 m .17374 .83921 L .17944 .84134 L p F P
0 g
s
.802 .699 .751 r
.17944 .84134 m .17374 .83921 L .17964 .83224 L p F P
0 g
s
.74 .726 .839 r
.26331 .76665 m .26981 .76255 L .2763 .76451 L p F P
0 g
s
.74 .729 .841 r
.27403 .75995 m .26981 .76255 L .2763 .76451 L p F P
0 g
s
.74 .729 .841 r
.2763 .76451 m .27728 .76389 L .27403 .75995 L p F P
0 g
s
.994 .749 .439 r
.76429 .08898 m .76644 .09311 L .7668 .08846 L p F P
0 g
s
.994 .749 .439 r
.7668 .08846 m .76466 .08433 L .76429 .08898 L p F P
0 g
s
.848 .832 .831 r
.71883 .21075 m .72239 .20714 L .72378 .21137 L p F P
0 g
s
.848 .832 .831 r
.72378 .21137 m .72138 .2138 L .71883 .21075 L p F P
0 g
s
.789 .711 .778 r
.20007 .81057 m .19507 .81552 L .19177 .81097 L p F P
0 g
s
.789 .711 .778 r
.19177 .81097 m .19434 .80842 L .20007 .81057 L p F P
0 g
s
.787 .713 .783 r
.20217 .8009 m .19434 .80842 L .20007 .81057 L p F P
0 g
s
.787 .713 .783 r
.2035 .80141 m .20217 .8009 L p .20007 .81057 L F P
0 g
s
.787 .439 .397 r
.22762 .96421 m .22831 .96602 L .22658 .96838 L p F P
0 g
s
.787 .439 .397 r
.22072 .96257 m .22762 .96421 L p .22658 .96838 L F P
0 g
s
.923 .844 .748 r
.75797 .15703 m .75906 .15525 L .7566 .15242 L p F P
0 g
s
.809 .524 .506 r
.21068 .95539 m .20587 .95412 L .20543 .94882 L p F P
0 g
s
.81 .524 .504 r
.19885 .94707 m .20543 .94882 L .20587 .95412 L p F P
0 g
s
.675 .201 .119 r
.2752 .98479 m .26844 .98359 L .263 .97955 L p F P
0 g
s
.642 .143 .05 r
.26147 .9793 m .263 .97955 L .26844 .98359 L p F P
0 g
s
.743 .723 .832 r
.26005 .7626 m .26331 .76665 L .2552 .7721 L p F P
0 g
s
.743 .723 .832 r
.24931 .76975 m .26005 .7626 L p .2552 .7721 L F P
0 g
s
.743 .723 .832 r
.2552 .7721 m .24994 .77054 L .24931 .76975 L p F P
0 g
s
.581 .513 .743 r
.62624 .84121 m .63435 .83794 L p .63453 .84683 L F P
0 g
s
.584 .522 .752 r
.62624 .84121 m .62535 .83868 L .63435 .83794 L closepath p F P
0 g
s
.841 .831 .837 r
.71634 .21871 m .72138 .2138 L .71883 .21075 L p F P
0 g
s
.727 .73 .853 r
.28797 .75773 m .27728 .76389 L .27403 .75995 L p F P
0 g
s
.569 .479 .713 r
.63421 .8664 m .63359 .86423 L .64373 .86023 L p F P
0 g
s
.574 .491 .723 r
.64247 .85606 m .64373 .86023 L .63359 .86423 L p F P
0 g
s
.574 .491 .723 r
.63243 .85633 m .64247 .85606 L p .63359 .86423 L F P
0 g
s
.977 .817 .618 r
.76465 .11229 m .7666 .11645 L .76824 .1113 L p F P
0 g
s
.977 .817 .618 r
.76824 .1113 m .76631 .10713 L .76465 .11229 L p F P
0 g
s
.705 .73 .87 r
.30189 .75585 m .30347 .7551 L .31127 .75666 L p F P
0 g
s
.712 .739 .873 r
.31257 .7508 m .30347 .7551 L .31127 .75666 L p F P
0 g
s
.712 .739 .873 r
.31127 .75666 m .31578 .75443 L .31257 .7508 L p F P
0 g
s
.793 .712 .774 r
.19269 .81796 m .19507 .81552 L .19177 .81097 L p F P
0 g
s
.946 .609 .194 r
.58055 .2346 m .58297 .2385 L .58224 .23416 L p F P
0 g
s
.946 .609 .194 r
.58224 .23416 m .57983 .23025 L .58055 .2346 L p F P
0 g
s
.56 .432 .663 r
.64076 .89231 m .64209 .89889 L .63173 .90258 L p F P
0 g
s
.555 .416 .647 r
.63173 .90258 m .64209 .89889 L p .64047 .9063 L F P
0 g
s
.555 .416 .647 r
.64047 .9063 m .6322 .90522 L .63173 .90258 L p F P
0 g
s
.584 .523 .752 r
.63435 .83794 m .62535 .83868 L .62338 .83312 L p F P
0 g
s
.816 .824 .856 r
.6996 .23404 m .69954 .23408 L .6995 .23391 L closepath p F P
0 g
s
.805 .818 .861 r
.697 .2309 m .68827 .23812 L p .69954 .23408 L F P
0 g
s
.805 .818 .861 r
.69954 .23408 m .6995 .23391 L .697 .2309 L p F P
0 g
s
.825 .825 .849 r
.70831 .22626 m .6996 .23404 L .6995 .23391 L p F P
0 g
s
.387 .566 .907 r
.5947 .25863 m .60149 .25991 L .60321 .264 L p F P
0 g
s
.349 .549 .907 r
.60149 .25991 m .5947 .25863 L .59187 .25409 L p F P
0 g
s
.841 .831 .837 r
.71883 .21075 m .71501 .21447 L .71634 .21871 L p F P
0 g
s
.837 .829 .84 r
.70794 .2212 m .71501 .21447 L .71634 .21871 L p F P
0 g
s
.837 .829 .84 r
.71634 .21871 m .71051 .22426 L .70794 .2212 L p F P
0 g
s
.57 .479 .712 r
.63565 .87151 m .63421 .8664 L .64546 .8663 L p F P
0 g
s
.569 .479 .713 r
.64373 .86023 m .64546 .8663 L .63421 .8664 L p F P
0 g
s
.645 .66 .85 r
.51568 .76042 m .52663 .75718 L .52955 .76193 L p F P
0 g
s
.646 .667 .856 r
.52663 .75718 m .51568 .76042 L .51274 .75582 L p F P
0 g
s
.773 .72 .803 r
.21361 .79072 m .22034 .7851 L .22617 .78724 L p F P
0 g
s
.771 .722 .807 r
.22445 .78176 m .22034 .7851 L .22617 .78724 L p F P
0 g
s
.771 .722 .807 r
.22617 .78724 m .22774 .78596 L .22445 .78176 L p F P
0 g
s
.43 .019 .155 r
.54209 .98164 m .54345 .97932 L .55509 .97712 L p F P
0 g
s
.491 .128 .278 r
.55589 .97523 m .55509 .97712 L .54345 .97932 L p F P
0 g
s
.793 .709 .772 r
.18708 .81578 m .19269 .81796 L .18589 .82518 L p F P
0 g
s
.793 .712 .774 r
.19177 .81097 m .18708 .81578 L .19269 .81796 L p F P
0 g
s
.707 .259 .183 r
.25856 .981 m .25539 .97812 L .26147 .9793 L closepath p F P
0 g
s
.642 .143 .05 r
.25856 .981 m .26147 .9793 L p .26844 .98359 L F P
0 g
s
.829 .828 .847 r
.70831 .22626 m .71051 .22426 L .70794 .2212 L p F P
0 g
s
.829 .828 .847 r
.70794 .2212 m .70706 .22201 L .70831 .22626 L p F P
0 g
s
.825 .825 .849 r
.69819 .22987 m .70706 .22201 L .70831 .22626 L p F P
0 g
s
.825 .825 .849 r
.6995 .23391 m .69819 .22987 L p .70831 .22626 L F P
0 g
s
.573 .491 .724 r
.64247 .85606 m .63243 .85633 L .64146 .85273 L closepath p F P
0 g
s
.578 .503 .734 r
.6395 .84661 m .64146 .85273 L .63243 .85633 L p F P
0 g
s
.578 .503 .734 r
.63453 .84683 m .6395 .84661 L p .63243 .85633 L F P
0 g
s
.765 .723 .813 r
.23679 .7789 m .22774 .78596 L .22445 .78176 L p F P
0 g
s
.818 .82 .851 r
.6995 .23391 m .697 .2309 L .69819 .22987 L closepath p F P
0 g
s
.07 0 0 r
.46181 .99501 m .46369 .99461 L .4709 .99403 L p F P
0 g
s
.654 .725 .901 r
.48205 .75027 m .47117 .75376 L .46818 .75007 L p F P
0 g
s
.657 .708 .885 r
.47117 .75376 m .48205 .75027 L .48502 .75416 L p F P
0 g
s
.923 .844 .748 r
.7566 .15242 m .75636 .15281 L .75797 .15703 L p F P
0 g
s
.911 .842 .763 r
.7523 .1589 m .75394 .16311 L .75797 .15703 L p F P
0 g
s
.911 .842 .763 r
.75797 .15703 m .75636 .15281 L .7523 .1589 L p F P
0 g
s
.809 .696 .741 r
.17399 .84817 m .17618 .84537 L .17289 .84026 L p F P
0 g
s
.388 0 0 r
.51727 .98681 m .51636 .98685 L .51737 .9867 L closepath p F P
0 g
s
.342 0 0 r
.51636 .98685 m .51727 .98681 L p .50342 .98982 L F P
0 g
s
.601 .566 .786 r
.5997 .80313 m .61084 .80143 L p .60972 .80883 L F P
0 g
s
.601 .567 .788 r
.60946 .79819 m .61084 .80143 L .5997 .80313 L p F P
0 g
s
.601 .567 .788 r
.5997 .80313 m .59934 .80228 L .60946 .79819 L p F P
0 g
s
.822 .658 .68 r
.16409 .88489 m .16988 .88695 L .1667 .89316 L p F P
0 g
s
.82 .664 .69 r
.16988 .88695 m .16409 .88489 L .16761 .87859 L p F P
0 g
s
.64 .65 .844 r
.54053 .75887 m .54161 .7607 L .53077 .76398 L p F P
0 g
s
.64 .65 .844 r
.53077 .76398 m .52955 .76193 L .54053 .75887 L p F P
0 g
s
.584 .523 .752 r
.62338 .83312 m .63188 .82965 L p .63435 .83794 L F P
0 g
s
.587 .532 .761 r
.62338 .83312 m .62243 .83056 L .63188 .82965 L closepath p F P
0 g
s
.891 .842 .789 r
.74857 .17075 m .74479 .17568 L .7463 .1799 L p F P
0 g
s
.885 .84 .796 r
.73961 .1822 m .74116 .1864 L .7463 .1799 L p F P
0 g
s
.885 .84 .796 r
.7463 .1799 m .74479 .17568 L .73961 .1822 L p F P
0 g
s
.624 .617 .823 r
.57419 .77459 m .56314 .77714 L .56025 .77159 L p F P
0 g
s
.567 .468 .702 r
.63565 .87151 m .64582 .86755 L p .64057 .87746 L F P
0 g
s
.567 .468 .702 r
.64057 .87746 m .63722 .87742 L .63565 .87151 L p F P
0 g
s
.57 .479 .712 r
.64546 .8663 m .64582 .86755 L .63565 .87151 L p F P
0 g
s
.247 0 0 r
.36483 .99631 m .36159 .99598 L .35103 .99544 L p F P
0 g
s
.232 .723 .921 r
.35103 .99544 m .36159 .99598 L .35847 .99511 L p F P
0 g
s
.232 .723 .921 r
.34775 .9953 m .35103 .99544 L p .35847 .99511 L F P
0 g
s
.643 .734 .915 r
.61152 .26774 m .62266 .26434 L .62541 .26798 L p F P
0 g
s
.633 .729 .916 r
.62266 .26434 m .61152 .26774 L .60874 .26383 L p F P
0 g
s
.174 0 0 r
.33921 .99442 m .34775 .9953 L p .33394 .99427 L F P
0 g
s
.174 0 0 r
.33394 .99427 m .33632 .99422 L .33921 .99442 L p F P
0 g
s
.603 .576 .795 r
.60795 .7948 m .60946 .79819 L .59934 .80228 L p F P
0 g
s
.603 .576 .795 r
.59934 .80228 m .59682 .79661 L .60795 .7948 L p F P
0 g
s
.738 .778 .885 r
.64496 .26303 m .63923 .26628 L .63651 .2628 L p F P
0 g
s
.705 .768 .901 r
.62541 .26798 m .63651 .2628 L .63923 .26628 L p F P
0 g
s
.515 .25 .45 r
.59167 .96005 m .59213 .95596 L .60313 .95307 L p F P
0 g
s
.535 .294 .497 r
.60337 .9479 m .60313 .95307 L .59213 .95596 L p F P
0 g
s
.368 0 0 r
.51727 .98681 m .51737 .9867 L .52934 .98483 L p F P
0 g
s
.984 .703 .347 r
.76242 .08023 m .76466 .08433 L .76458 .07986 L p F P
0 g
s
.984 .703 .347 r
.76458 .07986 m .76234 .07575 L .76242 .08023 L p F P
0 g
s
.958 .83 .675 r
.76228 .12718 m .7646 .12175 L .76647 .12592 L p F P
0 g
s
.958 .83 .675 r
.76343 .12974 m .76228 .12718 L p .76647 .12592 L F P
0 g
s
.958 .83 .675 r
.76647 .12592 m .76437 .13081 L .76343 .12974 L p F P
0 g
s
.615 .597 .81 r
.58025 .78684 m .57996 .78624 L .58393 .78544 L closepath p F P
0 g
s
.632 .635 .835 r
.55735 .76622 m .54634 .76905 L .54344 .76387 L p F P
0 g
s
.587 .533 .761 r
.63188 .82965 m .62243 .83056 L .62029 .8248 L p F P
0 g
s
.494 .188 .375 r
.5794 .96809 m .58041 .96357 L .59156 .96085 L p F P
0 g
s
.522 .247 .439 r
.59167 .96005 m .59156 .96085 L .58041 .96357 L p F P
0 g
s
.509 .201 .38 r
.58041 .96357 m .5794 .96809 L .56809 .97064 L p F P
0 g
s
.735 .329 .278 r
.25539 .97812 m .2478 .97668 L .24518 .97354 L p F P
0 g
s
.734 .329 .281 r
.2478 .97668 m .24269 .97572 L .24518 .97354 L closepath p F P
0 g
s
.934 .838 .726 r
.75807 .14275 m .75983 .14694 L .76299 .14119 L p F P
0 g
s
.934 .838 .726 r
.76299 .14119 m .76125 .13699 L .75807 .14275 L p F P
0 g
s
.555 .416 .647 r
.63287 .90897 m .6322 .90522 L .64047 .9063 L closepath p F P
0 g
s
.778 .803 .873 r
.66421 .25645 m .66402 .25622 L .66411 .25615 L closepath p F P
0 g
s
.793 .709 .772 r
.18074 .82247 m .18708 .81578 L p .18589 .82518 L F P
0 g
s
.793 .709 .772 r
.18589 .82518 m .18149 .82352 L .18074 .82247 L p F P
0 g
s
.798 .704 .762 r
.18404 .82722 m .18589 .82518 L .18149 .82352 L closepath p F P
0 g
s
.794 .479 .456 r
.22072 .96257 m .2138 .96092 L .21254 .95583 L p F P
0 g
s
.794 .479 .456 r
.21068 .95539 m .21254 .95583 L .2138 .96092 L p F P
0 g
s
.815 .68 .715 r
.16807 .86651 m .17 .86361 L .16558 .86199 L closepath p F P
0 g
s
.81 .686 .728 r
.16484 .86073 m .16901 .85487 L p .17 .86361 L F P
0 g
s
.81 .686 .728 r
.17 .86361 m .16558 .86199 L .16484 .86073 L p F P
0 g
s
.981 .69 .373 r
.57725 .2264 m .57983 .23025 L .57972 .22569 L p F P
0 g
s
.981 .69 .373 r
.57972 .22569 m .57715 .22184 L .57725 .2264 L p F P
0 g
s
.489 .144 .308 r
.56809 .97064 m .56693 .97397 L .55589 .97523 L p F P
0 g
s
.466 .097 .254 r
.55509 .97712 m .55589 .97523 L .56693 .97397 L p F P
0 g
s
.368 0 0 r
.52934 .98483 m .52824 .98588 L .51727 .98681 L p F P
0 g
s
.167 0 0 r
.51727 .98681 m .52824 .98588 L .52586 .98732 L p F P
0 g
s
.167 0 0 r
.51437 .98892 m .51727 .98681 L p .52586 .98732 L F P
0 g
s
.342 0 0 r
.51727 .98681 m .51437 .98892 L .50342 .98982 L p F P
0 g
s
.236 0 0 r
.33394 .99427 m .32953 .99356 L .33632 .99422 L closepath p F P
0 g
s
.615 .601 .813 r
.58393 .78544 m .57996 .78624 L .57708 .78036 L p F P
0 g
s
.811 .692 .734 r
.16842 .84601 m .17399 .84817 L .16901 .85487 L p F P
0 g
s
.809 .696 .741 r
.17289 .84026 m .16842 .84601 L .17399 .84817 L p F P
0 g
s
.67 .753 .913 r
.34351 .7525 m .35419 .74868 L .35736 .7519 L p F P
0 g
s
.653 .767 .933 r
.35419 .74868 m .34351 .7525 L .34032 .74913 L p F P
0 g
s
.682 .747 .9 r
.32965 .75333 m .34032 .74913 L .34351 .7525 L p F P
0 g
s
.51 .656 .925 r
.60595 .2599 m .60149 .25991 L .60321 .264 L p F P
0 g
s
.51 .656 .925 r
.60321 .264 m .60874 .26383 L .60595 .2599 L p F P
0 g
s
.671 .757 .915 r
.34032 .74913 m .32965 .75333 L .32645 .74982 L p F P
0 g
s
.694 .741 .888 r
.31578 .75443 m .32645 .74982 L .32965 .75333 L p F P
0 g
s
.653 .711 .89 r
.49592 .75072 m .48502 .75416 L .48205 .75027 L p F P
0 g
s
.802 .705 .758 r
.17964 .83224 m .18404 .82722 L .18149 .82352 L p F P
0 g
s
.658 .76 .925 r
.35736 .7519 m .36805 .74839 L .37121 .75145 L p F P
0 g
s
.633 .777 .95 r
.36805 .74839 m .35736 .7519 L .35419 .74868 L p F P
0 g
s
.765 .723 .813 r
.22445 .78176 m .23086 .77678 L .23679 .7789 L p F P
0 g
s
.764 .725 .817 r
.23525 .77344 m .23086 .77678 L .23679 .7789 L p F P
0 g
s
.764 .725 .817 r
.23679 .7789 m .23854 .77756 L .23525 .77344 L p F P
0 g
s
.777 .8 .871 r
.66411 .25615 m .66402 .25622 L .66135 .25291 L p F P
0 g
s
.761 .796 .881 r
.65029 .25998 m .66135 .25291 L .66402 .25622 L p F P
0 g
s
.777 .8 .871 r
.66135 .25291 m .66268 .25199 L .66411 .25615 L p F P
0 g
s
.779 .801 .871 r
.66411 .25615 m .67503 .24838 L .67238 .24512 L p F P
0 g
s
.779 .801 .871 r
.67238 .24512 m .66268 .25199 L .66411 .25615 L p F P
0 g
s
.737 .727 .842 r
.26981 .76255 m .26331 .76665 L .26005 .7626 L p F P
0 g
s
.822 .61 .615 r
.18183 .92487 m .17569 .92296 L .17732 .91714 L p F P
0 g
s
.822 .595 .594 r
.18684 .93245 m .18065 .93056 L .18183 .92487 L p F P
0 g
s
.824 .597 .595 r
.17569 .92296 m .18183 .92487 L .18065 .93056 L p F P
0 g
s
.131 0 0 r
.47568 .99378 m .4709 .99403 L .47652 .99353 L closepath p F P
0 g
s
.07 0 0 r
.4709 .99403 m .47568 .99378 L p .46181 .99501 L F P
0 g
s
.686 .749 .899 r
.32645 .74982 m .31578 .75443 L .31257 .7508 L p F P
0 g
s
.567 .468 .702 r
.63754 .87863 m .63722 .87742 L .64057 .87746 L closepath p F P
0 g
s
.523 .285 .495 r
.60313 .95307 m .60337 .9479 L .61422 .94483 L p F P
0 g
s
.539 .322 .533 r
.61417 .93942 m .61422 .94483 L .60337 .9479 L p F P
0 g
s
.824 .612 .617 r
.17124 .91521 m .17732 .91714 L .17569 .92296 L p F P
0 g
s
.822 .623 .634 r
.17732 .91714 m .17124 .91521 L .1733 .90928 L p F P
0 g
s
.757 .727 .825 r
.24876 .77014 m .23854 .77756 L .23525 .77344 L p F P
0 g
s
.647 .766 .935 r
.37121 .75145 m .38191 .74819 L .38505 .75112 L p F P
0 g
s
.615 .787 .964 r
.38191 .74819 m .37121 .75145 L .36805 .74839 L p F P
0 g
s
.701 .764 .901 r
.63651 .2628 m .62541 .26798 L .62266 .26434 L p F P
0 g
s
.651 .682 .866 r
.5098 .75144 m .5108 .75291 L .49946 .75566 L p F P
0 g
s
.651 .682 .866 r
.49946 .75566 m .49888 .7548 L .5098 .75144 L p F P
0 g
s
.771 .416 .384 r
.23708 .9706 m .2298 .96907 L .22831 .96602 L p F P
0 g
s
.771 .416 .383 r
.2298 .96907 m .22658 .96838 L .22831 .96602 L closepath p F P
0 g
s
.822 .578 .57 r
.1909 .93944 m .18614 .93802 L .18684 .93245 L p F P
0 g
s
.824 .579 .57 r
.18065 .93056 m .18684 .93245 L .18614 .93802 L p F P
0 g
s
.955 .633 .222 r
.76002 .07166 m .76234 .07575 L .76178 .07148 L p F P
0 g
s
.955 .633 .222 r
.76178 .07148 m .75945 .06739 L .76002 .07166 L p F P
0 g
s
.562 .454 .689 r
.63923 .88555 m .63754 .87863 L .64057 .87746 L p F P
0 g
s
.587 .533 .761 r
.62029 .8248 m .62708 .82199 L p .63188 .82965 L F P
0 g
s
.589 .542 .77 r
.62029 .8248 m .61952 .82281 L .62708 .82199 L closepath p F P
0 g
s
.821 .667 .692 r
.16191 .8765 m .16761 .87859 L .16409 .88489 L p F P
0 g
s
.819 .672 .7 r
.16575 .87011 m .16191 .8765 L .16761 .87859 L p F P
0 g
s
.55 .386 .612 r
.63381 .91519 m .63457 .92123 L .62404 .92469 L p F P
0 g
s
.541 .363 .589 r
.62404 .92469 m .63457 .92123 L p .62703 .92973 L F P
0 g
s
.541 .363 .589 r
.62703 .92973 m .62437 .92833 L .62404 .92469 L p F P
0 g
s
.985 .803 .579 r
.76428 .10298 m .76631 .10713 L .76758 .10212 L p F P
0 g
s
.985 .803 .579 r
.76758 .10212 m .76556 .09796 L .76428 .10298 L p F P
0 g
s
.501 0 0 r
.28471 .98616 m .2893 .98832 L .28673 .98858 L p F P
0 g
s
.501 0 0 r
.2763 .98495 m .28471 .98616 L p .28673 .98858 L F P
0 g
s
.659 .193 .137 r
.27566 .9846 m .2763 .98495 L .28471 .98616 L p F P
0 g
s
.823 .627 .638 r
.1673 .90732 m .1733 .90928 L .17124 .91521 L p F P
0 g
s
.822 .636 .651 r
.1733 .90928 m .1673 .90732 L .16977 .90129 L p F P
0 g
s
.169 0 0 r
.37865 .99685 m .37544 .99638 L .36483 .99631 L p F P
0 g
s
.308 .762 .956 r
.36483 .99631 m .37544 .99638 L .37341 .99573 L p F P
0 g
s
.308 .762 .956 r
.36159 .99598 m .36483 .99631 L p .37341 .99573 L F P
0 g
s
.794 .479 .456 r
.2138 .96092 m .2087 .95971 L .21068 .95539 L p F P
0 g
s
.806 .494 .461 r
.20587 .95412 m .21068 .95539 L .2087 .95971 L p F P
0 g
s
.64 .77 .942 r
.38505 .75112 m .39578 .74801 L .3989 .75085 L p F P
0 g
s
.601 .794 .973 r
.39578 .74801 m .38505 .75112 L .38191 .74819 L p F P
0 g
s
.641 .658 .851 r
.54053 .75887 m .52955 .76193 L .52663 .75718 L p F P
0 g
s
.818 .681 .712 r
.16575 .87011 m .16807 .86651 L .16558 .86199 L p F P
0 g
s
.705 .728 .869 r
.30189 .75585 m .30347 .7551 L .30082 .7546 L closepath p F P
0 g
s
.719 .734 .863 r
.30082 .7546 m .30189 .75585 L p .28797 .75773 L F P
0 g
s
.589 .543 .77 r
.62708 .82199 m .61952 .82281 L .61697 .81623 L p F P
0 g
s
.47 .122 .293 r
.56693 .97397 m .56809 .97064 L .5794 .96809 L p F P
0 g
s
.373 0 0 r
.31979 .99271 m .31088 .99164 L .30643 .99051 L p F P
0 g
s
.393 0 0 r
.31088 .99164 m .30384 .99089 L .30643 .99051 L closepath p F P
0 g
s
.802 .704 .756 r
.17408 .83006 m .17964 .83224 L .17374 .83921 L p F P
0 g
s
.802 .705 .758 r
.18024 .82302 m .17408 .83006 L .17964 .83224 L p F P
0 g
s
.802 .705 .758 r
.18149 .82352 m .18024 .82302 L p .17964 .83224 L F P
0 g
s
.876 .836 .804 r
.7379 .18425 m .73961 .1822 L .74116 .1864 L p F P
0 g
s
.876 .836 .804 r
.74116 .1864 m .74042 .18729 L .7379 .18425 L p F P
0 g
s
.811 .549 .541 r
.19885 .94707 m .19229 .94531 L .19245 .93987 L p F P
0 g
s
.814 .551 .541 r
.1909 .93944 m .19245 .93987 L .19229 .94531 L p F P
0 g
s
.754 .351 .287 r
.2298 .96907 m .23708 .9706 L .24031 .9752 L p F P
0 g
s
.757 .362 .305 r
.24269 .97572 m .24031 .9752 L .23708 .9706 L p F P
0 g
s
.978 .721 .472 r
.57439 .21803 m .57715 .22184 L .5775 .21712 L p F P
0 g
s
.978 .721 .472 r
.5775 .21712 m .57475 .21331 L .57439 .21803 L p F P
0 g
s
.759 .36 0 r
.7546 .05618 m .75594 .05926 L .75836 .06333 L p F P
0 g
s
.891 .524 .053 r
.75704 .06332 m .75945 .06739 L .75836 .06333 L p F P
0 g
s
.891 .524 .053 r
.75836 .06333 m .75594 .05926 L .75704 .06332 L p F P
0 g
s
.785 .718 .79 r
.2035 .80141 m .20272 .80039 L .20217 .8009 L closepath p F P
0 g
s
.637 .772 .945 r
.3989 .75085 m .40965 .74779 L .41275 .7506 L p F P
0 g
s
.596 .799 .977 r
.40965 .74779 m .3989 .75085 L .39578 .74801 L p F P
0 g
s
.871 .836 .81 r
.73535 .19315 m .74042 .18729 L .7379 .18425 L p F P
0 g
s
.651 .697 .88 r
.5098 .75144 m .49888 .7548 L .49592 .75072 L p F P
0 g
s
.289 0 0 r
.32953 .99356 m .33394 .99427 L p .32016 .99279 L F P
0 g
s
.289 0 0 r
.32016 .99279 m .32037 .99277 L .32953 .99356 L p F P
0 g
s
.822 .647 .666 r
.16977 .90129 m .16385 .89929 L .1667 .89316 L p F P
0 g
s
.823 .639 .654 r
.16385 .89929 m .16977 .90129 L .1673 .90732 L p F P
0 g
s
.548 .398 .629 r
.63381 .91519 m .63287 .90897 L .64047 .9063 L p F P
0 g
s
.904 .839 .771 r
.74799 .1651 m .74965 .16929 L .75394 .16311 L p F P
0 g
s
.904 .839 .771 r
.75394 .16311 m .7523 .1589 L .74799 .1651 L p F P
0 g
s
.69 .278 0 r
.75204 .05201 m .75171 .0514 L .75421 .05545 L p F P
0 g
s
.69 .278 0 r
.75421 .05545 m .7546 .05618 L .75204 .05201 L p F P
0 g
s
.254 0 0 r
.48956 .99213 m .48916 .99227 L .47652 .99353 L p F P
0 g
s
.112 0 0 r
.47568 .99378 m .47652 .99353 L .48916 .99227 L p F P
0 g
s
.754 .725 .825 r
.24994 .77054 m .24931 .76975 L .24876 .77014 L closepath p F P
0 g
s
.737 .781 .888 r
.64496 .26303 m .65029 .25998 L .64759 .25659 L p F P
0 g
s
.737 .781 .888 r
.64759 .25659 m .64364 .25882 L .64496 .26303 L p F P
0 g
s
.738 .778 .885 r
.63651 .2628 m .64364 .25882 L .64496 .26303 L p F P
0 g
s
.692 .221 .128 r
.25539 .97812 m .25856 .981 L .25697 .98164 L p F P
0 g
s
.692 .221 .128 r
.2478 .97668 m .25539 .97812 L p .25697 .98164 L F P
0 g
s
.701 .731 .874 r
.30934 .7473 m .31257 .7508 L .30347 .7551 L p F P
0 g
s
.701 .731 .874 r
.29866 .75211 m .30934 .7473 L p .30347 .7551 L F P
0 g
s
.701 .731 .874 r
.30347 .7551 m .30082 .7546 L .29866 .75211 L p F P
0 g
s
.604 .576 .796 r
.60523 .78868 m .60795 .7948 L .59682 .79661 L p F P
0 g
s
.604 .576 .796 r
.59682 .79661 m .59511 .79279 L .60523 .78868 L p F P
0 g
s
.601 .799 .975 r
.42353 .74752 m .41275 .7506 L .40965 .74779 L p F P
0 g
s
.638 .769 .942 r
.41275 .7506 m .42353 .74752 L .4266 .75037 L p F P
0 g
s
.598 .557 .779 r
.61373 .80825 m .60972 .80883 L .61337 .80737 L closepath p F P
0 g
s
.601 .566 .786 r
.61084 .80143 m .61337 .80737 L .60972 .80883 L p F P
0 g
s
.2 0 0 r
.50155 .99078 m .50342 .98982 L .51437 .98892 L p F P
0 g
s
.36 .785 .973 r
.37865 .99685 m .38931 .99656 L .38805 .99613 L p F P
0 g
s
.36 .785 .973 r
.37544 .99638 m .37865 .99685 L p .38805 .99613 L F P
0 g
s
.104 0 0 r
.39249 .99712 m .38931 .99656 L .37865 .99685 L p F P
0 g
s
.787 .439 .397 r
.22658 .96838 m .22276 .96746 L .22072 .96257 L p F P
0 g
s
.787 .434 .389 r
.2138 .96092 m .22072 .96257 L .22276 .96746 L p F P
0 g
s
.719 .734 .863 r
.28797 .75773 m .29627 .75335 L .30082 .7546 L p F P
0 g
s
.714 .736 .869 r
.29627 .75335 m .28797 .75773 L .28473 .75387 L p F P
0 g
s
.727 .73 .853 r
.27403 .75995 m .28473 .75387 L .28797 .75773 L p F P
0 g
s
.811 .692 .734 r
.16901 .85487 m .16339 .85273 L .16842 .84601 L p F P
0 g
s
.814 .688 .725 r
.16901 .85487 m .16484 .86073 L .16157 .85529 L p F P
0 g
s
.814 .688 .725 r
.16157 .85529 m .16339 .85273 L .16901 .85487 L p F P
0 g
s
.814 .551 .541 r
.19229 .94531 m .19022 .94474 L .1909 .93944 L p F P
0 g
s
.822 .559 .541 r
.18614 .93802 m .1909 .93944 L .19022 .94474 L p F P
0 g
s
.737 .727 .842 r
.26005 .7626 m .26327 .76061 L .26981 .76255 L p F P
0 g
s
.739 .732 .845 r
.27077 .75606 m .26327 .76061 L .26981 .76255 L p F P
0 g
s
.739 .732 .845 r
.26981 .76255 m .27403 .75995 L .27077 .75606 L p F P
0 g
s
.528 .313 .532 r
.61422 .94483 m .61417 .93942 L .62488 .93616 L p F P
0 g
s
.541 .344 .563 r
.62457 .93053 m .62488 .93616 L .61417 .93942 L p F P
0 g
s
.557 .442 .678 r
.63923 .88555 m .64943 .88164 L p .64507 .89068 L F P
0 g
s
.557 .442 .678 r
.64507 .89068 m .6403 .89027 L .63923 .88555 L p F P
0 g
s
.562 .454 .689 r
.64851 .87789 m .64943 .88164 L .63923 .88555 L p F P
0 g
s
.562 .454 .689 r
.64057 .87746 m .64851 .87789 L p .63923 .88555 L F P
0 g
s
.81 .524 .504 r
.20587 .95412 m .19931 .95236 L .19885 .94707 L p F P
0 g
s
.811 .524 .503 r
.19229 .94531 m .19885 .94707 L .19931 .95236 L p F P
0 g
s
.966 .822 .65 r
.76265 .11759 m .7646 .12175 L .7666 .11645 L p F P
0 g
s
.966 .822 .65 r
.7666 .11645 m .76465 .11229 L .76265 .11759 L p F P
0 g
s
.643 .763 .936 r
.4266 .75037 m .4374 .74721 L .44046 .75017 L p F P
0 g
s
.613 .793 .968 r
.4374 .74721 m .4266 .75037 L .42353 .74752 L p F P
0 g
s
.993 .782 .515 r
.76656 .09334 m .76642 .09322 L .76644 .09311 L closepath p F P
0 g
s
.786 .721 .791 r
.20217 .8009 m .20272 .80039 L .1994 .79609 L p F P
0 g
s
.781 .72 .796 r
.21086 .79312 m .20272 .80039 L .1994 .79609 L p F P
0 g
s
.757 .727 .825 r
.23525 .77344 m .24277 .76803 L .24876 .77014 L p F P
0 g
s
.756 .729 .827 r
.24602 .76574 m .24277 .76803 L .24876 .77014 L p F P
0 g
s
.756 .729 .827 r
.24876 .77014 m .24931 .76975 L .24602 .76574 L p F P
0 g
s
.786 .721 .791 r
.1994 .79609 m .19661 .79868 L .20217 .8009 L p F P
0 g
s
.787 .716 .785 r
.19661 .79868 m .20217 .8009 L .19434 .80842 L p F P
0 g
s
.821 .676 .703 r
.16015 .86797 m .16575 .87011 L .16191 .8765 L p F P
0 g
s
.818 .681 .712 r
.16431 .8615 m .16015 .86797 L .16575 .87011 L p F P
0 g
s
.818 .681 .712 r
.16558 .86199 m .16431 .8615 L p .16575 .87011 L F P
0 g
s
.823 .651 .669 r
.16087 .89112 m .1667 .89316 L .16385 .89929 L p F P
0 g
s
.822 .658 .68 r
.1667 .89316 m .16087 .89112 L .16409 .88489 L p F P
0 g
s
.748 .731 .836 r
.26005 .7626 m .24931 .76975 L .24602 .76574 L p F P
0 g
s
.589 .543 .77 r
.61697 .81623 m .61996 .81498 L p .62708 .82199 L F P
0 g
s
.592 .552 .778 r
.61697 .81623 m .61662 .81537 L .61996 .81498 L closepath p F P
0 g
s
.612 .592 .806 r
.59105 .78405 m .58393 .78544 L .5905 .7829 L closepath p F P
0 g
s
.615 .601 .813 r
.58817 .77811 m .5905 .7829 L .58393 .78544 L p F P
0 g
s
.615 .601 .813 r
.57708 .78036 m .58817 .77811 L p .58393 .78544 L F P
0 g
s
.781 .72 .796 r
.1994 .79609 m .2052 .79093 L .21086 .79312 L p F P
0 g
s
.779 .722 .8 r
.21029 .78649 m .2052 .79093 L .21086 .79312 L p F P
0 g
s
.779 .722 .8 r
.21086 .79312 m .21361 .79072 L .21029 .78649 L p F P
0 g
s
.792 .807 .864 r
.6771 .24681 m .67503 .24838 L .67238 .24512 L p F P
0 g
s
.871 .836 .81 r
.7379 .18425 m .73386 .18893 L .73535 .19315 L p F P
0 g
s
.866 .835 .814 r
.72776 .1958 m .73386 .18893 L .73535 .19315 L p F P
0 g
s
.866 .835 .814 r
.72872 .19843 m .72776 .1958 L p .73535 .19315 L F P
0 g
s
.866 .835 .814 r
.73535 .19315 m .72967 .19956 L .72872 .19843 L p F P
0 g
s
.772 .368 0 r
.75594 .05926 m .7546 .05618 L .75204 .05201 L p F P
0 g
s
.773 .722 .805 r
.22034 .7851 m .21361 .79072 L .21029 .78649 L p F P
0 g
s
.717 .735 .866 r
.30082 .7546 m .29866 .75211 L .29627 .75335 L closepath p F P
0 g
s
.807 .698 .745 r
.17289 .84026 m .17374 .83921 L .1717 .83842 L closepath p F P
0 g
s
.802 .704 .756 r
.16959 .83535 m .17408 .83006 L p .17374 .83921 L F P
0 g
s
.802 .704 .756 r
.17374 .83921 m .1717 .83842 L .16959 .83535 L p F P
0 g
s
.955 .833 .684 r
.76437 .13081 m .76413 .13135 L .76343 .12974 L closepath p F P
0 g
s
.991 .778 .519 r
.76401 .09069 m .76429 .08898 L .76644 .09311 L p F P
0 g
s
.991 .778 .519 r
.76644 .09311 m .76642 .09322 L .76401 .09069 L p F P
0 g
s
.592 .553 .779 r
.61996 .81498 m .61662 .81537 L .61373 .80825 L p F P
0 g
s
.619 .116 .033 r
.2763 .98495 m .2752 .98479 L .27566 .9846 L closepath p F P
0 g
s
.79 .713 .779 r
.19434 .80842 m .19177 .81097 L .18845 .80647 L p F P
0 g
s
.79 .713 .779 r
.18845 .80647 m .18867 .80624 L .19434 .80842 L p F P
0 g
s
.787 .716 .785 r
.19434 .80842 m .18867 .80624 L .19661 .79868 L p F P
0 g
s
.925 .837 .739 r
.75461 .14863 m .75807 .14275 L .75983 .14694 L p F P
0 g
s
.925 .837 .739 r
.75583 .15151 m .75461 .14863 L p .75983 .14694 L F P
0 g
s
.925 .837 .739 r
.75983 .14694 m .7566 .15242 L .75583 .15151 L p F P
0 g
s
.624 .617 .823 r
.56025 .77159 m .5713 .76902 L .57419 .77459 L p F P
0 g
s
.624 .621 .827 r
.56939 .7654 m .5713 .76902 L .56025 .77159 L p F P
0 g
s
.624 .621 .827 r
.56025 .77159 m .55897 .76918 L .56939 .7654 L p F P
0 g
s
.991 .782 .525 r
.76556 .09796 m .76642 .09322 L .76401 .09069 L p F P
0 g
s
.576 .502 .734 r
.6395 .84661 m .63453 .84683 L .639 .84503 L closepath p F P
0 g
s
.581 .513 .743 r
.63656 .8378 m .639 .84503 L .63453 .84683 L p F P
0 g
s
.581 .513 .743 r
.63435 .83794 m .63656 .8378 L p .63453 .84683 L F P
0 g
s
.648 .752 .926 r
.44046 .75017 m .45129 .74692 L .45431 .75005 L p F P
0 g
s
.627 .782 .956 r
.45129 .74692 m .44046 .75017 L .4374 .74721 L p F P
0 g
s
.216 .725 .892 r
.39249 .99712 m .40319 .99656 L .40634 .99714 L p F P
0 g
s
.392 .798 .982 r
.39249 .99712 m .40319 .99656 L .40238 .99627 L p F P
0 g
s
.392 .798 .982 r
.38931 .99656 m .39249 .99712 L p .40238 .99627 L F P
0 g
s
.795 .714 .775 r
.18708 .81578 m .19177 .81097 L .18845 .80647 L p F P
0 g
s
.794 .809 .864 r
.6771 .24681 m .68603 .23994 L .6834 .23671 L p F P
0 g
s
.794 .809 .864 r
.6834 .23671 m .67569 .24262 L .6771 .24681 L p F P
0 g
s
.792 .807 .864 r
.67238 .24512 m .67569 .24262 L .6771 .24681 L p F P
0 g
s
.811 .699 .741 r
.16842 .84601 m .17289 .84026 L .1717 .83842 L p F P
0 g
s
.937 .834 .716 r
.75942 .13282 m .76125 .13699 L .76413 .13135 L p F P
0 g
s
.937 .834 .716 r
.76192 .12792 m .75942 .13282 L p .76413 .13135 L F P
0 g
s
.937 .834 .716 r
.76413 .13135 m .76343 .12974 L .76192 .12792 L p F P
0 g
s
.615 .603 .815 r
.5854 .77249 m .58817 .77811 L .57708 .78036 L p F P
0 g
s
.615 .603 .815 r
.57708 .78036 m .57515 .77646 L .5854 .77249 L p F P
0 g
s
.646 .667 .856 r
.51274 .75582 m .5237 .75257 L .52663 .75718 L p F P
0 g
s
.647 .677 .864 r
.52191 .74987 m .5237 .75257 L .51274 .75582 L p F P
0 g
s
.647 .677 .864 r
.51274 .75582 m .5108 .75291 L .52191 .74987 L p F P
0 g
s
.561 .455 .691 r
.64851 .87789 m .64057 .87746 L .64772 .87468 L closepath p F P
0 g
s
.567 .468 .702 r
.64582 .86755 m .64772 .87468 L .64057 .87746 L p F P
0 g
s
.773 .722 .805 r
.21029 .78649 m .21457 .78294 L .22034 .7851 L p F P
0 g
s
.772 .724 .809 r
.22114 .7776 m .21457 .78294 L .22034 .7851 L p F P
0 g
s
.772 .724 .809 r
.22034 .7851 m .22445 .78176 L .22114 .7776 L p F P
0 g
s
.606 .585 .803 r
.60507 .78832 m .60523 .78868 L .59511 .79279 L p F P
0 g
s
.606 .585 .803 r
.59511 .79279 m .59393 .79024 L .60507 .78832 L p F P
0 g
s
.183 0 0 r
.50155 .99078 m .4923 .99191 L .48956 .99213 L p F P
0 g
s
.127 0 0 r
.4923 .99191 m .48916 .99227 L .48956 .99213 L closepath p F P
0 g
s
.349 0 0 r
.32016 .99279 m .31979 .99271 L .32037 .99277 L closepath p F P
0 g
s
.541 .363 .589 r
.62457 .93053 m .62437 .92833 L .62703 .92973 L closepath p F P
0 g
s
.816 .688 .722 r
.16558 .86199 m .16484 .86073 L .16431 .8615 L closepath p F P
0 g
s
.8 .711 .766 r
.18149 .82352 m .18074 .82247 L .18024 .82302 L closepath p F P
0 g
s
.726 .734 .857 r
.28473 .75387 m .27403 .75995 L .27077 .75606 L p F P
0 g
s
.797 .712 .771 r
.18708 .81578 m .18074 .82247 L .17741 .81793 L p F P
0 g
s
.797 .712 .771 r
.17741 .81793 m .18154 .81357 L .18708 .81578 L p F P
0 g
s
.795 .714 .775 r
.18845 .80647 m .18154 .81357 L .18708 .81578 L p F P
0 g
s
0 0 .511 r
.5862 .24485 m .58454 .24255 L .58681 .24648 L p F P
0 g
s
0 0 .511 r
.58681 .24648 m .58904 .24941 L .5862 .24485 L p F P
0 g
s
.199 0 0 r
.31979 .99271 m .32016 .99279 L .31681 .99262 L p F P
0 g
s
.199 0 0 r
.31681 .99262 m .31088 .99164 L .31979 .99271 L p F P
0 g
s
.632 .635 .835 r
.54344 .76387 m .55445 .76103 L .55735 .76622 L p F P
0 g
s
.633 .641 .84 r
.55224 .75715 m .55445 .76103 L .54344 .76387 L p F P
0 g
s
.633 .641 .84 r
.54344 .76387 m .54161 .7607 L .55224 .75715 L p F P
0 g
s
.759 .793 .88 r
.66135 .25291 m .65029 .25998 L .64759 .25659 L p F P
0 g
s
.652 .739 .914 r
.45431 .75005 m .46517 .74672 L .46818 .75007 L p F P
0 g
s
.639 .767 .94 r
.46517 .74672 m .45431 .75005 L .45129 .74692 L p F P
0 g
s
.501 0 0 r
.28673 .98858 m .2847 .98825 L .2763 .98495 L p F P
0 g
s
.396 0 0 r
.2752 .98479 m .2763 .98495 L .2847 .98825 L p F P
0 g
s
.236 .739 .898 r
.40634 .99714 m .41708 .9964 L .4202 .99695 L p F P
0 g
s
.409 .807 .985 r
.40634 .99714 m .41708 .9964 L .41638 .99614 L p F P
0 g
s
.409 .807 .985 r
.40319 .99656 m .40634 .99714 L p .41638 .99614 L F P
0 g
s
.765 .725 .815 r
.23086 .77678 m .22445 .78176 L .22114 .7776 L p F P
0 g
s
0 .278 .782 r
.59181 .25404 m .59159 .25365 L .59187 .25409 L closepath p F P
0 g
s
.557 .442 .677 r
.64076 .89231 m .6403 .89027 L .64507 .89068 L closepath p F P
0 g
s
.823 .662 .683 r
.15835 .88282 m .16409 .88489 L .16087 .89112 L p F P
0 g
s
.821 .667 .692 r
.16409 .88489 m .15835 .88282 L .16191 .8765 L p F P
0 g
s
.806 .494 .461 r
.2087 .95971 m .20696 .95925 L .20587 .95412 L p F P
0 g
s
.808 .493 .456 r
.19931 .95236 m .20587 .95412 L .20696 .95925 L p F P
0 g
s
.349 .549 .907 r
.59187 .25409 m .59954 .25588 L .60149 .25991 L p F P
0 g
s
.362 .543 .898 r
.59159 .25365 m .59187 .25409 L .59954 .25588 L p F P
0 g
s
.894 .836 .782 r
.74607 .1677 m .74799 .1651 L .74965 .16929 L p F P
0 g
s
.894 .836 .782 r
.74965 .16929 m .74857 .17075 L .74607 .1677 L p F P
0 g
s
.289 0 0 r
.33394 .99427 m .33063 .9938 L .32016 .99279 L p F P
0 g
s
.197 .695 .915 r
.33063 .9938 m .32016 .99279 L .31681 .99262 L p F P
0 g
s
.86 .835 .821 r
.72967 .19956 m .72925 .20001 L .72872 .19843 L closepath p F P
0 g
s
.32 0 0 r
.52824 .98588 m .52934 .98483 L .54117 .98281 L p F P
0 g
s
.415 0 .091 r
.54209 .98164 m .54117 .98281 L .52934 .98483 L p F P
0 g
s
.817 .423 0 r
.5821 .23866 m .58454 .24255 L .58297 .2385 L p F P
0 g
s
.817 .423 0 r
.58297 .2385 m .58055 .2346 L .5821 .23866 L p F P
0 g
s
.368 0 .064 r
.55509 .97712 m .56659 .97476 L .56439 .97826 L p F P
0 g
s
.368 0 .064 r
.55312 .98033 m .55509 .97712 L p .56439 .97826 L F P
0 g
s
.466 .097 .254 r
.56693 .97397 m .56659 .97476 L .55509 .97712 L p F P
0 g
s
.43 .019 .155 r
.55509 .97712 m .55312 .98033 L .54209 .98164 L p F P
0 g
s
.847 .829 .83 r
.7209 .20294 m .72239 .20714 L .72925 .20001 L p F P
0 g
s
.847 .829 .83 r
.72712 .19648 m .7209 .20294 L p .72925 .20001 L F P
0 g
s
.847 .829 .83 r
.72925 .20001 m .72872 .19843 L .72712 .19648 L p F P
0 g
s
.396 0 0 r
.27216 .98553 m .2752 .98479 L p .2847 .98825 L F P
0 g
s
.591 .055 0 r
.27216 .98553 m .26844 .98359 L .2752 .98479 L closepath p F P
0 g
s
.112 0 0 r
.48916 .99227 m .48657 .99273 L .47568 .99378 L p F P
0 g
s
.263 .766 .877 r
.48657 .99273 m .47568 .99378 L .47267 .99397 L p F P
0 g
s
.07 0 0 r
.47568 .99378 m .47267 .99397 L .46181 .99501 L p F P
0 g
s
.818 .69 .723 r
.16431 .8615 m .16484 .86073 L .16157 .85529 L p F P
0 g
s
.234 .741 .889 r
.4202 .99695 m .43097 .99607 L .43406 .99655 L p F P
0 g
s
.413 .812 .984 r
.4202 .99695 m .43097 .99607 L .43007 .99576 L p F P
0 g
s
.413 .812 .984 r
.41708 .9964 m .4202 .99695 L p .43007 .99576 L F P
0 g
s
.654 .725 .901 r
.46818 .75007 m .47906 .74669 L .48205 .75027 L p F P
0 g
s
.647 .748 .923 r
.47906 .74669 m .46818 .75007 L .46517 .74672 L p F P
0 g
s
.805 .813 .857 r
.68827 .23812 m .68603 .23994 L .6834 .23671 L p F P
0 g
s
.362 .543 .898 r
.5974 .25191 m .58993 .24998 L .59159 .25365 L p F P
0 g
s
.362 .543 .898 r
.59954 .25588 m .5974 .25191 L p .59159 .25365 L F P
0 g
s
.078 .348 .821 r
.58904 .24941 m .58993 .24998 L .59159 .25365 L closepath p F P
0 g
s
.551 .426 .662 r
.64209 .89889 m .64076 .89231 L .64507 .89068 L p F P
0 g
s
.801 .713 .768 r
.18024 .82302 m .18074 .82247 L .17741 .81793 L p F P
0 g
s
.626 .628 .833 r
.56841 .76359 m .56939 .7654 L .55897 .76918 L p F P
0 g
s
.626 .628 .833 r
.55897 .76918 m .55735 .76622 L .56841 .76359 L p F P
0 g
s
.992 .746 .446 r
.76205 .08488 m .76429 .08898 L .76466 .08433 L p F P
0 g
s
.992 .746 .446 r
.76466 .08433 m .76242 .08023 L .76205 .08488 L p F P
0 g
s
.889 .837 .788 r
.74479 .17568 m .74857 .17075 L .74607 .1677 L p F P
0 g
s
.811 .699 .741 r
.1717 .83842 m .16822 .83701 L p .16842 .84601 L F P
0 g
s
.809 .705 .75 r
.1717 .83842 m .16959 .83535 L .16822 .83701 L closepath p F P
0 g
s
.821 .685 .713 r
.1588 .85932 m .16431 .8615 L .16015 .86797 L p F P
0 g
s
.818 .69 .723 r
.16157 .85529 m .1588 .85932 L .16431 .8615 L p F P
0 g
s
.606 .587 .806 r
.60507 .78832 m .59393 .79024 L .59105 .78405 L p F P
0 g
s
.803 .709 .761 r
.1748 .82078 m .18024 .82302 L .17408 .83006 L p F P
0 g
s
.801 .713 .768 r
.17741 .81793 m .1748 .82078 L .18024 .82302 L p F P
0 g
s
.343 .801 .94 r
.46181 .99501 m .47267 .99397 L .46975 .9934 L p F P
0 g
s
.343 .801 .94 r
.45877 .99489 m .46181 .99501 L p .46975 .9934 L F P
0 g
s
.035 0 0 r
.46181 .99501 m .45877 .99489 L .44793 .99591 L p F P
0 g
s
.211 .73 .863 r
.43406 .99655 m .44487 .99558 L .44793 .99591 L p F P
0 g
s
.404 .814 .978 r
.43406 .99655 m .44487 .99558 L .44349 .99515 L p F P
0 g
s
.404 .814 .978 r
.43097 .99607 m .43406 .99655 L p .44349 .99515 L F P
0 g
s
0 0 0 r
.48657 .99273 m .48916 .99227 L .4923 .99191 L p F P
0 g
s
.808 .815 .856 r
.68827 .23812 m .697 .2309 L .69439 .2277 L p F P
0 g
s
.808 .815 .856 r
.69439 .2277 m .68684 .23393 L .68827 .23812 L p F P
0 g
s
.805 .813 .857 r
.6834 .23671 m .68684 .23393 L .68827 .23812 L p F P
0 g
s
.765 .725 .815 r
.22114 .7776 m .22498 .77463 L .23086 .77678 L p F P
0 g
s
.764 .727 .819 r
.23195 .76937 m .22498 .77463 L .23086 .77678 L p F P
0 g
s
.764 .727 .819 r
.23086 .77678 m .23525 .77344 L .23195 .76937 L p F P
0 g
s
.381 .811 .965 r
.44793 .99591 m .45877 .99489 L .4567 .99435 L p F P
0 g
s
.381 .811 .965 r
.44487 .99558 m .44793 .99591 L p .4567 .99435 L F P
0 g
s
.811 .697 .739 r
.16291 .84381 m .16842 .84601 L .16339 .85273 L p F P
0 g
s
.811 .699 .741 r
.16822 .83701 m .16291 .84381 L .16842 .84601 L p F P
0 g
s
.824 .597 .595 r
.18065 .93056 m .17449 .92866 L .17569 .92296 L p F P
0 g
s
.825 .599 .596 r
.16958 .92103 m .17569 .92296 L .17449 .92866 L p F P
0 g
s
.824 .612 .617 r
.17569 .92296 m .16958 .92103 L .17124 .91521 L p F P
0 g
s
.592 .553 .779 r
.61373 .80825 m .62492 .80696 L p .61996 .81498 L F P
0 g
s
.591 .553 .781 r
.62334 .80309 m .62492 .80696 L .61373 .80825 L p F P
0 g
s
.591 .553 .781 r
.61373 .80825 m .61337 .80737 L .62334 .80309 L p F P
0 g
s
.826 .615 .617 r
.16543 .91333 m .17124 .91521 L .16958 .92103 L p F P
0 g
s
.823 .627 .638 r
.16532 .91292 m .1673 .90732 L p .17124 .91521 L F P
0 g
s
.823 .627 .638 r
.17124 .91521 m .16543 .91333 L .16532 .91292 L p F P
0 g
s
.754 .351 .287 r
.24031 .9752 m .23318 .97363 L .2298 .96907 L p F P
0 g
s
.744 .327 .259 r
.22658 .96838 m .2298 .96907 L .23318 .97363 L p F P
0 g
s
.974 .811 .62 r
.76261 .10815 m .76465 .11229 L .76631 .10713 L p F P
0 g
s
.974 .811 .62 r
.76631 .10713 m .76428 .10298 L .76261 .10815 L p F P
0 g
s
.54 .378 .611 r
.63457 .92123 m .63381 .91519 L .64421 .91154 L p F P
0 g
s
.548 .398 .629 r
.64352 .90704 m .64421 .91154 L .63381 .91519 L p F P
0 g
s
.548 .398 .629 r
.64047 .9063 m .64352 .90704 L p .63381 .91519 L F P
0 g
s
.952 .611 .22 r
.57796 .23075 m .58055 .2346 L .57983 .23025 L p F P
0 g
s
.952 .611 .22 r
.57983 .23025 m .57725 .2264 L .57796 .23075 L p F P
0 g
s
.824 .579 .57 r
.18614 .93802 m .17994 .93615 L .18065 .93056 L p F P
0 g
s
.825 .581 .57 r
.17449 .92866 m .18065 .93056 L .17994 .93615 L p F P
0 g
s
.846 .828 .829 r
.71626 .20764 m .7209 .20294 L .72239 .20714 L p F P
0 g
s
.846 .828 .829 r
.72239 .20714 m .71883 .21075 L .71626 .20764 L p F P
0 g
s
.515 .25 .45 r
.60313 .95307 m .60275 .95657 L .59167 .96005 L p F P
0 g
s
.508 .235 .435 r
.59156 .96085 m .59167 .96005 L .60275 .95657 L p F P
0 g
s
.53 .336 .562 r
.62703 .92973 m .62457 .93053 L .62488 .93616 L p F P
0 g
s
.373 0 .038 r
.54117 .98281 m .54209 .98164 L .55312 .98033 L p F P
0 g
s
.594 .562 .788 r
.62203 .8 m .62334 .80309 L .61337 .80737 L p F P
0 g
s
.594 .562 .788 r
.61337 .80737 m .61084 .80143 L .62203 .8 L p F P
0 g
s
.692 .221 .128 r
.25697 .98164 m .25286 .98082 L .2478 .97668 L p F P
0 g
s
.672 .182 .077 r
.24269 .97572 m .2478 .97668 L .25286 .98082 L p F P
0 g
s
.589 .543 .77 r
.61996 .81498 m .62782 .81417 L p .62708 .82199 L F P
0 g
s
.588 .543 .772 r
.62782 .81417 m .61996 .81498 L .62697 .812 L closepath p F P
0 g
s
.592 .553 .779 r
.62492 .80696 m .62697 .812 L .61996 .81498 L p F P
0 g
s
.633 .729 .916 r
.60874 .26383 m .6199 .26066 L .62266 .26434 L p F P
0 g
s
.625 .724 .918 r
.6199 .26066 m .60874 .26383 L .60595 .2599 L p F P
0 g
s
.641 .658 .851 r
.52663 .75718 m .53761 .7541 L .54053 .75887 L p F P
0 g
s
.641 .665 .857 r
.53761 .7541 m .52663 .75718 L .5237 .75257 L p F P
0 g
s
.653 .711 .89 r
.48205 .75027 m .49296 .74689 L .49592 .75072 L p F P
0 g
s
.65 .73 .907 r
.49296 .74689 m .48205 .75027 L .47906 .74669 L p F P
0 g
s
.826 .629 .636 r
.16532 .91292 m .1673 .90732 L .16352 .90605 L closepath p F P
0 g
s
.823 .639 .654 r
.16244 .90273 m .16385 .89929 L p .1673 .90732 L F P
0 g
s
.823 .639 .654 r
.1673 .90732 m .16352 .90605 L .16244 .90273 L p F P
0 g
s
.748 .731 .836 r
.25689 .75875 m .26005 .7626 L p .24602 .76574 L F P
0 g
s
.737 .726 .841 r
.26005 .7626 m .26327 .76061 L .25689 .75875 L closepath p F P
0 g
s
.84 .827 .836 r
.71501 .21447 m .71883 .21075 L .71626 .20764 L p F P
0 g
s
.618 .61 .821 r
.58528 .77225 m .5854 .77249 L .57515 .77646 L p F P
0 g
s
.618 .61 .821 r
.57515 .77646 m .57419 .77459 L .58528 .77225 L p F P
0 g
s
.714 .736 .869 r
.28473 .75387 m .28939 .75151 L .29627 .75335 L p F P
0 g
s
.719 .742 .87 r
.29542 .74849 m .28939 .75151 L .29627 .75335 L p F P
0 g
s
.719 .742 .87 r
.29627 .75335 m .29866 .75211 L .29542 .74849 L p F P
0 g
s
.756 .728 .827 r
.24277 .76803 m .23525 .77344 L .23195 .76937 L p F P
0 g
s
.822 .672 .696 r
.15627 .87438 m .16191 .8765 L .15835 .88282 L p F P
0 g
s
.821 .676 .703 r
.16191 .8765 m .15627 .87438 L .16015 .86797 L p F P
0 g
s
.073 0 0 r
.50047 .99111 m .4923 .99191 L .50155 .99078 L closepath p F P
0 g
s
0 0 0 r
.4923 .99191 m .50047 .99111 L p .48657 .99273 L F P
0 g
s
.817 .817 .85 r
.69819 .22987 m .697 .2309 L .69439 .2277 L p F P
0 g
s
.822 .559 .541 r
.19022 .94474 m .18595 .94348 L .18614 .93802 L p F P
0 g
s
.824 .561 .54 r
.17994 .93615 m .18614 .93802 L .18595 .94348 L p F P
0 g
s
.921 .839 .747 r
.7566 .15242 m .75636 .15281 L .75583 .15151 L closepath p F P
0 g
s
.816 .819 .852 r
.69671 .22569 m .69819 .22987 L .70706 .22201 L p F P
0 g
s
.817 .817 .85 r
.69439 .2277 m .69671 .22569 L .69819 .22987 L p F P
0 g
s
.835 .825 .838 r
.70565 .21779 m .71358 .21025 L .71501 .21447 L p F P
0 g
s
.835 .825 .838 r
.70607 .21895 m .70565 .21779 L p .71501 .21447 L F P
0 g
s
.835 .825 .838 r
.71501 .21447 m .70794 .2212 L .70607 .21895 L p F P
0 g
s
.84 .827 .836 r
.71626 .20764 m .71358 .21025 L .71501 .21447 L p F P
0 g
s
.579 .513 .744 r
.63656 .8378 m .63435 .83794 L .63633 .83713 L closepath p F P
0 g
s
.584 .523 .752 r
.63363 .82951 m .63633 .83713 L .63435 .83794 L p F P
0 g
s
.584 .523 .752 r
.63188 .82965 m .63363 .82951 L p .63435 .83794 L F P
0 g
s
.671 .757 .915 r
.32645 .74982 m .33712 .74597 L .34032 .74913 L p F P
0 g
s
.653 .769 .934 r
.33712 .74597 m .32645 .74982 L .32323 .74647 L p F P
0 g
s
.686 .749 .899 r
.31257 .7508 m .32323 .74647 L .32645 .74982 L p F P
0 g
s
.944 .83 .702 r
.76343 .12974 m .76192 .12792 L .76228 .12718 L closepath p F P
0 g
s
.904 .836 .767 r
.75057 .15472 m .7523 .1589 L .75636 .15281 L p F P
0 g
s
.904 .836 .767 r
.75412 .14939 m .75057 .15472 L p .75636 .15281 L F P
0 g
s
.904 .836 .767 r
.75636 .15281 m .75583 .15151 L .75412 .14939 L p F P
0 g
s
.624 .782 .957 r
.351 .74573 m .34032 .74913 L .33712 .74597 L p F P
0 g
s
.653 .767 .933 r
.34032 .74913 m .351 .74573 L .35419 .74868 L p F P
0 g
s
.984 .701 .356 r
.76009 .07614 m .76242 .08023 L .76234 .07575 L p F P
0 g
s
.984 .701 .356 r
.76234 .07575 m .76002 .07166 L .76009 .07614 L p F P
0 g
s
.828 .825 .845 r
.70794 .2212 m .70706 .22201 L .70607 .21895 L closepath p F P
0 g
s
.816 .819 .852 r
.70535 .21806 m .69671 .22569 L p .70706 .22201 L F P
0 g
s
.816 .819 .852 r
.70706 .22201 m .70607 .21895 L .70535 .21806 L p F P
0 g
s
.676 .758 .913 r
.32323 .74647 m .31257 .7508 L .30934 .7473 L p F P
0 g
s
.735 .775 .885 r
.64364 .25882 m .63651 .2628 L .63377 .25928 L p F P
0 g
s
.701 .764 .901 r
.62266 .26434 m .63377 .25928 L .63651 .2628 L p F P
0 g
s
.787 .434 .389 r
.22276 .96746 m .21591 .9658 L .2138 .96092 L p F P
0 g
s
.784 .426 .378 r
.2087 .95971 m .2138 .96092 L .21591 .9658 L p F P
0 g
s
.806 .706 .754 r
.17408 .83006 m .16959 .83535 L .16626 .83058 L p F P
0 g
s
.806 .706 .754 r
.16626 .83058 m .16858 .82785 L .17408 .83006 L p F P
0 g
s
.803 .709 .761 r
.17408 .83006 m .16858 .82785 L .1748 .82078 L p F P
0 g
s
.633 .777 .95 r
.35419 .74868 m .36487 .74566 L .36805 .74839 L p F P
0 g
s
.588 .795 .978 r
.36487 .74566 m .35419 .74868 L .351 .74573 L p F P
0 g
s
.174 0 0 r
.34775 .9953 m .34448 .99459 L .33394 .99427 L p F P
0 g
s
.307 .752 .963 r
.33394 .99427 m .34448 .99459 L .34295 .99403 L p F P
0 g
s
.307 .752 .963 r
.33063 .9938 m .33394 .99427 L p .34295 .99403 L F P
0 g
s
.889 .837 .788 r
.74607 .1677 m .74318 .17148 L .74479 .17568 L p F P
0 g
s
.882 .835 .795 r
.73797 .17802 m .73961 .1822 L .74479 .17568 L p F P
0 g
s
.882 .835 .795 r
.74479 .17568 m .74318 .17148 L .73797 .17802 L p F P
0 g
s
.827 .641 .652 r
.16244 .90273 m .16385 .89929 L .16098 .8983 L closepath p F P
0 g
s
.823 .651 .669 r
.15942 .89425 m .16087 .89112 L p .16385 .89929 L F P
0 g
s
.823 .651 .669 r
.16385 .89929 m .16098 .8983 L .15942 .89425 L p F P
0 g
s
.978 .684 .387 r
.5745 .22259 m .57725 .2264 L .57715 .22184 L p F P
0 g
s
.978 .684 .387 r
.57715 .22184 m .57439 .21803 L .5745 .22259 L p F P
0 g
s
.635 .648 .846 r
.55155 .75597 m .55224 .75715 L .54161 .7607 L p F P
0 g
s
.635 .648 .846 r
.54161 .7607 m .54053 .75887 L .55155 .75597 L p F P
0 g
s
.955 .824 .676 r
.76031 .12303 m .76228 .12718 L .7646 .12175 L p F P
0 g
s
.955 .824 .676 r
.7646 .12175 m .76265 .11759 L .76031 .12303 L p F P
0 g
s
.48 .174 .37 r
.59057 .96537 m .59156 .96085 L .60258 .95795 L p F P
0 g
s
.508 .235 .435 r
.60275 .95657 m .60258 .95795 L .59156 .96085 L p F P
0 g
s
.494 .188 .375 r
.59156 .96085 m .59057 .96537 L .5794 .96809 L p F P
0 g
s
.264 0 0 r
.31088 .99164 m .31681 .99262 L p .30303 .99091 L F P
0 g
s
.264 0 0 r
.30303 .99091 m .30384 .99089 L .31088 .99164 L p F P
0 g
s
.732 .729 .848 r
.26749 .75223 m .27077 .75606 L .26327 .76061 L p F P
0 g
s
.732 .729 .848 r
.25677 .75861 m .26749 .75223 L p .26327 .76061 L F P
0 g
s
.732 .729 .848 r
.26327 .76061 m .25689 .75875 L .25677 .75861 L p F P
0 g
s
.647 .682 .869 r
.52077 .7482 m .52191 .74987 L .5108 .75291 L p F P
0 g
s
.647 .682 .869 r
.5108 .75291 m .5098 .75144 L .52077 .7482 L p F P
0 g
s
.503 .24 .448 r
.60275 .95657 m .60313 .95307 L .614 .95 L p F P
0 g
s
.523 .285 .495 r
.61422 .94483 m .614 .95 L .60313 .95307 L p F P
0 g
s
.694 .75 .895 r
.30934 .7473 m .29866 .75211 L .29542 .74849 L p F P
0 g
s
.931 .833 .726 r
.75622 .13859 m .75807 .14275 L .76125 .13699 L p F P
0 g
s
.931 .833 .726 r
.76125 .13699 m .75942 .13282 L .75622 .13859 L p F P
0 g
s
.811 .524 .503 r
.19931 .95236 m .19274 .9506 L .19229 .94531 L p F P
0 g
s
.812 .525 .503 r
.19022 .94474 m .19229 .94531 L .19274 .9506 L p F P
0 g
s
.615 .787 .964 r
.36805 .74839 m .37875 .74567 L .38191 .74819 L p F P
0 g
s
.548 .805 .993 r
.37875 .74567 m .36805 .74839 L .36487 .74566 L p F P
0 g
s
.651 .697 .88 r
.49592 .75072 m .50686 .74738 L .5098 .75144 L p F P
0 g
s
.65 .712 .893 r
.50686 .74738 m .49592 .75072 L .49296 .74689 L p F P
0 g
s
.618 .614 .825 r
.58528 .77225 m .57419 .77459 L .5713 .76902 L p F P
0 g
s
.744 .327 .259 r
.22448 .97026 m .22658 .96838 L p .23318 .97363 L F P
0 g
s
.772 .385 .322 r
.22448 .97026 m .22276 .96746 L .22658 .96838 L closepath p F P
0 g
s
.627 .632 .837 r
.56841 .76359 m .55735 .76622 L .55445 .76103 L p F P
0 g
s
.857 .83 .82 r
.72872 .19843 m .72712 .19648 L .72776 .1958 L closepath p F P
0 g
s
.697 .76 .901 r
.63377 .25928 m .62266 .26434 L .6199 .26066 L p F P
0 g
s
.587 .533 .761 r
.62708 .82199 m .63072 .82166 L p .63188 .82965 L F P
0 g
s
.585 .533 .763 r
.63072 .82166 m .62708 .82199 L .63034 .82063 L closepath p F P
0 g
s
.589 .543 .77 r
.62782 .81417 m .63034 .82063 L .62708 .82199 L p F P
0 g
s
.491 .647 .927 r
.60315 .25597 m .59954 .25588 L .60149 .25991 L p F P
0 g
s
.491 .647 .927 r
.60149 .25991 m .60595 .2599 L .60315 .25597 L p F P
0 g
s
.958 .633 .234 r
.7576 .06759 m .76002 .07166 L .75945 .06739 L p F P
0 g
s
.958 .633 .234 r
.75945 .06739 m .75704 .06332 L .7576 .06759 L p F P
0 g
s
.776 .797 .87 r
.66268 .25199 m .66135 .25291 L .65866 .24955 L p F P
0 g
s
.759 .793 .88 r
.64759 .25659 m .65866 .24955 L .66135 .25291 L p F P
0 g
s
.582 .523 .754 r
.63363 .82951 m .63188 .82965 L .63345 .829 L closepath p F P
0 g
s
.587 .533 .761 r
.63072 .82166 m .63345 .829 L .63188 .82965 L p F P
0 g
s
.53 .336 .562 r
.62488 .93616 m .62979 .93457 L .62703 .92973 L p F P
0 g
s
.529 .335 .563 r
.63512 .92708 m .62703 .92973 L .62979 .93457 L p F P
0 g
s
.541 .363 .589 r
.63457 .92123 m .63512 .92708 L .62703 .92973 L p F P
0 g
s
.569 .497 .735 r
.64146 .85273 m .6395 .84661 L .6508 .84649 L p F P
0 g
s
.568 .497 .735 r
.64895 .84075 m .6508 .84649 L .6395 .84661 L p F P
0 g
s
.568 .497 .735 r
.6395 .84661 m .639 .84503 L .64895 .84075 L p F P
0 g
s
.572 .508 .745 r
.64784 .83748 m .64895 .84075 L .639 .84503 L p F P
0 g
s
.572 .508 .745 r
.639 .84503 m .63656 .8378 L .64784 .83748 L p F P
0 g
s
.566 .487 .725 r
.64146 .85273 m .65144 .84849 L p .65351 .85614 L F P
0 g
s
.566 .487 .725 r
.65351 .85614 m .64247 .85606 L .64146 .85273 L p F P
0 g
s
.569 .497 .735 r
.6508 .84649 m .65144 .84849 L .64146 .85273 L p F P
0 g
s
.811 .697 .739 r
.15828 .84996 m .16291 .84381 L p .16339 .85273 L F P
0 g
s
.811 .697 .739 r
.16339 .85273 m .15895 .85099 L .15828 .84996 L p F P
0 g
s
.816 .691 .726 r
.16157 .85529 m .16339 .85273 L .15895 .85099 L closepath p F P
0 g
s
.756 .728 .827 r
.23195 .76937 m .23682 .7659 L .24277 .76803 L p F P
0 g
s
.756 .731 .83 r
.24272 .76177 m .23682 .7659 L .24277 .76803 L p F P
0 g
s
.756 .731 .83 r
.24277 .76803 m .24602 .76574 L .24272 .76177 L p F P
0 g
s
.375 0 0 r
.30179 .99061 m .2933 .98942 L .2893 .98832 L p F P
0 g
s
.394 0 0 r
.2933 .98942 m .28673 .98858 L .2893 .98832 L closepath p F P
0 g
s
.545 .41 .648 r
.64325 .90531 m .64209 .89889 L .65233 .89502 L p F P
0 g
s
.555 .416 .647 r
.64209 .89889 m .64325 .90531 L .64047 .9063 L p F P
0 g
s
.551 .426 .662 r
.65164 .89167 m .65233 .89502 L .64209 .89889 L p F P
0 g
s
.551 .426 .662 r
.64507 .89068 m .65164 .89167 L p .64209 .89889 L F P
0 g
s
.524 0 0 r
.26844 .98359 m .27216 .98553 L .26894 .98578 L p F P
0 g
s
.524 0 0 r
.26052 .98224 m .26844 .98359 L p .26894 .98578 L F P
0 g
s
.642 .143 .05 r
.26844 .98359 m .26052 .98224 L .25856 .981 L p F P
0 g
s
.601 .794 .973 r
.38191 .74819 m .39264 .74564 L .39578 .74801 L p F P
0 g
s
.514 .812 .999 r
.39264 .74564 m .38191 .74819 L .37875 .74567 L p F P
0 g
s
.566 .487 .725 r
.64373 .86023 m .64247 .85606 L .65351 .85614 L closepath p F P
0 g
s
.594 .563 .789 r
.61942 .79388 m .62203 .8 L .61084 .80143 L p F P
0 g
s
.594 .563 .789 r
.61084 .80143 m .60946 .79819 L .61942 .79388 L p F P
0 g
s
.826 .653 .667 r
.15942 .89425 m .16087 .89112 L .15776 .89001 L closepath p F P
0 g
s
.823 .662 .683 r
.15631 .88676 m .15835 .88282 L p .16087 .89112 L F P
0 g
s
.823 .662 .683 r
.16087 .89112 m .15776 .89001 L .15631 .88676 L p F P
0 g
s
.777 .798 .87 r
.66268 .25199 m .67238 .24512 L .66972 .2418 L p F P
0 g
s
.777 .798 .87 r
.66972 .2418 m .66113 .24784 L .66268 .25199 L p F P
0 g
s
.776 .797 .87 r
.65866 .24955 m .66113 .24784 L .66268 .25199 L p F P
0 g
s
.81 .707 .751 r
.16822 .83701 m .16959 .83535 L .16626 .83058 L p F P
0 g
s
.991 .782 .525 r
.76401 .09069 m .76345 .09383 L .76556 .09796 L p F P
0 g
s
.981 .798 .582 r
.76215 .09885 m .76428 .10298 L .76556 .09796 L p F P
0 g
s
.981 .798 .582 r
.76556 .09796 m .76345 .09383 L .76215 .09885 L p F P
0 g
s
.782 .723 .797 r
.2052 .79093 m .1994 .79609 L .19606 .79185 L p F P
0 g
s
.787 .723 .792 r
.19661 .79868 m .1994 .79609 L .19606 .79185 L p F P
0 g
s
.439 .079 .256 r
.5794 .96809 m .59057 .96537 L .58914 .96951 L p F P
0 g
s
.439 .079 .256 r
.57801 .97206 m .5794 .96809 L p .58914 .96951 L F P
0 g
s
.47 .122 .293 r
.5794 .96809 m .57801 .97206 L .56693 .97397 L p F P
0 g
s
.786 .72 .791 r
.19112 .79643 m .19661 .79868 L .18867 .80624 L p F P
0 g
s
.787 .723 .792 r
.19606 .79185 m .19112 .79643 L .19661 .79868 L p F P
0 g
s
.823 .679 .705 r
.15461 .86581 m .16015 .86797 L .15627 .87438 L p F P
0 g
s
.821 .685 .713 r
.16015 .86797 m .15461 .86581 L .1588 .85932 L p F P
0 g
s
.642 .145 .054 r
.26052 .98224 m .25697 .98164 L .25856 .981 L closepath p F P
0 g
s
.571 .508 .745 r
.64626 .8328 m .64784 .83748 L .63656 .8378 L p F P
0 g
s
.571 .508 .745 r
.63656 .8378 m .63633 .83713 L .64626 .8328 L p F P
0 g
s
.708 .736 .873 r
.28939 .75151 m .28473 .75387 L .28147 .75008 L p F P
0 g
s
.726 .734 .857 r
.27077 .75606 m .28147 .75008 L .28473 .75387 L p F P
0 g
s
.782 .723 .797 r
.19606 .79185 m .19959 .7887 L .2052 .79093 L p F P
0 g
s
.78 .725 .801 r
.20697 .7823 m .19959 .7887 L .2052 .79093 L p F P
0 g
s
.78 .725 .801 r
.2052 .79093 m .21029 .78649 L .20697 .7823 L p F P
0 g
s
.562 .476 .715 r
.64373 .86023 m .65351 .85614 L p .64863 .8664 L F P
0 g
s
.562 .476 .715 r
.64863 .8664 m .64546 .8663 L .64373 .86023 L p F P
0 g
s
.575 .518 .754 r
.64491 .82901 m .64626 .8328 L .63633 .83713 L p F P
0 g
s
.575 .518 .754 r
.63633 .83713 m .63363 .82951 L .64491 .82901 L p F P
0 g
s
.672 .182 .077 r
.24148 .97641 m .24269 .97572 L p .25286 .98082 L F P
0 g
s
.728 .289 .207 r
.24148 .97641 m .24031 .9752 L .24269 .97572 L closepath p F P
0 g
s
.606 .587 .806 r
.59105 .78405 m .60219 .78215 L .60507 .78832 L p F P
0 g
s
.606 .589 .808 r
.60056 .7787 m .60219 .78215 L .59105 .78405 L p F P
0 g
s
.606 .589 .808 r
.59105 .78405 m .5905 .7829 L .60056 .7787 L p F P
0 g
s
.772 .368 0 r
.75204 .05201 m .75343 .0552 L .75594 .05926 L p F P
0 g
s
.898 .528 .068 r
.75453 .05926 m .75704 .06332 L .75594 .05926 L p F P
0 g
s
.898 .528 .068 r
.75594 .05926 m .75343 .0552 L .75453 .05926 L p F P
0 g
s
.791 .716 .781 r
.18845 .80647 m .18867 .80624 L .18811 .80602 L closepath p F P
0 g
s
.786 .72 .791 r
.18511 .80216 m .19112 .79643 L p .18867 .80624 L F P
0 g
s
.786 .72 .791 r
.18867 .80624 m .18811 .80602 L .18511 .80216 L p F P
0 g
s
.796 .717 .777 r
.18154 .81357 m .18845 .80647 L .18811 .80602 L p F P
0 g
s
.773 .724 .807 r
.21457 .78294 m .21029 .78649 L .20697 .7823 L p F P
0 g
s
.813 .703 .744 r
.16283 .83478 m .16822 .83701 L .16291 .84381 L p F P
0 g
s
.81 .707 .751 r
.16626 .83058 m .16283 .83478 L .16822 .83701 L p F P
0 g
s
.528 .313 .532 r
.62488 .93616 m .62494 .94158 L .61422 .94483 L p F P
0 g
s
.511 .275 .492 r
.62494 .94158 m .61422 .94483 L .614 .95 L p F P
0 g
s
.596 .799 .977 r
.39578 .74801 m .40653 .7455 L .40965 .74779 L p F P
0 g
s
.498 .817 1 r
.40653 .7455 m .39578 .74801 L .39264 .74564 L p F P
0 g
s
.748 .731 .836 r
.24602 .76574 m .25667 .75867 L .25689 .75875 L p F P
0 g
s
.747 .735 .84 r
.25667 .75867 m .24602 .76574 L .24272 .76177 L p F P
0 g
s
.546 .397 .63 r
.64352 .90704 m .64047 .9063 L .64325 .90531 L closepath p F P
0 g
s
.636 .655 .852 r
.55155 .75597 m .54053 .75887 L .53761 .7541 L p F P
0 g
s
.232 .723 .921 r
.35847 .99511 m .35809 .99508 L .34775 .9953 L p F P
0 g
s
.198 .709 .896 r
.35809 .99508 m .34775 .9953 L .34448 .99459 L p F P
0 g
s
.913 .834 .755 r
.75583 .15151 m .75412 .14939 L .75461 .14863 L closepath p F P
0 g
s
.812 .525 .503 r
.19274 .9506 m .18884 .94954 L .19022 .94474 L p F P
0 g
s
.822 .536 .505 r
.18595 .94348 m .19022 .94474 L .18884 .94954 L p F P
0 g
s
.82 .692 .723 r
.1588 .85932 m .16157 .85529 L .15895 .85099 L p F P
0 g
s
.442 .069 .233 r
.56659 .97476 m .56693 .97397 L .57801 .97206 L p F P
0 g
s
.874 .832 .802 r
.73537 .18113 m .73797 .17802 L .73961 .1822 L p F P
0 g
s
.874 .832 .802 r
.73961 .1822 m .7379 .18425 L .73537 .18113 L p F P
0 g
s
.648 .696 .881 r
.52077 .7482 m .5098 .75144 L .50686 .74738 L p F P
0 g
s
.337 0 0 r
.30303 .99091 m .30179 .99061 L .30384 .99089 L closepath p F P
0 g
s
.773 .724 .807 r
.20697 .7823 m .20885 .78074 L .21457 .78294 L p F P
0 g
s
.772 .727 .811 r
.21782 .77348 m .20885 .78074 L .21457 .78294 L p F P
0 g
s
.772 .727 .811 r
.21457 .78294 m .22114 .7776 L .21782 .77348 L p F P
0 g
s
.808 .493 .456 r
.20696 .95925 m .20044 .95748 L .19931 .95236 L p F P
0 g
s
.808 .491 .453 r
.19274 .9506 m .19931 .95236 L .20044 .95748 L p F P
0 g
s
.796 .717 .777 r
.18811 .80602 m .18326 .80398 L p .18154 .81357 L F P
0 g
s
.794 .722 .784 r
.18811 .80602 m .18511 .80216 L .18326 .80398 L closepath p F P
0 g
s
.609 .597 .814 r
.5993 .7761 m .60056 .7787 L .5905 .7829 L p F P
0 g
s
.609 .597 .814 r
.5905 .7829 m .58817 .77811 L .5993 .7761 L p F P
0 g
s
.562 .475 .714 r
.64582 .86755 m .64546 .8663 L .64863 .8664 L closepath p F P
0 g
s
.601 .799 .975 r
.40965 .74779 m .42043 .74521 L .42353 .74752 L p F P
0 g
s
.508 .822 1 r
.42043 .74521 m .40965 .74779 L .40653 .7455 L p F P
0 g
s
.55 .426 .664 r
.65164 .89167 m .64507 .89068 L .65097 .88842 L closepath p F P
0 g
s
.557 .442 .678 r
.64943 .88164 m .65097 .88842 L .64507 .89068 L p F P
0 g
s
.557 .462 .703 r
.64772 .87468 m .64582 .86755 L .64863 .8664 L p F P
0 g
s
.054 0 0 r
.50047 .99111 m .50155 .99078 L .5138 .98915 L p F P
0 g
s
.2 0 0 r
.51437 .98892 m .5138 .98915 L .50155 .99078 L p F P
0 g
s
.83 .631 .634 r
.16352 .90605 m .16142 .90531 L p .16521 .91325 L F P
0 g
s
.83 .631 .634 r
.16521 .91325 m .16532 .91292 L .16352 .90605 L p F P
0 g
s
.83 .642 .649 r
.16352 .90605 m .16244 .90273 L .16142 .90531 L closepath p F P
0 g
s
.575 .518 .755 r
.64334 .82463 m .64491 .82901 L .63363 .82951 L p F P
0 g
s
.575 .518 .755 r
.63363 .82951 m .63345 .829 L .64334 .82463 L p F P
0 g
s
.32 0 0 r
.54117 .98281 m .53925 .98449 L .52824 .98588 L p F P
0 g
s
.192 0 0 r
.52586 .98732 m .52824 .98588 L .53925 .98449 L p F P
0 g
s
.901 .834 .771 r
.74623 .16093 m .74799 .1651 L .7523 .1589 L p F P
0 g
s
.901 .834 .771 r
.7523 .1589 m .75057 .15472 L .74623 .16093 L p F P
0 g
s
.831 .643 .65 r
.16142 .90531 m .16244 .90273 L .16098 .8983 L p F P
0 g
s
.597 .572 .796 r
.61914 .79324 m .61942 .79388 L .60946 .79819 L p F P
0 g
s
.597 .572 .796 r
.60946 .79819 m .60795 .7948 L .61914 .79324 L p F P
0 g
s
.578 .529 .763 r
.64198 .82098 m .64334 .82463 L .63345 .829 L p F P
0 g
s
.578 .529 .763 r
.63345 .829 m .63072 .82166 L .64198 .82098 L p F P
0 g
s
.798 .715 .772 r
.18154 .81357 m .17741 .81793 L .17407 .81344 L p F P
0 g
s
.798 .715 .772 r
.17407 .81344 m .17606 .81133 L .18154 .81357 L p F P
0 g
s
.796 .717 .777 r
.18326 .80398 m .17606 .81133 L .18154 .81357 L p F P
0 g
s
.831 .643 .65 r
.16098 .8983 m .15808 .89724 L p .16142 .90531 L F P
0 g
s
.83 .654 .664 r
.16098 .8983 m .15942 .89425 L .15808 .89724 L closepath p F P
0 g
s
.869 .832 .808 r
.73386 .18893 m .7379 .18425 L .73537 .18113 L p F P
0 g
s
.826 .664 .681 r
.15631 .88676 m .15835 .88282 L .15378 .88112 L closepath p F P
0 g
s
.822 .672 .696 r
.15315 .87988 m .15627 .87438 L p .15835 .88282 L F P
0 g
s
.822 .672 .696 r
.15835 .88282 m .15378 .88112 L .15315 .87988 L p F P
0 g
s
.734 .779 .889 r
.64364 .25882 m .64759 .25659 L .64488 .25316 L p F P
0 g
s
.734 .779 .889 r
.64488 .25316 m .64224 .25462 L .64364 .25882 L p F P
0 g
s
.735 .775 .885 r
.63377 .25928 m .64224 .25462 L .64364 .25882 L p F P
0 g
s
.539 .825 .998 r
.43434 .74478 m .42353 .74752 L .42043 .74521 L p F P
0 g
s
.613 .793 .968 r
.42353 .74752 m .43434 .74478 L .4374 .74721 L p F P
0 g
s
.712 .246 .144 r
.24031 .9752 m .24148 .97641 L .23788 .97788 L p F P
0 g
s
.712 .246 .144 r
.23318 .97363 m .24031 .9752 L p .23788 .97788 L F P
0 g
s
.194 0 0 r
.30179 .99061 m .30303 .99091 L .29965 .99056 L p F P
0 g
s
.194 0 0 r
.29965 .99056 m .2933 .98942 L .30179 .99061 L p F P
0 g
s
.765 .726 .817 r
.22498 .77463 m .22114 .7776 L .21782 .77348 L p F P
0 g
s
.724 .742 .865 r
.28147 .75008 m .27077 .75606 L .26749 .75223 L p F P
0 g
s
.77 .37 .295 r
.22276 .96746 m .22448 .97026 L .22287 .9714 L p F P
0 g
s
.77 .37 .295 r
.21591 .9658 m .22276 .96746 L p .22287 .9714 L F P
0 g
s
.53 .355 .589 r
.63512 .92708 m .63457 .92123 L .64498 .91759 L p F P
0 g
s
.54 .378 .611 r
.64421 .91154 m .64498 .91759 L .63457 .92123 L p F P
0 g
s
.784 .426 .378 r
.20765 .96117 m .2087 .95971 L p .21591 .9658 L F P
0 g
s
.799 .457 .409 r
.20765 .96117 m .20696 .95925 L .2087 .95971 L closepath p F P
0 g
s
.962 .816 .652 r
.7606 .11346 m .76265 .11759 L .76465 .11229 L p F P
0 g
s
.962 .816 .652 r
.76465 .11229 m .76261 .10815 L .7606 .11346 L p F P
0 g
s
.27 0 0 r
.53925 .98449 m .54117 .98281 L .55287 .98063 L p F P
0 g
s
.373 0 .038 r
.55312 .98033 m .55287 .98063 L .54117 .98281 L p F P
0 g
s
.803 .715 .768 r
.1748 .82078 m .17741 .81793 L .17407 .81344 L p F P
0 g
s
.01 .313 .803 r
.58993 .24998 m .58904 .24941 L .5862 .24485 L p F P
0 g
s
.83 .655 .664 r
.15808 .89724 m .15942 .89425 L .15776 .89001 L p F P
0 g
s
.308 .762 .956 r
.37341 .99573 m .36943 .99553 L .36159 .99598 L p F P
0 g
s
.29 .756 .944 r
.36943 .99553 m .35847 .99511 L .36159 .99598 L closepath p F P
0 g
s
.627 .782 .956 r
.4374 .74721 m .44824 .74429 L .45129 .74692 L p F P
0 g
s
.577 .819 .99 r
.44824 .74429 m .4374 .74721 L .43434 .74478 L p F P
0 g
s
.83 .631 .634 r
.16543 .91333 m .16532 .91292 L .16521 .91325 L closepath p F P
0 g
s
.989 .773 .521 r
.76156 .08785 m .76205 .08488 L .76429 .08898 L p F P
0 g
s
.989 .773 .521 r
.76429 .08898 m .76401 .09069 L .76156 .08785 L p F P
0 g
s
.825 .599 .596 r
.17449 .92866 m .16835 .92675 L .16958 .92103 L p F P
0 g
s
.827 .601 .596 r
.16667 .9201 m .16958 .92103 L .16835 .92675 L p F P
0 g
s
.826 .615 .617 r
.16958 .92103 m .16667 .9201 L .16543 .91333 L p F P
0 g
s
.832 .619 .614 r
.16521 .91325 m .16543 .91333 L .16667 .9201 L p F P
0 g
s
.765 .726 .817 r
.21782 .77348 m .21914 .77247 L .22498 .77463 L p F P
0 g
s
.764 .73 .821 r
.22863 .76534 m .21914 .77247 L .22498 .77463 L p F P
0 g
s
.764 .73 .821 r
.22498 .77463 m .23195 .76937 L .22863 .76534 L p F P
0 g
s
.708 .736 .873 r
.28147 .75008 m .28212 .74977 L .28939 .75151 L p F P
0 g
s
.714 .746 .877 r
.29216 .74496 m .28212 .74977 L .28939 .75151 L p F P
0 g
s
.714 .746 .877 r
.28939 .75151 m .29542 .74849 L .29216 .74496 L p F P
0 g
s
.79 .804 .863 r
.67569 .24262 m .67238 .24512 L .66972 .2418 L p F P
0 g
s
.823 .688 .715 r
.15336 .85712 m .1588 .85932 L .15461 .86581 L p F P
0 g
s
.82 .692 .723 r
.15785 .85055 m .15336 .85712 L .1588 .85932 L p F P
0 g
s
.82 .692 .723 r
.15895 .85099 m .15785 .85055 L p .1588 .85932 L F P
0 g
s
.825 .581 .57 r
.17994 .93615 m .17376 .93425 L .17449 .92866 L p F P
0 g
s
.826 .583 .571 r
.16835 .92675 m .17449 .92866 L .17376 .93425 L p F P
0 g
s
.835 .622 .615 r
.15944 .91121 m .16521 .91325 L .16363 .91906 L p F P
0 g
s
.83 .631 .634 r
.16142 .90531 m .15944 .91121 L .16521 .91325 L p F P
0 g
s
.832 .619 .614 r
.16667 .9201 m .16363 .91906 L .16521 .91325 L p F P
0 g
s
.803 .715 .768 r
.17407 .81344 m .16943 .81852 L .1748 .82078 L p F P
0 g
s
.804 .712 .763 r
.16943 .81852 m .1748 .82078 L .16858 .82785 L p F P
0 g
s
.922 .831 .739 r
.75274 .14447 m .75461 .14863 L .75807 .14275 L p F P
0 g
s
.922 .831 .739 r
.75807 .14275 m .75622 .13859 L .75274 .14447 L p F P
0 g
s
.553 .45 .691 r
.64772 .87468 m .65776 .87054 L p .65663 .87871 L F P
0 g
s
.553 .45 .691 r
.65663 .87871 m .64851 .87789 L .64772 .87468 L p F P
0 g
s
.557 .462 .703 r
.65681 .86698 m .65776 .87054 L .64772 .87468 L p F P
0 g
s
.557 .462 .703 r
.64863 .8664 m .65681 .86698 L p .64772 .87468 L F P
0 g
s
.869 .832 .808 r
.73537 .18113 m .73226 .18474 L .73386 .18893 L p F P
0 g
s
.863 .83 .813 r
.72612 .19162 m .72776 .1958 L .73386 .18893 L p F P
0 g
s
.863 .83 .813 r
.73386 .18893 m .73226 .18474 L .72612 .19162 L p F P
0 g
s
.639 .767 .94 r
.45129 .74692 m .46216 .74382 L .46517 .74672 L p F P
0 g
s
.61 .803 .974 r
.46216 .74382 m .45129 .74692 L .44824 .74429 L p F P
0 g
s
.578 .529 .764 r
.6402 .81622 m .64198 .82098 L .63072 .82166 L p F P
0 g
s
.578 .529 .764 r
.63072 .82166 m .63034 .82063 L .6402 .81622 L p F P
0 g
s
.815 .699 .737 r
.16291 .84381 m .15828 .84996 L .15496 .84493 L p F P
0 g
s
.815 .699 .737 r
.15496 .84493 m .15746 .8416 L .16291 .84381 L p F P
0 g
s
.813 .703 .744 r
.16291 .84381 m .15746 .8416 L .16283 .83478 L p F P
0 g
s
.597 .573 .797 r
.61626 .78678 m .61914 .79324 L .60795 .7948 L p F P
0 g
s
.597 .573 .797 r
.60654 .7881 m .61626 .78678 L p .60795 .7948 L F P
0 g
s
.597 .573 .797 r
.60795 .7948 m .60523 .78868 L .60654 .7881 L p F P
0 g
s
.941 .825 .702 r
.75944 .12482 m .76031 .12303 L .76228 .12718 L p F P
0 g
s
.941 .825 .702 r
.76228 .12718 m .76192 .12792 L .75944 .12482 L p F P
0 g
s
.83 .655 .664 r
.15776 .89001 m .15517 .88903 L p .15808 .89724 L F P
0 g
s
.829 .664 .678 r
.15776 .89001 m .15631 .88676 L .15517 .88903 L closepath p F P
0 g
s
.375 0 .099 r
.56439 .97826 m .56659 .97476 L .57794 .97222 L p F P
0 g
s
.442 .069 .233 r
.57801 .97206 m .57794 .97222 L .56659 .97476 L p F P
0 g
s
.581 .539 .772 r
.63907 .81332 m .6402 .81622 L .63034 .82063 L p F P
0 g
s
.581 .539 .772 r
.63034 .82063 m .62782 .81417 L .63907 .81332 L p F P
0 g
s
.641 .665 .857 r
.5237 .75257 m .5347 .74947 L .53761 .7541 L p F P
0 g
s
.643 .676 .866 r
.53277 .74655 m .5347 .74947 L .5237 .75257 L p F P
0 g
s
.643 .676 .866 r
.5237 .75257 m .52191 .74987 L .53277 .74655 L p F P
0 g
s
.517 .305 .531 r
.62979 .93457 m .62488 .93616 L .62494 .94158 L p F P
0 g
s
.824 .561 .54 r
.18595 .94348 m .17975 .9416 L .17994 .93615 L p F P
0 g
s
.826 .561 .54 r
.17376 .93425 m .17994 .93615 L .17975 .9416 L p F P
0 g
s
.793 .806 .863 r
.67569 .24262 m .6834 .23671 L .68075 .23343 L p F P
0 g
s
.793 .806 .863 r
.68075 .23343 m .67416 .23846 L .67569 .24262 L p F P
0 g
s
.79 .804 .863 r
.66972 .2418 m .67416 .23846 L .67569 .24262 L p F P
0 g
s
.538 .391 .63 r
.64325 .90531 m .65349 .90144 L p .65028 .90928 L F P
0 g
s
.538 .391 .63 r
.65028 .90928 m .64352 .90704 L .64325 .90531 L p F P
0 g
s
.545 .41 .648 r
.65233 .89502 m .65349 .90144 L .64325 .90531 L p F P
0 g
s
.835 .635 .634 r
.15572 .90324 m .16142 .90531 L .15944 .91121 L p F P
0 g
s
.831 .643 .65 r
.15808 .89724 m .15572 .90324 L .16142 .90531 L p F P
0 g
s
.801 .45 .393 r
.20696 .95925 m .20765 .96117 L .20581 .96336 L p F P
0 g
s
.801 .45 .393 r
.20044 .95748 m .20696 .95925 L p .20581 .96336 L F P
0 g
s
.264 0 0 r
.31681 .99262 m .31347 .99192 L .30303 .99091 L p F P
0 g
s
.216 .701 .929 r
.30303 .99091 m .31347 .99192 L .31067 .99095 L p F P
0 g
s
.216 .701 .929 r
.29965 .99056 m .30303 .99091 L p .31067 .99095 L F P
0 g
s
0 0 .456 r
.58335 .24047 m .5821 .23866 L .58454 .24255 L p F P
0 g
s
0 0 .456 r
.58454 .24255 m .5862 .24485 L .58335 .24047 L p F P
0 g
s
.618 .614 .825 r
.5713 .76902 m .58239 .76668 L .58528 .77225 L p F P
0 g
s
.619 .617 .827 r
.57962 .76137 m .58239 .76668 L .5713 .76902 L p F P
0 g
s
.619 .617 .827 r
.5713 .76902 m .56939 .7654 L .57962 .76137 L p F P
0 g
s
.36 .785 .973 r
.38805 .99613 m .38104 .99591 L .37544 .99638 L p F P
0 g
s
.349 .783 .968 r
.38104 .99591 m .37341 .99573 L .37544 .99638 L closepath p F P
0 g
s
.758 .79 .879 r
.65866 .24955 m .64759 .25659 L .64488 .25316 L p F P
0 g
s
.647 .748 .923 r
.46517 .74672 m .47607 .74349 L .47906 .74669 L p F P
0 g
s
.632 .781 .953 r
.47607 .74349 m .46517 .74672 L .46216 .74382 L p F P
0 g
s
.938 .828 .709 r
.75942 .13282 m .76192 .12792 L .75944 .12482 L p F P
0 g
s
.826 .673 .693 r
.15627 .87438 m .15315 .87988 L .14994 .87356 L p F P
0 g
s
.826 .673 .693 r
.14994 .87356 m .15068 .87224 L .15627 .87438 L p F P
0 g
s
.823 .679 .705 r
.15627 .87438 m .15068 .87224 L .15461 .86581 L p F P
0 g
s
.524 0 0 r
.26894 .98578 m .26837 .98567 L .26052 .98224 L p F P
0 g
s
.437 0 0 r
.25697 .98164 m .26052 .98224 L .26837 .98567 L p F P
0 g
s
.746 .732 .839 r
.25689 .75875 m .25677 .75861 L .25667 .75867 L closepath p F P
0 g
s
.553 .45 .691 r
.64943 .88164 m .64851 .87789 L .65663 .87871 L closepath p F P
0 g
s
.167 0 0 r
.52586 .98732 m .51986 .98826 L .51437 .98892 L p F P
0 g
s
.094 0 0 r
.51986 .98826 m .5138 .98915 L .51437 .98892 L closepath p F P
0 g
s
.747 .736 .842 r
.25348 .75477 m .25074 .75653 L .25667 .75867 L p F P
0 g
s
.747 .736 .842 r
.25667 .75867 m .25677 .75861 L .25348 .75477 L p F P
0 g
s
.747 .735 .84 r
.24272 .76177 m .25074 .75653 L .25667 .75867 L p F P
0 g
s
.755 .73 .829 r
.23682 .7659 m .23195 .76937 L .22863 .76534 L p F P
0 g
s
.841 .44 0 r
.57949 .23482 m .5821 .23866 L .58055 .2346 L p F P
0 g
s
.841 .44 0 r
.58055 .2346 m .57796 .23075 L .57949 .23482 L p F P
0 g
s
.734 .738 .854 r
.26749 .75223 m .25677 .75861 L .25348 .75477 L p F P
0 g
s
.312 .53 .904 r
.59509 .24799 m .5974 .25191 L .58993 .24998 L p F P
0 g
s
.312 .53 .904 r
.58993 .24998 m .58785 .24598 L .59509 .24799 L p F P
0 g
s
.01 .313 .803 r
.5862 .24485 m .58785 .24598 L .58993 .24998 L p F P
0 g
s
.627 .632 .837 r
.55445 .76103 m .56551 .75838 L .56841 .76359 L p F P
0 g
s
.628 .638 .841 r
.56266 .75333 m .56551 .75838 L .55445 .76103 L p F P
0 g
s
.628 .638 .841 r
.55445 .76103 m .55224 .75715 L .56266 .75333 L p F P
0 g
s
.83 .665 .678 r
.15517 .88903 m .15631 .88676 L .15378 .88112 L p F P
0 g
s
.892 .832 .78 r
.74355 .16457 m .74623 .16093 L .74799 .1651 L p F P
0 g
s
.892 .832 .78 r
.74799 .1651 m .74607 .1677 L .74355 .16457 L p F P
0 g
s
.609 .599 .816 r
.59642 .77023 m .5993 .7761 L .58817 .77811 L p F P
0 g
s
.609 .599 .816 r
.58655 .77201 m .59642 .77023 L p .58817 .77811 L F P
0 g
s
.609 .599 .816 r
.58817 .77811 m .5854 .77249 L .58655 .77201 L p F P
0 g
s
.988 .777 .528 r
.76345 .09383 m .76401 .09069 L .76156 .08785 L p F P
0 g
s
.818 .698 .733 r
.15895 .85099 m .15828 .84996 L .15785 .85055 L closepath p F P
0 g
s
.834 .648 .65 r
.15245 .89513 m .15808 .89724 L .15572 .90324 L p F P
0 g
s
.83 .655 .664 r
.15517 .88903 m .15245 .89513 L .15808 .89724 L p F P
0 g
s
.822 .536 .505 r
.18884 .94954 m .18633 .94879 L .18595 .94348 L p F P
0 g
s
.824 .537 .503 r
.17975 .9416 m .18595 .94348 L .18633 .94879 L p F P
0 g
s
.99 .742 .452 r
.75972 .08079 m .76205 .08488 L .76242 .08023 L p F P
0 g
s
.99 .742 .452 r
.76242 .08023 m .76009 .07614 L .75972 .08079 L p F P
0 g
s
.556 .463 .704 r
.65681 .86698 m .64863 .8664 L .65584 .86338 L closepath p F P
0 g
s
.562 .476 .715 r
.65378 .85615 m .65584 .86338 L .64863 .8664 L p F P
0 g
s
.562 .476 .715 r
.65351 .85614 m .65378 .85615 L p .64863 .8664 L F P
0 g
s
.828 .821 .842 r
.70607 .21895 m .70535 .21806 L .70565 .21779 L closepath p F P
0 g
s
.808 .708 .755 r
.16858 .82785 m .16626 .83058 L .16293 .82585 L p F P
0 g
s
.808 .708 .755 r
.16293 .82585 m .16314 .82561 L .16858 .82785 L p F P
0 g
s
.804 .712 .763 r
.16858 .82785 m .16314 .82561 L .16943 .81852 L p F P
0 g
s
.65 .73 .907 r
.47906 .74669 m .48998 .74339 L .49296 .74689 L p F P
0 g
s
.644 .756 .931 r
.48998 .74339 m .47906 .74669 L .47607 .74349 L p F P
0 g
s
.855 .826 .819 r
.72457 .19329 m .72612 .19162 L .72776 .1958 L p F P
0 g
s
.855 .826 .819 r
.72776 .1958 m .72712 .19648 L .72457 .19329 L p F P
0 g
s
.538 .391 .63 r
.64421 .91154 m .64352 .90704 L .65028 .90928 L closepath p F P
0 g
s
.672 .187 .091 r
.24544 .97932 m .23788 .97788 L .24148 .97641 L closepath p F P
0 g
s
.672 .182 .077 r
.25286 .98082 m .24544 .97932 L .24148 .97641 L p F P
0 g
s
.849 .826 .824 r
.7209 .20294 m .72712 .19648 L .72457 .19329 L p F P
0 g
s
.392 .798 .982 r
.40238 .99627 m .3931 .99616 L .38931 .99656 L p F P
0 g
s
.388 .798 .98 r
.3931 .99616 m .38805 .99613 L .38931 .99656 L closepath p F P
0 g
s
.503 .24 .448 r
.614 .95 m .61383 .95168 L .60275 .95657 L p F P
0 g
s
.494 .224 .433 r
.60258 .95795 m .60275 .95657 L .61383 .95168 L p F P
0 g
s
.804 .809 .856 r
.68684 .23393 m .6834 .23671 L .68075 .23343 L p F P
0 g
s
.548 .436 .678 r
.65097 .88842 m .64943 .88164 L .65663 .87871 L p F P
0 g
s
.625 .724 .918 r
.60595 .2599 m .61712 .25695 L .6199 .26066 L p F P
0 g
s
.616 .719 .919 r
.61712 .25695 m .60595 .2599 L .60315 .25597 L p F P
0 g
s
.955 .611 .243 r
.5752 .22695 m .57796 .23075 L .57725 .2264 L p F P
0 g
s
.955 .611 .243 r
.57725 .2264 m .5745 .22259 L .5752 .22695 L p F P
0 g
s
.581 .539 .773 r
.63682 .80755 m .63907 .81332 L .62782 .81417 L p F P
0 g
s
.581 .539 .773 r
.62782 .81417 m .62697 .812 L .63682 .80755 L p F P
0 g
s
.97 .806 .622 r
.76048 .10403 m .76261 .10815 L .76428 .10298 L p F P
0 g
s
.97 .806 .622 r
.76428 .10298 m .76215 .09885 L .76048 .10403 L p F P
0 g
s
.653 .769 .934 r
.32323 .74647 m .3339 .74304 L .33712 .74597 L p F P
0 g
s
.625 .781 .956 r
.3339 .74304 m .32323 .74647 L .32 .74329 L p F P
0 g
s
.676 .758 .913 r
.30934 .7473 m .32 .74329 L .32323 .74647 L p F P
0 g
s
.827 .601 .596 r
.16835 .92675 m .1673 .92641 L .16667 .9201 L p F P
0 g
s
.835 .607 .593 r
.16363 .91906 m .16667 .9201 L .1673 .92641 L p F P
0 g
s
.661 .768 .929 r
.32 .74329 m .30934 .7473 L .30609 .74392 L p F P
0 g
s
.694 .75 .895 r
.29542 .74849 m .30609 .74392 L .30934 .7473 L p F P
0 g
s
.755 .73 .829 r
.22863 .76534 m .23088 .76375 L .23682 .7659 L p F P
0 g
s
.756 .734 .832 r
.23942 .75785 m .23088 .76375 L .23682 .7659 L p F P
0 g
s
.756 .734 .832 r
.23682 .7659 m .24272 .76177 L .23942 .75785 L p F P
0 g
s
.812 .709 .752 r
.16283 .83478 m .16626 .83058 L .16293 .82585 L p F P
0 g
s
.264 0 0 r
.2933 .98942 m .29965 .99056 L p .28587 .98857 L F P
0 g
s
.264 0 0 r
.28587 .98857 m .28673 .98858 L .2933 .98942 L p F P
0 g
s
.807 .811 .854 r
.68684 .23393 m .69439 .2277 L .69176 .22443 L p F P
0 g
s
.807 .811 .854 r
.69176 .22443 m .68529 .22976 L .68684 .23393 L p F P
0 g
s
.804 .809 .856 r
.68075 .23343 m .68529 .22976 L .68684 .23393 L p F P
0 g
s
.887 .832 .786 r
.74318 .17148 m .74607 .1677 L .74355 .16457 L p F P
0 g
s
.819 .701 .734 r
.15785 .85055 m .15828 .84996 L .15496 .84493 L p F P
0 g
s
.054 0 0 r
.5138 .98915 m .51144 .98964 L .50047 .99111 L p F P
0 g
s
.287 .783 .878 r
.51144 .98964 m .50047 .99111 L .49751 .99125 L p F P
0 g
s
0 0 0 r
.50047 .99111 m .49751 .99125 L .48657 .99273 L p F P
0 g
s
.624 .782 .957 r
.33712 .74597 m .34778 .7431 L .351 .74573 L p F P
0 g
s
.573 .796 .984 r
.34778 .7431 m .33712 .74597 L .3339 .74304 L p F P
0 g
s
.621 .093 0 r
.255 .98209 m .25286 .98082 L .25697 .98164 L closepath p F P
0 g
s
.437 0 0 r
.255 .98209 m .25697 .98164 L p .26837 .98567 L F P
0 g
s
.409 .807 .985 r
.41638 .99614 m .40586 .99624 L .40319 .99656 L p F P
0 g
s
.411 .807 .986 r
.40586 .99624 m .40238 .99627 L .40319 .99656 L closepath p F P
0 g
s
.584 .549 .781 r
.63617 .80596 m .63682 .80755 L .62697 .812 L p F P
0 g
s
.584 .549 .781 r
.62697 .812 m .62492 .80696 L .63617 .80596 L p F P
0 g
s
.822 .696 .725 r
.15251 .8483 m .15785 .85055 L .15336 .85712 L p F P
0 g
s
.819 .701 .734 r
.15496 .84493 m .15251 .8483 L .15785 .85055 L p F P
0 g
s
.849 .826 .824 r
.72457 .19329 m .7193 .19876 L .7209 .20294 L p F P
0 g
s
.845 .824 .828 r
.71368 .20445 m .7193 .19876 L .7209 .20294 L p F P
0 g
s
.845 .824 .828 r
.7209 .20294 m .71626 .20764 L .71368 .20445 L p F P
0 g
s
.648 .733 .911 r
.5039 .74359 m .49296 .74689 L .48998 .74339 L p F P
0 g
s
.65 .712 .893 r
.49296 .74689 m .5039 .74359 L .50686 .74738 L p F P
0 g
s
.685 .757 .906 r
.30609 .74392 m .29542 .74849 L .29216 .74496 L p F P
0 g
s
.834 .659 .665 r
.14963 .8869 m .15517 .88903 L .15245 .89513 L p F P
0 g
s
.83 .665 .678 r
.1527 .88071 m .14963 .8869 L .15517 .88903 L p F P
0 g
s
.83 .665 .678 r
.15378 .88112 m .1527 .88071 L p .15517 .88903 L F P
0 g
s
.782 .725 .799 r
.19959 .7887 m .19606 .79185 L .19272 .78764 L p F P
0 g
s
.788 .725 .794 r
.19112 .79643 m .19606 .79185 L .19272 .78764 L p F P
0 g
s
.636 .655 .852 r
.53761 .7541 m .54864 .75118 L .55155 .75597 L p F P
0 g
s
.637 .662 .858 r
.54864 .75118 m .53761 .7541 L .5347 .74947 L p F P
0 g
s
.79 .724 .79 r
.19112 .79643 m .18511 .80216 L .18175 .79791 L p F P
0 g
s
.79 .724 .79 r
.18175 .79791 m .18569 .79416 L .19112 .79643 L p F P
0 g
s
.788 .725 .794 r
.19272 .78764 m .18569 .79416 L .19112 .79643 L p F P
0 g
s
.824 .684 .709 r
.14913 .86363 m .15461 .86581 L .15068 .87224 L p F P
0 g
s
.823 .688 .715 r
.15461 .86581 m .14913 .86363 L .15336 .85712 L p F P
0 g
s
.984 .699 .364 r
.75767 .07207 m .76009 .07614 L .76002 .07166 L p F P
0 g
s
.984 .699 .364 r
.76002 .07166 m .7576 .06759 L .75767 .07207 L p F P
0 g
s
.782 .725 .799 r
.19272 .78764 m .19405 .78646 L .19959 .7887 L p F P
0 g
s
.781 .727 .803 r
.20323 .77851 m .19405 .78646 L .19959 .7887 L p F P
0 g
s
.781 .727 .803 r
.20426 .77895 m .20323 .77851 L p .19959 .7887 L F P
0 g
s
.781 .727 .803 r
.19959 .7887 m .20697 .7823 L .20426 .77895 L p F P
0 g
s
.496 .802 .999 r
.36167 .74335 m .351 .74573 L .34778 .7431 L p F P
0 g
s
.588 .795 .978 r
.351 .74573 m .36167 .74335 L .36487 .74566 L p F P
0 g
s
.808 .491 .453 r
.20044 .95748 m .19391 .95571 L .19274 .9506 L p F P
0 g
s
.807 .485 .445 r
.18884 .94954 m .19274 .9506 L .19391 .95571 L p F P
0 g
s
.396 0 0 r
.2847 .98825 m .27668 .98693 L .27216 .98553 L p F P
0 g
s
.417 0 0 r
.27668 .98693 m .26894 .98578 L .27216 .98553 L closepath p F P
0 g
s
.599 .581 .804 r
.60523 .78868 m .60507 .78832 L .60654 .7881 L closepath p F P
0 g
s
0 0 0 r
.51144 .98964 m .5138 .98915 L .51986 .98826 L p F P
0 g
s
.413 .812 .984 r
.43007 .99576 m .41959 .99607 L .41708 .9964 L p F P
0 g
s
.421 .812 .987 r
.41959 .99607 m .41638 .99614 L .41708 .9964 L closepath p F P
0 g
s
.731 .772 .885 r
.64224 .25462 m .63377 .25928 L .63103 .25571 L p F P
0 g
s
.697 .76 .901 r
.6199 .26066 m .63103 .25571 L .63377 .25928 L p F P
0 g
s
.838 .824 .834 r
.71358 .21025 m .71626 .20764 L .71368 .20445 L p F P
0 g
s
.816 .814 .848 r
.69671 .22569 m .69439 .2277 L .69176 .22443 L p F P
0 g
s
.795 .724 .785 r
.18326 .80398 m .18511 .80216 L .18175 .79791 L p F P
0 g
s
.349 .762 .98 r
.31681 .99262 m .32734 .99282 L .32713 .99273 L p F P
0 g
s
.349 .762 .98 r
.31347 .99192 m .31681 .99262 L p .32713 .99273 L F P
0 g
s
.197 .695 .915 r
.31681 .99262 m .32734 .99282 L .33063 .9938 L p F P
0 g
s
.91 .83 .754 r
.75161 .14623 m .75274 .14447 L .75461 .14863 L p F P
0 g
s
.91 .83 .754 r
.75461 .14863 m .75412 .14939 L .75161 .14623 L p F P
0 g
s
.6 .584 .807 r
.60654 .7881 m .60507 .78832 L .60219 .78215 L p F P
0 g
s
.828 .674 .691 r
.15378 .88112 m .15315 .87988 L .1527 .88071 L closepath p F P
0 g
s
.819 .815 .846 r
.69671 .22569 m .70535 .21806 L .70275 .21481 L p F P
0 g
s
.819 .815 .846 r
.70275 .21481 m .69513 .22152 L .69671 .22569 L p F P
0 g
s
.816 .814 .848 r
.69176 .22443 m .69513 .22152 L .69671 .22569 L p F P
0 g
s
.712 .246 .144 r
.23788 .97788 m .23784 .97787 L .23318 .97363 L p F P
0 g
s
.7 .218 .1 r
.22597 .97207 m .23318 .97363 L .23784 .97787 L p F P
0 g
s
.744 .327 .259 r
.23318 .97363 m .22597 .97207 L .22448 .97026 L p F P
0 g
s
.391 .825 .956 r
.48657 .99273 m .49751 .99125 L .49498 .99071 L p F P
0 g
s
.391 .825 .956 r
.48358 .99246 m .48657 .99273 L p .49498 .99071 L F P
0 g
s
.263 .766 .877 r
.47267 .99397 m .48358 .99246 L .48657 .99273 L p F P
0 g
s
.838 .824 .834 r
.71368 .20445 m .71203 .20606 L .71358 .21025 L p F P
0 g
s
.833 .821 .838 r
.70404 .21363 m .70565 .21779 L .71358 .21025 L p F P
0 g
s
.833 .821 .838 r
.71358 .21025 m .71203 .20606 L .70404 .21363 L p F P
0 g
s
.794 .722 .784 r
.17793 .80168 m .18326 .80398 L .17606 .81133 L p F P
0 g
s
.795 .724 .785 r
.18175 .79791 m .17793 .80168 L .18326 .80398 L p F P
0 g
s
.784 .426 .378 r
.21591 .9658 m .20902 .96414 L .20765 .96117 L p F P
0 g
s
.785 .426 .377 r
.20902 .96414 m .20581 .96336 L .20765 .96117 L closepath p F P
0 g
s
.62 .625 .833 r
.5795 .76115 m .57962 .76137 L .56939 .7654 L p F P
0 g
s
.62 .625 .833 r
.56939 .7654 m .56841 .76359 L .5795 .76115 L p F P
0 g
s
.774 .726 .808 r
.20697 .7823 m .20885 .78074 L .20426 .77895 L closepath p F P
0 g
s
.814 .706 .746 r
.1575 .83251 m .16283 .83478 L .15746 .8416 L p F P
0 g
s
.812 .709 .752 r
.16293 .82585 m .1575 .83251 L .16283 .83478 L p F P
0 g
s
.951 .819 .677 r
.75825 .1189 m .76031 .12303 L .76265 .11759 L p F P
0 g
s
.951 .819 .677 r
.76265 .11759 m .7606 .11346 L .75825 .1189 L p F P
0 g
s
.708 .735 .873 r
.28147 .75008 m .28212 .74977 L .28096 .74949 L closepath p F P
0 g
s
.724 .742 .865 r
.28096 .74949 m .28147 .75008 L p .26749 .75223 L F P
0 g
s
.404 .814 .978 r
.44349 .99515 m .43454 .99559 L .43097 .99607 L p F P
0 g
s
.419 .815 .984 r
.43454 .99559 m .43007 .99576 L .43097 .99607 L closepath p F P
0 g
s
.769 .73 .816 r
.21603 .77129 m .21782 .77348 L .20885 .78074 L p F P
0 g
s
.769 .73 .816 r
.2135 .77024 m .21603 .77129 L p .20885 .78074 L F P
0 g
s
.769 .73 .816 r
.20363 .77818 m .2135 .77024 L p .20885 .78074 L F P
0 g
s
.769 .73 .816 r
.20885 .78074 m .20426 .77895 L .20363 .77818 L p F P
0 g
s
.906 .831 .761 r
.75057 .15472 m .75412 .14939 L .75161 .14623 L p F P
0 g
s
.77 .37 .295 r
.22287 .9714 m .219 .97043 L .21591 .9658 L p F P
0 g
s
.767 .359 .279 r
.20902 .96414 m .21591 .9658 L .219 .97043 L p F P
0 g
s
.643 .681 .871 r
.53177 .74508 m .53277 .74655 L .52191 .74987 L p F P
0 g
s
.643 .681 .871 r
.52191 .74987 m .52077 .7482 L .53177 .74508 L p F P
0 g
s
.827 .817 .84 r
.70275 .21481 m .70404 .21363 L .70565 .21779 L p F P
0 g
s
.827 .817 .84 r
.70565 .21779 m .70535 .21806 L .70275 .21481 L p F P
0 g
s
.745 .736 .843 r
.25074 .75653 m .24272 .76177 L .23942 .75785 L p F P
0 g
s
.887 .832 .786 r
.74355 .16457 m .74147 .1673 L .74318 .17148 L p F P
0 g
s
.88 .83 .794 r
.73622 .17385 m .73797 .17802 L .74318 .17148 L p F P
0 g
s
.88 .83 .794 r
.74318 .17148 m .74147 .1673 L .73622 .17385 L p F P
0 g
s
.334 .798 .934 r
.46975 .9934 m .47267 .99397 L .48358 .99246 L p F P
0 g
s
.548 .805 .993 r
.36487 .74566 m .37557 .74366 L .37875 .74567 L p F P
0 g
s
.398 .791 .988 r
.37557 .74366 m .36487 .74566 L .36167 .74335 L p F P
0 g
s
.83 .675 .692 r
.1527 .88071 m .15315 .87988 L .14994 .87356 L p F P
0 g
s
.381 .811 .965 r
.4567 .99435 m .45096 .99474 L .44487 .99558 L p F P
0 g
s
.405 .816 .977 r
.45096 .99474 m .44349 .99515 L .44487 .99558 L closepath p F P
0 g
s
.693 .757 .901 r
.63103 .25571 m .6199 .26066 L .61712 .25695 L p F P
0 g
s
.704 .738 .878 r
.28888 .74154 m .29216 .74496 L .28212 .74977 L p F P
0 g
s
.704 .738 .878 r
.2782 .74644 m .28888 .74154 L p .28212 .74977 L F P
0 g
s
.704 .738 .878 r
.28212 .74977 m .28096 .74949 L .2782 .74644 L p F P
0 g
s
.938 .828 .709 r
.75944 .12482 m .75748 .12866 L .75942 .13282 L p F P
0 g
s
.928 .827 .726 r
.75427 .13444 m .75622 .13859 L .75942 .13282 L p F P
0 g
s
.928 .827 .726 r
.75942 .13282 m .75748 .12866 L .75427 .13444 L p F P
0 g
s
.343 .801 .94 r
.46975 .9934 m .46912 .99345 L .45877 .99489 L p F P
0 g
s
.379 .811 .963 r
.46912 .99345 m .4567 .99435 L .45877 .99489 L closepath p F P
0 g
s
.465 .161 .366 r
.60161 .96248 m .60258 .95795 L .61345 .95488 L p F P
0 g
s
.494 .224 .433 r
.61383 .95168 m .61345 .95488 L .60258 .95795 L p F P
0 g
s
.48 .174 .37 r
.60258 .95795 m .60161 .96248 L .59057 .96537 L p F P
0 g
s
.744 .327 .258 r
.22597 .97207 m .22287 .9714 L .22448 .97026 L closepath p F P
0 g
s
.648 .696 .881 r
.50686 .74738 m .51783 .74414 L .52077 .7482 L p F P
0 g
s
.648 .712 .895 r
.51783 .74414 m .50686 .74738 L .5039 .74359 L p F P
0 g
s
.368 0 .064 r
.56439 .97826 m .559 .97938 L .55312 .98033 L p F P
0 g
s
.331 0 0 r
.559 .97938 m .55287 .98063 L .55312 .98033 L closepath p F P
0 g
s
.518 .327 .562 r
.63544 .93273 m .63512 .92708 L .64554 .92344 L p F P
0 g
s
.53 .355 .589 r
.64498 .91759 m .64554 .92344 L .63512 .92708 L p F P
0 g
s
.529 .335 .563 r
.62979 .93457 m .63544 .93273 L .63512 .92708 L p F P
0 g
s
.96 .633 .245 r
.75508 .06354 m .7576 .06759 L .75704 .06332 L p F P
0 g
s
.96 .633 .245 r
.75704 .06332 m .75453 .05926 L .75508 .06354 L p F P
0 g
s
.584 .549 .782 r
.63328 .79886 m .63617 .80596 L .62492 .80696 L p F P
0 g
s
.584 .549 .782 r
.63243 .79893 m .63328 .79886 L p .62492 .80696 L F P
0 g
s
.584 .549 .782 r
.62492 .80696 m .62334 .80309 L .63243 .79893 L p F P
0 g
s
.8 .717 .773 r
.17407 .81344 m .17606 .81133 L .17082 .80914 L closepath p F P
0 g
s
.794 .722 .784 r
.17071 .809 m .17793 .80168 L p .17606 .81133 L F P
0 g
s
.794 .722 .784 r
.17606 .81133 m .17082 .80914 L .17071 .809 L p F P
0 g
s
.542 .421 .664 r
.65097 .88842 m .66105 .88432 L p .65758 .89292 L F P
0 g
s
.542 .421 .664 r
.65758 .89292 m .65164 .89167 L .65097 .88842 L p F P
0 g
s
.548 .436 .678 r
.65989 .87923 m .66105 .88432 L .65097 .88842 L p F P
0 g
s
.548 .436 .678 r
.65663 .87871 m .65989 .87923 L p .65097 .88842 L F P
0 g
s
.833 .669 .679 r
.14724 .87853 m .1527 .88071 L .14963 .8869 L p F P
0 g
s
.83 .675 .692 r
.14994 .87356 m .14724 .87853 L .1527 .88071 L p F P
0 g
s
.529 .37 .61 r
.64498 .91759 m .64421 .91154 L .65028 .90928 L p F P
0 g
s
.596 .575 .8 r
.61626 .78678 m .60654 .7881 L .61513 .78427 L closepath p F P
0 g
s
.6 .584 .807 r
.61337 .78049 m .61513 .78427 L .60654 .7881 L p F P
0 g
s
.6 .584 .807 r
.60219 .78215 m .61337 .78049 L p .60654 .7881 L F P
0 g
s
.774 .794 .869 r
.66113 .24784 m .65866 .24955 L .65597 .24614 L p F P
0 g
s
.758 .79 .879 r
.64488 .25316 m .65597 .24614 L .65866 .24955 L p F P
0 g
s
.474 .64 .928 r
.60034 .25205 m .5974 .25191 L .59954 .25588 L p F P
0 g
s
.474 .64 .928 r
.59954 .25588 m .60315 .25597 L .60034 .25205 L p F P
0 g
s
.724 .742 .865 r
.26749 .75223 m .27576 .74775 L .28096 .74949 L p F P
0 g
s
.722 .743 .868 r
.28096 .74949 m .2782 .74644 L .27576 .74775 L closepath p F P
0 g
s
.804 .718 .769 r
.16943 .81852 m .17407 .81344 L .17082 .80914 L p F P
0 g
s
.347 0 0 r
.28587 .98857 m .2847 .98825 L .28673 .98858 L closepath p F P
0 g
s
.492 .232 .448 r
.61383 .95168 m .61965 .9483 L .614 .95 L closepath p F P
0 g
s
.511 .275 .492 r
.62485 .94405 m .62494 .94158 L p .614 .95 L F P
0 g
s
.511 .275 .492 r
.614 .95 m .61965 .9483 L .62485 .94405 L p F P
0 g
s
.517 .305 .531 r
.62494 .94158 m .62801 .94059 L .62979 .93457 L p F P
0 g
s
.515 .303 .53 r
.63544 .93273 m .62979 .93457 L .62801 .94059 L p F P
0 g
s
.988 .777 .528 r
.76156 .08785 m .76123 .08971 L .76345 .09383 L p F P
0 g
s
.978 .792 .585 r
.75993 .09474 m .76215 .09885 L .76345 .09383 L p F P
0 g
s
.978 .792 .585 r
.76345 .09383 m .76123 .08971 L .75993 .09474 L p F P
0 g
s
.514 .812 .999 r
.37875 .74567 m .38947 .74388 L .39264 .74564 L p F P
0 g
s
.334 .774 .964 r
.37875 .74567 m .38947 .74388 L .3875 .74324 L p F P
0 g
s
.334 .774 .964 r
.37557 .74366 m .37875 .74567 L p .3875 .74324 L F P
0 g
s
.437 .808 .994 r
.40004 .99531 m .3931 .99616 L .40238 .99627 L closepath p F P
0 g
s
.45 .814 .995 r
.40004 .99531 m .40238 .99627 L .40586 .99624 L p F P
0 g
s
.629 .644 .846 r
.56261 .75324 m .56266 .75333 L .55224 .75715 L p F P
0 g
s
.629 .644 .846 r
.55224 .75715 m .55155 .75597 L .56261 .75324 L p F P
0 g
s
.765 .728 .818 r
.21782 .77348 m .21914 .77247 L .21603 .77129 L closepath p F P
0 g
s
.568 .013 0 r
.25286 .98082 m .255 .98209 L .25148 .98238 L p F P
0 g
s
.568 .013 0 r
.25148 .98238 m .24544 .97932 L .25286 .98082 L p F P
0 g
s
.449 .815 .995 r
.41395 .99515 m .40586 .99624 L .41638 .99614 L closepath p F P
0 g
s
.45 .814 .995 r
.40586 .99624 m .41395 .99515 L p .40004 .99531 L F P
0 g
s
.423 .064 .249 r
.60161 .96248 m .59057 .96537 L .58914 .96951 L p F P
0 g
s
.621 .63 .838 r
.5795 .76115 m .56841 .76359 L .56551 .75838 L p F P
0 g
s
.835 .622 .615 r
.16363 .91906 m .15784 .91703 L .15944 .91121 L p F P
0 g
s
.837 .609 .594 r
.15784 .91703 m .16363 .91906 L .16246 .92476 L p F P
0 g
s
.835 .607 .593 r
.1673 .92641 m .16246 .92476 L .16363 .91906 L p F P
0 g
s
.611 .607 .822 r
.5854 .77249 m .58528 .77225 L .58655 .77201 L closepath p F P
0 g
s
.826 .583 .571 r
.17376 .93425 m .16761 .93234 L .16835 .92675 L p F P
0 g
s
.829 .585 .571 r
.1673 .92641 m .16835 .92675 L .16761 .93234 L p F P
0 g
s
.76 .732 .827 r
.22574 .76187 m .22863 .76534 L .21914 .77247 L p F P
0 g
s
.76 .732 .827 r
.22502 .76158 m .22574 .76187 L p .21914 .77247 L F P
0 g
s
.76 .732 .827 r
.21448 .76946 m .22502 .76158 L p .21914 .77247 L F P
0 g
s
.76 .732 .827 r
.21914 .77247 m .21603 .77129 L .21448 .76946 L p F P
0 g
s
.431 .808 .992 r
.3931 .99616 m .40004 .99531 L p .38614 .99537 L F P
0 g
s
.431 .808 .992 r
.38614 .99537 m .38805 .99613 L .3931 .99616 L p F P
0 g
s
.458 .819 .996 r
.41395 .99515 m .41638 .99614 L .41959 .99607 L p F P
0 g
s
.413 .799 .99 r
.38614 .99537 m .38104 .99591 L .38805 .99613 L closepath p F P
0 g
s
.611 .611 .826 r
.58655 .77201 m .58528 .77225 L .58239 .76668 L p F P
0 g
s
.72 .743 .87 r
.27576 .74775 m .26749 .75223 L .2642 .74847 L p F P
0 g
s
.734 .738 .854 r
.25348 .75477 m .2642 .74847 L .26749 .75223 L p F P
0 g
s
.774 .794 .869 r
.65597 .24614 m .65948 .24372 L .66113 .24784 L p F P
0 g
s
.775 .796 .869 r
.66113 .24784 m .66972 .2418 L .66704 .23843 L p F P
0 g
s
.775 .796 .869 r
.66704 .23843 m .65948 .24372 L .66113 .24784 L p F P
0 g
s
.451 .819 .994 r
.42787 .99489 m .41959 .99607 L .43007 .99576 L closepath p F P
0 g
s
.458 .819 .996 r
.41959 .99607 m .42787 .99489 L p .41395 .99515 L F P
0 g
s
.837 .625 .616 r
.15371 .90915 m .15944 .91121 L .15784 .91703 L p F P
0 g
s
.835 .635 .634 r
.15944 .91121 m .15371 .90915 L .15572 .90324 L p F P
0 g
s
.307 .752 .963 r
.34295 .99403 m .33792 .99354 L .33063 .9938 L p F P
0 g
s
.275 .743 .944 r
.33792 .99354 m .33063 .9938 L .32734 .99282 L p F P
0 g
s
.22 0 0 r
.55031 .98272 m .55287 .98063 L .559 .97938 L p F P
0 g
s
.27 0 0 r
.55287 .98063 m .55031 .98272 L .53925 .98449 L p F P
0 g
s
.802 .447 .385 r
.19391 .95571 m .20044 .95748 L .20235 .96241 L p F P
0 g
s
.801 .45 .393 r
.20581 .96336 m .20235 .96241 L .20044 .95748 L p F P
0 g
s
0 .282 .784 r
.58785 .24598 m .5862 .24485 L .58335 .24047 L p F P
0 g
s
.824 .691 .717 r
.14798 .85489 m .15336 .85712 L .14913 .86363 L p F P
0 g
s
.822 .696 .725 r
.15336 .85712 m .14798 .85489 L .15251 .8483 L p F P
0 g
s
.066 0 0 r
.52535 .98751 m .51986 .98826 L .52586 .98732 L closepath p F P
0 g
s
0 0 0 r
.51986 .98826 m .52535 .98751 L p .51144 .98964 L F P
0 g
s
.498 .817 1 r
.39264 .74564 m .40338 .74388 L .40653 .7455 L p F P
0 g
s
.292 .763 .938 r
.39264 .74564 m .40338 .74388 L .402 .74352 L p F P
0 g
s
.292 .763 .938 r
.38947 .74388 m .39264 .74564 L p .402 .74352 L F P
0 g
s
.826 .561 .54 r
.17975 .9416 m .17357 .93971 L .17376 .93425 L p F P
0 g
s
.827 .563 .54 r
.16761 .93234 m .17376 .93425 L .17357 .93971 L p F P
0 g
s
.21 0 0 r
.2847 .98825 m .28587 .98857 L .28245 .98812 L p F P
0 g
s
.21 0 0 r
.28245 .98812 m .27668 .98693 L .2847 .98825 L p F P
0 g
s
.587 .559 .789 r
.62334 .80309 m .62203 .8 L .63243 .79893 L closepath p F P
0 g
s
.804 .718 .769 r
.17065 .80906 m .16413 .81622 L .16943 .81852 L p F P
0 g
s
.804 .718 .769 r
.17082 .80914 m .17065 .80906 L p .16943 .81852 L F P
0 g
s
.804 .716 .768 r
.16413 .81622 m .16943 .81852 L .16314 .82561 L p F P
0 g
s
.4 .798 .986 r
.38104 .99591 m .38614 .99537 L p .37224 .9953 L F P
0 g
s
.4 .798 .986 r
.37224 .9953 m .37341 .99573 L .38104 .99591 L p F P
0 g
s
.817 .702 .737 r
.15746 .8416 m .15496 .84493 L .15163 .83995 L p F P
0 g
s
.817 .702 .737 r
.15163 .83995 m .15208 .83935 L .15746 .8416 L p F P
0 g
s
.814 .706 .746 r
.15746 .8416 m .15208 .83935 L .1575 .83251 L p F P
0 g
s
.542 .42 .663 r
.65233 .89502 m .65164 .89167 L .65758 .89292 L closepath p F P
0 g
s
.644 .694 .882 r
.53177 .74508 m .52077 .7482 L .51783 .74414 L p F P
0 g
s
.829 .585 .571 r
.16761 .93234 m .16728 .93224 L .1673 .92641 L p F P
0 g
s
.837 .592 .569 r
.16246 .92476 m .1673 .92641 L .16728 .93224 L p F P
0 g
s
.631 .652 .853 r
.56261 .75324 m .55155 .75597 L .54864 .75118 L p F P
0 g
s
.872 .828 .8 r
.73283 .17793 m .73622 .17385 L .73797 .17802 L p F P
0 g
s
.872 .828 .8 r
.73797 .17802 m .73537 .18113 L .73283 .17793 L p F P
0 g
s
.807 .485 .445 r
.18712 .95294 m .18884 .94954 L p .19391 .95571 L F P
0 g
s
.819 .506 .461 r
.18712 .95294 m .18633 .94879 L .18884 .94954 L closepath p F P
0 g
s
.836 .638 .635 r
.15006 .90115 m .15572 .90324 L .15371 .90915 L p F P
0 g
s
.834 .648 .65 r
.15572 .90324 m .15006 .90115 L .15245 .89513 L p F P
0 g
s
.457 .822 .994 r
.42787 .99489 m .43007 .99576 L .43454 .99559 L p F P
0 g
s
.608 .602 .819 r
.59642 .77023 m .58655 .77201 L .59541 .76821 L closepath p F P
0 g
s
.611 .611 .826 r
.59354 .76456 m .59541 .76821 L .58655 .77201 L p F P
0 g
s
.611 .611 .826 r
.58239 .76668 m .59354 .76456 L p .58655 .77201 L F P
0 g
s
.906 .831 .761 r
.75161 .14623 m .74874 .15055 L .75057 .15472 L p F P
0 g
s
.898 .829 .77 r
.74438 .15678 m .74623 .16093 L .75057 .15472 L p F P
0 g
s
.898 .829 .77 r
.75057 .15472 m .74874 .15055 L .74438 .15678 L p F P
0 g
s
.374 .785 .981 r
.37224 .9953 m .36943 .99553 L .37341 .99573 L closepath p F P
0 g
s
.746 .739 .845 r
.25017 .75098 m .24482 .75437 L .25074 .75653 L p F P
0 g
s
.746 .739 .845 r
.25074 .75653 m .25348 .75477 L .25017 .75098 L p F P
0 g
s
.745 .736 .843 r
.23942 .75785 m .24482 .75437 L .25074 .75653 L p F P
0 g
s
.508 .822 1 r
.40653 .7455 m .41731 .74361 L .42043 .74521 L p F P
0 g
s
.297 .77 .933 r
.40507 .74372 m .40338 .74388 L p .40579 .74377 L F P
0 g
s
.297 .77 .933 r
.40653 .7455 m .41731 .74361 L .41608 .74331 L p F P
0 g
s
.297 .77 .933 r
.41573 .74333 m .41194 .74422 L .41608 .74331 L F
.41194 .74422 m .40653 .7455 L .41208 .74423 L F
.41194 .74422 m .41208 .74423 L .41608 .74331 L F
.31 .775 .942 r
.40799 .74344 m .402 .74352 L .40338 .74388 L closepath p F P
0 g
s
.374 0 0 r
.40469 .74381 m .40185 .74352 L .40213 .74354 L F
.297 .77 .933 r
.40338 .74388 m .40653 .7455 L p .41594 .74328 L F P
0 g
s
.374 0 0 r
.4116 .74455 m .40451 .7438 L .40469 .74381 L F
.40451 .7438 m .40185 .74352 L .40469 .74381 L F
.292 .763 .938 r
.39482 .74346 m .38947 .74388 L p .40005 .74358 L F P
0 g
s
.292 .763 .938 r
.402 .74352 m .39482 .74346 L p .40005 .74358 L F P
0 g
s
.325 .772 .959 r
.39482 .74346 m .3875 .74324 L .38947 .74388 L closepath p F P
0 g
s
.377 0 0 r
.39746 .74465 m .38796 .74331 L .39482 .74346 L F
.3875 .74324 m .39482 .74346 L p .38796 .74331 L F P
0 g
s
.374 0 0 r
.40019 .74348 m .40185 .74352 L p .4116 .74455 L F P
0 g
s
.374 0 0 r
.40185 .74352 m .402 .74352 L p .40213 .74354 L F P
0 g
s
.297 .77 .933 r
.40799 .74344 m .40507 .74372 L p .41481 .74333 L F P
0 g
s
.297 .77 .933 r
.41481 .74333 m .40507 .74372 L .40579 .74377 L F
.41594 .74328 m .40799 .74344 L p .41481 .74333 L F P
0 g
s
.374 0 0 r
.40863 .74364 m .40248 .74353 L .40799 .74344 L F
.402 .74352 m .40799 .74344 L p .40248 .74353 L F P
0 g
s
.374 0 0 r
.4116 .74455 m .40469 .74381 L .40863 .74364 L F
.40469 .74381 m .402 .74352 L .40863 .74364 L F
.297 .77 .933 r
.41608 .74331 m .41594 .74328 L p .41573 .74333 L F P
0 g
s
.828 .676 .694 r
.14994 .87356 m .15068 .87224 L .1489 .87154 L closepath p F P
0 g
s
.824 .684 .709 r
.14669 .86762 m .14913 .86363 L p .15068 .87224 L F P
0 g
s
.824 .684 .709 r
.15068 .87224 m .1489 .87154 L .14669 .86762 L p F P
0 g
s
.824 .537 .503 r
.18633 .94879 m .18013 .94691 L .17975 .9416 L p F P
0 g
s
.825 .537 .501 r
.17357 .93971 m .17975 .9416 L .18013 .94691 L p F P
0 g
s
.5 .268 .493 r
.62485 .94405 m .62801 .94059 L .62494 .94158 L closepath p F P
0 g
s
.457 .822 .994 r
.43454 .99559 m .44179 .99452 L p .42787 .99489 L F P
0 g
s
.444 .822 .99 r
.44179 .99452 m .43454 .99559 L .44349 .99515 L closepath p F P
0 g
s
.6 .585 .808 r
.61049 .77432 m .61337 .78049 L .60219 .78215 L p F P
0 g
s
.6 .585 .808 r
.61026 .77436 m .61049 .77432 L p .60219 .78215 L F P
0 g
s
.6 .585 .808 r
.60219 .78215 m .60056 .7787 L .61026 .77436 L p F P
0 g
s
.959 .811 .653 r
.75845 .10934 m .7606 .11346 L .76261 .10815 L p F P
0 g
s
.959 .811 .653 r
.76261 .10815 m .76048 .10403 L .75845 .10934 L p F P
0 g
s
.353 .781 .972 r
.36943 .99553 m .37224 .9953 L p .35835 .99507 L F P
0 g
s
.353 .781 .972 r
.35835 .99507 m .35847 .99511 L .36943 .99553 L p F P
0 g
s
.439 .079 .256 r
.58914 .96951 m .58668 .9701 L .57801 .97206 L p F P
0 g
s
.42 .044 .216 r
.58668 .9701 m .57794 .97222 L .57801 .97206 L closepath p F P
0 g
s
.539 .825 .998 r
.42043 .74521 m .43124 .74306 L .43434 .74478 L p F P
0 g
s
.326 0 0 r
.41415 .74329 m .41594 .74328 L p .41804 .74342 L F P
0 g
s
.347 .797 .951 r
.42043 .74521 m .42811 .74368 L p .42579 .74362 L F P
0 g
s
.347 .797 .951 r
.41731 .74361 m .42043 .74521 L p .42939 .74256 L F P
0 g
s
.347 .797 .951 r
.42939 .74256 m .42298 .74289 L .41731 .74361 L p F P
0 g
s
.338 .794 .945 r
.42298 .74289 m .41594 .74328 L .41731 .74361 L closepath p F P
0 g
s
.326 0 0 r
.42518 .74391 m .41513 .74335 L .41804 .74342 L F
.41513 .74335 m .41415 .74329 L .41804 .74342 L F
.347 .797 .951 r
.43124 .74306 m .42939 .74256 L p .42579 .74362 L F P
0 g
s
.347 .797 .951 r
.42811 .74368 m .43124 .74306 L p .42579 .74362 L F P
0 g
s
.587 .56 .79 r
.63243 .79893 m .62203 .8 L .61942 .79388 L p F P
0 g
s
.867 .828 .807 r
.73226 .18474 m .73537 .18113 L .73283 .17793 L p F P
0 g
s
.756 .731 .83 r
.22863 .76534 m .23088 .76375 L .22574 .76187 L closepath p F P
0 g
s
.986 .768 .523 r
.75908 .08469 m .75972 .08079 L .76205 .08488 L p F P
0 g
s
.986 .768 .523 r
.76205 .08488 m .76156 .08785 L .75908 .08469 L p F P
0 g
s
.198 .709 .896 r
.34448 .99459 m .34803 .99431 L .35809 .99508 L p F P
0 g
s
.369 .782 .979 r
.34803 .99431 m .34295 .99403 L .34448 .99459 L closepath p F P
0 g
s
.731 .776 .889 r
.64224 .25462 m .64488 .25316 L .64215 .24967 L p F P
0 g
s
.731 .776 .889 r
.64215 .24967 m .64076 .25043 L .64224 .25462 L p F P
0 g
s
.731 .772 .885 r
.63103 .25571 m .64076 .25043 L .64224 .25462 L p F P
0 g
s
.836 .651 .652 r
.14688 .89301 m .15245 .89513 L .15006 .90115 L p F P
0 g
s
.834 .659 .665 r
.15245 .89513 m .14688 .89301 L .14963 .8869 L p F P
0 g
s
.821 .703 .734 r
.15251 .8483 m .15496 .84493 L .15163 .83995 L p F P
0 g
s
.832 .677 .691 r
.14724 .87853 m .14994 .87356 L .1489 .87154 L p F P
0 g
s
.264 0 0 r
.29965 .99056 m .29628 .98972 L .28587 .98857 L p F P
0 g
s
.212 .694 .932 r
.28587 .98857 m .29628 .98972 L .29362 .98874 L p F P
0 g
s
.212 .694 .932 r
.28245 .98812 m .28587 .98857 L p .29362 .98874 L F P
0 g
s
.733 .741 .858 r
.2642 .74847 m .25348 .75477 L .25017 .75098 L p F P
0 g
s
.81 .711 .757 r
.16293 .82585 m .16314 .82561 L .16258 .82537 L closepath p F P
0 g
s
.804 .716 .768 r
.15956 .82137 m .16413 .81622 L p .16314 .82561 L F P
0 g
s
.804 .716 .768 r
.16314 .82561 m .16258 .82537 L .15956 .82137 L p F P
0 g
s
.428 .828 .981 r
.43434 .74478 m .44518 .74232 L .44232 .74133 L p F P
0 g
s
.428 .828 .981 r
.43124 .74306 m .43434 .74478 L p .44232 .74133 L F P
0 g
s
.577 .819 .99 r
.43434 .74478 m .44518 .74232 L .44824 .74429 L p F P
0 g
s
.351 0 .082 r
.57575 .97571 m .57794 .97222 L .58668 .9701 L p F P
0 g
s
.375 0 .099 r
.57794 .97222 m .57575 .97571 L .56439 .97826 L p F P
0 g
s
.814 .712 .752 r
.1575 .83251 m .16293 .82585 L .16258 .82537 L p F P
0 g
s
.481 .214 .432 r
.61345 .95488 m .61383 .95168 L .61965 .9483 L p F P
0 g
s
.535 .403 .647 r
.65349 .90144 m .65233 .89502 L .65758 .89292 L p F P
0 g
s
.789 .801 .862 r
.67416 .23846 m .66972 .2418 L .66704 .23843 L p F P
0 g
s
.75 .734 .837 r
.23609 .75398 m .23942 .75785 L .23088 .76375 L p F P
0 g
s
.75 .734 .837 r
.22531 .76137 m .23609 .75398 L p .23088 .76375 L F P
0 g
s
.75 .734 .837 r
.23088 .76375 m .22574 .76187 L .22531 .76137 L p F P
0 g
s
.919 .826 .738 r
.75077 .14034 m .75274 .14447 L .75622 .13859 L p F P
0 g
s
.919 .826 .738 r
.75622 .13859 m .75427 .13444 L .75077 .14034 L p F P
0 g
s
.61 .803 .974 r
.44824 .74429 m .45912 .74152 L .46216 .74382 L p F P
0 g
s
.529 .839 .999 r
.45912 .74152 m .44824 .74429 L .44518 .74232 L p F P
0 g
s
.7 .218 .1 r
.23784 .97787 m .23087 .97624 L .22597 .97207 L p F P
0 g
s
.675 .174 .047 r
.22287 .9714 m .22597 .97207 L .23087 .97624 L p F P
0 g
s
.192 0 0 r
.53925 .98449 m .53772 .98529 L .52586 .98732 L p F P
0 g
s
.113 0 0 r
.53772 .98529 m .53925 .98449 L .55031 .98272 L p F P
0 g
s
.939 .82 .701 r
.75694 .12159 m .75825 .1189 L .76031 .12303 L p F P
0 g
s
.939 .82 .701 r
.76031 .12303 m .75944 .12482 L .75694 .12159 L p F P
0 g
s
.861 .826 .812 r
.72437 .18747 m .72612 .19162 L .73226 .18474 L p F P
0 g
s
.861 .826 .812 r
.73226 .18474 m .73056 .18057 L .72437 .18747 L p F P
0 g
s
.867 .828 .807 r
.73283 .17793 m .73056 .18057 L .73226 .18474 L p F P
0 g
s
.814 .712 .752 r
.16258 .82537 m .15791 .8233 L p .1575 .83251 L F P
0 g
s
.811 .717 .761 r
.16258 .82537 m .15956 .82137 L .15791 .8233 L closepath p F P
0 g
s
.448 .824 .991 r
.44179 .99452 m .44349 .99515 L .45096 .99474 L p F P
0 g
s
.562 .494 .736 r
.65144 .84849 m .6508 .84649 L .65565 .8466 L closepath p F P
0 g
s
.557 .483 .727 r
.65375 .85604 m .65144 .84849 L .65565 .8466 L p F P
0 g
s
.566 .487 .725 r
.65144 .84849 m .65375 .85604 L .65351 .85614 L p F P
0 g
s
.632 .781 .953 r
.46216 .74382 m .47306 .7408 L .47607 .74349 L p F P
0 g
s
.593 .823 .987 r
.47306 .7408 m .46216 .74382 L .45912 .74152 L p F P
0 g
s
.562 .494 .737 r
.65565 .8466 m .6508 .84649 L .64895 .84075 L p F P
0 g
s
.771 .734 .818 r
.21603 .77129 m .21448 .76946 L .2135 .77024 L closepath p F P
0 g
s
.562 .494 .737 r
.64895 .84075 m .65607 .8375 L p .65565 .8466 L F P
0 g
s
.565 .505 .746 r
.64895 .84075 m .64784 .83748 L .65607 .8375 L closepath p F P
0 g
s
.318 .761 .963 r
.35835 .99507 m .35809 .99508 L .35847 .99511 L closepath p F P
0 g
s
.822 .506 .454 r
.18633 .94879 m .18712 .95294 L .18666 .95374 L p F P
0 g
s
.822 .506 .454 r
.18013 .94691 m .18633 .94879 L p .18666 .95374 L F P
0 g
s
0 0 .406 r
.58051 .23632 m .57949 .23482 L .5821 .23866 L p F P
0 g
s
0 0 .406 r
.5821 .23866 m .58335 .24047 L .58051 .23632 L p F P
0 g
s
.435 .795 .996 r
.35809 .99508 m .35835 .99507 L .35512 .99359 L p F P
0 g
s
.435 .795 .996 r
.35512 .99359 m .34803 .99431 L .35809 .99508 L p F P
0 g
s
.56 .474 .715 r
.65378 .85615 m .65351 .85614 L .65375 .85604 L closepath p F P
0 g
s
.779 .731 .809 r
.20426 .77895 m .20363 .77818 L .20323 .77851 L closepath p F P
0 g
s
.637 .662 .858 r
.5347 .74947 m .54573 .74652 L .54864 .75118 L p F P
0 g
s
.638 .673 .867 r
.5434 .74294 m .54573 .74652 L .5347 .74947 L p F P
0 g
s
.638 .673 .867 r
.5347 .74947 m .53277 .74655 L .5434 .74294 L p F P
0 g
s
.832 .677 .691 r
.1489 .87154 m .14526 .87004 L p .14724 .87853 L F P
0 g
s
.83 .685 .703 r
.1489 .87154 m .14669 .86762 L .14526 .87004 L closepath p F P
0 g
s
.565 .505 .747 r
.65607 .8375 m .64784 .83748 L .64626 .8328 L p F P
0 g
s
.042 0 0 r
.52535 .98751 m .52586 .98732 L .53772 .98529 L p F P
0 g
s
.756 .787 .878 r
.65597 .24614 m .64488 .25316 L .64215 .24967 L p F P
0 g
s
.767 .359 .279 r
.219 .97043 m .21224 .96874 L .20902 .96414 L p F P
0 g
s
.758 .338 .251 r
.20581 .96336 m .20902 .96414 L .21224 .96874 L p F P
0 g
s
.353 .781 .972 r
.37224 .9953 m .36904 .99368 L .35835 .99507 L p F P
0 g
s
.557 .8 .989 r
.36904 .99368 m .35835 .99507 L .35512 .99359 L p F P
0 g
s
.551 .469 .716 r
.65378 .85615 m .65375 .85604 L .66359 .8516 L p F P
0 g
s
.557 .483 .727 r
.66217 .84697 m .66359 .8516 L .65375 .85604 L p F P
0 g
s
.557 .483 .727 r
.65565 .8466 m .66217 .84697 L p .65375 .85604 L F P
0 g
s
.552 .469 .715 r
.65584 .86338 m .65378 .85615 L .66518 .85711 L p F P
0 g
s
.551 .469 .716 r
.66359 .8516 m .66518 .85711 L .65378 .85615 L p F P
0 g
s
.859 .451 0 r
.57672 .23102 m .57949 .23482 L .57796 .23075 L p F P
0 g
s
.859 .451 0 r
.57796 .23075 m .5752 .22695 L .57672 .23102 L p F P
0 g
s
.821 .703 .734 r
.15163 .83995 m .14724 .84603 L .15251 .8483 L p F P
0 g
s
.824 .699 .727 r
.14724 .84603 m .15251 .8483 L .14798 .85489 L p F P
0 g
s
.644 .756 .931 r
.47607 .74349 m .487 .74031 L .48998 .74339 L p F P
0 g
s
.627 .793 .962 r
.487 .74031 m .47607 .74349 L .47306 .7408 L p F P
0 g
s
.836 .662 .667 r
.14414 .88473 m .14963 .8869 L .14688 .89301 L p F P
0 g
s
.833 .669 .679 r
.14963 .8869 m .14414 .88473 L .14724 .87853 L p F P
0 g
s
.791 .803 .862 r
.67416 .23846 m .68075 .23343 L .6781 .23008 L p F P
0 g
s
.791 .803 .862 r
.6781 .23008 m .67253 .23432 L .67416 .23846 L p F P
0 g
s
.789 .801 .862 r
.66704 .23843 m .67253 .23432 L .67416 .23846 L p F P
0 g
s
.437 0 0 r
.26837 .98567 m .26083 .98421 L .255 .98209 L p F P
0 g
s
.465 0 0 r
.26083 .98421 m .255 .98209 L .25148 .98238 L p F P
0 g
s
.565 .505 .747 r
.64626 .8328 m .6548 .82885 L p .65607 .8375 L F P
0 g
s
.568 .515 .756 r
.64626 .8328 m .64491 .82901 L .6548 .82885 L closepath p F P
0 g
s
.783 .727 .8 r
.19272 .78764 m .19405 .78646 L .19059 .78501 L closepath p F P
0 g
s
.79 .728 .795 r
.18569 .79416 m .19272 .78764 L .19059 .78501 L p F P
0 g
s
.778 .731 .809 r
.19791 .77618 m .20323 .77851 L .19405 .78646 L p F P
0 g
s
.778 .731 .809 r
.18935 .78353 m .19791 .77618 L p .19405 .78646 L F P
0 g
s
.778 .731 .809 r
.19405 .78646 m .19059 .78501 L .18935 .78353 L p F P
0 g
s
.791 .726 .791 r
.18569 .79416 m .18175 .79791 L .17838 .79371 L p F P
0 g
s
.791 .726 .791 r
.17838 .79371 m .18033 .79185 L .18569 .79416 L p F P
0 g
s
.79 .728 .795 r
.18866 .78415 m .18033 .79185 L .18569 .79416 L p F P
0 g
s
.79 .728 .795 r
.19059 .78501 m .18866 .78415 L p .18569 .79416 L F P
0 g
s
.828 .685 .706 r
.14913 .86363 m .14669 .86762 L .14341 .86189 L p F P
0 g
s
.828 .685 .706 r
.14341 .86189 m .1437 .86142 L .14913 .86363 L p F P
0 g
s
.824 .691 .717 r
.14913 .86363 m .1437 .86142 L .14798 .85489 L p F P
0 g
s
.602 .594 .815 r
.60056 .7787 m .5993 .7761 L .61026 .77436 L closepath p F P
0 g
s
.988 .738 .457 r
.7573 .07673 m .75972 .08079 L .76009 .07614 L p F P
0 g
s
.988 .738 .457 r
.76009 .07614 m .75767 .07207 L .7573 .07673 L p F P
0 g
s
.29 .526 .907 r
.59261 .24411 m .59509 .24799 L .58785 .24598 L p F P
0 g
s
.29 .526 .907 r
.58785 .24598 m .58553 .24204 L .59261 .24411 L p F P
0 g
s
0 .282 .784 r
.58335 .24047 m .58553 .24204 L .58785 .24598 L p F P
0 g
s
.308 0 0 r
.56419 .97849 m .559 .97938 L .56439 .97826 L closepath p F P
0 g
s
.22 0 0 r
.559 .97938 m .56419 .97849 L p .55031 .98272 L F P
0 g
s
.797 .726 .786 r
.17793 .80168 m .18175 .79791 L .17838 .79371 L p F P
0 g
s
.616 .719 .919 r
.60315 .25597 m .61434 .25321 L .61712 .25695 L p F P
0 g
s
.609 .716 .921 r
.61434 .25321 m .60315 .25597 L .60034 .25205 L p F P
0 g
s
.72 .743 .87 r
.2642 .74847 m .26951 .74569 L .27576 .74775 L p F P
0 g
s
.724 .748 .871 r
.27491 .74289 m .26951 .74569 L .27576 .74775 L p F P
0 g
s
.724 .748 .871 r
.27576 .74775 m .2782 .74644 L .27491 .74289 L p F P
0 g
s
.661 .768 .929 r
.30609 .74392 m .31675 .7403 L .32 .74329 L p F P
0 g
s
.638 .777 .948 r
.31675 .7403 m .30609 .74392 L .30283 .74068 L p F P
0 g
s
.685 .757 .906 r
.29216 .74496 m .30283 .74068 L .30609 .74392 L p F P
0 g
s
.519 .347 .587 r
.64554 .92344 m .64498 .91759 L .65527 .91377 L p F P
0 g
s
.529 .37 .61 r
.65502 .91185 m .65527 .91377 L .64498 .91759 L p F P
0 g
s
.529 .37 .61 r
.65028 .90928 m .65502 .91185 L p .64498 .91759 L F P
0 g
s
.5 0 0 r
.24544 .97932 m .25148 .98238 L .25024 .98233 L p F P
0 g
s
.5 0 0 r
.23788 .97788 m .24544 .97932 L p .25024 .98233 L F P
0 g
s
.936 .822 .708 r
.75748 .12866 m .75944 .12482 L .75694 .12159 L p F P
0 g
s
.89 .827 .779 r
.74102 .16134 m .74438 .15678 L .74623 .16093 L p F P
0 g
s
.89 .827 .779 r
.74623 .16093 m .74355 .16457 L .74102 .16134 L p F P
0 g
s
.426 .823 .983 r
.45572 .99403 m .45096 .99474 L .4567 .99435 L closepath p F P
0 g
s
.448 .824 .991 r
.45096 .99474 m .45572 .99403 L p .44179 .99452 L F P
0 g
s
.625 .781 .956 r
.32 .74329 m .33065 .74039 L .3339 .74304 L p F P
0 g
s
.579 .792 .98 r
.33065 .74039 m .32 .74329 L .31675 .7403 L p F P
0 g
s
.568 .515 .756 r
.6548 .82885 m .64491 .82901 L .64334 .82463 L p F P
0 g
s
.799 .725 .782 r
.17793 .80168 m .17071 .809 L .16733 .80477 L p F P
0 g
s
.799 .725 .782 r
.16733 .80477 m .17267 .79935 L .17793 .80168 L p F P
0 g
s
.797 .726 .786 r
.17838 .79371 m .17267 .79935 L .17793 .80168 L p F P
0 g
s
.648 .733 .911 r
.48998 .74339 m .50094 .74013 L .5039 .74359 L p F P
0 g
s
.642 .762 .935 r
.50094 .74013 m .48998 .74339 L .487 .74031 L p F P
0 g
s
.78 .734 .811 r
.20026 .7742 m .19791 .77618 L .20323 .77851 L p F P
0 g
s
.78 .734 .811 r
.20323 .77851 m .20363 .77818 L .20026 .7742 L p F P
0 g
s
.673 .764 .919 r
.30283 .74068 m .29216 .74496 L .28888 .74154 L p F P
0 g
s
.774 .735 .817 r
.2135 .77024 m .20363 .77818 L .20026 .7742 L p F P
0 g
s
.814 .711 .751 r
.15223 .83021 m .1575 .83251 L .15208 .83935 L p F P
0 g
s
.814 .712 .752 r
.15791 .8233 m .15223 .83021 L .1575 .83251 L p F P
0 g
s
.289 0 0 r
.27668 .98693 m .28245 .98812 L p .26868 .98577 L F P
0 g
s
.289 0 0 r
.26868 .98577 m .26894 .98578 L .27668 .98693 L p F P
0 g
s
.612 .613 .828 r
.59065 .75901 m .59354 .76456 L .58239 .76668 L p F P
0 g
s
.612 .613 .828 r
.58067 .76092 m .59065 .75901 L p .58239 .76668 L F P
0 g
s
.612 .613 .828 r
.58239 .76668 m .57962 .76137 L .58067 .76092 L p F P
0 g
s
.492 .257 .486 r
.62801 .94059 m .63552 .93815 L p .62473 .94675 L F P
0 g
s
.492 .257 .486 r
.62473 .94675 m .62485 .94405 L .62801 .94059 L p F P
0 g
s
.515 .303 .53 r
.62801 .94059 m .63552 .93815 L .63544 .93273 L p F P
0 g
s
.549 .458 .704 r
.65584 .86338 m .66573 .85899 L p .66405 .86779 L F P
0 g
s
.549 .458 .704 r
.66405 .86779 m .65681 .86698 L .65584 .86338 L p F P
0 g
s
.552 .469 .715 r
.66518 .85711 m .66573 .85899 L .65584 .86338 L p F P
0 g
s
.59 .568 .798 r
.61942 .79388 m .61914 .79324 L .62133 .79299 L closepath p F P
0 g
s
.587 .56 .79 r
.61942 .79388 m .62133 .79299 L p .63243 .79893 L F P
0 g
s
.481 .214 .432 r
.61965 .9483 m .62473 .94675 L p .61345 .95488 L F P
0 g
s
.508 .27 .488 r
.61965 .9483 m .62473 .94675 L .62485 .94405 L closepath p F P
0 g
s
.854 .822 .817 r
.722 .19003 m .72437 .18747 L .72612 .19162 L p F P
0 g
s
.854 .822 .817 r
.72612 .19162 m .72457 .19329 L .722 .19003 L p F P
0 g
s
.4 .798 .986 r
.38614 .99537 m .38296 .99366 L .37224 .9953 L p F P
0 g
s
.577 .798 .983 r
.38296 .99366 m .37224 .9953 L .36904 .99368 L p F P
0 g
s
.621 .63 .838 r
.56551 .75838 m .57662 .75592 L .5795 .76115 L p F P
0 g
s
.622 .634 .841 r
.57372 .75076 m .57662 .75592 L .56551 .75838 L p F P
0 g
s
.622 .634 .841 r
.56325 .7531 m .57372 .75076 L p .56551 .75838 L F P
0 g
s
.622 .634 .841 r
.56551 .75838 m .56266 .75333 L .56325 .7531 L p F P
0 g
s
.675 .174 .047 r
.22076 .97233 m .22287 .9714 L p .23087 .97624 L F P
0 g
s
.739 .29 .187 r
.22076 .97233 m .219 .97043 L .22287 .9714 L closepath p F P
0 g
s
.967 .801 .624 r
.75824 .09993 m .76048 .10403 L .76215 .09885 L p F P
0 g
s
.967 .801 .624 r
.76215 .09885 m .75993 .09474 L .75824 .09993 L p F P
0 g
s
.546 .435 .678 r
.65989 .87923 m .65663 .87871 L .6595 .87752 L closepath p F P
0 g
s
.553 .45 .691 r
.65776 .87054 m .6595 .87752 L .65663 .87871 L p F P
0 g
s
.573 .796 .984 r
.3339 .74304 m .34455 .74085 L .34778 .7431 L p F P
0 g
s
.474 .795 .999 r
.34455 .74085 m .3339 .74304 L .33065 .74039 L p F P
0 g
s
.59 .57 .8 r
.62133 .79299 m .61914 .79324 L .61626 .78678 L p F P
0 g
s
.802 .806 .855 r
.68529 .22976 m .68075 .23343 L .6781 .23008 L p F P
0 g
s
.848 .822 .823 r
.7193 .19876 m .72457 .19329 L .722 .19003 L p F P
0 g
s
.568 .515 .756 r
.64334 .82463 m .65182 .82065 L p .6548 .82885 L F P
0 g
s
.571 .525 .765 r
.64334 .82463 m .64198 .82098 L .65182 .82065 L closepath p F P
0 g
s
.503 .293 .528 r
.63552 .93815 m .63544 .93273 L .64587 .92909 L p F P
0 g
s
.518 .327 .562 r
.64554 .92344 m .64587 .92909 L .63544 .93273 L p F P
0 g
s
.743 .737 .846 r
.24482 .75437 m .23942 .75785 L .23609 .75398 L p F P
0 g
s
.802 .723 .777 r
.17082 .80914 m .17071 .809 L .17065 .80906 L closepath p F P
0 g
s
.697 .755 .897 r
.28888 .74154 m .2782 .74644 L .27491 .74289 L p F P
0 g
s
.803 .726 .778 r
.17065 .80906 m .17071 .809 L .16733 .80477 L p F P
0 g
s
.806 .721 .771 r
.16548 .80671 m .17065 .80906 L .16413 .81622 L p F P
0 g
s
.803 .726 .778 r
.16733 .80477 m .16548 .80671 L .17065 .80906 L p F P
0 g
s
.549 .458 .704 r
.65776 .87054 m .65681 .86698 L .66405 .86779 L closepath p F P
0 g
s
.216 .701 .929 r
.31067 .99095 m .30933 .99076 L .29965 .99056 L p F P
0 g
s
.159 .678 .887 r
.30933 .99076 m .29965 .99056 L .29628 .98972 L p F P
0 g
s
.835 .672 .681 r
.14184 .87633 m .14724 .87853 L .14414 .88473 L p F P
0 g
s
.832 .677 .691 r
.14526 .87004 m .14184 .87633 L .14724 .87853 L p F P
0 g
s
.042 0 0 r
.53772 .98529 m .53639 .9857 L .52535 .98751 L p F P
0 g
s
.245 .76 .823 r
.53639 .9857 m .52535 .98751 L .52244 .98784 L p F P
0 g
s
0 0 0 r
.52535 .98751 m .52244 .98784 L .51144 .98964 L p F P
0 g
s
.428 .824 .983 r
.45572 .99403 m .4567 .99435 L .46912 .99345 L p F P
0 g
s
.986 .771 .531 r
.76123 .08971 m .76156 .08785 L .75908 .08469 L p F P
0 g
s
.802 .447 .385 r
.20235 .96241 m .19588 .96063 L .19391 .95571 L p F P
0 g
s
.8 .442 .378 r
.18737 .95394 m .19391 .95571 L .19588 .96063 L p F P
0 g
s
.807 .485 .445 r
.19391 .95571 m .18737 .95394 L .18712 .95294 L p F P
0 g
s
.983 .696 .372 r
.75515 .06802 m .75767 .07207 L .7576 .06759 L p F P
0 g
s
.983 .696 .372 r
.7576 .06759 m .75508 .06354 L .75515 .06802 L p F P
0 g
s
.413 .795 .991 r
.34803 .99431 m .35512 .99359 L p .34122 .99332 L F P
0 g
s
.413 .795 .991 r
.34122 .99332 m .34295 .99403 L .34803 .99431 L p F P
0 g
s
.647 .734 .912 r
.51489 .74035 m .5039 .74359 L .50094 .74013 L p F P
0 g
s
.648 .712 .895 r
.5039 .74359 m .51489 .74035 L .51783 .74414 L p F P
0 g
s
.805 .808 .853 r
.68529 .22976 m .69176 .22443 L .68913 .22111 L p F P
0 g
s
.805 .808 .853 r
.68913 .22111 m .68363 .22562 L .68529 .22976 L p F P
0 g
s
.802 .806 .855 r
.6781 .23008 m .68363 .22562 L .68529 .22976 L p F P
0 g
s
.431 .808 .992 r
.40004 .99531 m .39689 .99355 L .38614 .99537 L p F P
0 g
s
.589 .797 .979 r
.39689 .99355 m .38614 .99537 L .38296 .99366 L p F P
0 g
s
.602 .596 .817 r
.61026 .77436 m .5993 .7761 L .59642 .77023 L p F P
0 g
s
.839 .594 .569 r
.15665 .92273 m .16246 .92476 L .16174 .93035 L p F P
0 g
s
.837 .609 .594 r
.16246 .92476 m .15665 .92273 L .15784 .91703 L p F P
0 g
s
.837 .592 .569 r
.16728 .93224 m .16174 .93035 L .16246 .92476 L p F P
0 g
s
.837 .625 .616 r
.15784 .91703 m .15209 .91497 L .15371 .90915 L p F P
0 g
s
.839 .612 .594 r
.15209 .91497 m .15784 .91703 L .15665 .92273 L p F P
0 g
s
.758 .338 .251 r
.20378 .9649 m .20581 .96336 L p .21224 .96874 L F P
0 g
s
.786 .397 .317 r
.20378 .9649 m .20235 .96241 L .20581 .96336 L closepath p F P
0 g
s
.571 .526 .765 r
.65182 .82065 m .64198 .82098 L .6402 .81622 L p F P
0 g
s
.528 .371 .611 r
.65502 .91185 m .65028 .90928 L .65448 .9077 L closepath p F P
0 g
s
.538 .391 .63 r
.65349 .90144 m .65448 .9077 L .65028 .90928 L p F P
0 g
s
.848 .822 .823 r
.722 .19003 m .7176 .1946 L .7193 .19876 L p F P
0 g
s
.844 .82 .826 r
.71109 .2012 m .7176 .1946 L .7193 .19876 L p F P
0 g
s
.844 .82 .826 r
.7193 .19876 m .71368 .20445 L .71109 .2012 L p F P
0 g
s
.886 .828 .785 r
.74147 .1673 m .74355 .16457 L .74102 .16134 L p F P
0 g
s
.729 .769 .885 r
.64076 .25043 m .63103 .25571 L .62828 .2521 L p F P
0 g
s
.693 .757 .901 r
.61712 .25695 m .62828 .2521 L .63103 .25571 L p F P
0 g
s
.774 .735 .817 r
.20026 .7742 m .2081 .76792 L .2135 .77024 L p F P
0 g
s
.772 .737 .82 r
.21113 .76554 m .2081 .76792 L .2135 .77024 L p F P
0 g
s
.772 .737 .82 r
.2135 .77024 m .21448 .76946 L .21113 .76554 L p F P
0 g
s
.496 .802 .999 r
.34778 .7431 m .35844 .74155 L .36167 .74335 L p F P
0 g
s
.336 .761 .974 r
.34778 .7431 m .35844 .74155 L .3565 .74083 L p F P
0 g
s
.336 .761 .974 r
.34455 .74085 m .34778 .7431 L p .3565 .74083 L F P
0 g
s
.765 .738 .828 r
.22502 .76158 m .21448 .76946 L .21113 .76554 L p F P
0 g
s
.827 .563 .54 r
.17357 .93971 m .1674 .9378 L .16761 .93234 L p F P
0 g
s
.829 .565 .539 r
.16728 .93224 m .16761 .93234 L .1674 .9378 L p F P
0 g
s
.527 .385 .631 r
.65448 .9077 m .65349 .90144 L .66362 .8974 L p F P
0 g
s
.535 .403 .647 r
.66311 .89463 m .66362 .8974 L .65349 .90144 L p F P
0 g
s
.535 .403 .647 r
.65758 .89292 m .66311 .89463 L p .65349 .90144 L F P
0 g
s
.831 .687 .704 r
.14526 .87004 m .14669 .86762 L .14341 .86189 L p F P
0 g
s
.544 .445 .692 r
.6595 .87752 m .65776 .87054 L .66405 .86779 L p F P
0 g
s
.839 .627 .617 r
.14803 .90707 m .15371 .90915 L .15209 .91497 L p F P
0 g
s
.836 .638 .635 r
.15371 .90915 m .14803 .90707 L .15006 .90115 L p F P
0 g
s
.908 .825 .753 r
.7491 .14296 m .75077 .14034 L .75274 .14447 L p F P
0 g
s
.908 .825 .753 r
.75274 .14447 m .75161 .14623 L .7491 .14296 L p F P
0 g
s
.631 .652 .853 r
.54864 .75118 m .55971 .74842 L .56261 .75324 L p F P
0 g
s
.632 .658 .858 r
.55971 .74842 m .54864 .75118 L .54573 .74652 L p F P
0 g
s
.814 .81 .847 r
.69513 .22152 m .69176 .22443 L .68913 .22111 L p F P
0 g
s
.375 .776 .985 r
.34122 .99332 m .33792 .99354 L .34295 .99403 L closepath p F P
0 g
s
.829 .565 .539 r
.1674 .9378 m .16652 .93753 L .16728 .93224 L p F P
0 g
s
.838 .573 .539 r
.16174 .93035 m .16728 .93224 L .16652 .93753 L p F P
0 g
s
.45 .814 .995 r
.41395 .99515 m .41083 .99337 L .40004 .99531 L p F P
0 g
s
.596 .797 .977 r
.41083 .99337 m .40004 .99531 L .39689 .99355 L p F P
0 g
s
.948 .813 .677 r
.75609 .1148 m .75825 .1189 L .7606 .11346 L p F P
0 g
s
.948 .813 .677 r
.7606 .11346 m .75845 .10934 L .75609 .1148 L p F P
0 g
s
.689 .754 .901 r
.62828 .2521 m .61712 .25695 L .61434 .25321 L p F P
0 g
s
.836 .82 .833 r
.71203 .20606 m .71368 .20445 L .71109 .2012 L p F P
0 g
s
.818 .812 .845 r
.69513 .22152 m .70275 .21481 L .70013 .21149 L p F P
0 g
s
.818 .812 .845 r
.70013 .21149 m .69344 .21738 L .69513 .22152 L p F P
0 g
s
.814 .81 .847 r
.68913 .22111 m .69344 .21738 L .69513 .22152 L p F P
0 g
s
.836 .82 .833 r
.71109 .2012 m .71038 .20189 L .71203 .20606 L p F P
0 g
s
.831 .817 .837 r
.70231 .20949 m .70404 .21363 L .71203 .20606 L p F P
0 g
s
.831 .817 .837 r
.71203 .20606 m .71038 .20189 L .70231 .20949 L p F P
0 g
s
.825 .696 .721 r
.14266 .85264 m .14798 .85489 L .1437 .86142 L p F P
0 g
s
.824 .699 .727 r
.14798 .85489 m .14266 .85264 L .14724 .84603 L p F P
0 g
s
.714 .743 .874 r
.26951 .74569 m .2642 .74847 L .2609 .74476 L p F P
0 g
s
.733 .741 .858 r
.25017 .75098 m .2609 .74476 L .2642 .74847 L p F P
0 g
s
.809 .719 .766 r
.16413 .81622 m .15956 .82137 L .15618 .81695 L p F P
0 g
s
.809 .719 .766 r
.15618 .81695 m .15889 .8139 L .16413 .81622 L p F P
0 g
s
.806 .721 .771 r
.16413 .81622 m .15889 .8139 L .16548 .80671 L p F P
0 g
s
.575 .536 .774 r
.6402 .81622 m .63907 .81332 L .64712 .81292 L closepath p F P
0 g
s
.571 .526 .765 r
.6402 .81622 m .64712 .81292 L p .65182 .82065 L F P
0 g
s
.886 .828 .785 r
.74102 .16134 m .73965 .16314 L .74147 .1673 L p F P
0 g
s
.877 .826 .793 r
.73437 .16971 m .73622 .17385 L .74147 .1673 L p F P
0 g
s
.877 .826 .793 r
.74147 .1673 m .73965 .16314 L .73437 .16971 L p F P
0 g
s
.936 .822 .708 r
.75694 .12159 m .75545 .12453 L .75748 .12866 L p F P
0 g
s
.925 .822 .726 r
.75222 .13032 m .75427 .13444 L .75748 .12866 L p F P
0 g
s
.925 .822 .726 r
.75748 .12866 m .75545 .12453 L .75222 .13032 L p F P
0 g
s
.819 .705 .739 r
.15163 .83995 m .15208 .83935 L .15087 .83883 L closepath p F P
0 g
s
.814 .711 .751 r
.14827 .83522 m .15223 .83021 L p .15208 .83935 L F P
0 g
s
.814 .711 .751 r
.15208 .83935 m .15087 .83883 L .14827 .83522 L p F P
0 g
s
.838 .641 .636 r
.14446 .89903 m .15006 .90115 L .14803 .90707 L p F P
0 g
s
.836 .651 .652 r
.15006 .90115 m .14446 .89903 L .14688 .89301 L p F P
0 g
s
.826 .814 .839 r
.70013 .21149 m .70231 .20949 L .70404 .21363 L p F P
0 g
s
.826 .814 .839 r
.70404 .21363 m .70275 .21481 L .70013 .21149 L p F P
0 g
s
.586 .561 .793 r
.63039 .7921 m .62133 .79299 L .62918 .78928 L closepath p F P
0 g
s
.59 .57 .8 r
.6275 .78552 m .62918 .78928 L .62133 .79299 L p F P
0 g
s
.59 .57 .8 r
.61626 .78678 m .6275 .78552 L p .62133 .79299 L F P
0 g
s
.587 .56 .79 r
.62133 .79299 m .63039 .7921 L p .63243 .79893 L F P
0 g
s
.745 .742 .849 r
.24685 .74725 m .23889 .7522 L .24482 .75437 L p F P
0 g
s
.745 .742 .849 r
.24482 .75437 m .25017 .75098 L .24685 .74725 L p F P
0 g
s
.743 .737 .846 r
.23609 .75398 m .23889 .7522 L .24482 .75437 L p F P
0 g
s
.393 .832 .947 r
.51144 .98964 m .52244 .98784 L .51952 .98734 L p F P
0 g
s
.393 .832 .947 r
.50849 .98943 m .51144 .98964 L p .51952 .98734 L F P
0 g
s
.287 .783 .878 r
.49751 .99125 m .50849 .98943 L .51144 .98964 L p F P
0 g
s
.458 .819 .996 r
.42787 .99489 m .42477 .99314 L .41395 .99515 L p F P
0 g
s
.597 .799 .977 r
.42477 .99314 m .41395 .99515 L .41083 .99337 L p F P
0 g
s
.825 .537 .501 r
.18013 .94691 m .17396 .94502 L .17357 .93971 L p F P
0 g
s
.826 .537 .5 r
.1674 .9378 m .17357 .93971 L .17396 .94502 L p F P
0 g
s
.18 .694 .892 r
.36167 .74335 m .37235 .74231 L .37229 .74229 L p F P
0 g
s
.18 .694 .892 r
.35844 .74155 m .36167 .74335 L p .37229 .74229 L F P
0 g
s
.398 .791 .988 r
.36167 .74335 m .37235 .74231 L .37557 .74366 L p F P
0 g
s
.644 .694 .882 r
.51783 .74414 m .52884 .74099 L .53177 .74508 L p F P
0 g
s
.645 .71 .895 r
.52884 .74099 m .51783 .74414 L .51489 .74035 L p F P
0 g
s
.823 .705 .735 r
.14724 .84603 m .15163 .83995 L .15087 .83883 L p F P
0 g
s
0 .257 .766 r
.58553 .24204 m .58335 .24047 L .58051 .23632 L p F P
0 g
s
.904 .826 .759 r
.74874 .15055 m .75161 .14623 L .7491 .14296 L p F P
0 g
s
.639 .679 .871 r
.54282 .74207 m .5434 .74294 L .53277 .74655 L p F P
0 g
s
.639 .679 .871 r
.53277 .74655 m .53177 .74508 L .54282 .74207 L p F P
0 g
s
.287 0 0 r
.56419 .97849 m .56439 .97826 L .57575 .97571 L p F P
0 g
s
.835 .682 .693 r
.13995 .8678 m .14526 .87004 L .14184 .87633 L p F P
0 g
s
.831 .687 .704 r
.14341 .86189 m .13995 .8678 L .14526 .87004 L p F P
0 g
s
.763 .736 .829 r
.22574 .76187 m .22531 .76137 L .22502 .76158 L closepath p F P
0 g
s
.772 .791 .869 r
.65948 .24372 m .65597 .24614 L .65326 .24267 L p F P
0 g
s
.756 .787 .878 r
.64215 .24967 m .65326 .24267 L .65597 .24614 L p F P
0 g
s
.986 .771 .531 r
.75908 .08469 m .75891 .08562 L .76123 .08971 L p F P
0 g
s
.975 .787 .588 r
.7576 .09066 m .75993 .09474 L .76123 .08971 L p F P
0 g
s
.975 .787 .588 r
.76123 .08971 m .75891 .08562 L .7576 .09066 L p F P
0 g
s
.458 .633 .93 r
.59752 .24815 m .59509 .24799 L .5974 .25191 L p F P
0 g
s
.458 .633 .93 r
.5974 .25191 m .60034 .25205 L .59752 .24815 L p F P
0 g
s
.787 .732 .802 r
.19059 .78501 m .18935 .78353 L .18866 .78415 L closepath p F P
0 g
s
.723 .251 .127 r
.219 .97043 m .22076 .97233 L .21759 .97326 L p F P
0 g
s
.723 .251 .127 r
.21224 .96874 m .219 .97043 L p .21759 .97326 L F P
0 g
s
.574 .536 .774 r
.64712 .81292 m .63907 .81332 L .63682 .80755 L p F P
0 g
s
.457 .822 .994 r
.44179 .99452 m .43872 .99286 L .42787 .99489 L p F P
0 g
s
.595 .803 .979 r
.43872 .99286 m .42787 .99489 L .42477 .99314 L p F P
0 g
s
.349 .762 .98 r
.32713 .99273 m .31888 .99169 L .31347 .99192 L p F P
0 g
s
.314 .756 .964 r
.31888 .99169 m .31067 .99095 L .31347 .99192 L closepath p F P
0 g
s
.459 .799 .999 r
.33792 .99354 m .34122 .99332 L .33796 .99161 L p F P
0 g
s
.459 .799 .999 r
.33796 .99161 m .32778 .99278 L .33792 .99354 L p F P
0 g
s
.275 .743 .944 r
.32734 .99282 m .32778 .99278 L .33792 .99354 L p F P
0 g
s
.378 .82 .949 r
.49498 .99071 m .49751 .99125 L .50849 .98943 L p F P
0 g
s
.45 .149 .362 r
.61251 .95941 m .61345 .95488 L .62419 .95163 L p F P
0 g
s
.481 .214 .432 r
.62473 .94675 m .62419 .95163 L .61345 .95488 L p F P
0 g
s
.465 .161 .366 r
.61345 .95488 m .61251 .95941 L .60161 .96248 L p F P
0 g
s
.38 0 0 r
.26868 .98577 m .26837 .98567 L .26894 .98578 L closepath p F P
0 g
s
.813 .72 .762 r
.15791 .8233 m .15956 .82137 L .15618 .81695 L p F P
0 g
s
.838 .654 .653 r
.14136 .89085 m .14688 .89301 L .14446 .89903 L p F P
0 g
s
.836 .662 .667 r
.14688 .89301 m .14136 .89085 L .14414 .88473 L p F P
0 g
s
.395 .819 .967 r
.46965 .99337 m .46912 .99345 L .46975 .9934 L closepath p F P
0 g
s
.428 .824 .983 r
.46912 .99345 m .46965 .99337 L p .45572 .99403 L F P
0 g
s
.588 .809 .984 r
.45267 .99249 m .44179 .99452 L .43872 .99286 L p F P
0 g
s
.448 .824 .991 r
.45572 .99403 m .45267 .99249 L .44179 .99452 L p F P
0 g
s
.538 .43 .679 r
.6595 .87752 m .66942 .87319 L p .66861 .88107 L F P
0 g
s
.538 .43 .679 r
.66861 .88107 m .65989 .87923 L .6595 .87752 L p F P
0 g
s
.544 .445 .692 r
.66824 .86848 m .66942 .87319 L .6595 .87752 L p F P
0 g
s
.544 .445 .692 r
.66405 .86779 m .66824 .86848 L p .6595 .87752 L F P
0 g
s
.556 .482 .728 r
.66217 .84697 m .65565 .8466 L .66128 .84403 L closepath p F P
0 g
s
.562 .494 .737 r
.6592 .8376 m .66128 .84403 L .65565 .8466 L p F P
0 g
s
.562 .494 .737 r
.65607 .8375 m .6592 .8376 L p .65565 .8466 L F P
0 g
s
.59 .571 .801 r
.62487 .77963 m .6275 .78552 L .61626 .78678 L p F P
0 g
s
.59 .571 .801 r
.61626 .78678 m .61513 .78427 L .62487 .77963 L p F P
0 g
s
.249 0 0 r
.26837 .98567 m .26868 .98577 L .26522 .9853 L p F P
0 g
s
.249 0 0 r
.26522 .9853 m .26083 .98421 L .26837 .98567 L p F P
0 g
s
.409 .826 .97 r
.46965 .99337 m .46975 .9934 L .48239 .99209 L p F P
0 g
s
.334 .798 .934 r
.48358 .99246 m .48239 .99209 L .46975 .9934 L p F P
0 g
s
.765 .738 .828 r
.21113 .76554 m .21958 .75926 L .22502 .76158 L p F P
0 g
s
.764 .74 .831 r
.22196 .75753 m .21958 .75926 L .22502 .76158 L p F P
0 g
s
.764 .74 .831 r
.22502 .76158 m .22531 .76137 L .22196 .75753 L p F P
0 g
s
.418 .071 .267 r
.60026 .96645 m .60161 .96248 L .61251 .95941 L p F P
0 g
s
.423 .064 .249 r
.60026 .96645 m .60161 .96248 L p .58914 .96951 L F P
0 g
s
.823 .705 .735 r
.15087 .83883 m .14687 .83704 L p .14724 .84603 L F P
0 g
s
.821 .711 .744 r
.15087 .83883 m .14827 .83522 L .14687 .83704 L closepath p F P
0 g
s
.287 0 0 r
.57575 .97571 m .5753 .97621 L .56419 .97849 L p F P
0 g
s
.143 0 0 r
.5753 .97621 m .56419 .97849 L .5614 .98061 L p F P
0 g
s
.22 0 0 r
.56419 .97849 m .5614 .98061 L .55031 .98272 L p F P
0 g
s
.534 .403 .649 r
.66311 .89463 m .65758 .89292 L .66243 .89095 L closepath p F P
0 g
s
.542 .421 .664 r
.66105 .88432 m .66243 .89095 L .65758 .89292 L p F P
0 g
s
.754 .739 .838 r
.23609 .75398 m .22531 .76137 L .22196 .75753 L p F P
0 g
s
.391 .825 .956 r
.49498 .99071 m .49124 .99117 L .48358 .99246 L p F P
0 g
s
.437 .833 .981 r
.49124 .99117 m .48239 .99209 L .48358 .99246 L closepath p F P
0 g
s
.334 .774 .964 r
.383 .74308 m .37557 .74366 L p .38626 .74329 L F P
0 g
s
.376 .779 .984 r
.383 .74308 m .37557 .74366 L .37235 .74231 L p F P
0 g
s
.271 0 0 r
.38299 .74399 m .37355 .74248 L p .383 .74308 L F P
0 g
s
.376 .779 .984 r
.37235 .74231 m .37247 .74231 L .383 .74308 L p F P
0 g
s
.271 0 0 r
.37355 .74248 m .37247 .74231 L .383 .74308 L p F P
0 g
s
.334 .774 .964 r
.3875 .74324 m .383 .74308 L p .38626 .74329 L F P
0 g
s
.428 .824 .983 r
.46965 .99337 m .46662 .99203 L .45572 .99403 L p F P
0 g
s
.577 .818 .99 r
.46662 .99203 m .45572 .99403 L .45267 .99249 L p F P
0 g
s
.5 0 0 r
.23786 .97788 m .23788 .97788 L p .25024 .98233 L F P
0 g
s
.656 .143 .008 r
.23786 .97788 m .23784 .97787 L .23788 .97788 L closepath p F P
0 g
s
.785 .382 .289 r
.20235 .96241 m .20378 .9649 L .20171 .96613 L p F P
0 g
s
.785 .382 .289 r
.19588 .96063 m .20235 .96241 L p .20171 .96613 L F P
0 g
s
.612 .069 0 r
.23784 .97787 m .23786 .97788 L .23428 .97829 L p F P
0 g
s
.612 .069 0 r
.23428 .97829 m .23087 .97624 L .23784 .97787 L p F P
0 g
s
.5 0 0 r
.25024 .98233 m .24561 .98131 L .23786 .97788 L p F P
0 g
s
.527 0 0 r
.24561 .98131 m .23786 .97788 L .23428 .97829 L p F P
0 g
s
.815 .716 .756 r
.15276 .82095 m .15791 .8233 L .15223 .83021 L p F P
0 g
s
.813 .72 .762 r
.15618 .81695 m .15276 .82095 L .15791 .8233 L p F P
0 g
s
.409 .826 .97 r
.48239 .99209 m .48058 .99141 L .46965 .99337 L p F P
0 g
s
.558 .829 .996 r
.48058 .99141 m .46965 .99337 L .46662 .99203 L p F P
0 g
s
.772 .791 .869 r
.65326 .24267 m .65771 .23962 L .65948 .24372 L p F P
0 g
s
.774 .793 .868 r
.65948 .24372 m .66704 .23843 L .66435 .23499 L p F P
0 g
s
.774 .793 .868 r
.66435 .23499 m .65771 .23962 L .65948 .24372 L p F P
0 g
s
.351 0 .082 r
.58668 .9701 m .58912 .96954 L p .57575 .97571 L F P
0 g
s
.402 .012 .181 r
.58912 .96954 m .58668 .9701 L .58914 .96951 L closepath p F P
0 g
s
.822 .506 .454 r
.18666 .95374 m .18116 .95206 L .18013 .94691 L p F P
0 g
s
.823 .505 .451 r
.17396 .94502 m .18013 .94691 L .18116 .95206 L p F P
0 g
s
.289 0 0 r
.28245 .98812 m .27904 .98723 L .26868 .98577 L p F P
0 g
s
.177 .671 .919 r
.26868 .98577 m .27904 .98723 L .27592 .98605 L p F P
0 g
s
.177 .671 .919 r
.26522 .9853 m .26868 .98577 L p .27592 .98605 L F P
0 g
s
.538 .429 .678 r
.66105 .88432 m .65989 .87923 L .66861 .88107 L closepath p F P
0 g
s
.614 .621 .834 r
.57962 .76137 m .5795 .76115 L .58067 .76092 L closepath p F P
0 g
s
.732 .747 .864 r
.2609 .74476 m .25017 .75098 L .24685 .74725 L p F P
0 g
s
.615 .627 .839 r
.58067 .76092 m .5795 .76115 L .57662 .75592 L p F P
0 g
s
.471 .208 .433 r
.62419 .95163 m .62473 .94675 L .63532 .94331 L p F P
0 g
s
.492 .257 .486 r
.63552 .93815 m .63532 .94331 L .62473 .94675 L p F P
0 g
s
.81 .487 .443 r
.18737 .95394 m .18666 .95374 L .18712 .95294 L closepath p F P
0 g
s
.871 .823 .799 r
.73027 .17465 m .73437 .16971 L .73622 .17385 L p F P
0 g
s
.871 .823 .799 r
.73622 .17385 m .73283 .17793 L .73027 .17465 L p F P
0 g
s
.641 .691 .881 r
.54282 .74207 m .53177 .74508 L .52884 .74099 L p F P
0 g
s
.574 .536 .774 r
.63682 .80755 m .6407 .80567 L p .64712 .81292 L F P
0 g
s
.577 .545 .782 r
.63682 .80755 m .63617 .80596 L .6407 .80567 L closepath p F P
0 g
s
0 0 0 r
.53639 .9857 m .53772 .98529 L .54945 .9831 L p F P
0 g
s
.113 0 0 r
.55031 .98272 m .54945 .9831 L .53772 .98529 L p F P
0 g
s
.714 .743 .874 r
.2609 .74476 m .26305 .74368 L .26951 .74569 L p F P
0 g
s
.72 .752 .877 r
.27161 .73941 m .26305 .74368 L .26951 .74569 L p F P
0 g
s
.72 .752 .877 r
.26951 .74569 m .27491 .74289 L .27161 .73941 L p F P
0 g
s
.904 .826 .759 r
.7491 .14296 m .7468 .14641 L .74874 .15055 L p F P
0 g
s
.896 .824 .769 r
.74242 .15265 m .74438 .15678 L .74874 .15055 L p F P
0 g
s
.896 .824 .769 r
.74874 .15055 m .7468 .14641 L .74242 .15265 L p F P
0 g
s
.507 .319 .56 r
.64587 .92909 m .64554 .92344 L .65584 .91963 L p F P
0 g
s
.519 .347 .587 r
.65527 .91377 m .65584 .91963 L .64554 .92344 L p F P
0 g
s
.593 .58 .808 r
.62462 .77908 m .62487 .77963 L .61513 .78427 L p F P
0 g
s
.593 .58 .808 r
.61513 .78427 m .61337 .78049 L .62462 .77908 L p F P
0 g
s
.837 .665 .669 r
.13871 .88254 m .14414 .88473 L .14136 .89085 L p F P
0 g
s
.835 .672 .681 r
.14414 .88473 m .13871 .88254 L .14184 .87633 L p F P
0 g
s
.624 .641 .847 r
.56266 .75333 m .56261 .75324 L .56325 .7531 L closepath p F P
0 g
s
.415 .792 .993 r
.32778 .99278 m .32713 .99273 L .32734 .99282 L closepath p F P
0 g
s
.602 .596 .817 r
.59642 .77023 m .60761 .76845 L p .61026 .77436 L F P
0 g
s
.603 .599 .82 r
.60525 .76367 m .60761 .76845 L .59642 .77023 L p F P
0 g
s
.603 .599 .82 r
.59642 .77023 m .59541 .76821 L .60525 .76367 L p F P
0 g
s
.956 .805 .654 r
.75621 .10525 m .75845 .10934 L .76048 .10403 L p F P
0 g
s
.956 .805 .654 r
.76048 .10403 m .75824 .09993 L .75621 .10525 L p F P
0 g
s
.624 .649 .854 r
.56325 .7531 m .56261 .75324 L .55971 .74842 L p F P
0 g
s
.825 .702 .729 r
.14202 .84373 m .14724 .84603 L .14266 .85264 L p F P
0 g
s
.823 .705 .735 r
.14687 .83704 m .14202 .84373 L .14724 .84603 L p F P
0 g
s
.983 .763 .526 r
.75656 .08118 m .7573 .07673 L .75972 .08079 L p F P
0 g
s
.983 .763 .526 r
.75972 .08079 m .75908 .08469 L .75656 .08118 L p F P
0 g
s
.789 .731 .798 r
.18348 .78178 m .18866 .78415 L .18033 .79185 L p F P
0 g
s
.788 .735 .803 r
.18597 .77955 m .18348 .78178 L .18866 .78415 L p F P
0 g
s
.788 .735 .803 r
.18866 .78415 m .18935 .78353 L .18597 .77955 L p F P
0 g
s
.783 .735 .809 r
.19791 .77618 m .18935 .78353 L .18597 .77955 L p F P
0 g
s
.577 .546 .783 r
.6407 .80567 m .63617 .80596 L .63328 .79886 L p F P
0 g
s
.789 .731 .798 r
.18033 .79185 m .17504 .78951 L .18348 .78178 L p F P
0 g
s
.792 .728 .793 r
.18033 .79185 m .17838 .79371 L .175 .78956 L p F P
0 g
s
.792 .728 .793 r
.175 .78956 m .17504 .78951 L .18033 .79185 L p F P
0 g
s
.83 .689 .707 r
.14341 .86189 m .1437 .86142 L .14296 .86111 L closepath p F P
0 g
s
.825 .696 .721 r
.1401 .85656 m .14266 .85264 L p .1437 .86142 L F P
0 g
s
.825 .696 .721 r
.1437 .86142 m .14296 .86111 L .1401 .85656 L p F P
0 g
s
.612 .617 .832 r
.59065 .75901 m .58067 .76092 L .58958 .75699 L closepath p F P
0 g
s
.615 .627 .839 r
.58777 .75367 m .58958 .75699 L .58067 .76092 L p F P
0 g
s
.615 .627 .839 r
.57662 .75592 m .58777 .75367 L p .58067 .76092 L F P
0 g
s
.798 .729 .788 r
.17267 .79935 m .17838 .79371 L .175 .78956 L p F P
0 g
s
.449 .799 .998 r
.32778 .99278 m .33796 .99161 L p .32404 .99132 L F P
0 g
s
.449 .799 .998 r
.32404 .99132 m .32713 .99273 L .32778 .99278 L p F P
0 g
s
.834 .689 .703 r
.13995 .8678 m .14341 .86189 L .14296 .86111 L p F P
0 g
s
.622 .64 .847 r
.57372 .75076 m .56325 .7531 L .57279 .74914 L closepath p F P
0 g
s
.624 .649 .854 r
.57083 .74584 m .57279 .74914 L .56325 .7531 L p F P
0 g
s
.624 .649 .854 r
.55971 .74842 m .57083 .74584 L p .56325 .7531 L F P
0 g
s
.519 .364 .611 r
.65448 .9077 m .66461 .90365 L p .65694 .91311 L F P
0 g
s
.519 .364 .611 r
.65694 .91311 m .65502 .91185 L .65448 .9077 L p F P
0 g
s
.527 .385 .631 r
.66362 .8974 m .66461 .90365 L .65448 .9077 L p F P
0 g
s
.407 .779 .993 r
.32404 .99132 m .31888 .99169 L .32713 .99273 L closepath p F P
0 g
s
.384 0 .172 r
.58912 .96954 m .59157 .96887 L .58914 .96951 L closepath p F P
0 g
s
.423 .064 .249 r
.58914 .96951 m .59157 .96887 L .60026 .96645 L p F P
0 g
s
.327 0 .068 r
.58697 .97299 m .58912 .96954 L .59157 .96887 L p F P
0 g
s
.351 0 .082 r
.58912 .96954 m .58697 .97299 L .57575 .97571 L p F P
0 g
s
.865 .823 .805 r
.73056 .18057 m .73283 .17793 L .73027 .17465 L p F P
0 g
s
.783 .735 .809 r
.18597 .77955 m .19265 .77382 L .19791 .77618 L p F P
0 g
s
.781 .737 .812 r
.19689 .77026 m .19265 .77382 L .19791 .77618 L p F P
0 g
s
.781 .737 .812 r
.19791 .77618 m .20026 .7742 L .19689 .77026 L p F P
0 g
s
.8 .728 .784 r
.17267 .79935 m .16733 .80477 L .16394 .80059 L p F P
0 g
s
.8 .728 .784 r
.16394 .80059 m .16748 .79699 L .17267 .79935 L p F P
0 g
s
.798 .729 .788 r
.175 .78956 m .16748 .79699 L .17267 .79935 L p F P
0 g
s
.728 .774 .889 r
.64076 .25043 m .64215 .24967 L .63942 .24614 L p F P
0 g
s
.728 .774 .889 r
.63942 .24614 m .63919 .24626 L .64076 .25043 L p F P
0 g
s
.729 .769 .885 r
.62828 .2521 m .63919 .24626 L .64076 .25043 L p F P
0 g
s
.8 .442 .378 r
.19588 .96063 m .1894 .95883 L .18737 .95394 L p F P
0 g
s
.8 .442 .379 r
.18666 .95374 m .18737 .95394 L .1894 .95883 L p F P
0 g
s
.916 .821 .738 r
.74871 .13622 m .75077 .14034 L .75427 .13444 L p F P
0 g
s
.916 .821 .738 r
.75427 .13444 m .75222 .13032 L .74871 .13622 L p F P
0 g
s
.787 .798 .861 r
.67253 .23432 m .66704 .23843 L .66435 .23499 L p F P
0 g
s
.818 .713 .749 r
.15223 .83021 m .14827 .83522 L .14489 .8306 L p F P
0 g
s
.818 .713 .749 r
.14489 .8306 m .14704 .82789 L .15223 .83021 L p F P
0 g
s
.815 .716 .756 r
.15223 .83021 m .14704 .82789 L .15276 .82095 L p F P
0 g
s
.774 .737 .819 r
.2081 .76792 m .20026 .7742 L .19689 .77026 L p F P
0 g
s
.532 .414 .665 r
.66243 .89095 m .66105 .88432 L .66861 .88107 L p F P
0 g
s
.834 .689 .703 r
.14296 .86111 m .13846 .85914 L p .13995 .8678 L F P
0 g
s
.831 .697 .715 r
.14296 .86111 m .1401 .85656 L .13846 .85914 L closepath p F P
0 g
s
.937 .815 .7 r
.75443 .11822 m .75609 .1148 L .75825 .1189 L p F P
0 g
s
.937 .815 .7 r
.75825 .1189 m .75694 .12159 L .75443 .11822 L p F P
0 g
s
.619 .174 0 r
.57766 .23241 m .57672 .23102 L .57949 .23482 L p F P
0 g
s
.619 .174 0 r
.57949 .23482 m .58051 .23632 L .57766 .23241 L p F P
0 g
s
.413 .795 .991 r
.35512 .99359 m .3519 .9917 L .34122 .99332 L p F P
0 g
s
.583 .79 .978 r
.3519 .9917 m .34122 .99332 L .33796 .99161 L p F P
0 g
s
.605 .607 .827 r
.60473 .76265 m .60525 .76367 L .59541 .76821 L p F P
0 g
s
.605 .607 .827 r
.59541 .76821 m .59354 .76456 L .60473 .76265 L p F P
0 g
s
.865 .823 .805 r
.73027 .17465 m .72874 .17642 L .73056 .18057 L p F P
0 g
s
.858 .821 .811 r
.72252 .18334 m .72437 .18747 L .73056 .18057 L p F P
0 g
s
.858 .821 .811 r
.73056 .18057 m .72874 .17642 L .72252 .18334 L p F P
0 g
s
.8 .442 .379 r
.1894 .95883 m .18342 .95718 L .18666 .95374 L p F P
0 g
s
.815 .464 .391 r
.18116 .95206 m .18666 .95374 L .18342 .95718 L p F P
0 g
s
.805 .728 .779 r
.16548 .80671 m .16733 .80477 L .16394 .80059 L p F P
0 g
s
.755 .784 .877 r
.65326 .24267 m .64215 .24967 L .63942 .24614 L p F P
0 g
s
.603 .786 .968 r
.31347 .73754 m .30283 .74068 L .29955 .73758 L p F P
0 g
s
.673 .764 .919 r
.28888 .74154 m .29955 .73758 L .30283 .74068 L p F P
0 g
s
.638 .777 .948 r
.30283 .74068 m .31347 .73754 L .31675 .7403 L p F P
0 g
s
.609 .716 .921 r
.60034 .25205 m .61155 .24945 L .61434 .25321 L p F P
0 g
s
.603 .713 .922 r
.61155 .24945 m .60034 .25205 L .59752 .24815 L p F P
0 g
s
.428 .828 .981 r
.44232 .74133 m .44103 .74143 L .43124 .74306 L p F P
0 g
s
.401 .824 .966 r
.44103 .74143 m .42939 .74256 L .43124 .74306 L closepath p F P
0 g
s
.593 .823 .987 r
.45912 .74152 m .47004 .73881 L .47306 .7408 L p F P
0 g
s
.462 .849 .981 r
.45912 .74152 m .47004 .73881 L .46716 .73781 L p F P
0 g
s
.462 .849 .981 r
.45607 .74003 m .45912 .74152 L p .46716 .73781 L F P
0 g
s
.529 .839 .999 r
.44518 .74232 m .45607 .74003 L .45912 .74152 L p F P
0 g
s
.657 .772 .933 r
.29955 .73758 m .28888 .74154 L .28559 .73821 L p F P
0 g
s
.697 .755 .897 r
.27491 .74289 m .28559 .73821 L .28888 .74154 L p F P
0 g
s
.839 .594 .569 r
.16174 .93035 m .15592 .92833 L .15665 .92273 L p F P
0 g
s
.841 .596 .569 r
.15089 .92069 m .15665 .92273 L .15592 .92833 L p F P
0 g
s
.839 .612 .594 r
.15665 .92273 m .15089 .92069 L .15209 .91497 L p F P
0 g
s
.483 .85 .989 r
.44232 .74133 m .44518 .74232 L .45607 .74003 L p F P
0 g
s
.837 .676 .682 r
.13649 .8741 m .14184 .87633 L .13871 .88254 L p F P
0 g
s
.835 .682 .693 r
.14184 .87633 m .13649 .8741 L .13995 .8678 L p F P
0 g
s
.627 .793 .962 r
.47306 .7408 m .48401 .73779 L .487 .74031 L p F P
0 g
s
.581 .84 .994 r
.48401 .73779 m .47306 .7408 L .47004 .73881 L p F P
0 g
s
.741 .738 .849 r
.23889 .7522 m .23609 .75398 L .23276 .75015 L p F P
0 g
s
.754 .739 .838 r
.22196 .75753 m .23276 .75015 L .23609 .75398 L p F P
0 g
s
.839 .627 .617 r
.15209 .91497 m .14639 .9129 L .14803 .90707 L p F P
0 g
s
.841 .614 .595 r
.14639 .9129 m .15209 .91497 L .15089 .92069 L p F P
0 g
s
.807 .724 .774 r
.16038 .80433 m .16548 .80671 L .15889 .8139 L p F P
0 g
s
.805 .728 .779 r
.16394 .80059 m .16038 .80433 L .16548 .80671 L p F P
0 g
s
.483 .251 .486 r
.63532 .94331 m .63552 .93815 L .64596 .93452 L p F P
0 g
s
.503 .293 .528 r
.64587 .92909 m .64596 .93452 L .63552 .93815 L p F P
0 g
s
.986 .734 .463 r
.75478 .07268 m .7573 .07673 L .75767 .07207 L p F P
0 g
s
.986 .734 .463 r
.75767 .07207 m .75515 .06802 L .75478 .07268 L p F P
0 g
s
.583 .551 .784 r
.63328 .79886 m .63243 .79893 L .63316 .79859 L closepath p F P
0 g
s
.587 .56 .79 r
.63039 .7921 m .63316 .79859 L .63243 .79893 L p F P
0 g
s
.838 .573 .539 r
.16652 .93753 m .16151 .93582 L .16174 .93035 L p F P
0 g
s
.84 .575 .538 r
.15592 .92833 m .16174 .93035 L .16151 .93582 L p F P
0 g
s
.592 .582 .811 r
.62462 .77908 m .61337 .78049 L .61049 .77432 L p F P
0 g
s
.579 .792 .98 r
.31675 .7403 m .32738 .73806 L .33065 .74039 L p F P
0 g
s
.497 .792 .998 r
.32738 .73806 m .31675 .7403 L .31347 .73754 L p F P
0 g
s
.642 .762 .935 r
.487 .74031 m .49797 .73713 L .50094 .74013 L p F P
0 g
s
.627 .802 .966 r
.49797 .73713 m .487 .74031 L .48401 .73779 L p F P
0 g
s
.634 .67 .867 r
.5539 .73918 m .55681 .74373 L .54573 .74652 L p F P
0 g
s
.634 .67 .867 r
.5525 .73954 m .5539 .73918 L p .54573 .74652 L F P
0 g
s
.634 .67 .867 r
.54573 .74652 m .5434 .74294 L .5525 .73954 L p F P
0 g
s
.632 .658 .858 r
.54573 .74652 m .55681 .74373 L .55971 .74842 L p F P
0 g
s
.675 .174 .047 r
.23087 .97624 m .22381 .97463 L .22076 .97233 L p F P
0 g
s
.675 .178 .057 r
.22381 .97463 m .21759 .97326 L .22076 .97233 L closepath p F P
0 g
s
.774 .737 .819 r
.19689 .77026 m .20278 .76557 L .2081 .76792 L p F P
0 g
s
.773 .739 .822 r
.20777 .76167 m .20278 .76557 L .2081 .76792 L p F P
0 g
s
.773 .739 .822 r
.2081 .76792 m .21113 .76554 L .20777 .76167 L p F P
0 g
s
.559 .494 .738 r
.6592 .8376 m .65607 .8375 L .65876 .83626 L closepath p F P
0 g
s
.565 .505 .747 r
.65625 .82886 m .65876 .83626 L .65607 .8375 L p F P
0 g
s
.565 .505 .747 r
.6548 .82885 m .65625 .82886 L p .65607 .8375 L F P
0 g
s
.79 .8 .86 r
.67253 .23432 m .6781 .23008 L .67543 .22667 L p F P
0 g
s
.79 .8 .86 r
.67543 .22667 m .67077 .2302 L .67253 .23432 L p F P
0 g
s
.787 .798 .861 r
.66435 .23499 m .67077 .2302 L .67253 .23432 L p F P
0 g
s
.272 .524 .91 r
.58998 .24027 m .59261 .24411 L .58553 .24204 L p F P
0 g
s
.272 .524 .91 r
.58553 .24204 m .58299 .23817 L .58998 .24027 L p F P
0 g
s
0 .257 .766 r
.58051 .23632 m .58299 .23817 L .58553 .24204 L p F P
0 g
s
.84 .63 .618 r
.1424 .90497 m .14803 .90707 L .14639 .9129 L p F P
0 g
s
.838 .641 .636 r
.14803 .90707 m .1424 .90497 L .14446 .89903 L p F P
0 g
s
.689 .761 .906 r
.28559 .73821 m .27491 .74289 L .27161 .73941 L p F P
0 g
s
.474 .838 .993 r
.48058 .99141 m .48239 .99209 L .49124 .99117 L p F P
0 g
s
.327 0 .068 r
.59157 .96887 m .60019 .96661 L p .58697 .97299 L F P
0 g
s
.401 .026 .208 r
.59157 .96887 m .60019 .96661 L .60026 .96645 L closepath p F P
0 g
s
.212 .694 .932 r
.29362 .98874 m .29194 .98846 L .28245 .98812 L p F P
0 g
s
.15 .669 .887 r
.29194 .98846 m .28245 .98812 L .27904 .98723 L p F P
0 g
s
.041 0 0 r
.54945 .9831 m .55031 .98272 L .5614 .98061 L p F P
0 g
s
.557 .8 .989 r
.35512 .99359 m .36584 .99165 L .36904 .99368 L p F P
0 g
s
.604 .786 .968 r
.36584 .99165 m .35512 .99359 L .3519 .9917 L p F P
0 g
s
.888 .823 .777 r
.73848 .15802 m .74242 .15265 L .74438 .15678 L p F P
0 g
s
.888 .823 .777 r
.74438 .15678 m .74102 .16134 L .73848 .15802 L p F P
0 g
s
.765 .74 .83 r
.21958 .75926 m .21113 .76554 L .20777 .76167 L p F P
0 g
s
.577 .546 .783 r
.63328 .79886 m .64459 .7982 L p .6407 .80567 L F P
0 g
s
.576 .547 .785 r
.64278 .7938 m .64459 .7982 L .63328 .79886 L p F P
0 g
s
.576 .547 .785 r
.63328 .79886 m .63316 .79859 L .64278 .7938 L p F P
0 g
s
.822 .714 .745 r
.14687 .83704 m .14827 .83522 L .14489 .8306 L p F P
0 g
s
.741 .738 .849 r
.23276 .75015 m .23294 .75004 L .23889 .7522 L p F P
0 g
s
.744 .745 .853 r
.24352 .74356 m .23294 .75004 L .23889 .7522 L p F P
0 g
s
.744 .745 .853 r
.23889 .7522 m .24685 .74725 L .24352 .74356 L p F P
0 g
s
.647 .734 .912 r
.50094 .74013 m .51194 .73691 L .51489 .74035 L p F P
0 g
s
.643 .764 .936 r
.51194 .73691 m .50094 .74013 L .49797 .73713 L p F P
0 g
s
.133 0 0 r
.26083 .98421 m .26522 .9853 L .26177 .98441 L p F P
0 g
s
.133 0 0 r
.26177 .98441 m .25302 .98282 L .26083 .98421 L p F P
0 g
s
.465 0 0 r
.25148 .98238 m .25302 .98282 L .26083 .98421 L p F P
0 g
s
.579 .557 .793 r
.6417 .79125 m .64278 .7938 L .63316 .79859 L p F P
0 g
s
.579 .557 .793 r
.63316 .79859 m .63039 .7921 L .6417 .79125 L p F P
0 g
s
.826 .537 .5 r
.17396 .94502 m .1678 .94311 L .1674 .9378 L p F P
0 g
s
.829 .539 .499 r
.16652 .93753 m .1674 .9378 L .1678 .94311 L p F P
0 g
s
.723 .251 .127 r
.21759 .97326 m .2167 .97303 L .21224 .96874 L p F P
0 g
s
.712 .225 .087 r
.20543 .96705 m .21224 .96874 L .2167 .97303 L p F P
0 g
s
.758 .338 .251 r
.21224 .96874 m .20543 .96705 L .20378 .9649 L p F P
0 g
s
.963 .795 .626 r
.75591 .09584 m .75824 .09993 L .75993 .09474 L p F P
0 g
s
.963 .795 .626 r
.75993 .09474 m .7576 .09066 L .75591 .09584 L p F P
0 g
s
.933 .817 .707 r
.75545 .12453 m .75694 .12159 L .75443 .11822 L p F P
0 g
s
.852 .818 .815 r
.71941 .1867 m .72252 .18334 L .72437 .18747 L p F P
0 g
s
.852 .818 .815 r
.72437 .18747 m .722 .19003 L .71941 .1867 L p F P
0 g
s
.829 .697 .718 r
.14266 .85264 m .1401 .85656 L .13676 .85134 L p F P
0 g
s
.829 .697 .718 r
.13676 .85134 m .13741 .85035 L .14266 .85264 L p F P
0 g
s
.825 .702 .729 r
.14266 .85264 m .13741 .85035 L .14202 .84373 L p F P
0 g
s
.474 .795 .999 r
.33065 .74039 m .34128 .73907 L .34455 .74085 L p F P
0 g
s
.324 .749 .974 r
.33065 .74039 m .34128 .73907 L .33969 .73845 L p F P
0 g
s
.324 .749 .974 r
.32738 .73806 m .33065 .74039 L p .33969 .73845 L F P
0 g
s
.84 .645 .639 r
.13891 .89689 m .14446 .89903 L .1424 .90497 L p F P
0 g
s
.838 .654 .653 r
.14446 .89903 m .13891 .89689 L .14136 .89085 L p F P
0 g
s
.807 .724 .774 r
.15889 .8139 m .15372 .81154 L .16038 .80433 L p F P
0 g
s
.81 .722 .767 r
.15889 .8139 m .15618 .81695 L .15279 .8126 L p F P
0 g
s
.81 .722 .767 r
.15279 .8126 m .15372 .81154 L .15889 .8139 L p F P
0 g
s
.801 .803 .853 r
.68363 .22562 m .6781 .23008 L .67543 .22667 L p F P
0 g
s
.758 .338 .251 r
.20543 .96705 m .20171 .96613 L .20378 .9649 L closepath p F P
0 g
s
.825 .71 .737 r
.14176 .83469 m .14687 .83704 L .14202 .84373 L p F P
0 g
s
.822 .714 .745 r
.14489 .8306 m .14176 .83469 L .14687 .83704 L p F P
0 g
s
.577 .798 .983 r
.36904 .99368 m .37979 .99152 L .38296 .99366 L p F P
0 g
s
.618 .781 .96 r
.37979 .99152 m .36904 .99368 L .36584 .99165 L p F P
0 g
s
.56 0 0 r
.23087 .97624 m .23428 .97829 L .23072 .97821 L p F P
0 g
s
.56 0 0 r
.23072 .97821 m .22381 .97463 L .23087 .97624 L p F P
0 g
s
.846 .818 .821 r
.7176 .1946 m .722 .19003 L .71941 .1867 L p F P
0 g
s
.369 .775 .983 r
.31888 .99169 m .32404 .99132 L p .31015 .99075 L F P
0 g
s
.369 .775 .983 r
.31015 .99075 m .31067 .99095 L .31888 .99169 L p F P
0 g
s
.829 .539 .499 r
.1678 .94311 m .16495 .94222 L .16652 .93753 L p F P
0 g
s
.838 .55 .501 r
.16151 .93582 m .16652 .93753 L .16495 .94222 L p F P
0 g
s
.714 .741 .873 r
.2609 .74476 m .26305 .74368 L .25876 .74241 L closepath p F P
0 g
s
.732 .747 .864 r
.25876 .74241 m .2609 .74476 L p .24685 .74725 L F P
0 g
s
.519 .364 .61 r
.65527 .91377 m .65502 .91185 L .65694 .91311 L closepath p F P
0 g
s
.726 .767 .885 r
.63919 .24626 m .62828 .2521 L .62551 .24846 L p F P
0 g
s
.689 .754 .901 r
.61434 .25321 m .62551 .24846 L .62828 .2521 L p F P
0 g
s
.837 .685 .695 r
.1347 .86553 m .13995 .8678 L .13649 .8741 L p F P
0 g
s
.834 .689 .703 r
.13846 .85914 m .1347 .86553 L .13995 .8678 L p F P
0 g
s
.785 .382 .289 r
.20171 .96613 m .19879 .96531 L .19588 .96063 L p F P
0 g
s
.783 .372 .273 r
.1894 .95883 m .19588 .96063 L .19879 .96531 L p F P
0 g
s
.542 .444 .693 r
.66824 .86848 m .66405 .86779 L .66767 .86618 L closepath p F P
0 g
s
.549 .458 .704 r
.66573 .85899 m .66767 .86618 L .66405 .86779 L p F P
0 g
s
.646 .732 .912 r
.52591 .73718 m .51489 .74035 L .51194 .73691 L p F P
0 g
s
.645 .71 .895 r
.51489 .74035 m .52591 .73718 L .52884 .74099 L p F P
0 g
s
.814 .722 .763 r
.15276 .82095 m .15618 .81695 L .15279 .8126 L p F P
0 g
s
.525 .397 .649 r
.66243 .89095 m .67239 .88667 L p .66683 .89604 L F P
0 g
s
.525 .397 .649 r
.66683 .89604 m .66311 .89463 L .66243 .89095 L p F P
0 g
s
.532 .414 .665 r
.67139 .88189 m .67239 .88667 L .66243 .89095 L p F P
0 g
s
.532 .414 .665 r
.66861 .88107 m .67139 .88189 L p .66243 .89095 L F P
0 g
s
.616 .63 .842 r
.58777 .75367 m .57662 .75592 L .57372 .75076 L p F P
0 g
s
.804 .805 .852 r
.68363 .22562 m .68913 .22111 L .68648 .21771 L p F P
0 g
s
.804 .805 .852 r
.68648 .21771 m .68186 .2215 L .68363 .22562 L p F P
0 g
s
.801 .803 .853 r
.67543 .22667 m .68186 .2215 L .68363 .22562 L p F P
0 g
s
.605 .61 .83 r
.60473 .76265 m .59354 .76456 L .59065 .75901 L p F P
0 g
s
.846 .818 .821 r
.71941 .1867 m .71578 .19046 L .7176 .1946 L p F P
0 g
s
.842 .817 .825 r
.7086 .19775 m .71578 .19046 L .7176 .1946 L p F P
0 g
s
.842 .817 .825 r
.70887 .19835 m .7086 .19775 L p .7176 .1946 L F P
0 g
s
.842 .817 .825 r
.7176 .1946 m .71109 .2012 L .70887 .19835 L p F P
0 g
s
.686 .752 .902 r
.62551 .24846 m .61434 .25321 L .61155 .24945 L p F P
0 g
s
.823 .505 .451 r
.18116 .95206 m .17502 .95016 L .17396 .94502 L p F P
0 g
s
.824 .504 .447 r
.1678 .94311 m .17396 .94502 L .17502 .95016 L p F P
0 g
s
.84 .658 .656 r
.13589 .88868 m .14136 .89085 L .13891 .89689 L p F P
0 g
s
.837 .665 .669 r
.14136 .89085 m .13589 .88868 L .13871 .88254 L p F P
0 g
s
.589 .797 .979 r
.38296 .99366 m .39375 .99135 L .39689 .99355 L p F P
0 g
s
.625 .778 .954 r
.39375 .99135 m .38296 .99366 L .37979 .99152 L p F P
0 g
s
0 .24 .751 r
.58299 .23817 m .58051 .23632 L .57766 .23241 L p F P
0 g
s
.983 .766 .534 r
.75891 .08562 m .75908 .08469 L .75656 .08118 L p F P
0 g
s
.906 .82 .751 r
.74656 .13958 m .74871 .13622 L .75077 .14034 L p F P
0 g
s
.906 .82 .751 r
.75077 .14034 m .7491 .14296 L .74656 .13958 L p F P
0 g
s
.765 .74 .83 r
.20777 .76167 m .21421 .75692 L .21958 .75926 L p F P
0 g
s
.764 .742 .833 r
.2186 .75374 m .21421 .75692 L .21958 .75926 L p F P
0 g
s
.764 .742 .833 r
.21958 .75926 m .22196 .75753 L .2186 .75374 L p F P
0 g
s
.883 .823 .783 r
.73965 .16314 m .74102 .16134 L .73848 .15802 L p F P
0 g
s
.945 .808 .678 r
.75384 .11071 m .75609 .1148 L .75845 .10934 L p F P
0 g
s
.945 .808 .678 r
.75845 .10934 m .75621 .10525 L .75384 .11071 L p F P
0 g
s
.574 .536 .774 r
.6407 .80567 m .64749 .80537 L p .64712 .81292 L F P
0 g
s
.573 .537 .776 r
.64749 .80537 m .6407 .80567 L .64649 .80283 L closepath p F P
0 g
s
.577 .546 .783 r
.64459 .7982 m .64649 .80283 L .6407 .80567 L p F P
0 g
s
.336 .761 .974 r
.3525 .74044 m .34455 .74085 L p .35544 .74083 L F P
0 g
s
.402 .761 .994 r
.3525 .74044 m .34455 .74085 L .34128 .73907 L p F P
0 g
s
.402 .761 .994 r
.34358 .73918 m .3525 .74044 L p .34695 .73976 L F P
0 g
s
.402 .761 .994 r
.34128 .73907 m .34358 .73918 L p .34695 .73976 L F P
0 g
s
.199 .682 .93 r
.34358 .73918 m .33969 .73845 L .34128 .73907 L closepath p F P
0 g
s
.507 0 0 r
.35103 .74125 m .34048 .73865 L .34358 .73918 L F
.33969 .73845 m .34358 .73918 L p .34048 .73865 L F P
0 g
s
.255 0 0 r
.35183 .74091 m .3445 .73938 L p .3525 .74044 L F P
0 g
s
.255 0 0 r
.3445 .73938 m .34358 .73918 L .3525 .74044 L p F P
0 g
s
.336 .761 .974 r
.3565 .74083 m .3525 .74044 L p .35544 .74083 L F P
0 g
s
.563 .505 .748 r
.65625 .82886 m .6548 .82885 L .65604 .82827 L closepath p F P
0 g
s
.568 .515 .756 r
.65331 .82064 m .65604 .82827 L .6548 .82885 L p F P
0 g
s
.568 .515 .756 r
.65182 .82065 m .65331 .82064 L p .6548 .82885 L F P
0 g
s
.336 0 0 r
.25302 .98282 m .25024 .98233 L .25148 .98238 L closepath p F P
0 g
s
.709 .743 .878 r
.26829 .73601 m .27161 .73941 L .26305 .74368 L p F P
0 g
s
.709 .743 .878 r
.25759 .74114 m .26829 .73601 L p .26305 .74368 L F P
0 g
s
.709 .743 .878 r
.26305 .74368 m .25876 .74241 L .25759 .74114 L p F P
0 g
s
.813 .807 .845 r
.69344 .21738 m .68913 .22111 L .68648 .21771 L p F P
0 g
s
0 0 0 r
.54945 .9831 m .54746 .98361 L .53639 .9857 L p F P
0 g
s
.316 .803 .876 r
.54746 .98361 m .53639 .9857 L .53349 .98577 L p F P
0 g
s
.245 .76 .823 r
.52244 .98784 m .53349 .98577 L .53639 .9857 L p F P
0 g
s
.833 .699 .716 r
.13846 .85914 m .1401 .85656 L .13676 .85134 L p F P
0 g
s
.255 0 0 r
.5753 .97621 m .57575 .97571 L .58697 .97299 L p F P
0 g
s
.816 .719 .758 r
.14768 .81857 m .15276 .82095 L .14704 .82789 L p F P
0 g
s
.814 .722 .763 r
.15279 .8126 m .14768 .81857 L .15276 .82095 L p F P
0 g
s
.755 .745 .843 r
.23276 .75015 m .22196 .75753 L .2186 .75374 L p F P
0 g
s
.596 .797 .977 r
.39689 .99355 m .40771 .99115 L .41083 .99337 L p F P
0 g
s
.629 .776 .951 r
.40771 .99115 m .39689 .99355 L .39375 .99135 L p F P
0 g
s
.835 .816 .831 r
.71109 .2012 m .71038 .20189 L .70887 .19835 L closepath p F P
0 g
s
.474 .838 .993 r
.49124 .99117 m .49454 .99059 L p .48058 .99141 L F P
0 g
s
.432 .836 .976 r
.49454 .99059 m .49124 .99117 L .49498 .99071 L closepath p F P
0 g
s
.816 .809 .843 r
.69344 .21738 m .70013 .21149 L .6975 .20811 L p F P
0 g
s
.816 .809 .843 r
.6975 .20811 m .69164 .21327 L .69344 .21738 L p F P
0 g
s
.813 .807 .845 r
.68648 .21771 m .69164 .21327 L .69344 .21738 L p F P
0 g
s
.933 .817 .707 r
.75443 .11822 m .75332 .12041 L .75545 .12453 L p F P
0 g
s
.922 .817 .726 r
.75008 .12621 m .75222 .13032 L .75545 .12453 L p F P
0 g
s
.922 .817 .726 r
.75545 .12453 m .75332 .12041 L .75008 .12621 L p F P
0 g
s
.159 .678 .887 r
.29628 .98972 m .30094 .98953 L .30933 .99076 L p F P
0 g
s
.326 .757 .971 r
.30094 .98953 m .29362 .98874 L .29628 .98972 L closepath p F P
0 g
s
.823 .811 .839 r
.70048 .20537 m .70231 .20949 L .71038 .20189 L p F P
0 g
s
.823 .811 .839 r
.70849 .19785 m .70048 .20537 L p .71038 .20189 L F P
0 g
s
.823 .811 .839 r
.71038 .20189 m .70887 .19835 L .70849 .19785 L p F P
0 g
s
.508 .339 .586 r
.65694 .91311 m .65527 .91377 L .65584 .91963 L p F P
0 g
s
.013 .587 .725 r
.40019 .74348 m .39482 .74346 L .402 .74352 L closepath p F P
0 g
s
.883 .823 .783 r
.73848 .15802 m .73772 .159 L .73965 .16314 L p F P
0 g
s
.875 .821 .792 r
.73242 .16559 m .73437 .16971 L .73965 .16314 L p F P
0 g
s
.875 .821 .792 r
.73965 .16314 m .73772 .159 L .73242 .16559 L p F P
0 g
s
.626 .654 .858 r
.57083 .74584 m .55971 .74842 L .55681 .74373 L p F P
0 g
s
.377 0 0 r
.39482 .74346 m .40019 .74348 L .39746 .74465 L p F P
0 g
s
.029 .601 .721 r
.41415 .74329 m .40799 .74344 L .41594 .74328 L closepath p F P
0 g
s
.374 0 0 r
.40799 .74344 m .41415 .74329 L .4116 .74455 L p F P
0 g
s
.824 .81 .837 r
.6975 .20811 m .70048 .20537 L .70231 .20949 L p F P
0 g
s
.824 .81 .837 r
.70231 .20949 m .70013 .21149 L .6975 .20811 L p F P
0 g
s
.549 .478 .728 r
.66128 .84403 m .67096 .83934 L p .67155 .84781 L F P
0 g
s
.549 .478 .728 r
.67155 .84781 m .66217 .84697 L .66128 .84403 L p F P
0 g
s
.552 .489 .738 r
.67064 .83834 m .67096 .83934 L .66128 .84403 L p F P
0 g
s
.552 .489 .738 r
.66128 .84403 m .6592 .8376 L .67064 .83834 L p F P
0 g
s
.599 .588 .812 r
.61049 .77432 m .61026 .77436 L .61046 .77426 L closepath p F P
0 g
s
.602 .596 .817 r
.60761 .76845 m .61046 .77426 L .61026 .77436 L p F P
0 g
s
.551 .489 .739 r
.66841 .83151 m .67064 .83834 L .6592 .8376 L p F P
0 g
s
.551 .489 .739 r
.6592 .8376 m .65876 .83626 L .66841 .83151 L p F P
0 g
s
.983 .766 .534 r
.75656 .08118 m .7565 .08156 L .75891 .08562 L p F P
0 g
s
.971 .781 .59 r
.75518 .08659 m .7576 .09066 L .75891 .08562 L p F P
0 g
s
.971 .781 .59 r
.75891 .08562 m .7565 .08156 L .75518 .08659 L p F P
0 g
s
.555 .5 .748 r
.66767 .82935 m .66841 .83151 L .65876 .83626 L p F P
0 g
s
.555 .5 .748 r
.65876 .83626 m .65625 .82886 L .66767 .82935 L p F P
0 g
s
.491 .284 .527 r
.64596 .93452 m .64587 .92909 L .65619 .92529 L p F P
0 g
s
.507 .319 .56 r
.65584 .91963 m .65619 .92529 L .64587 .92909 L p F P
0 g
s
.549 .478 .728 r
.66359 .8516 m .66217 .84697 L .67155 .84781 L closepath p F P
0 g
s
.641 .691 .881 r
.52884 .74099 m .5399 .73794 L .54282 .74207 L p F P
0 g
s
.642 .707 .893 r
.5399 .73794 m .52884 .74099 L .52591 .73718 L p F P
0 g
s
.579 .557 .794 r
.63881 .7845 m .6417 .79125 L .63039 .7921 L p F P
0 g
s
.579 .557 .794 r
.63866 .78451 m .63881 .7845 L p .63039 .7921 L F P
0 g
s
.579 .557 .794 r
.63039 .7921 m .62918 .78928 L .63866 .78451 L p F P
0 g
s
.592 .582 .811 r
.61049 .77432 m .62174 .77294 L .62462 .77908 L p F P
0 g
s
.592 .584 .813 r
.62012 .76949 m .62174 .77294 L .61049 .77432 L p F P
0 g
s
.592 .584 .813 r
.61049 .77432 m .61046 .77426 L .62012 .76949 L p F P
0 g
s
.732 .747 .864 r
.24685 .74725 m .25675 .74161 L .25876 .74241 L p F P
0 g
s
.729 .75 .869 r
.25675 .74161 m .24685 .74725 L .24352 .74356 L p F P
0 g
s
.77 .788 .868 r
.65771 .23962 m .65326 .24267 L .65054 .23916 L p F P
0 g
s
.755 .784 .877 r
.63942 .24614 m .65054 .23916 L .65326 .24267 L p F P
0 g
s
.309 .743 .969 r
.31015 .99075 m .30933 .99076 L .31067 .99095 L closepath p F P
0 g
s
.595 .593 .82 r
.61886 .76691 m .62012 .76949 L .61046 .77426 L p F P
0 g
s
.595 .593 .82 r
.61046 .77426 m .60761 .76845 L .61886 .76691 L p F P
0 g
s
.63 .776 .951 r
.42167 .99093 m .41083 .99337 L .40771 .99115 L p F P
0 g
s
.597 .799 .977 r
.41083 .99337 m .42167 .99093 L .42477 .99314 L p F P
0 g
s
.444 .629 .932 r
.5947 .24427 m .59261 .24411 L .59509 .24799 L p F P
0 g
s
.444 .629 .932 r
.59509 .24799 m .59752 .24815 L .5947 .24427 L p F P
0 g
s
.326 0 0 r
.41594 .74328 m .42298 .74289 L p .42518 .74391 L F P
0 g
s
.57 .526 .767 r
.6504 .81283 m .64712 .81292 L .64992 .81157 L closepath p F P
0 g
s
.574 .536 .774 r
.64749 .80537 m .64992 .81157 L .64712 .81292 L p F P
0 g
s
.571 .526 .765 r
.64712 .81292 m .6504 .81283 L p .65182 .82065 L F P
0 g
s
.566 .516 .758 r
.65331 .82064 m .65182 .82065 L .6531 .82004 L closepath p F P
0 g
s
.571 .526 .765 r
.6504 .81283 m .6531 .82004 L .65182 .82065 L p F P
0 g
s
.545 .466 .718 r
.66359 .8516 m .67155 .84781 L p .66881 .85754 L F P
0 g
s
.545 .466 .718 r
.66881 .85754 m .66518 .85711 L .66359 .8516 L p F P
0 g
s
.902 .821 .758 r
.7468 .14641 m .7491 .14296 L .74656 .13958 L p F P
0 g
s
.377 0 0 r
.38626 .74309 m .3875 .74324 L p .39746 .74465 L F P
0 g
s
.077 .634 .801 r
.38626 .74309 m .383 .74308 L .3875 .74324 L closepath p F P
0 g
s
.839 .669 .672 r
.13333 .88033 m .13871 .88254 L .13589 .88868 L p F P
0 g
s
.837 .676 .682 r
.13871 .88254 m .13333 .88033 L .13649 .8741 L p F P
0 g
s
.041 0 0 r
.5614 .98061 m .56103 .98076 L .54945 .9831 L p F P
0 g
s
0 0 0 r
.54746 .98361 m .54945 .9831 L .56103 .98076 L p F P
0 g
s
.525 .397 .648 r
.66362 .8974 m .66311 .89463 L .66683 .89604 L closepath p F P
0 g
s
.554 .5 .749 r
.66565 .82347 m .66767 .82935 L .65625 .82886 L p F P
0 g
s
.554 .5 .749 r
.65625 .82886 m .65604 .82827 L .66565 .82347 L p F P
0 g
s
.559 .511 .758 r
.66472 .82088 m .66565 .82347 L .65604 .82827 L p F P
0 g
s
.559 .511 .758 r
.65604 .82827 m .65331 .82064 L .66472 .82088 L p F P
0 g
s
.825 .71 .737 r
.14202 .84373 m .13687 .8414 L .14176 .83469 L p F P
0 g
s
.826 .707 .733 r
.13687 .8414 m .14202 .84373 L .13741 .85035 L p F P
0 g
s
.414 .777 .995 r
.30933 .99076 m .31015 .99075 L .30682 .98912 L p F P
0 g
s
.414 .777 .995 r
.30682 .98912 m .30094 .98953 L .30933 .99076 L p F P
0 g
s
.815 .464 .391 r
.18342 .95718 m .18293 .95703 L .18116 .95206 L p F P
0 g
s
.817 .461 .382 r
.17502 .95016 m .18116 .95206 L .18293 .95703 L p F P
0 g
s
.18 .694 .892 r
.36195 .74154 m .35844 .74155 L p .36574 .74194 L F P
0 g
s
.26 .724 .948 r
.36195 .74154 m .3565 .74083 L .35844 .74155 L closepath p F P
0 g
s
.458 0 0 r
.36732 .74313 m .35765 .74107 L .36195 .74154 L F
.3565 .74083 m .36195 .74154 L p .35765 .74107 L F P
0 g
s
.18 .694 .892 r
.37229 .74229 m .36195 .74154 L p .36574 .74194 L F P
0 g
s
.271 0 0 r
.383 .74308 m .38626 .74309 L .38299 .74399 L p F P
0 g
s
.788 .735 .804 r
.17837 .77937 m .18348 .78178 L .17504 .78951 L p F P
0 g
s
.79 .738 .805 r
.18257 .77561 m .17837 .77937 L .18348 .78178 L p F P
0 g
s
.79 .738 .805 r
.18348 .78178 m .18597 .77955 L .18257 .77561 L p F P
0 g
s
.794 .732 .794 r
.175 .78956 m .17504 .78951 L .17491 .78945 L closepath p F P
0 g
s
.788 .735 .804 r
.17159 .78558 m .17837 .77937 L p .17504 .78951 L F P
0 g
s
.788 .735 .804 r
.17504 .78951 m .17491 .78945 L .17159 .78558 L p F P
0 g
s
.8 .732 .789 r
.16748 .79699 m .175 .78956 L .17491 .78945 L p F P
0 g
s
.595 .803 .979 r
.42477 .99314 m .43564 .9907 L .43872 .99286 L p F P
0 g
s
.628 .779 .953 r
.43564 .9907 m .42477 .99314 L .42167 .99093 L p F P
0 g
s
.784 .738 .811 r
.19265 .77382 m .18597 .77955 L .18257 .77561 L p F P
0 g
s
.836 .694 .706 r
.1333 .85683 m .13846 .85914 L .1347 .86553 L p F P
0 g
s
.833 .699 .716 r
.13676 .85134 m .1333 .85683 L .13846 .85914 L p F P
0 g
s
.441 .84 .977 r
.49454 .99059 m .49498 .99071 L .50726 .98905 L p F P
0 g
s
.378 .82 .949 r
.50849 .98943 m .50726 .98905 L .49498 .99071 L p F P
0 g
s
.376 .826 .937 r
.51952 .98734 m .52244 .98784 L .53349 .98577 L p F P
0 g
s
.8 .732 .789 r
.17491 .78945 m .17 .78709 L p .16748 .79699 L F P
0 g
s
.797 .736 .796 r
.17491 .78945 m .17159 .78558 L .17 .78709 L closepath p F P
0 g
s
.545 .466 .717 r
.66573 .85899 m .66518 .85711 L .66881 .85754 L closepath p F P
0 g
s
.635 .675 .871 r
.5434 .74294 m .54282 .74207 L .5525 .73954 L closepath p F P
0 g
s
.122 .672 .789 r
.42812 .74252 m .42298 .74289 L .42939 .74256 L closepath p F P
0 g
s
.326 0 0 r
.42298 .74289 m .42812 .74252 L .42518 .74391 L p F P
0 g
s
.539 .452 .706 r
.66767 .86618 m .66573 .85899 L .66881 .85754 L p F P
0 g
s
.784 .738 .811 r
.18257 .77561 m .18747 .77142 L .19265 .77382 L p F P
0 g
s
.782 .74 .814 r
.1935 .76638 m .18747 .77142 L .19265 .77382 L p F P
0 g
s
.782 .74 .814 r
.19265 .77382 m .19689 .77026 L .1935 .76638 L p F P
0 g
s
.2 0 0 r
.25302 .98282 m .26177 .98441 L p .24797 .98203 L F P
0 g
s
.2 0 0 r
.24797 .98203 m .25024 .98233 L .25302 .98282 L p F P
0 g
s
.588 .809 .984 r
.43872 .99286 m .44961 .99044 L .45267 .99249 L p F P
0 g
s
.624 .784 .958 r
.44961 .99044 m .43872 .99286 L .43564 .9907 L p F P
0 g
s
.583 .567 .801 r
.62918 .78928 m .6275 .78552 L .63866 .78451 L closepath p F P
0 g
s
.519 .364 .611 r
.66461 .90365 m .66541 .90973 L .65694 .91311 L p F P
0 g
s
.506 .338 .587 r
.66541 .90973 m .65694 .91311 L .66082 .91768 L p F P
0 g
s
.508 .339 .586 r
.65584 .91963 m .66082 .91768 L .65694 .91311 L p F P
0 g
s
.802 .73 .785 r
.16748 .79699 m .16394 .80059 L .16053 .79646 L p F P
0 g
s
.802 .73 .785 r
.16053 .79646 m .16237 .7946 L .16748 .79699 L p F P
0 g
s
.8 .732 .789 r
.17 .78709 m .16237 .7946 L .16748 .79699 L p F P
0 g
s
.77 .788 .868 r
.65054 .23916 m .65582 .23555 L .65771 .23962 L p F P
0 g
s
.772 .79 .868 r
.65771 .23962 m .66435 .23499 L .66165 .23151 L p F P
0 g
s
.772 .79 .868 r
.66165 .23151 m .65582 .23555 L .65771 .23962 L p F P
0 g
s
.369 .775 .983 r
.32404 .99132 m .32076 .98944 L .31015 .99075 L p F P
0 g
s
.561 .788 .984 r
.32076 .98944 m .31015 .99075 L .30682 .98912 L p F P
0 g
s
.82 .716 .749 r
.14704 .82789 m .14489 .8306 L .1415 .82604 L p F P
0 g
s
.82 .716 .749 r
.1415 .82604 m .14191 .82553 L .14704 .82789 L p F P
0 g
s
.816 .719 .758 r
.14704 .82789 m .14191 .82553 L .14768 .81857 L p F P
0 g
s
.775 .74 .821 r
.20278 .76557 m .19689 .77026 L .1935 .76638 L p F P
0 g
s
.255 0 0 r
.58697 .97299 m .58644 .97357 L .5753 .97621 L p F P
0 g
s
.058 0 0 r
.5753 .97621 m .58644 .97357 L .58372 .97551 L p F P
0 g
s
.058 0 0 r
.57253 .97821 m .5753 .97621 L p .58372 .97551 L F P
0 g
s
.143 0 0 r
.5614 .98061 m .57253 .97821 L .5753 .97621 L p F P
0 g
s
.577 .818 .99 r
.45267 .99249 m .46359 .99013 L .46662 .99203 L p F P
0 g
s
.617 .791 .966 r
.46359 .99013 m .45267 .99249 L .44961 .99044 L p F P
0 g
s
.558 .511 .759 r
.66267 .81519 m .66472 .82088 L .65331 .82064 L p F P
0 g
s
.558 .511 .759 r
.65331 .82064 m .6531 .82004 L .66267 .81519 L p F P
0 g
s
.393 .832 .947 r
.51952 .98734 m .51951 .98734 L .50849 .98943 L p F P
0 g
s
.453 .843 .981 r
.51951 .98734 m .50726 .98905 L .50849 .98943 L closepath p F P
0 g
s
.404 .061 .267 r
.61142 .96275 m .61251 .95941 L .62327 .95617 L p F P
0 g
s
.418 .071 .267 r
.61251 .95941 m .61142 .96275 L .60026 .96645 L p F P
0 g
s
.45 .149 .362 r
.62419 .95163 m .62327 .95617 L .61251 .95941 L p F P
0 g
s
.807 .731 .781 r
.16038 .80433 m .16394 .80059 L .16053 .79646 L p F P
0 g
s
.841 .596 .569 r
.15592 .92833 m .15014 .92629 L .15089 .92069 L p F P
0 g
s
.842 .598 .569 r
.14516 .91862 m .15089 .92069 L .15014 .92629 L p F P
0 g
s
.841 .614 .595 r
.15089 .92069 m .14516 .91862 L .14639 .9129 L p F P
0 g
s
.562 .522 .768 r
.66179 .81285 m .66267 .81519 L .6531 .82004 L p F P
0 g
s
.562 .522 .768 r
.6531 .82004 m .6504 .81283 L .66179 .81285 L p F P
0 g
s
.869 .819 .797 r
.7277 .17128 m .73242 .16559 L .73437 .16971 L p F P
0 g
s
.869 .819 .797 r
.73437 .16971 m .73027 .17465 L .7277 .17128 L p F P
0 g
s
.436 .138 .36 r
.62327 .95617 m .62419 .95163 L .6348 .9482 L p F P
0 g
s
.471 .208 .433 r
.63532 .94331 m .6348 .9482 L .62419 .95163 L p F P
0 g
s
.84 .63 .618 r
.14639 .9129 m .14073 .91081 L .1424 .90497 L p F P
0 g
s
.843 .617 .596 r
.14073 .91081 m .14639 .9129 L .14516 .91862 L p F P
0 g
s
.193 .723 .824 r
.42812 .74252 m .42939 .74256 L .44103 .74143 L p F P
0 g
s
.517 .377 .63 r
.66683 .89604 m .66362 .8974 L .66461 .90365 L p F P
0 g
s
.893 .82 .768 r
.74036 .14854 m .74242 .15265 L .7468 .14641 L p F P
0 g
s
.893 .82 .768 r
.7468 .14641 m .74476 .14229 L .74036 .14854 L p F P
0 g
s
.902 .821 .758 r
.74656 .13958 m .74476 .14229 L .7468 .14641 L p F P
0 g
s
.98 .757 .529 r
.75401 .07733 m .75478 .07268 L .7573 .07673 L p F P
0 g
s
.98 .757 .529 r
.7573 .07673 m .75656 .08118 L .75401 .07733 L p F P
0 g
s
.558 .829 .996 r
.46662 .99203 m .47757 .98973 L .48058 .99141 L p F P
0 g
s
.606 .802 .975 r
.47757 .98973 m .46662 .99203 L .46359 .99013 L p F P
0 g
s
.952 .8 .655 r
.75387 .10117 m .75621 .10525 L .75824 .09993 L p F P
0 g
s
.952 .8 .655 r
.75824 .09993 m .75591 .09584 L .75387 .10117 L p F P
0 g
s
.69 .187 .04 r
.20171 .96613 m .20543 .96705 L .21011 .97128 L p F P
0 g
s
.712 .225 .087 r
.2167 .97303 m .21011 .97128 L .20543 .96705 L p F P
0 g
s
.84 .575 .538 r
.16151 .93582 m .15569 .9338 L .15592 .92833 L p F P
0 g
s
.842 .577 .537 r
.15014 .92629 m .15592 .92833 L .15569 .9338 L p F P
0 g
s
.441 .84 .977 r
.50726 .98905 m .50553 .98841 L .49454 .99059 L p F P
0 g
s
.567 .833 .996 r
.50553 .98841 m .49454 .99059 L .49155 .98917 L p F P
0 g
s
.474 .838 .993 r
.49454 .99059 m .49155 .98917 L .48058 .99141 L p F P
0 g
s
.635 .689 .883 r
.5525 .73954 m .54282 .74207 L .5399 .73794 L p F P
0 g
s
.838 .68 .687 r
.13121 .87185 m .13649 .8741 L .13333 .88033 L p F P
0 g
s
.837 .685 .695 r
.13649 .8741 m .13121 .87185 L .1347 .86553 L p F P
0 g
s
.59 .817 .986 r
.49155 .98917 m .48058 .99141 L .47757 .98973 L p F P
0 g
s
.73 .748 .866 r
.25876 .74241 m .25759 .74114 L .25675 .74161 L closepath p F P
0 g
s
.806 .729 .779 r
.15535 .80192 m .16038 .80433 L .15372 .81154 L p F P
0 g
s
.807 .731 .781 r
.16053 .79646 m .15535 .80192 L .16038 .80433 L p F P
0 g
s
.122 .658 .856 r
.37247 .74231 m .37229 .74229 L .37235 .74231 L closepath p F P
0 g
s
.843 .633 .619 r
.13819 .90336 m .1424 .90497 L .14073 .91081 L p F P
0 g
s
.84 .645 .639 r
.13746 .90104 m .13891 .89689 L p .1424 .90497 L F P
0 g
s
.84 .645 .639 r
.1424 .90497 m .13819 .90336 L .13746 .90104 L p F P
0 g
s
.824 .716 .746 r
.14176 .83469 m .14489 .8306 L .1415 .82604 L p F P
0 g
s
.488 0 0 r
.22381 .97463 m .23072 .97821 L .23057 .97819 L p F P
0 g
s
.488 0 0 r
.21759 .97326 m .22381 .97463 L p .23057 .97819 L F P
0 g
s
.775 .74 .821 r
.1935 .76638 m .19752 .76319 L .20278 .76557 L p F P
0 g
s
.773 .742 .824 r
.20439 .75785 m .19752 .76319 L .20278 .76557 L p F P
0 g
s
.773 .742 .824 r
.20278 .76557 m .20777 .76167 L .20439 .75785 L p F P
0 g
s
.742 .74 .85 r
.23276 .75015 m .23294 .75004 L .23251 .74988 L closepath p F P
0 g
s
.755 .745 .843 r
.23251 .74988 m .23276 .75015 L p .2186 .75374 L F P
0 g
s
.526 .01 0 r
.37247 .74231 m .38299 .74399 L .38271 .74418 L p F P
0 g
s
.526 .01 0 r
.37229 .74229 m .37247 .74231 L p .38271 .74418 L F P
0 g
s
.526 .01 0 r
.36907 .74239 m .37229 .74229 L p .38271 .74418 L F P
0 g
s
.18 0 0 r
.36907 .74239 m .36195 .74154 L .37229 .74229 L closepath p F P
0 g
s
.736 .743 .857 r
.24017 .73993 m .24352 .74356 L .23294 .75004 L p F P
0 g
s
.736 .743 .857 r
.2294 .74645 m .24017 .73993 L p .23294 .75004 L F P
0 g
s
.736 .743 .857 r
.23294 .75004 m .23251 .74988 L .2294 .74645 L p F P
0 g
s
.534 .439 .693 r
.66767 .86618 m .67743 .8616 L p .67606 .87012 L F P
0 g
s
.534 .439 .693 r
.67606 .87012 m .66824 .86848 L .66767 .86618 L p F P
0 g
s
.539 .452 .706 r
.67668 .85887 m .67743 .8616 L .66767 .86618 L p F P
0 g
s
.539 .452 .706 r
.66881 .85754 m .67668 .85887 L p .66767 .86618 L F P
0 g
s
.318 0 0 r
.24797 .98203 m .24561 .98131 L .25024 .98233 L closepath p F P
0 g
s
.838 .55 .501 r
.16495 .94222 m .16182 .94115 L .16151 .93582 L p F P
0 g
s
.841 .551 .499 r
.15569 .9338 m .16151 .93582 L .16182 .94115 L p F P
0 g
s
.381 .008 .199 r
.60019 .96661 m .60026 .96645 L .61142 .96275 L p F P
0 g
s
.449 .799 .998 r
.33796 .99161 m .33471 .98952 L .32404 .99132 L p F P
0 g
s
.598 .784 .969 r
.33471 .98952 m .32404 .99132 L .32076 .98944 L p F P
0 g
s
.605 .61 .83 r
.59065 .75901 m .60185 .7571 L .60473 .76265 L p F P
0 g
s
.606 .615 .833 r
.59937 .75236 m .60185 .7571 L .59065 .75901 L p F P
0 g
s
.606 .615 .833 r
.59065 .75901 m .58958 .75699 L .59937 .75236 L p F P
0 g
s
.753 .746 .846 r
.23251 .74988 m .2294 .74645 L .22754 .74769 L closepath p F P
0 g
s
.755 .745 .843 r
.2186 .75374 m .22754 .74769 L .23251 .74988 L p F P
0 g
s
.657 .772 .933 r
.28559 .73821 m .29625 .73465 L .29955 .73758 L p F P
0 g
s
.635 .778 .949 r
.29625 .73465 m .28559 .73821 L .28229 .735 L p F P
0 g
s
.689 .761 .906 r
.27161 .73941 m .28229 .735 L .28559 .73821 L p F P
0 g
s
.913 .816 .737 r
.74655 .13213 m .74871 .13622 L .75222 .13032 L p F P
0 g
s
.913 .816 .737 r
.75222 .13032 m .75008 .12621 L .74655 .13213 L p F P
0 g
s
.177 .671 .919 r
.27592 .98605 m .2753 .98593 L .26522 .9853 L p F P
0 g
s
.106 .639 .865 r
.2753 .98593 m .26522 .9853 L .26177 .98441 L p F P
0 g
s
.583 .567 .802 r
.63866 .78451 m .6275 .78552 L .62487 .77963 L p F P
0 g
s
.934 .81 .699 r
.7519 .11472 m .75384 .11071 L .75609 .1148 L p F P
0 g
s
.934 .81 .699 r
.75609 .1148 m .75443 .11822 L .7519 .11472 L p F P
0 g
s
.603 .713 .922 r
.59752 .24815 m .60875 .24568 L .61155 .24945 L p F P
0 g
s
.598 .711 .923 r
.60875 .24568 m .59752 .24815 L .5947 .24427 L p F P
0 g
s
.603 .786 .968 r
.29955 .73758 m .31017 .73502 L .31347 .73754 L p F P
0 g
s
.549 .789 .988 r
.31017 .73502 m .29955 .73758 L .29625 .73465 L p F P
0 g
s
.616 .63 .842 r
.57372 .75076 m .58488 .74848 L .58777 .75367 L p F P
0 g
s
.617 .638 .848 r
.58273 .74469 m .58488 .74848 L .57372 .75076 L p F P
0 g
s
.617 .638 .848 r
.57372 .75076 m .57279 .74914 L .58273 .74469 L p F P
0 g
s
.786 .794 .86 r
.67077 .2302 m .66435 .23499 L .66165 .23151 L p F P
0 g
s
.534 .439 .693 r
.66942 .87319 m .66824 .86848 L .67606 .87012 L closepath p F P
0 g
s
.306 0 .059 r
.59805 .97009 m .60019 .96661 L .6111 .96353 L p F P
0 g
s
.381 .008 .199 r
.61142 .96275 m .6111 .96353 L .60019 .96661 L p F P
0 g
s
.327 0 .068 r
.60019 .96661 m .59805 .97009 L .58697 .97299 L p F P
0 g
s
.843 .647 .638 r
.13746 .90104 m .13891 .89689 L .13576 .89565 L closepath p F P
0 g
s
.84 .658 .656 r
.13444 .89226 m .13589 .88868 L p .13891 .89689 L F P
0 g
s
.84 .658 .656 r
.13891 .89689 m .13576 .89565 L .13444 .89226 L p F P
0 g
s
.765 .743 .833 r
.21421 .75692 m .20777 .76167 L .20439 .75785 L p F P
0 g
s
.864 .819 .803 r
.72874 .17642 m .73027 .17465 L .7277 .17128 L p F P
0 g
s
.783 .372 .273 r
.19879 .96531 m .19242 .96348 L .1894 .95883 L p F P
0 g
s
.778 .361 .258 r
.18342 .95718 m .1894 .95883 L .19242 .96348 L p F P
0 g
s
.562 .522 .768 r
.65946 .80666 m .66179 .81285 L .6504 .81283 L p F P
0 g
s
.562 .522 .768 r
.6504 .81283 m .64992 .81157 L .65946 .80666 L p F P
0 g
s
.457 .198 .431 r
.6348 .9482 m .63532 .94331 L .64578 .9397 L p F P
0 g
s
.483 .251 .486 r
.64596 .93452 m .64578 .9397 L .63532 .94331 L p F P
0 g
s
.831 .701 .72 r
.13676 .85134 m .13741 .85035 L .13559 .84954 L closepath p F P
0 g
s
.826 .707 .733 r
.1334 .84639 m .13687 .8414 L p .13741 .85035 L F P
0 g
s
.826 .707 .733 r
.13741 .85035 m .13559 .84954 L .1334 .84639 L p F P
0 g
s
.728 .772 .888 r
.63942 .24614 m .63919 .24626 L .6388 .24532 L closepath p F P
0 g
s
.726 .767 .885 r
.63667 .24254 m .6388 .24532 L .63919 .24626 L p F P
0 g
s
.726 .767 .885 r
.62551 .24846 m .63667 .24254 L p .63919 .24626 L F P
0 g
s
.679 .766 .917 r
.28229 .735 m .27161 .73941 L .26829 .73601 L p F P
0 g
s
.759 .781 .871 r
.64781 .23559 m .65054 .23916 L .63942 .24614 L p F P
0 g
s
.759 .781 .871 r
.63716 .24224 m .64781 .23559 L p .63942 .24614 L F P
0 g
s
.759 .781 .871 r
.63942 .24614 m .6388 .24532 L .63716 .24224 L p F P
0 g
s
.566 .532 .777 r
.65888 .80517 m .65946 .80666 L .64992 .81157 L p F P
0 g
s
.566 .532 .777 r
.64992 .81157 m .64749 .80537 L .65888 .80517 L p F P
0 g
s
.806 .729 .779 r
.14937 .80837 m .15535 .80192 L p .15372 .81154 L F P
0 g
s
.806 .729 .779 r
.15372 .81154 m .15089 .81021 L .14937 .80837 L p F P
0 g
s
.812 .725 .769 r
.15279 .8126 m .15372 .81154 L .15089 .81021 L closepath p F P
0 g
s
.864 .819 .803 r
.7277 .17128 m .72683 .17229 L .72874 .17642 L p F P
0 g
s
.856 .817 .81 r
.72057 .17924 m .72252 .18334 L .72874 .17642 L p F P
0 g
s
.856 .817 .81 r
.72874 .17642 m .72683 .17229 L .72057 .17924 L p F P
0 g
s
.527 0 0 r
.23428 .97829 m .23838 .97975 L p .24411 .98091 L F P
0 g
s
.42 0 0 r
.23838 .97975 m .23428 .97829 L .23072 .97821 L p F P
0 g
s
0 .494 .738 r
.241 .98005 m .23175 .97841 L p .23838 .97975 L F P
0 g
s
.42 0 0 r
.23072 .97821 m .23088 .97825 L .23838 .97975 L p F P
0 g
s
0 .494 .738 r
.23175 .97841 m .23088 .97825 L .23838 .97975 L p F P
0 g
s
.527 0 0 r
.23838 .97975 m .24561 .98131 L p .24411 .98091 L F P
0 g
s
.827 .713 .739 r
.13672 .83232 m .14176 .83469 L .13687 .8414 L p F P
0 g
s
.824 .716 .746 r
.1415 .82604 m .13672 .83232 L .14176 .83469 L p F P
0 g
s
.816 .725 .764 r
.14768 .81857 m .15279 .8126 L .15089 .81021 L p F P
0 g
s
.596 .594 .821 r
.61598 .76107 m .61886 .76691 L .60761 .76845 L p F P
0 g
s
.596 .594 .821 r
.6084 .7621 m .61598 .76107 L p .60761 .76845 L F P
0 g
s
.596 .594 .821 r
.60761 .76845 m .60525 .76367 L .6084 .7621 L p F P
0 g
s
.824 .504 .447 r
.17502 .95016 m .16888 .94825 L .1678 .94311 L p F P
0 g
s
.824 .498 .437 r
.16495 .94222 m .1678 .94311 L .16888 .94825 L p F P
0 g
s
.835 .701 .716 r
.1333 .85683 m .13676 .85134 L .13559 .84954 L p F P
0 g
s
.375 .759 .989 r
.31347 .73754 m .32408 .73611 L .32167 .735 L p F P
0 g
s
.375 .759 .989 r
.31017 .73502 m .31347 .73754 L p .32167 .735 L F P
0 g
s
.497 .792 .998 r
.31347 .73754 m .32408 .73611 L .32738 .73806 L p F P
0 g
s
.621 .777 .956 r
.34867 .98943 m .33796 .99161 L .33471 .98952 L p F P
0 g
s
.583 .79 .978 r
.33796 .99161 m .34867 .98943 L .3519 .9917 L p F P
0 g
s
.377 .774 .986 r
.30094 .98953 m .30682 .98912 L p .29291 .98845 L F P
0 g
s
.377 .774 .986 r
.29291 .98845 m .29362 .98874 L .30094 .98953 L p F P
0 g
s
0 .24 .751 r
.57766 .23241 m .58025 .23436 L .58299 .23817 L p F P
0 g
s
.257 .524 .913 r
.58721 .23646 m .58998 .24027 L .58299 .23817 L p F P
0 g
s
.257 .524 .913 r
.58299 .23817 m .58025 .23436 L .58721 .23646 L p F P
0 g
s
.53 .413 .665 r
.67139 .88189 m .66861 .88107 L .671 .88002 L closepath p F P
0 g
s
.538 .43 .679 r
.66942 .87319 m .671 .88002 L .66861 .88107 L p F P
0 g
s
.377 0 0 r
.39746 .74465 m .39551 .74461 L .38626 .74309 L p F P
0 g
s
.339 0 0 r
.39551 .74461 m .38626 .74309 L .38299 .74399 L p F P
0 g
s
.729 .75 .869 r
.24352 .74356 m .25117 .73932 L .25675 .74161 L p F P
0 g
s
.731 .752 .869 r
.25426 .73763 m .25117 .73932 L .25675 .74161 L p F P
0 g
s
.731 .752 .869 r
.25675 .74161 m .25759 .74114 L .25426 .73763 L p F P
0 g
s
.838 .688 .697 r
.12951 .86323 m .1347 .86553 L .13121 .87185 L p F P
0 g
s
.836 .694 .706 r
.1347 .86553 m .12951 .86323 L .1333 .85683 L p F P
0 g
s
.627 .802 .966 r
.48401 .73779 m .49499 .73472 L .49797 .73713 L p F P
0 g
s
.579 .852 .995 r
.49499 .73472 m .48401 .73779 L .481 .73604 L p F P
0 g
s
.581 .84 .994 r
.47004 .73881 m .481 .73604 L .48401 .73779 L p F P
0 g
s
.458 0 0 r
.36195 .74154 m .36907 .74239 L .36732 .74313 L p F P
0 g
s
.643 .764 .936 r
.49797 .73713 m .50898 .73392 L .51194 .73691 L p F P
0 g
s
.631 .806 .967 r
.50898 .73392 m .49797 .73713 L .49499 .73472 L p F P
0 g
s
.609 .622 .839 r
.59897 .75162 m .59937 .75236 L .58958 .75699 L p F P
0 g
s
.609 .622 .839 r
.58958 .75699 m .58777 .75367 L .59897 .75162 L p F P
0 g
s
.528 .424 .68 r
.671 .88002 m .66942 .87319 L .67606 .87012 L p F P
0 g
s
.843 .66 .655 r
.13444 .89226 m .13589 .88868 L .13248 .88729 L closepath p F P
0 g
s
.839 .669 .672 r
.1313 .88474 m .13333 .88033 L p .13589 .88868 L F P
0 g
s
.839 .669 .672 r
.13589 .88868 m .13248 .88729 L .1313 .88474 L p F P
0 g
s
.788 .796 .859 r
.67077 .2302 m .67543 .22667 L .67275 .2232 L p F P
0 g
s
.788 .796 .859 r
.67275 .2232 m .6689 .22611 L .67077 .2302 L p F P
0 g
s
.786 .794 .86 r
.66165 .23151 m .6689 .22611 L .67077 .2302 L p F P
0 g
s
.69 .187 .04 r
.20001 .96673 m .20171 .96613 L p .21011 .97128 L F P
0 g
s
.755 .305 .184 r
.20001 .96673 m .19879 .96531 L .20171 .96613 L closepath p F P
0 g
s
.521 .868 .99 r
.46716 .73781 m .47004 .73881 L .481 .73604 L p F P
0 g
s
.704 .758 .894 r
.26829 .73601 m .25759 .74114 L .25426 .73763 L p F P
0 g
s
.495 .31 .559 r
.66082 .91768 m .65584 .91963 L .65619 .92529 L p F P
0 g
s
.273 .769 .895 r
.4421 .7413 m .44103 .74143 L .44232 .74133 L closepath p F P
0 g
s
.193 .723 .824 r
.44103 .74143 m .4421 .7413 L p .42812 .74252 L F P
0 g
s
.765 .743 .833 r
.20439 .75785 m .20888 .75456 L .21421 .75692 L p F P
0 g
s
.764 .745 .835 r
.21523 .75 m .20888 .75456 L .21421 .75692 L p F P
0 g
s
.764 .745 .835 r
.21421 .75692 m .2186 .75374 L .21523 .75 L p F P
0 g
s
.886 .818 .775 r
.73591 .1546 m .74036 .14854 L .74242 .15265 L p F P
0 g
s
.886 .818 .775 r
.74242 .15265 m .73848 .15802 L .73591 .1546 L p F P
0 g
s
.96 .789 .627 r
.75348 .09179 m .75591 .09584 L .7576 .09066 L p F P
0 g
s
.96 .789 .627 r
.7576 .09066 m .75518 .08659 L .75348 .09179 L p F P
0 g
s
.619 .645 .853 r
.58199 .74343 m .58273 .74469 L .57279 .74914 L p F P
0 g
s
.619 .645 .853 r
.57279 .74914 m .57083 .74584 L .58199 .74343 L p F P
0 g
s
.626 .654 .858 r
.55681 .74373 m .56793 .74109 L .57083 .74584 L p F P
0 g
s
.628 .662 .864 r
.56793 .74109 m .55681 .74373 L .5539 .73918 L p F P
0 g
s
.538 .453 .707 r
.67668 .85887 m .66881 .85754 L .67546 .85437 L closepath p F P
0 g
s
.545 .466 .718 r
.67364 .84809 m .67546 .85437 L .66881 .85754 L p F P
0 g
s
.545 .466 .718 r
.67155 .84781 m .67364 .84809 L p .66881 .85754 L F P
0 g
s
.315 .794 .91 r
.4421 .7413 m .44232 .74133 L .45501 .73984 L p F P
0 g
s
.483 .85 .989 r
.45607 .74003 m .45501 .73984 L .44232 .74133 L p F P
0 g
s
.604 .786 .968 r
.3519 .9917 m .36264 .98924 L .36584 .99165 L p F P
0 g
s
.635 .77 .944 r
.36264 .98924 m .3519 .9917 L .34867 .98943 L p F P
0 g
s
.646 .732 .912 r
.51194 .73691 m .52297 .7337 L .52591 .73718 L p F P
0 g
s
.644 .762 .934 r
.52297 .7337 m .51194 .73691 L .50898 .73392 L p F P
0 g
s
.395 .836 .941 r
.46579 .73801 m .45501 .73984 L .45607 .74003 L closepath p F P
0 g
s
.462 .849 .981 r
.46716 .73781 m .46579 .73801 L .45607 .74003 L p F P
0 g
s
.851 .815 .814 r
.71682 .18328 m .72057 .17924 L .72252 .18334 L p F P
0 g
s
.851 .815 .814 r
.72252 .18334 m .71941 .1867 L .71682 .18328 L p F P
0 g
s
.75 .778 .875 r
.6388 .24532 m .63667 .24254 L .63716 .24224 L closepath p F P
0 g
s
.565 .533 .777 r
.656 .79787 m .65888 .80517 L .64749 .80537 L p F P
0 g
s
.565 .533 .777 r
.64749 .80537 m .64649 .80283 L .656 .79787 L p F P
0 g
s
.2 0 0 r
.24561 .98131 m .24797 .98203 L .24448 .98121 L p F P
0 g
s
.2 0 0 r
.24448 .98121 m .23838 .97975 L .24561 .98131 L p F P
0 g
s
.488 .846 .993 r
.50553 .98841 m .50726 .98905 L .51951 .98734 L p F P
0 g
s
.799 .8 .852 r
.68186 .2215 m .67543 .22667 L .67275 .2232 L p F P
0 g
s
.374 0 0 r
.4116 .74455 m .40874 .74459 L .40019 .74348 L p F P
0 g
s
.358 0 0 r
.40874 .74459 m .39746 .74465 L .40019 .74348 L closepath p F P
0 g
s
.324 .749 .974 r
.33497 .73782 m .32738 .73806 L p .33822 .73841 L F P
0 g
s
.399 .748 .993 r
.33497 .73782 m .32738 .73806 L .32408 .73611 L p F P
0 g
s
.399 .748 .993 r
.32688 .7363 m .33497 .73782 L p .33003 .73705 L F P
0 g
s
.399 .748 .993 r
.32408 .73611 m .32688 .7363 L p .33003 .73705 L F P
0 g
s
.219 .679 .946 r
.32688 .7363 m .32167 .735 L .32408 .73611 L closepath p F P
0 g
s
.495 0 0 r
.3337 .73845 m .323 .73538 L .32688 .7363 L F
.32167 .735 m .32688 .7363 L p .323 .73538 L F P
0 g
s
.25 0 0 r
.33459 .73818 m .32785 .73654 L p .33497 .73782 L F P
0 g
s
.25 0 0 r
.32785 .73654 m .32688 .7363 L .33497 .73782 L p F P
0 g
s
.324 .749 .974 r
.33969 .73845 m .33497 .73782 L p .33822 .73841 L F P
0 g
s
.816 .724 .763 r
.14268 .81616 m .14768 .81857 L .14191 .82553 L p F P
0 g
s
.816 .725 .764 r
.14869 .80914 m .14268 .81616 L .14768 .81857 L p F P
0 g
s
.816 .725 .764 r
.15089 .81021 m .14869 .80914 L p .14768 .81857 L F P
0 g
s
.93 .811 .707 r
.75332 .12041 m .75443 .11822 L .7519 .11472 L p F P
0 g
s
0 0 0 r
.56103 .98076 m .5614 .98061 L .57253 .97821 L p F P
0 g
s
.517 .377 .63 r
.66461 .90365 m .67379 .89978 L .66683 .89604 L p F P
0 g
s
.515 .378 .632 r
.6736 .89313 m .66683 .89604 L .67379 .89978 L p F P
0 g
s
.525 .397 .649 r
.67239 .88667 m .6736 .89313 L .66683 .89604 L p F P
0 g
s
.835 .701 .716 r
.13559 .84954 m .1323 .84801 L p .1333 .85683 L F P
0 g
s
.832 .708 .727 r
.13559 .84954 m .1334 .84639 L .1323 .84801 L closepath p F P
0 g
s
.723 .767 .888 r
.63667 .24254 m .62551 .24846 L .62274 .24478 L p F P
0 g
s
.686 .752 .902 r
.61155 .24945 m .62274 .24478 L .62551 .24846 L p F P
0 g
s
.315 .794 .91 r
.45501 .73984 m .45299 .74009 L .4421 .7413 L p F P
0 g
s
.351 0 0 r
.4421 .7413 m .45299 .74009 L .4511 .7414 L p F P
0 g
s
.351 0 0 r
.43897 .74232 m .4421 .7413 L p .4511 .7414 L F P
0 g
s
.193 .723 .824 r
.4421 .7413 m .43897 .74232 L .42812 .74252 L p F P
0 g
s
.754 .747 .846 r
.22754 .74769 m .2186 .75374 L .21523 .75 L p F P
0 g
s
.618 .781 .96 r
.36584 .99165 m .37662 .989 L .37979 .99152 L p F P
0 g
s
.644 .764 .936 r
.37662 .989 m .36584 .99165 L .36264 .98924 L p F P
0 g
s
.817 .461 .382 r
.18293 .95703 m .17684 .95512 L .17502 .95016 L p F P
0 g
s
.817 .457 .375 r
.16888 .94825 m .17502 .95016 L .17684 .95512 L p F P
0 g
s
.683 .75 .902 r
.62274 .24478 m .61155 .24945 L .60875 .24568 L p F P
0 g
s
.844 .814 .82 r
.71578 .19046 m .71941 .1867 L .71682 .18328 L p F P
0 g
s
.507 .356 .61 r
.66541 .90973 m .66461 .90365 L .67379 .89978 L p F P
0 g
s
.15 .669 .887 r
.27904 .98723 m .28402 .98709 L .29194 .98846 L p F P
0 g
s
.313 .748 .969 r
.28402 .98709 m .27592 .98605 L .27904 .98723 L closepath p F P
0 g
s
.583 .567 .802 r
.62487 .77963 m .62627 .77891 L p .63866 .78451 L F P
0 g
s
.586 .576 .809 r
.62487 .77963 m .62462 .77908 L .62627 .77891 L closepath p F P
0 g
s
.842 .672 .67 r
.1313 .88474 m .13333 .88033 L .12823 .87818 L closepath p F P
0 g
s
.838 .68 .687 r
.1281 .87792 m .13121 .87185 L p .13333 .88033 L F P
0 g
s
.838 .68 .687 r
.13333 .88033 m .12823 .87818 L .1281 .87792 L p F P
0 g
s
.57 .543 .786 r
.65597 .79779 m .656 .79787 L .64649 .80283 L p F P
0 g
s
.57 .543 .786 r
.64649 .80283 m .64459 .7982 L .65597 .79779 L p F P
0 g
s
.458 0 0 r
.35517 .74057 m .3565 .74083 L p .36732 .74313 L F P
0 g
s
.068 .621 .822 r
.35517 .74057 m .3525 .74044 L .3565 .74083 L closepath p F P
0 g
s
.326 0 0 r
.42518 .74391 m .42401 .74397 L .41415 .74329 L p F P
0 g
s
.326 0 0 r
.42401 .74397 m .4116 .74455 L .41415 .74329 L closepath p F P
0 g
s
.238 0 0 r
.42518 .74391 m .42812 .74252 L .43897 .74232 L p F P
0 g
s
.835 .813 .829 r
.70887 .19835 m .70849 .19785 L .7086 .19775 L closepath p F P
0 g
s
.471 .242 .484 r
.64578 .9397 m .64596 .93452 L .65629 .93073 L p F P
0 g
s
.491 .284 .527 r
.65619 .92529 m .65629 .93073 L .64596 .93452 L p F P
0 g
s
.644 .728 .909 r
.53697 .73407 m .52591 .73718 L .52297 .7337 L p F P
0 g
s
.642 .707 .893 r
.52591 .73718 m .53697 .73407 L .5399 .73794 L p F P
0 g
s
.488 0 0 r
.2171 .97332 m .21759 .97326 L p .23057 .97819 L F P
0 g
s
.663 .141 0 r
.2171 .97332 m .2167 .97303 L .21759 .97326 L closepath p F P
0 g
s
.586 .579 .812 r
.62627 .77891 m .62462 .77908 L .62174 .77294 L p F P
0 g
s
.307 .737 .97 r
.29291 .98845 m .29194 .98846 L .29362 .98874 L closepath p F P
0 g
s
.802 .801 .851 r
.68186 .2215 m .68648 .21771 L .68382 .21426 L p F P
0 g
s
.802 .801 .851 r
.68382 .21426 m .67997 .21741 L .68186 .2215 L p F P
0 g
s
.799 .8 .852 r
.67275 .2232 m .67997 .21741 L .68186 .2215 L p F P
0 g
s
.942 .803 .678 r
.75149 .10664 m .75384 .11071 L .75621 .10525 L p F P
0 g
s
.942 .803 .678 r
.75621 .10525 m .75387 .10117 L .75149 .10664 L p F P
0 g
s
.824 .498 .437 r
.16266 .94594 m .16495 .94222 L p .16888 .94825 L F P
0 g
s
.836 .52 .454 r
.16266 .94594 m .16182 .94115 L .16495 .94222 L closepath p F P
0 g
s
.625 .778 .954 r
.37979 .99152 m .3906 .98875 L .39375 .99135 L p F P
0 g
s
.649 .76 .93 r
.3906 .98875 m .37979 .99152 L .37662 .989 L p F P
0 g
s
.904 .815 .75 r
.74401 .1361 m .74655 .13213 L .74871 .13622 L p F P
0 g
s
.904 .815 .75 r
.74871 .13622 m .74656 .13958 L .74401 .1361 L p F P
0 g
s
.844 .814 .82 r
.71682 .18328 m .71386 .18635 L .71578 .19046 L p F P
0 g
s
.84 .812 .823 r
.70663 .19366 m .7086 .19775 L .71578 .19046 L p F P
0 g
s
.84 .812 .823 r
.71578 .19046 m .71386 .18635 L .70663 .19366 L p F P
0 g
s
.725 .751 .873 r
.25117 .73932 m .24352 .74356 L .24017 .73993 L p F P
0 g
s
.847 .649 .635 r
.13576 .89565 m .13348 .89471 L p .13686 .90283 L F P
0 g
s
.847 .649 .635 r
.13686 .90283 m .13746 .90104 L .13576 .89565 L p F P
0 g
s
.846 .66 .651 r
.13576 .89565 m .13444 .89226 L .13348 .89471 L closepath p F P
0 g
s
.83 .709 .731 r
.13687 .8414 m .1334 .84639 L .13001 .8416 L p F P
0 g
s
.83 .709 .731 r
.13001 .8416 m .13179 .83904 L .13687 .8414 L p F P
0 g
s
.827 .713 .739 r
.13687 .8414 m .13179 .83904 L .13672 .83232 L p F P
0 g
s
.846 .648 .634 r
.13819 .90336 m .13746 .90104 L .13686 .90283 L closepath p F P
0 g
s
.793 .739 .803 r
.17837 .77937 m .17159 .78558 L .16817 .78166 L p F P
0 g
s
.798 .739 .798 r
.17 .78709 m .17159 .78558 L .16817 .78166 L p F P
0 g
s
.793 .739 .803 r
.16817 .78166 m .17334 .77692 L .17837 .77937 L p F P
0 g
s
.791 .74 .806 r
.17916 .77172 m .17334 .77692 L .17837 .77937 L p F P
0 g
s
.791 .74 .806 r
.17837 .77937 m .18257 .77561 L .17916 .77172 L p F P
0 g
s
.843 .633 .619 r
.14073 .91081 m .13981 .91046 L .13819 .90336 L p F P
0 g
s
.85 .637 .614 r
.13686 .90283 m .13819 .90336 L .13981 .91046 L p F P
0 g
s
.798 .739 .798 r
.16817 .78166 m .16504 .78464 L .17 .78709 L p F P
0 g
s
.8 .735 .792 r
.16504 .78464 m .17 .78709 L .16237 .7946 L p F P
0 g
s
.838 .697 .708 r
.12821 .8545 m .1333 .85683 L .12951 .86323 L p F P
0 g
s
.835 .701 .716 r
.1323 .84801 m .12821 .8545 L .1333 .85683 L p F P
0 g
s
.784 .74 .813 r
.18747 .77142 m .18257 .77561 L .17916 .77172 L p F P
0 g
s
.979 .76 .537 r
.7565 .08156 m .75656 .08118 L .75401 .07733 L p F P
0 g
s
.739 .269 .132 r
.19879 .96531 m .20001 .96673 L .1963 .96755 L p F P
0 g
s
.739 .269 .132 r
.1963 .96755 m .19242 .96348 L .19879 .96531 L p F P
0 g
s
.522 .408 .665 r
.671 .88002 m .68081 .8755 L p .67789 .88417 L F P
0 g
s
.522 .408 .665 r
.67789 .88417 m .67139 .88189 L .671 .88002 L p F P
0 g
s
.528 .424 .68 r
.6798 .87117 m .68081 .8755 L .671 .88002 L p F P
0 g
s
.528 .424 .68 r
.67606 .87012 m .6798 .87117 L p .671 .88002 L F P
0 g
s
.62 .072 0 r
.2167 .97303 m .2171 .97332 L .21348 .97344 L p F P
0 g
s
.62 .072 0 r
.21348 .97344 m .21011 .97128 L .2167 .97303 L p F P
0 g
s
.881 .818 .782 r
.73772 .159 m .73848 .15802 L .73591 .1546 L p F P
0 g
s
.811 .804 .844 r
.69164 .21327 m .68648 .21771 L .68382 .21426 L p F P
0 g
s
0 0 0 r
.57253 .97821 m .57246 .97823 L .56103 .98076 L p F P
0 g
s
.158 .693 .697 r
.55857 .98128 m .56103 .98076 L .57246 .97823 L p F P
0 g
s
0 0 0 r
.56103 .98076 m .55857 .98128 L .54746 .98361 L p F P
0 g
s
.93 .811 .707 r
.7519 .11472 m .75108 .11632 L .75332 .12041 L p F P
0 g
s
.918 .812 .725 r
.74783 .12213 m .75008 .12621 L .75332 .12041 L p F P
0 g
s
.918 .812 .725 r
.75332 .12041 m .75108 .11632 L .74783 .12213 L p F P
0 g
s
.229 0 0 r
.58644 .97357 m .58697 .97299 L .59805 .97009 L p F P
0 g
s
.813 .73 .772 r
.15089 .81021 m .14937 .80837 L .14869 .80914 L closepath p F P
0 g
s
.629 .776 .951 r
.39375 .99135 m .40458 .98851 L .40771 .99115 L p F P
0 g
s
.651 .757 .927 r
.40458 .98851 m .39375 .99135 L .3906 .98875 L p F P
0 g
s
.255 0 0 r
.3525 .74044 m .35517 .74057 L .35183 .74091 L p F P
0 g
s
.407 .77 .994 r
.29194 .98846 m .29291 .98845 L .28956 .98676 L p F P
0 g
s
.407 .77 .994 r
.28956 .98676 m .28402 .98709 L .29194 .98846 L p F P
0 g
s
.784 .74 .813 r
.17916 .77172 m .18236 .769 L .18747 .77142 L p F P
0 g
s
.783 .742 .816 r
.1901 .76253 m .18236 .769 L .18747 .77142 L p F P
0 g
s
.783 .742 .816 r
.18747 .77142 m .1935 .76638 L .1901 .76253 L p F P
0 g
s
.599 .603 .827 r
.60525 .76367 m .60473 .76265 L .6084 .7621 L closepath p F P
0 g
s
.979 .76 .537 r
.75401 .07733 m .75398 .07751 L .7565 .08156 L p F P
0 g
s
.967 .776 .592 r
.75265 .08255 m .75518 .08659 L .7565 .08156 L p F P
0 g
s
.967 .776 .592 r
.7565 .08156 m .75398 .07751 L .75265 .08255 L p F P
0 g
s
.847 .661 .651 r
.13348 .89471 m .13444 .89226 L .13248 .88729 L p F P
0 g
s
.815 .805 .842 r
.69164 .21327 m .6975 .20811 L .69486 .20466 L p F P
0 g
s
.815 .805 .842 r
.69486 .20466 m .68972 .20918 L .69164 .21327 L p F P
0 g
s
.811 .804 .844 r
.68382 .21426 m .68972 .20918 L .69164 .21327 L p F P
0 g
s
.881 .818 .782 r
.73591 .1546 m .73569 .15489 L .73772 .159 L p F P
0 g
s
.872 .816 .791 r
.73036 .16149 m .73242 .16559 L .73772 .159 L p F P
0 g
s
.872 .816 .791 r
.73772 .159 m .73569 .15489 L .73036 .16149 L p F P
0 g
s
.842 .598 .569 r
.15014 .92629 m .1444 .92423 L .14516 .91862 L p F P
0 g
s
.845 .6 .569 r
.14063 .91696 m .14516 .91862 L .1444 .92423 L p F P
0 g
s
.843 .617 .596 r
.14018 .91336 m .14073 .91081 L p .14516 .91862 L F P
0 g
s
.843 .617 .596 r
.14516 .91862 m .14063 .91696 L .14018 .91336 L p F P
0 g
s
.833 .809 .828 r
.70587 .1944 m .70663 .19366 L .7086 .19775 L p F P
0 g
s
.833 .809 .828 r
.7086 .19775 m .70849 .19785 L .70587 .1944 L p F P
0 g
s
.827 .808 .833 r
.70048 .20537 m .70849 .19785 L .70587 .1944 L p F P
0 g
s
.803 .733 .787 r
.16237 .7946 m .16053 .79646 L .1571 .79239 L p F P
0 g
s
.803 .733 .787 r
.1571 .79239 m .15732 .79217 L .16237 .7946 L p F P
0 g
s
.8 .735 .792 r
.16237 .7946 m .15732 .79217 L .16504 .78464 L p F P
0 g
s
.609 .626 .843 r
.59897 .75162 m .58777 .75367 L .58488 .74848 L p F P
0 g
s
.846 .62 .595 r
.14018 .91336 m .14073 .91081 L .13981 .91046 L closepath p F P
0 g
s
.822 .719 .751 r
.1415 .82604 m .14191 .82553 L .14066 .82494 L closepath p F P
0 g
s
.816 .724 .763 r
.13808 .82169 m .14268 .81616 L p .14191 .82553 L F P
0 g
s
.816 .724 .763 r
.14191 .82553 m .14066 .82494 L .13808 .82169 L p F P
0 g
s
.842 .577 .537 r
.15569 .9338 m .1499 .93176 L .15014 .92629 L p F P
0 g
s
.844 .578 .537 r
.1444 .92423 m .15014 .92629 L .1499 .93176 L p F P
0 g
s
.808 .733 .782 r
.15535 .80192 m .16053 .79646 L .1571 .79239 L p F P
0 g
s
.827 .808 .833 r
.70587 .1944 m .69853 .20129 L .70048 .20537 L p F P
0 g
s
.823 .807 .836 r
.69486 .20466 m .69853 .20129 L .70048 .20537 L p F P
0 g
s
.823 .807 .836 r
.70048 .20537 m .6975 .20811 L .69486 .20466 L p F P
0 g
s
.433 .625 .934 r
.59187 .24043 m .58998 .24027 L .59261 .24411 L p F P
0 g
s
.433 .625 .934 r
.59261 .24411 m .5947 .24427 L .59187 .24043 L p F P
0 g
s
.769 .785 .867 r
.65582 .23555 m .65054 .23916 L .64781 .23559 L p F P
0 g
s
.63 .776 .951 r
.40771 .99115 m .41857 .98829 L .42167 .99093 L p F P
0 g
s
.651 .755 .926 r
.41857 .98829 m .40771 .99115 L .40458 .98851 L p F P
0 g
s
.488 0 0 r
.23057 .97819 m .22412 .97655 L .2171 .97332 L p F P
0 g
s
.519 0 0 r
.22412 .97655 m .2171 .97332 L .21348 .97344 L p F P
0 g
s
.826 .719 .747 r
.13672 .83232 m .1415 .82604 L .14066 .82494 L p F P
0 g
s
.775 .742 .823 r
.19752 .76319 m .1935 .76638 L .1901 .76253 L p F P
0 g
s
.522 .408 .665 r
.67239 .88667 m .67139 .88189 L .67789 .88417 L closepath p F P
0 g
s
.569 .543 .786 r
.65307 .79077 m .65597 .79779 L .64459 .7982 L p F P
0 g
s
.569 .543 .786 r
.6482 .79092 m .65307 .79077 L p .64459 .7982 L F P
0 g
s
.569 .543 .786 r
.64459 .7982 m .64278 .7938 L .6482 .79092 L p F P
0 g
s
.583 .567 .802 r
.62627 .77891 m .63593 .77808 L p .63866 .78451 L F P
0 g
s
.581 .569 .805 r
.63593 .77808 m .62627 .77891 L .63439 .77467 L closepath p F P
0 g
s
.586 .579 .812 r
.63305 .77179 m .63439 .77467 L .62627 .77891 L p F P
0 g
s
.586 .579 .812 r
.62174 .77294 m .63305 .77179 L p .62627 .77891 L F P
0 g
s
.778 .361 .258 r
.18311 .95739 m .18342 .95718 L p .19242 .96348 L F P
0 g
s
.803 .417 .324 r
.18311 .95739 m .18293 .95703 L .18342 .95718 L closepath p F P
0 g
s
.599 .607 .831 r
.6084 .7621 m .60473 .76265 L .60185 .7571 L p F P
0 g
s
.366 .829 .908 r
.55857 .98128 m .54746 .98361 L .54458 .98349 L p F P
0 g
s
.316 .803 .876 r
.53349 .98577 m .54458 .98349 L .54746 .98361 L p F P
0 g
s
.635 .689 .883 r
.5399 .73794 m .55099 .73499 L p .5525 .73954 L F P
0 g
s
.639 .702 .891 r
.55099 .73499 m .5399 .73794 L .53697 .73407 L p F P
0 g
s
.842 .682 .684 r
.13121 .87185 m .1281 .87792 L .12482 .87186 L p F P
0 g
s
.842 .682 .684 r
.12482 .87186 m .12598 .86957 L .13121 .87185 L p F P
0 g
s
.838 .688 .697 r
.13121 .87185 m .12598 .86957 L .12951 .86323 L p F P
0 g
s
.852 .64 .615 r
.13151 .90063 m .13686 .90283 L .13527 .90865 L p F P
0 g
s
.847 .649 .635 r
.13348 .89471 m .13151 .90063 L .13686 .90283 L p F P
0 g
s
.85 .637 .614 r
.13981 .91046 m .13527 .90865 L .13686 .90283 L p F P
0 g
s
.377 .774 .986 r
.30682 .98912 m .3035 .98715 L .29291 .98845 L p F P
0 g
s
.563 .785 .982 r
.3035 .98715 m .29291 .98845 L .28956 .98676 L p F P
0 g
s
.621 .65 .858 r
.58199 .74343 m .57083 .74584 L .56793 .74109 L p F P
0 g
s
.899 .816 .757 r
.74476 .14229 m .74656 .13958 L .74401 .1361 L p F P
0 g
s
.847 .661 .651 r
.13248 .88729 m .13054 .88646 L p .13348 .89471 L F P
0 g
s
.845 .671 .667 r
.13248 .88729 m .1313 .88474 L .13054 .88646 L closepath p F P
0 g
s
.841 .551 .499 r
.16182 .94115 m .15601 .93913 L .15569 .9338 L p F P
0 g
s
.842 .552 .497 r
.1499 .93176 m .15569 .9338 L .15601 .93913 L p F P
0 g
s
.649 .756 .928 r
.43256 .9881 m .42167 .99093 L .41857 .98829 L p F P
0 g
s
.628 .779 .953 r
.42167 .99093 m .43256 .9881 L .43564 .9907 L p F P
0 g
s
.8 .399 .293 r
.18293 .95703 m .18311 .95739 L .17927 .95942 L p F P
0 g
s
.8 .399 .293 r
.17927 .95942 m .17684 .95512 L .18293 .95703 L p F P
0 g
s
.754 .749 .848 r
.22604 .74281 m .22223 .74531 L .22754 .74769 L p F P
0 g
s
.754 .749 .848 r
.22754 .74769 m .2294 .74645 L .22604 .74281 L p F P
0 g
s
.754 .747 .846 r
.21523 .75 m .22223 .74531 L .22754 .74769 L p F P
0 g
s
.775 .742 .823 r
.1901 .76253 m .19232 .76078 L .19752 .76319 L p F P
0 g
s
.774 .745 .826 r
.20099 .75407 m .19232 .76078 L .19752 .76319 L p F P
0 g
s
.774 .745 .826 r
.19752 .76319 m .20439 .75785 L .20099 .75407 L p F P
0 g
s
.811 .732 .778 r
.15535 .80192 m .14937 .80837 L .14593 .80428 L p F P
0 g
s
.811 .732 .778 r
.14593 .80428 m .15039 .79947 L .15535 .80192 L p F P
0 g
s
.808 .733 .782 r
.1571 .79239 m .15039 .79947 L .15535 .80192 L p F P
0 g
s
.85 .623 .593 r
.13981 .91046 m .13527 .90865 L p .13952 .91653 L F P
0 g
s
.85 .623 .593 r
.13952 .91653 m .14018 .91336 L .13981 .91046 L p F P
0 g
s
.161 .7 .742 r
.45299 .74009 m .45501 .73984 L .46579 .73801 L p F P
0 g
s
.2 0 0 r
.26177 .98441 m .25833 .98316 L .24797 .98203 L p F P
0 g
s
.256 .702 .958 r
.24797 .98203 m .25833 .98316 L .25728 .98268 L p F P
0 g
s
.256 .702 .958 r
.24448 .98121 m .24797 .98203 L p .25728 .98268 L F P
0 g
s
.834 .71 .728 r
.1323 .84801 m .1334 .84639 L .13001 .8416 L p F P
0 g
s
.624 .784 .958 r
.43564 .9907 m .44655 .98792 L .44961 .99044 L p F P
0 g
s
.645 .759 .932 r
.44655 .98792 m .43564 .9907 L .43256 .9881 L p F P
0 g
s
.74 .75 .861 r
.24017 .73993 m .2294 .74645 L .22604 .74281 L p F P
0 g
s
.778 .361 .258 r
.19242 .96348 m .18603 .96166 L .18311 .95739 L p F P
0 g
s
.777 .361 .261 r
.18603 .96166 m .18311 .95739 L .17927 .95942 L p F P
0 g
s
.826 .719 .747 r
.14066 .82494 m .13694 .82311 L p .13672 .83232 L F P
0 g
s
.823 .724 .756 r
.14066 .82494 m .13808 .82169 L .13694 .82311 L closepath p F P
0 g
s
.851 .654 .635 r
.1282 .89247 m .13348 .89471 L .13151 .90063 L p F P
0 g
s
.847 .661 .651 r
.13054 .88646 m .1282 .89247 L .13348 .89471 L p F P
0 g
s
.77 .787 .867 r
.65582 .23555 m .66165 .23151 L .65894 .22796 L p F P
0 g
s
.77 .787 .867 r
.65894 .22796 m .65381 .2315 L .65582 .23555 L p F P
0 g
s
.769 .785 .867 r
.64781 .23559 m .65381 .2315 L .65582 .23555 L p F P
0 g
s
.846 .673 .667 r
.13054 .88646 m .1313 .88474 L .12823 .87818 L p F P
0 g
s
.634 .681 .877 r
.5539 .73918 m .5525 .73954 L .5538 .73903 L closepath p F P
0 g
s
.635 .689 .883 r
.55099 .73499 m .5538 .73903 L .5525 .73954 L p F P
0 g
s
.839 .52 .449 r
.16182 .94115 m .16266 .94594 L .16245 .94623 L p F P
0 g
s
.839 .52 .449 r
.15601 .93913 m .16182 .94115 L p .16245 .94623 L F P
0 g
s
.573 .553 .794 r
.64278 .7938 m .6417 .79125 L .6482 .79092 L closepath p F P
0 g
s
.949 .794 .655 r
.75143 .09712 m .75387 .10117 L .75591 .09584 L p F P
0 g
s
.949 .794 .655 r
.75591 .09584 m .75348 .09179 L .75143 .09712 L p F P
0 g
s
.435 .847 .965 r
.53139 .98527 m .53349 .98577 L .54458 .98349 L p F P
0 g
s
.376 .826 .937 r
.53349 .98577 m .53139 .98527 L .51952 .98734 L p F P
0 g
s
.617 .791 .966 r
.44961 .99044 m .46055 .98774 L .46359 .99013 L p F P
0 g
s
.64 .765 .939 r
.46055 .98774 m .44961 .99044 L .44655 .98792 L p F P
0 g
s
.867 .815 .795 r
.72511 .16782 m .73036 .16149 L .73242 .16559 L p F P
0 g
s
.867 .815 .795 r
.73242 .16559 m .7277 .17128 L .72511 .16782 L p F P
0 g
s
.764 .745 .835 r
.20888 .75456 m .20439 .75785 L .20099 .75407 L p F P
0 g
s
.838 .706 .718 r
.1273 .84563 m .1323 .84801 L .12821 .8545 L p F P
0 g
s
.834 .71 .728 r
.13001 .8416 m .1273 .84563 L .1323 .84801 L p F P
0 g
s
.899 .816 .757 r
.74401 .1361 m .74262 .13819 L .74476 .14229 L p F P
0 g
s
.89 .815 .767 r
.7382 .14445 m .74036 .14854 L .74476 .14229 L p F P
0 g
s
.89 .815 .767 r
.74476 .14229 m .74262 .13819 L .7382 .14445 L p F P
0 g
s
.815 .733 .774 r
.14869 .80914 m .14937 .80837 L .14593 .80428 L p F P
0 g
s
.229 0 0 r
.59805 .97009 m .59761 .97059 L .58644 .97357 L p F P
0 g
s
.085 0 0 r
.58372 .97551 m .58644 .97357 L .59761 .97059 L p F P
0 g
s
.365 0 .199 r
.6111 .96353 m .61142 .96275 L .62259 .95838 L p F P
0 g
s
.404 .061 .267 r
.62327 .95617 m .62259 .95838 L .61142 .96275 L p F P
0 g
s
.561 .788 .984 r
.30682 .98912 m .31747 .98723 L .32076 .98944 L p F P
0 g
s
.605 .78 .964 r
.31747 .98723 m .30682 .98912 L .3035 .98715 L p F P
0 g
s
.69 .187 .04 r
.21011 .97128 m .20344 .96954 L .20001 .96673 L p F P
0 g
s
.691 .192 .053 r
.20344 .96954 m .20001 .96673 L .1963 .96755 L p F P
0 g
s
.818 .729 .767 r
.1438 .80668 m .14869 .80914 L .14268 .81616 L p F P
0 g
s
.815 .733 .774 r
.14593 .80428 m .1438 .80668 L .14869 .80914 L p F P
0 g
s
0 .494 .738 r
.23838 .97975 m .24448 .98121 L .241 .98005 L p F P
0 g
s
.725 .751 .873 r
.24017 .73993 m .24555 .73703 L .25117 .73932 L p F P
0 g
s
.728 .756 .874 r
.25091 .73418 m .24555 .73703 L .25117 .73932 L p F P
0 g
s
.728 .756 .874 r
.25117 .73932 m .25426 .73763 L .25091 .73418 L p F P
0 g
s
.514 .39 .649 r
.6736 .89313 m .67239 .88667 L .67789 .88417 L p F P
0 g
s
.492 .309 .559 r
.666 .91562 m .66082 .91768 L .66245 .92284 L p F P
0 g
s
.506 .338 .587 r
.66082 .91768 m .666 .91562 L .66541 .90973 L p F P
0 g
s
.495 .31 .559 r
.65619 .92529 m .66245 .92284 L .66082 .91768 L p F P
0 g
s
.585 .58 .813 r
.63017 .76565 m .63305 .77179 L .62174 .77294 L p F P
0 g
s
.585 .58 .813 r
.62675 .766 m .63017 .76565 L p .62174 .77294 L F P
0 g
s
.585 .58 .813 r
.62174 .77294 m .62012 .76949 L .62675 .766 L p F P
0 g
s
.606 .802 .975 r
.46359 .99013 m .47455 .98751 L .47757 .98973 L p F P
0 g
s
.633 .774 .948 r
.47455 .98751 m .46359 .99013 L .46055 .98774 L p F P
0 g
s
.849 .622 .593 r
.14063 .91696 m .14018 .91336 L .13952 .91653 L closepath p F P
0 g
s
.635 .778 .949 r
.28229 .735 m .29293 .73189 L .29625 .73465 L p F P
0 g
s
.604 .783 .966 r
.29293 .73189 m .28229 .735 L .27896 .73189 L p F P
0 g
s
.679 .766 .917 r
.26829 .73601 m .27896 .73189 L .28229 .735 L p F P
0 g
s
.828 .716 .741 r
.13175 .82991 m .13672 .83232 L .13179 .83904 L p F P
0 g
s
.826 .719 .747 r
.13694 .82311 m .13175 .82991 L .13672 .83232 L p F P
0 g
s
.542 .465 .718 r
.67364 .84809 m .67155 .84781 L .67331 .84696 L closepath p F P
0 g
s
.549 .478 .728 r
.67096 .83934 m .67331 .84696 L .67155 .84781 L p F P
0 g
s
.458 0 0 r
.36732 .74313 m .36245 .7427 L .35517 .74057 L p F P
0 g
s
.395 0 0 r
.36245 .7427 m .35517 .74057 L .35183 .74091 L p F P
0 g
s
.507 0 0 r
.34358 .73918 m .35183 .74091 L .35103 .74125 L p F P
0 g
s
.666 .771 .928 r
.27896 .73189 m .26829 .73601 L .26496 .73269 L p F P
0 g
s
.704 .758 .894 r
.25426 .73763 m .26496 .73269 L .26829 .73601 L p F P
0 g
s
.598 .711 .923 r
.5947 .24427 m .60595 .2419 L .60875 .24568 L p F P
0 g
s
.595 .71 .924 r
.60595 .2419 m .5947 .24427 L .59187 .24043 L p F P
0 g
s
.488 .846 .993 r
.51951 .98734 m .51952 .98734 L p .50553 .98841 L F P
0 g
s
.445 .849 .971 r
.51952 .98734 m .51952 .98734 L .53139 .98527 L p F P
0 g
s
.445 .849 .971 r
.53139 .98527 m .53058 .98502 L .51952 .98734 L p F P
0 g
s
.557 .845 .998 r
.53058 .98502 m .51952 .98734 L .51657 .98604 L p F P
0 g
s
.488 .846 .993 r
.51952 .98734 m .51657 .98604 L .50553 .98841 L p F P
0 g
s
.479 .276 .525 r
.66245 .92284 m .65619 .92529 L .65629 .93073 L p F P
0 g
s
.84 .693 .701 r
.12438 .86091 m .12951 .86323 L .12598 .86957 L p F P
0 g
s
.838 .697 .708 r
.12951 .86323 m .12438 .86091 L .12821 .8545 L p F P
0 g
s
.628 .662 .864 r
.5539 .73918 m .56503 .73649 L .56793 .74109 L p F P
0 g
s
.63 .679 .878 r
.56383 .73469 m .56503 .73649 L .5539 .73918 L p F P
0 g
s
.63 .679 .878 r
.5539 .73918 m .5538 .73903 L .56383 .73469 L p F P
0 g
s
.59 .817 .986 r
.47757 .98973 m .48856 .9872 L .49155 .98917 L p F P
0 g
s
.623 .787 .96 r
.48856 .9872 m .47757 .98973 L .47455 .98751 L p F P
0 g
s
.507 .356 .61 r
.67478 .9006 m .67543 .90551 L .66541 .90973 L p F P
0 g
s
.507 .356 .61 r
.67379 .89978 m .67478 .9006 L p .66541 .90973 L F P
0 g
s
.495 .33 .587 r
.666 .91562 m .66541 .90973 L .67543 .90551 L p F P
0 g
s
.851 .666 .652 r
.12533 .88419 m .13054 .88646 L .1282 .89247 L p F P
0 g
s
.846 .673 .667 r
.12802 .87809 m .12533 .88419 L .13054 .88646 L p F P
0 g
s
.846 .673 .667 r
.12823 .87818 m .12802 .87809 L p .13054 .88646 L F P
0 g
s
.573 .554 .795 r
.6482 .79092 m .6417 .79125 L .63881 .7845 L p F P
0 g
s
.549 .789 .988 r
.29625 .73465 m .30685 .73278 L .31017 .73502 L p F P
0 g
s
.461 .779 .998 r
.30685 .73278 m .29625 .73465 L .29293 .73189 L p F P
0 g
s
.764 .745 .835 r
.20099 .75407 m .20362 .75216 L .20888 .75456 L p F P
0 g
s
.764 .748 .838 r
.21184 .7463 m .20362 .75216 L .20888 .75456 L p F P
0 g
s
.764 .748 .838 r
.20888 .75456 m .21523 .75 L .21184 .7463 L p F P
0 g
s
.632 .685 .882 r
.56213 .73217 m .56383 .73469 L .5538 .73903 L p F P
0 g
s
.632 .685 .882 r
.5538 .73903 m .55099 .73499 L .56213 .73217 L p F P
0 g
s
.931 .805 .698 r
.74934 .11107 m .75149 .10664 L .75384 .11071 L p F P
0 g
s
.931 .805 .698 r
.75384 .11071 m .7519 .11472 L .74934 .11107 L p F P
0 g
s
.567 .833 .996 r
.49155 .98917 m .50256 .98673 L .50553 .98841 L p F P
0 g
s
.61 .803 .974 r
.50256 .98673 m .49155 .98917 L .48856 .9872 L p F P
0 g
s
.589 .823 .988 r
.51657 .98604 m .50553 .98841 L .50256 .98673 L p F P
0 g
s
.91 .811 .737 r
.74429 .12805 m .74655 .13213 L .75008 .12621 L p F P
0 g
s
.91 .811 .737 r
.75008 .12621 m .74783 .12213 L .74429 .12805 L p F P
0 g
s
.392 .056 .271 r
.62259 .95838 m .62327 .95617 L .63392 .95276 L p F P
0 g
s
.436 .138 .36 r
.6348 .9482 m .63392 .95276 L .62327 .95617 L p F P
0 g
s
.784 .791 .859 r
.6689 .22611 m .66165 .23151 L .65894 .22796 L p F P
0 g
s
.598 .784 .969 r
.32076 .98944 m .33146 .9871 L .33471 .98952 L p F P
0 g
s
.631 .772 .948 r
.33146 .9871 m .32076 .98944 L .31747 .98723 L p F P
0 g
s
.365 .767 .985 r
.28402 .98709 m .28956 .98676 L p .27564 .98594 L F P
0 g
s
.365 .767 .985 r
.27564 .98594 m .27592 .98605 L .28402 .98709 L p F P
0 g
s
.595 .597 .824 r
.61598 .76107 m .6084 .7621 L .61486 .75882 L closepath p F P
0 g
s
.599 .607 .831 r
.6131 .7554 m .61486 .75882 L .6084 .7621 L p F P
0 g
s
.599 .607 .831 r
.60185 .7571 m .6131 .7554 L p .6084 .7621 L F P
0 g
s
.75 .776 .874 r
.63716 .24224 m .63667 .24254 L .63392 .23889 L p F P
0 g
s
.723 .767 .888 r
.62274 .24478 m .63392 .23889 L .63667 .24254 L p F P
0 g
s
.817 .457 .375 r
.17684 .95512 m .17076 .95319 L .16888 .94825 L p F P
0 g
s
.817 .454 .368 r
.16275 .94633 m .16888 .94825 L .17076 .95319 L p F P
0 g
s
.824 .498 .437 r
.16888 .94825 m .16275 .94633 L .16266 .94594 L p F P
0 g
s
.862 .815 .802 r
.72683 .17229 m .7277 .17128 L .72511 .16782 L p F P
0 g
s
.698 .762 .901 r
.26496 .73269 m .25426 .73763 L .25091 .73418 L p F P
0 g
s
.751 .776 .874 r
.63716 .24224 m .64781 .23559 L .64508 .23197 L p F P
0 g
s
.751 .776 .874 r
.64508 .23197 m .63492 .23827 L .63716 .24224 L p F P
0 g
s
.75 .776 .874 r
.63392 .23889 m .63492 .23827 L .63716 .24224 L p F P
0 g
s
.42 .123 .353 r
.64529 .9446 m .6348 .9482 L .63392 .95276 L p F P
0 g
s
.457 .198 .431 r
.64578 .9397 m .64529 .9446 L .6348 .9482 L p F P
0 g
s
.862 .815 .802 r
.72511 .16782 m .7248 .16819 L .72683 .17229 L p F P
0 g
s
.854 .813 .809 r
.71851 .17515 m .72057 .17924 L .72683 .17229 L p F P
0 g
s
.854 .813 .809 r
.72683 .17229 m .7248 .16819 L .71851 .17515 L p F P
0 g
s
.821 .727 .761 r
.14268 .81616 m .13808 .82169 L .13464 .81746 L p F P
0 g
s
.821 .727 .761 r
.13464 .81746 m .13774 .81372 L .14268 .81616 L p F P
0 g
s
.818 .729 .767 r
.14268 .81616 m .13774 .81372 L .1438 .80668 L p F P
0 g
s
.375 .759 .989 r
.32167 .735 m .31934 .73461 L .31017 .73502 L p F P
0 g
s
.44 .745 .992 r
.31934 .73461 m .31017 .73502 L .30685 .73278 L p F P
0 g
s
.621 .777 .956 r
.33471 .98952 m .34545 .98683 L .34867 .98943 L p F P
0 g
s
.647 .763 .934 r
.34545 .98683 m .33471 .98952 L .33146 .9871 L p F P
0 g
s
.844 .682 .681 r
.12823 .87818 m .1281 .87792 L .12802 .87809 L closepath p F P
0 g
s
.263 0 .007 r
.62187 .96027 m .6111 .96353 L .609 .96703 L p F P
0 g
s
.365 0 .199 r
.62259 .95838 m .62187 .96027 L .6111 .96353 L p F P
0 g
s
.306 0 .059 r
.6111 .96353 m .609 .96703 L .59805 .97009 L p F P
0 g
s
.57 .001 0 r
.21011 .97128 m .21348 .97344 L .20988 .97314 L p F P
0 g
s
.57 .001 0 r
.20988 .97314 m .20344 .96954 L .21011 .97128 L p F P
0 g
s
.845 .6 .569 r
.1444 .92423 m .14064 .92286 L .14063 .91696 L p F P
0 g
s
.852 .607 .567 r
.13952 .91653 m .14063 .91696 L .14064 .92286 L p F P
0 g
s
.539 .473 .73 r
.67331 .84696 m .67096 .83934 L .67255 .83853 L p F P
0 g
s
.544 .485 .74 r
.67096 .83934 m .67064 .83834 L .67255 .83853 L closepath p F P
0 g
s
.544 .486 .741 r
.67255 .83853 m .67064 .83834 L .66841 .83151 L p F P
0 g
s
.729 .242 .084 r
.19242 .96348 m .1963 .96755 L .19583 .9676 L p F P
0 g
s
.729 .242 .084 r
.18603 .96166 m .19242 .96348 L p .19583 .9676 L F P
0 g
s
.846 .684 .682 r
.12802 .87809 m .1281 .87792 L .12482 .87186 L p F P
0 g
s
.589 .589 .82 r
.62012 .76949 m .61886 .76691 L .62675 .766 L closepath p F P
0 g
s
.039 .596 .815 r
.33796 .73807 m .33497 .73782 L .33969 .73845 L closepath p F P
0 g
s
.507 0 0 r
.33796 .73807 m .33969 .73845 L p .35103 .74125 L F P
0 g
s
.85 .677 .667 r
.1229 .87578 m .12802 .87809 L .12533 .88419 L p F P
0 g
s
.846 .684 .682 r
.12482 .87186 m .1229 .87578 L .12802 .87809 L p F P
0 g
s
.753 .749 .849 r
.22223 .74531 m .21523 .75 L .21184 .7463 L p F P
0 g
s
.544 .486 .741 r
.66841 .83151 m .67197 .82966 L p .67255 .83853 L F P
0 g
s
.548 .497 .75 r
.66841 .83151 m .66767 .82935 L .67197 .82966 L closepath p F P
0 g
s
.609 .626 .843 r
.58488 .74848 m .59609 .7464 L .59897 .75162 L p F P
0 g
s
.611 .632 .847 r
.5932 .74126 m .59609 .7464 L .58488 .74848 L p F P
0 g
s
.611 .632 .847 r
.58767 .7423 m .5932 .74126 L p .58488 .74848 L F P
0 g
s
.611 .632 .847 r
.58488 .74848 m .58273 .74469 L .58767 .7423 L p F P
0 g
s
.956 .784 .628 r
.75095 .08775 m .75348 .09179 L .75518 .08659 L p F P
0 g
s
.956 .784 .628 r
.75518 .08659 m .75265 .08255 L .75095 .08775 L p F P
0 g
s
.271 .726 .955 r
.26794 .98441 m .26177 .98441 L .25833 .98316 L p F P
0 g
s
.106 .639 .865 r
.26177 .98441 m .26794 .98441 L .2753 .98593 L p F P
0 g
s
.599 .609 .833 r
.61022 .74988 m .6131 .7554 L .60185 .7571 L p F P
0 g
s
.599 .609 .833 r
.6017 .75117 m .61022 .74988 L p .60185 .7571 L F P
0 g
s
.599 .609 .833 r
.60185 .7571 m .59937 .75236 L .6017 .75117 L p F P
0 g
s
.534 .46 .719 r
.67331 .84696 m .68287 .84207 L p .68437 .84989 L F P
0 g
s
.534 .46 .719 r
.68437 .84989 m .67364 .84809 L .67331 .84696 L p F P
0 g
s
.539 .473 .73 r
.68217 .83984 m .68287 .84207 L .67331 .84696 L p F P
0 g
s
.539 .473 .73 r
.67255 .83853 m .68217 .83984 L p .67331 .84696 L F P
0 g
s
.548 .497 .751 r
.67197 .82966 m .66767 .82935 L .66565 .82347 L p F P
0 g
s
.644 .762 .934 r
.50898 .73392 m .52002 .73067 L .52297 .7337 L p F P
0 g
s
.637 .805 .964 r
.52002 .73067 m .50898 .73392 L .50601 .73154 L p F P
0 g
s
.631 .806 .967 r
.49499 .73472 m .50601 .73154 L .50898 .73392 L p F P
0 g
s
.589 .86 .994 r
.50601 .73154 m .49499 .73472 L .492 .73313 L p F P
0 g
s
.579 .852 .995 r
.481 .73604 m .492 .73313 L .49499 .73472 L p F P
0 g
s
.884 .814 .774 r
.73353 .15081 m .7382 .14445 L .74036 .14854 L p F P
0 g
s
.884 .814 .774 r
.7346 .1528 m .73353 .15081 L p .74036 .14854 L F P
0 g
s
.884 .814 .774 r
.74036 .14854 m .73591 .1546 L .7346 .1528 L p F P
0 g
s
.786 .793 .858 r
.6689 .22611 m .67275 .2232 L .67006 .21967 L p F P
0 g
s
.786 .793 .858 r
.67006 .21967 m .6669 .22205 L .6689 .22611 L p F P
0 g
s
.784 .791 .859 r
.65894 .22796 m .6669 .22205 L .6689 .22611 L p F P
0 g
s
.535 .46 .718 r
.67546 .85437 m .67364 .84809 L .68437 .84989 L closepath p F P
0 g
s
.635 .77 .944 r
.34867 .98943 m .35944 .98649 L .36264 .98924 L p F P
0 g
s
.657 .755 .923 r
.35944 .98649 m .34867 .98943 L .34545 .98683 L p F P
0 g
s
.526 .423 .681 r
.6798 .87117 m .67606 .87012 L .67921 .86865 L closepath p F P
0 g
s
.534 .439 .693 r
.67743 .8616 m .67921 .86865 L .67606 .87012 L p F P
0 g
s
.828 .716 .741 r
.13179 .83904 m .12677 .83665 L .13175 .82991 L p F P
0 g
s
.832 .712 .731 r
.13179 .83904 m .13001 .8416 L .1266 .83689 L p F P
0 g
s
.832 .712 .731 r
.1266 .83689 m .12677 .83665 L .13179 .83904 L p F P
0 g
s
.794 .742 .804 r
.17334 .77692 m .16817 .78166 L .16473 .77778 L p F P
0 g
s
.8 .742 .799 r
.16504 .78464 m .16817 .78166 L .16473 .77778 L p F P
0 g
s
.794 .742 .804 r
.16473 .77778 m .16839 .77445 L .17334 .77692 L p F P
0 g
s
.792 .743 .808 r
.17574 .76788 m .16839 .77445 L .17334 .77692 L p F P
0 g
s
.792 .743 .808 r
.17334 .77692 m .17916 .77172 L .17574 .76788 L p F P
0 g
s
.548 .497 .751 r
.66565 .82347 m .67004 .82114 L p .67197 .82966 L F P
0 g
s
.552 .508 .76 r
.66565 .82347 m .66472 .82088 L .67004 .82114 L closepath p F P
0 g
s
.84 .701 .71 r
.12318 .85213 m .12821 .8545 L .12438 .86091 L p F P
0 g
s
.838 .706 .718 r
.12821 .8545 m .12318 .85213 L .1273 .84563 L p F P
0 g
s
.798 .74 .798 r
.16015 .78214 m .16504 .78464 L .15732 .79217 L p F P
0 g
s
.8 .742 .799 r
.16473 .77778 m .16015 .78214 L .16504 .78464 L p F P
0 g
s
.785 .743 .814 r
.18236 .769 m .17916 .77172 L .17574 .76788 L p F P
0 g
s
.644 .728 .909 r
.52297 .7337 m .53404 .73052 L .53697 .73407 L p F P
0 g
s
.646 .757 .93 r
.53404 .73052 m .52297 .7337 L .52002 .73067 L p F P
0 g
s
.495 .875 .974 r
.47914 .73557 m .481 .73604 L .492 .73313 L p F P
0 g
s
.521 .868 .99 r
.481 .73604 m .47914 .73557 L .46716 .73781 L p F P
0 g
s
.74 .75 .861 r
.22604 .74281 m .23681 .73634 L .24017 .73993 L p F P
0 g
s
.72 .752 .877 r
.24555 .73703 m .24017 .73993 L .23681 .73634 L p F P
0 g
s
.722 .765 .887 r
.63392 .23889 m .62274 .24478 L .61996 .24107 L p F P
0 g
s
.683 .75 .902 r
.60875 .24568 m .61996 .24107 L .62274 .24478 L p F P
0 g
s
.849 .811 .812 r
.71421 .17979 m .71851 .17515 L .72057 .17924 L p F P
0 g
s
.849 .811 .812 r
.72057 .17924 m .71682 .18328 L .71421 .17979 L p F P
0 g
s
.852 .607 .567 r
.14064 .92286 m .13877 .92213 L .13952 .91653 L p F P
0 g
s
.855 .61 .567 r
.13409 .91436 m .13952 .91653 L .13877 .92213 L p F P
0 g
s
.85 .623 .593 r
.13527 .90865 m .13409 .91436 L .13952 .91653 L p F P
0 g
s
.161 .7 .742 r
.46579 .73801 m .467 .73779 L p .45299 .74009 L F P
0 g
s
.339 .81 .913 r
.467 .73779 m .46579 .73801 L .46716 .73781 L closepath p F P
0 g
s
.526 .01 0 r
.38271 .74418 m .37259 .74361 L .36907 .74239 L p F P
0 g
s
.505 0 0 r
.37259 .74361 m .36732 .74313 L .36907 .74239 L closepath p F P
0 g
s
.682 .748 .901 r
.61996 .24107 m .60875 .24568 L .60595 .2419 L p F P
0 g
s
.644 .764 .936 r
.36264 .98924 m .37345 .98613 L .37662 .989 L p F P
0 g
s
.662 .748 .914 r
.37345 .98613 m .36264 .98924 L .35944 .98649 L p F P
0 g
s
.844 .578 .537 r
.1499 .93176 m .14415 .92971 L .1444 .92423 L p F P
0 g
s
.846 .58 .537 r
.14064 .92286 m .1444 .92423 L .14415 .92971 L p F P
0 g
s
.798 .796 .851 r
.67997 .21741 m .67275 .2232 L .67006 .21967 L p F P
0 g
s
.785 .743 .814 r
.17574 .76788 m .17732 .76654 L .18236 .769 L p F P
0 g
s
.783 .745 .818 r
.18669 .75874 m .17732 .76654 L .18236 .769 L p F P
0 g
s
.783 .745 .818 r
.18236 .769 m .1901 .76253 L .18669 .75874 L p F P
0 g
s
.53 .448 .707 r
.67546 .85437 m .68437 .84989 L p .6811 .85978 L F P
0 g
s
.53 .448 .707 r
.6811 .85978 m .67668 .85887 L .67546 .85437 L p F P
0 g
s
.578 .559 .796 r
.63881 .7845 m .63866 .78451 L .63878 .78445 L closepath p F P
0 g
s
.583 .567 .802 r
.63593 .77808 m .63878 .78445 L .63866 .78451 L p F P
0 g
s
.552 .508 .76 r
.67004 .82114 m .66472 .82088 L .66267 .81519 L p F P
0 g
s
.825 .727 .757 r
.13694 .82311 m .13808 .82169 L .13464 .81746 L p F P
0 g
s
.505 .371 .632 r
.67462 .89943 m .6736 .89313 L .68345 .88867 L p F P
0 g
s
.514 .39 .649 r
.68306 .88661 m .68345 .88867 L .6736 .89313 L p F P
0 g
s
.514 .39 .649 r
.67789 .88417 m .68306 .88661 L p .6736 .89313 L F P
0 g
s
.515 .378 .632 r
.67379 .89978 m .67462 .89943 L .6736 .89313 L p F P
0 g
s
.444 .187 .428 r
.65613 .93592 m .64578 .9397 L .64529 .9446 L p F P
0 g
s
.471 .242 .484 r
.65629 .93073 m .65613 .93592 L .64578 .9397 L p F P
0 g
s
.852 .64 .615 r
.13527 .90865 m .12991 .90645 L .13151 .90063 L p F P
0 g
s
.855 .627 .593 r
.12991 .90645 m .13527 .90865 L .13409 .91436 L p F P
0 g
s
.573 .554 .795 r
.63881 .7845 m .65018 .78397 L p .6482 .79092 L F P
0 g
s
.571 .555 .797 r
.64817 .77929 m .65018 .78397 L .63881 .7845 L p F P
0 g
s
.571 .555 .797 r
.63881 .7845 m .63878 .78445 L .64817 .77929 L p F P
0 g
s
.575 .565 .805 r
.6473 .77735 m .64817 .77929 L .63878 .78445 L p F P
0 g
s
.575 .565 .805 r
.63878 .78445 m .63593 .77808 L .6473 .77735 L p F P
0 g
s
.927 .806 .706 r
.75108 .11632 m .7519 .11472 L .74934 .11107 L p F P
0 g
s
.622 .657 .863 r
.5791 .73864 m .56793 .74109 L .56503 .73649 L p F P
0 g
s
.621 .65 .858 r
.56793 .74109 m .5791 .73864 L .58199 .74343 L p F P
0 g
s
.805 .736 .788 r
.1571 .79239 m .15732 .79217 L .15661 .79182 L closepath p F P
0 g
s
.798 .74 .798 r
.15366 .78848 m .16015 .78214 L p .15732 .79217 L F P
0 g
s
.798 .74 .798 r
.15732 .79217 m .15661 .79182 L .15366 .78848 L p F P
0 g
s
.81 .737 .783 r
.15039 .79947 m .1571 .79239 L .15661 .79182 L p F P
0 g
s
.25 0 0 r
.33497 .73782 m .33796 .73807 L .33459 .73818 L p F P
0 g
s
.379 .833 .925 r
.467 .73779 m .46716 .73781 L .47914 .73557 L p F P
0 g
s
.8 .39 .272 r
.17684 .95512 m .17927 .95942 L .17878 .9596 L p F P
0 g
s
.8 .39 .272 r
.17076 .95319 m .17684 .95512 L p .17878 .9596 L F P
0 g
s
.589 .591 .822 r
.62675 .766 m .61886 .76691 L .61598 .76107 L p F P
0 g
s
.828 .723 .749 r
.13207 .82066 m .13694 .82311 L .13175 .82991 L p F P
0 g
s
.825 .727 .757 r
.13464 .81746 m .13207 .82066 L .13694 .82311 L p F P
0 g
s
.649 .76 .93 r
.37662 .989 m .38745 .98579 L .3906 .98875 L p F P
0 g
s
.665 .743 .908 r
.38745 .98579 m .37662 .989 L .37345 .98613 L p F P
0 g
s
.843 .81 .818 r
.71386 .18635 m .71682 .18328 L .71421 .17979 L p F P
0 g
s
.842 .552 .497 r
.15601 .93913 m .15023 .9371 L .1499 .93176 L p F P
0 g
s
.844 .553 .496 r
.14415 .92971 m .1499 .93176 L .15023 .9371 L p F P
0 g
s
.938 .797 .678 r
.74905 .10259 m .75149 .10664 L .75387 .10117 L p F P
0 g
s
.938 .797 .678 r
.75387 .10117 m .75143 .09712 L .74905 .10259 L p F P
0 g
s
.058 0 0 r
.58372 .97551 m .58013 .97638 L .57253 .97821 L p F P
0 g
s
0 0 0 r
.58013 .97638 m .57246 .97823 L .57253 .97821 L closepath p F P
0 g
s
.286 0 0 r
.23088 .97825 m .23057 .97819 L .23072 .97821 L closepath p F P
0 g
s
.836 .713 .728 r
.1273 .84563 m .13001 .8416 L .1266 .83689 L p F P
0 g
s
.282 .722 .964 r
.27564 .98594 m .2753 .98593 L .27592 .98605 L closepath p F P
0 g
s
.775 .744 .825 r
.19232 .76078 m .1901 .76253 L .18669 .75874 L p F P
0 g
s
.902 .811 .749 r
.74145 .1325 m .74429 .12805 L .74655 .13213 L p F P
0 g
s
.902 .811 .749 r
.74655 .13213 m .74401 .1361 L .74145 .1325 L p F P
0 g
s
.538 .474 .732 r
.68217 .83984 m .67255 .83853 L .68048 .8344 L closepath p F P
0 g
s
.544 .486 .741 r
.67918 .83042 m .68048 .8344 L .67255 .83853 L p F P
0 g
s
.544 .486 .741 r
.67197 .82966 m .67918 .83042 L p .67255 .83853 L F P
0 g
s
.854 .643 .616 r
.12621 .8984 m .13151 .90063 L .12991 .90645 L p F P
0 g
s
.851 .654 .635 r
.13151 .90063 m .12621 .8984 L .1282 .89247 L p F P
0 g
s
.152 .645 .916 r
.23088 .97825 m .241 .98005 L .2377 .97865 L p F P
0 g
s
.152 .645 .916 r
.23057 .97819 m .23088 .97825 L p .2377 .97865 L F P
0 g
s
.53 .448 .707 r
.67743 .8616 m .67668 .85887 L .6811 .85978 L closepath p F P
0 g
s
.844 .685 .685 r
.12482 .87186 m .12598 .86957 L .12277 .86813 L closepath p F P
0 g
s
.84 .693 .701 r
.12151 .86605 m .12438 .86091 L p .12598 .86957 L F P
0 g
s
.84 .693 .701 r
.12598 .86957 m .12277 .86813 L .12151 .86605 L p F P
0 g
s
.379 .833 .925 r
.47797 .73559 m .467 .73779 L p .47083 .73709 L F P
0 g
s
.379 .833 .925 r
.47914 .73557 m .47797 .73559 L p .47083 .73709 L F P
0 g
s
.327 .811 .859 r
.48899 .73306 m .47797 .73559 L p .48181 .73477 L F P
0 g
s
.327 .811 .859 r
.49069 .73288 m .48899 .73306 L p .48181 .73477 L F P
0 g
s
.306 .799 .812 r
.48899 .73306 m .49069 .73288 L .50191 .72981 L p F P
0 g
s
.306 .799 .812 r
.50005 .73007 m .48899 .73306 L p .49288 .73208 L F P
0 g
s
.306 .799 .812 r
.50191 .72981 m .50005 .73007 L p .49288 .73208 L F P
0 g
s
.329 .813 .806 r
.50005 .73007 m .50191 .72981 L .51283 .72638 L p F P
0 g
s
.329 .813 .806 r
.51115 .72655 m .50005 .73007 L p .50391 .72895 L F P
0 g
s
.329 .813 .806 r
.51283 .72638 m .51115 .72655 L p .50391 .72895 L F P
0 g
s
.395 .853 .843 r
.52228 .72257 m .51115 .72655 L p .51502 .7253 L F P
0 g
s
.395 .853 .843 r
.52341 .72257 m .52228 .72257 L p .51502 .7253 L F P
0 g
s
.492 .902 .903 r
.5336 .71828 m .53344 .71826 L .52228 .72257 L p F P
0 g
s
0 0 0 r
.52228 .72257 m .53344 .71826 L p .5311 .71926 L F P
0 g
s
.395 .853 .843 r
.51115 .72655 m .51283 .72638 L .52341 .72257 L p F P
0 g
s
.525 .898 .964 r
.52523 .72306 m .52341 .72257 L .51283 .72638 L p F P
0 g
s
.492 .902 .903 r
.52228 .72257 m .52341 .72257 L .5336 .71828 L p F P
0 g
s
0 0 0 r
.51974 .72412 m .52228 .72257 L p .5311 .71926 L F P
0 g
s
0 0 0 r
.51115 .72655 m .52228 .72257 L p .51874 .72403 L F P
0 g
s
.497 .888 .956 r
.50191 .72981 m .50304 .73001 L .51411 .72664 L p F P
0 g
s
.497 .888 .956 r
.51411 .72664 m .51283 .72638 L .50191 .72981 L p F P
0 g
s
.525 .898 .964 r
.51283 .72638 m .51411 .72664 L .52523 .72306 L p F P
0 g
s
0 0 0 r
.50918 .72799 m .51115 .72655 L p .51874 .72403 L F P
0 g
s
.054 0 0 r
.50005 .73007 m .51115 .72655 L p .50715 .72807 L F P
0 g
s
.589 .86 .994 r
.492 .73313 m .50304 .73001 L .50601 .73154 L p F P
0 g
s
.486 .88 .96 r
.49069 .73288 m .492 .73313 L .50304 .73001 L p F P
0 g
s
.486 .88 .96 r
.50304 .73001 m .50191 .72981 L .49069 .73288 L p F P
0 g
s
.054 0 0 r
.49825 .73145 m .50005 .73007 L p .50715 .72807 L F P
0 g
s
.081 0 0 r
.48899 .73306 m .50005 .73007 L p .49652 .73127 L F P
0 g
s
.327 .811 .859 r
.47797 .73559 m .47914 .73557 L .49069 .73288 L p F P
0 g
s
.495 .875 .974 r
.492 .73313 m .49069 .73288 L .47914 .73557 L p F P
0 g
s
.081 0 0 r
.48698 .73451 m .48899 .73306 L p .49652 .73127 L F P
0 g
s
.067 0 0 r
.47797 .73559 m .48899 .73306 L p .48665 .73376 L F P
0 g
s
.067 0 0 r
.47535 .73716 m .47797 .73559 L p .48665 .73376 L F P
0 g
s
.228 0 0 r
.467 .73779 m .47797 .73559 L .47535 .73716 L p F P
0 g
s
.228 0 0 r
.46393 .73893 m .467 .73779 L p .47535 .73716 L F P
0 g
s
.161 .7 .742 r
.467 .73779 m .46393 .73893 L .45299 .74009 L p F P
0 g
s
.203 .727 .73 r
.56971 .97875 m .57246 .97823 L .58013 .97638 L p F P
0 g
s
.158 .693 .697 r
.57246 .97823 m .56971 .97875 L .55857 .98128 L p F P
0 g
s
.552 .508 .76 r
.66267 .81519 m .66676 .81299 L p .67004 .82114 L F P
0 g
s
.555 .518 .769 r
.66267 .81519 m .66179 .81285 L .66676 .81299 L closepath p F P
0 g
s
.753 .749 .849 r
.21184 .7463 m .21697 .7429 L .22223 .74531 L p F P
0 g
s
.753 .752 .851 r
.22265 .73921 m .21697 .7429 L .22223 .74531 L p F P
0 g
s
.753 .752 .851 r
.22223 .74531 m .22604 .74281 L .22265 .73921 L p F P
0 g
s
.801 .798 .849 r
.67997 .21741 m .68382 .21426 L .68115 .21073 L p F P
0 g
s
.801 .798 .849 r
.68115 .21073 m .67795 .21334 L .67997 .21741 L p F P
0 g
s
.798 .796 .851 r
.67006 .21967 m .67795 .21334 L .67997 .21741 L p F P
0 g
s
.843 .81 .818 r
.71421 .17979 m .71182 .18226 L .71386 .18635 L p F P
0 g
s
.838 .808 .822 r
.70455 .18959 m .70663 .19366 L .71386 .18635 L p F P
0 g
s
.838 .808 .822 r
.71386 .18635 m .71182 .18226 L .70455 .18959 L p F P
0 g
s
.291 0 0 r
.22718 .97752 m .22412 .97655 L .23057 .97819 L closepath p F P
0 g
s
.152 .645 .916 r
.22718 .97752 m .23057 .97819 L p .2377 .97865 L F P
0 g
s
.642 .721 .905 r
.54808 .73104 m .53697 .73407 L .53404 .73052 L p F P
0 g
s
.639 .702 .891 r
.53697 .73407 m .54808 .73104 L .55099 .73499 L p F P
0 g
s
.385 .758 .991 r
.2753 .98593 m .27564 .98594 L .27225 .98425 L p F P
0 g
s
.385 .758 .991 r
.27225 .98425 m .26794 .98441 L .2753 .98593 L p F P
0 g
s
.651 .757 .927 r
.3906 .98875 m .40145 .98549 L .40458 .98851 L p F P
0 g
s
.666 .739 .905 r
.40145 .98549 m .3906 .98875 L .38745 .98579 L p F P
0 g
s
.775 .744 .825 r
.18669 .75874 m .18719 .75834 L .19232 .76078 L p F P
0 g
s
.774 .747 .828 r
.19759 .75033 m .18719 .75834 L .19232 .76078 L p F P
0 g
s
.774 .747 .828 r
.19232 .76078 m .20099 .75407 L .19759 .75033 L p F P
0 g
s
.81 .737 .783 r
.15661 .79182 m .15248 .78968 L p .15039 .79947 L F P
0 g
s
.807 .741 .79 r
.15661 .79182 m .15366 .78848 L .15248 .78968 L closepath p F P
0 g
s
.927 .806 .706 r
.74934 .11107 m .74874 .11225 L .75108 .11632 L p F P
0 g
s
.915 .806 .725 r
.74548 .11807 m .74783 .12213 L .75108 .11632 L p F P
0 g
s
.915 .806 .725 r
.75108 .11632 m .74874 .11225 L .74548 .11807 L p F P
0 g
s
.524 .433 .695 r
.67921 .86865 m .67743 .8616 L .6811 .85978 L p F P
0 g
s
.365 .767 .985 r
.28956 .98676 m .2862 .98477 L .27564 .98594 L p F P
0 g
s
.554 .782 .984 r
.2862 .98477 m .27564 .98594 L .27225 .98425 L p F P
0 g
s
.812 .735 .779 r
.15039 .79947 m .14593 .80428 L .14248 .80026 L p F P
0 g
s
.812 .735 .779 r
.14248 .80026 m .1455 .797 L .15039 .79947 L p F P
0 g
s
.81 .737 .783 r
.15248 .78968 m .1455 .797 L .15039 .79947 L p F P
0 g
s
.555 .519 .77 r
.66676 .81299 m .66179 .81285 L .65946 .80666 L p F P
0 g
s
.81 .8 .842 r
.68972 .20918 m .68382 .21426 L .68115 .21073 L p F P
0 g
s
.879 .814 .78 r
.73591 .1546 m .73569 .15489 L .7346 .1528 L closepath p F P
0 g
s
.839 .52 .449 r
.16245 .94623 m .15696 .94431 L .15601 .93913 L p F P
0 g
s
.841 .52 .445 r
.15023 .9371 m .15601 .93913 L .15696 .94431 L p F P
0 g
s
.651 .755 .926 r
.40458 .98851 m .41546 .98526 L .41857 .98829 L p F P
0 g
s
.665 .737 .904 r
.41546 .98526 m .40458 .98851 L .40145 .98549 L p F P
0 g
s
.865 .811 .794 r
.7282 .15742 m .73036 .16149 L .73569 .15489 L p F P
0 g
s
.865 .811 .794 r
.73334 .15106 m .7282 .15742 L p .73569 .15489 L F P
0 g
s
.865 .811 .794 r
.73569 .15489 m .7346 .1528 L .73334 .15106 L p F P
0 g
s
.424 .624 .936 r
.58903 .23662 m .58721 .23646 L .58998 .24027 L p F P
0 g
s
.424 .624 .936 r
.58998 .24027 m .59187 .24043 L .58903 .23662 L p F P
0 g
s
.854 .657 .636 r
.12298 .89021 m .1282 .89247 L .12621 .8984 L p F P
0 g
s
.851 .666 .652 r
.1282 .89247 m .12298 .89021 L .12533 .88419 L p F P
0 g
s
.832 .806 .826 r
.70324 .19088 m .70455 .18959 L .70663 .19366 L p F P
0 g
s
.832 .806 .826 r
.70663 .19366 m .70587 .1944 L .70324 .19088 L p F P
0 g
s
.813 .802 .84 r
.68972 .20918 m .69486 .20466 L .69221 .20114 L p F P
0 g
s
.813 .802 .84 r
.69221 .20114 m .68768 .20511 L .68972 .20918 L p F P
0 g
s
.81 .8 .842 r
.68115 .21073 m .68768 .20511 L .68972 .20918 L p F P
0 g
s
.825 .805 .832 r
.69853 .20129 m .70587 .1944 L .70324 .19088 L p F P
0 g
s
.208 0 0 r
.59761 .97059 m .59805 .97009 L .609 .96703 L p F P
0 g
s
.767 .783 .866 r
.65381 .2315 m .64781 .23559 L .64508 .23197 L p F P
0 g
s
.825 .805 .832 r
.70324 .19088 m .69648 .19722 L .69853 .20129 L p F P
0 g
s
.821 .803 .834 r
.69221 .20114 m .69648 .19722 L .69853 .20129 L p F P
0 g
s
.821 .803 .834 r
.69853 .20129 m .69486 .20466 L .69221 .20114 L p F P
0 g
s
.739 .753 .864 r
.23681 .73634 m .22604 .74281 L .22265 .73921 L p F P
0 g
s
.72 .752 .877 r
.23681 .73634 m .23986 .73475 L .24555 .73703 L p F P
0 g
s
.725 .759 .879 r
.24755 .73078 m .23986 .73475 L .24555 .73703 L p F P
0 g
s
.725 .759 .879 r
.24555 .73703 m .25091 .73418 L .24755 .73078 L p F P
0 g
s
.481 .3 .558 r
.66637 .92129 m .666 .91562 L .67603 .9114 L p F P
0 g
s
.495 .33 .587 r
.67543 .90551 m .67603 .9114 L .666 .91562 L p F P
0 g
s
.492 .309 .559 r
.66245 .92284 m .66637 .92129 L .666 .91562 L p F P
0 g
s
.649 .756 .928 r
.41857 .98829 m .42947 .98509 L .43256 .9881 L p F P
0 g
s
.662 .737 .905 r
.42947 .98509 m .41857 .98829 L .41546 .98526 L p F P
0 g
s
.817 .735 .775 r
.1438 .80668 m .14593 .80428 L .14248 .80026 L p F P
0 g
s
.848 .686 .681 r
.1229 .87578 m .12482 .87186 L .12277 .86813 L p F P
0 g
s
.613 .639 .853 r
.58273 .74469 m .58199 .74343 L .58767 .7423 L closepath p F P
0 g
s
.839 .709 .72 r
.12236 .84322 m .1273 .84563 L .12318 .85213 L p F P
0 g
s
.836 .713 .728 r
.1266 .83689 m .12236 .84322 L .1273 .84563 L p F P
0 g
s
.618 .231 .288 r
.39746 .74465 m .40874 .74459 L p .40953 .748 L F P
0 g
s
.618 .231 .288 r
.39694 .7452 m .39746 .74465 L p .40953 .748 L F P
0 g
s
.576 .123 .139 r
.39694 .7452 m .39551 .74461 L .39746 .74465 L closepath p F P
0 g
s
.764 .747 .837 r
.20362 .75216 m .20099 .75407 L .19759 .75033 L p F P
0 g
s
.236 0 0 r
.4511 .7414 m .45299 .74009 L .46393 .73893 L p F P
0 g
s
.536 .032 .005 r
.38366 .74422 m .38271 .74418 L .38299 .74399 L closepath p F P
0 g
s
.339 0 0 r
.38299 .74399 m .38366 .74422 L .39551 .74461 L p F P
0 g
s
.827 .5 .435 r
.16275 .94633 m .16245 .94623 L .16266 .94594 L closepath p F P
0 g
s
.634 .237 .274 r
.39551 .74461 m .39694 .7452 L .39529 .74804 L p F P
0 g
s
.634 .237 .274 r
.38366 .74422 m .39551 .74461 L p .39529 .74804 L F P
0 g
s
.349 0 .203 r
.62187 .96027 m .62259 .95838 L .63377 .95327 L p F P
0 g
s
.392 .056 .271 r
.63392 .95276 m .63377 .95327 L .62259 .95838 L p F P
0 g
s
.602 .617 .839 r
.59937 .75236 m .59897 .75162 L .6017 .75117 L closepath p F P
0 g
s
.559 .114 .149 r
.41092 .74536 m .40874 .74459 L .4116 .74455 L closepath p F P
0 g
s
.618 .231 .288 r
.40874 .74459 m .41092 .74536 L .40953 .748 L p F P
0 g
s
.595 .21 .283 r
.4116 .74455 m .42401 .74397 L p .42324 .74745 L F P
0 g
s
.595 .21 .283 r
.41092 .74536 m .4116 .74455 L p .42324 .74745 L F P
0 g
s
.817 .735 .775 r
.14248 .80026 m .13898 .80418 L .1438 .80668 L p F P
0 g
s
.819 .732 .769 r
.13898 .80418 m .1438 .80668 L .13774 .81372 L p F P
0 g
s
.897 .811 .755 r
.74262 .13819 m .74401 .1361 L .74145 .1325 L p F P
0 g
s
.559 .529 .778 r
.65946 .80666 m .65888 .80517 L .66213 .8052 L closepath p F P
0 g
s
.555 .519 .77 r
.65946 .80666 m .66213 .8052 L p .66676 .81299 L F P
0 g
s
.645 .759 .932 r
.43256 .9881 m .44348 .98497 L .44655 .98792 L p F P
0 g
s
.659 .738 .909 r
.44348 .98497 m .43256 .9881 L .42947 .98509 L p F P
0 g
s
.483 .857 .985 r
.53058 .98502 m .53139 .98527 L .54316 .98307 L p F P
0 g
s
.435 .847 .965 r
.54458 .98349 m .54316 .98307 L .53139 .98527 L p F P
0 g
s
.635 .695 .888 r
.56213 .73217 m .55099 .73499 L .54808 .73104 L p F P
0 g
s
.829 .721 .746 r
.12684 .82747 m .13175 .82991 L .12677 .83665 L p F P
0 g
s
.828 .723 .749 r
.13175 .82991 m .12684 .82747 L .13207 .82066 L p F P
0 g
s
.504 .354 .61 r
.67478 .9006 m .67379 .89978 L .67462 .89943 L closepath p F P
0 g
s
.399 .845 .925 r
.56971 .97875 m .55857 .98128 L .55571 .98103 L p F P
0 g
s
.366 .829 .908 r
.54458 .98349 m .55571 .98103 L .55857 .98128 L p F P
0 g
s
.563 .785 .982 r
.28956 .98676 m .30019 .98489 L .3035 .98715 L p F P
0 g
s
.604 .778 .964 r
.30019 .98489 m .28956 .98676 L .2862 .98477 L p F P
0 g
s
.844 .695 .698 r
.12438 .86091 m .12151 .86605 L .11816 .86064 L p F P
0 g
s
.844 .695 .698 r
.11816 .86064 m .11931 .85856 L .12438 .86091 L p F P
0 g
s
.84 .701 .71 r
.12438 .86091 m .11931 .85856 L .12318 .85213 L p F P
0 g
s
.764 .747 .837 r
.19759 .75033 m .19842 .74973 L .20362 .75216 L p F P
0 g
s
.764 .75 .84 r
.20844 .74264 m .19842 .74973 L .20362 .75216 L p F P
0 g
s
.764 .75 .84 r
.20362 .75216 m .21184 .7463 L .20844 .74264 L p F P
0 g
s
.817 .454 .368 r
.16245 .94623 m .16275 .94633 L .16468 .95126 L p F P
0 g
s
.817 .454 .368 r
.17076 .95319 m .16468 .95126 L .16275 .94633 L p F P
0 g
s
.853 .669 .653 r
.12019 .88189 m .12533 .88419 L .12298 .89021 L p F P
0 g
s
.85 .677 .667 r
.12533 .88419 m .12019 .88189 L .1229 .87578 L p F P
0 g
s
.518 .418 .681 r
.67921 .86865 m .68885 .86387 L p .6857 .87311 L F P
0 g
s
.518 .418 .681 r
.6857 .87311 m .6798 .87117 L .67921 .86865 L p F P
0 g
s
.524 .433 .695 r
.6883 .86171 m .68885 .86387 L .67921 .86865 L p F P
0 g
s
.524 .433 .695 r
.6811 .85978 m .6883 .86171 L p .67921 .86865 L F P
0 g
s
.512 .39 .65 r
.68306 .88661 m .67789 .88417 L .68222 .88218 L closepath p F P
0 g
s
.522 .408 .665 r
.68081 .8755 m .68222 .88218 L .67789 .88417 L p F P
0 g
s
.559 .529 .779 r
.66213 .8052 m .65888 .80517 L .656 .79787 L p F P
0 g
s
.602 .623 .844 r
.6017 .75117 m .59897 .75162 L .59609 .7464 L p F P
0 g
s
.568 .544 .789 r
.65307 .79077 m .6482 .79092 L .65224 .78875 L closepath p F P
0 g
s
.573 .554 .795 r
.65018 .78397 m .65224 .78875 L .6482 .79092 L p F P
0 g
s
.575 .565 .806 r
.64441 .77095 m .6473 .77735 L .63593 .77808 L p F P
0 g
s
.575 .565 .806 r
.64067 .77118 m .64441 .77095 L p .63593 .77808 L F P
0 g
s
.575 .565 .806 r
.63593 .77808 m .63439 .77467 L .64067 .77118 L p F P
0 g
s
.459 .233 .483 r
.6616 .92866 m .65629 .93073 L .65613 .93592 L p F P
0 g
s
.479 .276 .525 r
.65629 .93073 m .6616 .92866 L .66245 .92284 L p F P
0 g
s
.506 0 0 r
.20344 .96954 m .20988 .97314 L .20954 .97308 L p F P
0 g
s
.506 0 0 r
.19669 .96782 m .20344 .96954 L p .20954 .97308 L F P
0 g
s
.691 .192 .053 r
.1963 .96755 m .19669 .96782 L .20344 .96954 L p F P
0 g
s
.817 .454 .368 r
.16468 .95126 m .15871 .94935 L .16245 .94623 L p F P
0 g
s
.832 .477 .383 r
.15696 .94431 m .16245 .94623 L .15871 .94935 L p F P
0 g
s
.945 .789 .656 r
.74889 .09309 m .75143 .09712 L .75348 .09179 L p F P
0 g
s
.945 .789 .656 r
.75348 .09179 m .75095 .08775 L .74889 .09309 L p F P
0 g
s
.64 .765 .939 r
.44655 .98792 m .4575 .9849 L .46055 .98774 L p F P
0 g
s
.654 .742 .914 r
.4575 .9849 m .44655 .98792 L .44348 .98497 L p F P
0 g
s
.638 .228 .25 r
.38271 .74418 m .38366 .74422 L .38907 .74788 L p F P
0 g
s
.634 .237 .274 r
.39529 .74804 m .38907 .74788 L .38366 .74422 L p F P
0 g
s
.542 .485 .742 r
.67918 .83042 m .67197 .82966 L .6779 .82652 L closepath p F P
0 g
s
.548 .497 .751 r
.67621 .82163 m .6779 .82652 L .67197 .82966 L p F P
0 g
s
.548 .497 .751 r
.67004 .82114 m .67621 .82163 L p .67197 .82966 L F P
0 g
s
.846 .58 .537 r
.14415 .92971 m .13979 .92813 L .14064 .92286 L p F P
0 g
s
.854 .588 .537 r
.13877 .92213 m .14064 .92286 L .13979 .92813 L p F P
0 g
s
.475 .272 .524 r
.66637 .92129 m .66245 .92284 L .6616 .92866 L p F P
0 g
s
.769 .784 .866 r
.65381 .2315 m .65894 .22796 L .65622 .22436 L p F P
0 g
s
.769 .784 .866 r
.65622 .22436 m .65167 .22749 L .65381 .2315 L p F P
0 g
s
.767 .783 .866 r
.64508 .23197 m .65167 .22749 L .65381 .2315 L p F P
0 g
s
.638 .228 .25 r
.38907 .74788 m .38041 .74748 L .38271 .74418 L p F P
0 g
s
.646 .237 .253 r
.37259 .74361 m .38271 .74418 L .38041 .74748 L p F P
0 g
s
.613 .647 .86 r
.58767 .7423 m .58199 .74343 L .5791 .73864 L p F P
0 g
s
.729 .242 .084 r
.19583 .9676 m .1904 .96596 L .18603 .96166 L p F P
0 g
s
.717 .219 .054 r
.17959 .95984 m .18603 .96166 L .1904 .96596 L p F P
0 g
s
.777 .361 .261 r
.17927 .95942 m .17959 .95984 L .18603 .96166 L p F P
0 g
s
.507 0 0 r
.35103 .74125 m .34398 .74035 L .33796 .73807 L p F P
0 g
s
.444 0 0 r
.34398 .74035 m .33796 .73807 L .33459 .73818 L p F P
0 g
s
.56 .784 .983 r
.28958 .72931 m .27896 .73189 L .27562 .7289 L p F P
0 g
s
.666 .771 .928 r
.26496 .73269 m .27562 .7289 L .27896 .73189 L p F P
0 g
s
.604 .783 .966 r
.27896 .73189 m .28958 .72931 L .29293 .73189 L p F P
0 g
s
.888 .81 .766 r
.73594 .14039 m .7382 .14445 L .74262 .13819 L p F P
0 g
s
.888 .81 .766 r
.74262 .13819 m .74037 .13412 L .73594 .14039 L p F P
0 g
s
.897 .811 .755 r
.74145 .1325 m .74037 .13412 L .74262 .13819 L p F P
0 g
s
.65 .775 .94 r
.27562 .7289 m .26496 .73269 L .26161 .72944 L p F P
0 g
s
.698 .762 .901 r
.25091 .73418 m .26161 .72944 L .26496 .73269 L p F P
0 g
s
.865 .811 .794 r
.72264 .16411 m .7282 .15742 L .73036 .16149 L p F P
0 g
s
.865 .811 .794 r
.72332 .16537 m .72264 .16411 L p .73036 .16149 L F P
0 g
s
.865 .811 .794 r
.73036 .16149 m .72511 .16782 L .72332 .16537 L p F P
0 g
s
.495 0 0 r
.32688 .7363 m .33459 .73818 L .3337 .73845 L p F P
0 g
s
.495 .347 .609 r
.67462 .89943 m .68447 .89496 L p .67856 .90412 L F P
0 g
s
.495 .347 .609 r
.67856 .90412 m .67478 .9006 L .67462 .89943 L p F P
0 g
s
.505 .371 .632 r
.68345 .88867 m .68447 .89496 L .67462 .89943 L p F P
0 g
s
.208 0 0 r
.609 .96703 m .60881 .96725 L .59761 .97059 L p F P
0 g
s
.09 0 0 r
.60881 .96725 m .59761 .97059 L .59489 .97258 L p F P
0 g
s
.085 0 0 r
.59761 .97059 m .59489 .97258 L p .58372 .97551 L F P
0 g
s
.518 .418 .68 r
.68081 .8755 m .6798 .87117 L .6857 .87311 L closepath p F P
0 g
s
.633 .774 .948 r
.46055 .98774 m .47152 .98482 L .47455 .98751 L p F P
0 g
s
.649 .749 .923 r
.47152 .98482 m .46055 .98774 L .4575 .9849 L p F P
0 g
s
.595 .71 .924 r
.59187 .24043 m .60313 .23811 L .60595 .2419 L p F P
0 g
s
.594 .71 .924 r
.60313 .23811 m .59187 .24043 L .58903 .23662 L p F P
0 g
s
.521 .067 .114 r
.42494 .74419 m .42401 .74397 L .42518 .74391 L closepath p F P
0 g
s
.595 .21 .283 r
.42401 .74397 m .42494 .74419 L .42324 .74745 L p F P
0 g
s
.351 0 0 r
.4511 .7414 m .44269 .74234 L .43897 .74232 L p F P
0 g
s
.376 0 0 r
.44269 .74234 m .43836 .74287 L .43897 .74232 L closepath p F P
0 g
s
.238 0 0 r
.43897 .74232 m .43836 .74287 L .42518 .74391 L p F P
0 g
s
.589 .591 .822 r
.61598 .76107 m .62729 .75977 L p .62675 .766 L F P
0 g
s
.589 .594 .825 r
.62441 .75394 m .62729 .75977 L .61598 .76107 L p F P
0 g
s
.589 .594 .825 r
.62367 .75403 m .62441 .75394 L p .61598 .76107 L F P
0 g
s
.589 .594 .825 r
.61598 .76107 m .61486 .75882 L .62367 .75403 L p F P
0 g
s
.635 .769 .944 r
.31419 .98473 m .3035 .98715 L .30019 .98489 L p F P
0 g
s
.605 .78 .964 r
.3035 .98715 m .31419 .98473 L .31747 .98723 L p F P
0 g
s
.56 .165 .251 r
.42518 .74391 m .43836 .74287 L .43644 .74641 L p F P
0 g
s
.56 .165 .251 r
.42494 .74419 m .42518 .74391 L p .43644 .74641 L F P
0 g
s
.848 .686 .681 r
.12277 .86813 m .12087 .86724 L p .1229 .87578 L F P
0 g
s
.845 .694 .695 r
.12277 .86813 m .12151 .86605 L .12087 .86724 L closepath p F P
0 g
s
.476 .858 .98 r
.54316 .98307 m .54458 .98349 L .55571 .98103 L p F P
0 g
s
.823 .73 .762 r
.13774 .81372 m .13464 .81746 L .13119 .81329 L p F P
0 g
s
.823 .73 .762 r
.13119 .81329 m .13287 .81125 L .13774 .81372 L p F P
0 g
s
.819 .732 .769 r
.13774 .81372 m .13287 .81125 L .13898 .80418 L p F P
0 g
s
.256 .702 .958 r
.25728 .98268 m .25245 .98155 L .24448 .98121 L p F P
0 g
s
.193 .684 .922 r
.25245 .98155 m .24448 .98121 L .241 .98005 L p F P
0 g
s
.519 0 0 r
.21348 .97344 m .21727 .97487 L p .2229 .97619 L F P
0 g
s
.412 0 0 r
.21727 .97487 m .21348 .97344 L .20988 .97314 L p F P
0 g
s
0 .496 .758 r
.22012 .97515 m .21089 .97337 L p .21727 .97487 L F P
0 g
s
.412 0 0 r
.20988 .97314 m .2102 .97323 L .21727 .97487 L p F P
0 g
s
0 .496 .758 r
.21089 .97337 m .2102 .97323 L .21727 .97487 L p F P
0 g
s
.519 0 0 r
.21727 .97487 m .22412 .97655 L p .2229 .97619 L F P
0 g
s
.691 .766 .908 r
.26161 .72944 m .25091 .73418 L .24755 .73078 L p F P
0 g
s
.461 .779 .998 r
.29293 .73189 m .3035 .73084 L .30685 .73278 L p F P
0 g
s
.357 .741 .987 r
.29293 .73189 m .3035 .73084 L .30202 .73013 L p F P
0 g
s
.357 .741 .987 r
.28958 .72931 m .29293 .73189 L p .30202 .73013 L F P
0 g
s
.623 .787 .96 r
.47455 .98751 m .48555 .98471 L .48856 .9872 L p F P
0 g
s
.642 .759 .934 r
.48555 .98471 m .47455 .98751 L .47152 .98482 L p F P
0 g
s
.928 .799 .698 r
.74677 .10728 m .74905 .10259 L .75149 .10664 L p F P
0 g
s
.928 .799 .698 r
.75149 .10664 m .74934 .11107 L .74677 .10728 L p F P
0 g
s
.907 .806 .736 r
.74192 .124 m .74429 .12805 L .74783 .12213 L p F P
0 g
s
.907 .806 .736 r
.74783 .12213 m .74548 .11807 L .74192 .124 L p F P
0 g
s
.496 .347 .609 r
.67543 .90551 m .67478 .9006 L .67856 .90412 L closepath p F P
0 g
s
.618 .231 .288 r
.40953 .748 m .40164 .74806 L .39694 .7452 L p F P
0 g
s
.62 .226 .274 r
.40164 .74806 m .39529 .74804 L .39694 .7452 L closepath p F P
0 g
s
.852 .68 .668 r
.11784 .87344 m .1229 .87578 L .12019 .88189 L p F P
0 g
s
.848 .686 .681 r
.12087 .86724 m .11784 .87344 L .1229 .87578 L p F P
0 g
s
.646 .237 .253 r
.38041 .74748 m .37775 .74733 L .37259 .74361 L p F P
0 g
s
.68 .302 .323 r
.36732 .74313 m .37259 .74361 L .37775 .74733 L p F P
0 g
s
.578 .575 .813 r
.63439 .77467 m .63305 .77179 L .64067 .77118 L closepath p F P
0 g
s
.783 .788 .857 r
.6669 .22205 m .65894 .22796 L .65622 .22436 L p F P
0 g
s
.752 .751 .851 r
.21697 .7429 m .21184 .7463 L .20844 .74264 L p F P
0 g
s
.749 .773 .873 r
.63492 .23827 m .63392 .23889 L .63115 .2352 L p F P
0 g
s
.722 .765 .887 r
.61996 .24107 m .63115 .2352 L .63392 .23889 L p F P
0 g
s
.61 .803 .974 r
.48856 .9872 m .49958 .98451 L .50256 .98673 L p F P
0 g
s
.633 .773 .947 r
.49958 .98451 m .48856 .9872 L .48555 .98471 L p F P
0 g
s
.631 .772 .948 r
.31747 .98723 m .3282 .98438 L .33146 .9871 L p F P
0 g
s
.654 .76 .927 r
.3282 .98438 m .31747 .98723 L .31419 .98473 L p F P
0 g
s
.448 .781 .998 r
.26794 .98441 m .27225 .98425 L .26886 .98228 L p F P
0 g
s
.448 .781 .998 r
.26886 .98228 m .25987 .98307 L .26794 .98441 L p F P
0 g
s
.271 .726 .955 r
.25833 .98316 m .25987 .98307 L .26794 .98441 L p F P
0 g
s
.483 .857 .985 r
.54316 .98307 m .54168 .98254 L .53058 .98502 L p F P
0 g
s
.575 .84 .995 r
.54168 .98254 m .53058 .98502 L .52765 .98352 L p F P
0 g
s
.557 .845 .998 r
.51657 .98604 m .52765 .98352 L .53058 .98502 L p F P
0 g
s
.559 .529 .779 r
.656 .79787 m .65615 .79779 L p .66213 .8052 L F P
0 g
s
.562 .539 .787 r
.656 .79787 m .65597 .79779 L .65615 .79779 L closepath p F P
0 g
s
.562 .54 .789 r
.65615 .79779 m .65597 .79779 L .65307 .79077 L p F P
0 g
s
.56 .165 .251 r
.43644 .74641 m .43266 .7467 L .42494 .74419 L p F P
0 g
s
.56 .169 .258 r
.43266 .7467 m .42324 .74745 L .42494 .74419 L closepath p F P
0 g
s
.546 .497 .752 r
.67621 .82163 m .67004 .82114 L .6751 .81842 L closepath p F P
0 g
s
.552 .508 .76 r
.67327 .81335 m .6751 .81842 L .67004 .82114 L p F P
0 g
s
.552 .508 .76 r
.66676 .81299 m .67327 .81335 L p .67004 .82114 L F P
0 g
s
.622 .657 .863 r
.56503 .73649 m .5762 .73397 L .5791 .73864 L p F P
0 g
s
.626 .673 .875 r
.57373 .73013 m .5762 .73397 L .56503 .73649 L p F P
0 g
s
.626 .673 .875 r
.56503 .73649 m .56383 .73469 L .57373 .73013 L p F P
0 g
s
.185 0 0 r
.22412 .97655 m .22718 .97752 L .22365 .97648 L p F P
0 g
s
.185 0 0 r
.22365 .97648 m .21727 .97487 L .22412 .97655 L p F P
0 g
s
.589 .823 .988 r
.50256 .98673 m .51362 .98414 L .51657 .98604 L p F P
0 g
s
.621 .791 .964 r
.51362 .98414 m .50256 .98673 L .49958 .98451 L p F P
0 g
s
.874 .811 .784 r
.7346 .1528 m .73334 .15106 L .73353 .15081 L closepath p F P
0 g
s
.599 .613 .837 r
.61022 .74988 m .6017 .75117 L .6089 .74738 L closepath p F P
0 g
s
.602 .623 .844 r
.60734 .74453 m .6089 .74738 L .6017 .75117 L p F P
0 g
s
.602 .623 .844 r
.59609 .7464 m .60734 .74453 L p .6017 .75117 L F P
0 g
s
.749 .774 .873 r
.63492 .23827 m .64508 .23197 L .64233 .2283 L p F P
0 g
s
.749 .774 .873 r
.64233 .2283 m .63256 .23434 L .63492 .23827 L p F P
0 g
s
.749 .773 .873 r
.63115 .2352 m .63256 .23434 L .63492 .23827 L p F P
0 g
s
.857 .612 .567 r
.1287 .91218 m .13409 .91436 L .13333 .91997 L p F P
0 g
s
.855 .627 .593 r
.13409 .91436 m .1287 .91218 L .12991 .90645 L p F P
0 g
s
.855 .61 .567 r
.13877 .92213 m .13333 .91997 L .13409 .91436 L p F P
0 g
s
.854 .588 .537 r
.13979 .92813 m .13849 .92762 L .13877 .92213 L p F P
0 g
s
.857 .591 .535 r
.13333 .91997 m .13877 .92213 L .13849 .92762 L p F P
0 g
s
.829 .721 .746 r
.12316 .83246 m .12684 .82747 L p .12677 .83665 L F P
0 g
s
.829 .721 .746 r
.12677 .83665 m .12622 .83637 L .12316 .83246 L p F P
0 g
s
.835 .716 .733 r
.1266 .83689 m .12677 .83665 L .12622 .83637 L closepath p F P
0 g
s
.559 .529 .779 r
.65615 .79779 m .66743 .79795 L p .66213 .8052 L F P
0 g
s
.556 .53 .781 r
.66743 .79795 m .65615 .79779 L .66531 .7926 L closepath p F P
0 g
s
.562 .54 .789 r
.66452 .7907 m .66531 .7926 L .65615 .79779 L p F P
0 g
s
.562 .54 .789 r
.65307 .79077 m .66452 .7907 L p .65615 .79779 L F P
0 g
s
.511 .401 .666 r
.68222 .88218 m .68081 .8755 L .6857 .87311 L p F P
0 g
s
.603 .814 .981 r
.52765 .98352 m .51657 .98604 L .51362 .98414 L p F P
0 g
s
.795 .744 .806 r
.16839 .77445 m .16473 .77778 L .16128 .77397 L p F P
0 g
s
.801 .745 .8 r
.16015 .78214 m .16473 .77778 L .16128 .77397 L p F P
0 g
s
.8 .39 .272 r
.17878 .9596 m .17355 .9579 L .17076 .95319 L p F P
0 g
s
.798 .381 .257 r
.16468 .95126 m .17076 .95319 L .17355 .9579 L p F P
0 g
s
.795 .744 .806 r
.16128 .77397 m .16351 .77194 L .16839 .77445 L p F P
0 g
s
.793 .746 .81 r
.1723 .76409 m .16351 .77194 L .16839 .77445 L p F P
0 g
s
.793 .746 .81 r
.16839 .77445 m .17574 .76788 L .1723 .76409 L p F P
0 g
s
.827 .73 .758 r
.13207 .82066 m .13464 .81746 L .13119 .81329 L p F P
0 g
s
.838 .716 .729 r
.12236 .84322 m .1266 .83689 L .12622 .83637 L p F P
0 g
s
.841 .706 .715 r
.11821 .84973 m .12318 .85213 L .11931 .85856 L p F P
0 g
s
.839 .709 .72 r
.12318 .85213 m .11821 .84973 L .12236 .84322 L p F P
0 g
s
.86 .81 .8 r
.72511 .16782 m .7248 .16819 L .72332 .16537 L closepath p F P
0 g
s
.801 .745 .8 r
.16128 .77397 m .15534 .77962 L .16015 .78214 L p F P
0 g
s
.803 .743 .797 r
.16015 .78214 m .15366 .78848 L .15019 .78464 L p F P
0 g
s
.803 .743 .797 r
.15019 .78464 m .15534 .77962 L .16015 .78214 L p F P
0 g
s
.847 .807 .811 r
.71633 .17109 m .71851 .17515 L .7248 .16819 L p F P
0 g
s
.847 .807 .811 r
.72251 .16426 m .71633 .17109 L p .7248 .16819 L F P
0 g
s
.847 .807 .811 r
.7248 .16819 m .72332 .16537 L .72251 .16426 L p F P
0 g
s
.786 .746 .816 r
.17732 .76654 m .17574 .76788 L .1723 .76409 L p F P
0 g
s
.592 .603 .832 r
.61486 .75882 m .6131 .7554 L .62367 .75403 L closepath p F P
0 g
s
.595 .21 .283 r
.42324 .74745 m .41586 .74776 L .41092 .74536 L p F P
0 g
s
.595 .208 .279 r
.41586 .74776 m .40953 .748 L .41092 .74536 L closepath p F P
0 g
s
.647 .763 .934 r
.33146 .9871 m .34222 .98392 L .34545 .98683 L p F P
0 g
s
.665 .75 .914 r
.34222 .98392 m .33146 .9871 L .3282 .98438 L p F P
0 g
s
.854 .643 .616 r
.12991 .90645 m .12459 .90423 L .12621 .8984 L p F P
0 g
s
.857 .63 .594 r
.12459 .90423 m .12991 .90645 L .1287 .91218 L p F P
0 g
s
0 0 0 r
.58369 .97553 m .58013 .97638 L .58372 .97551 L closepath p F P
0 g
s
.203 .727 .73 r
.58013 .97638 m .58369 .97553 L p .56971 .97875 L F P
0 g
s
.786 .746 .816 r
.1723 .76409 m .17236 .76405 L .17732 .76654 L p F P
0 g
s
.784 .748 .82 r
.1823 .75582 m .17236 .76405 L .17732 .76654 L p F P
0 g
s
.784 .748 .82 r
.18561 .75756 m .1823 .75582 L p .17732 .76654 L F P
0 g
s
.784 .748 .82 r
.17732 .76654 m .18669 .75874 L .18561 .75756 L p F P
0 g
s
.522 .434 .696 r
.6883 .86171 m .6811 .85978 L .68704 .85679 L closepath p F P
0 g
s
.53 .448 .707 r
.6852 .85007 m .68704 .85679 L .6811 .85978 L p F P
0 g
s
.53 .448 .707 r
.68437 .84989 m .6852 .85007 L p .6811 .85978 L F P
0 g
s
.844 .553 .496 r
.15023 .9371 m .14449 .93504 L .14415 .92971 L p F P
0 g
s
.846 .552 .492 r
.13979 .92813 m .14415 .92971 L .14449 .93504 L p F P
0 g
s
.847 .697 .695 r
.12087 .86724 m .12151 .86605 L .11816 .86064 L p F P
0 g
s
.68 .302 .323 r
.36569 .74486 m .36732 .74313 L p .37775 .74733 L F P
0 g
s
.642 .203 .191 r
.36569 .74486 m .36245 .7427 L .36732 .74313 L closepath p F P
0 g
s
.715 .752 .881 r
.23986 .73475 m .23681 .73634 L .23344 .7328 L p F P
0 g
s
.739 .753 .864 r
.22265 .73921 m .23344 .7328 L .23681 .73634 L p F P
0 g
s
.835 .722 .739 r
.12622 .83637 m .12316 .83246 L .12192 .8342 L closepath p F P
0 g
s
.838 .716 .729 r
.12622 .83637 m .12192 .8342 L p .12236 .84322 L F P
0 g
s
.808 .743 .792 r
.15248 .78968 m .15366 .78848 L .15019 .78464 L p F P
0 g
s
.811 .74 .786 r
.14772 .78714 m .15248 .78968 L .1455 .797 L p F P
0 g
s
.808 .743 .792 r
.15019 .78464 m .14772 .78714 L .15248 .78968 L p F P
0 g
s
.549 .508 .762 r
.67327 .81335 m .66676 .81299 L .67209 .81008 L closepath p F P
0 g
s
.555 .519 .77 r
.67034 .80548 m .67209 .81008 L .66676 .81299 L p F P
0 g
s
.555 .519 .77 r
.66213 .8052 m .67034 .80548 L p .66676 .81299 L F P
0 g
s
.657 .755 .923 r
.34545 .98683 m .35625 .98342 L .35944 .98649 L p F P
0 g
s
.672 .742 .903 r
.35625 .98342 m .34545 .98683 L .34222 .98392 L p F P
0 g
s
.553 .519 .772 r
.67034 .80548 m .66213 .8052 L .66882 .80148 L closepath p F P
0 g
s
.559 .529 .779 r
.66743 .79795 m .66882 .80148 L .66213 .8052 L p F P
0 g
s
.44 .745 .992 r
.30685 .73278 m .31154 .73299 L p .31521 .734 L F P
0 g
s
.309 .704 .978 r
.31154 .73299 m .30685 .73278 L .3035 .73084 L p F P
0 g
s
.309 .704 .978 r
.3048 .73104 m .31154 .73299 L p .30765 .73195 L F P
0 g
s
.309 .704 .978 r
.3035 .73084 m .3048 .73104 L p .30765 .73195 L F P
0 g
s
.546 0 0 r
.3048 .73104 m .31261 .7339 L p .30249 .73029 L F P
0 g
s
.126 .614 .913 r
.3048 .73104 m .30202 .73013 L .3035 .73084 L closepath p F P
0 g
s
.546 0 0 r
.30202 .73013 m .3048 .73104 L p .30249 .73029 L F P
0 g
s
.416 0 0 r
.31494 .7344 m .30629 .73153 L .31154 .73299 L F
.3048 .73104 m .31154 .73299 L p .30629 .73153 L F P
0 g
s
.44 .745 .992 r
.31154 .73299 m .31934 .73461 L p .31521 .734 L F P
0 g
s
.882 .809 .773 r
.73125 .14675 m .73353 .15081 L .7382 .14445 L p F P
0 g
s
.882 .809 .773 r
.7382 .14445 m .73594 .14039 L .73125 .14675 L p F P
0 g
s
.857 .646 .617 r
.12096 .89615 m .12621 .8984 L .12459 .90423 L p F P
0 g
s
.854 .657 .636 r
.12621 .8984 m .12096 .89615 L .12298 .89021 L p F P
0 g
s
.83 .727 .751 r
.12727 .81817 m .13207 .82066 L .12684 .82747 L p F P
0 g
s
.827 .73 .758 r
.13119 .81329 m .12727 .81817 L .13207 .82066 L p F P
0 g
s
.578 .576 .814 r
.64067 .77118 m .63305 .77179 L .63017 .76565 L p F P
0 g
s
.752 .751 .851 r
.20844 .74264 m .21176 .74047 L .21697 .7429 L p F P
0 g
s
.752 .754 .854 r
.21926 .73565 m .21176 .74047 L .21697 .7429 L p F P
0 g
s
.752 .754 .854 r
.21697 .7429 m .22265 .73921 L .21926 .73565 L p F P
0 g
s
.382 .053 .278 r
.63377 .95327 m .63622 .95197 L .63392 .95276 L closepath p F P
0 g
s
.42 .123 .353 r
.64493 .94667 m .64529 .9446 L p .63392 .95276 L F P
0 g
s
.42 .123 .353 r
.63392 .95276 m .63622 .95197 L .64493 .94667 L p F P
0 g
s
.785 .79 .857 r
.6669 .22205 m .67006 .21967 L .66736 .21608 L p F P
0 g
s
.785 .79 .857 r
.66736 .21608 m .66477 .21803 L .6669 .22205 L p F P
0 g
s
.783 .788 .857 r
.65622 .22436 m .66477 .21803 L .6669 .22205 L p F P
0 g
s
.517 .118 .224 r
.43644 .74641 m .43836 .74287 L .44269 .74234 L p F P
0 g
s
.851 .691 .682 r
.11589 .86487 m .12087 .86724 L .11784 .87344 L p F P
0 g
s
.847 .697 .695 r
.11816 .86064 m .11589 .86487 L .12087 .86724 L p F P
0 g
s
.646 .757 .93 r
.52002 .73067 m .53111 .7274 L .53404 .73052 L p F P
0 g
s
.644 .798 .957 r
.53111 .7274 m .52002 .73067 L .51707 .72825 L p F P
0 g
s
.637 .805 .964 r
.50601 .73154 m .51707 .72825 L .52002 .73067 L p F P
0 g
s
.662 .748 .914 r
.35944 .98649 m .37027 .98294 L .37345 .98613 L p F P
0 g
s
.676 .735 .895 r
.37027 .98294 m .35944 .98649 L .35625 .98342 L p F P
0 g
s
.776 .747 .827 r
.18669 .75874 m .18719 .75834 L .18561 .75756 L closepath p F P
0 g
s
.608 .862 .991 r
.51707 .72825 m .50601 .73154 L .50304 .73001 L p F P
0 g
s
.721 .763 .886 r
.63115 .2352 m .61996 .24107 L .61717 .23733 L p F P
0 g
s
.682 .748 .901 r
.60595 .2419 m .61717 .23733 L .61996 .24107 L p F P
0 g
s
.77 .75 .835 r
.19591 .74853 m .19759 .75033 L .18719 .75834 L p F P
0 g
s
.77 .75 .835 r
.19343 .74723 m .19591 .74853 L p .18719 .75834 L F P
0 g
s
.77 .75 .835 r
.18325 .75505 m .19343 .74723 L p .18719 .75834 L F P
0 g
s
.77 .75 .835 r
.18719 .75834 m .18561 .75756 L .18325 .75505 L p F P
0 g
s
.495 0 0 r
.32074 .7347 m .32167 .735 L p .3337 .73845 L F P
0 g
s
.137 .652 .892 r
.32074 .7347 m .31934 .73461 L .32167 .735 L closepath p F P
0 g
s
.68 .746 .901 r
.61717 .23733 m .60595 .2419 L .60313 .23811 L p F P
0 g
s
.841 .52 .445 r
.15696 .94431 m .1512 .94227 L .15023 .9371 L p F P
0 g
s
.842 .519 .441 r
.14449 .93504 m .15023 .9371 L .1512 .94227 L p F P
0 g
s
.395 0 0 r
.35183 .74091 m .35312 .74156 L .36245 .7427 L p F P
0 g
s
.679 .278 .278 r
.36245 .7427 m .36569 .74486 L .36481 .74627 L p F P
0 g
s
.679 .278 .278 r
.35312 .74156 m .36245 .7427 L p .36481 .74627 L F P
0 g
s
.585 .582 .816 r
.63017 .76565 m .62675 .766 L .6296 .76447 L closepath p F P
0 g
s
.589 .591 .822 r
.62729 .75977 m .6296 .76447 L .62675 .766 L p F P
0 g
s
.847 .807 .81 r
.71158 .17622 m .71633 .17109 L .71851 .17515 L p F P
0 g
s
.847 .807 .81 r
.71851 .17515 m .71421 .17979 L .71158 .17622 L p F P
0 g
s
.665 .743 .908 r
.37345 .98613 m .3843 .9825 L .38745 .98579 L p F P
0 g
s
.677 .728 .889 r
.3843 .9825 m .37345 .98613 L .37027 .98294 L p F P
0 g
s
.653 .124 0 r
.19669 .96782 m .19583 .9676 L .1963 .96755 L closepath p F P
0 g
s
.796 .793 .849 r
.67795 .21334 m .67006 .21967 L .66736 .21608 L p F P
0 g
s
.392 .771 .991 r
.25987 .98307 m .25728 .98268 L .25833 .98316 L closepath p F P
0 g
s
.274 0 .057 r
.62003 .96347 m .62187 .96027 L .63251 .95683 L p F P
0 g
s
.349 0 .203 r
.63377 .95327 m .63251 .95683 L .62187 .96027 L p F P
0 g
s
.263 0 .007 r
.62003 .96347 m .62187 .96027 L p .609 .96703 L F P
0 g
s
.642 .721 .905 r
.53404 .73052 m .54516 .72739 L .54808 .73104 L p F P
0 g
s
.646 .748 .924 r
.54516 .72739 m .53404 .73052 L .53111 .7274 L p F P
0 g
s
.814 .738 .78 r
.1455 .797 m .14248 .80026 L .13901 .7963 L p F P
0 g
s
.814 .738 .78 r
.13901 .7963 m .14069 .79448 L .1455 .797 L p F P
0 g
s
.811 .74 .786 r
.1455 .797 m .14069 .79448 L .14772 .78714 L p F P
0 g
s
.715 .752 .881 r
.23344 .7328 m .23403 .73251 L .23986 .73475 L p F P
0 g
s
.721 .761 .885 r
.24417 .72743 m .23403 .73251 L .23986 .73475 L p F P
0 g
s
.721 .761 .885 r
.23986 .73475 m .24755 .73078 L .24417 .72743 L p F P
0 g
s
.856 .66 .637 r
.11781 .88792 m .12298 .89021 L .12096 .89615 L p F P
0 g
s
.853 .669 .653 r
.12298 .89021 m .11781 .88792 L .12019 .88189 L p F P
0 g
s
.924 .8 .705 r
.74874 .11225 m .74934 .11107 L .74677 .10728 L p F P
0 g
s
.463 .263 .522 r
.66649 .92673 m .66637 .92129 L .67641 .91708 L p F P
0 g
s
.481 .3 .558 r
.67603 .9114 m .67641 .91708 L .66637 .92129 L p F P
0 g
s
.475 .272 .524 r
.6616 .92866 m .66649 .92673 L .66637 .92129 L p F P
0 g
s
.627 .678 .879 r
.57331 .72949 m .57373 .73013 L .56383 .73469 L p F P
0 g
s
.627 .678 .879 r
.56383 .73469 m .56213 .73217 L .57331 .72949 L p F P
0 g
s
.666 .739 .905 r
.38745 .98579 m .39833 .98214 L .40145 .98549 L p F P
0 g
s
.677 .723 .885 r
.39833 .98214 m .38745 .98579 L .3843 .9825 L p F P
0 g
s
.935 .792 .678 r
.7465 .09856 m .74905 .10259 L .75143 .09712 L p F P
0 g
s
.935 .792 .678 r
.75143 .09712 m .74889 .09309 L .7465 .09856 L p F P
0 g
s
.412 .125 .364 r
.64493 .94667 m .6503 .94278 L .64529 .9446 L closepath p F P
0 g
s
.444 .187 .428 r
.656 .93744 m .65613 .93592 L p .64529 .9446 L F P
0 g
s
.444 .187 .428 r
.64529 .9446 m .6503 .94278 L .656 .93744 L p F P
0 g
s
.583 .057 0 r
.35312 .74156 m .35103 .74125 L .35183 .74091 L closepath p F P
0 g
s
.767 .33 .213 r
.17959 .95984 m .17878 .9596 L .17927 .95942 L closepath p F P
0 g
s
.603 .626 .847 r
.60734 .74453 m .59609 .7464 L .5932 .74126 L p F P
0 g
s
.337 0 .214 r
.63251 .95683 m .63377 .95327 L .63622 .95197 L p F P
0 g
s
.56 .54 .79 r
.66162 .7837 m .66452 .7907 L .65307 .79077 L p F P
0 g
s
.56 .54 .79 r
.66103 .7837 m .66162 .7837 L p .65307 .79077 L F P
0 g
s
.56 .54 .79 r
.65307 .79077 m .65224 .78875 L .66103 .7837 L p F P
0 g
s
.148 0 0 r
.31934 .73461 m .32074 .7347 L .31735 .7342 L p F P
0 g
s
.148 0 0 r
.31735 .7342 m .31154 .73299 L .31934 .73461 L p F P
0 g
s
.502 .081 .174 r
.44985 .74338 m .44269 .74234 L .4511 .7414 L closepath p F P
0 g
s
.517 .118 .224 r
.44269 .74234 m .44985 .74338 L p .43644 .74641 L F P
0 g
s
.899 .806 .747 r
.73886 .12879 m .74192 .124 L .74429 .12805 L p F P
0 g
s
.899 .806 .747 r
.74429 .12805 m .74145 .1325 L .73886 .12879 L p F P
0 g
s
.818 .738 .776 r
.13898 .80418 m .14248 .80026 L .13901 .7963 L p F P
0 g
s
.506 0 0 r
.20954 .97308 m .20379 .97142 L .19669 .96782 L p F P
0 g
s
.424 0 0 r
.19583 .9676 m .19669 .96782 L .20379 .97142 L p F P
0 g
s
.841 .806 .817 r
.71182 .18226 m .71421 .17979 L .71158 .17622 L p F P
0 g
s
.61 .637 .852 r
.5932 .74126 m .58767 .7423 L .59243 .73992 L closepath p F P
0 g
s
.613 .647 .86 r
.59031 .73636 m .59243 .73992 L .58767 .7423 L p F P
0 g
s
.613 .647 .86 r
.5791 .73864 m .59031 .73636 L p .58767 .7423 L F P
0 g
s
.665 .737 .904 r
.40145 .98549 m .41235 .98187 L .41546 .98526 L p F P
0 g
s
.675 .721 .884 r
.41235 .98187 m .40145 .98549 L .39833 .98214 L p F P
0 g
s
.085 0 0 r
.59489 .97258 m .58725 .97459 L .58372 .97551 L p F P
0 g
s
0 0 0 r
.58369 .97553 m .58725 .97459 L .58372 .97551 L closepath p F P
0 g
s
.484 .321 .585 r
.67856 .90412 m .67543 .90551 L .67603 .9114 L p F P
0 g
s
.592 .606 .834 r
.62367 .75403 m .6131 .7554 L .61022 .74988 L p F P
0 g
s
.503 .384 .65 r
.68222 .88218 m .69191 .87747 L p .68528 .8878 L F P
0 g
s
.503 .384 .65 r
.68528 .8878 m .68306 .88661 L .68222 .88218 L p F P
0 g
s
.511 .401 .666 r
.69151 .87558 m .69191 .87747 L .68222 .88218 L p F P
0 g
s
.511 .401 .666 r
.6857 .87311 m .69151 .87558 L p .68222 .88218 L F P
0 g
s
.227 .744 .741 r
.58725 .97459 m .58369 .97553 L .5809 .97603 L p F P
0 g
s
.203 .727 .73 r
.58369 .97553 m .5809 .97603 L .56971 .97875 L p F P
0 g
s
.841 .806 .817 r
.71158 .17622 m .70967 .1782 L .71182 .18226 L p F P
0 g
s
.836 .804 .821 r
.70237 .18555 m .70455 .18959 L .71182 .18226 L p F P
0 g
s
.836 .804 .821 r
.71182 .18226 m .70967 .1782 L .70237 .18555 L p F P
0 g
s
.738 .759 .869 r
.23344 .7328 m .22265 .73921 L .21926 .73565 L p F P
0 g
s
.924 .8 .705 r
.74677 .10728 m .7463 .10821 L .74874 .11225 L p F P
0 g
s
.912 .801 .724 r
.74302 .11403 m .74548 .11807 L .74874 .11225 L p F P
0 g
s
.912 .801 .724 r
.74874 .11225 m .7463 .10821 L .74302 .11403 L p F P
0 g
s
.799 .795 .848 r
.67795 .21334 m .68115 .21073 L .67847 .20714 L p F P
0 g
s
.799 .795 .848 r
.67847 .20714 m .67581 .20931 L .67795 .21334 L p F P
0 g
s
.796 .793 .849 r
.66736 .21608 m .67581 .20931 L .67795 .21334 L p F P
0 g
s
.841 .713 .722 r
.1175 .84078 m .12236 .84322 L .11821 .84973 L p F P
0 g
s
.838 .716 .729 r
.12192 .8342 m .1175 .84078 L .12236 .84322 L p F P
0 g
s
.832 .477 .383 r
.15871 .94935 m .1586 .94931 L .15696 .94431 L p F P
0 g
s
.835 .475 .374 r
.1512 .94227 m .15696 .94431 L .1586 .94931 L p F P
0 g
s
.717 .219 .054 r
.1904 .96596 m .18417 .96409 L .17959 .95984 L p F P
0 g
s
.688 .17 0 r
.17878 .9596 m .17959 .95984 L .18417 .96409 L p F P
0 g
s
.565 .551 .797 r
.65224 .78875 m .65018 .78397 L .66103 .7837 L closepath p F P
0 g
s
.424 0 0 r
.19263 .96756 m .19583 .9676 L p .20379 .97142 L F P
0 g
s
.645 .101 0 r
.19263 .96756 m .1904 .96596 L .19583 .9676 L closepath p F P
0 g
s
.616 .652 .863 r
.59031 .73636 m .5791 .73864 L .5762 .73397 L p F P
0 g
s
.765 .749 .839 r
.19759 .75033 m .19842 .74973 L .19591 .74853 L closepath p F P
0 g
s
.459 .233 .483 r
.65613 .93592 m .65799 .9352 L .6616 .92866 L p F P
0 g
s
.453 .227 .479 r
.66649 .92673 m .6616 .92866 L .65799 .9352 L p F P
0 g
s
.782 .751 .825 r
.18561 .75756 m .18325 .75505 L .1823 .75582 L closepath p F P
0 g
s
.662 .737 .905 r
.41546 .98526 m .42638 .98171 L .42947 .98509 L p F P
0 g
s
.672 .719 .885 r
.42638 .98171 m .41546 .98526 L .41235 .98187 L p F P
0 g
s
.337 0 .214 r
.63622 .95197 m .6444 .94913 L p .63251 .95683 L F P
0 g
s
.408 .105 .336 r
.63622 .95197 m .6444 .94913 L .64493 .94667 L closepath p F P
0 g
s
.511 .86 .992 r
.54168 .98254 m .54316 .98307 L .5548 .98072 L p F P
0 g
s
.476 .858 .98 r
.55571 .98103 m .5548 .98072 L .54316 .98307 L p F P
0 g
s
.427 .78 .997 r
.25987 .98307 m .26886 .98228 L p .2549 .98154 L F P
0 g
s
.427 .78 .997 r
.2549 .98154 m .25728 .98268 L .25987 .98307 L p F P
0 g
s
.809 .797 .841 r
.68768 .20511 m .68115 .21073 L .67847 .20714 L p F P
0 g
s
.821 .736 .771 r
.13423 .80166 m .13898 .80418 L .13287 .81125 L p F P
0 g
s
.818 .738 .776 r
.13901 .7963 m .13423 .80166 L .13898 .80418 L p F P
0 g
s
.635 .695 .888 r
.54808 .73104 m .55922 .72812 L .56213 .73217 L p F P
0 g
s
.639 .713 .901 r
.55922 .72812 m .54808 .73104 L .54516 .72739 L p F P
0 g
s
.758 .751 .846 r
.20503 .73902 m .20844 .74264 L .19842 .74973 L p F P
0 g
s
.758 .751 .846 r
.19416 .74668 m .20503 .73902 L p .19842 .74973 L F P
0 g
s
.758 .751 .846 r
.19842 .74973 m .19591 .74853 L .19416 .74668 L p F P
0 g
s
.833 .724 .744 r
.12684 .82747 m .12316 .83246 L .11971 .82813 L p F P
0 g
s
.833 .724 .744 r
.11971 .82813 m .12201 .825 L .12684 .82747 L p F P
0 g
s
.83 .727 .751 r
.12684 .82747 m .12201 .825 L .12727 .81817 L p F P
0 g
s
.855 .673 .654 r
.11511 .87957 m .12019 .88189 L .11781 .88792 L p F P
0 g
s
.852 .68 .668 r
.12019 .88189 m .11511 .87957 L .11784 .87344 L p F P
0 g
s
.846 .699 .699 r
.11816 .86064 m .11931 .85856 L .11579 .85688 L closepath p F P
0 g
s
.841 .706 .715 r
.11479 .85541 m .11821 .84973 L p .11931 .85856 L F P
0 g
s
.841 .706 .715 r
.11931 .85856 m .11579 .85688 L .11479 .85541 L p F P
0 g
s
.872 .807 .782 r
.73074 .14741 m .73125 .14675 L .73353 .15081 L p F P
0 g
s
.872 .807 .782 r
.73353 .15081 m .73334 .15106 L .73074 .14741 L p F P
0 g
s
.868 .807 .788 r
.7282 .15742 m .73334 .15106 L .73074 .14741 L p F P
0 g
s
.766 .78 .865 r
.65167 .22749 m .64508 .23197 L .64233 .2283 L p F P
0 g
s
.688 .17 0 r
.1755 .96024 m .17878 .9596 L p .18417 .96409 L F P
0 g
s
.765 .303 .151 r
.1755 .96024 m .17355 .9579 L .17878 .9596 L closepath p F P
0 g
s
.83 .802 .824 r
.70059 .18729 m .70237 .18555 L .70455 .18959 L p F P
0 g
s
.83 .802 .824 r
.70455 .18959 m .70324 .19088 L .70059 .18729 L p F P
0 g
s
.812 .798 .839 r
.68768 .20511 m .69221 .20114 L .68955 .19755 L p F P
0 g
s
.812 .798 .839 r
.68955 .19755 m .68552 .20108 L .68768 .20511 L p F P
0 g
s
.809 .797 .841 r
.67847 .20714 m .68552 .20108 L .68768 .20511 L p F P
0 g
s
.824 .801 .83 r
.69648 .19722 m .70324 .19088 L .70059 .18729 L p F P
0 g
s
.596 .778 .967 r
.28285 .9825 m .27225 .98425 L .26886 .98228 L p F P
0 g
s
.554 .782 .984 r
.27225 .98425 m .28285 .9825 L .2862 .98477 L p F P
0 g
s
.659 .738 .909 r
.42947 .98509 m .44041 .98164 L .44348 .98497 L p F P
0 g
s
.668 .72 .888 r
.44041 .98164 m .42947 .98509 L .42638 .98171 L p F P
0 g
s
.495 0 0 r
.3337 .73845 m .32746 .73739 L .32074 .7347 L p F P
0 g
s
.396 0 0 r
.32746 .73739 m .32074 .7347 L .31735 .7342 L p F P
0 g
s
.824 .801 .83 r
.70059 .18729 m .6943 .19318 L .69648 .19722 L p F P
0 g
s
.82 .8 .833 r
.68955 .19755 m .6943 .19318 L .69648 .19722 L p F P
0 g
s
.82 .8 .833 r
.69648 .19722 m .69221 .20114 L .68955 .19755 L p F P
0 g
s
.152 .645 .916 r
.2377 .97865 m .23735 .97856 L .22718 .97752 L p F P
0 g
s
.074 .611 .858 r
.23735 .97856 m .22718 .97752 L .22365 .97648 L p F P
0 g
s
.679 .278 .278 r
.36481 .74627 m .3574 .74553 L .35312 .74156 L p F P
0 g
s
.719 .341 .333 r
.35103 .74125 m .35312 .74156 L .3574 .74553 L p F P
0 g
s
.341 .737 .983 r
.2549 .98154 m .25245 .98155 L .25728 .98268 L closepath p F P
0 g
s
0 .496 .758 r
.21727 .97487 m .22365 .97648 L .22012 .97515 L p F P
0 g
s
.664 .723 .893 r
.45445 .98164 m .44348 .98497 L .44041 .98164 L p F P
0 g
s
.654 .742 .914 r
.44348 .98497 m .45445 .98164 L .4575 .9849 L p F P
0 g
s
.433 .183 .433 r
.656 .93744 m .65799 .9352 L .65613 .93592 L closepath p F P
0 g
s
.193 0 0 r
.60881 .96725 m .61407 .96551 L .609 .96703 L closepath p F P
0 g
s
.263 0 .007 r
.609 .96703 m .61407 .96551 L .62003 .96347 L p F P
0 g
s
.578 .576 .814 r
.63017 .76565 m .64154 .76477 L p .64067 .77118 L F P
0 g
s
.578 .579 .817 r
.63887 .75913 m .64154 .76477 L .63017 .76565 L p F P
0 g
s
.578 .579 .817 r
.63017 .76565 m .6296 .76447 L .63887 .75913 L p F P
0 g
s
.846 .552 .492 r
.13864 .93108 m .13979 .92813 L p .14449 .93504 L F P
0 g
s
.854 .566 .5 r
.13864 .93108 m .13849 .92762 L .13979 .92813 L closepath p F P
0 g
s
.517 .139 .262 r
.4511 .7414 m .4634 .73946 L .4616 .74307 L p F P
0 g
s
.517 .139 .262 r
.44985 .74338 m .4511 .7414 L p .4616 .74307 L F P
0 g
s
.236 0 0 r
.46393 .73893 m .4634 .73946 L .4511 .7414 L p F P
0 g
s
.85 .699 .695 r
.11589 .86487 m .11816 .86064 L .11579 .85688 L p F P
0 g
s
.894 .806 .754 r
.74037 .13412 m .74145 .1325 L .73886 .12879 L p F P
0 g
s
.65 .775 .94 r
.26161 .72944 m .27226 .72602 L .27562 .7289 L p F P
0 g
s
.629 .778 .952 r
.27226 .72602 m .26161 .72944 L .25825 .72626 L p F P
0 g
s
.691 .766 .908 r
.24755 .73078 m .25825 .72626 L .26161 .72944 L p F P
0 g
s
.504 .384 .65 r
.68345 .88867 m .68306 .88661 L .68528 .8878 L closepath p F P
0 g
s
.719 .341 .333 r
.34837 .7441 m .35103 .74125 L p .3574 .74553 L F P
0 g
s
.678 .25 .223 r
.34837 .7441 m .34398 .74035 L .35103 .74125 L closepath p F P
0 g
s
.825 .733 .763 r
.13287 .81125 m .13119 .81329 L .12771 .80919 L p F P
0 g
s
.825 .733 .763 r
.12771 .80919 m .12808 .80875 L .13287 .81125 L p F P
0 g
s
.821 .736 .771 r
.13287 .81125 m .12808 .80875 L .13423 .80166 L p F P
0 g
s
.565 .551 .798 r
.66103 .7837 m .65018 .78397 L .64817 .77929 L p F P
0 g
s
.604 .778 .964 r
.2862 .98477 m .29687 .98235 L .30019 .98489 L p F P
0 g
s
.634 .769 .945 r
.29687 .98235 m .2862 .98477 L .28285 .9825 L p F P
0 g
s
.798 .381 .257 r
.17355 .9579 m .16756 .95594 L .16468 .95126 L p F P
0 g
s
.795 .371 .243 r
.15871 .94935 m .16468 .95126 L .16756 .95594 L p F P
0 g
s
0 0 0 r
.58725 .97459 m .59482 .97261 L .59489 .97258 L closepath p F P
0 g
s
.227 .744 .741 r
.59482 .97261 m .58725 .97459 L p .5809 .97603 L F P
0 g
s
.854 .684 .67 r
.11284 .87108 m .11784 .87344 L .11511 .87957 L p F P
0 g
s
.851 .691 .682 r
.11784 .87344 m .11284 .87108 L .11589 .86487 L p F P
0 g
s
.56 .784 .983 r
.27562 .7289 m .28622 .72693 L .28958 .72931 L p F P
0 g
s
.497 .776 .994 r
.28622 .72693 m .27562 .7289 L .27226 .72602 L p F P
0 g
s
.857 .808 .801 r
.72332 .16537 m .72251 .16426 L .72264 .16411 L closepath p F P
0 g
s
.649 .749 .923 r
.4575 .9849 m .46849 .9817 L .47152 .98482 L p F P
0 g
s
.659 .728 .9 r
.46849 .9817 m .4575 .9849 L .45445 .98164 L p F P
0 g
s
.582 .588 .824 r
.63866 .75869 m .63887 .75913 L .6296 .76447 L p F P
0 g
s
.582 .588 .824 r
.6296 .76447 m .62729 .75977 L .63866 .75869 L p F P
0 g
s
.837 .724 .74 r
.12192 .8342 m .12316 .83246 L .11971 .82813 L p F P
0 g
s
.418 .854 .932 r
.5809 .97603 m .56971 .97875 L .56687 .97841 L p F P
0 g
s
.399 .845 .925 r
.55571 .98103 m .56687 .97841 L .56971 .97875 L p F P
0 g
s
.631 .688 .885 r
.57331 .72949 m .56213 .73217 L .55922 .72812 L p F P
0 g
s
.885 .805 .765 r
.73357 .13635 m .73594 .14039 L .74037 .13412 L p F P
0 g
s
.885 .805 .765 r
.74037 .13412 m .73802 .13007 L .73357 .13635 L p F P
0 g
s
.894 .806 .754 r
.73886 .12879 m .73802 .13007 L .74037 .13412 L p F P
0 g
s
.766 .78 .865 r
.64233 .2283 m .6494 .22351 L .65167 .22749 L p F P
0 g
s
.768 .782 .864 r
.65167 .22749 m .65622 .22436 L .65349 .2207 L p F P
0 g
s
.768 .782 .864 r
.65349 .2207 m .6494 .22351 L .65167 .22749 L p F P
0 g
s
.093 0 0 r
.61407 .96551 m .60881 .96725 L .60612 .96936 L p F P
0 g
s
.09 0 0 r
.59489 .97258 m .60612 .96936 L .60881 .96725 L p F P
0 g
s
.53 .469 .732 r
.68048 .8344 m .68601 .83135 L p .68584 .84045 L F P
0 g
s
.53 .469 .732 r
.68584 .84045 m .68217 .83984 L .68048 .8344 L p F P
0 g
s
.535 .481 .742 r
.68048 .8344 m .67918 .83042 L .68601 .83135 L closepath p F P
0 g
s
.594 .71 .924 r
.58903 .23662 m .6003 .23431 L .60313 .23811 L p F P
0 g
s
.868 .807 .788 r
.73074 .14741 m .72593 .15337 L .7282 .15742 L p F P
0 g
s
.863 .806 .792 r
.72035 .16007 m .72264 .16411 L .7282 .15742 L p F P
0 g
s
.863 .806 .792 r
.7282 .15742 m .72593 .15337 L .72035 .16007 L p F P
0 g
s
.859 .593 .535 r
.12794 .91779 m .13333 .91997 L .13305 .92546 L p F P
0 g
s
.857 .612 .567 r
.13333 .91997 m .12794 .91779 L .1287 .91218 L p F P
0 g
s
.857 .591 .535 r
.13849 .92762 m .13305 .92546 L .13333 .91997 L p F P
0 g
s
.683 .769 .916 r
.25825 .72626 m .24755 .73078 L .24417 .72743 L p F P
0 g
s
.86 .615 .567 r
.12337 .90996 m .1287 .91218 L .12794 .91779 L p F P
0 g
s
.857 .63 .594 r
.1287 .91218 m .12337 .90996 L .12459 .90423 L p F P
0 g
s
.829 .733 .759 r
.12727 .81817 m .13119 .81329 L .12771 .80919 L p F P
0 g
s
.535 .481 .743 r
.68601 .83135 m .67918 .83042 L .6779 .82652 L p F P
0 g
s
.527 .446 .708 r
.6852 .85007 m .68437 .84989 L .68506 .84954 L closepath p F P
0 g
s
.534 .46 .719 r
.68287 .84207 m .68506 .84954 L .68437 .84989 L p F P
0 g
s
.53 .469 .732 r
.68287 .84207 m .68217 .83984 L .68584 .84045 L closepath p F P
0 g
s
.535 .481 .743 r
.6779 .82652 m .68495 .82257 L p .68601 .83135 L F P
0 g
s
.539 .492 .752 r
.6779 .82652 m .67621 .82163 L .68495 .82257 L closepath p F P
0 g
s
.75 .753 .854 r
.21176 .74047 m .20844 .74264 L .20503 .73902 L p F P
0 g
s
.525 .456 .721 r
.68506 .84954 m .68287 .84207 L .68584 .84045 L p F P
0 g
s
.858 .567 .496 r
.13849 .92762 m .13864 .93108 L .13795 .93267 L p F P
0 g
s
.858 .567 .496 r
.13305 .92546 m .13849 .92762 L p .13795 .93267 L F P
0 g
s
.382 .082 .327 r
.6444 .94913 m .64493 .94667 L .6503 .94278 L p F P
0 g
s
.642 .759 .934 r
.47152 .98482 m .48254 .98176 L .48555 .98471 L p F P
0 g
s
.653 .735 .91 r
.48254 .98176 m .47152 .98482 L .46849 .9817 L p F P
0 g
s
.509 .401 .668 r
.69151 .87558 m .6857 .87311 L .69047 .87076 L closepath p F P
0 g
s
.518 .418 .681 r
.68885 .86387 m .69047 .87076 L .6857 .87311 L p F P
0 g
s
.796 .747 .808 r
.16351 .77194 m .16128 .77397 L .15781 .7702 L p F P
0 g
s
.802 .748 .802 r
.15534 .77962 m .16128 .77397 L .15781 .7702 L p F P
0 g
s
.837 .724 .74 r
.11971 .82813 m .11715 .83171 L .12192 .8342 L p F P
0 g
s
.841 .72 .731 r
.11715 .83171 m .12192 .8342 L .1175 .84078 L p F P
0 g
s
.494 .362 .63 r
.68528 .8878 m .68345 .88867 L .68447 .89496 L p F P
0 g
s
.796 .747 .808 r
.15781 .7702 m .1587 .76939 L .16351 .77194 L p F P
0 g
s
.794 .749 .812 r
.16765 .76147 m .1587 .76939 L .16351 .77194 L p F P
0 g
s
.794 .749 .812 r
.17216 .76395 m .16765 .76147 L p .16351 .77194 L F P
0 g
s
.794 .749 .812 r
.16351 .77194 m .1723 .76409 L .17216 .76395 L p F P
0 g
s
.857 .646 .617 r
.12459 .90423 m .11933 .90199 L .12096 .89615 L p F P
0 g
s
.859 .633 .594 r
.11933 .90199 m .12459 .90423 L .12337 .90996 L p F P
0 g
s
.635 .769 .944 r
.30019 .98489 m .31091 .98195 L .31419 .98473 L p F P
0 g
s
.657 .759 .925 r
.31091 .98195 m .30019 .98489 L .29687 .98235 L p F P
0 g
s
.845 .708 .712 r
.11821 .84973 m .11479 .85541 L .11137 .85054 L p F P
0 g
s
.845 .708 .712 r
.11137 .85054 m .11331 .84731 L .11821 .84973 L p F P
0 g
s
.841 .713 .722 r
.11821 .84973 m .11331 .84731 L .1175 .84078 L p F P
0 g
s
.416 0 0 r
.31154 .73299 m .31735 .7342 L .31494 .7344 L p F P
0 g
s
.773 .753 .835 r
.19591 .74853 m .19416 .74668 L .19343 .74723 L closepath p F P
0 g
s
.925 .794 .697 r
.74418 .10334 m .7465 .09856 L .74905 .10259 L p F P
0 g
s
.925 .794 .697 r
.74905 .10259 m .74677 .10728 L .74418 .10334 L p F P
0 g
s
.538 .493 .753 r
.68495 .82257 m .67621 .82163 L .6751 .81842 L p F P
0 g
s
.805 .746 .798 r
.15534 .77962 m .15019 .78464 L .14671 .78086 L p F P
0 g
s
.805 .746 .798 r
.14671 .78086 m .15061 .77706 L .15534 .77962 L p F P
0 g
s
.802 .748 .802 r
.15781 .7702 m .15061 .77706 L .15534 .77962 L p F P
0 g
s
.787 .749 .818 r
.1723 .76409 m .17236 .76405 L .17216 .76395 L closepath p F P
0 g
s
.78 .751 .827 r
.17756 .75324 m .1823 .75582 L .17236 .76405 L p F P
0 g
s
.78 .751 .827 r
.16884 .76044 m .17756 .75324 L p .17236 .76405 L F P
0 g
s
.78 .751 .827 r
.17236 .76405 m .17216 .76395 L .16884 .76044 L p F P
0 g
s
.495 .347 .609 r
.68447 .89496 m .68531 .90107 L .67856 .90412 L p F P
0 g
s
.484 .321 .585 r
.67603 .9114 m .68163 .90892 L .67856 .90412 L p F P
0 g
s
.481 .32 .586 r
.68531 .90107 m .67856 .90412 L .68163 .90892 L p F P
0 g
s
.905 .801 .735 r
.73946 .11997 m .74192 .124 L .74548 .11807 L p F P
0 g
s
.905 .801 .735 r
.74548 .11807 m .74302 .11403 L .73946 .11997 L p F P
0 g
s
.412 .156 .414 r
.65799 .9352 m .66633 .93191 L p .65564 .9408 L F P
0 g
s
.412 .156 .414 r
.65564 .9408 m .656 .93744 L .65799 .9352 L p F P
0 g
s
.453 .227 .479 r
.65799 .9352 m .66633 .93191 L .66649 .92673 L p F P
0 g
s
.791 .752 .817 r
.17216 .76395 m .16884 .76044 L .16765 .76147 L closepath p F P
0 g
s
.538 .493 .753 r
.6751 .81842 m .68266 .81412 L p .68495 .82257 L F P
0 g
s
.542 .504 .762 r
.6751 .81842 m .67327 .81335 L .68266 .81412 L closepath p F P
0 g
s
.357 .741 .987 r
.30202 .73013 m .29776 .72917 L .28958 .72931 L p F P
0 g
s
.424 .727 .989 r
.29776 .72917 m .28958 .72931 L .28622 .72693 L p F P
0 g
s
.519 .442 .708 r
.68506 .84954 m .69448 .84444 L p .69494 .8526 L F P
0 g
s
.519 .442 .708 r
.69494 .8526 m .6852 .85007 L .68506 .84954 L p F P
0 g
s
.525 .456 .721 r
.69381 .84216 m .69448 .84444 L .68506 .84954 L p F P
0 g
s
.525 .456 .721 r
.68584 .84045 m .69381 .84216 L p .68506 .84954 L F P
0 g
s
.81 .746 .793 r
.14772 .78714 m .15019 .78464 L .14671 .78086 L p F P
0 g
s
.633 .773 .947 r
.48555 .98471 m .49659 .98179 L .49958 .98451 L p F P
0 g
s
.647 .746 .922 r
.49659 .98179 m .48555 .98471 L .48254 .98176 L p F P
0 g
s
.519 .441 .708 r
.68704 .85679 m .6852 .85007 L .69494 .8526 L closepath p F P
0 g
s
.654 .76 .927 r
.31419 .98473 m .32495 .98138 L .3282 .98438 L p F P
0 g
s
.671 .749 .909 r
.32495 .98138 m .31419 .98473 L .31091 .98195 L p F P
0 g
s
.747 .771 .873 r
.63256 .23434 m .63115 .2352 L .62837 .23147 L p F P
0 g
s
.721 .763 .886 r
.61717 .23733 m .62837 .23147 L .63115 .2352 L p F P
0 g
s
.781 .786 .856 r
.66477 .21803 m .65622 .22436 L .65349 .2207 L p F P
0 g
s
.859 .649 .618 r
.11578 .89387 m .12096 .89615 L .11933 .90199 L p F P
0 g
s
.856 .66 .637 r
.12096 .89615 m .11578 .89387 L .11781 .88792 L p F P
0 g
s
.752 .757 .857 r
.21585 .73213 m .20659 .73801 L .21176 .74047 L p F P
0 g
s
.752 .757 .857 r
.21176 .74047 m .21926 .73565 L .21585 .73213 L p F P
0 g
s
.75 .753 .854 r
.20503 .73902 m .20659 .73801 L .21176 .74047 L p F P
0 g
s
.603 .626 .847 r
.5932 .74126 m .60446 .73936 L .60734 .74453 L p F P
0 g
s
.606 .635 .853 r
.6019 .73483 m .60446 .73936 L .5932 .74126 L p F P
0 g
s
.606 .635 .853 r
.5932 .74126 m .59243 .73992 L .6019 .73483 L p F P
0 g
s
.228 0 0 r
.47535 .73716 m .47036 .73808 L .46393 .73893 L p F P
0 g
s
.301 0 0 r
.47036 .73808 m .4634 .73946 L .46393 .73893 L closepath p F P
0 g
s
.842 .519 .441 r
.1512 .94227 m .14548 .94021 L .14449 .93504 L p F P
0 g
s
.844 .519 .438 r
.13877 .93297 m .14449 .93504 L .14548 .94021 L p F P
0 g
s
.846 .552 .492 r
.14449 .93504 m .13877 .93297 L .13864 .93108 L p F P
0 g
s
.436 .176 .42 r
.6503 .94278 m .65564 .9408 L .656 .93744 L closepath p F P
0 g
s
.505 .864 .988 r
.5548 .98072 m .55571 .98103 L .56687 .97841 L p F P
0 g
s
.812 .743 .788 r
.14305 .78457 m .14772 .78714 L .14069 .79448 L p F P
0 g
s
.81 .746 .793 r
.14671 .78086 m .14305 .78457 L .14772 .78714 L p F P
0 g
s
.592 .606 .834 r
.61022 .74988 m .62154 .7484 L p .62367 .75403 L F P
0 g
s
.593 .61 .838 r
.61866 .74291 m .62154 .7484 L .61022 .74988 L p F P
0 g
s
.593 .61 .838 r
.61631 .74322 m .61866 .74291 L p .61022 .74988 L F P
0 g
s
.593 .61 .838 r
.61022 .74988 m .6089 .74738 L .61631 .74322 L p F P
0 g
s
.738 .759 .869 r
.2326 .73195 m .23344 .7328 L p .21926 .73565 L F P
0 g
s
.715 .752 .881 r
.23344 .7328 m .23403 .73251 L .2326 .73195 L closepath p F P
0 g
s
.382 .082 .327 r
.6503 .94278 m .65564 .9408 L p .6444 .94913 L F P
0 g
s
.568 .561 .806 r
.64817 .77929 m .6473 .77735 L .6518 .77717 L closepath p F P
0 g
s
.565 .551 .798 r
.64817 .77929 m .6518 .77717 L p .66103 .7837 L F P
0 g
s
.444 0 0 r
.33459 .73818 m .33573 .73887 L .34398 .74035 L p F P
0 g
s
.704 .3 .279 r
.34398 .74035 m .34837 .7441 L .34829 .74422 L p F P
0 g
s
.704 .3 .279 r
.33573 .73887 m .34398 .74035 L p .34829 .74422 L F P
0 g
s
.665 .75 .914 r
.3282 .98438 m .339 .98074 L .34222 .98392 L p F P
0 g
s
.679 .739 .896 r
.339 .98074 m .3282 .98438 L .32495 .98138 L p F P
0 g
s
.831 .73 .753 r
.12255 .81565 m .12727 .81817 L .12201 .825 L p F P
0 g
s
.829 .733 .759 r
.12771 .80919 m .12255 .81565 L .12727 .81817 L p F P
0 g
s
.854 .694 .684 r
.11098 .86247 m .11589 .86487 L .11284 .87108 L p F P
0 g
s
.85 .699 .695 r
.11435 .85617 m .11098 .86247 L .11589 .86487 L p F P
0 g
s
.85 .699 .695 r
.11579 .85688 m .11435 .85617 L p .11589 .86487 L F P
0 g
s
.748 .772 .872 r
.63256 .23434 m .64233 .2283 L .63957 .22458 L p F P
0 g
s
.748 .772 .872 r
.63957 .22458 m .63008 .23043 L .63256 .23434 L p F P
0 g
s
.747 .771 .873 r
.62837 .23147 m .63008 .23043 L .63256 .23434 L p F P
0 g
s
.71 .754 .886 r
.24078 .72413 m .24417 .72743 L .23403 .73251 L p F P
0 g
s
.71 .754 .886 r
.23005 .72936 m .24078 .72413 L p .23403 .73251 L F P
0 g
s
.71 .754 .886 r
.23403 .73251 m .2326 .73195 L .23005 .72936 L p F P
0 g
s
.621 .791 .964 r
.49958 .98451 m .51065 .98171 L .51362 .98414 L p F P
0 g
s
.638 .761 .937 r
.51065 .98171 m .49958 .98451 L .49659 .98179 L p F P
0 g
s
.661 .342 .423 r
.40164 .74806 m .40953 .748 L .40841 .75238 L p F P
0 g
s
.661 .342 .423 r
.40841 .75238 m .40485 .7524 L .40164 .74806 L p F P
0 g
s
.665 .343 .418 r
.39529 .74804 m .40164 .74806 L .40485 .7524 L p F P
0 g
s
.665 .343 .418 r
.40485 .7524 m .39409 .75237 L .39529 .74804 L p F P
0 g
s
.678 .356 .422 r
.38907 .74788 m .39529 .74804 L .39409 .75237 L p F P
0 g
s
.783 .754 .827 r
.1798 .75143 m .17756 .75324 L .1823 .75582 L p F P
0 g
s
.783 .754 .827 r
.1823 .75582 m .18325 .75505 L .1798 .75143 L p F P
0 g
s
.542 .504 .763 r
.68266 .81412 m .67327 .81335 L .67209 .81008 L p F P
0 g
s
.68 .302 .323 r
.37775 .74733 m .3673 .74652 L .36569 .74486 L p F P
0 g
s
.688 .299 .305 r
.3673 .74652 m .36481 .74627 L .36569 .74486 L closepath p F P
0 g
s
.414 .764 .995 r
.25245 .98155 m .2549 .98154 L .25147 .97963 L p F P
0 g
s
.414 .764 .995 r
.25147 .97963 m .24523 .97997 L .25245 .98155 L p F P
0 g
s
.193 .684 .922 r
.241 .98005 m .24523 .97997 L .25245 .98155 L p F P
0 g
s
.642 .324 .418 r
.40953 .748 m .41586 .74776 L .41961 .75195 L p F P
0 g
s
.642 .324 .418 r
.41961 .75195 m .40841 .75238 L .40953 .748 L p F P
0 g
s
.601 .037 0 r
.1904 .96596 m .19263 .96756 L .18898 .96715 L p F P
0 g
s
.601 .037 0 r
.18898 .96715 m .18417 .96409 L .1904 .96596 L p F P
0 g
s
.775 .755 .835 r
.19343 .74723 m .18325 .75505 L .1798 .75143 L p F P
0 g
s
.672 .742 .903 r
.34222 .98392 m .35305 .98007 L .35625 .98342 L p F P
0 g
s
.684 .729 .884 r
.35305 .98007 m .34222 .98392 L .339 .98074 L p F P
0 g
s
.329 .745 .978 r
.24523 .97997 m .2377 .97865 L .241 .98005 L closepath p F P
0 g
s
.855 .804 .8 r
.71989 .1606 m .72035 .16007 L .72264 .16411 L p F P
0 g
s
.855 .804 .8 r
.72264 .16411 m .72251 .16426 L .71989 .1606 L p F P
0 g
s
.85 .804 .805 r
.71633 .17109 m .72251 .16426 L .71989 .1606 L p F P
0 g
s
.469 .291 .556 r
.68163 .90892 m .67603 .9114 L .67641 .91708 L p F P
0 g
s
.511 .86 .992 r
.5548 .98072 m .55283 .97993 L .54168 .98254 L p F P
0 g
s
.586 .835 .992 r
.55283 .97993 m .54168 .98254 L .53877 .98089 L p F P
0 g
s
.575 .84 .995 r
.52765 .98352 m .53877 .98089 L .54168 .98254 L p F P
0 g
s
.603 .814 .981 r
.51362 .98414 m .52471 .98144 L .52765 .98352 L p F P
0 g
s
.628 .781 .955 r
.52471 .98144 m .51362 .98414 L .51065 .98171 L p F P
0 g
s
.846 .706 .708 r
.11579 .85688 m .11479 .85541 L .11435 .85617 L closepath p F P
0 g
s
.678 .356 .422 r
.39409 .75237 m .39195 .75231 L .38907 .74788 L p F P
0 g
s
.692 .382 .446 r
.38041 .74748 m .38907 .74788 L .39195 .75231 L p F P
0 g
s
.676 .735 .895 r
.35625 .98342 m .3671 .97945 L .37027 .98294 L p F P
0 g
s
.686 .721 .875 r
.3671 .97945 m .35625 .98342 L .35305 .98007 L p F P
0 g
s
.574 .567 .808 r
.64441 .77095 m .64067 .77118 L .64373 .76944 L closepath p F P
0 g
s
.578 .576 .814 r
.64154 .76477 m .64373 .76944 L .64067 .77118 L p F P
0 g
s
.612 .806 .975 r
.53877 .98089 m .52765 .98352 L .52471 .98144 L p F P
0 g
s
.514 .428 .696 r
.68704 .85679 m .69494 .8526 L p .69124 .86263 L F P
0 g
s
.514 .428 .696 r
.69124 .86263 m .6883 .86171 L .68704 .85679 L p F P
0 g
s
.542 .504 .763 r
.67209 .81008 m .67913 .806 L p .68266 .81412 L F P
0 g
s
.546 .515 .772 r
.67209 .81008 m .67034 .80548 L .67913 .806 L closepath p F P
0 g
s
.858 .663 .638 r
.1127 .88561 m .11781 .88792 L .11578 .89387 L p F P
0 g
s
.855 .673 .654 r
.11781 .88792 m .1127 .88561 L .11511 .87957 L p F P
0 g
s
.816 .741 .782 r
.14069 .79448 m .13901 .7963 L .13553 .7924 L p F P
0 g
s
.816 .741 .782 r
.13553 .7924 m .13596 .79194 L .14069 .79448 L p F P
0 g
s
.812 .743 .788 r
.14069 .79448 m .13596 .79194 L .14305 .78457 L p F P
0 g
s
.64 .324 .42 r
.41586 .74776 m .42324 .74745 L .42216 .75184 L p F P
0 g
s
.64 .324 .42 r
.42216 .75184 m .41961 .75195 L .41586 .74776 L p F P
0 g
s
.568 .562 .807 r
.6518 .77717 m .6473 .77735 L .64441 .77095 L p F P
0 g
s
.677 .728 .889 r
.38128 .97906 m .3843 .9825 L p .37027 .98294 L F P
0 g
s
.677 .728 .889 r
.37027 .98294 m .38076 .97905 L .38128 .97906 L p F P
0 g
s
.687 .715 .87 r
.38076 .97905 m .37027 .98294 L .3671 .97945 L p F P
0 g
s
.608 .642 .858 r
.60158 .73428 m .6019 .73483 L .59243 .73992 L p F P
0 g
s
.608 .642 .858 r
.59243 .73992 m .59031 .73636 L .60158 .73428 L p F P
0 g
s
.879 .804 .771 r
.72887 .14272 m .73125 .14675 L .73594 .14039 L p F P
0 g
s
.879 .804 .771 r
.73594 .14039 m .73357 .13635 L .72887 .14272 L p F P
0 g
s
.75 .268 .096 r
.17355 .9579 m .1755 .96024 L .17205 .9605 L p F P
0 g
s
.75 .268 .096 r
.16756 .95594 m .17355 .9579 L p .17205 .9605 L F P
0 g
s
.616 .652 .863 r
.5762 .73397 m .58743 .73163 L .59031 .73636 L p F P
0 g
s
.62 .665 .872 r
.58453 .72703 m .58743 .73163 L .5762 .73397 L p F P
0 g
s
.62 .665 .872 r
.57637 .7288 m .58453 .72703 L p .5762 .73397 L F P
0 g
s
.62 .665 .872 r
.5762 .73397 m .57373 .73013 L .57637 .7288 L p F P
0 g
s
.439 .216 .477 r
.66633 .93191 m .66649 .92673 L .67654 .92253 L p F P
0 g
s
.463 .263 .522 r
.67641 .91708 m .67654 .92253 L .66649 .92673 L p F P
0 g
s
.494 .362 .63 r
.68447 .89496 m .69087 .89192 L .68528 .8878 L p F P
0 g
s
.492 .362 .632 r
.69315 .88397 m .68528 .8878 L .69087 .89192 L p F P
0 g
s
.503 .384 .65 r
.69191 .87747 m .69315 .88397 L .68528 .8878 L p F P
0 g
s
.82 .741 .777 r
.13423 .80166 m .13901 .7963 L .13553 .7924 L p F P
0 g
s
.835 .475 .374 r
.1586 .94931 m .1529 .94726 L .1512 .94227 L p F P
0 g
s
.835 .472 .367 r
.14548 .94021 m .1512 .94227 L .1529 .94726 L p F P
0 g
s
.581 .59 .827 r
.63866 .75869 m .62729 .75977 L .62441 .75394 L p F P
0 g
s
.72 .761 .885 r
.62837 .23147 m .61717 .23733 L .61436 .23355 L p F P
0 g
s
.68 .746 .901 r
.60313 .23811 m .61436 .23355 L .61717 .23733 L p F P
0 g
s
.68 .745 .9 r
.61436 .23355 m .60313 .23811 L .6003 .23431 L p F P
0 g
s
.285 0 0 r
.2102 .97323 m .20954 .97308 L .20988 .97314 L closepath p F P
0 g
s
.677 .723 .885 r
.39598 .97938 m .39833 .98214 L p .3843 .9825 L F P
0 g
s
.677 .723 .885 r
.3843 .9825 m .39278 .97935 L .39598 .97938 L p F P
0 g
s
.677 .729 .889 r
.3843 .9825 m .39278 .97935 L .38128 .97906 L closepath p F P
0 g
s
.738 .759 .869 r
.21926 .73565 m .22884 .73005 L .2326 .73195 L p F P
0 g
s
.736 .759 .871 r
.2326 .73195 m .23005 .72936 L .22884 .73005 L closepath p F P
0 g
s
.784 .787 .855 r
.66477 .21803 m .66736 .21608 L .66464 .21243 L p F P
0 g
s
.784 .787 .855 r
.66464 .21243 m .66251 .21403 L .66477 .21803 L p F P
0 g
s
.781 .786 .856 r
.65349 .2207 m .66251 .21403 L .66477 .21803 L p F P
0 g
s
.613 .082 0 r
.33573 .73887 m .3337 .73845 L .33459 .73818 L closepath p F P
0 g
s
.093 0 0 r
.6198 .96377 m .61407 .96551 L p .60612 .96936 L F P
0 g
s
.207 0 0 r
.61407 .96551 m .6198 .96377 L .62003 .96347 L closepath p F P
0 g
s
.692 .361 .41 r
.37954 .75016 m .37775 .74733 L .38041 .74748 L closepath p F P
0 g
s
.692 .382 .446 r
.37954 .75016 m .38041 .74748 L p .39195 .75231 L F P
0 g
s
.616 .3 .412 r
.42216 .75184 m .42324 .74745 L .43266 .7467 L p F P
0 g
s
.646 .748 .924 r
.53111 .7274 m .54223 .72413 L .54516 .72739 L p F P
0 g
s
.649 .786 .947 r
.54223 .72413 m .53111 .7274 L .52817 .72484 L p F P
0 g
s
.644 .798 .957 r
.51707 .72825 m .52817 .72484 L .53111 .7274 L p F P
0 g
s
.629 .855 .985 r
.52817 .72484 m .51707 .72825 L .51411 .72664 L p F P
0 g
s
.608 .862 .991 r
.50304 .73001 m .51411 .72664 L .51707 .72825 L p F P
0 g
s
.143 .632 .916 r
.2102 .97323 m .22012 .97515 L .21675 .97363 L p F P
0 g
s
.143 .632 .916 r
.20954 .97308 m .2102 .97323 L p .21675 .97363 L F P
0 g
s
.675 .721 .884 r
.41025 .97936 m .41235 .98187 L p .39833 .98214 L F P
0 g
s
.675 .721 .884 r
.39833 .98214 m .40584 .97939 L .41025 .97936 L p F P
0 g
s
.675 .723 .886 r
.39833 .98214 m .40584 .97939 L .39598 .97938 L closepath p F P
0 g
s
.596 .618 .844 r
.6089 .74738 m .60734 .74453 L .61631 .74322 L closepath p F P
0 g
s
.546 .515 .772 r
.67913 .806 m .67034 .80548 L .66882 .80148 L p F P
0 g
s
.85 .804 .805 r
.71989 .1606 m .71405 .16705 L .71633 .17109 L p F P
0 g
s
.846 .803 .809 r
.70895 .17257 m .71405 .16705 L .71633 .17109 L p F P
0 g
s
.846 .803 .809 r
.71633 .17109 m .71158 .17622 L .70895 .17257 L p F P
0 g
s
.843 .716 .724 r
.1127 .83831 m .1175 .84078 L .11331 .84731 L p F P
0 g
s
.841 .72 .731 r
.1175 .84078 m .1127 .83831 L .11715 .83171 L p F P
0 g
s
.704 .385 .435 r
.37775 .74733 m .37954 .75016 L .37914 .75177 L p F P
0 g
s
.704 .385 .435 r
.3673 .74652 m .37775 .74733 L p .37914 .75177 L F P
0 g
s
.848 .709 .709 r
.11435 .85617 m .11479 .85541 L .11137 .85054 L p F P
0 g
s
.795 .79 .848 r
.67581 .20931 m .66736 .21608 L .66464 .21243 L p F P
0 g
s
.514 .428 .696 r
.68885 .86387 m .6883 .86171 L .69124 .86263 L closepath p F P
0 g
s
.456 .065 .208 r
.4616 .74307 m .4634 .73946 L .47036 .73808 L p F P
0 g
s
.735 .761 .873 r
.22884 .73005 m .21926 .73565 L .21585 .73213 L p F P
0 g
s
.308 0 0 r
.2063 .9723 m .20379 .97142 L .20954 .97308 L closepath p F P
0 g
s
.143 .632 .916 r
.2063 .9723 m .20954 .97308 L p .21675 .97363 L F P
0 g
s
.775 .755 .835 r
.1798 .75143 m .18867 .74465 L .19343 .74723 L p F P
0 g
s
.774 .756 .837 r
.19072 .74311 m .18867 .74465 L .19343 .74723 L p F P
0 g
s
.774 .756 .837 r
.19343 .74723 m .19416 .74668 L .19072 .74311 L p F P
0 g
s
.672 .719 .885 r
.42418 .97904 m .42638 .98171 L p .41235 .98187 L F P
0 g
s
.672 .719 .885 r
.41235 .98187 m .42002 .97914 L .42418 .97904 L p F P
0 g
s
.672 .72 .885 r
.41235 .98187 m .42002 .97914 L .41025 .97936 L closepath p F P
0 g
s
.921 .795 .705 r
.7463 .10821 m .74677 .10728 L .74418 .10334 L p F P
0 g
s
.858 .676 .656 r
.11008 .87722 m .11511 .87957 L .1127 .88561 L p F P
0 g
s
.854 .684 .67 r
.11511 .87957 m .11008 .87722 L .11284 .87108 L p F P
0 g
s
.765 .758 .847 r
.20503 .73902 m .19416 .74668 L .19072 .74311 L p F P
0 g
s
.82 .741 .777 r
.13553 .7924 m .12956 .7991 L .13423 .80166 L p F P
0 g
s
.82 .741 .776 r
.12956 .7991 m .13423 .80166 L .12808 .80875 L p F P
0 g
s
.853 .704 .696 r
.10952 .85373 m .11435 .85617 L .11098 .86247 L p F P
0 g
s
.848 .709 .709 r
.11137 .85054 m .10952 .85373 L .11435 .85617 L p F P
0 g
s
.835 .727 .745 r
.12201 .825 m .11971 .82813 L .11623 .82388 L p F P
0 g
s
.835 .727 .745 r
.11623 .82388 m .11724 .8225 L .12201 .825 L p F P
0 g
s
.831 .73 .753 r
.12201 .825 m .11724 .8225 L .12255 .81565 L p F P
0 g
s
.639 .713 .901 r
.54516 .72739 m .55631 .72434 L .55922 .72812 L p F P
0 g
s
.644 .737 .916 r
.55631 .72434 m .54516 .72739 L .54223 .72413 L p F P
0 g
s
.897 .801 .746 r
.73627 .12497 m .73946 .11997 L .74192 .124 L p F P
0 g
s
.897 .801 .746 r
.74192 .124 m .73886 .12879 L .73627 .12497 L p F P
0 g
s
.531 .862 .995 r
.55283 .97993 m .5548 .98072 L .56629 .9782 L p F P
0 g
s
.505 .864 .988 r
.56687 .97841 m .56629 .9782 L .5548 .98072 L p F P
0 g
s
.507 .411 .682 r
.69124 .86263 m .68885 .86387 L .69047 .87076 L p F P
0 g
s
.523 .456 .723 r
.69381 .84216 m .68584 .84045 L .69226 .83692 L closepath p F P
0 g
s
.53 .469 .732 r
.69079 .8322 m .69226 .83692 L .68584 .84045 L p F P
0 g
s
.53 .469 .732 r
.68601 .83135 m .69079 .8322 L p .68584 .84045 L F P
0 g
s
.427 .78 .997 r
.26886 .98228 m .26547 .98005 L .2549 .98154 L p F P
0 g
s
.579 .777 .974 r
.26547 .98005 m .2549 .98154 L .25147 .97963 L p F P
0 g
s
.483 .339 .609 r
.68531 .90107 m .68447 .89496 L .69087 .89192 L p F P
0 g
s
.546 .515 .772 r
.66882 .80148 m .67436 .79821 L p .67913 .806 L F P
0 g
s
.55 .526 .781 r
.66882 .80148 m .66743 .79795 L .67436 .79821 L closepath p F P
0 g
s
.839 .802 .815 r
.70967 .1782 m .71158 .17622 L .70895 .17257 L p F P
0 g
s
.921 .795 .705 r
.74418 .10334 m .74375 .10418 L .7463 .10821 L p F P
0 g
s
.909 .796 .723 r
.74047 .11001 m .74302 .11403 L .7463 .10821 L p F P
0 g
s
.909 .796 .723 r
.7463 .10821 m .74375 .10418 L .74047 .11001 L p F P
0 g
s
.668 .72 .888 r
.43775 .97843 m .44041 .98164 L p .42638 .98171 L F P
0 g
s
.668 .72 .888 r
.42638 .98171 m .43565 .97851 L .43775 .97843 L p F P
0 g
s
.668 .718 .886 r
.42638 .98171 m .43565 .97851 L .42418 .97904 L closepath p F P
0 g
s
.849 .555 .491 r
.13877 .93297 m .13795 .93267 L .13864 .93108 L closepath p F P
0 g
s
.839 .802 .815 r
.70895 .17257 m .7074 .17417 L .70967 .1782 L p F P
0 g
s
.834 .801 .819 r
.70007 .18153 m .70237 .18555 L .70967 .1782 L p F P
0 g
s
.834 .801 .819 r
.70967 .1782 m .7074 .17417 L .70007 .18153 L p F P
0 g
s
.795 .371 .243 r
.15864 .94938 m .15871 .94935 L p .16756 .95594 L F P
0 g
s
.82 .43 .314 r
.15864 .94938 m .1586 .94931 L .15871 .94935 L closepath p F P
0 g
s
0 0 0 r
.59482 .97261 m .59489 .97258 L .60612 .96936 L p F P
0 g
s
.798 .791 .846 r
.67581 .20931 m .67847 .20714 L .67577 .20349 L p F P
0 g
s
.798 .791 .846 r
.67577 .20349 m .67353 .20531 L .67581 .20931 L p F P
0 g
s
.795 .79 .848 r
.66464 .21243 m .67353 .20531 L .67581 .20931 L p F P
0 g
s
.818 .415 .285 r
.1586 .94931 m .15864 .94938 L .15475 .95084 L p F P
0 g
s
.818 .415 .285 r
.15475 .95084 m .1529 .94726 L .1586 .94931 L p F P
0 g
s
.795 .371 .243 r
.16756 .95594 m .16158 .95397 L .15864 .94938 L p F P
0 g
s
.793 .372 .248 r
.16158 .95397 m .15864 .94938 L .15475 .95084 L p F P
0 g
s
0 0 0 r
.60612 .96936 m .60576 .96951 L .59482 .97261 L p F P
0 g
s
.256 .764 .754 r
.59212 .97312 m .59482 .97261 L .60576 .96951 L p F P
0 g
s
.227 .744 .741 r
.5809 .97603 m .59212 .97312 L .59482 .97261 L p F P
0 g
s
.616 .296 .405 r
.43573 .74917 m .43266 .7467 L .43644 .74641 L closepath p F P
0 g
s
.616 .3 .412 r
.43266 .7467 m .43573 .74917 L p .42216 .75184 L F P
0 g
s
.704 .3 .279 r
.34829 .74422 m .33954 .74298 L .33573 .73887 L p F P
0 g
s
.745 .359 .322 r
.3337 .73845 m .33573 .73887 L .33954 .74298 L p F P
0 g
s
.807 .793 .839 r
.68552 .20108 m .67847 .20714 L .67577 .20349 L p F P
0 g
s
.87 .803 .781 r
.72814 .14366 m .72887 .14272 L .73125 .14675 L p F P
0 g
s
.87 .803 .781 r
.73125 .14675 m .73074 .14741 L .72814 .14366 L p F P
0 g
s
.416 0 0 r
.31494 .7344 m .31261 .7339 L .3048 .73104 L p F P
0 g
s
.839 .727 .741 r
.11715 .83171 m .11971 .82813 L .11623 .82388 L p F P
0 g
s
.664 .723 .893 r
.44041 .98164 m .45139 .97801 L .45445 .98164 L p F P
0 g
s
.665 .719 .889 r
.45108 .9776 m .45139 .97801 L .44041 .98164 L p F P
0 g
s
.665 .719 .889 r
.44041 .98164 m .43775 .97843 L .45108 .9776 L p F P
0 g
s
.765 .778 .864 r
.6494 .22351 m .64233 .2283 L .63957 .22458 L p F P
0 g
s
.325 0 .203 r
.65476 .94533 m .6444 .94913 L .64303 .95323 L p F P
0 g
s
.337 0 .214 r
.6444 .94913 m .64303 .95323 L .63251 .95683 L p F P
0 g
s
.382 .082 .327 r
.65564 .9408 m .65476 .94533 L .6444 .94913 L p F P
0 g
s
.517 .139 .262 r
.4616 .74307 m .45484 .74406 L .44985 .74338 L p F P
0 g
s
.522 .157 .289 r
.45484 .74406 m .44922 .74494 L .44985 .74338 L closepath p F P
0 g
s
.517 .118 .224 r
.44985 .74338 m .44922 .74494 L .43644 .74641 L p F P
0 g
s
.866 .803 .787 r
.72593 .15337 m .73074 .14741 L .72814 .14366 L p F P
0 g
s
.704 .385 .435 r
.37914 .75177 m .36955 .75112 L .3673 .74652 L p F P
0 g
s
.717 .39 .424 r
.36481 .74627 m .3673 .74652 L .36955 .75112 L p F P
0 g
s
.55 .526 .782 r
.67436 .79821 m .66743 .79795 L .66531 .7926 L p F P
0 g
s
.829 .799 .823 r
.69793 .18362 m .70007 .18153 L .70237 .18555 L p F P
0 g
s
.829 .799 .823 r
.70237 .18555 m .70059 .18729 L .69793 .18362 L p F P
0 g
s
.267 0 .073 r
.63127 .95915 m .63251 .95683 L .64303 .95323 L p F P
0 g
s
.274 0 .057 r
.63251 .95683 m .63127 .95915 L .62003 .96347 L p F P
0 g
s
.811 .795 .837 r
.68552 .20108 m .68955 .19755 L .68687 .19389 L p F P
0 g
s
.811 .795 .837 r
.68687 .19389 m .68324 .19707 L .68552 .20108 L p F P
0 g
s
.807 .793 .839 r
.67577 .20349 m .68324 .19707 L .68552 .20108 L p F P
0 g
s
.822 .797 .828 r
.6943 .19318 m .70059 .18729 L .69793 .18362 L p F P
0 g
s
.857 .687 .671 r
.1079 .86869 m .11284 .87108 L .11008 .87722 L p F P
0 g
s
.854 .694 .684 r
.11284 .87108 m .1079 .86869 L .11098 .86247 L p F P
0 g
s
.827 .736 .765 r
.12771 .80919 m .12808 .80875 L .12668 .80799 L closepath p F P
0 g
s
.82 .741 .776 r
.12422 .80525 m .12956 .7991 L p .12808 .80875 L F P
0 g
s
.82 .741 .776 r
.12808 .80875 m .12668 .80799 L .12422 .80525 L p F P
0 g
s
.606 .304 .431 r
.43644 .74641 m .44922 .74494 L .44827 .74942 L p F P
0 g
s
.606 .304 .431 r
.43573 .74917 m .43644 .74641 L p .44827 .74942 L F P
0 g
s
.568 .562 .807 r
.64441 .77095 m .65585 .7705 L p .6518 .77717 L F P
0 g
s
.567 .564 .809 r
.65297 .76413 m .65585 .7705 L .64441 .77095 L p F P
0 g
s
.567 .564 .809 r
.65249 .76414 m .65297 .76413 L p .64441 .77095 L F P
0 g
s
.567 .564 .809 r
.64441 .77095 m .64373 .76944 L .65249 .76414 L p F P
0 g
s
.635 .704 .896 r
.57041 .72533 m .55922 .72812 L .55631 .72434 L p F P
0 g
s
.631 .688 .885 r
.55922 .72812 m .57041 .72533 L .57331 .72949 L p F P
0 g
s
.859 .593 .535 r
.13305 .92546 m .12766 .92328 L .12794 .91779 L p F P
0 g
s
.862 .595 .534 r
.1226 .91558 m .12794 .91779 L .12766 .92328 L p F P
0 g
s
.86 .615 .567 r
.12794 .91779 m .1226 .91558 L .12337 .90996 L p F P
0 g
s
.822 .797 .828 r
.69793 .18362 m .69201 .18917 L .6943 .19318 L p F P
0 g
s
.818 .796 .831 r
.68687 .19389 m .69201 .18917 L .6943 .19318 L p F P
0 g
s
.818 .796 .831 r
.6943 .19318 m .68955 .19755 L .68687 .19389 L p F P
0 g
s
.831 .736 .76 r
.12255 .81565 m .12771 .80919 L .12668 .80799 L p F P
0 g
s
.596 .622 .848 r
.61631 .74322 m .60734 .74453 L .60446 .73936 L p F P
0 g
s
.862 .617 .567 r
.11809 .90773 m .12337 .90996 L .1226 .91558 L p F P
0 g
s
.859 .633 .594 r
.12337 .90996 m .11809 .90773 L .11933 .90199 L p F P
0 g
s
.596 .778 .967 r
.26886 .98228 m .2795 .97998 L .28285 .9825 L p F P
0 g
s
.627 .771 .949 r
.2795 .97998 m .26886 .98228 L .26547 .98005 L p F P
0 g
s
.424 0 0 r
.19737 .96959 m .19263 .96756 L p .20313 .97119 L F P
0 g
s
.449 0 0 r
.19737 .96959 m .19263 .96756 L .18898 .96715 L p F P
0 g
s
.449 0 0 r
.18898 .96715 m .19082 .9678 L .19737 .96959 L p F P
0 g
s
0 .467 .749 r
.19914 .96975 m .19124 .9679 L p .19737 .96959 L F P
0 g
s
0 .467 .749 r
.19124 .9679 m .19082 .9678 L .19737 .96959 L p F P
0 g
s
.424 0 0 r
.20379 .97142 m .19737 .96959 L p .20313 .97119 L F P
0 g
s
.717 .39 .424 r
.36955 .75112 m .36347 .75052 L .36481 .74627 L p F P
0 g
s
.718 .39 .423 r
.3574 .74553 m .36481 .74627 L .36347 .75052 L p F P
0 g
s
.666 .709 .879 r
.46545 .97817 m .45445 .98164 L .45139 .97801 L p F P
0 g
s
.659 .728 .9 r
.45445 .98164 m .46545 .97817 L .46849 .9817 L p F P
0 g
s
.86 .569 .494 r
.12766 .92328 m .13305 .92546 L .1333 .93082 L p F P
0 g
s
.858 .567 .496 r
.13795 .93267 m .1333 .93082 L .13305 .92546 L p F P
0 g
s
.745 .359 .322 r
.3311 .74068 m .3337 .73845 L p .33954 .74298 L F P
0 g
s
.693 .251 .197 r
.3311 .74068 m .32746 .73739 L .3337 .73845 L closepath p F P
0 g
s
.588 .597 .828 r
.62441 .75394 m .62367 .75403 L .62428 .75369 L closepath p F P
0 g
s
.592 .606 .834 r
.62154 .7484 m .62428 .75369 L .62367 .75403 L p F P
0 g
s
.375 .761 .989 r
.24523 .97997 m .25147 .97963 L p .23752 .97857 L F P
0 g
s
.375 .761 .989 r
.23752 .97857 m .2377 .97865 L .24523 .97997 L p F P
0 g
s
.61 .647 .862 r
.60158 .73428 m .59031 .73636 L .58743 .73163 L p F P
0 g
s
.629 .778 .952 r
.25825 .72626 m .26888 .72325 L .27226 .72602 L p F P
0 g
s
.603 .779 .965 r
.26888 .72325 m .25825 .72626 L .25487 .72315 L p F P
0 g
s
.683 .769 .916 r
.24417 .72743 m .25487 .72315 L .25825 .72626 L p F P
0 g
s
.862 .636 .595 r
.11412 .89972 m .11933 .90199 L .11809 .90773 L p F P
0 g
s
.859 .649 .618 r
.11933 .90199 m .11412 .89972 L .11578 .89387 L p F P
0 g
s
.5 .396 .667 r
.69047 .87076 m .69973 .86594 L p .69362 .87659 L F P
0 g
s
.5 .396 .667 r
.69362 .87659 m .69151 .87558 L .69047 .87076 L p F P
0 g
s
.507 .411 .682 r
.69047 .87076 m .69973 .86594 L .69124 .86263 L p F P
0 g
s
.571 .573 .817 r
.64373 .76944 m .64154 .76477 L .65249 .76414 L closepath p F P
0 g
s
.892 .801 .753 r
.73802 .13007 m .73886 .12879 L .73627 .12497 L p F P
0 g
s
.751 .754 .855 r
.20503 .73902 m .20659 .73801 L .20184 .7357 L closepath p F P
0 g
s
.765 .758 .847 r
.20184 .7357 m .20503 .73902 L p .19072 .74311 L F P
0 g
s
.797 .75 .81 r
.15781 .7702 m .1587 .76939 L .1553 .76753 L closepath p F P
0 g
s
.804 .751 .804 r
.15061 .77706 m .15781 .7702 L .1553 .76753 L p F P
0 g
s
.175 0 0 r
.6198 .96377 m .62003 .96347 L .63127 .95915 L p F P
0 g
s
.79 .753 .819 r
.16303 .75885 m .16765 .76147 L .1587 .76939 L p F P
0 g
s
.79 .753 .819 r
.15433 .76652 m .16303 .75885 L p .1587 .76939 L F P
0 g
s
.79 .753 .819 r
.1587 .76939 m .1553 .76753 L .15433 .76652 L p F P
0 g
s
.848 .711 .712 r
.11331 .84731 m .11137 .85054 L .10793 .84576 L p F P
0 g
s
.848 .711 .712 r
.10793 .84576 m .10848 .84485 L .11331 .84731 L p F P
0 g
s
.843 .716 .724 r
.11331 .84731 m .10848 .84485 L .1127 .83831 L p F P
0 g
s
.565 .551 .798 r
.6518 .77717 m .65874 .77702 L p .66103 .7837 L F P
0 g
s
.563 .552 .801 r
.65874 .77702 m .6518 .77717 L .65736 .77385 L closepath p F P
0 g
s
.568 .562 .807 r
.65585 .7705 m .65736 .77385 L .6518 .77717 L p F P
0 g
s
.839 .727 .741 r
.11623 .82388 m .11245 .8292 L .11715 .83171 L p F P
0 g
s
.842 .724 .733 r
.11245 .8292 m .11715 .83171 L .1127 .83831 L p F P
0 g
s
.674 .771 .924 r
.25487 .72315 m .24417 .72743 L .24078 .72413 L p F P
0 g
s
.38 .087 .337 r
.65476 .94533 m .65564 .9408 L .66585 .9368 L p F P
0 g
s
.412 .156 .414 r
.66633 .93191 m .66585 .9368 L .65564 .9408 L p F P
0 g
s
.581 .59 .827 r
.62441 .75394 m .63578 .75288 L .63866 .75869 L p F P
0 g
s
.581 .593 .83 r
.63345 .7482 m .63578 .75288 L .62441 .75394 L p F P
0 g
s
.581 .593 .83 r
.62441 .75394 m .62428 .75369 L .63345 .7482 L p F P
0 g
s
.844 .519 .438 r
.14548 .94021 m .13978 .93814 L .13877 .93297 L p F P
0 g
s
.845 .52 .437 r
.13795 .93267 m .13877 .93297 L .13978 .93814 L p F P
0 g
s
.497 .776 .994 r
.27226 .72602 m .28283 .72475 L .28622 .72693 L p F P
0 g
s
.421 .75 .994 r
.27226 .72602 m .28283 .72475 L .27976 .72297 L p F P
0 g
s
.421 .75 .994 r
.26888 .72325 m .27226 .72602 L p .27976 .72297 L F P
0 g
s
.585 .602 .836 r
.63291 .74714 m .63345 .7482 L .62428 .75369 L p F P
0 g
s
.585 .602 .836 r
.62428 .75369 m .62154 .7484 L .63291 .74714 L p F P
0 g
s
.067 0 0 r
.48899 .73306 m .48698 .73451 L .47535 .73716 L p F P
0 g
s
.806 .749 .8 r
.15061 .77706 m .14671 .78086 L .14322 .77713 L p F P
0 g
s
.806 .749 .8 r
.14322 .77713 m .14596 .77447 L .15061 .77706 L p F P
0 g
s
.804 .751 .804 r
.15403 .7668 m .14596 .77447 L .15061 .77706 L p F P
0 g
s
.804 .751 .804 r
.1553 .76753 m .15403 .7668 L p .15061 .77706 L F P
0 g
s
.653 .735 .91 r
.46849 .9817 m .47952 .97839 L .48254 .98176 L p F P
0 g
s
.661 .715 .889 r
.47952 .97839 m .46849 .9817 L .46545 .97817 L p F P
0 g
s
.793 .755 .819 r
.16536 .75683 m .16303 .75885 L .16765 .76147 L p F P
0 g
s
.793 .755 .819 r
.16765 .76147 m .16884 .76044 L .16536 .75683 L p F P
0 g
s
.402 0 .08 r
.47492 .73777 m .47036 .73808 L .47535 .73716 L closepath p F P
0 g
s
.456 .065 .208 r
.47036 .73808 m .47492 .73777 L p .4616 .74307 L F P
0 g
s
.656 .761 .927 r
.29356 .97957 m .28285 .9825 L .2795 .97998 L p F P
0 g
s
.634 .769 .945 r
.28285 .9825 m .29356 .97957 L .29687 .98235 L p F P
0 g
s
.54 0 0 r
.18417 .96409 m .18898 .96715 L .18673 .9667 L p F P
0 g
s
.54 0 0 r
.17788 .96221 m .18417 .96409 L p .18673 .9667 L F P
0 g
s
.688 .17 0 r
.18417 .96409 m .17788 .96221 L .1755 .96024 L p F P
0 g
s
.786 .756 .826 r
.17756 .75324 m .16884 .76044 L .16536 .75683 L p F P
0 g
s
.55 .526 .782 r
.66531 .7926 m .66835 .79077 L p .67436 .79821 L F P
0 g
s
.553 .536 .79 r
.66531 .7926 m .66452 .7907 L .66835 .79077 L closepath p F P
0 g
s
.744 .756 .862 r
.21243 .72865 m .21585 .73213 L .20659 .73801 L p F P
0 g
s
.744 .756 .862 r
.2016 .73546 m .21243 .72865 L p .20659 .73801 L F P
0 g
s
.744 .756 .862 r
.20659 .73801 m .20184 .7357 L .2016 .73546 L p F P
0 g
s
.892 .801 .753 r
.73627 .12497 m .73556 .12604 L .73802 .13007 L p F P
0 g
s
.882 .801 .764 r
.73109 .13233 m .73357 .13635 L .73802 .13007 L p F P
0 g
s
.882 .801 .764 r
.73802 .13007 m .73556 .12604 L .73109 .13233 L p F P
0 g
s
.861 .653 .619 r
.11064 .89156 m .11578 .89387 L .11412 .89972 L p F P
0 g
s
.858 .663 .638 r
.11578 .89387 m .11064 .89156 L .1127 .88561 L p F P
0 g
s
.074 .611 .858 r
.22365 .97648 m .23082 .97678 L .23735 .97856 L p F P
0 g
s
.223 .694 .941 r
.23082 .97678 m .22365 .97648 L .22012 .97515 L p F P
0 g
s
.811 .749 .795 r
.14305 .78457 m .14671 .78086 L .14322 .77713 L p F P
0 g
s
.866 .803 .787 r
.72814 .14366 m .72355 .14934 L .72593 .15337 L p F P
0 g
s
.861 .802 .791 r
.71796 .15606 m .72035 .16007 L .72593 .15337 L p F P
0 g
s
.861 .802 .791 r
.72593 .15337 m .72355 .14934 L .71796 .15606 L p F P
0 g
s
.689 .172 0 r
.17788 .96221 m .17205 .9605 L .1755 .96024 L closepath p F P
0 g
s
.767 .779 .863 r
.6494 .22351 m .65349 .2207 L .65075 .21699 L p F P
0 g
s
.767 .779 .863 r
.65075 .21699 m .64698 .21956 L .6494 .22351 L p F P
0 g
s
.765 .778 .864 r
.63957 .22458 m .64698 .21956 L .6494 .22351 L p F P
0 g
s
.546 0 0 r
.30011 .72944 m .30202 .73013 L p .31261 .7339 L F P
0 g
s
.094 .616 .88 r
.30011 .72944 m .29776 .72917 L .30202 .73013 L closepath p F P
0 g
s
.621 .671 .876 r
.57373 .73013 m .57331 .72949 L .57637 .7288 L closepath p F P
0 g
s
.505 .413 .684 r
.69834 .85886 m .69124 .86263 L .69973 .86594 L p F P
0 g
s
.514 .428 .696 r
.6969 .85323 m .69834 .85886 L .69124 .86263 L p F P
0 g
s
.514 .428 .696 r
.69494 .8526 m .6969 .85323 L p .69124 .86263 L F P
0 g
s
.735 .761 .873 r
.21585 .73213 m .22392 .72751 L .22884 .73005 L p F P
0 g
s
.737 .762 .873 r
.22664 .72597 m .22392 .72751 L .22884 .73005 L p F P
0 g
s
.737 .762 .873 r
.22884 .73005 m .23005 .72936 L .22664 .72597 L p F P
0 g
s
.831 .736 .76 r
.12668 .80799 m .12343 .80619 L p .12255 .81565 L F P
0 g
s
.827 .741 .769 r
.12668 .80799 m .12422 .80525 L .12343 .80619 L closepath p F P
0 g
s
.418 .854 .932 r
.56687 .97841 m .57808 .97566 L .5809 .97603 L p F P
0 g
s
.426 .859 .931 r
.59212 .97312 m .5809 .97603 L .57808 .97566 L p F P
0 g
s
.527 .469 .734 r
.69079 .8322 m .68601 .83135 L .68985 .82921 L closepath p F P
0 g
s
.535 .481 .743 r
.68779 .82298 m .68985 .82921 L .68601 .83135 L p F P
0 g
s
.535 .481 .743 r
.68495 .82257 m .68779 .82298 L p .68601 .83135 L F P
0 g
s
.45 .254 .521 r
.68296 .91419 m .67641 .91708 L .67654 .92253 L p F P
0 g
s
.469 .291 .556 r
.67641 .91708 m .68296 .91419 L .68163 .90892 L p F P
0 g
s
.81 .748 .794 r
.13845 .78197 m .14305 .78457 L .13596 .79194 L p F P
0 g
s
.811 .749 .795 r
.14322 .77713 m .13845 .78197 L .14305 .78457 L p F P
0 g
s
.845 .52 .437 r
.13978 .93814 m .13491 .93634 L .13795 .93267 L p F P
0 g
s
.856 .536 .445 r
.1333 .93082 m .13795 .93267 L .13491 .93634 L p F P
0 g
s
.657 .759 .925 r
.29687 .98235 m .30762 .97892 L .31091 .98195 L p F P
0 g
s
.673 .749 .908 r
.30762 .97892 m .29687 .98235 L .29356 .97957 L p F P
0 g
s
.553 .537 .791 r
.66835 .79077 m .66452 .7907 L .66162 .7837 L p F P
0 g
s
.675 .72 .883 r
.41025 .97936 m .40924 .97814 L .40584 .97939 L closepath p F P
0 g
s
.675 .723 .885 r
.40613 .97406 m .40924 .97814 L .40584 .97939 L p F P
0 g
s
.675 .723 .885 r
.39519 .97846 m .40613 .97406 L p .40584 .97939 L F P
0 g
s
.675 .723 .885 r
.40584 .97939 m .39598 .97938 L .39519 .97846 L p F P
0 g
s
.856 .698 .685 r
.10613 .86003 m .11098 .86247 L .1079 .86869 L p F P
0 g
s
.853 .704 .696 r
.11098 .86247 m .10613 .86003 L .10952 .85373 L p F P
0 g
s
.718 .39 .423 r
.36347 .75052 m .35965 .75013 L .3574 .74553 L p F P
0 g
s
.733 .411 .436 r
.34849 .74425 m .3574 .74553 L .35965 .75013 L p F P
0 g
s
.719 .341 .333 r
.3574 .74553 m .34849 .74425 L .34837 .7441 L p F P
0 g
s
.677 .723 .884 r
.39598 .97938 m .39519 .97846 L .39278 .97935 L closepath p F P
0 g
s
.647 .746 .922 r
.48254 .98176 m .49359 .97862 L .49659 .98179 L p F P
0 g
s
.655 .723 .899 r
.49359 .97862 m .48254 .98176 L .47952 .97839 L p F P
0 g
s
.051 0 0 r
.61737 .96584 m .6198 .96377 L .63043 .96031 L p F P
0 g
s
.175 0 0 r
.63127 .95915 m .63043 .96031 L .6198 .96377 L p F P
0 g
s
.093 0 0 r
.60612 .96936 m .61737 .96584 L .6198 .96377 L p F P
0 g
s
.672 .719 .884 r
.42002 .97914 m .41025 .97936 L .40924 .97814 L p F P
0 g
s
.677 .728 .888 r
.39206 .97443 m .39519 .97846 L .39278 .97935 L p F P
0 g
s
.677 .728 .888 r
.38115 .9789 m .39206 .97443 L p .39278 .97935 L F P
0 g
s
.677 .728 .888 r
.39278 .97935 m .38128 .97906 L .38115 .9789 L p F P
0 g
s
.831 .735 .759 r
.11789 .8131 m .12255 .81565 L .11724 .8225 L p F P
0 g
s
.831 .736 .76 r
.12343 .80619 m .11789 .8131 L .12255 .81565 L p F P
0 g
s
.741 .246 .06 r
.16158 .95397 m .16756 .95594 L .17158 .96034 L p F P
0 g
s
.75 .268 .096 r
.17205 .9605 m .17158 .96034 L .16756 .95594 L p F P
0 g
s
.902 .796 .734 r
.7369 .11596 m .73946 .11997 L .74302 .11403 L p F P
0 g
s
.902 .796 .734 r
.74302 .11403 m .74047 .11001 L .7369 .11596 L p F P
0 g
s
.786 .756 .826 r
.16536 .75683 m .17291 .75062 L .17756 .75324 L p F P
0 g
s
.784 .757 .829 r
.17634 .74786 m .17291 .75062 L .17756 .75324 L p F P
0 g
s
.784 .757 .829 r
.17756 .75324 m .1798 .75143 L .17634 .74786 L p F P
0 g
s
.708 .766 .897 r
.24078 .72413 m .23005 .72936 L .22664 .72597 L p F P
0 g
s
.671 .749 .909 r
.31091 .98195 m .3217 .97814 L .32495 .98138 L p F P
0 g
s
.684 .739 .893 r
.3217 .97814 m .31091 .98195 L .30762 .97892 L p F P
0 g
s
.621 .684 .888 r
.57637 .7288 m .57331 .72949 L .57041 .72533 L p F P
0 g
s
.396 0 0 r
.31735 .7342 m .31984 .73571 L .32746 .73739 L p F P
0 g
s
.594 .035 0 r
.31984 .73571 m .31494 .7344 L .31735 .7342 L closepath p F P
0 g
s
.209 0 0 r
.20379 .97142 m .2063 .9723 L .20272 .97116 L p F P
0 g
s
.209 0 0 r
.20272 .97116 m .19737 .96959 L .20379 .97142 L p F P
0 g
s
.679 .739 .896 r
.32495 .98138 m .33578 .9773 L .339 .98074 L p F P
0 g
s
.691 .727 .878 r
.33578 .9773 m .32495 .98138 L .3217 .97814 L p F P
0 g
s
.776 .758 .837 r
.18867 .74465 m .1798 .75143 L .17634 .74786 L p F P
0 g
s
.835 .472 .367 r
.1529 .94726 m .14722 .94519 L .14548 .94021 L p F P
0 g
s
.836 .469 .36 r
.13978 .93814 m .14548 .94021 L .14722 .94519 L p F P
0 g
s
.746 .769 .872 r
.63008 .23043 m .62837 .23147 L .62559 .22771 L p F P
0 g
s
.72 .761 .885 r
.61436 .23355 m .62559 .22771 L .62837 .23147 L p F P
0 g
s
.861 .667 .639 r
.10765 .88327 m .1127 .88561 L .11064 .89156 L p F P
0 g
s
.858 .676 .656 r
.1127 .88561 m .10765 .88327 L .11008 .87722 L p F P
0 g
s
.684 .729 .884 r
.35087 .97761 m .35305 .98007 L p .339 .98074 L F P
0 g
s
.684 .729 .884 r
.339 .98074 m .3474 .97742 L .35087 .97761 L p F P
0 g
s
.695 .723 .871 r
.3474 .97742 m .339 .98074 L .33578 .9773 L p F P
0 g
s
.851 .712 .709 r
.10952 .85373 m .11137 .85054 L .10793 .84576 L p F P
0 g
s
.672 .719 .884 r
.42418 .97904 m .42329 .97797 L .42002 .97914 L closepath p F P
0 g
s
.672 .719 .884 r
.4202 .97386 m .42329 .97797 L .42002 .97914 L p F P
0 g
s
.672 .719 .884 r
.40924 .97814 m .4202 .97386 L p .42002 .97914 L F P
0 g
s
.501 .396 .667 r
.69191 .87747 m .69151 .87558 L .69362 .87659 L closepath p F P
0 g
s
.78 .783 .855 r
.66251 .21403 m .65349 .2207 L .65075 .21699 L p F P
0 g
s
.686 .721 .875 r
.36633 .97853 m .3671 .97945 L p .35305 .98007 L F P
0 g
s
.686 .721 .875 r
.35305 .98007 m .35776 .97816 L .36633 .97853 L p F P
0 g
s
.688 .731 .883 r
.35305 .98007 m .35776 .97816 L .35087 .97761 L closepath p F P
0 g
s
.465 .289 .556 r
.68593 .90698 m .68163 .90892 L .68296 .91419 L p F P
0 g
s
.481 .32 .586 r
.68163 .90892 m .68593 .90698 L .68531 .90107 L p F P
0 g
s
.692 .382 .446 r
.39195 .75231 m .38035 .75183 L .37954 .75016 L p F P
0 g
s
.699 .385 .441 r
.38035 .75183 m .37914 .75177 L .37954 .75016 L closepath p F P
0 g
s
.722 .305 .257 r
.32746 .73739 m .3311 .74068 L .33068 .74121 L p F P
0 g
s
.722 .305 .257 r
.31984 .73571 m .32746 .73739 L p .33068 .74121 L F P
0 g
s
.677 .728 .888 r
.38128 .97906 m .38115 .9789 L .38076 .97905 L closepath p F P
0 g
s
.817 .745 .783 r
.13553 .7924 m .13596 .79194 L .13423 .79098 L closepath p F P
0 g
s
.81 .748 .794 r
.13202 .78863 m .13845 .78197 L p .13596 .79194 L F P
0 g
s
.81 .748 .794 r
.13596 .79194 m .13423 .79098 L .13202 .78863 L p F P
0 g
s
.638 .761 .937 r
.49659 .98179 m .50767 .97879 L .51065 .98171 L p F P
0 g
s
.648 .735 .913 r
.50767 .97879 m .49659 .98179 L .49359 .97862 L p F P
0 g
s
.687 .715 .87 r
.3671 .97945 m .36899 .97868 L .38076 .97905 L p F P
0 g
s
.688 .722 .875 r
.3671 .97945 m .36899 .97868 L .36633 .97853 L closepath p F P
0 g
s
.675 .71 .875 r
.378 .97497 m .36899 .97868 L .38076 .97905 L p F P
0 g
s
.675 .71 .875 r
.38076 .97905 m .38115 .9789 L .378 .97497 L p F P
0 g
s
.668 .717 .885 r
.43565 .97851 m .42418 .97904 L .42329 .97797 L p F P
0 g
s
.47 .312 .585 r
.68593 .90698 m .68531 .90107 L .69507 .89644 L p F P
0 g
s
.483 .339 .609 r
.69505 .8963 m .69507 .89644 L .68531 .90107 L p F P
0 g
s
.483 .339 .609 r
.69087 .89192 m .69505 .8963 L p .68531 .90107 L F P
0 g
s
.822 .745 .778 r
.12956 .7991 m .13553 .7924 L .13423 .79098 L p F P
0 g
s
.424 .727 .989 r
.28622 .72693 m .29091 .72723 L p .29471 .72858 L F P
0 g
s
.315 .689 .978 r
.29091 .72723 m .28622 .72693 L .28283 .72475 L p F P
0 g
s
.315 .689 .978 r
.28482 .72506 m .29091 .72723 L p .28756 .7262 L F P
0 g
s
.315 .689 .978 r
.28283 .72475 m .28482 .72506 L p .28756 .7262 L F P
0 g
s
.386 0 0 r
.29409 .72851 m .2923 .72801 L .28482 .72506 L p F P
0 g
s
.493 0 0 r
.28482 .72506 m .2923 .72801 L p .28103 .72348 L F P
0 g
s
.493 0 0 r
.27976 .72297 m .28482 .72506 L p .28103 .72348 L F P
0 g
s
.386 0 0 r
.29409 .72851 m .28589 .72546 L .29091 .72723 L F
.28482 .72506 m .29091 .72723 L p .28589 .72546 L F P
0 g
s
.424 .727 .989 r
.29091 .72723 m .29776 .72917 L p .29471 .72858 L F P
0 g
s
.692 .698 .851 r
.39206 .97443 m .38115 .9789 L .378 .97497 L p F P
0 g
s
.747 .77 .871 r
.63008 .23043 m .63957 .22458 L .63679 .22081 L p F P
0 g
s
.747 .77 .871 r
.63679 .22081 m .62747 .22656 L .63008 .23043 L p F P
0 g
s
.746 .769 .872 r
.62559 .22771 m .62747 .22656 L .63008 .23043 L p F P
0 g
s
.355 0 .054 r
.47492 .73777 m .47535 .73716 L .48698 .73451 L p F P
0 g
s
.572 .267 .413 r
.44827 .74942 m .44922 .74494 L .45484 .74406 L p F P
0 g
s
.524 .868 .991 r
.56629 .9782 m .56687 .97841 L .57808 .97566 L p F P
0 g
s
.571 .574 .817 r
.65249 .76414 m .64154 .76477 L .63887 .75913 L p F P
0 g
s
.689 .694 .849 r
.40613 .97406 m .39519 .97846 L .39206 .97443 L p F P
0 g
s
.491 .375 .649 r
.69362 .87659 m .69191 .87747 L .69315 .88397 L p F P
0 g
s
.853 .8 .798 r
.71726 .15685 m .71796 .15606 L .72035 .16007 L p F P
0 g
s
.853 .8 .798 r
.72035 .16007 m .71989 .1606 L .71726 .15685 L p F P
0 g
s
.628 .781 .955 r
.51065 .98171 m .52175 .97884 L .52471 .98144 L p F P
0 g
s
.641 .751 .929 r
.52175 .97884 m .51065 .98171 L .50767 .97879 L p F P
0 g
s
.848 .8 .804 r
.71405 .16705 m .71989 .1606 L .71726 .15685 L p F P
0 g
s
0 .451 .737 r
.29776 .72917 m .30011 .72944 L .29667 .72867 L p F P
0 g
s
0 .451 .737 r
.29667 .72867 m .29091 .72723 L .29776 .72917 L p F P
0 g
s
.408 .153 .413 r
.67641 .92773 m .66633 .93191 L .66585 .9368 L p F P
0 g
s
.439 .216 .477 r
.67654 .92253 m .67641 .92773 L .66633 .93191 L p F P
0 g
s
.844 .721 .729 r
.10796 .83581 m .1127 .83831 L .10848 .84485 L p F P
0 g
s
.842 .724 .733 r
.1127 .83831 m .10796 .83581 L .11245 .8292 L p F P
0 g
s
.689 .721 .875 r
.37485 .97078 m .378 .97497 L .36899 .97868 L p F P
0 g
s
.689 .721 .875 r
.36393 .97566 m .37485 .97078 L p .36899 .97868 L F P
0 g
s
.689 .721 .875 r
.36899 .97868 m .36633 .97853 L .36393 .97566 L p F P
0 g
s
.559 .542 .792 r
.66162 .7837 m .66103 .7837 L .66151 .78342 L closepath p F P
0 g
s
.565 .551 .798 r
.65874 .77702 m .66151 .78342 L .66103 .7837 L p F P
0 g
s
.685 .691 .849 r
.4202 .97386 m .40924 .97814 L .40613 .97406 L p F P
0 g
s
.266 .702 .963 r
.23752 .97857 m .23735 .97856 L .2377 .97865 L closepath p F P
0 g
s
.776 .758 .837 r
.17634 .74786 m .18399 .74203 L .18867 .74465 L p F P
0 g
s
.774 .759 .839 r
.18727 .73958 m .18399 .74203 L .18867 .74465 L p F P
0 g
s
.774 .759 .839 r
.18867 .74465 m .19072 .74311 L .18727 .73958 L p F P
0 g
s
.877 .8 .77 r
.72639 .13871 m .72887 .14272 L .73357 .13635 L p F P
0 g
s
.877 .8 .77 r
.73357 .13635 m .73109 .13233 L .72639 .13871 L p F P
0 g
s
.86 .68 .657 r
.10512 .87483 m .11008 .87722 L .10765 .88327 L p F P
0 g
s
.857 .687 .671 r
.11008 .87722 m .10512 .87483 L .1079 .86869 L p F P
0 g
s
.612 .806 .975 r
.52471 .98144 m .53584 .97867 L .53877 .98089 L p F P
0 g
s
.631 .773 .948 r
.53584 .97867 m .52471 .98144 L .52175 .97884 L p F P
0 g
s
.68 .745 .9 r
.6003 .23431 m .61155 .22975 L .61436 .23355 L p F P
0 g
s
.719 .759 .884 r
.62559 .22771 m .61436 .23355 L .61155 .22975 L p F P
0 g
s
.679 .404 .499 r
.40485 .7524 m .40841 .75238 L .40787 .75732 L p F P
0 g
s
.679 .404 .499 r
.40787 .75732 m .4061 .75733 L .40485 .7524 L p F P
0 g
s
.684 .408 .498 r
.39409 .75237 m .40485 .7524 L .4061 .75733 L p F P
0 g
s
.531 .862 .995 r
.56629 .9782 m .56401 .97723 L .55283 .97993 L p F P
0 g
s
.593 .833 .99 r
.56401 .97723 m .55283 .97993 L .54992 .97818 L p F P
0 g
s
.586 .835 .992 r
.53877 .98089 m .54992 .97818 L .55283 .97993 L p F P
0 g
s
.359 .737 .988 r
.23735 .97856 m .23752 .97857 L .23405 .97677 L p F P
0 g
s
.359 .737 .988 r
.23405 .97677 m .23082 .97678 L .23735 .97856 L p F P
0 g
s
.532 .481 .744 r
.68779 .82298 m .68495 .82257 L .68723 .82128 L closepath p F P
0 g
s
.538 .493 .753 r
.68483 .81437 m .68723 .82128 L .68495 .82257 L p F P
0 g
s
.538 .493 .753 r
.68266 .81412 m .68483 .81437 L p .68495 .82257 L F P
0 g
s
.663 .39 .497 r
.40841 .75238 m .41961 .75195 L .4211 .75682 L p F P
0 g
s
.663 .39 .497 r
.4211 .75682 m .40787 .75732 L .40841 .75238 L p F P
0 g
s
.684 .408 .498 r
.4061 .75733 m .39351 .75729 L .39409 .75237 L p F P
0 g
s
.696 .418 .499 r
.39195 .75231 m .39409 .75237 L .39351 .75729 L p F P
0 g
s
.686 .721 .876 r
.36633 .97853 m .36393 .97566 L .35776 .97816 L closepath p F P
0 g
s
.669 .719 .887 r
.43775 .97843 m .43734 .97793 L .43565 .97851 L closepath p F P
0 g
s
.668 .717 .885 r
.43426 .97383 m .43734 .97793 L .43565 .97851 L p F P
0 g
s
.668 .717 .885 r
.42329 .97797 m .43426 .97383 L p .43565 .97851 L F P
0 g
s
.855 .707 .698 r
.10476 .85125 m .10952 .85373 L .10613 .86003 L p F P
0 g
s
.851 .712 .709 r
.10793 .84576 m .10476 .85125 L .10952 .85373 L p F P
0 g
s
.617 .8 .97 r
.54992 .97818 m .53877 .98089 L .53584 .97867 L p F P
0 g
s
.375 .761 .989 r
.25147 .97963 m .24804 .97749 L .23752 .97857 L p F P
0 g
s
.547 .775 .983 r
.24804 .97749 m .23752 .97857 L .23405 .97677 L p F P
0 g
s
.696 .418 .499 r
.39351 .75729 m .39305 .75728 L .39195 .75231 L p F P
0 g
s
.702 .427 .505 r
.38035 .75183 m .39195 .75231 L .39305 .75728 L p F P
0 g
s
.733 .762 .876 r
.22392 .72751 m .21585 .73213 L .21243 .72865 L p F P
0 g
s
.825 .743 .774 r
.12956 .7991 m .12422 .80525 L .1207 .80142 L p F P
0 g
s
.825 .743 .774 r
.1207 .80142 m .12497 .79651 L .12956 .7991 L p F P
0 g
s
.822 .745 .778 r
.13137 .78934 m .12497 .79651 L .12956 .7991 L p F P
0 g
s
.822 .745 .778 r
.13423 .79098 m .13137 .78934 L p .12956 .7991 L F P
0 g
s
.837 .73 .746 r
.11623 .82388 m .11724 .8225 L .11328 .82036 L closepath p F P
0 g
s
.831 .735 .759 r
.11274 .81973 m .11789 .8131 L p .11724 .8225 L F P
0 g
s
.831 .735 .759 r
.11724 .8225 m .11328 .82036 L .11274 .81973 L p F P
0 g
s
.765 .758 .847 r
.19072 .74311 m .20151 .73552 L .20184 .7357 L p F P
0 g
s
.765 .761 .849 r
.20151 .73552 m .19072 .74311 L .18727 .73958 L p F P
0 g
s
.817 .404 .262 r
.1529 .94726 m .15475 .95084 L .15324 .95121 L p F P
0 g
s
.817 .404 .262 r
.14722 .94519 m .1529 .94726 L p .15324 .95121 L F P
0 g
s
.553 .537 .791 r
.66162 .7837 m .67315 .78396 L p .66835 .79077 L F P
0 g
s
.551 .537 .793 r
.67057 .77777 m .67315 .78396 L .66162 .7837 L p F P
0 g
s
.551 .537 .793 r
.66162 .7837 m .66151 .78342 L .67057 .77777 L p F P
0 g
s
.674 .721 .885 r
.44833 .97397 m .45108 .9776 L .43775 .97843 L p F P
0 g
s
.674 .721 .885 r
.43775 .97843 m .43734 .97793 L .44833 .97397 L p F P
0 g
s
.681 .689 .851 r
.43426 .97383 m .42329 .97797 L .4202 .97386 L p F P
0 g
s
.556 .548 .801 r
.67025 .77703 m .67057 .77777 L .66151 .78342 L p F P
0 g
s
.556 .548 .801 r
.66151 .78342 m .65874 .77702 L .67025 .77703 L p F P
0 g
s
.782 .784 .854 r
.66251 .21403 m .66464 .21243 L .66192 .20871 L p F P
0 g
s
.782 .784 .854 r
.66192 .20871 m .6601 .21007 L .66251 .21403 L p F P
0 g
s
.78 .783 .855 r
.65075 .21699 m .6601 .21007 L .66251 .21403 L p F P
0 g
s
.596 .622 .848 r
.60446 .73936 m .61578 .73767 L p .61631 .74322 L F P
0 g
s
.598 .627 .851 r
.6129 .73253 m .61578 .73767 L .60446 .73936 L p F P
0 g
s
.598 .627 .851 r
.60334 .73399 m .6129 .73253 L p .60446 .73936 L F P
0 g
s
.598 .627 .851 r
.60446 .73936 m .6019 .73483 L .60334 .73399 L p F P
0 g
s
.619 .671 .878 r
.58453 .72703 m .57637 .7288 L .58328 .72513 L closepath p F P
0 g
s
.621 .684 .888 r
.58164 .7227 m .58328 .72513 L .57637 .7288 L p F P
0 g
s
.621 .684 .888 r
.57041 .72533 m .58164 .7227 L p .57637 .7288 L F P
0 g
s
.724 .341 .324 r
.34849 .74425 m .34829 .74422 L .34837 .7441 L closepath p F P
0 g
s
.841 .73 .742 r
.11245 .8292 m .11623 .82388 L .11328 .82036 L p F P
0 g
s
.848 .8 .804 r
.71726 .15685 m .71166 .16304 L .71405 .16705 L p F P
0 g
s
.844 .799 .807 r
.7063 .16883 m .71166 .16304 L .71405 .16705 L p F P
0 g
s
.844 .799 .807 r
.71405 .16705 m .70895 .17257 L .7063 .16883 L p F P
0 g
s
.649 .786 .947 r
.52817 .72484 m .53931 .72138 L .54223 .72413 L p F P
0 g
s
.646 .84 .975 r
.53931 .72138 m .52817 .72484 L .52523 .72306 L p F P
0 g
s
.629 .855 .985 r
.51411 .72664 m .52523 .72306 L .52817 .72484 L p F P
0 g
s
.733 .411 .436 r
.35965 .75013 m .35037 .74896 L .34849 .74425 L p F P
0 g
s
.746 .417 .427 r
.34829 .74422 m .34849 .74425 L .35037 .74896 L p F P
0 g
s
.644 .737 .916 r
.54223 .72413 m .5534 .72091 L .55631 .72434 L p F P
0 g
s
.65 .77 .937 r
.5534 .72091 m .54223 .72413 L .53931 .72138 L p F P
0 g
s
.794 .787 .846 r
.67353 .20531 m .66464 .21243 L .66192 .20871 L p F P
0 g
s
.746 .417 .427 r
.35037 .74896 m .34685 .74841 L .34829 .74422 L p F P
0 g
s
.739 .409 .422 r
.33954 .74298 m .34829 .74422 L .34685 .74841 L p F P
0 g
s
.606 .304 .431 r
.44827 .74942 m .43744 .75059 L .43573 .74917 L p F P
0 g
s
.604 .305 .435 r
.43744 .75059 m .43541 .75083 L .43573 .74917 L closepath p F P
0 g
s
.616 .3 .412 r
.43573 .74917 m .43541 .75083 L .42216 .75184 L p F P
0 g
s
.585 .604 .838 r
.63291 .74714 m .62154 .7484 L .61866 .74291 L p F P
0 g
s
.545 .863 .996 r
.56401 .97723 m .56629 .9782 L .5776 .97548 L p F P
0 g
s
.524 .868 .991 r
.57808 .97566 m .5776 .97548 L .56629 .9782 L p F P
0 g
s
.818 .748 .786 r
.13423 .79098 m .13202 .78863 L .13137 .78934 L closepath p F P
0 g
s
.661 .389 .498 r
.41961 .75195 m .42216 .75184 L .42165 .75679 L p F P
0 g
s
.661 .389 .498 r
.42165 .75679 m .4211 .75682 L .41961 .75195 L p F P
0 g
s
.688 .73 .882 r
.36075 .97159 m .36393 .97566 L .35776 .97816 L p F P
0 g
s
.688 .73 .882 r
.34985 .97645 m .36075 .97159 L p .35776 .97816 L F P
0 g
s
.688 .73 .882 r
.35776 .97816 m .35087 .97761 L .34985 .97645 L p F P
0 g
s
.8 .754 .81 r
.1553 .76753 m .15433 .76652 L .15403 .7668 L closepath p F P
0 g
s
.676 .689 .854 r
.44833 .97397 m .43734 .97793 L .43426 .97383 L p F P
0 g
s
.894 .796 .745 r
.73365 .12104 m .7369 .11596 L .73946 .11997 L p F P
0 g
s
.894 .796 .745 r
.73946 .11997 m .73627 .12497 L .73365 .12104 L p F P
0 g
s
.355 0 .054 r
.48698 .73451 m .48596 .73621 L .47492 .73777 L p F P
0 g
s
.442 .069 .235 r
.47362 .7408 m .47492 .73777 L .48596 .73621 L p F P
0 g
s
.456 .065 .208 r
.47492 .73777 m .47362 .7408 L .4616 .74307 L p F P
0 g
s
.573 .26 .4 r
.46078 .74665 m .45484 .74406 L .4616 .74307 L closepath p F P
0 g
s
.572 .267 .413 r
.45484 .74406 m .46078 .74665 L p .44827 .74942 L F P
0 g
s
.643 .373 .495 r
.42165 .75679 m .42216 .75184 L .43541 .75083 L p F P
0 g
s
.702 .427 .505 r
.39305 .75728 m .38126 .75686 L .38035 .75183 L p F P
0 g
s
.711 .433 .503 r
.37914 .75177 m .38035 .75183 L .38126 .75686 L p F P
0 g
s
.61 .647 .862 r
.58743 .73163 m .5987 .72948 L .60158 .73428 L p F P
0 g
s
.612 .654 .867 r
.5987 .72948 m .58743 .73163 L .58453 .72703 L p F P
0 g
s
.717 .438 .503 r
.36955 .75112 m .37914 .75177 L .37855 .75671 L p F P
0 g
s
.711 .433 .503 r
.38126 .75686 m .37855 .75671 L .37914 .75177 L p F P
0 g
s
.5 .396 .667 r
.70007 .86611 m .70145 .87251 L .69362 .87659 L p F P
0 g
s
.5 .396 .667 r
.69973 .86594 m .70007 .86611 L p .69362 .87659 L F P
0 g
s
.491 .375 .649 r
.69315 .88397 m .6999 .88052 L .69362 .87659 L p F P
0 g
s
.489 .376 .651 r
.70145 .87251 m .69362 .87659 L .6999 .88052 L p F P
0 g
s
.547 .527 .784 r
.67605 .7911 m .66835 .79077 L .67443 .78705 L closepath p F P
0 g
s
.553 .537 .791 r
.67315 .78396 m .67443 .78705 L .66835 .79077 L p F P
0 g
s
.55 .526 .782 r
.66835 .79077 m .67605 .7911 L p .67436 .79821 L F P
0 g
s
.862 .595 .534 r
.12766 .92328 m .12231 .92108 L .1226 .91558 L p F P
0 g
s
.864 .597 .533 r
.1173 .91335 m .1226 .91558 L .12231 .92108 L p F P
0 g
s
.862 .617 .567 r
.1226 .91558 m .1173 .91335 L .11809 .90773 L p F P
0 g
s
.536 .493 .755 r
.68483 .81437 m .68266 .81412 L .6844 .81312 L closepath p F P
0 g
s
.542 .504 .763 r
.68189 .80624 m .6844 .81312 L .68266 .81412 L p F P
0 g
s
.542 .504 .763 r
.67913 .806 m .68189 .80624 L p .68266 .81412 L F P
0 g
s
.865 .62 .567 r
.11286 .90546 m .11809 .90773 L .1173 .91335 L p F P
0 g
s
.862 .636 .595 r
.11809 .90773 m .11286 .90546 L .11412 .89972 L p F P
0 g
s
.829 .744 .77 r
.12343 .80619 m .12422 .80525 L .1207 .80142 L p F P
0 g
s
.859 .691 .673 r
.10302 .86627 m .1079 .86869 L .10512 .87483 L p F P
0 g
s
.856 .698 .685 r
.1079 .86869 m .10302 .86627 L .10613 .86003 L p F P
0 g
s
.838 .798 .813 r
.7074 .17417 m .70895 .17257 L .7063 .16883 L p F P
0 g
s
.143 .632 .916 r
.21675 .97363 m .21647 .97355 L .2063 .9723 L p F P
0 g
s
.064 .599 .859 r
.21647 .97355 m .2063 .9723 L .20272 .97116 L p F P
0 g
s
.86 .569 .494 r
.1333 .93082 m .12792 .92864 L .12766 .92328 L p F P
0 g
s
.863 .57 .492 r
.12231 .92108 m .12766 .92328 L .12792 .92864 L p F P
0 g
s
.833 .74 .762 r
.11888 .80359 m .12343 .80619 L .11789 .8131 L p F P
0 g
s
.829 .744 .77 r
.1207 .80142 m .11888 .80359 L .12343 .80619 L p F P
0 g
s
.635 .704 .896 r
.55631 .72434 m .56751 .72141 L .57041 .72533 L p F P
0 g
s
.641 .724 .909 r
.56751 .72141 m .55631 .72434 L .5534 .72091 L p F P
0 g
s
0 0 0 r
.60576 .96951 m .60612 .96936 L .61737 .96584 L p F P
0 g
s
.838 .798 .813 r
.7063 .16883 m .70502 .17016 L .7074 .17417 L p F P
0 g
s
.832 .797 .818 r
.69766 .17754 m .70007 .18153 L .7074 .17417 L p F P
0 g
s
.832 .797 .818 r
.7074 .17417 m .70502 .17016 L .69766 .17754 L p F P
0 g
s
.54 0 0 r
.18673 .9667 m .18443 .96595 L .17788 .96221 L p F P
0 g
s
.489 0 0 r
.17205 .9605 m .17788 .96221 L .18443 .96595 L p F P
0 g
s
.666 .709 .879 r
.46424 .97661 m .46545 .97817 L p .45139 .97801 L F P
0 g
s
.666 .709 .879 r
.45139 .97801 m .45311 .97743 L .46424 .97661 L p F P
0 g
s
.666 .702 .874 r
.45139 .97801 m .45311 .97743 L .45108 .9776 L closepath p F P
0 g
s
.579 .777 .974 r
.25147 .97963 m .26208 .97759 L .26547 .98005 L p F P
0 g
s
.613 .773 .957 r
.26208 .97759 m .25147 .97963 L .24804 .97749 L p F P
0 g
s
.796 .788 .845 r
.67353 .20531 m .67577 .20349 L .67306 .19977 L p F P
0 g
s
.796 .788 .845 r
.67306 .19977 m .67113 .20134 L .67353 .20531 L p F P
0 g
s
.794 .787 .846 r
.66192 .20871 m .67113 .20134 L .67353 .20531 L p F P
0 g
s
.481 .339 .611 r
.69505 .8963 m .69087 .89192 L .69421 .8903 L closepath p F P
0 g
s
.492 .362 .632 r
.69087 .89192 m .69421 .8903 L .69315 .88397 L p F P
0 g
s
.864 .64 .597 r
.10896 .89742 m .11412 .89972 L .11286 .90546 L p F P
0 g
s
.861 .653 .619 r
.11412 .89972 m .10896 .89742 L .11064 .89156 L p F P
0 g
s
.546 .515 .772 r
.67436 .79821 m .67896 .79851 L p .67913 .806 L F P
0 g
s
.544 .516 .775 r
.67896 .79851 m .67436 .79821 L .67801 .79602 L closepath p F P
0 g
s
.55 .526 .782 r
.67605 .7911 m .67801 .79602 L .67436 .79821 L p F P
0 g
s
.806 .79 .838 r
.68324 .19707 m .67577 .20349 L .67306 .19977 L p F P
0 g
s
.468 0 0 r
.30528 .73212 m .30011 .72944 L .29667 .72867 L p F P
0 g
s
.546 0 0 r
.31261 .7339 m .30528 .73212 L .30011 .72944 L p F P
0 g
s
.868 .799 .779 r
.72551 .13983 m .72639 .13871 L .72887 .14272 L p F P
0 g
s
.868 .799 .779 r
.72887 .14272 m .72814 .14366 L .72551 .13983 L p F P
0 g
s
.54 .504 .765 r
.68189 .80624 m .67913 .806 L .68133 .8047 L closepath p F P
0 g
s
.546 .515 .772 r
.67896 .79851 m .68133 .8047 L .67913 .806 L p F P
0 g
s
.764 .775 .862 r
.64698 .21956 m .63957 .22458 L .63679 .22081 L p F P
0 g
s
.859 .537 .441 r
.12792 .92864 m .1333 .93082 L .13414 .93603 L p F P
0 g
s
.856 .536 .445 r
.13491 .93634 m .13414 .93603 L .1333 .93082 L p F P
0 g
s
.571 .574 .817 r
.63887 .75913 m .6397 .75861 L p .65249 .76414 L F P
0 g
s
.574 .583 .824 r
.63887 .75913 m .63866 .75869 L .6397 .75861 L closepath p F P
0 g
s
.722 .305 .257 r
.33068 .74121 m .32348 .73986 L .31984 .73571 L p F P
0 g
s
.756 .351 .286 r
.31494 .7344 m .31984 .73571 L .32348 .73986 L p F P
0 g
s
.481 .355 .631 r
.69421 .8903 m .69315 .88397 L .6999 .88052 L p F P
0 g
s
.762 .758 .849 r
.20184 .7357 m .2016 .73546 L .20151 .73552 L closepath p F P
0 g
s
.684 .729 .884 r
.35087 .97761 m .34985 .97645 L .3474 .97742 L closepath p F P
0 g
s
.666 .701 .873 r
.45311 .97743 m .45108 .9776 L .44833 .97397 L p F P
0 g
s
.267 0 .073 r
.64303 .95323 m .64253 .95426 L .63127 .95915 L p F P
0 g
s
.167 0 0 r
.63043 .96031 m .63127 .95915 L .64253 .95426 L p F P
0 g
s
.863 .798 .785 r
.72355 .14934 m .72814 .14366 L .72551 .13983 L p F P
0 g
s
.827 .795 .821 r
.69526 .17988 m .69766 .17754 L .70007 .18153 L p F P
0 g
s
.827 .795 .821 r
.70007 .18153 m .69793 .18362 L .69526 .17988 L p F P
0 g
s
.85 .715 .713 r
.10793 .84576 m .10848 .84485 L .1065 .84382 L closepath p F P
0 g
s
.844 .721 .729 r
.10447 .84123 m .10796 .83581 L p .10848 .84485 L F P
0 g
s
.844 .721 .729 r
.10848 .84485 m .1065 .84382 L .10447 .84123 L p F P
0 g
s
.574 .586 .828 r
.6397 .75861 m .63866 .75869 L .63578 .75288 L p F P
0 g
s
.796 .757 .817 r
.16303 .75885 m .15433 .76652 L .15083 .76294 L p F P
0 g
s
.802 .757 .811 r
.15403 .7668 m .15433 .76652 L .15083 .76294 L p F P
0 g
s
.804 .754 .806 r
.14952 .76414 m .15403 .7668 L .14596 .77447 L p F P
0 g
s
.802 .757 .811 r
.15083 .76294 m .14952 .76414 L .15403 .7668 L p F P
0 g
s
.524 .476 .744 r
.68985 .82921 m .68779 .82298 L .69751 .82468 L closepath p F P
0 g
s
.52 .464 .734 r
.68985 .82921 m .69751 .82468 L p .69785 .83368 L F P
0 g
s
.52 .464 .734 r
.69785 .83368 m .69079 .8322 L .68985 .82921 L p F P
0 g
s
.809 .791 .836 r
.68324 .19707 m .68687 .19389 L .68418 .19016 L p F P
0 g
s
.809 .791 .836 r
.68418 .19016 m .68083 .19309 L .68324 .19707 L p F P
0 g
s
.806 .79 .838 r
.67306 .19977 m .68083 .19309 L .68324 .19707 L p F P
0 g
s
.821 .794 .827 r
.69201 .18917 m .69793 .18362 L .69526 .17988 L p F P
0 g
s
.841 .73 .742 r
.11256 .81996 m .10782 .82665 L .11245 .8292 L p F P
0 g
s
.841 .73 .742 r
.11328 .82036 m .11256 .81996 L p .11245 .8292 L F P
0 g
s
.844 .728 .735 r
.10782 .82665 m .11245 .8292 L .10796 .83581 L p F P
0 g
s
.511 .427 .697 r
.6969 .85323 m .69494 .8526 L .69651 .85175 L closepath p F P
0 g
s
.519 .442 .708 r
.69448 .84444 m .69651 .85175 L .69494 .8526 L p F P
0 g
s
.52 .464 .734 r
.69226 .83692 m .69079 .8322 L .69785 .83368 L closepath p F P
0 g
s
.765 .761 .849 r
.18727 .73958 m .19684 .73289 L .20151 .73552 L p F P
0 g
s
.763 .761 .851 r
.19815 .73199 m .19684 .73289 L .20151 .73552 L p F P
0 g
s
.763 .761 .851 r
.20151 .73552 m .2016 .73546 L .19815 .73199 L p F P
0 g
s
.748 .762 .864 r
.21243 .72865 m .2016 .73546 L .19815 .73199 L p F P
0 g
s
.661 .715 .889 r
.47702 .97528 m .47952 .97839 L p .46545 .97817 L F P
0 g
s
.661 .715 .889 r
.46545 .97817 m .47344 .97561 L .47702 .97528 L p F P
0 g
s
.66 .706 .881 r
.46545 .97817 m .47344 .97561 L .46424 .97661 L closepath p F P
0 g
s
.717 .438 .503 r
.37855 .75671 m .3704 .75616 L .36955 .75112 L p F P
0 g
s
.731 .448 .499 r
.36347 .75052 m .36955 .75112 L .3704 .75616 L p F P
0 g
s
.667 .707 .878 r
.46424 .97661 m .46241 .97424 L .45311 .97743 L closepath p F P
0 g
s
.666 .701 .873 r
.45936 .96993 m .46241 .97424 L .45311 .97743 L p F P
0 g
s
.666 .701 .873 r
.44833 .97397 m .45936 .96993 L p .45311 .97743 L F P
0 g
s
.821 .794 .827 r
.69526 .17988 m .6896 .18519 L .69201 .18917 L p F P
0 g
s
.817 .793 .829 r
.68418 .19016 m .6896 .18519 L .69201 .18917 L p F P
0 g
s
.817 .793 .829 r
.69201 .18917 m .68687 .19389 L .68418 .19016 L p F P
0 g
s
.695 .723 .871 r
.33578 .9773 m .33746 .97656 L .3474 .97742 L p F P
0 g
s
.682 .714 .873 r
.34666 .97254 m .33746 .97656 L .3474 .97742 L p F P
0 g
s
.682 .714 .873 r
.3474 .97742 m .34985 .97645 L .34666 .97254 L p F P
0 g
s
.864 .656 .62 r
.10557 .88923 m .11064 .89156 L .10896 .89742 L p F P
0 g
s
.861 .667 .639 r
.11064 .89156 m .10557 .88923 L .10765 .88327 L p F P
0 g
s
.515 .451 .723 r
.69226 .83692 m .69785 .83368 L p .69705 .84297 L F P
0 g
s
.515 .451 .723 r
.69705 .84297 m .69381 .84216 L .69226 .83692 L p F P
0 g
s
.524 .476 .745 r
.69751 .82468 m .68779 .82298 L .68723 .82128 L p F P
0 g
s
0 .467 .749 r
.19737 .96959 m .20272 .97116 L .19914 .96975 L p F P
0 g
s
.804 .754 .806 r
.14596 .77447 m .14139 .77183 L .14952 .76414 L p F P
0 g
s
.807 .753 .802 r
.14596 .77447 m .14322 .77713 L .13971 .77347 L p F P
0 g
s
.807 .753 .802 r
.13971 .77347 m .14139 .77183 L .14596 .77447 L p F P
0 g
s
.741 .246 .06 r
.17158 .96034 m .16575 .95833 L .16158 .95397 L p F P
0 g
s
.729 .226 .031 r
.15558 .952 m .16158 .95397 L .16575 .95833 L p F P
0 g
s
.793 .372 .248 r
.15475 .95084 m .15558 .952 L .16158 .95397 L p F P
0 g
s
.796 .757 .817 r
.15083 .76294 m .15849 .75619 L .16303 .75885 L p F P
0 g
s
.794 .758 .82 r
.16187 .75327 m .15849 .75619 L .16303 .75885 L p F P
0 g
s
.794 .758 .82 r
.16303 .75885 m .16536 .75683 L .16187 .75327 L p F P
0 g
s
.524 .476 .745 r
.68723 .82128 m .69605 .81597 L p .69751 .82468 L F P
0 g
s
.529 .488 .755 r
.68723 .82128 m .68483 .81437 L .69605 .81597 L closepath p F P
0 g
s
.603 .779 .965 r
.25487 .72315 m .26549 .7206 L .26888 .72325 L p F P
0 g
s
.571 .776 .976 r
.26549 .7206 m .25487 .72315 L .25147 .72011 L p F P
0 g
s
.674 .771 .924 r
.24078 .72413 m .25147 .72011 L .25487 .72315 L p F P
0 g
s
.555 .548 .802 r
.66736 .7704 m .67025 .77703 L .65874 .77702 L p F P
0 g
s
.555 .548 .802 r
.66281 .77039 m .66736 .7704 L p .65874 .77702 L F P
0 g
s
.555 .548 .802 r
.65874 .77702 m .65736 .77385 L .66281 .77039 L p F P
0 g
s
.593 .613 .841 r
.61866 .74291 m .61631 .74322 L .61823 .74211 L closepath p F P
0 g
s
.596 .622 .848 r
.61578 .73767 m .61823 .74211 L .61631 .74322 L p F P
0 g
s
.853 .715 .709 r
.10476 .85125 m .10793 .84576 L .1065 .84382 L p F P
0 g
s
.627 .771 .949 r
.26547 .98005 m .27615 .97724 L .2795 .97998 L p F P
0 g
s
.65 .764 .932 r
.27615 .97724 m .26547 .98005 L .26208 .97759 L p F P
0 g
s
.787 .759 .828 r
.17291 .75062 m .16536 .75683 L .16187 .75327 L p F P
0 g
s
.813 .752 .796 r
.13845 .78197 m .14322 .77713 L .13971 .77347 L p F P
0 g
s
0 0 0 r
.61737 .96584 m .61656 .96622 L .60576 .96951 L p F P
0 g
s
.265 .768 .746 r
.60337 .97001 m .60576 .96951 L .61656 .96622 L p F P
0 g
s
.256 .764 .754 r
.60576 .96951 m .60337 .97001 L .59212 .97312 L p F P
0 g
s
.663 .773 .931 r
.25147 .72011 m .24078 .72413 L .23738 .72088 L p F P
0 g
s
.708 .766 .897 r
.22664 .72597 m .23738 .72088 L .24078 .72413 L p F P
0 g
s
.733 .762 .876 r
.21243 .72865 m .21903 .72494 L .22392 .72751 L p F P
0 g
s
.735 .765 .877 r
.22322 .72261 m .21903 .72494 L .22392 .72751 L p F P
0 g
s
.735 .765 .877 r
.22392 .72751 m .22664 .72597 L .22322 .72261 L p F P
0 g
s
.453 .28 .555 r
.68633 .91268 m .68593 .90698 L .6957 .90235 L p F P
0 g
s
.47 .312 .585 r
.69507 .89644 m .6957 .90235 L .68593 .90698 L p F P
0 g
s
.465 .289 .556 r
.68296 .91419 m .68633 .91268 L .68593 .90698 L p F P
0 g
s
.558 .261 .419 r
.4616 .74307 m .47362 .7408 L .4727 .74527 L p F P
0 g
s
.558 .261 .419 r
.46078 .74665 m .4616 .74307 L p .4727 .74527 L F P
0 g
s
.515 .451 .722 r
.69448 .84444 m .69381 .84216 L .69705 .84297 L closepath p F P
0 g
s
.624 .36 .498 r
.43541 .75083 m .43744 .75059 L .43947 .75531 L p F P
0 g
s
.624 .36 .498 r
.43947 .75531 m .43497 .75583 L .43541 .75083 L p F P
0 g
s
.643 .373 .495 r
.43541 .75083 m .43497 .75583 L .42165 .75679 L p F P
0 g
s
.571 .574 .817 r
.6397 .75861 m .65009 .75805 L p .65249 .76414 L F P
0 g
s
.569 .576 .82 r
.65009 .75805 m .6397 .75861 L .6479 .75344 L closepath p F P
0 g
s
.574 .586 .828 r
.64721 .75204 m .6479 .75344 L .6397 .75861 L p F P
0 g
s
.574 .586 .828 r
.63578 .75288 m .64721 .75204 L p .6397 .75861 L F P
0 g
s
.427 .207 .476 r
.68239 .91996 m .67654 .92253 L .67641 .92773 L p F P
0 g
s
.45 .254 .521 r
.67654 .92253 m .68239 .91996 L .68296 .91419 L p F P
0 g
s
.836 .469 .36 r
.14722 .94519 m .14156 .9431 L .13978 .93814 L p F P
0 g
s
.836 .465 .351 r
.13491 .93634 m .13978 .93814 L .14156 .9431 L p F P
0 g
s
.889 .796 .751 r
.73556 .12604 m .73627 .12497 L .73365 .12104 L p F P
0 g
s
.758 .431 .431 r
.33158 .7414 m .33954 .74298 L .34153 .74765 L p F P
0 g
s
.745 .359 .322 r
.33954 .74298 m .33158 .7414 L .3311 .74068 L p F P
0 g
s
.739 .409 .422 r
.34685 .74841 m .34153 .74765 L .33954 .74298 L p F P
0 g
s
.508 .436 .711 r
.69651 .85175 m .69448 .84444 L .69705 .84297 L p F P
0 g
s
.858 .701 .687 r
.10134 .85757 m .10613 .86003 L .10302 .86627 L p F P
0 g
s
.855 .707 .698 r
.10613 .86003 m .10134 .85757 L .10476 .85125 L p F P
0 g
s
.629 .694 .891 r
.58164 .7227 m .57041 .72533 L .56751 .72141 L p F P
0 g
s
.816 .751 .792 r
.13845 .78197 m .13202 .78863 L .1285 .78496 L p F P
0 g
s
.816 .751 .792 r
.1285 .78496 m .13393 .77933 L .13845 .78197 L p F P
0 g
s
.813 .752 .796 r
.13971 .77347 m .13393 .77933 L .13845 .78197 L p F P
0 g
s
.528 .488 .755 r
.69605 .81597 m .68483 .81437 L .6844 .81312 L p F P
0 g
s
.655 .723 .899 r
.47952 .97839 m .49058 .97503 L .49359 .97862 L p F P
0 g
s
.657 .713 .889 r
.48966 .97381 m .49058 .97503 L .47952 .97839 L p F P
0 g
s
.657 .713 .889 r
.47952 .97839 m .47702 .97528 L .48966 .97381 L p F P
0 g
s
.656 .761 .927 r
.2795 .97998 m .29024 .97656 L .29356 .97957 L p F P
0 g
s
.673 .752 .911 r
.29024 .97656 m .2795 .97998 L .27615 .97724 L p F P
0 g
s
.528 .488 .755 r
.6844 .81312 m .69345 .80757 L p .69605 .81597 L F P
0 g
s
.533 .5 .765 r
.6844 .81312 m .68189 .80624 L .69345 .80757 L closepath p F P
0 g
s
.386 0 0 r
.29091 .72723 m .29667 .72867 L .29409 .72851 L p F P
0 g
s
.836 .738 .757 r
.11789 .8131 m .11274 .81973 L .10921 .81579 L p F P
0 g
s
.836 .738 .757 r
.10921 .81579 m .11331 .81052 L .11789 .8131 L p F P
0 g
s
.833 .74 .762 r
.11789 .8131 m .11331 .81052 L .11888 .80359 L p F P
0 g
s
.787 .759 .828 r
.16187 .75327 m .16834 .74797 L .17291 .75062 L p F P
0 g
s
.785 .76 .83 r
.17286 .74433 m .16834 .74797 L .17291 .75062 L p F P
0 g
s
.785 .76 .83 r
.17291 .75062 m .17634 .74786 L .17286 .74433 L p F P
0 g
s
.421 .75 .994 r
.27976 .72297 m .27907 .72278 L .26888 .72325 L p F P
0 g
s
.468 .727 .982 r
.27907 .72278 m .26888 .72325 L .26549 .7206 L p F P
0 g
s
.626 .361 .497 r
.43744 .75059 m .44827 .74942 L .44784 .7544 L p F P
0 g
s
.626 .361 .497 r
.44784 .7544 m .43947 .75531 L .43744 .75059 L p F P
0 g
s
.889 .796 .751 r
.73365 .12104 m .73299 .12204 L .73556 .12604 L p F P
0 g
s
.88 .796 .763 r
.72851 .12833 m .73109 .13233 L .73556 .12604 L p F P
0 g
s
.88 .796 .763 r
.73556 .12604 m .73299 .12204 L .72851 .12833 L p F P
0 g
s
.863 .671 .641 r
.10267 .8809 m .10765 .88327 L .10557 .88923 L p F P
0 g
s
.86 .68 .657 r
.10765 .88327 m .10267 .8809 L .10512 .87483 L p F P
0 g
s
.731 .448 .499 r
.3704 .75616 m .3628 .75541 L .36347 .75052 L p F P
0 g
s
.732 .449 .499 r
.35965 .75013 m .36347 .75052 L .3628 .75541 L p F P
0 g
s
.7 .695 .842 r
.37485 .97078 m .36393 .97566 L .36075 .97159 L p F P
0 g
s
.686 .741 .893 r
.30434 .97567 m .29356 .97957 L .29024 .97656 L p F P
0 g
s
.673 .749 .908 r
.29356 .97957 m .30434 .97567 L .30762 .97892 L p F P
0 g
s
.702 .701 .847 r
.36075 .97159 m .34985 .97645 L .34666 .97254 L p F P
0 g
s
.863 .798 .785 r
.72551 .13983 m .72106 .14533 L .72355 .14934 L p F P
0 g
s
.859 .798 .79 r
.71545 .15206 m .71796 .15606 L .72355 .14934 L p F P
0 g
s
.859 .798 .79 r
.72355 .14934 m .72106 .14533 L .71545 .15206 L p F P
0 g
s
.696 .73 .876 r
.33578 .9773 m .33746 .97656 L .33489 .97628 L closepath p F P
0 g
s
.691 .727 .878 r
.33489 .97628 m .33578 .9773 L p .3217 .97814 L F P
0 g
s
.692 .698 .851 r
.378 .97497 m .38893 .97014 L .39206 .97443 L p F P
0 g
s
.697 .689 .838 r
.38893 .97014 m .378 .97497 L .37485 .97078 L p F P
0 g
s
.764 .775 .862 r
.63679 .22081 m .64443 .21565 L .64698 .21956 L p F P
0 g
s
.765 .776 .862 r
.64698 .21956 m .65075 .21699 L .64799 .21321 L p F P
0 g
s
.765 .776 .862 r
.64799 .21321 m .64443 .21565 L .64698 .21956 L p F P
0 g
s
.691 .727 .878 r
.3217 .97814 m .32749 .97571 L .33489 .97628 L p F P
0 g
s
.703 .73 .871 r
.32749 .97571 m .3217 .97814 L .31845 .97467 L p F P
0 g
s
.684 .739 .893 r
.30762 .97892 m .31845 .97467 L .3217 .97814 L p F P
0 g
s
.704 .768 .902 r
.23738 .72088 m .22664 .72597 L .22322 .72261 L p F P
0 g
s
.695 .728 .875 r
.31845 .97467 m .30762 .97892 L .30434 .97567 L p F P
0 g
s
.601 .635 .857 r
.6019 .73483 m .60158 .73428 L .60334 .73399 L closepath p F P
0 g
s
.776 .76 .839 r
.18399 .74203 m .17634 .74786 L .17286 .74433 L p F P
0 g
s
.56 .559 .809 r
.65736 .77385 m .65585 .7705 L .66281 .77039 L closepath p F P
0 g
s
.42 .761 .996 r
.23082 .97678 m .23405 .97677 L .23057 .97474 L p F P
0 g
s
.42 .761 .996 r
.23057 .97474 m .22394 .97509 L .23082 .97678 L p F P
0 g
s
.223 .694 .941 r
.22012 .97515 m .22394 .97509 L .23082 .97678 L p F P
0 g
s
.693 .684 .836 r
.40302 .96969 m .39206 .97443 L .38893 .97014 L p F P
0 g
s
.689 .694 .849 r
.39206 .97443 m .40302 .96969 L .40613 .97406 L p F P
0 g
s
.081 0 0 r
.50005 .73007 m .49825 .73145 L .48698 .73451 L p F P
0 g
s
.82 .751 .787 r
.13137 .78934 m .13202 .78863 L .1285 .78496 L p F P
0 g
s
.824 .748 .781 r
.12689 .78669 m .13137 .78934 L .12497 .79651 L p F P
0 g
s
.82 .751 .787 r
.1285 .78496 m .12689 .78669 L .13137 .78934 L p F P
0 g
s
.424 .861 .922 r
.60337 .97001 m .59212 .97312 L .58932 .97276 L p F P
0 g
s
.426 .859 .931 r
.57808 .97566 m .58932 .97276 L .59212 .97312 L p F P
0 g
s
.502 .421 .697 r
.69651 .85175 m .70582 .84645 L p .70383 .85579 L F P
0 g
s
.502 .421 .697 r
.70383 .85579 m .6969 .85323 L .69651 .85175 L p F P
0 g
s
.508 .436 .711 r
.70558 .84558 m .70582 .84645 L .69651 .85175 L p F P
0 g
s
.508 .436 .711 r
.69705 .84297 m .70558 .84558 L p .69651 .85175 L F P
0 g
s
.648 .735 .913 r
.49359 .97862 m .50468 .97543 L .50767 .97879 L p F P
0 g
s
.654 .714 .892 r
.50468 .97543 m .49359 .97862 L .49058 .97503 L p F P
0 g
s
.446 .25 .519 r
.68633 .91268 m .68296 .91419 L .68239 .91996 L p F P
0 g
s
.264 0 .095 r
.64253 .95426 m .64911 .95102 L .64303 .95323 L closepath p F P
0 g
s
.325 0 .203 r
.65377 .94848 m .65476 .94533 L p .64303 .95323 L F P
0 g
s
.325 0 .203 r
.64303 .95323 m .64911 .95102 L .65377 .94848 L p F P
0 g
s
.601 .643 .864 r
.60334 .73399 m .60158 .73428 L .5987 .72948 L p F P
0 g
s
.585 .604 .838 r
.61866 .74291 m .63003 .74164 L .63291 .74714 L p F P
0 g
s
.587 .61 .843 r
.62731 .73648 m .63003 .74164 L .61866 .74291 L p F P
0 g
s
.587 .61 .843 r
.61866 .74291 m .61823 .74211 L .62731 .73648 L p F P
0 g
s
.685 .691 .849 r
.40613 .97406 m .4171 .96945 L .4202 .97386 L p F P
0 g
s
.689 .68 .836 r
.4171 .96945 m .40613 .97406 L .40302 .96969 L p F P
0 g
s
.66 .705 .88 r
.47344 .97561 m .46424 .97661 L .46241 .97424 L p F P
0 g
s
.533 .5 .766 r
.69345 .80757 m .68189 .80624 L .68133 .8047 L p F P
0 g
s
.732 .449 .499 r
.3628 .75541 m .36047 .75518 L .35965 .75013 L p F P
0 g
s
.741 .459 .503 r
.35037 .74896 m .35965 .75013 L .36047 .75518 L p F P
0 g
s
.334 0 0 r
.19082 .9678 m .18673 .9667 L .18898 .96715 L closepath p F P
0 g
s
.341 0 .089 r
.48596 .73621 m .48698 .73451 L .49825 .73145 L p F P
0 g
s
.746 .768 .871 r
.62747 .22656 m .62559 .22771 L .62279 .2239 L p F P
0 g
s
.719 .759 .884 r
.61155 .22975 m .62279 .2239 L .62559 .22771 L p F P
0 g
s
.853 .715 .709 r
.1065 .84382 m .10377 .84235 L p .10476 .85125 L F P
0 g
s
.85 .721 .721 r
.1065 .84382 m .10447 .84123 L .10377 .84235 L closepath p F P
0 g
s
.325 0 .233 r
.65377 .94848 m .65476 .94533 L .66501 .94136 L p F P
0 g
s
.38 .087 .337 r
.66585 .9368 m .66501 .94136 L .65476 .94533 L p F P
0 g
s
.697 .729 .875 r
.34346 .96842 m .34666 .97254 L .33746 .97656 L p F P
0 g
s
.697 .729 .875 r
.33255 .97359 m .34346 .96842 L p .33746 .97656 L F P
0 g
s
.697 .729 .875 r
.33746 .97656 m .33489 .97628 L .33255 .97359 L p F P
0 g
s
.502 .421 .697 r
.69834 .85886 m .6969 .85323 L .70383 .85579 L closepath p F P
0 g
s
.837 .735 .751 r
.11328 .82036 m .11274 .81973 L .11256 .81996 L closepath p F P
0 g
s
.341 .744 .982 r
.22394 .97509 m .21675 .97363 L .22012 .97515 L closepath p F P
0 g
s
.533 .5 .766 r
.68133 .8047 m .68971 .79947 L p .69345 .80757 L F P
0 g
s
.537 .511 .775 r
.68133 .8047 m .67896 .79851 L .68971 .79947 L closepath p F P
0 g
s
.756 .351 .286 r
.31389 .73492 m .31494 .7344 L p .32348 .73986 L F P
0 g
s
.68 .196 .094 r
.31389 .73492 m .31261 .7339 L .31494 .7344 L closepath p F P
0 g
s
.779 .78 .853 r
.6601 .21007 m .65075 .21699 L .64799 .21321 L p F P
0 g
s
.817 .404 .262 r
.15324 .95121 m .14982 .94995 L .14722 .94519 L p F P
0 g
s
.816 .396 .247 r
.14156 .9431 m .14722 .94519 L .14982 .94995 L p F P
0 g
s
.681 .689 .851 r
.4202 .97386 m .43118 .96942 L .43426 .97383 L p F P
0 g
s
.685 .678 .837 r
.43118 .96942 m .4202 .97386 L .4171 .96945 L p F P
0 g
s
.59 .618 .848 r
.62715 .73619 m .62731 .73648 L .61823 .74211 L p F P
0 g
s
.59 .618 .848 r
.61823 .74211 m .61578 .73767 L .62715 .73619 L p F P
0 g
s
.848 .724 .726 r
.10796 .83581 m .10447 .84123 L .10097 .8369 L p F P
0 g
s
.848 .724 .726 r
.10097 .8369 m .1033 .83328 L .10796 .83581 L p F P
0 g
s
.844 .728 .735 r
.10796 .83581 m .1033 .83328 L .10782 .82665 L p F P
0 g
s
.862 .684 .66 r
.10022 .87243 m .10512 .87483 L .10267 .8809 L p F P
0 g
s
.859 .691 .673 r
.10512 .87483 m .10022 .87243 L .10302 .86627 L p F P
0 g
s
.776 .76 .839 r
.17286 .74433 m .17939 .73937 L .18399 .74203 L p F P
0 g
s
.775 .762 .841 r
.1838 .73609 m .17939 .73937 L .18399 .74203 L p F P
0 g
s
.775 .762 .841 r
.18399 .74203 m .18727 .73958 L .1838 .73609 L p F P
0 g
s
.641 .751 .929 r
.50767 .97879 m .51878 .97576 L .52175 .97884 L p F P
0 g
s
.648 .726 .906 r
.51878 .97576 m .50767 .97879 L .50468 .97543 L p F P
0 g
s
.747 .768 .87 r
.62747 .22656 m .63679 .22081 L .63401 .217 L p F P
0 g
s
.747 .768 .87 r
.63401 .217 m .62474 .22271 L .62747 .22656 L p F P
0 g
s
.746 .768 .871 r
.62279 .2239 m .62474 .22271 L .62747 .22656 L p F P
0 g
s
.69 .727 .878 r
.33489 .97628 m .33255 .97359 L .32749 .97571 L closepath p F P
0 g
s
.751 .359 .311 r
.33158 .7414 m .33068 .74121 L .3311 .74068 L closepath p F P
0 g
s
.785 .344 .202 r
.15558 .952 m .15324 .95121 L .15475 .95084 L closepath p F P
0 g
s
.857 .711 .699 r
.10006 .84875 m .10476 .85125 L .10134 .85757 L p F P
0 g
s
.853 .715 .709 r
.10377 .84235 m .10006 .84875 L .10476 .85125 L p F P
0 g
s
.471 .332 .61 r
.69421 .8903 m .7038 .88541 L p .69514 .8964 L F P
0 g
s
.471 .332 .61 r
.69514 .8964 m .69505 .8963 L .69421 .8903 L p F P
0 g
s
.481 .355 .631 r
.70347 .88349 m .7038 .88541 L .69421 .8903 L p F P
0 g
s
.481 .355 .631 r
.6999 .88052 m .70347 .88349 L p .69421 .8903 L F P
0 g
s
.56 .559 .81 r
.66281 .77039 m .65585 .7705 L .65297 .76413 L p F P
0 g
s
.839 .739 .753 r
.11256 .81996 m .11274 .81973 L .10921 .81579 L p F P
0 g
s
.844 .735 .743 r
.10803 .81737 m .11256 .81996 L .10782 .82665 L p F P
0 g
s
.839 .739 .753 r
.10921 .81579 m .10803 .81737 L .11256 .81996 L p F P
0 g
s
.851 .796 .797 r
.71462 .15302 m .71545 .15206 L .71796 .15606 L p F P
0 g
s
.851 .796 .797 r
.71796 .15606 m .71726 .15685 L .71462 .15302 L p F P
0 g
s
.827 .747 .776 r
.12497 .79651 m .1207 .80142 L .11717 .79767 L p F P
0 g
s
.827 .747 .776 r
.11717 .79767 m .12045 .79388 L .12497 .79651 L p F P
0 g
s
.824 .748 .781 r
.12497 .79651 m .12045 .79388 L .12689 .78669 L p F P
0 g
s
.597 .631 .855 r
.6129 .73253 m .60334 .73399 L .61108 .72934 L closepath p F P
0 g
s
.601 .643 .864 r
.61002 .72754 m .61108 .72934 L .60334 .73399 L p F P
0 g
s
.601 .643 .864 r
.5987 .72948 m .61002 .72754 L p .60334 .73399 L F P
0 g
s
.489 0 0 r
.17175 .96048 m .17205 .9605 L p .18443 .96595 L F P
0 g
s
.685 .155 0 r
.17175 .96048 m .17158 .96034 L .17205 .9605 L closepath p F P
0 g
s
.676 .689 .854 r
.43426 .97383 m .44527 .96959 L .44833 .97397 L p F P
0 g
s
.68 .677 .84 r
.44527 .96959 m .43426 .97383 L .43118 .96942 L p F P
0 g
s
.612 .654 .867 r
.58453 .72703 m .59581 .7248 L .5987 .72948 L p F P
0 g
s
.616 .67 .879 r
.59292 .72027 m .59581 .7248 L .58453 .72703 L p F P
0 g
s
.616 .67 .879 r
.59142 .72058 m .59292 .72027 L p .58453 .72703 L F P
0 g
s
.616 .67 .879 r
.58453 .72703 m .58328 .72513 L .59142 .72058 L p F P
0 g
s
.846 .796 .802 r
.71166 .16304 m .71726 .15685 L .71462 .15302 L p F P
0 g
s
.764 .763 .852 r
.19684 .73289 m .18727 .73958 L .1838 .73609 L p F P
0 g
s
.73 .763 .879 r
.21903 .72494 m .21243 .72865 L .20899 .72521 L p F P
0 g
s
.748 .762 .864 r
.19815 .73199 m .20899 .72521 L .21243 .72865 L p F P
0 g
s
.171 .62 .938 r
.28482 .72506 m .27976 .72297 L .28283 .72475 L closepath p F P
0 g
s
.574 .588 .829 r
.64434 .74627 m .64721 .75204 L .63578 .75288 L p F P
0 g
s
.574 .588 .829 r
.63544 .74692 m .64434 .74627 L p .63578 .75288 L F P
0 g
s
.574 .588 .829 r
.63578 .75288 m .63345 .7482 L .63544 .74692 L p F P
0 g
s
.73 .29 .206 r
.31261 .7339 m .31389 .73492 L .31151 .73682 L p F P
0 g
s
.73 .29 .206 r
.30528 .73212 m .31261 .7339 L p .31151 .73682 L F P
0 g
s
.688 .441 .544 r
.4061 .75733 m .40787 .75732 L .40777 .76269 L p F P
0 g
s
.688 .441 .544 r
.40777 .76269 m .40593 .7627 L .4061 .75733 L p F P
0 g
s
.693 .446 .544 r
.39351 .75729 m .4061 .75733 L .40593 .7627 L p F P
0 g
s
.673 .429 .544 r
.40787 .75732 m .4211 .75682 L .42094 .76218 L p F P
0 g
s
.673 .429 .544 r
.42094 .76218 m .40777 .76269 L .40787 .75732 L p F P
0 g
s
.495 .406 .684 r
.7 .86579 m .69834 .85886 L .70383 .85579 L p F P
0 g
s
.505 .413 .684 r
.69973 .86594 m .7 .86579 L .69834 .85886 L p F P
0 g
s
.537 .872 .992 r
.5776 .97548 m .57808 .97566 L .58932 .97276 L p F P
0 g
s
.693 .446 .544 r
.40593 .7627 m .39339 .76266 L .39351 .75729 L p F P
0 g
s
.704 .455 .545 r
.39305 .75728 m .39351 .75729 L .39339 .76266 L p F P
0 g
s
.708 .458 .544 r
.38126 .75686 m .39305 .75728 L .39287 .76265 L p F P
0 g
s
.704 .455 .545 r
.39339 .76266 m .39287 .76265 L .39305 .75728 L p F P
0 g
s
.631 .773 .948 r
.52175 .97884 m .53289 .97594 L .53584 .97867 L p F P
0 g
s
.641 .744 .923 r
.53289 .97594 m .52175 .97884 L .51878 .97576 L p F P
0 g
s
.875 .795 .769 r
.7238 .13473 m .72639 .13871 L .73109 .13233 L p F P
0 g
s
.875 .795 .769 r
.73109 .13233 m .72851 .12833 L .7238 .13473 L p F P
0 g
s
.649 .098 0 r
.17158 .96034 m .17175 .96048 L .16804 .96006 L p F P
0 g
s
.649 .098 0 r
.16804 .96006 m .16575 .95833 L .17158 .96034 L p F P
0 g
s
.601 .339 .493 r
.44784 .7544 m .44827 .74942 L .46063 .7475 L p F P
0 g
s
.572 .267 .413 r
.46078 .74665 m .46063 .7475 L .44827 .74942 L p F P
0 g
s
.537 .512 .775 r
.68971 .79947 m .67896 .79851 L .67801 .79602 L p F P
0 g
s
.055 0 0 r
.62866 .96197 m .63043 .96031 L .64095 .95668 L p F P
0 g
s
.167 0 0 r
.64253 .95426 m .64095 .95668 L .63043 .96031 L p F P
0 g
s
.051 0 0 r
.63043 .96031 m .62866 .96197 L .61737 .96584 L p F P
0 g
s
.368 .081 .339 r
.67432 .93331 m .66585 .9368 L .66501 .94136 L p F P
0 g
s
.408 .153 .413 r
.6761 .93123 m .67641 .92773 L p .66585 .9368 L F P
0 g
s
.408 .153 .413 r
.66585 .9368 m .67432 .93331 L .6761 .93123 L p F P
0 g
s
.864 .597 .533 r
.12231 .92108 m .11701 .91885 L .1173 .91335 L p F P
0 g
s
.867 .6 .533 r
.11206 .9111 m .1173 .91335 L .11701 .91885 L p F P
0 g
s
.865 .62 .567 r
.1173 .91335 m .11206 .9111 L .11286 .90546 L p F P
0 g
s
.489 0 0 r
.17845 .96399 m .17175 .96048 L p .18422 .96587 L F P
0 g
s
.521 0 0 r
.17845 .96399 m .17175 .96048 L .16804 .96006 L p F P
0 g
s
.521 0 0 r
.17242 .96203 m .17845 .96399 L p .17806 .96384 L F P
0 g
s
.521 0 0 r
.16804 .96006 m .17242 .96203 L p .17806 .96384 L F P
0 g
s
.43 0 0 r
.17242 .96203 m .16804 .96006 L .16434 .95933 L p F P
0 g
s
.43 0 0 r
.16434 .95933 m .16632 .96008 L .17242 .96203 L p F P
0 g
s
0 .472 .775 r
.17446 .96214 m .16655 .96014 L p .17242 .96203 L F P
0 g
s
0 .472 .775 r
.16655 .96014 m .16632 .96008 L .17242 .96203 L p F P
0 g
s
0 .401 .704 r
.17809 .96375 m .17258 .96207 L p .17845 .96399 L F P
0 g
s
0 .401 .704 r
.17258 .96207 m .17242 .96203 L .17845 .96399 L p F P
0 g
s
.489 0 0 r
.18443 .96595 m .17845 .96399 L p .18422 .96587 L F P
0 g
s
.507 .437 .713 r
.70558 .84558 m .69705 .84297 L .70376 .83908 L closepath p F P
0 g
s
.515 .451 .723 r
.70251 .83489 m .70376 .83908 L .69705 .84297 L p F P
0 g
s
.515 .451 .723 r
.69785 .83368 m .70251 .83489 L p .69705 .84297 L F P
0 g
s
.867 .623 .567 r
.10851 .90354 m .11286 .90546 L .11206 .9111 L p F P
0 g
s
.864 .64 .597 r
.1081 .90134 m .10896 .89742 L p .11286 .90546 L F P
0 g
s
.864 .64 .597 r
.11286 .90546 m .10851 .90354 L .1081 .90134 L p F P
0 g
s
.758 .431 .431 r
.34153 .74765 m .33326 .74617 L .33158 .7414 L p F P
0 g
s
.772 .438 .421 r
.33068 .74121 m .33158 .7414 L .33326 .74617 L p F P
0 g
s
.863 .57 .492 r
.12792 .92864 m .12257 .92644 L .12231 .92108 L p F P
0 g
s
.865 .572 .49 r
.11701 .91885 m .12231 .92108 L .12257 .92644 L p F P
0 g
s
.675 .677 .844 r
.45936 .96993 m .44833 .97397 L .44527 .96959 L p F P
0 g
s
.617 .8 .97 r
.53584 .97867 m .54701 .97586 L .54992 .97818 L p F P
0 g
s
.632 .767 .944 r
.54701 .97586 m .53584 .97867 L .53289 .97594 L p F P
0 g
s
.781 .781 .852 r
.6601 .21007 m .66192 .20871 L .65918 .20493 L p F P
0 g
s
.781 .781 .852 r
.65918 .20493 m .65756 .20614 L .6601 .21007 L p F P
0 g
s
.779 .78 .853 r
.64799 .21321 m .65756 .20614 L .6601 .21007 L p F P
0 g
s
.537 .512 .775 r
.67801 .79602 m .68482 .79168 L p .68971 .79947 L F P
0 g
s
.541 .522 .784 r
.67801 .79602 m .67605 .7911 L .68482 .79168 L closepath p F P
0 g
s
.831 .747 .771 r
.11888 .80359 m .1207 .80142 L .11717 .79767 L p F P
0 g
s
.703 .73 .871 r
.31845 .97467 m .31874 .97453 L .32749 .97571 L p F P
0 g
s
.688 .715 .869 r
.32933 .96965 m .31874 .97453 L .32749 .97571 L p F P
0 g
s
.688 .715 .869 r
.32749 .97571 m .33255 .97359 L .32933 .96965 L p F P
0 g
s
.545 .863 .996 r
.5776 .97548 m .57523 .97444 L .56401 .97723 L p F P
0 g
s
.596 .832 .989 r
.57523 .97444 m .56401 .97723 L .56112 .97541 L p F P
0 g
s
.593 .833 .99 r
.54992 .97818 m .56112 .97541 L .56401 .97723 L p F P
0 g
s
.86 .696 .677 r
.09821 .86382 m .10302 .86627 L .10022 .87243 L p F P
0 g
s
.858 .701 .687 r
.10302 .86627 m .09821 .86382 L .10134 .85757 L p F P
0 g
s
.619 .797 .967 r
.56112 .97541 m .54992 .97818 L .54701 .97586 L p F P
0 g
s
.708 .458 .544 r
.39287 .76265 m .38107 .76222 L .38126 .75686 L p F P
0 g
s
.717 .466 .545 r
.37855 .75671 m .38126 .75686 L .38107 .76222 L p F P
0 g
s
.846 .796 .802 r
.71462 .15302 m .70916 .15906 L .71166 .16304 L p F P
0 g
s
.842 .795 .806 r
.70363 .16502 m .70916 .15906 L .71166 .16304 L p F P
0 g
s
.842 .795 .806 r
.71166 .16304 m .7063 .16883 L .70363 .16502 L p F P
0 g
s
.2 0 0 r
.18534 .96634 m .18673 .9667 L .19082 .9678 L p F P
0 g
s
.2 0 0 r
.19082 .9678 m .19914 .96975 L p .18534 .96634 L F P
0 g
s
.661 .714 .887 r
.47702 .97528 m .47649 .97462 L .47344 .97561 L closepath p F P
0 g
s
.66 .705 .88 r
.47346 .97043 m .47649 .97462 L .47344 .97561 L p F P
0 g
s
.66 .705 .88 r
.46241 .97424 m .47346 .97043 L p .47344 .97561 L F P
0 g
s
.772 .438 .421 r
.33326 .74617 m .32905 .74526 L .33068 .74121 L p F P
0 g
s
.759 .422 .414 r
.32348 .73986 m .33068 .74121 L .32905 .74526 L p F P
0 g
s
.672 .428 .544 r
.4211 .75682 m .42165 .75679 L .42156 .76216 L p F P
0 g
s
.672 .428 .544 r
.42156 .76216 m .42094 .76218 L .4211 .75682 L p F P
0 g
s
.547 .775 .983 r
.23405 .97677 m .24461 .97513 L .24804 .97749 L p F P
0 g
s
.587 .774 .969 r
.24461 .97513 m .23405 .97677 L .23057 .97474 L p F P
0 g
s
.792 .784 .845 r
.67113 .20134 m .66192 .20871 L .65918 .20493 L p F P
0 g
s
.657 .416 .543 r
.42156 .76216 m .42165 .75679 L .43497 .75583 L p F P
0 g
s
.864 .656 .62 r
.10525 .89036 m .10557 .88923 L p .10896 .89742 L F P
0 g
s
.864 .656 .62 r
.10896 .89742 m .1072 .89662 L .10525 .89036 L p F P
0 g
s
.868 .643 .595 r
.1081 .90134 m .10896 .89742 L .1072 .89662 L closepath p F P
0 g
s
.741 .459 .503 r
.36047 .75518 m .35105 .75404 L .35037 .74896 L p F P
0 g
s
.756 .47 .5 r
.34685 .74841 m .35037 .74896 L .35105 .75404 L p F P
0 g
s
.65 .77 .937 r
.53931 .72138 m .55048 .71793 L .5534 .72091 L p F P
0 g
s
.656 .818 .961 r
.55048 .71793 m .53931 .72138 L .53638 .71933 L p F P
0 g
s
.646 .84 .975 r
.52523 .72306 m .53638 .71933 L .53931 .72138 L p F P
0 g
s
.164 0 0 r
.64095 .95668 m .64253 .95426 L .64911 .95102 L p F P
0 g
s
.859 .537 .441 r
.13414 .93603 m .12877 .93385 L .12792 .92864 L p F P
0 g
s
.861 .537 .437 r
.12257 .92644 m .12792 .92864 L .12877 .93385 L p F P
0 g
s
.717 .466 .545 r
.38107 .76222 m .3784 .76208 L .37855 .75671 L p F P
0 g
s
.723 .47 .544 r
.3704 .75616 m .37855 .75671 L .3784 .76208 L p F P
0 g
s
.834 .744 .764 r
.1144 .80096 m .11888 .80359 L .11331 .81052 L p F P
0 g
s
.831 .747 .771 r
.11717 .79767 m .1144 .80096 L .11888 .80359 L p F P
0 g
s
.555 .866 .996 r
.57523 .97444 m .5776 .97548 L .58874 .97255 L p F P
0 g
s
.537 .872 .992 r
.58932 .97276 m .58874 .97255 L .5776 .97548 L p F P
0 g
s
.729 .226 .031 r
.16575 .95833 m .15992 .95631 L .15558 .952 L p F P
0 g
s
.708 .188 0 r
.15324 .95121 m .15558 .952 L .15992 .95631 L p F P
0 g
s
.852 .724 .722 r
.10377 .84235 m .10447 .84123 L .10097 .8369 L p F P
0 g
s
.641 .724 .909 r
.5534 .72091 m .5646 .71779 L .56751 .72141 L p F P
0 g
s
.648 .753 .926 r
.5646 .71779 m .5534 .72091 L .55048 .71793 L p F P
0 g
s
.836 .465 .351 r
.13434 .93673 m .13491 .93634 L p .14156 .9431 L F P
0 g
s
.85 .5 .389 r
.13434 .93673 m .13414 .93603 L .13491 .93634 L closepath p F P
0 g
s
.669 .68 .851 r
.47346 .97043 m .46241 .97424 L .45936 .96993 L p F P
0 g
s
.496 .393 .667 r
.70007 .86611 m .69973 .86594 L .7 .86579 L closepath p F P
0 g
s
.662 .714 .887 r
.48756 .97102 m .48966 .97381 L .47702 .97528 L p F P
0 g
s
.662 .714 .887 r
.47702 .97528 m .47649 .97462 L .48756 .97102 L p F P
0 g
s
0 0 0 r
.61656 .96622 m .61737 .96584 L .62866 .96197 L p F P
0 g
s
.521 .22 .397 r
.4727 .74527 m .47362 .7408 L .48524 .73811 L p F P
0 g
s
.442 .069 .235 r
.48596 .73621 m .48524 .73811 L .47362 .7408 L p F P
0 g
s
.836 .794 .811 r
.70502 .17016 m .7063 .16883 L .70363 .16502 L p F P
0 g
s
.618 .676 .883 r
.58328 .72513 m .58164 .7227 L .59142 .72058 L closepath p F P
0 g
s
.856 .719 .711 r
.09916 .8398 m .10377 .84235 L .10006 .84875 L p F P
0 g
s
.852 .724 .722 r
.10097 .8369 m .09916 .8398 L .10377 .84235 L p F P
0 g
s
.487 .387 .667 r
.7 .86579 m .70936 .86056 L p .70655 .86972 L F P
0 g
s
.487 .387 .667 r
.70655 .86972 m .70007 .86611 L .7 .86579 L p F P
0 g
s
.495 .406 .684 r
.70875 .85801 m .70936 .86056 L .7 .86579 L p F P
0 g
s
.495 .406 .684 r
.70383 .85579 m .70875 .85801 L p .7 .86579 L F P
0 g
s
.868 .659 .618 r
.10525 .89036 m .10557 .88923 L .10477 .88885 L closepath p F P
0 g
s
.863 .671 .641 r
.1021 .88255 m .10267 .8809 L p .10557 .88923 L F P
0 g
s
.863 .671 .641 r
.10557 .88923 m .10477 .88885 L .1021 .88255 L p F P
0 g
s
.446 .25 .519 r
.68239 .91996 m .68647 .91813 L .68633 .91268 L p F P
0 g
s
.433 .24 .517 r
.68647 .91813 m .68633 .91268 L .69611 .90805 L p F P
0 g
s
.453 .28 .555 r
.6957 .90235 m .69611 .90805 L .68633 .91268 L p F P
0 g
s
.561 .902 .977 r
.52341 .72257 m .52523 .72306 L .53638 .71933 L p F P
0 g
s
.764 .763 .852 r
.1838 .73609 m .19226 .73022 L .19684 .73289 L p F P
0 g
s
.763 .764 .853 r
.19469 .72855 m .19226 .73022 L .19684 .73289 L p F P
0 g
s
.763 .764 .853 r
.19684 .73289 m .19815 .73199 L .19469 .72855 L p F P
0 g
s
.566 .566 .812 r
.65297 .76413 m .65249 .76414 L .65287 .76391 L closepath p F P
0 g
s
.571 .574 .817 r
.65009 .75805 m .65287 .76391 L .65249 .76414 L p F P
0 g
s
.797 .76 .819 r
.15849 .75619 m .15083 .76294 L .14731 .75941 L p F P
0 g
s
.803 .76 .813 r
.14952 .76414 m .15083 .76294 L .14731 .75941 L p F P
0 g
s
.487 .387 .667 r
.70145 .87251 m .70007 .86611 L .70655 .86972 L closepath p F P
0 g
s
.805 .757 .808 r
.1451 .76145 m .14952 .76414 L .14139 .77183 L p F P
0 g
s
.803 .76 .813 r
.14731 .75941 m .1451 .76145 L .14952 .76414 L p F P
0 g
s
.836 .794 .811 r
.70363 .16502 m .70251 .16618 L .70502 .17016 L p F P
0 g
s
.83 .793 .816 r
.69513 .17358 m .69766 .17754 L .70502 .17016 L p F P
0 g
s
.83 .793 .816 r
.70502 .17016 m .70251 .16618 L .69513 .17358 L p F P
0 g
s
.541 .523 .785 r
.68482 .79168 m .67605 .7911 L .67443 .78705 L p F P
0 g
s
.846 .731 .737 r
.10326 .82407 m .10782 .82665 L .1033 .83328 L p F P
0 g
s
.844 .735 .743 r
.10782 .82665 m .10326 .82407 L .10803 .81737 L p F P
0 g
s
.852 .492 .371 r
.13414 .93603 m .13434 .93673 L .13031 .93888 L p F P
0 g
s
.852 .492 .371 r
.13031 .93888 m .12877 .93385 L .13414 .93603 L p F P
0 g
s
.756 .351 .286 r
.32348 .73986 m .31608 .7381 L .31389 .73492 L p F P
0 g
s
.768 .351 .258 r
.31608 .7381 m .31151 .73682 L .31389 .73492 L closepath p F P
0 g
s
.795 .785 .843 r
.67113 .20134 m .67306 .19977 L .67034 .19598 L p F P
0 g
s
.795 .785 .843 r
.67034 .19598 m .6686 .1974 L .67113 .20134 L p F P
0 g
s
.792 .784 .845 r
.65918 .20493 m .6686 .1974 L .67113 .20134 L p F P
0 g
s
.384 .758 .991 r
.22394 .97509 m .23057 .97474 L p .2166 .97356 L F P
0 g
s
.384 .758 .991 r
.2166 .97356 m .21675 .97363 L .22394 .97509 L p F P
0 g
s
.756 .47 .5 r
.35105 .75404 m .34613 .75328 L .34685 .74841 L p F P
0 g
s
.752 .466 .498 r
.34153 .74765 m .34685 .74841 L .34613 .75328 L p F P
0 g
s
.73 .763 .879 r
.20899 .72521 m .21419 .72235 L .21903 .72494 L p F P
0 g
s
.732 .767 .88 r
.21979 .71929 m .21419 .72235 L .21903 .72494 L p F P
0 g
s
.732 .767 .88 r
.21903 .72494 m .22322 .72261 L .21979 .71929 L p F P
0 g
s
.805 .757 .808 r
.14139 .77183 m .13691 .76917 L .1451 .76145 L p F P
0 g
s
.809 .756 .803 r
.14139 .77183 m .13971 .77347 L .13618 .76987 L p F P
0 g
s
.809 .756 .803 r
.13618 .76987 m .13691 .76917 L .14139 .77183 L p F P
0 g
s
.797 .76 .819 r
.14731 .75941 m .15404 .7535 L .15849 .75619 L p F P
0 g
s
.795 .761 .822 r
.15837 .74976 m .15404 .7535 L .15849 .75619 L p F P
0 g
s
.795 .761 .822 r
.15849 .75619 m .16187 .75327 L .15837 .74976 L p F P
0 g
s
.763 .773 .861 r
.64443 .21565 m .63679 .22081 L .63401 .217 L p F P
0 g
s
.748 .765 .866 r
.20899 .72521 m .19815 .73199 L .19469 .72855 L p F P
0 g
s
.866 .795 .778 r
.72288 .1359 m .7238 .13473 L .72639 .13871 L p F P
0 g
s
.866 .795 .778 r
.72639 .13871 m .72551 .13983 L .72288 .1359 L p F P
0 g
s
.723 .47 .544 r
.3784 .76208 m .37021 .76152 L .3704 .75616 L p F P
0 g
s
.736 .482 .545 r
.3628 .75541 m .3704 .75616 L .37021 .76152 L p F P
0 g
s
.815 .756 .797 r
.13393 .77933 m .13971 .77347 L .13618 .76987 L p F P
0 g
s
.805 .787 .836 r
.68083 .19309 m .67306 .19977 L .67034 .19598 L p F P
0 g
s
.613 .773 .957 r
.24804 .97749 m .25869 .97493 L .26208 .97759 L p F P
0 g
s
.638 .768 .941 r
.25869 .97493 m .24804 .97749 L .24461 .97513 L p F P
0 g
s
.56 .559 .81 r
.65297 .76413 m .66448 .76397 L p .66281 .77039 L F P
0 g
s
.558 .561 .813 r
.66177 .75803 m .66448 .76397 L .65297 .76413 L p F P
0 g
s
.558 .561 .813 r
.65297 .76413 m .65287 .76391 L .66177 .75803 L p F P
0 g
s
.787 .762 .83 r
.16834 .74797 m .16187 .75327 L .15837 .74976 L p F P
0 g
s
.563 .572 .82 r
.66159 .75765 m .66177 .75803 L .65287 .76391 L p F P
0 g
s
.563 .572 .82 r
.65287 .76391 m .65009 .75805 L .66159 .75765 L p F P
0 g
s
.59 .621 .851 r
.62715 .73619 m .61578 .73767 L .6129 .73253 L p F P
0 g
s
.664 .684 .859 r
.48756 .97102 m .47649 .97462 L .47346 .97043 L p F P
0 g
s
.861 .794 .783 r
.72106 .14533 m .72551 .13983 L .72288 .1359 L p F P
0 g
s
.629 .694 .891 r
.56751 .72141 m .57875 .71863 L .58164 .7227 L p F P
0 g
s
.635 .711 .902 r
.57875 .71863 m .56751 .72141 L .5646 .71779 L p F P
0 g
s
.578 .597 .836 r
.63345 .7482 m .63291 .74714 L .63544 .74692 L closepath p F P
0 g
s
.697 .689 .838 r
.37485 .97078 m .3858 .96558 L .38893 .97014 L p F P
0 g
s
.702 .678 .824 r
.3858 .96558 m .37485 .97078 L .37169 .96634 L p F P
0 g
s
.7 .695 .842 r
.36075 .97159 m .37169 .96634 L .37485 .97078 L p F P
0 g
s
.705 .684 .828 r
.37169 .96634 m .36075 .97159 L .35758 .9673 L p F P
0 g
s
.702 .701 .847 r
.34666 .97254 m .35758 .9673 L .36075 .97159 L p F P
0 g
s
.826 .792 .82 r
.69258 .17607 m .69513 .17358 L .69766 .17754 L p F P
0 g
s
.826 .792 .82 r
.69766 .17754 m .69526 .17988 L .69258 .17607 L p F P
0 g
s
.87 .659 .615 r
.1072 .89662 m .10525 .89036 L .10395 .89508 L closepath p F P
0 g
s
.871 .661 .615 r
.10395 .89508 m .10525 .89036 L .10477 .88885 L p F P
0 g
s
.871 .661 .615 r
.10477 .88885 m .10066 .88684 L p .10395 .89508 L F P
0 g
s
.869 .673 .635 r
.10477 .88885 m .1021 .88255 L .10066 .88684 L closepath p F P
0 g
s
.86 .705 .688 r
.09662 .85508 m .10134 .85757 L .09821 .86382 L p F P
0 g
s
.857 .711 .699 r
.10134 .85757 m .09662 .85508 L .10006 .84875 L p F P
0 g
s
.693 .684 .836 r
.38893 .97014 m .3999 .96505 L .40302 .96969 L p F P
0 g
s
.698 .672 .821 r
.3999 .96505 m .38893 .97014 L .3858 .96558 L p F P
0 g
s
.808 .788 .834 r
.68083 .19309 m .68418 .19016 L .68148 .18636 L p F P
0 g
s
.808 .788 .834 r
.68148 .18636 m .6783 .18914 L .68083 .19309 L p F P
0 g
s
.805 .787 .836 r
.67034 .19598 m .6783 .18914 L .68083 .19309 L p F P
0 g
s
.819 .79 .825 r
.6896 .18519 m .69526 .17988 L .69258 .17607 L p F P
0 g
s
.707 .692 .834 r
.35758 .9673 m .34666 .97254 L .34346 .96842 L p F P
0 g
s
.872 .645 .593 r
.1072 .89662 m .10395 .89508 L p .10771 .90317 L F P
0 g
s
.872 .645 .593 r
.10771 .90317 m .1081 .90134 L .1072 .89662 L p F P
0 g
s
.558 .261 .419 r
.4727 .74527 m .46237 .74717 L .46078 .74665 L p F P
0 g
s
.557 .267 .431 r
.46237 .74717 m .46063 .7475 L .46078 .74665 L closepath p F P
0 g
s
.663 .773 .931 r
.23738 .72088 m .24806 .71713 L .25147 .72011 L p F P
0 g
s
.651 .774 .939 r
.24806 .71713 m .23738 .72088 L .23396 .71767 L p F P
0 g
s
.704 .768 .902 r
.22322 .72261 m .23396 .71767 L .23738 .72088 L p F P
0 g
s
.605 .648 .866 r
.61002 .72754 m .5987 .72948 L .59581 .7248 L p F P
0 g
s
.571 .776 .976 r
.25147 .72011 m .26207 .71805 L .26549 .7206 L p F P
0 g
s
.531 .77 .985 r
.26207 .71805 m .25147 .72011 L .24806 .71713 L p F P
0 g
s
.817 .755 .794 r
.13393 .77933 m .1285 .78496 L .12495 .78136 L p F P
0 g
s
.817 .755 .794 r
.12495 .78136 m .1295 .77665 L .13393 .77933 L p F P
0 g
s
.815 .756 .797 r
.13618 .76987 m .1295 .77665 L .13393 .77933 L p F P
0 g
s
.819 .79 .825 r
.69258 .17607 m .68707 .18123 L .6896 .18519 L p F P
0 g
s
.816 .789 .828 r
.68148 .18636 m .68707 .18123 L .6896 .18519 L p F P
0 g
s
.816 .789 .828 r
.6896 .18519 m .68418 .19016 L .68148 .18636 L p F P
0 g
s
.837 .466 .349 r
.13593 .941 m .13434 .93673 L .13031 .93888 L p F P
0 g
s
.836 .465 .351 r
.14156 .9431 m .13593 .941 L .13434 .93673 L p F P
0 g
s
.064 .599 .859 r
.20272 .97116 m .21034 .97165 L .21647 .97355 L p F P
0 g
s
.201 .677 .935 r
.21034 .97165 m .20272 .97116 L .19914 .96975 L p F P
0 g
s
.636 .398 .541 r
.43497 .75583 m .43947 .75531 L .43932 .76069 L p F P
0 g
s
.636 .398 .541 r
.43932 .76069 m .4349 .76119 L .43497 .75583 L p F P
0 g
s
.657 .416 .543 r
.43497 .75583 m .4349 .76119 L .42156 .76216 L p F P
0 g
s
.867 .674 .639 r
.1021 .88255 m .10267 .8809 L .10103 .8801 L closepath p F P
0 g
s
.862 .684 .66 r
.09883 .87588 m .10022 .87243 L p .10267 .8809 L F P
0 g
s
.862 .684 .66 r
.10267 .8809 m .10103 .8801 L .09883 .87588 L p F P
0 g
s
.708 .702 .842 r
.34346 .96842 m .33255 .97359 L .32933 .96965 L p F P
0 g
s
.694 .669 .821 r
.41369 .9649 m .40302 .96969 L .3999 .96505 L p F P
0 g
s
.689 .68 .836 r
.41409 .9649 m .4171 .96945 L p .40302 .96969 L F P
0 g
s
.689 .68 .836 r
.40302 .96969 m .41369 .9649 L .41409 .9649 L p F P
0 g
s
.838 .742 .758 r
.11331 .81052 m .10921 .81579 L .10567 .81194 L p F P
0 g
s
.838 .742 .758 r
.10567 .81194 m .1088 .8079 L .11331 .81052 L p F P
0 g
s
.834 .744 .764 r
.11331 .81052 m .1088 .8079 L .1144 .80096 L p F P
0 g
s
.427 .207 .476 r
.67641 .92773 m .67968 .92629 L .68239 .91996 L p F P
0 g
s
.421 .201 .472 r
.68647 .91813 m .68239 .91996 L .67968 .92629 L p F P
0 g
s
.787 .762 .83 r
.15837 .74976 m .16385 .74528 L .16834 .74797 L p F P
0 g
s
.786 .763 .832 r
.16937 .74085 m .16385 .74528 L .16834 .74797 L p F P
0 g
s
.786 .763 .832 r
.16834 .74797 m .17286 .74433 L .16937 .74085 L p F P
0 g
s
.541 .523 .785 r
.67443 .78705 m .67879 .78421 L p .68482 .79168 L F P
0 g
s
.544 .533 .793 r
.67443 .78705 m .67315 .78396 L .67879 .78421 L closepath p F P
0 g
s
.708 .188 0 r
.15093 .9514 m .15324 .95121 L p .15992 .95631 L F P
0 g
s
.784 .322 .147 r
.15093 .9514 m .14982 .94995 L .15324 .95121 L closepath p F P
0 g
s
.65 .764 .932 r
.26208 .97759 m .2728 .97429 L .27615 .97724 L p F P
0 g
s
.668 .757 .917 r
.2728 .97429 m .26208 .97759 L .25869 .97493 L p F P
0 g
s
.471 .332 .61 r
.69507 .89644 m .69505 .8963 L .69514 .8964 L closepath p F P
0 g
s
.397 .15 .419 r
.6761 .93123 m .67968 .92629 L .67641 .92773 L closepath p F P
0 g
s
.456 .302 .583 r
.69514 .8964 m .69507 .89644 L .6957 .90235 L p F P
0 g
s
.577 .601 .84 r
.63544 .74692 m .63291 .74714 L .63003 .74164 L p F P
0 g
s
.456 .302 .583 r
.6957 .90235 m .69769 .90136 L .69514 .8964 L p F P
0 g
s
.453 .301 .583 r
.70466 .89155 m .69514 .8964 L .69769 .90136 L p F P
0 g
s
.471 .332 .61 r
.7038 .88541 m .70466 .89155 L .69514 .8964 L p F P
0 g
s
.341 0 .089 r
.49825 .73145 m .49705 .73356 L .48596 .73621 L p F P
0 g
s
.426 .068 .253 r
.48524 .73811 m .48596 .73621 L .49705 .73356 L p F P
0 g
s
.703 .731 .872 r
.31845 .97467 m .31874 .97453 L .31827 .97447 L closepath p F P
0 g
s
.695 .728 .875 r
.31827 .97447 m .31845 .97467 L p .30434 .97567 L F P
0 g
s
.704 .73 .871 r
.32611 .96551 m .32933 .96965 L .31874 .97453 L p F P
0 g
s
.704 .73 .871 r
.3152 .97094 m .32611 .96551 L p .31874 .97453 L F P
0 g
s
.704 .73 .871 r
.31874 .97453 m .31827 .97447 L .3152 .97094 L p F P
0 g
s
.368 0 0 r
.18534 .96634 m .18443 .96595 L .18673 .9667 L closepath p F P
0 g
s
.709 .735 .872 r
.30916 .97357 m .30434 .97567 L .30106 .97222 L p F P
0 g
s
.686 .741 .893 r
.29024 .97656 m .30106 .97222 L .30434 .97567 L p F P
0 g
s
.695 .728 .875 r
.30434 .97567 m .30916 .97357 L .31827 .97447 L p F P
0 g
s
.673 .752 .911 r
.27615 .97724 m .28693 .97335 L .29024 .97656 L p F P
0 g
s
.686 .745 .896 r
.28693 .97335 m .27615 .97724 L .2728 .97429 L p F P
0 g
s
.468 0 0 r
.29667 .72867 m .29867 .73011 L .30528 .73212 L p F P
0 g
s
.73 .29 .206 r
.31151 .73682 m .309 .73624 L .30528 .73212 L p F P
0 g
s
.755 .33 .24 r
.29867 .73011 m .30528 .73212 L .309 .73624 L p F P
0 g
s
.685 .678 .837 r
.4171 .96945 m .4281 .96471 L .43118 .96942 L p F P
0 g
s
.685 .679 .838 r
.42796 .96448 m .4281 .96471 L .4171 .96945 L p F P
0 g
s
.685 .679 .838 r
.4171 .96945 m .41409 .9649 L .42796 .96448 L p F P
0 g
s
.164 0 0 r
.64911 .95102 m .6534 .94942 L p .64095 .95668 L F P
0 g
s
.299 0 .166 r
.64911 .95102 m .6534 .94942 L .65377 .94848 L closepath p F P
0 g
s
.822 .755 .789 r
.12689 .78669 m .1285 .78496 L .12495 .78136 L p F P
0 g
s
.695 .728 .876 r
.31827 .97447 m .3152 .97094 L .30916 .97357 L closepath p F P
0 g
s
.776 .763 .841 r
.17939 .73937 m .17286 .74433 L .16937 .74085 L p F P
0 g
s
.698 .731 .876 r
.30106 .97222 m .29024 .97656 L .28693 .97335 L p F P
0 g
s
.654 .714 .892 r
.50196 .97202 m .50468 .97543 L p .49058 .97503 L F P
0 g
s
.654 .714 .892 r
.49058 .97503 m .49944 .97234 L .50196 .97202 L p F P
0 g
s
.654 .7 .88 r
.49058 .97503 m .49944 .97234 L .48966 .97381 L closepath p F P
0 g
s
.759 .422 .414 r
.32905 .74526 m .32534 .74457 L .32348 .73986 L p F P
0 g
s
.775 .442 .423 r
.31608 .7381 m .32348 .73986 L .32534 .74457 L p F P
0 g
s
.512 .45 .724 r
.70251 .83489 m .69785 .83368 L .7015 .83152 L closepath p F P
0 g
s
.52 .464 .734 r
.69948 .82511 m .7015 .83152 L .69785 .83368 L p F P
0 g
s
.52 .464 .734 r
.69751 .82468 m .69948 .82511 L p .69785 .83368 L F P
0 g
s
.752 .466 .498 r
.34613 .75328 m .34223 .75272 L .34153 .74765 L p F P
0 g
s
.764 .479 .501 r
.33326 .74617 m .34153 .74765 L .34223 .75272 L p F P
0 g
s
.699 .77 .907 r
.23396 .71767 m .22322 .72261 L .21979 .71929 L p F P
0 g
s
.816 .396 .247 r
.14982 .94995 m .14424 .94784 L .14156 .9431 L p F P
0 g
s
.814 .389 .233 r
.13593 .941 m .14156 .9431 L .14424 .94784 L p F P
0 g
s
.825 .752 .783 r
.12249 .78401 m .12689 .78669 L .12045 .79388 L p F P
0 g
s
.822 .755 .789 r
.12495 .78136 m .12249 .78401 L .12689 .78669 L p F P
0 g
s
.478 .354 .632 r
.70347 .88349 m .6999 .88052 L .70272 .87906 L closepath p F P
0 g
s
.489 .376 .651 r
.6999 .88052 m .70272 .87906 L .70145 .87251 L p F P
0 g
s
.736 .482 .545 r
.37021 .76152 m .36264 .76078 L .3628 .75541 L p F P
0 g
s
.738 .483 .544 r
.36047 .75518 m .3628 .75541 L .36264 .76078 L p F P
0 g
s
.581 .325 .494 r
.46063 .7475 m .46237 .74717 L .4662 .75138 L p F P
0 g
s
.581 .325 .494 r
.4662 .75138 m .46025 .75252 L .46063 .7475 L p F P
0 g
s
.601 .339 .493 r
.46063 .7475 m .46025 .75252 L .44784 .7544 L p F P
0 g
s
.639 .401 .542 r
.43947 .75531 m .44784 .7544 L .44778 .75977 L p F P
0 g
s
.639 .401 .542 r
.44778 .75977 m .43932 .76069 L .43947 .75531 L p F P
0 g
s
.468 .727 .982 r
.26549 .7206 m .27252 .72072 L .27907 .72278 L p F P
0 g
s
.4 .705 .984 r
.27252 .72072 m .26549 .7206 L .26207 .71805 L p F P
0 g
s
.544 .534 .794 r
.67879 .78421 m .67315 .78396 L .67057 .77777 L p F P
0 g
s
.861 .794 .783 r
.72288 .1359 m .71847 .14135 L .72106 .14533 L p F P
0 g
s
.857 .794 .788 r
.71285 .1481 m .71545 .15206 L .72106 .14533 L p F P
0 g
s
.857 .794 .788 r
.72106 .14533 m .71847 .14135 L .71285 .1481 L p F P
0 g
s
.87 .675 .635 r
.10066 .88684 m .1021 .88255 L .10103 .8801 L p F P
0 g
s
.87 .644 .593 r
.10851 .90354 m .1081 .90134 L .10771 .90317 L closepath p F P
0 g
s
.763 .773 .861 r
.63401 .217 m .64172 .21178 L .64443 .21565 L p F P
0 g
s
.765 .773 .86 r
.64443 .21565 m .64799 .21321 L .64523 .20939 L p F P
0 g
s
.765 .773 .86 r
.64523 .20939 m .64172 .21178 L .64443 .21565 L p F P
0 g
s
.68 .677 .84 r
.43118 .96942 m .4422 .9649 L .44527 .96959 L p F P
0 g
s
.683 .665 .825 r
.4422 .9649 m .43118 .96942 L .4281 .96471 L p F P
0 g
s
.478 .368 .651 r
.70272 .87906 m .70145 .87251 L .70655 .86972 L p F P
0 g
s
.627 .068 0 r
.29867 .73011 m .29409 .72851 L .29667 .72867 L closepath p F P
0 g
s
.738 .483 .544 r
.36264 .76078 m .36026 .76054 L .36047 .75518 L p F P
0 g
s
.746 .49 .544 r
.35105 .75404 m .36047 .75518 L .36026 .76054 L p F P
0 g
s
.866 .687 .658 r
.09883 .87588 m .10022 .87243 L .09576 .87018 L closepath p F P
0 g
s
.86 .696 .677 r
.0955 .86974 m .09821 .86382 L p .10022 .87243 L F P
0 g
s
.86 .696 .677 r
.10022 .87243 m .09576 .87018 L .0955 .86974 L p F P
0 g
s
.054 0 0 r
.51115 .72655 m .50918 .72799 L .49825 .73145 L p F P
0 g
s
.851 .727 .727 r
.1033 .83328 m .10097 .8369 L .09745 .83267 L p F P
0 g
s
.851 .727 .727 r
.09745 .83267 m .09871 .83071 L .1033 .83328 L p F P
0 g
s
.846 .731 .737 r
.1033 .83328 m .09871 .83071 L .10326 .82407 L p F P
0 g
s
0 0 0 r
.62866 .96197 m .62723 .96275 L .61656 .96622 L p F P
0 g
s
.262 .764 .725 r
.61466 .9667 m .61656 .96622 L .62723 .96275 L p F P
0 g
s
.265 .768 .746 r
.61656 .96622 m .61466 .9667 L .60337 .97001 L p F P
0 g
s
.618 .689 .894 r
.59142 .72058 m .58164 .7227 L .57875 .71863 L p F P
0 g
s
.841 .742 .754 r
.10803 .81737 m .10921 .81579 L .10567 .81194 L p F P
0 g
s
.776 .763 .841 r
.16937 .74085 m .17488 .73668 L .17939 .73937 L p F P
0 g
s
.775 .764 .843 r
.18031 .73265 m .17488 .73668 L .17939 .73937 L p F P
0 g
s
.775 .764 .843 r
.17939 .73937 m .1838 .73609 L .18031 .73265 L p F P
0 g
s
.648 .726 .906 r
.50468 .97543 m .5158 .97225 L .51878 .97576 L p F P
0 g
s
.651 .712 .892 r
.51422 .97016 m .5158 .97225 L .50468 .97543 L p F P
0 g
s
.651 .712 .892 r
.50468 .97543 m .50196 .97202 L .51422 .97016 L p F P
0 g
s
.584 .325 .49 r
.46237 .74717 m .4727 .74527 L .4723 .75026 L p F P
0 g
s
.584 .325 .49 r
.4723 .75026 m .4662 .75138 L .46237 .74717 L p F P
0 g
s
.608 .041 0 r
.16575 .95833 m .16804 .96006 L .16434 .95933 L p F P
0 g
s
.608 .041 0 r
.16434 .95933 m .15992 .95631 L .16575 .95833 L p F P
0 g
s
.412 .858 .904 r
.61466 .9667 m .60337 .97001 L .60059 .96973 L p F P
0 g
s
.424 .861 .922 r
.58932 .97276 m .60059 .96973 L .60337 .97001 L p F P
0 g
s
.87 .675 .635 r
.10103 .8801 m .09781 .87848 L p .10066 .88684 L F P
0 g
s
.867 .685 .654 r
.10103 .8801 m .09883 .87588 L .09781 .87848 L closepath p F P
0 g
s
.867 .623 .567 r
.11206 .9111 m .10866 .9096 L .10851 .90354 L p F P
0 g
s
.873 .628 .565 r
.10771 .90317 m .10851 .90354 L .10866 .9096 L p F P
0 g
s
.305 0 .085 r
.49705 .73356 m .49825 .73145 L .50918 .72799 L p F P
0 g
s
.859 .715 .701 r
.09543 .84622 m .10006 .84875 L .09662 .85508 L p F P
0 g
s
.856 .719 .711 r
.10006 .84875 m .09543 .84622 L .09916 .8398 L p F P
0 g
s
.693 .465 .573 r
.40593 .7627 m .40777 .76269 L .40798 .76836 L p F P
0 g
s
.693 .465 .573 r
.40798 .76836 m .4047 .76839 L .40593 .7627 L p F P
0 g
s
.698 .47 .574 r
.39339 .76266 m .40593 .7627 L .4047 .76839 L p F P
0 g
s
.679 .454 .574 r
.40777 .76269 m .42094 .76218 L .41955 .76793 L p F P
0 g
s
.679 .454 .574 r
.41955 .76793 m .40798 .76836 L .40777 .76269 L p F P
0 g
s
.698 .47 .574 r
.4047 .76839 m .3936 .76835 L .39339 .76266 L p F P
0 g
s
.708 .478 .574 r
.39287 .76265 m .39339 .76266 L .3936 .76835 L p F P
0 g
s
.714 .481 .571 r
.38107 .76222 m .39287 .76265 L .39173 .7683 L p F P
0 g
s
.708 .478 .574 r
.3936 .76835 m .39173 .7683 L .39287 .76265 L p F P
0 g
s
.675 .677 .844 r
.44527 .96959 m .45631 .9653 L .45936 .96993 L p F P
0 g
s
.678 .665 .83 r
.45631 .9653 m .44527 .96959 L .4422 .9649 L p F P
0 g
s
.778 .777 .852 r
.65756 .20614 m .64799 .21321 L .64523 .20939 L p F P
0 g
s
.325 0 .233 r
.66501 .94136 m .66499 .94142 L .65377 .94848 L p F P
0 g
s
.261 0 .15 r
.6534 .94942 m .65377 .94848 L .66499 .94142 L p F P
0 g
s
.846 .738 .745 r
.10356 .81474 m .10803 .81737 L .10326 .82407 L p F P
0 g
s
.841 .742 .754 r
.10567 .81194 m .10356 .81474 L .10803 .81737 L p F P
0 g
s
.654 .699 .879 r
.49944 .97234 m .48966 .97381 L .48756 .97102 L p F P
0 g
s
.829 .75 .777 r
.12045 .79388 m .11717 .79767 L .11361 .79398 L p F P
0 g
s
.829 .75 .777 r
.11361 .79398 m .11601 .79122 L .12045 .79388 L p F P
0 g
s
.825 .752 .783 r
.12045 .79388 m .11601 .79122 L .12249 .78401 L p F P
0 g
s
.273 0 0 r
.18443 .96595 m .18534 .96634 L .18171 .96516 L p F P
0 g
s
.273 0 0 r
.18171 .96516 m .17845 .96399 L .18443 .96595 L p F P
0 g
s
.554 .55 .804 r
.66736 .7704 m .66281 .77039 L .66635 .7681 L closepath p F P
0 g
s
.56 .559 .81 r
.66448 .76397 m .66635 .7681 L .66281 .77039 L p F P
0 g
s
.573 .59 .832 r
.64434 .74627 m .63544 .74692 L .64238 .74236 L closepath p F P
0 g
s
.577 .601 .84 r
.64147 .74059 m .64238 .74236 L .63544 .74692 L p F P
0 g
s
.577 .601 .84 r
.63003 .74164 m .64147 .74059 L p .63544 .74692 L F P
0 g
s
.87 .603 .532 r
.10866 .9096 m .11206 .9111 L .11176 .9166 L p F P
0 g
s
.867 .6 .533 r
.11701 .91885 m .11176 .9166 L .11206 .9111 L p F P
0 g
s
.764 .766 .854 r
.19226 .73022 m .1838 .73609 L .18031 .73265 L p F P
0 g
s
.562 .572 .821 r
.65872 .75162 m .66159 .75765 L .65009 .75805 L p F P
0 g
s
.562 .572 .821 r
.65019 .75189 m .65872 .75162 L p .65009 .75805 L F P
0 g
s
.562 .572 .821 r
.65009 .75805 m .6479 .75344 L .65019 .75189 L p F P
0 g
s
.727 .765 .882 r
.21419 .72235 m .20899 .72521 L .20554 .72181 L p F P
0 g
s
.748 .765 .866 r
.19469 .72855 m .20554 .72181 L .20899 .72521 L p F P
0 g
s
.26 .693 .963 r
.2166 .97356 m .21647 .97355 L .21675 .97363 L closepath p F P
0 g
s
.865 .572 .49 r
.12257 .92644 m .11728 .92421 L .11701 .91885 L p F P
0 g
s
.868 .574 .488 r
.11176 .9166 m .11701 .91885 L .11728 .92421 L p F P
0 g
s
.873 .628 .565 r
.10866 .9096 m .10693 .9088 L .10771 .90317 L p F P
0 g
s
.877 .632 .564 r
.10274 .90082 m .10771 .90317 L .10693 .9088 L p F P
0 g
s
.872 .645 .593 r
.10395 .89508 m .10274 .90082 L .10771 .90317 L p F P
0 g
s
.709 .735 .872 r
.30106 .97222 m .3011 .9722 L .30916 .97357 L p F P
0 g
s
.693 .718 .868 r
.31195 .96702 m .3011 .9722 L .30916 .97357 L p F P
0 g
s
.693 .718 .868 r
.30916 .97357 m .3152 .97094 L .31195 .96702 L p F P
0 g
s
.641 .744 .923 r
.51878 .97576 m .52993 .97274 L .53289 .97594 L p F P
0 g
s
.647 .719 .901 r
.52993 .97274 m .51878 .97576 L .5158 .97225 L p F P
0 g
s
.346 .726 .985 r
.21647 .97355 m .2166 .97356 L .21308 .97168 L p F P
0 g
s
.346 .726 .985 r
.21308 .97168 m .21034 .97165 L .21647 .97355 L p F P
0 g
s
.85 .792 .795 r
.71196 .1491 m .71285 .1481 L .71545 .15206 L p F P
0 g
s
.85 .792 .795 r
.71545 .15206 m .71462 .15302 L .71196 .1491 L p F P
0 g
s
.384 .758 .991 r
.23057 .97474 m .2271 .97252 L .2166 .97356 L p F P
0 g
s
.544 .771 .982 r
.2271 .97252 m .2166 .97356 L .21308 .97168 L p F P
0 g
s
.617 .383 .54 r
.44778 .75977 m .44784 .7544 L .46025 .75252 L p F P
0 g
s
.714 .481 .571 r
.39173 .7683 m .38005 .76784 L .38107 .76222 L p F P
0 g
s
.72 .487 .572 r
.3784 .76208 m .38107 .76222 L .38005 .76784 L p F P
0 g
s
.833 .75 .772 r
.1144 .80096 m .11717 .79767 L .11361 .79398 L p F P
0 g
s
.844 .792 .8 r
.70916 .15906 m .71462 .15302 L .71196 .1491 L p F P
0 g
s
.677 .453 .573 r
.42094 .76218 m .42156 .76216 L .42178 .76783 L p F P
0 g
s
.677 .453 .573 r
.42178 .76783 m .41955 .76793 L .42094 .76218 L p F P
0 g
s
.771 .294 .103 r
.14982 .94995 m .15093 .9514 L .14713 .95136 L p F P
0 g
s
.771 .294 .103 r
.14713 .95136 m .14424 .94784 L .14982 .94995 L p F P
0 g
s
.663 .442 .573 r
.42178 .76783 m .42156 .76216 L .4349 .76119 L p F P
0 g
s
.854 .727 .723 r
.09916 .8398 m .10097 .8369 L .09745 .83267 L p F P
0 g
s
.669 .68 .851 r
.45936 .96993 m .47042 .96589 L .47346 .97043 L p F P
0 g
s
.672 .668 .837 r
.47042 .96589 m .45936 .96993 L .45631 .9653 L p F P
0 g
s
.861 .537 .437 r
.12877 .93385 m .12345 .93164 L .12257 .92644 L p F P
0 g
s
.863 .537 .433 r
.11728 .92421 m .12257 .92644 L .12345 .93164 L p F P
0 g
s
.544 .534 .794 r
.67057 .77777 m .67163 .77707 L p .67879 .78421 L F P
0 g
s
.548 .544 .802 r
.67057 .77777 m .67025 .77703 L .67163 .77707 L closepath p F P
0 g
s
.865 .699 .674 r
.09821 .86382 m .0955 .86974 L .09209 .86437 L p F P
0 g
s
.865 .699 .674 r
.09209 .86437 m .09347 .86134 L .09821 .86382 L p F P
0 g
s
.86 .705 .688 r
.09821 .86382 m .09347 .86134 L .09662 .85508 L p F P
0 g
s
.493 0 0 r
.27942 .7228 m .27976 .72297 L p .2923 .72801 L F P
0 g
s
.233 .679 .954 r
.27942 .7228 m .27907 .72278 L .27976 .72297 L closepath p F P
0 g
s
.524 .476 .745 r
.69649 .81605 m .69905 .82376 L .69751 .82468 L p F P
0 g
s
.524 .476 .745 r
.69605 .81597 m .69649 .81605 L p .69751 .82468 L F P
0 g
s
.517 .463 .736 r
.69948 .82511 m .69751 .82468 L .69905 .82376 L closepath p F P
0 g
s
.72 .487 .572 r
.38005 .76784 m .37859 .76776 L .3784 .76208 L p F P
0 g
s
.726 .492 .571 r
.37021 .76152 m .3784 .76208 L .37859 .76776 L p F P
0 g
s
.871 .661 .615 r
.10066 .88684 m .09905 .89269 L .10395 .89508 L p F P
0 g
s
.876 .65 .592 r
.09905 .89269 m .10395 .89508 L .10274 .90082 L p F P
0 g
s
.2 0 0 r
.19914 .96975 m .19557 .96812 L .18534 .96634 L p F P
0 g
s
.195 .651 .943 r
.18534 .96634 m .19557 .96812 L .19396 .9673 L p F P
0 g
s
.195 .651 .943 r
.18171 .96516 m .18534 .96634 L p .19396 .9673 L F P
0 g
s
.548 .545 .804 r
.67163 .77707 m .67025 .77703 L .66736 .7704 L p F P
0 g
s
.368 .117 .396 r
.67968 .92629 m .68634 .92332 L p .67595 .93262 L F P
0 g
s
.368 .117 .396 r
.67595 .93262 m .6761 .93123 L .67968 .92629 L p F P
0 g
s
.421 .201 .472 r
.67968 .92629 m .68634 .92332 L .68647 .91813 L p F P
0 g
s
.59 .621 .851 r
.6129 .73253 m .62428 .73102 L .62715 .73619 L p F P
0 g
s
.592 .628 .856 r
.6214 .72591 m .62428 .73102 L .6129 .73253 L p F P
0 g
s
.592 .628 .856 r
.61502 .7268 m .6214 .72591 L p .6129 .73253 L F P
0 g
s
.592 .628 .856 r
.6129 .73253 m .61108 .72934 L .61502 .7268 L p F P
0 g
s
.545 .876 .991 r
.58874 .97255 m .58932 .97276 L .60059 .96973 L p F P
0 g
s
.632 .767 .944 r
.53289 .97594 m .54407 .97303 L .54701 .97586 L p F P
0 g
s
.64 .738 .919 r
.54407 .97303 m .53289 .97594 L .52993 .97274 L p F P
0 g
s
.054 .574 .873 r
.27907 .72278 m .27942 .7228 L .27597 .72133 L p F P
0 g
s
.054 .574 .873 r
.27597 .72133 m .27252 .72072 L .27907 .72278 L p F P
0 g
s
.493 .405 .685 r
.70875 .85801 m .70383 .85579 L .70768 .8536 L closepath p F P
0 g
s
.502 .421 .697 r
.70582 .84645 m .70768 .8536 L .70383 .85579 L p F P
0 g
s
.746 .49 .544 r
.36026 .76054 m .35084 .7594 L .35105 .75404 L p F P
0 g
s
.76 .502 .544 r
.34613 .75328 m .35105 .75404 L .35084 .7594 L p F P
0 g
s
.869 .687 .654 r
.09781 .87848 m .09883 .87588 L .09576 .87018 L p F P
0 g
s
.836 .748 .766 r
.11 .79829 m .1144 .80096 L .1088 .8079 L p F P
0 g
s
.833 .75 .772 r
.11361 .79398 m .11 .79829 L .1144 .80096 L p F P
0 g
s
.764 .479 .501 r
.34223 .75272 m .33384 .75127 L .33326 .74617 L p F P
0 g
s
.781 .492 .497 r
.32905 .74526 m .33326 .74617 L .33384 .75127 L p F P
0 g
s
.78 .778 .851 r
.65756 .20614 m .65918 .20493 L .65643 .20109 L p F P
0 g
s
.78 .778 .851 r
.65643 .20109 m .65488 .20225 L .65756 .20614 L p F P
0 g
s
.778 .777 .852 r
.64523 .20939 m .65488 .20225 L .65756 .20614 L p F P
0 g
s
.493 0 0 r
.2923 .72801 m .28568 .72599 L .27942 .7228 L p F P
0 g
s
.367 0 0 r
.28568 .72599 m .27942 .7228 L .27597 .72133 L p F P
0 g
s
.578 .603 .841 r
.63859 .73513 m .64147 .74059 L .63003 .74164 L p F P
0 g
s
.578 .603 .841 r
.62786 .73612 m .63859 .73513 L p .63003 .74164 L F P
0 g
s
.578 .603 .841 r
.63003 .74164 m .62731 .73648 L .62786 .73612 L p F P
0 g
s
.561 .902 .977 r
.53638 .71933 m .5336 .71828 L .52341 .72257 L p F P
0 g
s
.855 .491 .362 r
.12877 .93385 m .13031 .93888 L .13031 .93888 L p F P
0 g
s
.855 .491 .362 r
.12345 .93164 m .12877 .93385 L p .13031 .93888 L F P
0 g
s
.469 .347 .632 r
.70272 .87906 m .71215 .87391 L p .70492 .88481 L F P
0 g
s
.469 .347 .632 r
.70492 .88481 m .70347 .88349 L .70272 .87906 L p F P
0 g
s
.478 .368 .651 r
.71208 .87357 m .71215 .87391 L .70272 .87906 L p F P
0 g
s
.478 .368 .651 r
.70655 .86972 m .71208 .87357 L p .70272 .87906 L F P
0 g
s
.844 .792 .8 r
.71196 .1491 m .70654 .1551 L .70916 .15906 L p F P
0 g
s
.84 .791 .804 r
.70096 .16112 m .70654 .1551 L .70916 .15906 L p F P
0 g
s
.84 .791 .804 r
.70916 .15906 m .70363 .16502 L .70096 .16112 L p F P
0 g
s
.702 .678 .824 r
.38534 .96487 m .3858 .96558 L p .37169 .96634 L F P
0 g
s
.702 .678 .824 r
.37169 .96634 m .37512 .96459 L .38534 .96487 L p F P
0 g
s
.704 .685 .829 r
.37169 .96634 m .37512 .96459 L .37038 .96438 L closepath p F P
0 g
s
.705 .684 .828 r
.37038 .96438 m .37169 .96634 L p .35758 .9673 L F P
0 g
s
.698 .672 .821 r
.39988 .96502 m .3999 .96505 L p .3858 .96558 L F P
0 g
s
.698 .672 .821 r
.3858 .96558 m .38716 .96491 L .39988 .96502 L p F P
0 g
s
.7 .678 .825 r
.3858 .96558 m .38716 .96491 L .38534 .96487 L closepath p F P
0 g
s
.791 .781 .843 r
.6686 .1974 m .65918 .20493 L .65643 .20109 L p F P
0 g
s
.875 .666 .615 r
.09583 .88442 m .10066 .88684 L .09905 .89269 L p F P
0 g
s
.87 .675 .635 r
.09781 .87848 m .09583 .88442 L .10066 .88684 L p F P
0 g
s
.619 .797 .967 r
.54701 .97586 m .55821 .97302 L .56112 .97541 L p F P
0 g
s
.632 .763 .942 r
.55821 .97302 m .54701 .97586 L .54407 .97303 L p F P
0 g
s
.406 .19 .469 r
.68634 .92332 m .68647 .91813 L .69627 .91352 L p F P
0 g
s
.433 .24 .517 r
.69611 .90805 m .69627 .91352 L .68647 .91813 L p F P
0 g
s
.169 0 0 r
.66363 .9454 m .6534 .94942 L .65137 .95289 L p F P
0 g
s
.261 0 .15 r
.66499 .94142 m .66363 .9454 L .6534 .94942 L p F P
0 g
s
.164 0 0 r
.6534 .94942 m .65137 .95289 L .64095 .95668 L p F P
0 g
s
.496 .201 .396 r
.48437 .74261 m .48524 .73811 L .49652 .73504 L p F P
0 g
s
.426 .068 .253 r
.49705 .73356 m .49652 .73504 L .48524 .73811 L p F P
0 g
s
.521 .22 .397 r
.48524 .73811 m .48437 .74261 L .4727 .74527 L p F P
0 g
s
.664 .684 .859 r
.47346 .97043 m .48454 .96662 L .48756 .97102 L p F P
0 g
s
.667 .67 .844 r
.48454 .96662 m .47346 .97043 L .47042 .96589 L p F P
0 g
s
.708 .694 .835 r
.35758 .9673 m .3638 .96408 L .35489 .96347 L closepath p F P
0 g
s
.707 .692 .834 r
.35489 .96347 m .35758 .9673 L p .34346 .96842 L F P
0 g
s
.705 .684 .828 r
.35758 .9673 m .3638 .96408 L .37038 .96438 L p F P
0 g
s
.775 .442 .423 r
.32534 .74457 m .31769 .74288 L .31608 .7381 L p F P
0 g
s
.798 .471 .434 r
.31151 .73682 m .31608 .7381 L .31769 .74288 L p F P
0 g
s
.555 .866 .996 r
.58874 .97255 m .58648 .97157 L .57523 .97444 L p F P
0 g
s
.597 .834 .989 r
.58648 .97157 m .57523 .97444 L .57235 .97259 L p F P
0 g
s
.596 .832 .989 r
.56112 .97541 m .57235 .97259 L .57523 .97444 L p F P
0 g
s
.694 .669 .821 r
.3999 .96505 m .39997 .96502 L .41369 .9649 L p F P
0 g
s
.695 .672 .823 r
.3999 .96505 m .39997 .96502 L .39988 .96502 L closepath p F P
0 g
s
.858 .723 .712 r
.09462 .83723 m .09916 .8398 L .09543 .84622 L p F P
0 g
s
.854 .727 .723 r
.09745 .83267 m .09462 .83723 L .09916 .8398 L p F P
0 g
s
.695 .671 .822 r
.39997 .96502 m .39988 .96502 L .39679 .96007 L p F P
0 g
s
.698 .672 .821 r
.39988 .96502 m .39679 .96007 L .38716 .96491 L closepath p F P
0 g
s
.605 .648 .866 r
.59581 .7248 m .60714 .72279 L .61002 .72754 L p F P
0 g
s
.608 .655 .871 r
.60714 .72279 m .59581 .7248 L .59292 .72027 L p F P
0 g
s
.686 .665 .824 r
.4109 .95971 m .39997 .96502 L .41369 .9649 L p F P
0 g
s
.695 .671 .822 r
.40781 .95441 m .4109 .95971 L .39997 .96502 L p F P
0 g
s
.695 .671 .822 r
.39679 .96007 m .40781 .95441 L p .39997 .96502 L F P
0 g
s
.764 .766 .854 r
.18031 .73265 m .18776 .72751 L .19226 .73022 L p F P
0 g
s
.763 .767 .856 r
.19122 .72516 m .18776 .72751 L .19226 .73022 L p F P
0 g
s
.763 .767 .856 r
.19226 .73022 m .19469 .72855 L .19122 .72516 L p F P
0 g
s
.055 0 0 r
.64095 .95668 m .63996 .95772 L .62866 .96197 L p F P
0 g
s
0 0 0 r
.62723 .96275 m .62866 .96197 L .63996 .95772 L p F P
0 g
s
.726 .492 .571 r
.37859 .76776 m .36923 .76712 L .37021 .76152 L p F P
0 g
s
.738 .504 .574 r
.36264 .76078 m .37021 .76152 L .36923 .76712 L p F P
0 g
s
.727 .765 .882 r
.20554 .72181 m .20939 .71973 L .21419 .72235 L p F P
0 g
s
.73 .769 .884 r
.21634 .716 m .20939 .71973 L .21419 .72235 L p F P
0 g
s
.73 .769 .884 r
.21419 .72235 m .21979 .71929 L .21634 .716 L p F P
0 g
s
.44 .269 .552 r
.69769 .90136 m .6957 .90235 L .69611 .90805 L p F P
0 g
s
.62 .795 .966 r
.57235 .97259 m .56112 .97541 L .55821 .97302 L p F P
0 g
s
.846 .738 .745 r
.10326 .82407 m .09876 .82146 L .10356 .81474 L p F P
0 g
s
.848 .735 .738 r
.09876 .82146 m .10326 .82407 L .09871 .83071 L p F P
0 g
s
.648 .753 .926 r
.55048 .71793 m .56169 .71455 L .5646 .71779 L p F P
0 g
s
.658 .792 .946 r
.56169 .71455 m .55048 .71793 L .54756 .71555 L p F P
0 g
s
.656 .818 .961 r
.53638 .71933 m .54756 .71555 L .55048 .71793 L p F P
0 g
s
.798 .763 .821 r
.15404 .7535 m .14731 .75941 L .14377 .75594 L p F P
0 g
s
.805 .763 .814 r
.1451 .76145 m .14731 .75941 L .14377 .75594 L p F P
0 g
s
.803 .762 .815 r
.14076 .75871 m .1451 .76145 L .13691 .76917 L p F P
0 g
s
.805 .763 .814 r
.14377 .75594 m .14076 .75871 L .1451 .76145 L p F P
0 g
s
.707 .692 .834 r
.34346 .96842 m .35326 .96336 L .35489 .96347 L p F P
0 g
s
.713 .686 .823 r
.35326 .96336 m .34346 .96842 L .34026 .96408 L p F P
0 g
s
.708 .702 .842 r
.32933 .96965 m .34026 .96408 L .34346 .96842 L p F P
0 g
s
.755 .33 .24 r
.309 .73624 m .3019 .73437 L .29867 .73011 L p F P
0 g
s
.786 .37 .262 r
.29409 .72851 m .29867 .73011 L .3019 .73437 L p F P
0 g
s
.587 .774 .969 r
.23057 .97474 m .24119 .97259 L .24461 .97513 L p F P
0 g
s
.617 .772 .954 r
.24119 .97259 m .23057 .97474 L .2271 .97252 L p F P
0 g
s
.544 .534 .794 r
.67163 .77707 m .68184 .77757 L p .67879 .78421 L F P
0 g
s
.542 .535 .796 r
.68184 .77757 m .67163 .77707 L .67942 .7718 L closepath p F P
0 g
s
.548 .545 .804 r
.67894 .77071 m .67942 .7718 L .67163 .77707 L p F P
0 g
s
.548 .545 .804 r
.66736 .7704 m .67894 .77071 L p .67163 .77707 L F P
0 g
s
.7 .677 .824 r
.39368 .95486 m .39679 .96007 L .38716 .96491 L p F P
0 g
s
.7 .677 .824 r
.38267 .96072 m .39368 .95486 L p .38716 .96491 L F P
0 g
s
.7 .677 .824 r
.38716 .96491 m .38534 .96487 L .38267 .96072 L p F P
0 g
s
.686 .665 .824 r
.41369 .9649 m .414 .96476 L .4109 .95971 L p F P
0 g
s
.69 .679 .835 r
.41409 .9649 m .414 .96476 L .41369 .9649 L closepath p F P
0 g
s
.693 .681 .833 r
.42502 .95963 m .42796 .96448 L .41409 .9649 L p F P
0 g
s
.693 .681 .833 r
.41409 .9649 m .414 .96476 L .42502 .95963 L p F P
0 g
s
.702 .678 .823 r
.38534 .96487 m .38267 .96072 L .37512 .96459 L closepath p F P
0 g
s
.81 .759 .805 r
.13618 .76987 m .13691 .76917 L .13316 .76686 L closepath p F P
0 g
s
.803 .762 .815 r
.13263 .76635 m .14076 .75871 L p .13691 .76917 L F P
0 g
s
.803 .762 .815 r
.13691 .76917 m .13316 .76686 L .13263 .76635 L p F P
0 g
s
.691 .657 .811 r
.42502 .95963 m .414 .96476 L .4109 .95971 L p F P
0 g
s
.798 .763 .821 r
.14377 .75594 m .14967 .75076 L .15404 .7535 L p F P
0 g
s
.796 .764 .824 r
.15484 .74631 m .14967 .75076 L .15404 .7535 L p F P
0 g
s
.796 .764 .824 r
.15404 .7535 m .15837 .74976 L .15484 .74631 L p F P
0 g
s
.321 0 .254 r
.66499 .94142 m .66517 .94129 L .66501 .94136 L closepath p F P
0 g
s
.368 .081 .339 r
.66501 .94136 m .66517 .94129 L .67432 .93331 L p F P
0 g
s
.816 .759 .799 r
.1295 .77665 m .13618 .76987 L .13316 .76686 L p F P
0 g
s
.398 .141 .404 r
.67432 .93331 m .67595 .93262 L .6761 .93123 L closepath p F P
0 g
s
.566 .582 .828 r
.6479 .75344 m .64721 .75204 L .65019 .75189 L closepath p F P
0 g
s
.26 0 .181 r
.66363 .9454 m .66499 .94142 L .66517 .94129 L p F P
0 g
s
.26 0 .181 r
.66517 .94129 m .67508 .93713 L p .66363 .9454 L F P
0 g
s
.354 .063 .324 r
.67595 .93262 m .67432 .93331 L .66517 .94129 L p F P
0 g
s
.354 .063 .324 r
.66517 .94129 m .67508 .93713 L .67595 .93262 L p F P
0 g
s
.714 .693 .829 r
.34026 .96408 m .32933 .96965 L .32611 .96551 L p F P
0 g
s
.748 .767 .868 r
.20554 .72181 m .19469 .72855 L .19122 .72516 L p F P
0 g
s
.788 .764 .831 r
.16385 .74528 m .15837 .74976 L .15484 .74631 L p F P
0 g
s
.834 .79 .81 r
.70251 .16618 m .70363 .16502 L .70096 .16112 L p F P
0 g
s
.643 .424 .57 r
.4349 .76119 m .43932 .76069 L .43752 .76656 L p F P
0 g
s
.643 .424 .57 r
.43752 .76656 m .4351 .76683 L .4349 .76119 L p F P
0 g
s
.663 .442 .573 r
.4349 .76119 m .4351 .76683 L .42178 .76783 L p F P
0 g
s
.561 .869 .995 r
.58648 .97157 m .58874 .97255 L .59971 .96942 L p F P
0 g
s
.545 .876 .991 r
.60059 .96973 m .59971 .96942 L .58874 .97255 L p F P
0 g
s
.521 .476 .747 r
.69649 .81605 m .69605 .81597 L .69639 .81576 L closepath p F P
0 g
s
.528 .488 .755 r
.69353 .80758 m .69639 .81576 L .69605 .81597 L p F P
0 g
s
.528 .488 .755 r
.69345 .80757 m .69353 .80758 L p .69605 .81597 L F P
0 g
s
.595 .896 .988 r
.5336 .71828 m .53638 .71933 L .54756 .71555 L p F P
0 g
s
.635 .711 .902 r
.5646 .71779 m .57585 .71482 L .57875 .71863 L p F P
0 g
s
.643 .735 .915 r
.57585 .71482 m .5646 .71779 L .56169 .71455 L p F P
0 g
s
.863 .709 .69 r
.09197 .85256 m .09662 .85508 L .09347 .86134 L p F P
0 g
s
.859 .715 .701 r
.09662 .85508 m .09197 .85256 L .09543 .84622 L p F P
0 g
s
.834 .79 .81 r
.70096 .16112 m .69989 .16223 L .70251 .16618 L p F P
0 g
s
.829 .789 .814 r
.69249 .16964 m .69513 .17358 L .70251 .16618 L p F P
0 g
s
.829 .789 .814 r
.70251 .16618 m .69989 .16223 L .69249 .16964 L p F P
0 g
s
.509 .459 .736 r
.69905 .82376 m .70751 .81838 L p .70827 .82731 L F P
0 g
s
.509 .459 .736 r
.70827 .82731 m .69948 .82511 L .69905 .82376 L p F P
0 g
s
.514 .471 .747 r
.69905 .82376 m .69649 .81605 L .70751 .81838 L closepath p F P
0 g
s
.509 .458 .736 r
.7015 .83152 m .69948 .82511 L .70827 .82731 L closepath p F P
0 g
s
.76 .502 .544 r
.35084 .7594 m .34594 .75866 L .34613 .75328 L p F P
0 g
s
.756 .499 .544 r
.34223 .75272 m .34613 .75328 L .34594 .75866 L p F P
0 g
s
.504 .445 .725 r
.7015 .83152 m .70827 .82731 L p .70798 .8365 L F P
0 g
s
.504 .445 .725 r
.70798 .8365 m .70251 .83489 L .7015 .83152 L p F P
0 g
s
.794 .781 .841 r
.6686 .1974 m .67034 .19598 L .66761 .19212 L p F P
0 g
s
.794 .781 .841 r
.66761 .19212 m .66592 .1935 L .6686 .1974 L p F P
0 g
s
.791 .781 .843 r
.65643 .20109 m .66592 .1935 L .6686 .1974 L p F P
0 g
s
.874 .68 .636 r
.09306 .87602 m .09781 .87848 L .09583 .88442 L p F P
0 g
s
.869 .687 .654 r
.09539 .86998 m .09306 .87602 L .09781 .87848 L p F P
0 g
s
.869 .687 .654 r
.09576 .87018 m .09539 .86998 L p .09781 .87848 L F P
0 g
s
.705 .684 .828 r
.37954 .95561 m .38267 .96072 L .37512 .96459 L p F P
0 g
s
.705 .684 .828 r
.36854 .96163 m .37954 .95561 L p .37512 .96459 L F P
0 g
s
.705 .684 .828 r
.37512 .96459 m .37038 .96438 L .36854 .96163 L p F P
0 g
s
.714 .705 .84 r
.32611 .96551 m .3152 .97094 L .31195 .96702 L p F P
0 g
s
.683 .665 .825 r
.44154 .96382 m .4422 .9649 L p .4281 .96471 L F P
0 g
s
.683 .665 .825 r
.4281 .96471 m .42872 .96444 L .44154 .96382 L p F P
0 g
s
.683 .663 .824 r
.4281 .96471 m .42872 .96444 L .42796 .96448 L closepath p F P
0 g
s
.708 .188 0 r
.15992 .95631 m .15408 .95428 L .15093 .9514 L p F P
0 g
s
.709 .192 0 r
.15408 .95428 m .15093 .9514 L .14713 .95136 L p F P
0 g
s
.819 .758 .795 r
.1295 .77665 m .12495 .78136 L .12139 .77782 L p F P
0 g
s
.819 .758 .795 r
.12139 .77782 m .12514 .77394 L .1295 .77665 L p F P
0 g
s
.816 .759 .799 r
.13252 .76646 m .12514 .77394 L .1295 .77665 L p F P
0 g
s
.816 .759 .799 r
.13316 .76686 m .13252 .76646 L p .1295 .77665 L F P
0 g
s
.654 .699 .879 r
.48756 .97102 m .49867 .96745 L p .49944 .97234 L F P
0 g
s
.661 .675 .853 r
.49867 .96745 m .48756 .97102 L .48454 .96662 L p F P
0 g
s
.803 .784 .835 r
.6783 .18914 m .67034 .19598 L .66761 .19212 L p F P
0 g
s
.513 .471 .747 r
.70751 .81838 m .69649 .81605 L .69639 .81576 L p F P
0 g
s
.513 .471 .747 r
.69639 .81576 m .70537 .80995 L p .70751 .81838 L F P
0 g
s
.518 .483 .758 r
.70527 .80967 m .70537 .80995 L .69639 .81576 L p F P
0 g
s
.518 .483 .758 r
.69639 .81576 m .69353 .80758 L .70527 .80967 L p F P
0 g
s
.655 .713 .89 r
.50196 .97202 m .50168 .97166 L .49944 .97234 L closepath p F P
0 g
s
.654 .699 .879 r
.49867 .96745 m .50168 .97166 L .49944 .97234 L p F P
0 g
s
.067 0 0 r
.63996 .95772 m .64095 .95668 L .65137 .95289 L p F P
0 g
s
.504 .445 .724 r
.70376 .83908 m .70251 .83489 L .70798 .8365 L closepath p F P
0 g
s
.788 .764 .831 r
.15484 .74631 m .15945 .74255 L .16385 .74528 L p F P
0 g
s
.786 .766 .834 r
.16586 .73741 m .15945 .74255 L .16385 .74528 L p F P
0 g
s
.786 .766 .834 r
.16385 .74528 m .16937 .74085 L .16586 .73741 L p F P
0 g
s
.812 .381 .219 r
.13031 .93889 m .13593 .941 L .13869 .94572 L p F P
0 g
s
.837 .466 .349 r
.13031 .93888 m .13031 .93889 L .13593 .941 L p F P
0 g
s
.814 .389 .233 r
.14424 .94784 m .13869 .94572 L .13593 .941 L p F P
0 g
s
.559 .304 .485 r
.4723 .75026 m .4727 .74527 L .48437 .74261 L p F P
0 g
s
.84 .745 .759 r
.1088 .8079 m .10567 .81194 L .1021 .80817 L p F P
0 g
s
.84 .745 .759 r
.1021 .80817 m .10437 .80525 L .1088 .8079 L p F P
0 g
s
.836 .748 .766 r
.1088 .8079 m .10437 .80525 L .11 .79829 L p F P
0 g
s
.781 .492 .497 r
.33384 .75127 m .32824 .75008 L .32905 .74526 L p F P
0 g
s
.771 .481 .495 r
.32534 .74457 m .32905 .74526 L .32824 .75008 L p F P
0 g
s
.683 .663 .824 r
.42872 .96444 m .42796 .96448 L .42502 .95963 L p F P
0 g
s
.658 .762 .927 r
.25531 .97209 m .24461 .97513 L .24119 .97259 L p F P
0 g
s
.638 .768 .941 r
.24461 .97513 m .25531 .97209 L .25869 .97493 L p F P
0 g
s
.566 .584 .831 r
.65019 .75189 m .64721 .75204 L .64434 .74627 L p F P
0 g
s
.684 .663 .824 r
.44154 .96382 m .43913 .95984 L .42872 .96444 L closepath p F P
0 g
s
.683 .663 .824 r
.43606 .95448 m .43913 .95984 L .42872 .96444 L p F P
0 g
s
.683 .663 .824 r
.42502 .95963 m .43606 .95448 L p .42872 .96444 L F P
0 g
s
.651 .774 .939 r
.23396 .71767 m .24464 .7142 L .24806 .71713 L p F P
0 g
s
.637 .774 .946 r
.24464 .7142 m .23396 .71767 L .23053 .7145 L p F P
0 g
s
.699 .77 .907 r
.21979 .71929 m .23053 .7145 L .23396 .71767 L p F P
0 g
s
.87 .603 .532 r
.11176 .9166 m .10762 .91479 L .10866 .9096 L p F P
0 g
s
.876 .61 .532 r
.10693 .9088 m .10866 .9096 L .10762 .91479 L p F P
0 g
s
.824 .788 .818 r
.68989 .17218 m .69249 .16964 L .69513 .17358 L p F P
0 g
s
.824 .788 .818 r
.69513 .17358 m .69258 .17607 L .68989 .17218 L p F P
0 g
s
.709 .735 .872 r
.30106 .97222 m .3011 .9722 L .30103 .97219 L closepath p F P
0 g
s
.698 .731 .876 r
.30103 .97219 m .30106 .97222 L p .28693 .97335 L F P
0 g
s
.705 .684 .828 r
.37038 .96438 m .36854 .96163 L .3638 .96408 L closepath p F P
0 g
s
.71 .735 .87 r
.30869 .96293 m .31195 .96702 L .3011 .9722 L p F P
0 g
s
.71 .735 .87 r
.29778 .96854 m .30869 .96293 L p .3011 .9722 L F P
0 g
s
.71 .735 .87 r
.3011 .9722 m .30103 .97219 L .29778 .96854 L p F P
0 g
s
.499 .432 .713 r
.70376 .83908 m .70798 .8365 L p .70665 .84595 L F P
0 g
s
.499 .432 .713 r
.70665 .84595 m .70558 .84558 L .70376 .83908 L p F P
0 g
s
.698 .731 .876 r
.28693 .97335 m .29197 .97111 L .30103 .97219 L p F P
0 g
s
.698 .731 .877 r
.30103 .97219 m .29778 .96854 L .29197 .97111 L closepath p F P
0 g
s
.738 .504 .574 r
.36923 .76712 m .36284 .7665 L .36264 .76078 L p F P
0 g
s
.741 .505 .573 r
.36026 .76054 m .36264 .76078 L .36284 .7665 L p F P
0 g
s
.806 .784 .832 r
.6783 .18914 m .68148 .18636 L .67877 .18249 L p F P
0 g
s
.806 .784 .832 r
.67877 .18249 m .67564 .18523 L .6783 .18914 L p F P
0 g
s
.803 .784 .835 r
.66761 .19212 m .67564 .18523 L .6783 .18914 L p F P
0 g
s
.818 .787 .824 r
.68707 .18123 m .69258 .17607 L .68989 .17218 L p F P
0 g
s
.531 .77 .985 r
.24806 .71713 m .25864 .71559 L .26207 .71805 L p F P
0 g
s
.483 .758 .991 r
.25864 .71559 m .24806 .71713 L .24464 .7142 L p F P
0 g
s
.541 .523 .785 r
.67879 .78421 m .68475 .78463 L p .68482 .79168 L F P
0 g
s
.538 .524 .787 r
.68475 .78463 m .67879 .78421 L .68336 .78119 L closepath p F P
0 g
s
.544 .534 .794 r
.68184 .77757 m .68336 .78119 L .67879 .78421 L p F P
0 g
s
.824 .758 .79 r
.12249 .78401 m .12495 .78136 L .12139 .77782 L p F P
0 g
s
.546 .545 .805 r
.67606 .76413 m .67894 .77071 L .66736 .7704 L p F P
0 g
s
.546 .545 .805 r
.67225 .76402 m .67606 .76413 L p .66736 .7704 L F P
0 g
s
.546 .545 .805 r
.66736 .7704 m .66635 .7681 L .67225 .76402 L p F P
0 g
s
.646 .426 .571 r
.43932 .76069 m .44778 .75977 L .44801 .76542 L p F P
0 g
s
.646 .426 .571 r
.44801 .76542 m .43752 .76656 L .43932 .76069 L p F P
0 g
s
.818 .787 .824 r
.68989 .17218 m .68442 .1773 L .68707 .18123 L p F P
0 g
s
.814 .786 .826 r
.67877 .18249 m .68442 .1773 L .68707 .18123 L p F P
0 g
s
.814 .786 .826 r
.68707 .18123 m .68148 .18636 L .67877 .18249 L p F P
0 g
s
.595 .636 .861 r
.61108 .72934 m .61002 .72754 L .61502 .7268 L closepath p F P
0 g
s
.711 .739 .873 r
.29197 .97111 m .28693 .97335 L .28361 .96996 L p F P
0 g
s
.686 .745 .896 r
.2728 .97429 m .28361 .96996 L .28693 .97335 L p F P
0 g
s
.668 .757 .917 r
.25869 .97493 m .26945 .97117 L .2728 .97429 L p F P
0 g
s
.683 .751 .903 r
.26945 .97117 m .25869 .97493 L .25531 .97209 L p F P
0 g
s
.777 .766 .843 r
.17488 .73668 m .16937 .74085 L .16586 .73741 L p F P
0 g
s
.654 .712 .891 r
.51281 .96831 m .51422 .97016 L .50196 .97202 L p F P
0 g
s
.654 .712 .891 r
.50196 .97202 m .50168 .97166 L .51281 .96831 L p F P
0 g
s
.526 .488 .758 r
.69353 .80758 m .69345 .80757 L .69351 .80753 L closepath p F P
0 g
s
.533 .5 .766 r
.69058 .79957 m .69351 .80753 L .69345 .80757 L p F P
0 g
s
.533 .5 .766 r
.68971 .79947 m .69058 .79957 L p .69345 .80757 L F P
0 g
s
.678 .665 .83 r
.45483 .96288 m .45631 .9653 L p .4422 .9649 L F P
0 g
s
.678 .665 .83 r
.4422 .9649 m .44553 .96352 L .45483 .96288 L p F P
0 g
s
.677 .662 .827 r
.4422 .9649 m .44553 .96352 L .44154 .96382 L closepath p F P
0 g
s
.698 .736 .88 r
.28361 .96996 m .2728 .97429 L .26945 .97117 L p F P
0 g
s
.469 .347 .631 r
.7038 .88541 m .70347 .88349 L .70492 .88481 L closepath p F P
0 g
s
.696 .482 .593 r
.4047 .76839 m .40798 .76836 L .40844 .77428 L p F P
0 g
s
.696 .482 .593 r
.40844 .77428 m .40266 .77433 L .4047 .76839 L p F P
0 g
s
.701 .487 .595 r
.3936 .76835 m .4047 .76839 L .40266 .77433 L p F P
0 g
s
.756 .499 .544 r
.34594 .75866 m .34201 .75809 L .34223 .75272 L p F P
0 g
s
.768 .509 .543 r
.33384 .75127 m .34223 .75272 L .34201 .75809 L p F P
0 g
s
.516 .483 .758 r
.70243 .80163 m .70527 .80967 L .69353 .80758 L p F P
0 g
s
.516 .483 .758 r
.69353 .80758 m .69351 .80753 L .70243 .80163 L p F P
0 g
s
.866 .697 .671 r
.09576 .87018 m .0955 .86974 L .09539 .86998 L closepath p F P
0 g
s
.523 .496 .768 r
.7023 .8013 m .70243 .80163 L .69351 .80753 L p F P
0 g
s
.523 .496 .768 r
.69351 .80753 m .69058 .79957 L .7023 .8013 L p F P
0 g
s
.741 .505 .573 r
.36284 .7665 m .35928 .76614 L .36026 .76054 L p F P
0 g
s
.75 .512 .571 r
.35084 .7594 m .36026 .76054 L .35928 .76614 L p F P
0 g
s
.683 .472 .594 r
.40798 .76836 m .41955 .76793 L .41722 .77395 L p F P
0 g
s
.683 .472 .594 r
.41722 .77395 m .40844 .77428 L .40798 .76836 L p F P
0 g
s
.549 0 0 r
.15992 .95631 m .16434 .95933 L .16141 .95854 L p F P
0 g
s
.549 0 0 r
.15408 .95428 m .15992 .95631 L p .16141 .95854 L F P
0 g
s
.701 .487 .595 r
.40266 .77433 m .39407 .7743 L .3936 .76835 L p F P
0 g
s
.711 .494 .594 r
.39173 .7683 m .3936 .76835 L .39407 .7743 L p F P
0 g
s
.827 .756 .785 r
.11816 .7813 m .12249 .78401 L .11601 .79122 L p F P
0 g
s
.824 .758 .79 r
.12139 .77782 m .11816 .7813 L .12249 .78401 L p F P
0 g
s
.718 .501 .594 r
.38005 .76784 m .39173 .7683 L .38986 .77419 L p F P
0 g
s
.711 .494 .594 r
.39407 .7743 m .38986 .77419 L .39173 .7683 L p F P
0 g
s
.708 .693 .833 r
.36539 .95666 m .36854 .96163 L .3638 .96408 L p F P
0 g
s
.708 .693 .833 r
.35441 .96277 m .36539 .95666 L p .3638 .96408 L F P
0 g
s
.708 .693 .833 r
.3638 .96408 m .35489 .96347 L .35441 .96277 L p F P
0 g
s
.694 .771 .911 r
.23053 .7145 m .21979 .71929 L .21634 .716 L p F P
0 g
s
.868 .7 .671 r
.09539 .86998 m .0955 .86974 L .09209 .86437 L p F P
0 g
s
.618 .689 .894 r
.57875 .71863 m .59003 .71605 L p .59142 .72058 L F P
0 g
s
.628 .698 .896 r
.59003 .71605 m .57875 .71863 L .57585 .71482 L p F P
0 g
s
.44 .269 .552 r
.69611 .90805 m .69884 .90669 L .69769 .90136 L p F P
0 g
s
.436 .267 .552 r
.70531 .89749 m .69769 .90136 L .69884 .90669 L p F P
0 g
s
.453 .301 .583 r
.69769 .90136 m .70531 .89749 L .70466 .89155 L p F P
0 g
s
0 .401 .704 r
.17845 .96399 m .18171 .96516 L .17809 .96375 L p F P
0 g
s
.656 .683 .864 r
.51281 .96831 m .50168 .97166 L .49867 .96745 L p F P
0 g
s
.499 .432 .712 r
.70582 .84645 m .70558 .84558 L .70665 .84595 L closepath p F P
0 g
s
.534 .512 .778 r
.68766 .79195 m .68482 .79168 L .68701 .79026 L closepath p F P
0 g
s
.541 .523 .785 r
.68475 .78463 m .68701 .79026 L .68482 .79168 L p F P
0 g
s
.537 .512 .775 r
.68482 .79168 m .68766 .79195 L p .68971 .79947 L F P
0 g
s
.596 .366 .538 r
.46025 .75252 m .4662 .75138 L .46602 .75678 L p F P
0 g
s
.596 .366 .538 r
.46602 .75678 m .46021 .75789 L .46025 .75252 L p F P
0 g
s
.617 .383 .54 r
.46025 .75252 m .46021 .75789 L .44778 .75977 L p F P
0 g
s
.844 .745 .755 r
.10356 .81474 m .10567 .81194 L .1021 .80817 L p F P
0 g
s
.873 .692 .654 r
.09072 .86749 m .09539 .86998 L .09306 .87602 L p F P
0 g
s
.868 .7 .671 r
.09209 .86437 m .09072 .86749 L .09539 .86998 L p F P
0 g
s
.331 .036 .304 r
.68588 .92821 m .67595 .93262 L .67508 .93713 L p F P
0 g
s
.368 .117 .396 r
.68634 .92332 m .68588 .92821 L .67595 .93262 L p F P
0 g
s
.798 .471 .434 r
.31023 .73922 m .31151 .73682 L p .31769 .74288 L F P
0 g
s
.776 .424 .391 r
.31023 .73922 m .309 .73624 L .31151 .73682 L closepath p F P
0 g
s
.53 .501 .768 r
.69058 .79957 m .68971 .79947 L .69039 .79904 L closepath p F P
0 g
s
.537 .512 .775 r
.68766 .79195 m .69039 .79904 L .68971 .79947 L p F P
0 g
s
.49 .415 .698 r
.70665 .84595 m .70582 .84645 L .70768 .8536 L p F P
0 g
s
.551 .556 .813 r
.66635 .7681 m .66448 .76397 L .67225 .76402 L closepath p F P
0 g
s
.771 .481 .495 r
.32824 .75008 m .32598 .74965 L .32534 .74457 L p F P
0 g
s
.781 .492 .498 r
.31769 .74288 m .32534 .74457 L .32598 .74965 L p F P
0 g
s
.853 .731 .727 r
.09871 .83071 m .09745 .83267 L .09392 .82854 L p F P
0 g
s
.853 .731 .727 r
.09392 .82854 m .09419 .82811 L .09871 .83071 L p F P
0 g
s
.848 .735 .738 r
.09871 .83071 m .09419 .82811 L .09876 .82146 L p F P
0 g
s
.777 .766 .843 r
.16586 .73741 m .17047 .73395 L .17488 .73668 L p F P
0 g
s
.776 .767 .845 r
.17682 .72924 m .17047 .73395 L .17488 .73668 L p F P
0 g
s
.776 .767 .845 r
.17488 .73668 m .18031 .73265 L .17682 .72924 L p F P
0 g
s
.677 .661 .827 r
.44553 .96352 m .44154 .96382 L .43913 .95984 L p F P
0 g
s
.404 .75 .994 r
.21034 .97165 m .21308 .97168 L .20956 .96961 L p F P
0 g
s
.404 .75 .994 r
.20956 .96961 m .20396 .9698 L .21034 .97165 L p F P
0 g
s
.201 .677 .935 r
.19914 .96975 m .20396 .9698 L .21034 .97165 L p F P
0 g
s
.313 .727 .976 r
.20396 .9698 m .19914 .96975 L .19557 .96812 L p F P
0 g
s
.681 .47 .593 r
.41955 .76793 m .42178 .76783 L .42225 .77374 L p F P
0 g
s
.681 .47 .593 r
.42225 .77374 m .41722 .77395 L .41955 .76793 L p F P
0 g
s
.456 .321 .608 r
.70492 .88481 m .7038 .88541 L .70466 .89155 L p F P
0 g
s
.672 .668 .837 r
.46777 .96165 m .47042 .96589 L p .45631 .9653 L F P
0 g
s
.672 .668 .837 r
.45631 .9653 m .46515 .96188 L .46777 .96165 L p F P
0 g
s
.671 .662 .832 r
.45631 .9653 m .46515 .96188 L .45483 .96288 L closepath p F P
0 g
s
.487 .387 .667 r
.70936 .86056 m .71084 .86733 L .70655 .86972 L p F P
0 g
s
.476 .369 .653 r
.71208 .87357 m .70655 .86972 L .71084 .86733 L closepath p F P
0 g
s
.862 .718 .702 r
.09087 .84365 m .09543 .84622 L .09197 .85256 L p F P
0 g
s
.858 .723 .712 r
.09543 .84622 m .09087 .84365 L .09462 .83723 L p F P
0 g
s
0 0 0 r
.52228 .72257 m .51974 .72412 L .50918 .72799 L p F P
0 g
s
.305 0 .085 r
.50918 .72799 m .50818 .72969 L .49705 .73356 L p F P
0 g
s
.399 .048 .25 r
.49652 .73504 m .49705 .73356 L .50818 .72969 L p F P
0 g
s
.718 .501 .594 r
.3789 .77179 m .38005 .76784 L p .38986 .77419 L F P
0 g
s
.722 .503 .592 r
.3789 .77179 m .38005 .76784 L .37859 .76776 L closepath p F P
0 g
s
.665 .457 .594 r
.42178 .76783 m .4351 .76683 L p .43452 .77279 L F P
0 g
s
.665 .457 .594 r
.43452 .77279 m .42225 .77374 L .42178 .76783 L p F P
0 g
s
.582 .612 .847 r
.62731 .73648 m .62715 .73619 L .62786 .73612 L closepath p F P
0 g
s
.876 .61 .532 r
.10762 .91479 m .10659 .91432 L .10693 .9088 L p F P
0 g
s
.879 .613 .531 r
.10195 .90645 m .10693 .9088 L .10659 .91432 L p F P
0 g
s
.877 .632 .564 r
.10693 .9088 m .10195 .90645 L .10274 .90082 L p F P
0 g
s
.4 .705 .984 r
.26207 .71805 m .26668 .71845 L .27252 .72072 L p F P
0 g
s
.319 .672 .976 r
.26668 .71845 m .26207 .71805 L .25864 .71559 L p F P
0 g
s
.87 .575 .485 r
.10762 .91479 m .11176 .9166 L .11202 .92196 L p F P
0 g
s
.868 .574 .488 r
.11728 .92421 m .11202 .92196 L .11176 .9166 L p F P
0 g
s
.721 .502 .593 r
.37859 .76776 m .36923 .76712 L p .37834 .77367 L F P
0 g
s
.721 .502 .593 r
.37834 .77367 m .3789 .77179 L .37859 .76776 L p F P
0 g
s
.521 .495 .769 r
.69936 .79336 m .7023 .8013 L .69058 .79957 L p F P
0 g
s
.521 .495 .769 r
.6989 .79329 m .69936 .79336 L p .69058 .79957 L F P
0 g
s
.521 .495 .769 r
.69058 .79957 m .69039 .79904 L .6989 .79329 L p F P
0 g
s
.848 .742 .747 r
.09917 .81208 m .10356 .81474 L .09876 .82146 L p F P
0 g
s
.844 .745 .755 r
.1021 .80817 m .09917 .81208 L .10356 .81474 L p F P
0 g
s
.595 .643 .868 r
.61502 .7268 m .61002 .72754 L .60714 .72279 L p F P
0 g
s
0 .457 .791 r
.27252 .72072 m .27597 .72133 L .27248 .72016 L p F P
0 g
s
0 .457 .791 r
.27065 .71962 m .26668 .71845 L p .27249 .72031 L F P
0 g
s
.319 0 0 r
.26668 .71845 m .27248 .72016 L .26957 .71941 L p F P
0 g
s
.319 0 0 r
.2613 .71601 m .26668 .71845 L p .26957 .71941 L F P
0 g
s
.319 0 0 r
.26957 .71941 m .26853 .71902 L .2637 .71701 L p F P
0 g
s
.319 0 0 r
.2637 .71701 m .2613 .71601 L p .2641 .71716 L F P
0 g
s
.319 0 0 r
.26957 .71941 m .2637 .71701 L .2641 .71716 L F
0 .457 .791 r
.26668 .71845 m .27252 .72072 L p .27249 .72031 L F P
0 g
s
0 .457 .791 r
.27248 .72016 m .27065 .71962 L p .27249 .72031 L F P
0 g
s
.831 .754 .778 r
.11601 .79122 m .11361 .79398 L .11004 .79038 L p F P
0 g
s
.831 .754 .778 r
.11004 .79038 m .11165 .78852 L .11601 .79122 L p F P
0 g
s
.827 .756 .785 r
.11601 .79122 m .11165 .78852 L .11816 .7813 L p F P
0 g
s
.581 .617 .853 r
.62786 .73612 m .62715 .73619 L .62428 .73102 L p F P
0 g
s
.527 .508 .778 r
.69039 .79904 m .68766 .79195 L .6989 .79329 L closepath p F P
0 g
s
.786 .37 .262 r
.29318 .72876 m .29409 .72851 L p .3019 .73437 L F P
0 g
s
.69 .186 .037 r
.29318 .72876 m .2923 .72801 L .29409 .72851 L closepath p F P
0 g
s
.678 .664 .829 r
.45483 .96288 m .45325 .96031 L .44553 .96352 L closepath p F P
0 g
s
.677 .661 .827 r
.45019 .95497 m .45325 .96031 L .44553 .96352 L p F P
0 g
s
.677 .661 .827 r
.43913 .95984 m .45019 .95497 L p .44553 .96352 L F P
0 g
s
.76 .267 .056 r
.14424 .94784 m .14713 .95136 L .14513 .95117 L p F P
0 g
s
.76 .267 .056 r
.13869 .94572 m .14424 .94784 L p .14513 .95117 L F P
0 g
s
.857 .731 .723 r
.09462 .83723 m .09745 .83267 L .09392 .82854 L p F P
0 g
s
.88 .635 .564 r
.09783 .89843 m .10274 .90082 L .10195 .90645 L p F P
0 g
s
.876 .65 .592 r
.10274 .90082 m .09783 .89843 L .09905 .89269 L p F P
0 g
s
.262 .764 .725 r
.62723 .96275 m .62598 .96314 L .61466 .9667 L p F P
0 g
s
.389 .849 .874 r
.62598 .96314 m .61466 .9667 L .6119 .96654 L p F P
0 g
s
.412 .858 .904 r
.60059 .96973 m .6119 .96654 L .61466 .9667 L p F P
0 g
s
.707 .693 .834 r
.35489 .96347 m .35441 .96277 L .35326 .96336 L closepath p F P
0 g
s
.489 .416 .7 r
.71497 .84088 m .70665 .84595 L .71476 .84936 L p F P
0 g
s
.499 .432 .713 r
.71436 .83875 m .71497 .84088 L .70665 .84595 L p F P
0 g
s
.499 .432 .713 r
.70798 .8365 m .71436 .83875 L p .70665 .84595 L F P
0 g
s
.49 .415 .698 r
.70768 .8536 m .71476 .84936 L .70665 .84595 L p F P
0 g
s
.626 .41 .57 r
.44801 .76542 m .44778 .75977 L .46021 .75789 L p F P
0 g
s
.647 .719 .901 r
.5158 .97225 m .52696 .9691 L .52993 .97274 L p F P
0 g
s
.648 .702 .886 r
.52615 .96799 m .52696 .9691 L .5158 .97225 L p F P
0 g
s
.648 .702 .886 r
.5158 .97225 m .51422 .97016 L .52615 .96799 L p F P
0 g
s
.616 .676 .884 r
.59292 .72027 m .59142 .72058 L .59265 .71986 L closepath p F P
0 g
s
.618 .689 .894 r
.59003 .71605 m .59265 .71986 L .59142 .72058 L p F P
0 g
s
.787 .445 .409 r
.309 .73624 m .31023 .73922 L .3096 .74067 L p F P
0 g
s
.787 .445 .409 r
.3019 .73437 m .309 .73624 L p .3096 .74067 L F P
0 g
s
.561 .574 .824 r
.65872 .75162 m .65019 .75189 L .6567 .74741 L closepath p F P
0 g
s
.566 .584 .831 r
.65584 .74567 m .6567 .74741 L .65019 .75189 L p F P
0 g
s
.566 .584 .831 r
.64434 .74627 m .65584 .74567 L p .65019 .75189 L F P
0 g
s
.764 .768 .856 r
.18776 .72751 m .18031 .73265 L .17682 .72924 L p F P
0 g
s
.863 .537 .433 r
.12345 .93164 m .11817 .92941 L .11728 .92421 L p F P
0 g
s
.866 .538 .429 r
.11202 .92196 m .11728 .92421 L .11817 .92941 L p F P
0 g
s
.705 .656 .799 r
.39368 .95486 m .38267 .96072 L .37954 .95561 L p F P
0 g
s
.713 .686 .823 r
.34026 .96408 m .34294 .96259 L .35326 .96336 L p F P
0 g
s
.703 .681 .826 r
.35123 .95797 m .34294 .96259 L .35326 .96336 L p F P
0 g
s
.703 .681 .826 r
.35326 .96336 m .35441 .96277 L .35123 .95797 L p F P
0 g
s
.725 .766 .885 r
.20939 .71973 m .20554 .72181 L .20208 .71845 L p F P
0 g
s
.748 .767 .868 r
.19122 .72516 m .20208 .71845 L .20554 .72181 L p F P
0 g
s
.577 .605 .844 r
.63859 .73513 m .62786 .73612 L .63612 .73046 L closepath p F P
0 g
s
.581 .617 .853 r
.63572 .72973 m .63612 .73046 L .62786 .73612 L p F P
0 g
s
.581 .617 .853 r
.62428 .73102 m .63572 .72973 L p .62786 .73612 L F P
0 g
s
.71 .663 .802 r
.37954 .95561 m .36854 .96163 L .36539 .95666 L p F P
0 g
s
.7 .651 .798 r
.40781 .95441 m .39679 .96007 L .39368 .95486 L p F P
0 g
s
.835 .753 .773 r
.11 .79829 m .11361 .79398 L .11004 .79038 L p F P
0 g
s
.484 .4 .685 r
.70768 .8536 m .71476 .84936 L p .71143 .85934 L F P
0 g
s
.484 .4 .685 r
.71143 .85934 m .70875 .85801 L .70768 .8536 L p F P
0 g
s
.711 .739 .873 r
.28361 .96996 m .28431 .96962 L .29197 .97111 L p F P
0 g
s
.696 .722 .87 r
.2945 .96468 m .28431 .96962 L .29197 .97111 L p F P
0 g
s
.696 .722 .87 r
.29197 .97111 m .29778 .96854 L .2945 .96468 L p F P
0 g
s
.879 .653 .592 r
.09421 .89027 m .09905 .89269 L .09783 .89843 L p F P
0 g
s
.875 .666 .615 r
.09905 .89269 m .09421 .89027 L .09583 .88442 L p F P
0 g
s
.868 .702 .674 r
.09347 .86134 m .09209 .86437 L .08866 .85911 L p F P
0 g
s
.868 .702 .674 r
.08866 .85911 m .08879 .85883 L .09347 .86134 L p F P
0 g
s
.863 .709 .69 r
.09347 .86134 m .08879 .85883 L .09197 .85256 L p F P
0 g
s
.667 .67 .844 r
.47042 .96589 m .48151 .96188 L .48454 .96662 L p F P
0 g
s
.667 .665 .838 r
.48053 .96023 m .48151 .96188 L .47042 .96589 L p F P
0 g
s
.667 .665 .838 r
.47042 .96589 m .46777 .96165 L .48053 .96023 L p F P
0 g
s
.714 .67 .806 r
.36539 .95666 m .35441 .96277 L .35123 .95797 L p F P
0 g
s
.456 .321 .608 r
.70466 .89155 m .70851 .88949 L .70492 .88481 L p F P
0 g
s
.453 .32 .609 r
.71323 .88027 m .70492 .88481 L .70851 .88949 L p F P
0 g
s
.469 .347 .632 r
.71215 .87391 m .71323 .88027 L .70492 .88481 L p F P
0 g
s
.691 .657 .811 r
.4109 .95971 m .42193 .95429 L .42502 .95963 L p F P
0 g
s
.694 .647 .799 r
.42193 .95429 m .4109 .95971 L .40781 .95441 L p F P
0 g
s
.75 .512 .571 r
.35928 .76614 m .34994 .76498 L .35084 .7594 L p F P
0 g
s
.761 .523 .573 r
.34594 .75866 m .35084 .7594 L .34994 .76498 L p F P
0 g
s
.748 .288 .157 r
.2923 .72801 m .29318 .72876 L .28993 .73034 L p F P
0 g
s
.748 .288 .157 r
.28568 .72599 m .2923 .72801 L p .28993 .73034 L F P
0 g
s
.551 .557 .813 r
.67225 .76402 m .66448 .76397 L .66177 .75803 L p F P
0 g
s
.24 0 .037 r
.50818 .72969 m .50918 .72799 L .51974 .72412 L p F P
0 g
s
.721 .502 .593 r
.36923 .76712 m .36765 .77292 L .37834 .77367 L p F P
0 g
s
.74 .519 .594 r
.36284 .7665 m .36923 .76712 L .36765 .77292 L p F P
0 g
s
.612 .674 .885 r
.60167 .71413 m .60426 .71815 L .59292 .72027 L p F P
0 g
s
.612 .674 .885 r
.59292 .72027 m .59265 .71986 L .60167 .71413 L p F P
0 g
s
.608 .655 .871 r
.59292 .72027 m .60426 .71815 L .60714 .72279 L p F P
0 g
s
.855 .491 .362 r
.13031 .93888 m .12502 .93667 L .12345 .93164 L p F P
0 g
s
.856 .489 .355 r
.11817 .92941 m .12345 .93164 L .12502 .93667 L p F P
0 g
s
.716 .695 .829 r
.34026 .96408 m .34294 .96259 L .33893 .96219 L closepath p F P
0 g
s
.714 .693 .829 r
.33893 .96219 m .34026 .96408 L p .32611 .96551 L F P
0 g
s
.6 .37 .539 r
.4662 .75138 m .4723 .75026 L .47228 .75563 L p F P
0 g
s
.6 .37 .539 r
.47228 .75563 m .46602 .75678 L .4662 .75138 L p F P
0 g
s
.645 .713 .898 r
.54112 .96974 m .52993 .97274 L .52696 .9691 L p F P
0 g
s
.64 .738 .919 r
.52993 .97274 m .54112 .96974 L .54407 .97303 L p F P
0 g
s
.566 .586 .833 r
.65297 .73993 m .65584 .74567 L .64434 .74627 L p F P
0 g
s
.566 .586 .833 r
.64525 .74034 m .65297 .73993 L p .64434 .74627 L F P
0 g
s
.566 .586 .833 r
.64434 .74627 m .64238 .74236 L .64525 .74034 L p F P
0 g
s
.419 .23 .515 r
.69884 .90669 m .69611 .90805 L .69627 .91352 L p F P
0 g
s
.671 .661 .832 r
.46515 .96188 m .45483 .96288 L .45325 .96031 L p F P
0 g
s
.688 .645 .801 r
.43606 .95448 m .42502 .95963 L .42193 .95429 L p F P
0 g
s
.768 .509 .543 r
.34201 .75809 m .3336 .75664 L .33384 .75127 L p F P
0 g
s
.783 .523 .543 r
.32824 .75008 m .33384 .75127 L .3336 .75664 L p F P
0 g
s
.838 .751 .768 r
.10568 .79559 m .11 .79829 L .10437 .80525 L p F P
0 g
s
.835 .753 .773 r
.11004 .79038 m .10568 .79559 L .11 .79829 L p F P
0 g
s
.527 .508 .778 r
.6989 .79329 m .68766 .79195 L .68701 .79026 L p F P
0 g
s
.615 .68 .888 r
.60137 .71367 m .60167 .71413 L .59265 .71986 L p F P
0 g
s
.615 .68 .888 r
.59265 .71986 m .59003 .71605 L .60137 .71367 L p F P
0 g
s
.878 .669 .616 r
.09106 .88197 m .09583 .88442 L .09421 .89027 L p F P
0 g
s
.874 .68 .636 r
.09583 .88442 m .09106 .88197 L .09306 .87602 L p F P
0 g
s
.812 .762 .806 r
.13316 .76686 m .13263 .76635 L .13252 .76646 L closepath p F P
0 g
s
.484 .399 .684 r
.70936 .86056 m .70875 .85801 L .71143 .85934 L closepath p F P
0 g
s
.648 .442 .59 r
.43539 .77081 m .43752 .76656 L .4351 .76683 L closepath p F P
0 g
s
.665 .457 .594 r
.4351 .76683 m .43539 .77081 L .43452 .77279 L p F P
0 g
s
.544 .771 .982 r
.21308 .97168 m .22363 .97011 L .2271 .97252 L p F P
0 g
s
.581 .772 .97 r
.22363 .97011 m .21308 .97168 L .20956 .96961 L p F P
0 g
s
0 0 0 r
.63996 .95772 m .63778 .95912 L .62723 .96275 L p F P
0 g
s
.248 .749 .691 r
.62598 .96314 m .62723 .96275 L .63778 .95912 L p F P
0 g
s
.723 .695 .823 r
.33308 .96168 m .32611 .96551 L .32288 .96119 L p F P
0 g
s
.714 .705 .84 r
.31195 .96702 m .32288 .96119 L .32611 .96551 L p F P
0 g
s
.714 .693 .829 r
.32611 .96551 m .33308 .96168 L .33893 .96219 L p F P
0 g
s
.725 .766 .885 r
.20208 .71845 m .20464 .71709 L .20939 .71973 L p F P
0 g
s
.727 .771 .887 r
.21288 .71275 m .20464 .71709 L .20939 .71973 L p F P
0 g
s
.727 .771 .887 r
.20939 .71973 m .21634 .716 L .21288 .71275 L p F P
0 g
s
.067 0 0 r
.65137 .95289 m .65128 .95299 L .63996 .95772 L p F P
0 g
s
0 0 0 r
.63778 .95912 m .63996 .95772 L .65128 .95299 L p F P
0 g
s
.531 .519 .787 r
.68701 .79026 m .68475 .78463 L .69392 .7855 L closepath p F P
0 g
s
.527 .508 .778 r
.68701 .79026 m .69392 .7855 L p .6989 .79329 L F P
0 g
s
.763 .769 .858 r
.18773 .7218 m .18335 .72476 L .18776 .72751 L p F P
0 g
s
.763 .769 .858 r
.18776 .72751 m .19122 .72516 L .18773 .7218 L p F P
0 g
s
.764 .768 .856 r
.17682 .72924 m .18335 .72476 L .18776 .72751 L p F P
0 g
s
.861 .727 .714 r
.09014 .83462 m .09462 .83723 L .09087 .84365 L p F P
0 g
s
.857 .731 .723 r
.09392 .82854 m .09014 .83462 L .09462 .83723 L p F P
0 g
s
.549 .882 .989 r
.59971 .96942 m .60059 .96973 L .6119 .96654 L p F P
0 g
s
.661 .675 .853 r
.48454 .96662 m .49565 .96288 L .49867 .96745 L p F P
0 g
s
.663 .663 .84 r
.49565 .96288 m .48454 .96662 L .48151 .96188 L p F P
0 g
s
.717 .695 .828 r
.34806 .95299 m .35123 .95797 L .34294 .96259 L p F P
0 g
s
.717 .695 .828 r
.33706 .95951 m .34806 .95299 L p .34294 .96259 L F P
0 g
s
.717 .695 .828 r
.34294 .96259 m .33893 .96219 L .33706 .95951 L p F P
0 g
s
.849 .74 .744 r
.09434 .81881 m .09876 .82146 L .09419 .82811 L p F P
0 g
s
.848 .742 .747 r
.09876 .82146 m .09434 .81881 L .09917 .81208 L p F P
0 g
s
.632 .763 .942 r
.54407 .97303 m .55529 .97013 L .55821 .97302 L p F P
0 g
s
.639 .734 .918 r
.55529 .97013 m .54407 .97303 L .54112 .96974 L p F P
0 g
s
.653 .448 .593 r
.43752 .76656 m .44801 .76542 L p .43554 .77271 L F P
0 g
s
.653 .448 .593 r
.43554 .77271 m .43539 .77081 L .43752 .76656 L p F P
0 g
s
.799 .766 .823 r
.14967 .75076 m .14377 .75594 L .14022 .75253 L p F P
0 g
s
.806 .766 .816 r
.14076 .75871 m .14377 .75594 L .14022 .75253 L p F P
0 g
s
.808 .765 .813 r
.14076 .75871 m .13263 .76635 L .12907 .76293 L p F P
0 g
s
.808 .765 .813 r
.12907 .76293 m .13651 .75594 L .14076 .75871 L p F P
0 g
s
.806 .766 .816 r
.14022 .75253 m .13651 .75594 L .14076 .75871 L p F P
0 g
s
.372 .126 .406 r
.69616 .91873 m .68634 .92332 L .68588 .92821 L p F P
0 g
s
.406 .19 .469 r
.69627 .91352 m .69616 .91873 L .68634 .92332 L p F P
0 g
s
.682 .644 .805 r
.45019 .95497 m .43913 .95984 L .43606 .95448 L p F P
0 g
s
.74 .519 .594 r
.36765 .77292 m .36334 .7725 L .36284 .7665 L p F P
0 g
s
.742 .52 .593 r
.35928 .76614 m .36284 .7665 L .36334 .7725 L p F P
0 g
s
.761 .523 .573 r
.34994 .76498 m .34615 .76441 L .34594 .75866 L p F P
0 g
s
.759 .521 .573 r
.34201 .75809 m .34594 .75866 L .34615 .76441 L p F P
0 g
s
.475 .38 .668 r
.71143 .85934 m .70936 .86056 L .71084 .86733 L p F P
0 g
s
.698 .493 .607 r
.40266 .77433 m .40844 .77428 L .40908 .78039 L p F P
0 g
s
.698 .493 .607 r
.40908 .78039 m .39999 .78046 L .40266 .77433 L p F P
0 g
s
.702 .498 .609 r
.39407 .7743 m .40266 .77433 L .39999 .78046 L p F P
0 g
s
.718 .501 .594 r
.38986 .77419 m .37905 .77371 L .3789 .77179 L p F P
0 g
s
.725 .506 .594 r
.37905 .77371 m .3789 .77179 L .37834 .77367 L closepath p F P
0 g
s
.72 .696 .827 r
.32288 .96119 m .31195 .96702 L .30869 .96293 L p F P
0 g
s
.702 .498 .609 r
.39999 .78046 m .39474 .78044 L .39407 .7743 L p F P
0 g
s
.712 .506 .608 r
.38986 .77419 m .39407 .7743 L .39474 .78044 L p F P
0 g
s
.814 .765 .807 r
.13252 .76646 m .13263 .76635 L .12907 .76293 L p F P
0 g
s
.814 .765 .807 r
.12907 .76293 m .12829 .76369 L .13252 .76646 L p F P
0 g
s
.818 .763 .801 r
.12829 .76369 m .13252 .76646 L .12514 .77394 L p F P
0 g
s
.685 .484 .609 r
.40844 .77428 m .41722 .77395 L .41416 .7802 L p F P
0 g
s
.685 .484 .609 r
.41416 .7802 m .40908 .78039 L .40844 .77428 L p F P
0 g
s
.871 .702 .671 r
.09072 .86749 m .09209 .86437 L .08866 .85911 L p F P
0 g
s
.799 .766 .823 r
.14022 .75253 m .14539 .74799 L .14967 .75076 L p F P
0 g
s
.797 .767 .826 r
.15131 .7429 m .14539 .74799 L .14967 .75076 L p F P
0 g
s
.797 .767 .826 r
.14967 .75076 m .15484 .74631 L .15131 .7429 L p F P
0 g
s
.798 .37 .232 r
.2954 .73232 m .28993 .73034 L .29318 .72876 L closepath p F P
0 g
s
.786 .37 .262 r
.3019 .73437 m .2954 .73232 L .29318 .72876 L p F P
0 g
s
.837 .453 .324 r
.13031 .93889 m .13031 .93888 L .13031 .93888 L closepath p F P
0 g
s
.812 .381 .219 r
.13869 .94572 m .13315 .94358 L .13031 .93889 L p F P
0 g
s
.804 .358 .184 r
.13031 .93888 m .13031 .93889 L .13315 .94358 L p F P
0 g
s
.804 .358 .184 r
.1264 .93956 m .13031 .93888 L p .13315 .94358 L F P
0 g
s
.838 .431 .272 r
.1264 .93956 m .12502 .93667 L .13031 .93888 L closepath p F P
0 g
s
.781 .492 .498 r
.32598 .74965 m .31823 .748 L .31769 .74288 L p F P
0 g
s
.801 .511 .498 r
.3107 .74099 m .31769 .74288 L .31823 .748 L p F P
0 g
s
.798 .471 .434 r
.31769 .74288 m .3107 .74099 L .31023 .73922 L p F P
0 g
s
.468 .178 .389 r
.49568 .73955 m .49652 .73504 L .50748 .73159 L p F P
0 g
s
.399 .048 .25 r
.50818 .72969 m .50748 .73159 L .49652 .73504 L p F P
0 g
s
.496 .201 .396 r
.49652 .73504 m .49568 .73955 L .48437 .74261 L p F P
0 g
s
.712 .506 .608 r
.39474 .78044 m .38743 .78025 L .38986 .77419 L p F P
0 g
s
.719 .514 .611 r
.37905 .77371 m .38986 .77419 L .38743 .78025 L p F P
0 g
s
.651 .702 .884 r
.52398 .96502 m .52615 .96799 L .51422 .97016 L p F P
0 g
s
.651 .702 .884 r
.51422 .97016 m .51281 .96831 L .52398 .96502 L p F P
0 g
s
.864 .714 .694 r
.08738 .85 m .09197 .85256 L .08879 .85883 L p F P
0 g
s
.862 .718 .702 r
.09197 .85256 m .08738 .85 L .09087 .84365 L p F P
0 g
s
.789 .767 .833 r
.15945 .74255 m .15484 .74631 L .15131 .7429 L p F P
0 g
s
.748 .77 .871 r
.20208 .71845 m .19122 .72516 L .18773 .7218 L p F P
0 g
s
.877 .683 .637 r
.08837 .87353 m .09306 .87602 L .09106 .88197 L p F P
0 g
s
.873 .692 .654 r
.09306 .87602 m .08837 .87353 L .09072 .86749 L p F P
0 g
s
.127 .63 .904 r
.19078 .9662 m .18171 .96516 L .17809 .96375 L p F P
0 g
s
.195 .651 .943 r
.19396 .9673 m .19078 .9662 L .18171 .96516 L p F P
0 g
s
.62 .795 .966 r
.55821 .97302 m .56946 .97018 L .57235 .97259 L p F P
0 g
s
.631 .761 .941 r
.56946 .97018 m .55821 .97302 L .55529 .97013 L p F P
0 g
s
.561 .869 .995 r
.59971 .96942 m .59778 .9686 L .58648 .97157 L p F P
0 g
s
.596 .839 .99 r
.59778 .9686 m .58648 .97157 L .58363 .96973 L p F P
0 g
s
.597 .834 .989 r
.57235 .97259 m .58363 .96973 L .58648 .97157 L p F P
0 g
s
.713 .693 .83 r
.33893 .96219 m .33706 .95951 L .33308 .96168 L closepath p F P
0 g
s
.742 .52 .593 r
.36334 .7725 m .35771 .77193 L .35928 .76614 L p F P
0 g
s
.754 .529 .591 r
.34994 .76498 m .35928 .76614 L .35771 .77193 L p F P
0 g
s
.719 .71 .841 r
.30869 .96293 m .29778 .96854 L .2945 .96468 L p F P
0 g
s
.535 .284 .483 r
.484 .74762 m .48437 .74261 L .49568 .73955 L p F P
0 g
s
.559 .304 .485 r
.48437 .74261 m .484 .74762 L .4723 .75026 L p F P
0 g
s
.643 .735 .915 r
.56169 .71455 m .57295 .71133 L .57585 .71482 L p F P
0 g
s
.654 .767 .932 r
.57295 .71133 m .56169 .71455 L .55879 .71182 L p F P
0 g
s
.658 .792 .946 r
.54756 .71555 m .55879 .71182 L .56169 .71455 L p F P
0 g
s
.617 .772 .954 r
.2271 .97252 m .23776 .96987 L .24119 .97259 L p F P
0 g
s
.64 .768 .94 r
.23776 .96987 m .2271 .97252 L .22363 .97011 L p F P
0 g
s
.683 .482 .608 r
.41722 .77395 m .42225 .77374 L .42289 .77984 L p F P
0 g
s
.683 .482 .608 r
.42289 .77984 m .41416 .7802 L .41722 .77395 L p F P
0 g
s
.549 0 0 r
.16141 .95854 m .16025 .95811 L .15408 .95428 L p F P
0 g
s
.505 0 0 r
.14822 .95225 m .15408 .95428 L .16025 .95811 L p F P
0 g
s
.709 .192 0 r
.14713 .95136 m .14822 .95225 L .15408 .95428 L p F P
0 g
s
.441 .292 .582 r
.70851 .88949 m .70466 .89155 L .70531 .89749 L p F P
0 g
s
.82 .761 .797 r
.12514 .77394 m .12139 .77782 L .11781 .77435 L p F P
0 g
s
.82 .761 .797 r
.11781 .77435 m .12087 .77119 L .12514 .77394 L p F P
0 g
s
.818 .763 .801 r
.12514 .77394 m .12087 .77119 L .12829 .76369 L p F P
0 g
s
.619 .797 .967 r
.58363 .96973 m .57235 .97259 L .56946 .97018 L p F P
0 g
s
.789 .767 .833 r
.15131 .7429 m .15515 .73977 L .15945 .74255 L p F P
0 g
s
.787 .769 .836 r
.16233 .73403 m .15515 .73977 L .15945 .74255 L p F P
0 g
s
.787 .769 .836 r
.15945 .74255 m .16586 .73741 L .16233 .73403 L p F P
0 g
s
.842 .749 .76 r
.10437 .80525 m .1021 .80817 L .09852 .80449 L p F P
0 g
s
.842 .749 .76 r
.09852 .80449 m .10002 .80256 L .10437 .80525 L p F P
0 g
s
.838 .751 .768 r
.10437 .80525 m .10002 .80256 L .10568 .79559 L p F P
0 g
s
.668 .847 .969 r
.55879 .71182 m .54756 .71555 L .54464 .71398 L p F P
0 g
s
.595 .896 .988 r
.54756 .71555 m .54464 .71398 L p .5336 .71828 L F P
0 g
s
.595 .643 .868 r
.61853 .72099 m .62 .72349 L .61502 .7268 L p F P
0 g
s
.595 .643 .868 r
.60714 .72279 m .61853 .72099 L p .61502 .7268 L F P
0 g
s
.592 .631 .859 r
.6214 .72591 m .61502 .7268 L .62 .72349 L closepath p F P
0 g
s
0 .472 .775 r
.17242 .96203 m .17809 .96375 L .17446 .96214 L p F P
0 g
s
.531 .52 .788 r
.69392 .7855 m .68475 .78463 L .68336 .78119 L p F P
0 g
s
.671 .661 .832 r
.45325 .96031 m .46433 .95574 L p .46515 .96188 L F P
0 g
s
.676 .645 .811 r
.46433 .95574 m .45325 .96031 L .45019 .95497 L p F P
0 g
s
.579 .352 .536 r
.47228 .75563 m .4723 .75026 L .484 .74762 L p F P
0 g
s
.656 .683 .864 r
.49867 .96745 m .50981 .96395 L .51281 .96831 L p F P
0 g
s
.657 .668 .849 r
.50981 .96395 m .49867 .96745 L .49565 .96288 L p F P
0 g
s
.771 .53 .571 r
.3336 .75664 m .34201 .75809 L .34108 .76367 L p F P
0 g
s
.759 .521 .573 r
.34615 .76441 m .34108 .76367 L .34201 .75809 L p F P
0 g
s
.495 .431 .714 r
.71436 .83875 m .70798 .8365 L .71286 .83346 L closepath p F P
0 g
s
.504 .445 .725 r
.71129 .82822 m .71286 .83346 L .70798 .8365 L p F P
0 g
s
.504 .445 .725 r
.70827 .82731 m .71129 .82822 L p .70798 .8365 L F P
0 g
s
.452 .768 .997 r
.20396 .9698 m .20956 .96961 L .20605 .96737 L p F P
0 g
s
.452 .768 .997 r
.20605 .96737 m .19717 .96805 L .20396 .9698 L p F P
0 g
s
.313 .727 .976 r
.19557 .96812 m .19717 .96805 L .20396 .9698 L p F P
0 g
s
.668 .47 .609 r
.42225 .77374 m .43452 .77279 L .43084 .77922 L p F P
0 g
s
.668 .47 .609 r
.43084 .77922 m .42289 .77984 L .42225 .77374 L p F P
0 g
s
.367 0 0 r
.27597 .72133 m .27962 .72378 L .28568 .72599 L p F P
0 g
s
.539 0 0 r
.27962 .72378 m .27597 .72133 L .27248 .72016 L p F P
0 g
s
.57 .596 .839 r
.64238 .74236 m .64147 .74059 L .64525 .74034 L closepath p F P
0 g
s
.719 .514 .611 r
.38743 .78025 m .37977 .77991 L .37905 .77371 L p F P
0 g
s
.726 .519 .61 r
.37834 .77367 m .37905 .77371 L .37977 .77991 L p F P
0 g
s
.825 .761 .792 r
.11816 .7813 m .12139 .77782 L .11781 .77435 L p F P
0 g
s
.551 .557 .813 r
.66177 .75803 m .66231 .75764 L p .67225 .76402 L F P
0 g
s
.555 .566 .821 r
.66177 .75803 m .66159 .75765 L .66231 .75764 L closepath p F P
0 g
s
.712 .741 .875 r
.28361 .96996 m .28431 .96962 L .28306 .96937 L closepath p F P
0 g
s
.698 .736 .88 r
.28306 .96937 m .28361 .96996 L p .26945 .97117 L F P
0 g
s
.673 .666 .835 r
.46777 .96165 m .46737 .96101 L .46515 .96188 L closepath p F P
0 g
s
.671 .661 .832 r
.46433 .95574 m .46737 .96101 L .46515 .96188 L p F P
0 g
s
.726 .519 .61 r
.37977 .77991 m .37604 .77969 L .37834 .77367 L p F P
0 g
s
.734 .522 .606 r
.36765 .77292 m .37834 .77367 L .37604 .77969 L p F P
0 g
s
.87 .575 .485 r
.10666 .91658 m .10762 .91479 L p .11202 .92196 L F P
0 g
s
.877 .587 .493 r
.10666 .91658 m .10659 .91432 L .10762 .91479 L closepath p F P
0 g
s
.637 .774 .946 r
.23053 .7145 m .2412 .71131 L .24464 .7142 L p F P
0 g
s
.622 .773 .952 r
.2412 .71131 m .23053 .7145 L .22709 .71136 L p F P
0 g
s
.694 .771 .911 r
.21634 .716 m .22709 .71136 L .23053 .7145 L p F P
0 g
s
.554 .569 .824 r
.66231 .75764 m .66159 .75765 L .65872 .75162 L p F P
0 g
s
.783 .523 .543 r
.3336 .75664 m .32803 .75546 L .32824 .75008 L p F P
0 g
s
.775 .516 .543 r
.32598 .74965 m .32824 .75008 L .32803 .75546 L p F P
0 g
s
.584 .62 .854 r
.63572 .72973 m .62428 .73102 L .6214 .72591 L p F P
0 g
s
.658 .762 .927 r
.24119 .97259 m .25192 .96907 L .25531 .97209 L p F P
0 g
s
.674 .757 .913 r
.25192 .96907 m .24119 .97259 L .23776 .96987 L p F P
0 g
s
.787 .445 .409 r
.3096 .74067 m .30354 .73914 L .3019 .73437 L p F P
0 g
s
.807 .466 .412 r
.2954 .73232 m .3019 .73437 L .30354 .73914 L p F P
0 g
s
.606 .394 .567 r
.46021 .75789 m .46602 .75678 L .46281 .76308 L p F P
0 g
s
.606 .394 .567 r
.46281 .76308 m .46043 .76353 L .46021 .75789 L p F P
0 g
s
.626 .41 .57 r
.46021 .75789 m .46043 .76353 L .44801 .76542 L p F P
0 g
s
.713 .741 .873 r
.29121 .96067 m .2945 .96468 L .28431 .96962 L p F P
0 g
s
.713 .741 .873 r
.2803 .96637 m .29121 .96067 L p .28431 .96962 L F P
0 g
s
.713 .741 .873 r
.28431 .96962 m .28306 .96937 L .2803 .96637 L p F P
0 g
s
.777 .769 .845 r
.17047 .73395 m .16586 .73741 L .16233 .73403 L p F P
0 g
s
.698 .736 .88 r
.26945 .97117 m .27578 .96836 L .28306 .96937 L p F P
0 g
s
.711 .742 .876 r
.27578 .96836 m .26945 .97117 L .2661 .96788 L p F P
0 g
s
.683 .751 .903 r
.25531 .97209 m .2661 .96788 L .26945 .97117 L p F P
0 g
s
.628 .698 .896 r
.57585 .71482 m .58714 .71205 L .59003 .71605 L p F P
0 g
s
.636 .717 .906 r
.58714 .71205 m .57585 .71482 L .57295 .71133 L p F P
0 g
s
.846 .748 .756 r
.09917 .81208 m .1021 .80817 L .09852 .80449 L p F P
0 g
s
.707 .663 .804 r
.37954 .95561 m .38366 .95327 L .37806 .9531 L closepath p F P
0 g
s
.71 .663 .802 r
.37806 .9531 m .37954 .95561 L p .36539 .95666 L F P
0 g
s
.705 .656 .799 r
.39287 .95344 m .39368 .95486 L p .37954 .95561 L F P
0 g
s
.705 .656 .799 r
.37954 .95561 m .38366 .95327 L .39287 .95344 L p F P
0 g
s
.695 .743 .889 r
.2661 .96788 m .25531 .97209 L .25192 .96907 L p F P
0 g
s
.723 .695 .823 r
.32288 .96119 m .32387 .96061 L .33308 .96168 L p F P
0 g
s
.711 .685 .823 r
.33387 .95472 m .32387 .96061 L .33308 .96168 L p F P
0 g
s
.711 .685 .823 r
.33308 .96168 m .33706 .95951 L .33387 .95472 L p F P
0 g
s
.828 .759 .787 r
.11392 .77855 m .11816 .7813 L .11165 .78852 L p F P
0 g
s
.825 .761 .792 r
.11781 .77435 m .11392 .77855 L .11816 .7813 L p F P
0 g
s
.7 .651 .798 r
.40727 .95344 m .40781 .95441 L p .39368 .95486 L F P
0 g
s
.7 .651 .798 r
.39368 .95486 m .39622 .95346 L .40727 .95344 L p F P
0 g
s
.701 .656 .801 r
.39368 .95486 m .39622 .95346 L .39287 .95344 L closepath p F P
0 g
s
.807 .476 .429 r
.3107 .74099 m .3096 .74067 L .31023 .73922 L closepath p F P
0 g
s
.6 .648 .869 r
.61853 .72099 m .60714 .72279 L .60426 .71815 L p F P
0 g
s
.671 .666 .836 r
.47847 .95675 m .48053 .96023 L .46777 .96165 L p F P
0 g
s
.671 .666 .836 r
.46777 .96165 m .46737 .96101 L .47847 .95675 L p F P
0 g
s
.483 .758 .991 r
.24464 .7142 m .25519 .71321 L .25864 .71559 L p F P
0 g
s
.439 .736 .99 r
.24464 .7142 m .25519 .71321 L .2524 .71135 L p F P
0 g
s
.439 .736 .99 r
.2412 .71131 m .24464 .7142 L p .2524 .71135 L F P
0 g
s
.876 .696 .655 r
.0861 .86496 m .09072 .86749 L .08837 .87353 L p F P
0 g
s
.871 .702 .671 r
.08866 .85911 m .0861 .86496 L .09072 .86749 L p F P
0 g
s
.419 .23 .515 r
.69627 .91352 m .69845 .91244 L .69884 .90669 L p F P
0 g
s
.414 .225 .514 r
.70574 .9032 m .69884 .90669 L .69845 .91244 L p F P
0 g
s
.436 .267 .552 r
.69884 .90669 m .70574 .9032 L .70531 .89749 L p F P
0 g
s
.531 .52 .788 r
.68336 .78119 m .68788 .778 L p .69392 .7855 L F P
0 g
s
.535 .53 .796 r
.68336 .78119 m .68184 .77757 L .68788 .778 L closepath p F P
0 g
s
.319 .672 .976 r
.25864 .71559 m .2613 .71601 L .26668 .71845 L p F P
0 g
s
.71 .663 .802 r
.36539 .95666 m .37191 .95286 L .37806 .9531 L p F P
0 g
s
.713 .671 .808 r
.36539 .95666 m .37191 .95286 L .36276 .95235 L closepath p F P
0 g
s
.714 .67 .806 r
.36276 .95235 m .36539 .95666 L p .35123 .95797 L F P
0 g
s
.563 .874 .994 r
.59778 .9686 m .59971 .96942 L .61054 .9661 L p F P
0 g
s
.549 .882 .989 r
.6119 .96654 m .61054 .9661 L .59971 .96942 L p F P
0 g
s
.665 .457 .593 r
.43554 .77271 m .43539 .77081 L .43452 .77279 L closepath p F P
0 g
s
.551 .557 .813 r
.66231 .75764 m .67317 .75775 L p .67225 .76402 L F P
0 g
s
.549 .558 .816 r
.67317 .75775 m .66231 .75764 L .67044 .75179 L closepath p F P
0 g
s
.554 .569 .824 r
.67029 .75147 m .67044 .75179 L .66231 .75764 L p F P
0 g
s
.554 .569 .824 r
.65872 .75162 m .67029 .75147 L p .66231 .75764 L F P
0 g
s
.694 .647 .799 r
.42131 .95315 m .42193 .95429 L p .40781 .95441 L F P
0 g
s
.694 .647 .799 r
.40781 .95441 m .40974 .9534 L .42131 .95315 L p F P
0 g
s
.695 .65 .8 r
.40781 .95441 m .40974 .9534 L .40727 .95344 L closepath p F P
0 g
s
.689 .773 .915 r
.22709 .71136 m .21634 .716 L .21288 .71275 L p F P
0 g
s
.697 .737 .881 r
.28306 .96937 m .2803 .96637 L .27578 .96836 L closepath p F P
0 g
s
.63 .428 .591 r
.44801 .76542 m .46043 .76353 L p .45805 .76982 L F P
0 g
s
.63 .428 .591 r
.45805 .76982 m .44845 .77129 L .44801 .76542 L p F P
0 g
s
.653 .448 .593 r
.44801 .76542 m .44845 .77129 L .43554 .77271 L p F P
0 g
s
.856 .735 .729 r
.09392 .82854 m .09419 .82811 L .09282 .8273 L closepath p F P
0 g
s
.849 .74 .744 r
.09035 .82463 m .09434 .81881 L p .09419 .82811 L F P
0 g
s
.849 .74 .744 r
.09419 .82811 m .09282 .8273 L .09035 .82463 L p F P
0 g
s
.467 .362 .652 r
.71084 .86733 m .71777 .86326 L p .71237 .87378 L F P
0 g
s
.467 .362 .652 r
.71237 .87378 m .71208 .87357 L .71084 .86733 L p F P
0 g
s
.475 .38 .668 r
.71084 .86733 m .71777 .86326 L .71143 .85934 L p F P
0 g
s
.577 .926 .954 r
.53344 .71826 m .53468 .71776 L .5336 .71828 L closepath p F P
0 g
s
.595 .896 .988 r
.54464 .71398 m .53468 .71776 L .5336 .71828 L p F P
0 g
s
.775 .516 .543 r
.32803 .75546 m .32573 .75502 L .32598 .74965 L p F P
0 g
s
.785 .523 .542 r
.31823 .748 m .32598 .74965 L .32573 .75502 L p F P
0 g
s
.777 .769 .845 r
.16233 .73403 m .16614 .73117 L .17047 .73395 L p F P
0 g
s
.776 .77 .847 r
.1733 .72588 m .16614 .73117 L .17047 .73395 L p F P
0 g
s
.776 .77 .847 r
.17047 .73395 m .17682 .72924 L .1733 .72588 L p F P
0 g
s
.57 .599 .843 r
.64525 .74034 m .64147 .74059 L .63859 .73513 L p F P
0 g
s
.67 .644 .815 r
.47847 .95675 m .46737 .96101 L .46433 .95574 L p F P
0 g
s
.75 .248 .025 r
.13315 .94358 m .13869 .94572 L .14255 .95016 L p F P
0 g
s
.76 .267 .056 r
.14513 .95117 m .14255 .95016 L .13869 .94572 L p F P
0 g
s
.881 .589 .489 r
.10659 .91432 m .10666 .91658 L .10519 .91896 L p F P
0 g
s
.881 .589 .489 r
.10162 .91197 m .10659 .91432 L p .10519 .91896 L F P
0 g
s
.879 .613 .531 r
.10659 .91432 m .10162 .91197 L .10195 .90645 L p F P
0 g
s
.859 .734 .724 r
.09014 .83462 m .09392 .82854 L .09282 .8273 L p F P
0 g
s
.714 .67 .806 r
.35123 .95797 m .36095 .95225 L .36276 .95235 L p F P
0 g
s
.719 .666 .797 r
.36095 .95225 m .35123 .95797 L .34806 .95299 L p F P
0 g
s
.882 .616 .53 r
.09703 .90407 m .10195 .90645 L .10162 .91197 L p F P
0 g
s
.88 .635 .564 r
.10195 .90645 m .09703 .90407 L .09783 .89843 L p F P
0 g
s
.652 .677 .861 r
.52398 .96502 m .51281 .96831 L .50981 .96395 L p F P
0 g
s
.473 .38 .67 r
.71857 .85508 m .71143 .85934 L .71777 .86326 L p F P
0 g
s
.484 .4 .685 r
.71752 .85077 m .71857 .85508 L .71143 .85934 L p F P
0 g
s
.484 .4 .685 r
.71476 .84936 m .71752 .85077 L p .71143 .85934 L F P
0 g
s
.748 .288 .157 r
.28993 .73034 m .28928 .73014 L .28568 .72599 L p F P
0 g
s
.77 .325 .193 r
.27962 .72378 m .28568 .72599 L .28928 .73014 L p F P
0 g
s
.864 .722 .704 r
.08637 .84105 m .09087 .84365 L .08738 .85 L p F P
0 g
s
.861 .727 .714 r
.09087 .84365 m .08637 .84105 L .09014 .83462 L p F P
0 g
s
.7 .651 .798 r
.40727 .95344 m .40471 .94879 L .39622 .95346 L closepath p F P
0 g
s
.702 .655 .8 r
.40163 .94296 m .40471 .94879 L .39622 .95346 L p F P
0 g
s
.702 .655 .8 r
.40154 .94296 m .40163 .94296 L p .39622 .95346 L F P
0 g
s
.702 .655 .8 r
.39056 .94934 m .40154 .94296 L p .39622 .95346 L F P
0 g
s
.702 .655 .8 r
.39622 .95346 m .39287 .95344 L .39056 .94934 L p F P
0 g
s
.695 .649 .8 r
.40974 .9534 m .40727 .95344 L .40471 .94879 L p F P
0 g
s
.688 .645 .801 r
.43503 .95257 m .43606 .95448 L p .42193 .95429 L F P
0 g
s
.688 .645 .801 r
.42193 .95429 m .4245 .95301 L .43503 .95257 L p F P
0 g
s
.688 .645 .801 r
.42193 .95429 m .4245 .95301 L .42131 .95315 L closepath p F P
0 g
s
.705 .656 .799 r
.39287 .95344 m .39056 .94934 L .38366 .95327 L closepath p F P
0 g
s
.532 .923 .869 r
.53468 .71776 m .53344 .71826 L .53052 .71936 L p F P
0 g
s
.532 .923 .869 r
.53052 .71936 m .54173 .71398 L .54364 .71377 L p F P
0 g
s
.016 0 0 r
.53052 .71936 m .54173 .71398 L p .53503 .71736 L F P
0 g
s
0 0 0 r
.53344 .71826 m .53052 .71936 L p .52086 .72364 L F P
0 g
s
.532 .923 .869 r
.54364 .71377 m .53468 .71776 L p .53052 .71936 L F P
0 g
s
.016 0 0 r
.53002 .71989 m .53052 .71936 L p .53503 .71736 L F P
0 g
s
0 0 0 r
.51974 .72412 m .52086 .72364 L .53052 .71936 L F
.694 .647 .798 r
.42131 .95315 m .41885 .9486 L .40974 .9534 L closepath p F P
0 g
s
.695 .649 .8 r
.41582 .94277 m .41885 .9486 L .40974 .9534 L p F P
0 g
s
.695 .649 .8 r
.41555 .94278 m .41582 .94277 L p .40974 .9534 L F P
0 g
s
.695 .649 .8 r
.40471 .94879 m .41555 .94278 L p .40974 .9534 L F P
0 g
s
.734 .522 .606 r
.37604 .77969 m .36558 .77886 L .36765 .77292 L p F P
0 g
s
.74 .529 .608 r
.36334 .7725 m .36765 .77292 L .36558 .77886 L p F P
0 g
s
.883 .638 .564 r
.09298 .89602 m .09783 .89843 L .09703 .90407 L p F P
0 g
s
.879 .653 .592 r
.09783 .89843 m .09298 .89602 L .09421 .89027 L p F P
0 g
s
.868 .539 .425 r
.10682 .91969 m .11202 .92196 L .11293 .92716 L p F P
0 g
s
.87 .575 .485 r
.11202 .92196 m .10682 .91969 L .10666 .91658 L p F P
0 g
s
.866 .538 .429 r
.11817 .92941 m .11293 .92716 L .11202 .92196 L p F P
0 g
s
.323 0 0 r
.16632 .96008 m .16141 .95854 L .16434 .95933 L closepath p F P
0 g
s
.85 .746 .748 r
.09484 .80939 m .09917 .81208 L .09434 .81881 L p F P
0 g
s
.846 .748 .756 r
.09852 .80449 m .09484 .80939 L .09917 .81208 L p F P
0 g
s
.832 .757 .78 r
.11165 .78852 m .11004 .79038 L .10645 .78685 L p F P
0 g
s
.832 .757 .78 r
.10645 .78685 m .10737 .78579 L .11165 .78852 L p F P
0 g
s
.828 .759 .787 r
.11165 .78852 m .10737 .78579 L .11392 .77855 L p F P
0 g
s
.754 .529 .591 r
.35771 .77193 m .34851 .77073 L .34994 .76498 L p F P
0 g
s
.761 .537 .593 r
.34615 .76441 m .34994 .76498 L .34851 .77073 L p F P
0 g
s
.708 .662 .803 r
.38745 .94358 m .39056 .94934 L .38366 .95327 L p F P
0 g
s
.708 .662 .803 r
.37641 .95025 m .38745 .94358 L p .38366 .95327 L F P
0 g
s
.708 .662 .803 r
.38366 .95327 m .37806 .9531 L .37641 .95025 L p F P
0 g
s
.192 0 .035 r
.6626 .94739 m .67254 .94173 L .66363 .9454 L closepath p F P
0 g
s
.26 0 .181 r
.6739 .94086 m .67254 .94173 L .66363 .9454 L p F P
0 g
s
.26 0 .181 r
.67508 .93713 m .6739 .94086 L p .66363 .9454 L F P
0 g
s
.169 0 0 r
.6626 .94739 m .66363 .9454 L p .65137 .95289 L F P
0 g
s
.721 .672 .801 r
.34806 .95299 m .33706 .95951 L .33387 .95472 L p F P
0 g
s
.668 .471 .609 r
.43452 .77279 m .43554 .77271 L .4362 .77881 L p F P
0 g
s
.668 .471 .609 r
.4362 .77881 m .43084 .77922 L .43452 .77279 L p F P
0 g
s
.24 0 .037 r
.51974 .72412 m .51933 .72473 L .50818 .72969 L p F P
0 g
s
.361 .009 .226 r
.50748 .73159 m .50818 .72969 L .51933 .72473 L p F P
0 g
s
.535 .531 .797 r
.68788 .778 m .68184 .77757 L .67942 .7718 L p F P
0 g
s
.654 .461 .61 r
.4362 .77881 m .43554 .77271 L .44845 .77129 L p F P
0 g
s
.689 .644 .8 r
.4245 .95301 m .42131 .95315 L .41885 .9486 L p F P
0 g
s
.574 .919 .964 r
.53468 .71776 m .54364 .71377 L .54464 .71398 L closepath p F P
0 g
s
.837 .757 .775 r
.10568 .79559 m .11004 .79038 L .10645 .78685 L p F P
0 g
s
.71 .663 .802 r
.37806 .9531 m .37641 .95025 L .37191 .95286 L closepath p F P
0 g
s
.699 .502 .618 r
.39999 .78046 m .40908 .78039 L .40988 .78665 L p F P
0 g
s
.699 .502 .618 r
.40988 .78665 m .39682 .78674 L .39999 .78046 L p F P
0 g
s
.703 .507 .62 r
.39474 .78044 m .39999 .78046 L .39682 .78674 L p F P
0 g
s
.764 .77 .858 r
.18335 .72476 m .17682 .72924 L .1733 .72588 L p F P
0 g
s
.703 .507 .62 r
.39682 .78674 m .39557 .78674 L .39474 .78044 L p F P
0 g
s
.713 .514 .619 r
.38743 .78025 m .39474 .78044 L .39557 .78674 L p F P
0 g
s
.682 .644 .805 r
.44842 .9517 m .45019 .95497 L p .43606 .95448 L F P
0 g
s
.682 .644 .805 r
.43606 .95448 m .44104 .95217 L .44842 .9517 L p F P
0 g
s
.682 .642 .803 r
.43606 .95448 m .44104 .95217 L .43503 .95257 L closepath p F P
0 g
s
.674 .135 0 r
.14822 .95225 m .14513 .95117 L .14713 .95136 L closepath p F P
0 g
s
.248 .749 .691 r
.63778 .95912 m .63732 .9593 L .62598 .96314 L p F P
0 g
s
.354 .829 .826 r
.63732 .9593 m .62598 .96314 L .62325 .96317 L p F P
0 g
s
.389 .849 .874 r
.6119 .96654 m .62325 .96317 L .62598 .96314 L p F P
0 g
s
.878 .669 .616 r
.09421 .89027 m .08943 .88783 L .09106 .88197 L p F P
0 g
s
.882 .657 .592 r
.08943 .88783 m .09421 .89027 L .09298 .89602 L p F P
0 g
s
.687 .493 .619 r
.40908 .78039 m .41416 .7802 L .41052 .78663 L p F P
0 g
s
.687 .493 .619 r
.41052 .78663 m .40988 .78665 L .40908 .78039 L p F P
0 g
s
.62 .686 .89 r
.60137 .71367 m .59003 .71605 L .58714 .71205 L p F P
0 g
s
.689 .644 .8 r
.43503 .95257 m .43299 .94878 L .4245 .95301 L closepath p F P
0 g
s
.689 .644 .8 r
.42992 .9428 m .43299 .94878 L .4245 .95301 L p F P
0 g
s
.689 .644 .8 r
.41885 .9486 m .42992 .9428 L p .4245 .95301 L F P
0 g
s
.722 .767 .888 r
.20464 .71709 m .20208 .71845 L .1986 .71512 L p F P
0 g
s
.748 .77 .871 r
.18773 .7218 m .1986 .71512 L .20208 .71845 L p F P
0 g
s
.871 .706 .675 r
.08866 .85911 m .08879 .85883 L .08827 .85854 L closepath p F P
0 g
s
.864 .714 .694 r
.08517 .85438 m .08738 .85 L p .08879 .85883 L F P
0 g
s
.864 .714 .694 r
.08879 .85883 m .08827 .85854 L .08517 .85438 L p F P
0 g
s
.74 .529 .608 r
.36558 .77886 m .36405 .77872 L .36334 .7725 L p F P
0 g
s
.743 .531 .608 r
.35771 .77193 m .36334 .7725 L .36405 .77872 L p F P
0 g
s
.856 .489 .355 r
.12502 .93667 m .11977 .93443 L .11817 .92941 L p F P
0 g
s
.858 .488 .348 r
.11293 .92716 m .11817 .92941 L .11977 .93443 L p F P
0 g
s
.61 .399 .57 r
.46602 .75678 m .47228 .75563 L .47254 .76129 L p F P
0 g
s
.61 .399 .57 r
.47254 .76129 m .46281 .76308 L .46602 .75678 L p F P
0 g
s
.399 .757 .994 r
.19717 .96805 m .19396 .9673 L .19557 .96812 L closepath p F P
0 g
s
.663 .663 .84 r
.49298 .95853 m .49565 .96288 L p .48151 .96188 L F P
0 g
s
.663 .663 .84 r
.48151 .96188 m .4899 .95892 L .49298 .95853 L p F P
0 g
s
.661 .653 .831 r
.48151 .96188 m .4899 .95892 L .48053 .96023 L closepath p F P
0 g
s
.874 .706 .67 r
.0861 .86496 m .08866 .85911 L .08827 .85854 L p F P
0 g
s
.724 .699 .826 r
.32288 .96119 m .32387 .96061 L .32232 .9604 L closepath p F P
0 g
s
.72 .696 .827 r
.32232 .9604 m .32288 .96119 L p .30869 .96293 L F P
0 g
s
.713 .514 .619 r
.39557 .78674 m .38455 .78645 L .38743 .78025 L p F P
0 g
s
.72 .522 .622 r
.37977 .77991 m .38743 .78025 L .38455 .78645 L p F P
0 g
s
.078 0 0 r
.65128 .95299 m .65223 .95256 L .65137 .95289 L closepath p F P
0 g
s
.169 0 0 r
.65137 .95289 m .65223 .95256 L .6626 .94739 L p F P
0 g
s
.223 .625 .955 r
.2613 .71601 m .25864 .71559 L .25519 .71321 L p F P
0 g
s
.812 .52 .495 r
.3096 .74067 m .3107 .74099 L .31113 .74614 L p F P
0 g
s
.801 .511 .498 r
.31823 .748 m .31113 .74614 L .3107 .74099 L p F P
0 g
s
.5 .445 .726 r
.71129 .82822 m .70827 .82731 L .71057 .82585 L closepath p F P
0 g
s
.509 .459 .736 r
.70826 .81858 m .71057 .82585 L .70827 .82731 L p F P
0 g
s
.509 .459 .736 r
.70751 .81838 m .70826 .81858 L p .70827 .82731 L F P
0 g
s
.645 .713 .898 r
.52696 .9691 m .53816 .96601 L .54112 .96974 L p F P
0 g
s
.645 .694 .881 r
.53786 .96558 m .53816 .96601 L .52696 .9691 L p F P
0 g
s
.645 .694 .881 r
.52696 .9691 m .52615 .96799 L .53786 .96558 L p F P
0 g
s
.713 .67 .806 r
.37328 .94463 m .37641 .95025 L .37191 .95286 L p F P
0 g
s
.713 .67 .806 r
.36224 .95149 m .37328 .94463 L p .37191 .95286 L F P
0 g
s
.713 .67 .806 r
.37191 .95286 m .36276 .95235 L .36224 .95149 L p F P
0 g
s
.859 .734 .724 r
.09282 .8273 m .08979 .82547 L p .09014 .83462 L F P
0 g
s
.855 .739 .736 r
.09282 .8273 m .09035 .82463 L .08979 .82547 L closepath p F P
0 g
s
.685 .491 .618 r
.41416 .7802 m .42289 .77984 L .42368 .78608 L p F P
0 g
s
.685 .491 .618 r
.42368 .78608 m .41052 .78663 L .41416 .7802 L p F P
0 g
s
.272 0 .201 r
.6739 .94086 m .68446 .93302 L .67508 .93713 L closepath p F P
0 g
s
.331 .036 .304 r
.68513 .93241 m .68588 .92821 L p .67508 .93713 L F P
0 g
s
.331 .036 .304 r
.67508 .93713 m .68446 .93302 L .68513 .93241 L p F P
0 g
s
.771 .53 .571 r
.34108 .76367 m .33275 .7622 L .3336 .75664 L p F P
0 g
s
.783 .543 .573 r
.32803 .75546 m .3336 .75664 L .33275 .7622 L p F P
0 g
s
.392 .18 .468 r
.69845 .91244 m .69627 .91352 L .69616 .91873 L p F P
0 g
s
.761 .537 .593 r
.34851 .77073 m .34667 .77045 L .34615 .76441 L p F P
0 g
s
.76 .535 .593 r
.34108 .76367 m .34615 .76441 L .34667 .77045 L p F P
0 g
s
.725 .699 .825 r
.33067 .94978 m .33387 .95472 L .32387 .96061 L p F P
0 g
s
.725 .699 .825 r
.31966 .95664 m .33067 .94978 L p .32387 .96061 L F P
0 g
s
.725 .699 .825 r
.32387 .96061 m .32232 .9604 L .31966 .95664 L p F P
0 g
s
.02 0 0 r
.65223 .95256 m .65128 .95299 L .64868 .95506 L p F P
0 g
s
0 0 0 r
.65128 .95299 m .64868 .95506 L p .63778 .95912 L F P
0 g
s
.874 .706 .67 r
.08827 .85854 m .08425 .85626 L p .0861 .86496 L F P
0 g
s
.87 .714 .686 r
.08827 .85854 m .08517 .85438 L .08425 .85626 L closepath p F P
0 g
s
.711 .742 .876 r
.2661 .96788 m .26826 .96683 L .27578 .96836 L p F P
0 g
s
.696 .729 .875 r
.27698 .96262 m .26826 .96683 L .27578 .96836 L p F P
0 g
s
.696 .729 .875 r
.27578 .96836 m .2803 .96637 L .27698 .96262 L p F P
0 g
s
.881 .673 .617 r
.08636 .87949 m .09106 .88197 L .08943 .88783 L p F P
0 g
s
.877 .683 .637 r
.09106 .88197 m .08636 .87949 L .08837 .87353 L p F P
0 g
s
.727 .527 .621 r
.37604 .77969 m .37977 .77991 L .38066 .78628 L p F P
0 g
s
.72 .522 .622 r
.38455 .78645 m .38066 .78628 L .37977 .77991 L p F P
0 g
s
.553 .57 .825 r
.66741 .74548 m .67029 .75147 L .65872 .75162 L p F P
0 g
s
.553 .57 .825 r
.65919 .74557 m .66741 .74548 L p .65872 .75162 L F P
0 g
s
.553 .57 .825 r
.65872 .75162 m .6567 .74741 L .65919 .74557 L p F P
0 g
s
.812 .52 .495 r
.31113 .74614 m .30869 .74543 L .3096 .74067 L p F P
0 g
s
.797 .504 .492 r
.30354 .73914 m .3096 .74067 L .30869 .74543 L p F P
0 g
s
.682 .641 .802 r
.44104 .95217 m .43503 .95257 L .43299 .94878 L p F P
0 g
s
.84 .755 .77 r
.10143 .79285 m .10568 .79559 L .10002 .80256 L p F P
0 g
s
.837 .757 .775 r
.10645 .78685 m .10143 .79285 L .10568 .79559 L p F P
0 g
s
.676 .645 .811 r
.46147 .95052 m .46433 .95574 L p .45019 .95497 L F P
0 g
s
.676 .645 .811 r
.45019 .95497 m .46024 .95063 L .46147 .95052 L p F P
0 g
s
.675 .64 .807 r
.45019 .95497 m .46024 .95063 L .44842 .9517 L closepath p F P
0 g
s
.02 0 0 r
.66158 .94883 m .65223 .95256 L p .64868 .95506 L F P
0 g
s
.119 0 0 r
.65223 .95256 m .66158 .94883 L .6626 .94739 L closepath p F P
0 g
s
.722 .767 .888 r
.1986 .71512 m .19995 .71442 L .20464 .71709 L p F P
0 g
s
.725 .772 .89 r
.20941 .70951 m .19995 .71442 L .20464 .71709 L p F P
0 g
s
.725 .772 .89 r
.20464 .71709 m .21288 .71275 L .20941 .70951 L p F P
0 g
s
.719 .697 .828 r
.32232 .9604 m .31966 .95664 L .31457 .95955 L closepath p F P
0 g
s
.72 .696 .827 r
.30869 .96293 m .31457 .95955 L .32232 .9604 L p F P
0 g
s
.874 .577 .483 r
.10682 .91969 m .10519 .91896 L .10666 .91658 L closepath p F P
0 g
s
.67 .48 .62 r
.42289 .77984 m .43084 .77922 L .42645 .78587 L p F P
0 g
s
.67 .48 .62 r
.42645 .78587 m .42368 .78608 L .42289 .77984 L p F P
0 g
s
.73 .702 .824 r
.31457 .95955 m .30869 .96293 L .30544 .95867 L p F P
0 g
s
.719 .71 .841 r
.2945 .96468 m .30544 .95867 L .30869 .96293 L p F P
0 g
s
.467 .362 .652 r
.71215 .87391 m .71208 .87357 L .71237 .87378 L closepath p F P
0 g
s
.743 .531 .608 r
.36405 .77872 m .35569 .77787 L .35771 .77193 L p F P
0 g
s
.756 .545 .61 r
.34851 .77073 m .35771 .77193 L .35569 .77787 L p F P
0 g
s
.423 .257 .551 r
.71091 .8945 m .70531 .89749 L .70574 .9032 L p F P
0 g
s
.441 .292 .582 r
.70531 .89749 m .71091 .8945 L .70851 .88949 L p F P
0 g
s
.545 .547 .808 r
.67606 .76413 m .67225 .76402 L .67512 .76201 L closepath p F P
0 g
s
.551 .557 .813 r
.67317 .75775 m .67512 .76201 L .67225 .76402 L p F P
0 g
s
.454 .336 .63 r
.71237 .87378 m .71215 .87391 L .71323 .88027 L p F P
0 g
s
.764 .77 .858 r
.1733 .72588 m .17903 .72197 L .18335 .72476 L p F P
0 g
s
.763 .772 .86 r
.18423 .71848 m .17903 .72197 L .18335 .72476 L p F P
0 g
s
.763 .772 .86 r
.18335 .72476 m .18773 .7218 L .18423 .71848 L p F P
0 g
s
.727 .527 .621 r
.38066 .78628 m .37333 .78584 L .37604 .77969 L p F P
0 g
s
.736 .537 .624 r
.36558 .77886 m .37604 .77969 L .37333 .78584 L p F P
0 g
s
.661 .652 .83 r
.4899 .95892 m .48053 .96023 L .47847 .95675 L p F P
0 g
s
.836 .419 .247 r
.12502 .93667 m .1264 .93956 L .12338 .93975 L p F P
0 g
s
.836 .419 .247 r
.11977 .93443 m .12502 .93667 L p .12338 .93975 L F P
0 g
s
.863 .731 .715 r
.08574 .83198 m .09014 .83462 L .08637 .84105 L p F P
0 g
s
.859 .734 .724 r
.08979 .82547 m .08574 .83198 L .09014 .83462 L p F P
0 g
s
.43 .765 .996 r
.19717 .96805 m .20605 .96737 L p .19201 .96626 L F P
0 g
s
.43 .765 .996 r
.19201 .96626 m .19396 .9673 L .19717 .96805 L p F P
0 g
s
.713 .67 .806 r
.36276 .95235 m .36224 .95149 L .36095 .95225 L closepath p F P
0 g
s
.535 .531 .797 r
.67942 .7718 m .6808 .77081 L p .68788 .778 L F P
0 g
s
.539 .541 .805 r
.67942 .7718 m .67894 .77071 L .6808 .77081 L closepath p F P
0 g
s
.639 .734 .918 r
.54112 .96974 m .55236 .96678 L .55529 .97013 L p F P
0 g
s
.642 .71 .896 r
.55236 .96678 m .54112 .96974 L .53816 .96601 L p F P
0 g
s
.705 .637 .778 r
.40154 .94296 m .39056 .94934 L .38745 .94358 L p F P
0 g
s
.647 .694 .88 r
.53519 .96183 m .53786 .96558 L .52615 .96799 L p F P
0 g
s
.647 .694 .88 r
.52615 .96799 m .52398 .96502 L .53519 .96183 L p F P
0 g
s
.453 .32 .609 r
.70851 .88949 m .71412 .88644 L .71323 .88027 L p F P
0 g
s
.438 .29 .583 r
.71412 .88644 m .70851 .88949 L .71091 .8945 L p F P
0 g
s
.565 .588 .835 r
.65297 .73993 m .64525 .74034 L .65106 .73616 L closepath p F P
0 g
s
.57 .599 .843 r
.65009 .7343 m .65106 .73616 L .64525 .74034 L p F P
0 g
s
.57 .599 .843 r
.63859 .73513 m .65009 .7343 L p .64525 .74034 L F P
0 g
s
.454 .336 .63 r
.71323 .88027 m .71674 .87825 L .71237 .87378 L p F P
0 g
s
.452 .336 .631 r
.72141 .86849 m .71237 .87378 L .71674 .87825 L p F P
0 g
s
.467 .362 .652 r
.72084 .86565 m .72141 .86849 L .71237 .87378 L p F P
0 g
s
.467 .362 .652 r
.71777 .86326 m .72084 .86565 L p .71237 .87378 L F P
0 g
s
.853 .743 .741 r
.09434 .81881 m .09035 .82463 L .08675 .82086 L p F P
0 g
s
.853 .743 .741 r
.08675 .82086 m .09 .81613 L .09434 .81881 L p F P
0 g
s
.85 .746 .748 r
.09434 .81881 m .09 .81613 L .09484 .80939 L p F P
0 g
s
.711 .643 .779 r
.38745 .94358 m .37641 .95025 L .37328 .94463 L p F P
0 g
s
.505 0 0 r
.16025 .95811 m .15469 .956 L .14822 .95225 L p F P
0 g
s
.45 0 0 r
.14513 .95117 m .14822 .95225 L .15469 .956 L p F P
0 g
s
.719 .666 .797 r
.34806 .95299 m .35039 .95152 L .36095 .95225 L p F P
0 g
s
.71 .661 .8 r
.35909 .94604 m .35039 .95152 L .36095 .95225 L p F P
0 g
s
.71 .661 .8 r
.36095 .95225 m .36224 .95149 L .35909 .94604 L p F P
0 g
s
0 .395 .693 r
.16632 .96008 m .17446 .96214 L p .16065 .9583 L F P
0 g
s
0 .395 .693 r
.16065 .9583 m .16141 .95854 L .16632 .96008 L p F P
0 g
s
.657 .668 .849 r
.49565 .96288 m .5068 .95923 L .50981 .96395 L p F P
0 g
s
.658 .659 .84 r
.50529 .95666 m .5068 .95923 L .49565 .96288 L p F P
0 g
s
.658 .659 .84 r
.49565 .96288 m .49298 .95853 L .50529 .95666 L p F P
0 g
s
.698 .643 .791 r
.40471 .94879 m .41555 .94278 L .40163 .94296 L closepath p F P
0 g
s
.801 .77 .825 r
.14539 .74799 m .14022 .75253 L .13665 .74917 L p F P
0 g
s
.807 .769 .818 r
.13651 .75594 m .14022 .75253 L .13665 .74917 L p F P
0 g
s
.81 .768 .814 r
.13651 .75594 m .12907 .76293 L .12548 .75956 L p F P
0 g
s
.81 .768 .814 r
.12548 .75956 m .13234 .75313 L .13651 .75594 L p F P
0 g
s
.807 .769 .818 r
.13665 .74917 m .13234 .75313 L .13651 .75594 L p F P
0 g
s
.584 .62 .854 r
.6214 .72591 m .63285 .72459 L .63572 .72973 L p F P
0 g
s
.586 .628 .86 r
.62997 .71951 m .63285 .72459 L .6214 .72591 L p F P
0 g
s
.586 .628 .86 r
.62464 .72016 m .62997 .71951 L p .6214 .72591 L F P
0 g
s
.586 .628 .86 r
.6214 .72591 m .62 .72349 L .62464 .72016 L p F P
0 g
s
.682 .641 .802 r
.44407 .94332 m .44713 .94931 L .44104 .95217 L p F P
0 g
s
.682 .641 .802 r
.43299 .94878 m .44407 .94332 L p .44104 .95217 L F P
0 g
s
.683 .642 .803 r
.44842 .9517 m .44713 .94931 L .44104 .95217 L closepath p F P
0 g
s
.539 .542 .807 r
.6808 .77081 m .67894 .77071 L .67606 .76413 L p F P
0 g
s
.807 .466 .412 r
.30354 .73914 m .29683 .73715 L .2954 .73232 L p F P
0 g
s
.826 .489 .417 r
.28993 .73034 m .2954 .73232 L .29683 .73715 L p F P
0 g
s
.724 .701 .828 r
.30544 .95867 m .2945 .96468 L .29121 .96067 L p F P
0 g
s
.815 .768 .809 r
.12829 .76369 m .12907 .76293 L .12548 .75956 L p F P
0 g
s
.785 .523 .542 r
.32573 .75502 m .31798 .75337 L .31823 .748 L p F P
0 g
s
.802 .54 .541 r
.31113 .74614 m .31823 .748 L .31798 .75337 L p F P
0 g
s
.801 .77 .825 r
.13665 .74917 m .14121 .74518 L .14539 .74799 L p F P
0 g
s
.798 .77 .828 r
.14775 .73955 m .14121 .74518 L .14539 .74799 L p F P
0 g
s
.798 .77 .828 r
.14539 .74799 m .15131 .7429 L .14775 .73955 L p F P
0 g
s
.815 .768 .809 r
.12548 .75956 m .12414 .76088 L .12829 .76369 L p F P
0 g
s
.819 .766 .803 r
.12414 .76088 m .12829 .76369 L .12087 .77119 L p F P
0 g
s
.774 .547 .591 r
.33275 .7622 m .34108 .76367 L .33963 .76942 L p F P
0 g
s
.76 .535 .593 r
.34667 .77045 m .33963 .76942 L .34108 .76367 L p F P
0 g
s
.716 .65 .782 r
.37328 .94463 m .36224 .95149 L .35909 .94604 L p F P
0 g
s
.869 .717 .691 r
.08738 .85 m .08517 .85438 L .08165 .84983 L p F P
0 g
s
.869 .717 .691 r
.08165 .84983 m .08287 .84742 L .08738 .85 L p F P
0 g
s
.864 .722 .704 r
.08738 .85 m .08287 .84742 L .08637 .84105 L p F P
0 g
s
.581 .772 .97 r
.20956 .96961 m .22016 .96755 L .22363 .97011 L p F P
0 g
s
.61 .771 .958 r
.22016 .96755 m .20956 .96961 L .20605 .96737 L p F P
0 g
s
.88 .687 .637 r
.08374 .87101 m .08837 .87353 L .08636 .87949 L p F P
0 g
s
.876 .696 .655 r
.08837 .87353 m .08374 .87101 L .0861 .86496 L p F P
0 g
s
.55 .89 .984 r
.61054 .9661 m .6119 .96654 L .62325 .96317 L p F P
0 g
s
.691 .638 .791 r
.42966 .94228 m .42992 .9428 L .41885 .9486 L p F P
0 g
s
.691 .638 .791 r
.41885 .9486 m .41582 .94277 L .42966 .94228 L p F P
0 g
s
.79 .771 .835 r
.15515 .73977 m .15131 .7429 L .14775 .73955 L p F P
0 g
s
.612 .414 .589 r
.4606 .76577 m .46281 .76308 L .46043 .76353 L closepath p F P
0 g
s
.63 .428 .591 r
.46043 .76353 m .4606 .76577 L .45805 .76982 L p F P
0 g
s
.67 .48 .62 r
.43084 .77922 m .4362 .77881 L .43701 .78506 L p F P
0 g
s
.67 .48 .62 r
.43701 .78506 m .42645 .78587 L .43084 .77922 L p F P
0 g
s
.67 .644 .815 r
.46433 .95574 m .47544 .95128 L .47847 .95675 L p F P
0 g
s
.671 .641 .811 r
.47433 .94917 m .47544 .95128 L .46433 .95574 L p F P
0 g
s
.671 .641 .811 r
.46433 .95574 m .46147 .95052 L .47433 .94917 L p F P
0 g
s
.57 .602 .845 r
.64722 .72886 m .65009 .7343 L .63859 .73513 L p F P
0 g
s
.57 .602 .845 r
.63729 .72959 m .64722 .72886 L p .63859 .73513 L F P
0 g
s
.57 .602 .845 r
.63859 .73513 m .63612 .73046 L .63729 .72959 L p F P
0 g
s
.748 .772 .873 r
.1986 .71512 m .18773 .7218 L .18423 .71848 L p F P
0 g
s
.59 .383 .569 r
.47254 .76129 m .47228 .75563 L .48399 .75299 L p F P
0 g
s
.579 .352 .536 r
.484 .74762 m .48399 .75299 L .47228 .75563 L p F P
0 g
s
.634 .442 .606 r
.44845 .77129 m .45805 .76982 L .45246 .77682 L p F P
0 g
s
.634 .442 .606 r
.45246 .77682 m .44906 .77734 L .44845 .77129 L p F P
0 g
s
.654 .461 .61 r
.44845 .77129 m .44906 .77734 L .4362 .77881 L p F P
0 g
s
.505 .458 .738 r
.70826 .81858 m .70751 .81838 L .70808 .81802 L closepath p F P
0 g
s
.513 .471 .747 r
.70537 .80995 m .70808 .81802 L .70751 .81838 L p F P
0 g
s
.631 .761 .941 r
.55529 .97013 m .56655 .96726 L .56946 .97018 L p F P
0 g
s
.636 .732 .918 r
.56655 .96726 m .55529 .97013 L .55236 .96678 L p F P
0 g
s
0 0 0 r
.53052 .71936 m .52397 .72234 L .51974 .72412 L p F P
0 g
s
.136 0 0 r
.51933 .72473 m .52397 .72234 L .51974 .72412 L closepath p F P
0 g
s
.603 .661 .879 r
.61277 .71165 m .61565 .71626 L .60426 .71815 L p F P
0 g
s
.603 .661 .879 r
.60269 .71343 m .61277 .71165 L p .60426 .71815 L F P
0 g
s
.603 .661 .879 r
.60426 .71815 m .60167 .71413 L .60269 .71343 L p F P
0 g
s
.6 .648 .869 r
.60426 .71815 m .61565 .71626 L .61853 .72099 L p F P
0 g
s
.822 .765 .799 r
.12087 .77119 m .11781 .77435 L .11422 .77095 L p F P
0 g
s
.822 .765 .799 r
.11422 .77095 m .11668 .7684 L .12087 .77119 L p F P
0 g
s
.819 .766 .803 r
.12087 .77119 m .11668 .7684 L .12414 .76088 L p F P
0 g
s
.722 .674 .802 r
.34806 .95299 m .35039 .95152 L .34698 .95123 L closepath p F P
0 g
s
.721 .672 .801 r
.34698 .95123 m .34806 .95299 L p .33387 .95472 L F P
0 g
s
.79 .771 .835 r
.14775 .73955 m .15094 .73696 L .15515 .73977 L p F P
0 g
s
.788 .772 .838 r
.15879 .73069 m .15094 .73696 L .15515 .73977 L p F P
0 g
s
.788 .772 .838 r
.15515 .73977 m .16233 .73403 L .15879 .73069 L p F P
0 g
s
.556 .334 .534 r
.48399 .75299 m .484 .74762 L .49533 .74456 L p F P
0 g
s
.535 .284 .483 r
.49568 .73955 m .49533 .74456 L .484 .74762 L p F P
0 g
s
.722 .716 .844 r
.29121 .96067 m .2803 .96637 L .27698 .96262 L p F P
0 g
s
.783 .543 .573 r
.33275 .7622 m .32827 .76127 L .32803 .75546 L p F P
0 g
s
.777 .537 .573 r
.32573 .75502 m .32803 .75546 L .32827 .76127 L p F P
0 g
s
.325 .044 .323 r
.68513 .93241 m .69171 .92549 L .68588 .92821 L closepath p F P
0 g
s
.372 .126 .406 r
.69614 .91898 m .69616 .91873 L p .68588 .92821 L F P
0 g
s
.372 .126 .406 r
.68588 .92821 m .69171 .92549 L .69614 .91898 L p F P
0 g
s
.844 .752 .762 r
.10002 .80256 m .09852 .80449 L .09492 .80089 L p F P
0 g
s
.844 .752 .762 r
.09492 .80089 m .09574 .79984 L .10002 .80256 L p F P
0 g
s
.84 .755 .77 r
.10002 .80256 m .09574 .79984 L .10143 .79285 L p F P
0 g
s
.414 .225 .514 r
.69845 .91244 m .70591 .90867 L .70574 .9032 L p F P
0 g
s
.392 .18 .468 r
.69616 .91873 m .69633 .91864 L .69845 .91244 L p F P
0 g
s
.386 .173 .464 r
.70591 .90867 m .69845 .91244 L .69633 .91864 L p F P
0 g
s
.675 .639 .806 r
.46024 .95063 m .44842 .9517 L .44713 .94931 L p F P
0 g
s
.717 .69 .823 r
.31644 .95192 m .30609 .95827 L .31457 .95955 L p F P
0 g
s
.717 .69 .823 r
.31457 .95955 m .31966 .95664 L .31644 .95192 L p F P
0 g
s
.73 .702 .824 r
.30544 .95867 m .30609 .95827 L .31457 .95955 L p F P
0 g
s
.701 .516 .634 r
.39682 .78674 m .40988 .78665 L p .40648 .79318 L F P
0 g
s
.701 .516 .634 r
.39584 .78846 m .39682 .78674 L p .40648 .79318 L F P
0 g
s
.705 .516 .631 r
.39584 .78846 m .39682 .78674 L .39557 .78674 L closepath p F P
0 g
s
.717 .529 .634 r
.39557 .78674 m .39584 .78846 L .3932 .79317 L p F P
0 g
s
.717 .529 .634 r
.38455 .78645 m .39557 .78674 L p .3932 .79317 L F P
0 g
s
.736 .537 .624 r
.36447 .78157 m .36558 .77886 L p .37333 .78584 L F P
0 g
s
.741 .539 .621 r
.36447 .78157 m .36558 .77886 L .36405 .77872 L closepath p F P
0 g
s
.827 .765 .793 r
.11392 .77855 m .11781 .77435 L .11422 .77095 L p F P
0 g
s
.404 0 0 r
.25627 .71347 m .2613 .71601 L .26853 .71902 L p F P
0 g
s
.223 .625 .955 r
.25519 .71321 m .25627 .71347 L .2613 .71601 L p F P
0 g
s
.558 .58 .832 r
.6567 .74741 m .65584 .74567 L .65919 .74557 L closepath p F P
0 g
s
.686 .626 .783 r
.44407 .94332 m .43299 .94878 L .42992 .9428 L p F P
0 g
s
.509 .264 .478 r
.49533 .74456 m .49568 .73955 L .50665 .7361 L p F P
0 g
s
.468 .178 .389 r
.50748 .73159 m .50665 .7361 L .49568 .73955 L p F P
0 g
s
.653 .468 .622 r
.4362 .77881 m .44906 .77734 L p .44637 .78397 L F P
0 g
s
.653 .468 .622 r
.44637 .78397 m .43701 .78506 L .4362 .77881 L p F P
0 g
s
.298 .7 .976 r
.19201 .96626 m .19078 .9662 L .19396 .9673 L closepath p F P
0 g
s
.688 .502 .631 r
.41 .78743 m .41052 .78663 L .40988 .78665 L closepath p F P
0 g
s
.701 .516 .634 r
.40988 .78665 m .41 .78743 L .40648 .79318 L p F P
0 g
s
.616 .42 .593 r
.46281 .76308 m .47254 .76129 L p .46089 .76941 L F P
0 g
s
.616 .42 .593 r
.46089 .76941 m .4606 .76577 L .46281 .76308 L p F P
0 g
s
.686 .504 .635 r
.41052 .78663 m .42368 .78608 L p .42166 .79264 L F P
0 g
s
.686 .504 .635 r
.41 .78743 m .41052 .78663 L p .42166 .79264 L F P
0 g
s
.64 .768 .94 r
.22363 .97011 m .23433 .967 L .23776 .96987 L p F P
0 g
s
.659 .764 .927 r
.23433 .967 m .22363 .97011 L .22016 .96755 L p F P
0 g
s
.795 .356 .203 r
.27399 .72144 m .27962 .72378 L .28282 .72805 L p F P
0 g
s
.77 .325 .193 r
.28928 .73014 m .28282 .72805 L .27962 .72378 L p F P
0 g
s
.539 0 0 r
.27248 .72016 m .27399 .72144 L .27962 .72378 L p F P
0 g
s
.503 .466 .749 r
.70566 .80975 m .70537 .80995 L .70808 .81802 L p F P
0 g
s
.503 .466 .749 r
.70808 .81802 m .71632 .81239 L .70566 .80975 L p F P
0 g
s
.497 .453 .738 r
.70808 .81802 m .71632 .81239 L p .71745 .82124 L F P
0 g
s
.497 .453 .738 r
.71745 .82124 m .70826 .81858 L .70808 .81802 L p F P
0 g
s
.497 .453 .738 r
.71057 .82585 m .70826 .81858 L .71745 .82124 L closepath p F P
0 g
s
.722 .673 .801 r
.3565 .94141 m .35909 .94604 L .35039 .95152 L p F P
0 g
s
.722 .673 .801 r
.35463 .94128 m .3565 .94141 L p .35039 .95152 L F P
0 g
s
.722 .673 .801 r
.34489 .94777 m .35463 .94128 L p .35039 .95152 L F P
0 g
s
.722 .673 .801 r
.35039 .95152 m .34698 .95123 L .34489 .94777 L p F P
0 g
s
.563 .874 .994 r
.61054 .9661 m .60911 .96554 L .59778 .9686 L p F P
0 g
s
.593 .846 .992 r
.60911 .96554 m .59778 .9686 L .59494 .96681 L p F P
0 g
s
.596 .839 .99 r
.58363 .96973 m .59494 .96681 L .59778 .9686 L p F P
0 g
s
.619 .797 .967 r
.56946 .97018 m .58075 .96733 L .58363 .96973 L p F P
0 g
s
.629 .762 .943 r
.58075 .96733 m .56946 .97018 L .56655 .96726 L p F P
0 g
s
.848 .752 .757 r
.09484 .80939 m .09852 .80449 L .09492 .80089 L p F P
0 g
s
.492 .44 .727 r
.71057 .82585 m .71745 .82124 L p .71761 .83035 L F P
0 g
s
.492 .44 .727 r
.71761 .83035 m .71129 .82822 L .71057 .82585 L p F P
0 g
s
.654 .767 .932 r
.55879 .71182 m .57005 .70824 L .57295 .71133 L p F P
0 g
s
.669 .811 .951 r
.57005 .70824 m .55879 .71182 L .55588 .70975 L p F P
0 g
s
.668 .847 .969 r
.54464 .71398 m .55588 .70975 L .55879 .71182 L p F P
0 g
s
.737 .536 .622 r
.36405 .77872 m .35569 .77787 L p .36303 .78497 L F P
0 g
s
.737 .536 .622 r
.36303 .78497 m .36447 .78157 L .36405 .77872 L p F P
0 g
s
.434 .148 .377 r
.50665 .7361 m .50748 .73159 L .5181 .72776 L p F P
0 g
s
.361 .009 .226 r
.51933 .72473 m .5181 .72776 L .50748 .73159 L p F P
0 g
s
.653 .661 .846 r
.52099 .96054 m .50981 .96395 L .5068 .95923 L p F P
0 g
s
.652 .677 .861 r
.50981 .96395 m .52099 .96054 L .52398 .96502 L p F P
0 g
s
.713 .749 .881 r
.2661 .96788 m .26826 .96683 L .2641 .96582 L closepath p F P
0 g
s
.695 .743 .889 r
.2641 .96582 m .2661 .96788 L p .25192 .96907 L F P
0 g
s
.48 .398 .686 r
.71752 .85077 m .71476 .84936 L .71687 .84808 L closepath p F P
0 g
s
.489 .416 .7 r
.71476 .84936 m .71687 .84808 L .71497 .84088 L p F P
0 g
s
.535 .531 .797 r
.6808 .77081 m .69062 .77155 L p .68788 .778 L F P
0 g
s
.533 .532 .8 r
.69062 .77155 m .6808 .77081 L .68805 .76548 L closepath p F P
0 g
s
.539 .542 .807 r
.68772 .76472 m .68805 .76548 L .6808 .77081 L p F P
0 g
s
.539 .542 .807 r
.67606 .76413 m .68772 .76472 L p .6808 .77081 L F P
0 g
s
.492 .439 .726 r
.71286 .83346 m .71129 .82822 L .71761 .83035 L closepath p F P
0 g
s
.75 .248 .025 r
.14255 .95016 m .13714 .94798 L .13315 .94358 L p F P
0 g
s
.74 .229 0 r
.12763 .94143 m .13315 .94358 L .13714 .94798 L p F P
0 g
s
.804 .358 .184 r
.13315 .94358 m .12763 .94143 L .1264 .93956 L p F P
0 g
s
.721 .672 .801 r
.33387 .95472 m .34027 .95068 L .34698 .95123 L p F P
0 g
s
.729 .676 .798 r
.34027 .95068 m .33387 .95472 L .33067 .94978 L p F P
0 g
s
.686 .504 .635 r
.42166 .79264 m .4109 .79312 L .41 .78743 L p F P
0 g
s
.698 .512 .633 r
.4109 .79312 m .41 .78743 L .40648 .79318 L closepath p F P
0 g
s
.778 .772 .847 r
.16614 .73117 m .16233 .73403 L .15879 .73069 L p F P
0 g
s
.717 .529 .634 r
.38159 .79219 m .38455 .78645 L p .3932 .79317 L F P
0 g
s
.721 .529 .63 r
.38159 .79219 m .38455 .78645 L .38066 .78628 L closepath p F P
0 g
s
.617 .801 .97 r
.59494 .96681 m .58363 .96973 L .58075 .96733 L p F P
0 g
s
.777 .537 .573 r
.32827 .76127 m .32481 .7606 L .32573 .75502 L p F P
0 g
s
.787 .545 .571 r
.31798 .75337 m .32573 .75502 L .32481 .7606 L p F P
0 g
s
.636 .717 .906 r
.57295 .71133 m .58425 .70831 L .58714 .71205 L p F P
0 g
s
.646 .743 .919 r
.58425 .70831 m .57295 .71133 L .57005 .70824 L p F P
0 g
s
.756 .545 .61 r
.34721 .77481 m .34851 .77073 L p .35569 .77787 L F P
0 g
s
.761 .548 .608 r
.34721 .77481 m .34851 .77073 L .34667 .77045 L closepath p F P
0 g
s
.622 .773 .952 r
.22709 .71136 m .23774 .70845 L .2412 .71131 L p F P
0 g
s
.607 .77 .958 r
.23774 .70845 m .22709 .71136 L .22363 .70824 L p F P
0 g
s
.689 .773 .915 r
.21288 .71275 m .22363 .70824 L .22709 .71136 L p F P
0 g
s
.874 .706 .67 r
.08425 .85626 m .08155 .86241 L .0861 .86496 L p F P
0 g
s
.879 .7 .656 r
.08155 .86241 m .0861 .86496 L .08374 .87101 L p F P
0 g
s
.83 .763 .789 r
.10975 .77576 m .11392 .77855 L .10737 .78579 L p F P
0 g
s
.827 .765 .793 r
.11422 .77095 m .10975 .77576 L .11392 .77855 L p F P
0 g
s
.695 .743 .889 r
.25192 .96907 m .26071 .96529 L .2641 .96582 L p F P
0 g
s
.707 .743 .88 r
.26071 .96529 m .25192 .96907 L .24853 .96591 L p F P
0 g
s
.674 .757 .913 r
.23776 .96987 m .24853 .96591 L .25192 .96907 L p F P
0 g
s
.688 .753 .901 r
.24853 .96591 m .23776 .96987 L .23433 .967 L p F P
0 g
s
.51 .48 .76 r
.70537 .80995 m .70527 .80967 L .70566 .80975 L closepath p F P
0 g
s
.51 .48 .76 r
.70566 .80975 m .70527 .80967 L .70243 .80163 L p F P
0 g
s
.701 .516 .634 r
.40648 .79318 m .3966 .79323 L .39584 .78846 L p F P
0 g
s
.711 .523 .633 r
.3966 .79323 m .39584 .78846 L .3932 .79317 L closepath p F P
0 g
s
.857 .743 .737 r
.08979 .82547 m .09035 .82463 L .08675 .82086 L p F P
0 g
s
.487 .426 .714 r
.71286 .83346 m .71761 .83035 L p .71679 .8397 L F P
0 g
s
.487 .426 .714 r
.71679 .8397 m .71436 .83875 L .71286 .83346 L p F P
0 g
s
.589 .636 .865 r
.62 .72349 m .61853 .72099 L .62464 .72016 L closepath p F P
0 g
s
.633 .432 .593 r
.46089 .76941 m .4606 .76577 L .45805 .76982 L closepath p F P
0 g
s
.127 .63 .904 r
.17809 .96375 m .18495 .96417 L .19078 .9662 L p F P
0 g
s
.238 .687 .954 r
.18495 .96417 m .17809 .96375 L .17446 .96214 L p F P
0 g
s
0 0 0 r
.64868 .95506 m .643 .95722 L .63778 .95912 L p F P
0 g
s
0 0 0 r
.63732 .9593 m .643 .95722 L .63778 .95912 L closepath p F P
0 g
s
.881 .589 .489 r
.10519 .91896 m .10179 .91736 L .10162 .91197 L p F P
0 g
s
.884 .591 .486 r
.09669 .9096 m .10162 .91197 L .10179 .91736 L p F P
0 g
s
.882 .616 .53 r
.10162 .91197 m .09669 .9096 L .09703 .90407 L p F P
0 g
s
.661 .652 .83 r
.47847 .95675 m .48961 .95261 L p .4899 .95892 L F P
0 g
s
.665 .638 .813 r
.48961 .95261 m .47847 .95675 L .47544 .95128 L p F P
0 g
s
.72 .529 .631 r
.38066 .78628 m .37333 .78584 L p .38129 .79276 L F P
0 g
s
.72 .529 .631 r
.38129 .79276 m .38159 .79219 L .38066 .78628 L p F P
0 g
s
.797 .504 .492 r
.30869 .74543 m .30407 .74426 L .30354 .73914 L p F P
0 g
s
.812 .518 .492 r
.29683 .73715 m .30354 .73914 L .30407 .74426 L p F P
0 g
s
.721 .672 .802 r
.34698 .95123 m .34489 .94777 L .34027 .95068 L closepath p F P
0 g
s
.885 .618 .529 r
.09217 .90167 m .09703 .90407 L .09669 .9096 L p F P
0 g
s
.883 .638 .564 r
.09703 .90407 m .09217 .90167 L .09298 .89602 L p F P
0 g
s
.45 0 0 r
.14336 .95085 m .14513 .95117 L p .15469 .956 L F P
0 g
s
.68 .137 0 r
.14336 .95085 m .14255 .95016 L .14513 .95117 L closepath p F P
0 g
s
.862 .739 .726 r
.08547 .82279 m .08979 .82547 L .08574 .83198 L p F P
0 g
s
.857 .743 .737 r
.08675 .82086 m .08547 .82279 L .08979 .82547 L p F P
0 g
s
.558 .582 .835 r
.65919 .74557 m .65584 .74567 L .65297 .73993 L p F P
0 g
s
.502 .468 .752 r
.71415 .80382 m .70566 .80975 L .71632 .81239 L p F P
0 g
s
.51 .48 .76 r
.71413 .80378 m .71415 .80382 L .70566 .80975 L p F P
0 g
s
.51 .48 .76 r
.70278 .80139 m .71413 .80378 L p .70566 .80975 L F P
0 g
s
.51 .48 .76 r
.70243 .80163 m .70278 .80139 L p .70566 .80975 L F P
0 g
s
.754 .543 .61 r
.34667 .77045 m .33963 .76942 L p .3466 .77663 L F P
0 g
s
.754 .543 .61 r
.3466 .77663 m .34721 .77481 L .34667 .77045 L p F P
0 g
s
.778 .772 .847 r
.15879 .73069 m .16191 .72835 L .16614 .73117 L p F P
0 g
s
.776 .773 .85 r
.16977 .72257 m .16191 .72835 L .16614 .73117 L p F P
0 g
s
.776 .773 .85 r
.16614 .73117 m .1733 .72588 L .16977 .72257 L p F P
0 g
s
.684 .773 .919 r
.22363 .70824 m .21288 .71275 L .20941 .70951 L p F P
0 g
s
.868 .539 .425 r
.11293 .92716 m .10774 .92489 L .10682 .91969 L p F P
0 g
s
.87 .535 .415 r
.10519 .91896 m .10682 .91969 L .10774 .92489 L p F P
0 g
s
.714 .748 .879 r
.27366 .95874 m .27698 .96262 L .26826 .96683 L p F P
0 g
s
.714 .748 .879 r
.26275 .96442 m .27366 .95874 L p .26826 .96683 L F P
0 g
s
.714 .748 .879 r
.26826 .96683 m .2641 .96582 L .26275 .96442 L p F P
0 g
s
.679 .625 .787 r
.45823 .94422 m .44713 .94931 L .44407 .94332 L p F P
0 g
s
.675 .639 .806 r
.44713 .94931 m .45823 .94422 L p .46024 .95063 L F P
0 g
s
.663 .661 .837 r
.49298 .95853 m .49263 .95795 L .4899 .95892 L closepath p F P
0 g
s
.661 .652 .83 r
.48961 .95261 m .49263 .95795 L .4899 .95892 L p F P
0 g
s
.439 .736 .99 r
.2524 .71135 m .25127 .7109 L .2412 .71131 L p F P
0 g
s
.47 .716 .977 r
.25127 .7109 m .2412 .71131 L .23774 .70845 L p F P
0 g
s
.671 .489 .63 r
.42412 .78903 m .42645 .78587 L .42368 .78608 L closepath p F P
0 g
s
.686 .504 .635 r
.42368 .78608 m .42412 .78903 L .42166 .79264 L p F P
0 g
s
.866 .726 .706 r
.08195 .83843 m .08637 .84105 L .08287 .84742 L p F P
0 g
s
.863 .731 .715 r
.08637 .84105 m .08195 .83843 L .08574 .83198 L p F P
0 g
s
.309 0 .176 r
.5181 .72776 m .51933 .72473 L .52397 .72234 L p F P
0 g
s
.872 .717 .687 r
.08425 .85626 m .08517 .85438 L .08165 .84983 L p F P
0 g
s
.886 .641 .563 r
.08818 .89359 m .09298 .89602 L .09217 .90167 L p F P
0 g
s
.882 .657 .592 r
.09298 .89602 m .08818 .89359 L .08943 .88783 L p F P
0 g
s
.487 .426 .714 r
.71497 .84088 m .71436 .83875 L .71679 .8397 L closepath p F P
0 g
s
.536 .543 .808 r
.68483 .7582 m .68772 .76472 L .67606 .76413 L p F P
0 g
s
.536 .543 .808 r
.68048 .75797 m .68483 .7582 L p .67606 .76413 L F P
0 g
s
.536 .543 .808 r
.67606 .76413 m .67512 .76201 L .68048 .75797 L p F P
0 g
s
.441 .311 .608 r
.71674 .87825 m .71323 .88027 L .71412 .88644 L p F P
0 g
s
.728 .676 .799 r
.33067 .94978 m .31966 .95664 L .31644 .95192 L p F P
0 g
s
.571 .918 .964 r
.54364 .71377 m .54464 .71398 L .55588 .70975 L p F P
0 g
s
.736 .537 .624 r
.37333 .78584 m .365 .78515 L .36447 .78157 L p F P
0 g
s
.74 .539 .623 r
.365 .78515 m .36447 .78157 L .36303 .78497 L closepath p F P
0 g
s
.514 .492 .77 r
.70243 .80163 m .7023 .8013 L .70278 .80139 L closepath p F P
0 g
s
.063 0 0 r
.66158 .94883 m .6626 .94739 L .67254 .94173 L p F P
0 g
s
.514 .493 .771 r
.70278 .80139 m .7023 .8013 L .69936 .79336 L p F P
0 g
s
.478 .409 .7 r
.71679 .8397 m .71497 .84088 L .71687 .84808 L p F P
0 g
s
.676 .495 .634 r
.42645 .78587 m .43701 .78506 L p .42465 .7925 L F P
0 g
s
.676 .495 .634 r
.42465 .7925 m .42412 .78903 L .42645 .78587 L p F P
0 g
s
.531 .52 .788 r
.68788 .778 m .69352 .77856 L p .69392 .7855 L F P
0 g
s
.529 .52 .791 r
.69352 .77856 m .68788 .778 L .69208 .775 L closepath p F P
0 g
s
.535 .531 .797 r
.69062 .77155 m .69208 .775 L .68788 .778 L p F P
0 g
s
.705 .637 .778 r
.38745 .94358 m .38862 .94286 L .40154 .94296 L p F P
0 g
s
.708 .642 .782 r
.38745 .94358 m .38862 .94286 L .38706 .94283 L closepath p F P
0 g
s
.711 .643 .779 r
.38706 .94283 m .38745 .94358 L p .37328 .94463 L F P
0 g
s
.72 .529 .631 r
.37333 .78584 m .37028 .7921 L .38129 .79276 L p F P
0 g
s
.736 .544 .633 r
.365 .78515 m .37333 .78584 L .37028 .7921 L p F P
0 g
s
.852 .75 .75 r
.09059 .80667 m .09484 .80939 L .09 .81613 L p F P
0 g
s
.848 .752 .757 r
.09492 .80089 m .09059 .80667 L .09484 .80939 L p F P
0 g
s
.698 .642 .79 r
.41555 .94278 m .40163 .94296 L .40161 .94292 L p F P
0 g
s
.703 .644 .788 r
.40163 .94296 m .40161 .94292 L .40154 .94296 L closepath p F P
0 g
s
.699 .634 .781 r
.39851 .93672 m .38862 .94286 L .40154 .94296 L p F P
0 g
s
.699 .634 .781 r
.40154 .94296 m .40161 .94292 L .39851 .93672 L p F P
0 g
s
.698 .642 .79 r
.40161 .94292 m .41268 .93636 L p .41555 .94278 L F P
0 g
s
.701 .626 .769 r
.41268 .93636 m .40161 .94292 L .39851 .93672 L p F P
0 g
s
.834 .761 .781 r
.10737 .78579 m .10645 .78685 L .10284 .7834 L p F P
0 g
s
.834 .761 .781 r
.10284 .7834 m .10317 .78301 L .10737 .78579 L p F P
0 g
s
.83 .763 .789 r
.10737 .78579 m .10317 .78301 L .10975 .77576 L p F P
0 g
s
.774 .547 .591 r
.33963 .76942 m .33141 .76792 L .33275 .7622 L p F P
0 g
s
.783 .557 .593 r
.32827 .76127 m .33275 .7622 L .33141 .76792 L p F P
0 g
s
.648 .671 .859 r
.53519 .96183 m .52398 .96502 L .52099 .96054 L p F P
0 g
s
.62 .686 .89 r
.58714 .71205 m .59849 .70951 L .60137 .71367 L p F P
0 g
s
.627 .701 .899 r
.59849 .70951 m .58714 .71205 L .58425 .70831 L p F P
0 g
s
.711 .643 .779 r
.37328 .94463 m .37655 .94253 L .38706 .94283 L p F P
0 g
s
.714 .651 .785 r
.37328 .94463 m .37655 .94253 L .37205 .94234 L closepath p F P
0 g
s
.716 .65 .782 r
.37205 .94234 m .37328 .94463 L p .35909 .94604 L F P
0 g
s
.859 .486 .34 r
.10774 .92489 m .11293 .92716 L .11457 .93218 L p F P
0 g
s
.858 .488 .348 r
.11977 .93443 m .11457 .93218 L .11293 .92716 L p F P
0 g
s
.737 .536 .622 r
.35569 .77787 m .3533 .78392 L .36303 .78497 L p F P
0 g
s
.756 .554 .623 r
.34746 .77674 m .35569 .77787 L .3533 .78392 L p F P
0 g
s
.756 .545 .61 r
.35569 .77787 m .34746 .77674 L .34721 .77481 L p F P
0 g
s
.708 .642 .781 r
.3968 .93314 m .39851 .93672 L .38862 .94286 L p F P
0 g
s
.708 .642 .781 r
.39114 .93307 m .3968 .93314 L p .38862 .94286 L F P
0 g
s
.708 .642 .781 r
.38434 .93753 m .39114 .93307 L p .38862 .94286 L F P
0 g
s
.708 .642 .781 r
.38862 .94286 m .38706 .94283 L .38434 .93753 L p F P
0 g
s
.839 .76 .776 r
.10143 .79285 m .10645 .78685 L .10284 .7834 L p F P
0 g
s
.711 .643 .779 r
.38706 .94283 m .38434 .93753 L .37655 .94253 L closepath p F P
0 g
s
.885 .66 .592 r
.08471 .88535 m .08943 .88783 L .08818 .89359 L p F P
0 g
s
.881 .673 .617 r
.08943 .88783 m .08471 .88535 L .08636 .87949 L p F P
0 g
s
.505 .478 .761 r
.70278 .80139 m .71413 .80378 L .71117 .79547 L p F P
0 g
s
.505 .478 .761 r
.71117 .79547 m .7111 .79546 L .70278 .80139 L p F P
0 g
s
.514 .493 .771 r
.69936 .79336 m .7111 .79546 L .70278 .80139 L p F P
0 g
s
.381 0 0 r
.16065 .9583 m .16025 .95811 L .16141 .95854 L closepath p F P
0 g
s
.729 .676 .798 r
.33067 .94978 m .33088 .94964 L .34027 .95068 L p F P
0 g
s
.718 .666 .797 r
.34172 .94236 m .33088 .94964 L .34027 .95068 L p F P
0 g
s
.718 .666 .797 r
.34027 .95068 m .34489 .94777 L .34172 .94236 L p F P
0 g
s
.66 .66 .839 r
.50379 .95412 m .50529 .95666 L .49298 .95853 L p F P
0 g
s
.66 .66 .839 r
.49298 .95853 m .49263 .95795 L .50379 .95412 L p F P
0 g
s
.655 .099 0 r
.27399 .72144 m .26957 .71941 L .27248 .72016 L closepath p F P
0 g
s
.697 .639 .788 r
.41582 .94277 m .41576 .94266 L .41555 .94278 L closepath p F P
0 g
s
.698 .642 .79 r
.41268 .93636 m .41576 .94266 L .41555 .94278 L p F P
0 g
s
.697 .64 .788 r
.42684 .93645 m .42966 .94228 L .41582 .94277 L p F P
0 g
s
.697 .64 .788 r
.41582 .94277 m .41576 .94266 L .42684 .93645 L p F P
0 g
s
.677 .643 .809 r
.46147 .95052 m .46128 .95018 L .46024 .95063 L closepath p F P
0 g
s
.675 .639 .806 r
.45823 .94422 m .46128 .95018 L .46024 .95063 L p F P
0 g
s
.695 .621 .771 r
.42684 .93645 m .41576 .94266 L .41268 .93636 L p F P
0 g
s
.542 .554 .816 r
.67512 .76201 m .67317 .75775 L .68048 .75797 L closepath p F P
0 g
s
.805 .358 .18 r
.12763 .94143 m .12338 .93975 L .1264 .93956 L closepath p F P
0 g
s
.637 .447 .609 r
.45805 .76982 m .46089 .76941 L .46156 .77549 L p F P
0 g
s
.637 .447 .609 r
.46156 .77549 m .45246 .77682 L .45805 .76982 L p F P
0 g
s
.877 .711 .672 r
.07978 .85367 m .08425 .85626 L .08155 .86241 L p F P
0 g
s
.872 .717 .687 r
.08165 .84983 m .07978 .85367 L .08425 .85626 L p F P
0 g
s
.764 .773 .86 r
.17903 .72197 m .1733 .72588 L .16977 .72257 L p F P
0 g
s
.315 .801 .767 r
.643 .95722 m .63732 .9593 L .63462 .95958 L p F P
0 g
s
.354 .829 .826 r
.62325 .96317 m .63462 .95958 L .63732 .9593 L p F P
0 g
s
.527 .508 .778 r
.69392 .7855 m .69643 .78581 L p .6989 .79329 L F P
0 g
s
.524 .509 .781 r
.69643 .78581 m .69392 .7855 L .6958 .78418 L closepath p F P
0 g
s
.531 .52 .788 r
.69352 .77856 m .6958 .78418 L .69392 .7855 L p F P
0 g
s
.674 .642 .81 r
.47239 .94544 m .47433 .94917 L .46147 .95052 L p F P
0 g
s
.674 .642 .81 r
.46147 .95052 m .46128 .95018 L .47239 .94544 L p F P
0 g
s
.716 .65 .782 r
.35909 .94604 m .36522 .94201 L .37205 .94234 L p F P
0 g
s
.72 .66 .789 r
.35909 .94604 m .36522 .94201 L .3565 .94141 L closepath p F P
0 g
s
.575 .611 .851 r
.63612 .73046 m .63572 .72973 L .63729 .72959 L closepath p F P
0 g
s
.731 .706 .827 r
.30544 .95867 m .30609 .95827 L .30502 .95809 L closepath p F P
0 g
s
.724 .701 .828 r
.30502 .95809 m .30544 .95867 L p .29121 .96067 L F P
0 g
s
.362 .726 .988 r
.19078 .9662 m .19201 .96626 L .18844 .9642 L p F P
0 g
s
.362 .726 .988 r
.18844 .9642 m .18495 .96417 L .19078 .9662 L p F P
0 g
s
.52 .497 .771 r
.69936 .79336 m .6989 .79329 L .69925 .79306 L closepath p F P
0 g
s
.527 .508 .778 r
.69643 .78581 m .69925 .79306 L .6989 .79329 L p F P
0 g
s
.812 .549 .54 r
.30869 .74543 m .31113 .74614 L .31086 .75151 L p F P
0 g
s
.802 .54 .541 r
.31798 .75337 m .31086 .75151 L .31113 .74614 L p F P
0 g
s
.659 .639 .819 r
.50379 .95412 m .49263 .95795 L .48961 .95261 L p F P
0 g
s
.72 .768 .891 r
.19995 .71442 m .1986 .71512 L .19511 .71182 L p F P
0 g
s
.748 .772 .873 r
.18423 .71848 m .19511 .71182 L .1986 .71512 L p F P
0 g
s
.684 .501 .632 r
.42465 .7925 m .42412 .78903 L .42166 .79264 L closepath p F P
0 g
s
.672 .623 .792 r
.47239 .94544 m .46128 .95018 L .45823 .94422 L p F P
0 g
s
.702 .522 .642 r
.3966 .79323 m .40648 .79318 L .4021 .79983 L p F P
0 g
s
.702 .522 .642 r
.4021 .79983 m .39777 .79986 L .3966 .79323 L p F P
0 g
s
.712 .529 .64 r
.3932 .79317 m .3966 .79323 L .39777 .79986 L p F P
0 g
s
.732 .705 .825 r
.31347 .94746 m .31644 .95192 L .30609 .95827 L p F P
0 g
s
.732 .705 .825 r
.31273 .94737 m .31347 .94746 L p .30609 .95827 L F P
0 g
s
.732 .705 .825 r
.30219 .95421 m .31273 .94737 L p .30609 .95827 L F P
0 g
s
.732 .705 .825 r
.30609 .95827 m .30502 .95809 L .30219 .95421 L p F P
0 g
s
.87 .535 .415 r
.10231 .9211 m .10519 .91896 L p .10774 .92489 L F P
0 g
s
.879 .557 .437 r
.10231 .9211 m .10179 .91736 L .10519 .91896 L closepath p F P
0 g
s
.826 .489 .417 r
.28956 .73082 m .28993 .73034 L p .29683 .73715 L F P
0 g
s
.8 .432 .36 r
.28956 .73082 m .28928 .73014 L .28993 .73034 L closepath p F P
0 g
s
.714 .65 .783 r
.38203 .93286 m .38434 .93753 L .37655 .94253 L p F P
0 g
s
.714 .65 .783 r
.37899 .93276 m .38203 .93286 L p .37655 .94253 L F P
0 g
s
.714 .65 .783 r
.37015 .93876 m .37899 .93276 L p .37655 .94253 L F P
0 g
s
.714 .65 .783 r
.37655 .94253 m .37205 .94234 L .37015 .93876 L p F P
0 g
s
.561 .88 .992 r
.60911 .96554 m .61054 .9661 L .62125 .96262 L p F P
0 g
s
.55 .89 .984 r
.62325 .96317 m .62125 .96262 L .61054 .9661 L p F P
0 g
s
.699 .517 .639 r
.40648 .79318 m .4109 .79312 L .41202 .7997 L p F P
0 g
s
.699 .517 .639 r
.41202 .7997 m .4021 .79983 L .40648 .79318 L p F P
0 g
s
.712 .529 .64 r
.39777 .79986 m .38926 .7997 L .3932 .79317 L p F P
0 g
s
.718 .536 .643 r
.38169 .79278 m .3932 .79317 L .38926 .7997 L p F P
0 g
s
.717 .529 .634 r
.3932 .79317 m .38169 .79278 L .38159 .79219 L p F P
0 g
s
.4 .215 .511 r
.71201 .89986 m .70574 .9032 L .70591 .90867 L p F P
0 g
s
.423 .257 .551 r
.70574 .9032 m .71201 .89986 L .71091 .8945 L p F P
0 g
s
.686 .509 .641 r
.4109 .79312 m .42166 .79264 L .41661 .79949 L p F P
0 g
s
.686 .509 .641 r
.41661 .79949 m .41202 .7997 L .4109 .79312 L p F P
0 g
s
.589 .642 .872 r
.62464 .72016 m .61853 .72099 L .61565 .71626 L p F P
0 g
s
.512 .492 .771 r
.7111 .79546 m .69936 .79336 L .69925 .79306 L p F P
0 g
s
.04 0 0 r
.52397 .72234 m .53002 .71989 L .53052 .71936 L closepath p F P
0 g
s
.309 0 .176 r
.52397 .72234 m .53002 .71989 L p .5181 .72776 L F P
0 g
s
.574 .616 .856 r
.63729 .72959 m .63572 .72973 L .63285 .72459 L p F P
0 g
s
.471 .392 .686 r
.71687 .84808 m .72438 .84326 L p .7217 .85311 L F P
0 g
s
.471 .392 .686 r
.7217 .85311 m .71752 .85077 L .71687 .84808 L p F P
0 g
s
.478 .409 .7 r
.71687 .84808 m .72438 .84326 L .71679 .8397 L p F P
0 g
s
.637 .454 .619 r
.44941 .7801 m .45246 .77682 L .44906 .77734 L closepath p F P
0 g
s
.653 .468 .622 r
.44906 .77734 m .44941 .7801 L .44637 .78397 L p F P
0 g
s
.512 .492 .771 r
.69925 .79306 m .70702 .78739 L p .7111 .79546 L F P
0 g
s
.517 .504 .781 r
.69925 .79306 m .69643 .78581 L .70702 .78739 L closepath p F P
0 g
s
.297 0 0 r
.16025 .95811 m .16065 .9583 L .15697 .95693 L p F P
0 g
s
.297 0 0 r
.15697 .95693 m .15469 .956 L .16025 .95811 L p F P
0 g
s
.686 .626 .783 r
.44319 .9415 m .44407 .94332 L p .42992 .9428 L F P
0 g
s
.686 .626 .783 r
.42992 .9428 m .43107 .9422 L .44319 .9415 L p F P
0 g
s
.686 .625 .782 r
.42992 .9428 m .43107 .9422 L .42966 .94228 L closepath p F P
0 g
s
.724 .701 .828 r
.29121 .96067 m .29733 .95706 L .30502 .95809 L p F P
0 g
s
.724 .702 .829 r
.30502 .95809 m .30219 .95421 L .29733 .95706 L closepath p F P
0 g
s
.884 .677 .617 r
.08171 .87698 m .08636 .87949 L .08471 .88535 L p F P
0 g
s
.88 .687 .637 r
.08636 .87949 m .08171 .87698 L .08374 .87101 L p F P
0 g
s
.814 .46 .388 r
.28928 .73014 m .28956 .73082 L .28762 .73386 L p F P
0 g
s
.814 .46 .388 r
.28282 .72805 m .28928 .73014 L p .28762 .73386 L F P
0 g
s
.72 .768 .891 r
.19511 .71182 m .19533 .71171 L .19995 .71442 L p F P
0 g
s
.722 .774 .893 r
.20592 .7063 m .19533 .71171 L .19995 .71442 L p F P
0 g
s
.722 .774 .893 r
.19995 .71442 m .20941 .70951 L .20592 .7063 L p F P
0 g
s
.736 .544 .633 r
.37028 .7921 m .36612 .79175 L .365 .78515 L p F P
0 g
s
.74 .547 .632 r
.36303 .78497 m .365 .78515 L .36612 .79175 L p F P
0 g
s
.777 .563 .609 r
.33141 .76792 m .33963 .76942 L .33776 .77531 L p F P
0 g
s
.754 .543 .61 r
.33963 .76942 m .33776 .77531 L .3466 .77663 L p F P
0 g
s
.716 .65 .783 r
.37205 .94234 m .37015 .93876 L .36522 .94201 L closepath p F P
0 g
s
.621 .435 .609 r
.46156 .77549 m .46089 .76941 L .47301 .76718 L p F P
0 g
s
.616 .42 .593 r
.47254 .76129 m .47301 .76718 L .46089 .76941 L p F P
0 g
s
.361 .124 .413 r
.69614 .91898 m .69633 .91864 L .69616 .91873 L closepath p F P
0 g
s
.646 .088 0 r
.14255 .95016 m .14336 .95085 L .1396 .94994 L p F P
0 g
s
.646 .088 0 r
.1396 .94994 m .13714 .94798 L .14255 .95016 L p F P
0 g
s
.836 .419 .247 r
.12338 .93975 m .12221 .93924 L .11977 .93443 L p F P
0 g
s
.836 .413 .231 r
.11457 .93218 m .11977 .93443 L .12221 .93924 L p F P
0 g
s
.756 .544 .61 r
.34746 .77674 m .34721 .77481 L .3466 .77663 L closepath p F P
0 g
s
.686 .624 .781 r
.43107 .9422 m .42966 .94228 L .42684 .93645 L p F P
0 g
s
.726 .655 .779 r
.35463 .94128 m .34489 .94777 L .34172 .94236 L p F P
0 g
s
.655 .476 .63 r
.43701 .78506 m .44637 .78397 L .44007 .79118 L p F P
0 g
s
.655 .476 .63 r
.44007 .79118 m .43794 .79143 L .43701 .78506 L p F P
0 g
s
.676 .495 .634 r
.43701 .78506 m .43794 .79143 L .42465 .7925 L p F P
0 g
s
.724 .533 .632 r
.38169 .79278 m .38159 .79219 L .38129 .79276 L closepath p F P
0 g
s
.694 .744 .89 r
.2641 .96582 m .26275 .96442 L .26071 .96529 L closepath p F P
0 g
s
.326 .086 .389 r
.69633 .91864 m .7058 .91387 L p .6957 .9236 L F P
0 g
s
.326 .086 .389 r
.6957 .9236 m .69614 .91898 L .69633 .91864 L p F P
0 g
s
.386 .173 .464 r
.69633 .91864 m .7058 .91387 L .70591 .90867 L p F P
0 g
s
.642 .71 .896 r
.53816 .96601 m .5494 .963 L .55236 .96678 L p F P
0 g
s
.642 .688 .878 r
.54939 .96298 m .5494 .963 L .53816 .96601 L p F P
0 g
s
.642 .688 .878 r
.53816 .96601 m .53786 .96558 L .54939 .96298 L p F P
0 g
s
.841 .759 .772 r
.09725 .79007 m .10143 .79285 L .09574 .79984 L p F P
0 g
s
.839 .76 .776 r
.10284 .7834 m .09725 .79007 L .10143 .79285 L p F P
0 g
s
.686 .625 .781 r
.44319 .9415 m .441 .93699 L .43107 .9422 L closepath p F P
0 g
s
.686 .624 .781 r
.43866 .9319 m .441 .93699 L .43107 .9422 L p F P
0 g
s
.686 .624 .781 r
.43473 .93211 m .43866 .9319 L p .43107 .9422 L F P
0 g
s
.686 .624 .781 r
.42684 .93645 m .43473 .93211 L p .43107 .9422 L F P
0 g
s
.74 .547 .632 r
.36612 .79175 m .36007 .79119 L .36303 .78497 L p F P
0 g
s
.75 .554 .629 r
.3533 .78392 m .36303 .78497 L .36007 .79119 L p F P
0 g
s
.363 .116 .399 r
.69171 .92549 m .6957 .9236 L .69614 .91898 L closepath p F P
0 g
s
0 .395 .693 r
.17446 .96214 m .17084 .96035 L .16065 .9583 L p F P
0 g
s
.169 .628 .935 r
.16065 .9583 m .17084 .96035 L .16863 .95916 L p F P
0 g
s
.169 .628 .935 r
.15697 .95693 m .16065 .9583 L p .16863 .95916 L F P
0 g
s
.722 .716 .844 r
.27698 .96262 m .28793 .95652 L .29121 .96067 L p F P
0 g
s
.735 .708 .825 r
.29733 .95706 m .29121 .96067 L .28793 .95652 L p F P
0 g
s
.718 .536 .643 r
.38926 .7997 m .38293 .79949 L .38169 .79278 L p F P
0 g
s
.724 .541 .642 r
.38129 .79276 m .38169 .79278 L .38293 .79949 L p F P
0 g
s
.733 .549 .643 r
.37028 .7921 m .38129 .79276 L .37761 .79921 L p F P
0 g
s
.724 .541 .642 r
.38293 .79949 m .37761 .79921 L .38129 .79276 L p F P
0 g
s
.43 .765 .996 r
.20605 .96737 m .20253 .96498 L .19201 .96626 L p F P
0 g
s
.558 .769 .977 r
.20253 .96498 m .19201 .96626 L .18844 .9642 L p F P
0 g
s
.606 .667 .883 r
.60167 .71413 m .60137 .71367 L .60269 .71343 L closepath p F P
0 g
s
.553 .572 .827 r
.66741 .74548 m .65919 .74557 L .66526 .741 L closepath p F P
0 g
s
.558 .582 .835 r
.66454 .73956 m .66526 .741 L .65919 .74557 L p F P
0 g
s
.558 .582 .835 r
.65297 .73993 m .66454 .73956 L p .65919 .74557 L F P
0 g
s
.597 .404 .591 r
.47301 .76718 m .47254 .76129 L .48426 .75865 L p F P
0 g
s
.59 .383 .569 r
.48399 .75299 m .48426 .75865 L .47254 .76129 L p F P
0 g
s
.764 .773 .86 r
.16977 .72257 m .17482 .71914 L .17903 .72197 L p F P
0 g
s
.763 .774 .862 r
.18071 .71519 m .17482 .71914 L .17903 .72197 L p F P
0 g
s
.763 .774 .862 r
.17903 .72197 m .18423 .71848 L .18071 .71519 L p F P
0 g
s
.471 .392 .685 r
.71857 .85508 m .71752 .85077 L .7217 .85311 L closepath p F P
0 g
s
.117 .564 .919 r
.25627 .71347 m .2524 .71135 L .25519 .71321 L closepath p F P
0 g
s
.783 .557 .593 r
.33141 .76792 m .32886 .76739 L .32827 .76127 L p F P
0 g
s
.777 .552 .594 r
.32481 .7606 m .32827 .76127 L .32886 .76739 L p F P
0 g
s
.787 .545 .571 r
.32481 .7606 m .31713 .75893 L .31798 .75337 L p F P
0 g
s
.803 .56 .57 r
.31086 .75151 m .31798 .75337 L .31713 .75893 L p F P
0 g
s
.865 .735 .717 r
.08141 .82931 m .08574 .83198 L .08195 .83843 L p F P
0 g
s
.862 .739 .726 r
.08574 .83198 m .08141 .82931 L .08547 .82279 L p F P
0 g
s
.685 .507 .64 r
.42166 .79264 m .42465 .7925 L .42577 .79906 L p F P
0 g
s
.685 .507 .64 r
.42577 .79906 m .41661 .79949 L .42166 .79264 L p F P
0 g
s
.721 .659 .788 r
.36702 .93268 m .37015 .93876 L .36522 .94201 L p F P
0 g
s
.721 .659 .788 r
.35594 .94041 m .36702 .93268 L p .36522 .94201 L F P
0 g
s
.721 .659 .788 r
.36522 .94201 m .3565 .94141 L .35594 .94041 L p F P
0 g
s
.643 .688 .877 r
.54644 .95875 m .54939 .96298 L .53786 .96558 L p F P
0 g
s
.643 .688 .877 r
.53786 .96558 m .53519 .96183 L .54644 .95875 L p F P
0 g
s
.812 .549 .54 r
.31086 .75151 m .30845 .75082 L .30869 .74543 L p F P
0 g
s
.8 .537 .541 r
.30407 .74426 m .30869 .74543 L .30845 .75082 L p F P
0 g
s
.826 .489 .417 r
.29683 .73715 m .29061 .735 L .28956 .73082 L p F P
0 g
s
.837 .496 .409 r
.29061 .735 m .28762 .73386 L .28956 .73082 L closepath p F P
0 g
s
.641 .461 .623 r
.45246 .77682 m .46156 .77549 L p .44987 .78358 L F P
0 g
s
.641 .461 .623 r
.44987 .78358 m .44941 .7801 L .45246 .77682 L p F P
0 g
s
.856 .747 .742 r
.09 .81613 m .08675 .82086 L .08314 .81719 L p F P
0 g
s
.856 .747 .742 r
.08314 .81719 m .08573 .81342 L .09 .81613 L p F P
0 g
s
.852 .75 .75 r
.09 .81613 m .08573 .81342 L .09059 .80667 L p F P
0 g
s
.477 .409 .702 r
.72394 .83502 m .71679 .8397 L .72438 .84326 L p F P
0 g
s
.487 .426 .714 r
.72324 .83259 m .72394 .83502 L .71679 .8397 L p F P
0 g
s
.487 .426 .714 r
.71761 .83035 m .72324 .83259 L p .71679 .8397 L F P
0 g
s
.605 .679 .894 r
.60269 .71343 m .60137 .71367 L .59849 .70951 L p F P
0 g
s
.462 .359 .652 r
.72084 .86565 m .71777 .86326 L .72009 .86189 L closepath p F P
0 g
s
.473 .38 .67 r
.71777 .86326 m .72009 .86189 L .71857 .85508 L p F P
0 g
s
.671 .498 .642 r
.42465 .7925 m .43794 .79143 L p .43375 .7984 L F P
0 g
s
.671 .498 .642 r
.43375 .7984 m .42577 .79906 L .42465 .7925 L p F P
0 g
s
.57 .604 .847 r
.64722 .72886 m .63729 .72959 L .64465 .72404 L closepath p F P
0 g
s
.574 .616 .856 r
.64435 .72349 m .64465 .72404 L .63729 .72959 L p F P
0 g
s
.574 .616 .856 r
.63285 .72459 m .64435 .72349 L p .63729 .72959 L F P
0 g
s
.542 .554 .817 r
.68048 .75797 m .67317 .75775 L .67044 .75179 L p F P
0 g
s
.679 .625 .787 r
.45638 .94043 m .45823 .94422 L p .44407 .94332 L F P
0 g
s
.679 .625 .787 r
.44407 .94332 m .44882 .94103 L .45638 .94043 L p F P
0 g
s
.678 .621 .785 r
.44407 .94332 m .44882 .94103 L .44319 .9415 L closepath p F P
0 g
s
.756 .554 .623 r
.3533 .78392 m .34848 .78326 L .34746 .77674 L p F P
0 g
s
.756 .554 .624 r
.3466 .77663 m .34746 .77674 L .34848 .78326 L p F P
0 g
s
.802 .773 .826 r
.14121 .74518 m .13665 .74917 L .13307 .74587 L p F P
0 g
s
.809 .772 .819 r
.13234 .75313 m .13665 .74917 L .13307 .74587 L p F P
0 g
s
.811 .772 .816 r
.13234 .75313 m .12548 .75956 L .12188 .75626 L p F P
0 g
s
.811 .772 .816 r
.12188 .75626 m .12826 .75028 L .13234 .75313 L p F P
0 g
s
.809 .772 .819 r
.13307 .74587 m .12826 .75028 L .13234 .75313 L p F P
0 g
s
.665 .638 .813 r
.48686 .9475 m .48961 .95261 L p .47544 .95128 L F P
0 g
s
.665 .638 .813 r
.47544 .95128 m .4844 .94781 L .48686 .9475 L p F P
0 g
s
.663 .629 .805 r
.47544 .95128 m .4844 .94781 L .47433 .94917 L closepath p F P
0 g
s
.522 .918 .867 r
.54173 .71398 m .54364 .71377 L .55318 .70868 L p F P
0 g
s
.571 .918 .964 r
.55588 .70975 m .55318 .70868 L .54364 .71377 L p F P
0 g
s
.731 .679 .8 r
.33067 .94978 m .33088 .94964 L .33056 .9496 L closepath p F P
0 g
s
.728 .676 .799 r
.33056 .9496 m .33067 .94978 L p .31644 .95192 L F P
0 g
s
.653 .661 .846 r
.5068 .95923 m .51799 .95571 L .52099 .96054 L p F P
0 g
s
.652 .65 .835 r
.5173 .95451 m .51799 .95571 L .5068 .95923 L p F P
0 g
s
.652 .65 .835 r
.5068 .95923 m .50529 .95666 L .5173 .95451 L p F P
0 g
s
.883 .691 .638 r
.07918 .86847 m .08374 .87101 L .08171 .87698 L p F P
0 g
s
.879 .7 .656 r
.08374 .87101 m .07918 .86847 L .08155 .86241 L p F P
0 g
s
.872 .72 .691 r
.08287 .84742 m .08165 .84983 L .07811 .84542 L p F P
0 g
s
.872 .72 .691 r
.07811 .84542 m .07842 .8448 L .08287 .84742 L p F P
0 g
s
.866 .726 .706 r
.08287 .84742 m .07842 .8448 L .08195 .83843 L p F P
0 g
s
.731 .678 .798 r
.34041 .94005 m .34172 .94236 L .33088 .94964 L p F P
0 g
s
.731 .678 .798 r
.33465 .9395 m .34041 .94005 L p .33088 .94964 L F P
0 g
s
.731 .678 .798 r
.32748 .94459 m .33465 .9395 L p .33088 .94964 L F P
0 g
s
.731 .678 .798 r
.33088 .94964 m .33056 .9496 L .32748 .94459 L p F P
0 g
s
.817 .771 .81 r
.12414 .76088 m .12548 .75956 L .12188 .75626 L p F P
0 g
s
.557 .584 .837 r
.66167 .73386 m .66454 .73956 L .65297 .73993 L p F P
0 g
s
.557 .584 .837 r
.65368 .73412 m .66167 .73386 L p .65297 .73993 L F P
0 g
s
.557 .584 .837 r
.65297 .73993 m .65106 .73616 L .65368 .73412 L p F P
0 g
s
.802 .773 .826 r
.13307 .74587 m .13711 .74233 L .14121 .74518 L p F P
0 g
s
.799 .774 .829 r
.14418 .73625 m .13711 .74233 L .14121 .74518 L p F P
0 g
s
.799 .774 .829 r
.14121 .74518 m .14775 .73955 L .14418 .73625 L p F P
0 g
s
.756 .554 .624 r
.34848 .78326 m .34419 .78269 L .3466 .77663 L p F P
0 g
s
.765 .56 .62 r
.33776 .77531 m .3466 .77663 L .34419 .78269 L p F P
0 g
s
.728 .676 .799 r
.31644 .95192 m .32141 .94861 L .33056 .9496 L p F P
0 g
s
.728 .677 .8 r
.33056 .9496 m .32748 .94459 L .32141 .94861 L closepath p F P
0 g
s
.063 0 0 r
.67254 .94173 m .67375 .94122 L p .66158 .94883 L F P
0 g
s
.239 0 .127 r
.67254 .94173 m .67375 .94122 L .6739 .94086 L closepath p F P
0 g
s
.82 .77 .805 r
.12007 .75803 m .12414 .76088 L .11668 .7684 L p F P
0 g
s
.817 .771 .81 r
.12188 .75626 m .12007 .75803 L .12414 .76088 L p F P
0 g
s
.655 .47 .622 r
.44987 .78358 m .44941 .7801 L .44637 .78397 L closepath p F P
0 g
s
.568 .366 .566 r
.48426 .75865 m .48399 .75299 L .49534 .74994 L p F P
0 g
s
.556 .334 .534 r
.49533 .74456 m .49534 .74994 L .48399 .75299 L p F P
0 g
s
.707 .743 .88 r
.24853 .96591 m .25303 .96379 L .26071 .96529 L p F P
0 g
s
.693 .736 .884 r
.25939 .96081 m .25303 .96379 L .26071 .96529 L p F P
0 g
s
.693 .736 .884 r
.26071 .96529 m .26275 .96442 L .25939 .96081 L p F P
0 g
s
.728 .709 .832 r
.28793 .95652 m .27698 .96262 L .27366 .95874 L p F P
0 g
s
.478 0 0 r
.14911 .95388 m .14336 .95085 L .1396 .94994 L p F P
0 g
s
.45 0 0 r
.14911 .95388 m .14336 .95085 L p .15466 .95599 L F P
0 g
s
.478 0 0 r
.14352 .95175 m .14911 .95388 L p .14903 .95384 L F P
0 g
s
.478 0 0 r
.1396 .94994 m .14352 .95175 L p .14903 .95384 L F P
0 g
s
.392 0 0 r
.14352 .95175 m .1396 .94994 L .13585 .9488 L p F P
0 g
s
.392 0 0 r
.1379 .94963 m .14352 .95175 L p .1433 .95167 L F P
0 g
s
.392 0 0 r
.13585 .9488 m .1379 .94963 L p .1433 .95167 L F P
0 g
s
.608 .038 0 r
.13714 .94798 m .1396 .94994 L .13585 .9488 L p F P
0 g
s
.608 .038 0 r
.13585 .9488 m .13175 .9458 L .13714 .94798 L p F P
0 g
s
.566 0 0 r
.13175 .9458 m .13585 .9488 L .1321 .94745 L p F P
0 g
s
.297 0 0 r
.1379 .94963 m .13585 .9488 L .1321 .94745 L p F P
0 g
s
.006 .532 .853 r
.14225 .94979 m .13232 .94752 L p .1379 .94963 L F P
0 g
s
.006 .532 .853 r
.13232 .94752 m .13224 .9475 L .1379 .94963 L p F P
0 g
s
0 .482 .808 r
.14593 .9518 m .13795 .94964 L p .14352 .95175 L F P
0 g
s
0 .482 .808 r
.13795 .94964 m .1379 .94963 L .14352 .95175 L p F P
0 g
s
0 .425 .754 r
.14961 .95366 m .14354 .95176 L p .14911 .95388 L F P
0 g
s
0 .425 .754 r
.14354 .95176 m .14352 .95175 L .14911 .95388 L p F P
0 g
s
.45 0 0 r
.15469 .956 m .14911 .95388 L p .15466 .95599 L F P
0 g
s
.419 .255 .55 r
.71479 .89239 m .71091 .8945 L .71201 .89986 L p F P
0 g
s
.438 .29 .583 r
.71091 .8945 m .71479 .89239 L .71412 .88644 L p F P
0 g
s
.701 .626 .769 r
.41113 .93306 m .41268 .93636 L p .39851 .93672 L F P
0 g
s
.701 .626 .769 r
.39851 .93672 m .40427 .93312 L .41113 .93306 L p F P
0 g
s
.703 .63 .772 r
.39851 .93672 m .40427 .93312 L .3968 .93314 L closepath p F P
0 g
s
.71 .637 .774 r
.38434 .93753 m .39114 .93307 L .38203 .93286 L closepath p F P
0 g
s
.517 .504 .781 r
.70702 .78739 m .69643 .78581 L .6958 .78418 L p F P
0 g
s
.795 .356 .203 r
.28282 .72805 m .27685 .72581 L .27399 .72144 L p F P
0 g
s
.819 .388 .22 r
.26957 .71941 m .27399 .72144 L .27685 .72581 L p F P
0 g
s
.812 .518 .492 r
.30407 .74426 m .29729 .74229 L .29683 .73715 L p F P
0 g
s
.829 .535 .492 r
.29061 .735 m .29683 .73715 L .29729 .74229 L p F P
0 g
s
.636 .732 .918 r
.55236 .96678 m .56363 .96388 L .56655 .96726 L p F P
0 g
s
.638 .71 .899 r
.56363 .96388 m .55236 .96678 L .5494 .963 L p F P
0 g
s
.19 0 .106 r
.67375 .94122 m .6739 .94086 L .68446 .93302 L p F P
0 g
s
.791 .774 .837 r
.15094 .73696 m .14775 .73955 L .14418 .73625 L p F P
0 g
s
.461 .373 .67 r
.7217 .85311 m .71857 .85508 L .72009 .86189 L p F P
0 g
s
.404 0 0 r
.26853 .71902 m .26274 .71671 L .25627 .71347 L p F P
0 g
s
.463 0 0 r
.2524 .71135 m .25627 .71347 L .26274 .71671 L p F P
0 g
s
.747 .775 .876 r
.19511 .71182 m .18423 .71848 L .18071 .71519 L p F P
0 g
s
.733 .549 .643 r
.36726 .79788 m .37028 .7921 L p .37761 .79921 L F P
0 g
s
.737 .549 .64 r
.36726 .79788 m .37028 .7921 L .36612 .79175 L closepath p F P
0 g
s
.678 .621 .784 r
.44882 .94103 m .44319 .9415 L .441 .93699 L p F P
0 g
s
.695 .623 .772 r
.41268 .93636 m .41865 .93284 L .41113 .93306 L closepath p F P
0 g
s
.695 .621 .771 r
.42508 .93264 m .42684 .93645 L p .41268 .93636 L F P
0 g
s
.695 .621 .771 r
.41268 .93636 m .41865 .93284 L .42508 .93264 L p F P
0 g
s
0 0 0 r
.643 .95722 m .64817 .95527 L .64868 .95506 L closepath p F P
0 g
s
.315 .801 .767 r
.64817 .95527 m .643 .95722 L p .63462 .95958 L F P
0 g
s
.603 .664 .882 r
.61277 .71165 m .60269 .71343 L .61038 .70796 L closepath p F P
0 g
s
.605 .679 .894 r
.60988 .70721 m .61038 .70796 L .60269 .71343 L p F P
0 g
s
.605 .679 .894 r
.59849 .70951 m .60988 .70721 L p .60269 .71343 L F P
0 g
s
.441 .311 .608 r
.71412 .88644 m .72011 .88301 L .71674 .87825 L p F P
0 g
s
.425 .281 .581 r
.72011 .88301 m .71412 .88644 L .71479 .89239 L p F P
0 g
s
.719 .636 .765 r
.37899 .93276 m .37015 .93876 L .36702 .93268 L p F P
0 g
s
.777 .552 .594 r
.32886 .76739 m .3234 .76635 L .32481 .7606 L p F P
0 g
s
.79 .562 .592 r
.31713 .75893 m .32481 .7606 L .3234 .76635 L p F P
0 g
s
.547 .898 .976 r
.62125 .96262 m .62325 .96317 L .63462 .95958 L p F P
0 g
s
.521 .516 .791 r
.6958 .78418 m .69352 .77856 L .70196 .77959 L closepath p F P
0 g
s
.517 .504 .781 r
.6958 .78418 m .70196 .77959 L p .70702 .78739 L F P
0 g
s
.791 .774 .837 r
.14418 .73625 m .14683 .7341 L .15094 .73696 L p F P
0 g
s
.789 .775 .84 r
.15523 .7274 m .14683 .7341 L .15094 .73696 L p F P
0 g
s
.789 .775 .84 r
.15094 .73696 m .15879 .73069 L .15523 .7274 L p F P
0 g
s
.74 .229 0 r
.13714 .94798 m .13175 .9458 L .12763 .94143 L p F P
0 g
s
.726 .205 0 r
.12338 .93975 m .12763 .94143 L .13175 .9458 L p F P
0 g
s
.824 .769 .8 r
.11668 .7684 m .11422 .77095 L .1106 .76762 L p F P
0 g
s
.824 .769 .8 r
.1106 .76762 m .11258 .76557 L .11668 .7684 L p F P
0 g
s
.82 .77 .805 r
.11668 .7684 m .11258 .76557 L .12007 .75803 L p F P
0 g
s
.703 .527 .647 r
.39869 .80474 m .4021 .79983 L .39777 .79986 L closepath p F P
0 g
s
.705 .529 .647 r
.39777 .79986 m .38926 .7997 L p .39744 .80658 L F P
0 g
s
.705 .529 .647 r
.39744 .80658 m .39869 .80474 L .39777 .79986 L p F P
0 g
s
.721 .659 .787 r
.3565 .94141 m .35594 .94041 L .35463 .94128 L closepath p F P
0 g
s
.847 .756 .763 r
.09574 .79984 m .09492 .80089 L .0913 .79739 L p F P
0 g
s
.847 .756 .763 r
.0913 .79739 m .09154 .79708 L .09574 .79984 L p F P
0 g
s
.841 .759 .772 r
.09574 .79984 m .09154 .79708 L .09725 .79007 L p F P
0 g
s
.7 .528 .652 r
.4021 .79983 m .41202 .7997 L p .41127 .80643 L F P
0 g
s
.7 .528 .652 r
.39869 .80474 m .4021 .79983 L p .41127 .80643 L F P
0 g
s
.61 .771 .958 r
.20605 .96737 m .21668 .96484 L .22016 .96755 L p F P
0 g
s
.633 .77 .945 r
.21668 .96484 m .20605 .96737 L .20253 .96498 L p F P
0 g
s
.722 .696 .825 r
.29893 .9496 m .28932 .95564 L .29733 .95706 L p F P
0 g
s
.722 .696 .825 r
.29733 .95706 m .30219 .95421 L .29893 .9496 L p F P
0 g
s
.735 .708 .825 r
.28793 .95652 m .28932 .95564 L .29733 .95706 L p F P
0 g
s
.663 .629 .805 r
.4844 .94781 m .47433 .94917 L .47239 .94544 L p F P
0 g
s
.724 .723 .85 r
.27366 .95874 m .26275 .96442 L .25939 .96081 L p F P
0 g
s
.829 .768 .794 r
.10975 .77576 m .11422 .77095 L .1106 .76762 L p F P
0 g
s
.726 .655 .779 r
.34172 .94236 m .34441 .94045 L .35463 .94128 L p F P
0 g
s
.718 .651 .782 r
.3528 .93452 m .34441 .94045 L .35463 .94128 L p F P
0 g
s
.718 .651 .782 r
.35463 .94128 m .35594 .94041 L .3528 .93452 L p F P
0 g
s
.657 .479 .632 r
.44637 .78397 m .44987 .78358 L .45083 .78997 L p F P
0 g
s
.657 .479 .632 r
.45083 .78997 m .44007 .79118 L .44637 .78397 L p F P
0 g
s
.687 .514 .647 r
.41286 .80429 m .41661 .79949 L .41202 .7997 L closepath p F P
0 g
s
.7 .528 .652 r
.41202 .7997 m .41286 .80429 L .41127 .80643 L p F P
0 g
s
.705 .529 .647 r
.38926 .7997 m .38508 .8063 L .39744 .80658 L p F P
0 g
s
.718 .54 .648 r
.38293 .79949 m .38926 .7997 L .38508 .8063 L p F P
0 g
s
.85 .755 .758 r
.09059 .80667 m .09492 .80089 L .0913 .79739 L p F P
0 g
s
.734 .69 .809 r
.31644 .95192 m .32141 .94861 L .31347 .94746 L closepath p F P
0 g
s
.75 .554 .629 r
.36007 .79119 m .35063 .79006 L .3533 .78392 L p F P
0 g
s
.756 .56 .632 r
.34848 .78326 m .3533 .78392 L .35063 .79006 L p F P
0 g
s
.273 0 .273 r
.69171 .92549 m .6957 .9236 L p .68506 .93275 L F P
0 g
s
.273 0 .273 r
.68506 .93275 m .68513 .93241 L .69171 .92549 L p F P
0 g
s
.101 0 0 r
.68369 .93678 m .67375 .94122 L .67171 .94463 L p F P
0 g
s
.19 0 .106 r
.68506 .93275 m .68369 .93678 L .67375 .94122 L p F P
0 g
s
.19 0 .106 r
.68446 .93302 m .68506 .93275 L p .67375 .94122 L F P
0 g
s
.063 0 0 r
.67375 .94122 m .67171 .94463 L .66158 .94883 L p F P
0 g
s
.532 .315 .531 r
.49534 .74994 m .49533 .74456 L .50631 .74111 L p F P
0 g
s
.509 .264 .478 r
.50665 .7361 m .50631 .74111 L .49533 .74456 L p F P
0 g
s
.734 .548 .641 r
.36612 .79175 m .36007 .79119 L p .36696 .79844 L F P
0 g
s
.734 .548 .641 r
.36696 .79844 m .36726 .79788 L .36612 .79175 L p F P
0 g
s
.671 .62 .789 r
.46924 .93905 m .46935 .93928 L .45823 .94422 L p F P
0 g
s
.671 .62 .789 r
.45823 .94422 m .45638 .94043 L .46924 .93905 L p F P
0 g
s
.672 .623 .792 r
.45823 .94422 m .46935 .93928 L .47239 .94544 L p F P
0 g
s
.875 .72 .687 r
.07978 .85367 m .08165 .84983 L .07811 .84542 L p F P
0 g
s
.438 .31 .609 r
.72252 .87488 m .71674 .87825 L .72011 .88301 L p F P
0 g
s
.452 .336 .631 r
.71674 .87825 m .72252 .87488 L .72141 .86849 L p F P
0 g
s
.687 .618 .773 r
.42684 .93645 m .43473 .93211 L .42508 .93264 L closepath p F P
0 g
s
.723 .64 .765 r
.36702 .93268 m .35594 .94041 L .3528 .93452 L p F P
0 g
s
.859 .746 .738 r
.08547 .82279 m .08675 .82086 L .08314 .81719 L p F P
0 g
s
.629 .762 .943 r
.56655 .96726 m .57785 .96442 L .58075 .96733 L p F P
0 g
s
.633 .732 .919 r
.57785 .96442 m .56655 .96726 L .56363 .96388 L p F P
0 g
s
.692 .52 .651 r
.41661 .79949 m .42577 .79906 L p .41327 .80639 L F P
0 g
s
.692 .52 .651 r
.41327 .80639 m .41286 .80429 L .41661 .79949 L p F P
0 g
s
.718 .54 .648 r
.38508 .8063 m .38425 .80627 L .38293 .79949 L p F P
0 g
s
.725 .544 .646 r
.37761 .79921 m .38293 .79949 L .38425 .80627 L p F P
0 g
s
.881 .703 .657 r
.07707 .85982 m .08155 .86241 L .07918 .86847 L p F P
0 g
s
.877 .711 .672 r
.08155 .86241 m .07707 .85982 L .07978 .85367 L p F P
0 g
s
.884 .591 .486 r
.10179 .91736 m .09687 .91499 L .09669 .9096 L p F P
0 g
s
.887 .593 .484 r
.09183 .90719 m .09669 .9096 L .09687 .91499 L p F P
0 g
s
.885 .618 .529 r
.09669 .9096 m .09183 .90719 L .09217 .90167 L p F P
0 g
s
.679 .623 .785 r
.45638 .94043 m .45517 .93794 L .44882 .94103 L closepath p F P
0 g
s
.678 .621 .784 r
.45212 .93133 m .45517 .93794 L .44882 .94103 L p F P
0 g
s
.678 .621 .784 r
.441 .93699 m .45212 .93133 L p .44882 .94103 L F P
0 g
s
.778 .775 .849 r
.16191 .72835 m .15879 .73069 L .15523 .7274 L p F P
0 g
s
.719 .749 .876 r
.25303 .96379 m .24853 .96591 L .24513 .96262 L p F P
0 g
s
.688 .753 .901 r
.23433 .967 m .24513 .96262 L .24853 .96591 L p F P
0 g
s
.703 .629 .771 r
.40427 .93312 m .3968 .93314 L .39542 .93026 L p F P
0 g
s
.708 .631 .769 r
.3968 .93314 m .39542 .93026 L .39114 .93307 L closepath p F P
0 g
s
.889 .621 .527 r
.08736 .89924 m .09217 .90167 L .09183 .90719 L p F P
0 g
s
.886 .641 .563 r
.09217 .90167 m .08736 .89924 L .08818 .89359 L p F P
0 g
s
.701 .625 .769 r
.41113 .93306 m .4096 .92978 L .40427 .93312 L closepath p F P
0 g
s
.703 .629 .771 r
.40687 .9237 m .4096 .92978 L .40427 .93312 L p F P
0 g
s
.703 .629 .771 r
.40534 .92371 m .40687 .9237 L p .40427 .93312 L F P
0 g
s
.703 .629 .771 r
.39542 .93026 m .40534 .92371 L p .40427 .93312 L F P
0 g
s
.659 .764 .927 r
.22016 .96755 m .23089 .96399 L .23433 .967 L p F P
0 g
s
.674 .761 .916 r
.23089 .96399 m .22016 .96755 L .21668 .96484 L p F P
0 g
s
.777 .563 .609 r
.32971 .77369 m .33141 .76792 L p .33776 .77531 L F P
0 g
s
.783 .567 .608 r
.32971 .77369 m .33141 .76792 L .32886 .76739 L closepath p F P
0 g
s
.659 .639 .819 r
.48961 .95261 m .50077 .94864 L .50379 .95412 L p F P
0 g
s
.659 .633 .813 r
.49922 .94565 m .50077 .94864 L .48961 .95261 L p F P
0 g
s
.659 .633 .813 r
.48961 .95261 m .48686 .9475 L .49922 .94565 L p F P
0 g
s
0 0 0 r
.66006 .95028 m .66158 .94883 L .67171 .94463 L p F P
0 g
s
.02 0 0 r
.64868 .95506 m .66006 .95028 L .66158 .94883 L p F P
0 g
s
.828 .768 .795 r
.10566 .77293 m .10975 .77576 L .10317 .78301 L p F P
0 g
s
.829 .768 .794 r
.1106 .76762 m .10566 .77293 L .10975 .77576 L p F P
0 g
s
.883 .558 .43 r
.10179 .91736 m .10231 .9211 L .10101 .92187 L p F P
0 g
s
.883 .558 .43 r
.09687 .91499 m .10179 .91736 L p .10101 .92187 L F P
0 g
s
.648 .671 .859 r
.52099 .96054 m .53221 .95727 L .53519 .96183 L p F P
0 g
s
.648 .656 .844 r
.53221 .95727 m .52099 .96054 L .51799 .95571 L p F P
0 g
s
.711 .636 .772 r
.39239 .92367 m .39542 .93026 L .39114 .93307 L p F P
0 g
s
.711 .636 .772 r
.39215 .92367 m .39239 .92367 L p .39114 .93307 L F P
0 g
s
.711 .636 .772 r
.38123 .93124 m .39215 .92367 L p .39114 .93307 L F P
0 g
s
.711 .636 .772 r
.39114 .93307 m .38203 .93286 L .38123 .93124 L p F P
0 g
s
.8 .537 .541 r
.30845 .75082 m .3038 .74963 L .30407 .74426 L p F P
0 g
s
.813 .549 .539 r
.29729 .74229 m .30407 .74426 L .3038 .74963 L p F P
0 g
s
.695 .622 .771 r
.41865 .93284 m .41113 .93306 L .4096 .92978 L p F P
0 g
s
.654 .651 .834 r
.51498 .95045 m .5173 .95451 L .50529 .95666 L p F P
0 g
s
.654 .651 .834 r
.50529 .95666 m .50379 .95412 L .51498 .95045 L p F P
0 g
s
.642 .468 .633 r
.45083 .78997 m .44987 .78358 L .46236 .78172 L p F P
0 g
s
.641 .461 .623 r
.46156 .77549 m .46236 .78172 L .44987 .78358 L p F P
0 g
s
.656 .484 .639 r
.43821 .79313 m .44007 .79118 L .43794 .79143 L closepath p F P
0 g
s
.671 .498 .642 r
.43794 .79143 m .43821 .79313 L .43375 .7984 L p F P
0 g
s
.699 .747 .888 r
.24513 .96262 m .23433 .967 L .23089 .96399 L p F P
0 g
s
.315 .016 .288 r
.68446 .93302 m .68506 .93275 L .68513 .93241 L closepath p F P
0 g
s
.607 .77 .958 r
.22363 .70824 m .23427 .70562 L .23774 .70845 L p F P
0 g
s
.592 .767 .963 r
.23427 .70562 m .22363 .70824 L .22015 .70514 L p F P
0 g
s
.684 .773 .919 r
.20941 .70951 m .22015 .70514 L .22363 .70824 L p F P
0 g
s
.646 .743 .919 r
.57005 .70824 m .58136 .7049 L .58425 .70831 L p F P
0 g
s
.661 .777 .935 r
.58136 .7049 m .57005 .70824 L .56715 .70569 L p F P
0 g
s
.669 .811 .951 r
.55588 .70975 m .56715 .70569 L .57005 .70824 L p F P
0 g
s
.561 .88 .992 r
.62125 .96262 m .62048 .96235 L .60911 .96554 L p F P
0 g
s
.588 .856 .994 r
.62048 .96235 m .60911 .96554 L .60629 .96384 L p F P
0 g
s
.593 .846 .992 r
.59494 .96681 m .60629 .96384 L .60911 .96554 L p F P
0 g
s
.733 .555 .651 r
.36738 .79848 m .37761 .79921 L .37371 .80573 L p F P
0 g
s
.733 .549 .643 r
.37761 .79921 m .36738 .79848 L .36726 .79788 L p F P
0 g
s
.725 .544 .646 r
.38425 .80627 m .37371 .80573 L .37761 .79921 L p F P
0 g
s
.864 .743 .727 r
.08122 .82007 m .08547 .82279 L .08141 .82931 L p F P
0 g
s
.859 .746 .738 r
.08314 .81719 m .08122 .82007 L .08547 .82279 L p F P
0 g
s
.889 .645 .563 r
.08345 .89112 m .08818 .89359 L .08736 .89924 L p F P
0 g
s
.885 .66 .592 r
.08818 .89359 m .08345 .89112 L .08471 .88535 L p F P
0 g
s
.778 .775 .849 r
.15523 .7274 m .15779 .72549 L .16191 .72835 L p F P
0 g
s
.777 .776 .852 r
.16623 .71929 m .15779 .72549 L .16191 .72835 L p F P
0 g
s
.777 .776 .852 r
.16191 .72835 m .16977 .72257 L .16623 .71929 L p F P
0 g
s
.617 .801 .97 r
.58075 .96733 m .59208 .96446 L .59494 .96681 L p F P
0 g
s
.627 .765 .946 r
.59208 .96446 m .58075 .96733 L .57785 .96442 L p F P
0 g
s
.735 .689 .807 r
.32428 .93927 m .32748 .94459 L .32141 .94861 L p F P
0 g
s
.735 .689 .807 r
.31321 .94706 m .32428 .93927 L p .32141 .94861 L F P
0 g
s
.735 .689 .807 r
.32141 .94861 m .31347 .94746 L .31321 .94706 L p F P
0 g
s
.521 .516 .791 r
.70196 .77959 m .69352 .77856 L .69208 .775 L p F P
0 g
s
.714 .638 .771 r
.38203 .93286 m .38123 .93124 L .37899 .93276 L closepath p F P
0 g
s
.562 .594 .843 r
.65106 .73616 m .65009 .7343 L .65368 .73412 L closepath p F P
0 g
s
.622 .445 .621 r
.46236 .78172 m .46156 .77549 L .47365 .77323 L p F P
0 g
s
.621 .435 .609 r
.47301 .76718 m .47365 .77323 L .46156 .77549 L p F P
0 g
s
.695 .621 .769 r
.42508 .93264 m .42377 .92981 L .41865 .93284 L closepath p F P
0 g
s
.695 .622 .771 r
.42092 .92336 m .42377 .92981 L .41865 .93284 L p F P
0 g
s
.695 .622 .771 r
.41986 .92339 m .42092 .92336 L p .41865 .93284 L F P
0 g
s
.695 .622 .771 r
.4096 .92978 m .41986 .92339 L p .41865 .93284 L F P
0 g
s
.868 .732 .711 r
.07759 .83576 m .08195 .83843 L .07842 .8448 L p F P
0 g
s
.865 .735 .717 r
.08195 .83843 m .07759 .83576 L .08141 .82931 L p F P
0 g
s
.734 .548 .641 r
.36007 .79119 m .35687 .7975 L .36696 .79844 L p F P
0 g
s
.751 .565 .644 r
.35063 .79006 m .36007 .79119 L .35687 .7975 L p F P
0 g
s
.692 .52 .651 r
.42577 .79906 m .42696 .8057 L .41327 .80639 L p F P
0 g
s
.672 .502 .647 r
.42577 .79906 m .43375 .7984 L .42725 .80568 L p F P
0 g
s
.672 .502 .647 r
.42725 .80568 m .42696 .8057 L .42577 .79906 L p F P
0 g
s
.73 .664 .785 r
.34172 .94236 m .34441 .94045 L .34041 .94005 L closepath p F P
0 g
s
.661 .491 .643 r
.44007 .79118 m .45083 .78997 L p .43904 .79797 L F P
0 g
s
.661 .491 .643 r
.43904 .79797 m .43821 .79313 L .44007 .79118 L p F P
0 g
s
.479 .239 .472 r
.50631 .74111 m .50665 .7361 L .51726 .73223 L p F P
0 g
s
.434 .148 .377 r
.5181 .72776 m .51726 .73223 L .50665 .7361 L p F P
0 g
s
.735 .683 .8 r
.31273 .94737 m .30219 .95421 L .29893 .9496 L p F P
0 g
s
.68 .774 .922 r
.22015 .70514 m .20941 .70951 L .20592 .7063 L p F P
0 g
s
.615 .807 .974 r
.60629 .96384 m .59494 .96681 L .59208 .96446 L p F P
0 g
s
.7 .528 .652 r
.41127 .80643 m .39905 .80659 L .39869 .80474 L p F P
0 g
s
.71 .534 .65 r
.39905 .80659 m .39869 .80474 L .39744 .80658 L closepath p F P
0 g
s
.756 .56 .632 r
.35063 .79006 m .34967 .78994 L .34848 .78326 L p F P
0 g
s
.756 .56 .632 r
.34419 .78269 m .34848 .78326 L .34967 .78994 L p F P
0 g
s
.68 .614 .775 r
.45191 .93086 m .45212 .93133 L .441 .93699 L p F P
0 g
s
.68 .614 .775 r
.441 .93699 m .43866 .9319 L .45191 .93086 L p F P
0 g
s
.542 .554 .817 r
.67044 .75179 m .67084 .75148 L p .68048 .75797 L F P
0 g
s
.546 .564 .824 r
.67044 .75179 m .67029 .75147 L .67084 .75148 L closepath p F P
0 g
s
.719 .636 .765 r
.36702 .93268 m .36765 .93223 L .37899 .93276 L p F P
0 g
s
.711 .63 .766 r
.37812 .92468 m .36765 .93223 L .37899 .93276 L p F P
0 g
s
.711 .63 .766 r
.37899 .93276 m .38123 .93124 L .37812 .92468 L p F P
0 g
s
.859 .486 .34 r
.11457 .93218 m .1094 .92989 L .10774 .92489 L p F P
0 g
s
.861 .484 .333 r
.10259 .92259 m .10774 .92489 L .1094 .92989 L p F P
0 g
s
.87 .535 .415 r
.10774 .92489 m .10259 .92259 L .10231 .9211 L p F P
0 g
s
.218 0 .145 r
.69486 .92811 m .68506 .93275 L .68369 .93678 L p F P
0 g
s
.273 0 .273 r
.6957 .9236 m .69486 .92811 L .68506 .93275 L p F P
0 g
s
.577 .619 .858 r
.64435 .72349 m .63285 .72459 L .62997 .71951 L p F P
0 g
s
.461 .373 .67 r
.72009 .86189 m .72765 .85714 L .7217 .85311 L p F P
0 g
s
.452 .353 .652 r
.72009 .86189 m .72765 .85714 L p .72303 .86749 L F P
0 g
s
.452 .353 .652 r
.72303 .86749 m .72084 .86565 L .72009 .86189 L p F P
0 g
s
.671 .498 .642 r
.43904 .79797 m .43821 .79313 L .43375 .7984 L closepath p F P
0 g
s
.412 .746 .994 r
.18495 .96417 m .18844 .9642 L .18487 .962 L p F P
0 g
s
.412 .746 .994 r
.18487 .962 m .17895 .96219 L .18495 .96417 L p F P
0 g
s
.238 .687 .954 r
.17446 .96214 m .17895 .96219 L .18495 .96417 L p F P
0 g
s
.614 .9 .986 r
.55318 .70868 m .55588 .70975 L .56715 .70569 L p F P
0 g
s
.776 .572 .624 r
.32972 .77377 m .33776 .77531 L .33557 .78131 L p F P
0 g
s
.777 .563 .609 r
.33776 .77531 m .32972 .77377 L .32971 .77369 L p F P
0 g
s
.765 .56 .62 r
.34419 .78269 m .33557 .78131 L .33776 .77531 L p F P
0 g
s
.545 .567 .827 r
.67084 .75148 m .67029 .75147 L .66741 .74548 L p F P
0 g
s
.697 .524 .65 r
.41327 .80639 m .41286 .80429 L .41127 .80643 L closepath p F P
0 g
s
.814 .46 .388 r
.28762 .73386 m .28442 .73283 L .28282 .72805 L p F P
0 g
s
.828 .477 .392 r
.27685 .72581 m .28282 .72805 L .28442 .73283 L p F P
0 g
s
.483 .425 .716 r
.72324 .83259 m .71761 .83035 L .7218 .82755 L closepath p F P
0 g
s
.492 .44 .727 r
.72016 .82217 m .7218 .82755 L .71761 .83035 L p F P
0 g
s
.492 .44 .727 r
.71745 .82124 m .72016 .82217 L p .71761 .83035 L F P
0 g
s
.687 .617 .772 r
.43473 .93211 m .42508 .93264 L .42377 .92981 L p F P
0 g
s
.772 .559 .611 r
.32886 .76739 m .3234 .76635 L p .32968 .77377 L F P
0 g
s
.772 .559 .611 r
.32968 .77377 m .32971 .77369 L .32886 .76739 L p F P
0 g
s
.627 .701 .899 r
.58425 .70831 m .5956 .70555 L .59849 .70951 L p F P
0 g
s
.636 .721 .909 r
.5956 .70555 m .58425 .70831 L .58136 .7049 L p F P
0 g
s
.585 .63 .863 r
.62997 .71951 m .62464 .72016 L .62865 .71723 L closepath p F P
0 g
s
.589 .642 .872 r
.62709 .71462 m .62865 .71723 L .62464 .72016 L p F P
0 g
s
.589 .642 .872 r
.61565 .71626 m .62709 .71462 L p .62464 .72016 L F P
0 g
s
.705 .624 .764 r
.39542 .93026 m .40534 .92371 L .39239 .92367 L closepath p F P
0 g
s
.594 .647 .872 r
.62709 .71462 m .61565 .71626 L .61277 .71165 L p F P
0 g
s
.73 .663 .784 r
.35102 .93109 m .3528 .93452 L .34441 .94045 L p F P
0 g
s
.73 .663 .784 r
.34658 .93073 m .35102 .93109 L p .34441 .94045 L F P
0 g
s
.73 .663 .784 r
.33855 .93674 m .34658 .93073 L p .34441 .94045 L F P
0 g
s
.73 .663 .784 r
.34441 .94045 m .34041 .94005 L .33855 .93674 L p F P
0 g
s
.47 .716 .977 r
.23774 .70845 m .24577 .70847 L .25127 .7109 L p F P
0 g
s
.431 .701 .978 r
.24577 .70847 m .23774 .70845 L .23427 .70562 L p F P
0 g
s
.854 .753 .752 r
.08642 .80391 m .09059 .80667 L .08573 .81342 L p F P
0 g
s
.85 .755 .758 r
.0913 .79739 m .08642 .80391 L .09059 .80667 L p F P
0 g
s
.884 .677 .617 r
.08471 .88535 m .08005 .88285 L .08171 .87698 L p F P
0 g
s
.888 .664 .593 r
.08005 .88285 m .08471 .88535 L .08345 .89112 L p F P
0 g
s
.676 .621 .787 r
.4663 .93272 m .46924 .93905 L .45638 .94043 L p F P
0 g
s
.676 .621 .787 r
.45638 .94043 m .45517 .93794 L .4663 .93272 L p F P
0 g
s
.713 .621 .753 r
.39215 .92367 m .38123 .93124 L .37812 .92468 L p F P
0 g
s
.828 .768 .795 r
.09921 .78004 m .10566 .77293 L p .10317 .78301 L F P
0 g
s
.828 .768 .795 r
.10317 .78301 m .10034 .78108 L .09921 .78004 L p F P
0 g
s
.836 .765 .783 r
.10284 .7834 m .10317 .78301 L .10034 .78108 L closepath p F P
0 g
s
.663 .629 .805 r
.47239 .94544 m .48354 .9409 L p .4844 .94781 L F P
0 g
s
.667 .616 .789 r
.48354 .9409 m .47239 .94544 L .46935 .93928 L p F P
0 g
s
.803 .56 .57 r
.31713 .75893 m .31005 .75706 L .31086 .75151 L p F P
0 g
s
.811 .568 .57 r
.30845 .75082 m .31086 .75151 L .31005 .75706 L p F P
0 g
s
.7 .533 .658 r
.39905 .80659 m .41127 .80643 L .40581 .81341 L p F P
0 g
s
.7 .533 .658 r
.40581 .81341 m .40049 .81348 L .39905 .80659 L p F P
0 g
s
.71 .539 .656 r
.39744 .80658 m .39905 .80659 L .40049 .81348 L p F P
0 g
s
.841 .764 .777 r
.09725 .79007 m .10284 .7834 L .10034 .78108 L p F P
0 g
s
.697 .617 .763 r
.4096 .92978 m .41986 .92339 L .40687 .9237 L closepath p F P
0 g
s
.71 .539 .656 r
.40049 .81348 m .39255 .81339 L .39744 .80658 L p F P
0 g
s
.715 .546 .659 r
.38508 .8063 m .39744 .80658 L .39255 .81339 L p F P
0 g
s
.54 .557 .82 r
.67084 .75148 m .68194 .75184 L .67906 .7456 L p F P
0 g
s
.54 .557 .82 r
.67906 .7456 m .67833 .74558 L .67084 .75148 L p F P
0 g
s
.545 .567 .827 r
.66741 .74548 m .67833 .74558 L .67084 .75148 L p F P
0 g
s
.542 .554 .817 r
.67084 .75148 m .68194 .75184 L p .68048 .75797 L F P
0 g
s
.279 .76 .658 r
.64817 .95527 m .64868 .95506 L .66006 .95028 L p F P
0 g
s
.329 .726 .982 r
.17895 .96219 m .17446 .96214 L .17084 .96035 L p F P
0 g
s
.601 .418 .607 r
.47365 .77323 m .47301 .76718 L .48473 .76452 L p F P
0 g
s
.597 .404 .591 r
.48426 .75865 m .48473 .76452 L .47301 .76718 L p F P
0 g
s
.521 .516 .791 r
.69208 .775 m .69592 .77206 L p .70196 .77959 L F P
0 g
s
.525 .527 .8 r
.69208 .775 m .69062 .77155 L .69592 .77206 L closepath p F P
0 g
s
0 .362 .69 r
.15469 .956 m .15697 .95693 L .15329 .95538 L p F P
0 g
s
0 .362 .69 r
.15329 .95538 m .14911 .95388 L .15469 .956 L p F P
0 g
s
.395 .119 .372 r
.52836 .72349 m .5181 .72776 L .51726 .73223 L p F P
0 g
s
.309 0 .176 r
.53002 .71989 m .52836 .72349 L .5181 .72776 L p F P
0 g
s
.212 0 .125 r
.53998 .71526 m .53002 .71989 L .52836 .72349 L p F P
0 g
s
.016 0 0 r
.54173 .71398 m .53998 .71526 L .53002 .71989 L p F P
0 g
s
.88 .715 .673 r
.07538 .85104 m .07978 .85367 L .07707 .85982 L p F P
0 g
s
.875 .72 .687 r
.07811 .84542 m .07538 .85104 L .07978 .85367 L p F P
0 g
s
.737 .551 .642 r
.36738 .79848 m .36726 .79788 L .36696 .79844 L closepath p F P
0 g
s
.697 .529 .656 r
.41127 .80643 m .41327 .80639 L .41466 .81323 L p F P
0 g
s
.697 .529 .656 r
.41466 .81323 m .40581 .81341 L .41127 .80643 L p F P
0 g
s
.686 .521 .658 r
.41327 .80639 m .42696 .8057 L p .42087 .81292 L F P
0 g
s
.686 .521 .658 r
.42087 .81292 m .41466 .81323 L .41327 .80639 L p F P
0 g
s
.719 .749 .876 r
.24513 .96262 m .24629 .96202 L .25303 .96379 L p F P
0 g
s
.704 .733 .873 r
.25603 .95708 m .24629 .96202 L .25303 .96379 L p F P
0 g
s
.704 .733 .873 r
.25303 .96379 m .25939 .96081 L .25603 .95708 L p F P
0 g
s
.562 .597 .847 r
.65368 .73412 m .65009 .7343 L .64722 .72886 L p F P
0 g
s
.371 .162 .461 r
.71168 .90561 m .70591 .90867 L .7058 .91387 L p F P
0 g
s
.4 .215 .511 r
.70591 .90867 m .71168 .90561 L .71201 .89986 L p F P
0 g
s
.721 .641 .768 r
.36702 .93268 m .36765 .93223 L .36677 .93218 L closepath p F P
0 g
s
.723 .64 .765 r
.36677 .93218 m .36702 .93268 L p .3528 .93452 L F P
0 g
s
.733 .555 .651 r
.37371 .80573 m .36882 .80538 L .36738 .79848 L p F P
0 g
s
.737 .557 .65 r
.36696 .79844 m .36738 .79848 L .36882 .80538 L p F P
0 g
s
.643 .667 .858 r
.54644 .95875 m .53519 .96183 L .53221 .95727 L p F P
0 g
s
.764 .776 .862 r
.17482 .71914 m .16977 .72257 L .16623 .71929 L p F P
0 g
s
.737 .557 .65 r
.36882 .80538 m .3632 .80492 L .36696 .79844 L p F P
0 g
s
.746 .562 .646 r
.35687 .7975 m .36696 .79844 L .3632 .80492 L p F P
0 g
s
.737 .665 .78 r
.33465 .9395 m .32748 .94459 L .32428 .93927 L p F P
0 g
s
.756 .56 .632 r
.34967 .78994 m .3415 .78884 L .34419 .78269 L p F P
0 g
s
.77 .571 .63 r
.33557 .78131 m .34419 .78269 L .3415 .78884 L p F P
0 g
s
.715 .546 .659 r
.38445 .80722 m .38508 .8063 L p .39255 .81339 L F P
0 g
s
.718 .545 .655 r
.38445 .80722 m .38508 .8063 L .38425 .80627 L closepath p F P
0 g
s
.721 .64 .767 r
.37749 .92329 m .37812 .92468 L .36765 .93223 L p F P
0 g
s
.721 .64 .767 r
.36841 .92288 m .37749 .92329 L p .36765 .93223 L F P
0 g
s
.721 .64 .767 r
.3639 .92632 m .36841 .92288 L p .36765 .93223 L F P
0 g
s
.721 .64 .767 r
.36765 .93223 m .36677 .93218 L .3639 .92632 L p F P
0 g
s
.672 .503 .648 r
.43375 .7984 m .43904 .79797 L .44025 .80462 L p F P
0 g
s
.672 .503 .648 r
.44025 .80462 m .42725 .80568 L .43375 .7984 L p F P
0 g
s
.729 .558 .659 r
.38425 .80627 m .38445 .80722 L .38056 .81301 L p F P
0 g
s
.729 .558 .659 r
.37371 .80573 m .38425 .80627 L p .38056 .81301 L F P
0 g
s
.653 .633 .817 r
.51498 .95045 m .50379 .95412 L .50077 .94864 L p F P
0 g
s
.737 .713 .829 r
.28793 .95652 m .28932 .95564 L .28689 .95516 L closepath p F P
0 g
s
.728 .709 .832 r
.28689 .95516 m .28793 .95652 L p .27366 .95874 L F P
0 g
s
.723 .64 .765 r
.3528 .93452 m .35679 .93157 L .36677 .93218 L p F P
0 g
s
.723 .64 .766 r
.36677 .93218 m .3639 .92632 L .35679 .93157 L closepath p F P
0 g
s
.729 .663 .785 r
.34041 .94005 m .33855 .93674 L .33465 .9395 L closepath p F P
0 g
s
.836 .407 .218 r
.1094 .92989 m .11457 .93218 L .11705 .93697 L p F P
0 g
s
.836 .413 .231 r
.12221 .93924 m .11705 .93697 L .11457 .93218 L p F P
0 g
s
.687 .617 .772 r
.42377 .92981 m .43488 .92335 L p .43473 .93211 L F P
0 g
s
.69 .612 .764 r
.43461 .9227 m .43488 .92335 L .42377 .92981 L p F P
0 g
s
.69 .612 .764 r
.42377 .92981 m .42092 .92336 L .43461 .9227 L p F P
0 g
s
.72 .77 .892 r
.19511 .71182 m .19533 .71171 L .19431 .71108 L closepath p F P
0 g
s
.747 .775 .876 r
.19431 .71108 m .19511 .71182 L p .18071 .71519 L F P
0 g
s
.688 .617 .772 r
.43866 .9319 m .43794 .93034 L .43473 .93211 L closepath p F P
0 g
s
.687 .617 .772 r
.43488 .92335 m .43794 .93034 L .43473 .93211 L p F P
0 g
s
.714 .77 .897 r
.20242 .70311 m .20592 .7063 L .19533 .71171 L p F P
0 g
s
.714 .77 .897 r
.1916 .70857 m .20242 .70311 L p .19533 .71171 L F P
0 g
s
.714 .77 .897 r
.19533 .71171 m .19431 .71108 L .1916 .70857 L p F P
0 g
s
.79 .562 .592 r
.3234 .76635 m .31583 .76464 L .31713 .75893 L p F P
0 g
s
.804 .576 .593 r
.31005 .75706 m .31713 .75893 L .31583 .76464 L p F P
0 g
s
.715 .546 .659 r
.39255 .81339 m .38576 .81323 L .38445 .80722 L p F P
0 g
s
.722 .55 .657 r
.38576 .81323 m .38445 .80722 L .38056 .81301 L closepath p F P
0 g
s
.887 .681 .618 r
.07713 .87444 m .08171 .87698 L .08005 .88285 L p F P
0 g
s
.883 .691 .638 r
.08171 .87698 m .07713 .87444 L .07918 .86847 L p F P
0 g
s
.666 .636 .81 r
.48686 .9475 m .48657 .94696 L .4844 .94781 L closepath p F P
0 g
s
.663 .629 .805 r
.48354 .9409 m .48657 .94696 L .4844 .94781 L p F P
0 g
s
.674 .607 .772 r
.4663 .93272 m .45517 .93794 L .45212 .93133 L p F P
0 g
s
.738 .712 .828 r
.29568 .94488 m .29893 .9496 L .28932 .95564 L p F P
0 g
s
.738 .712 .828 r
.28464 .9522 m .29568 .94488 L p .28932 .95564 L F P
0 g
s
.738 .712 .828 r
.28932 .95564 m .28689 .95516 L .28464 .9522 L p F P
0 g
s
.452 .353 .651 r
.72141 .86849 m .72084 .86565 L .72303 .86749 L closepath p F P
0 g
s
.819 .388 .22 r
.26896 .7194 m .26957 .71941 L p .27685 .72581 L F P
0 g
s
.689 .157 0 r
.26896 .7194 m .26853 .71902 L .26957 .71941 L closepath p F P
0 g
s
.685 .616 .773 r
.44906 .92434 m .45191 .93086 L .43866 .9319 L p F P
0 g
s
.685 .616 .773 r
.43866 .9319 m .43794 .93034 L .44906 .92434 L p F P
0 g
s
.811 .568 .57 r
.31005 .75706 m .30873 .75668 L .30845 .75082 L p F P
0 g
s
.801 .559 .572 r
.3038 .74963 m .30845 .75082 L .30873 .75668 L p F P
0 g
s
.726 .205 0 r
.12251 .93969 m .12338 .93975 L p .13175 .9458 L F P
0 g
s
.803 .341 .135 r
.12251 .93969 m .12221 .93924 L .12338 .93975 L closepath p F P
0 g
s
.525 .528 .8 r
.69592 .77206 m .69062 .77155 L .68805 .76548 L p F P
0 g
s
.728 .65 .772 r
.3528 .93452 m .35679 .93157 L .35102 .93109 L closepath p F P
0 g
s
.576 .388 .589 r
.48473 .76452 m .48426 .75865 L .49561 .7556 L p F P
0 g
s
.568 .366 .566 r
.49534 .74994 m .49561 .7556 L .48426 .75865 L p F P
0 g
s
.459 .373 .671 r
.72762 .84932 m .7217 .85311 L .72765 .85714 L p F P
0 g
s
.471 .392 .686 r
.7264 .8444 m .72762 .84932 L .7217 .85311 L p F P
0 g
s
.471 .392 .686 r
.72438 .84326 m .7264 .8444 L p .7217 .85311 L F P
0 g
s
.829 .535 .492 r
.29729 .74229 m .29098 .74016 L .29061 .735 L p F P
0 g
s
.842 .546 .488 r
.28762 .73386 m .29061 .735 L .29098 .74016 L p F P
0 g
s
.656 .492 .65 r
.43904 .79797 m .45188 .79646 L p .44724 .80378 L F P
0 g
s
.656 .492 .65 r
.44724 .80378 m .44025 .80462 L .43904 .79797 L p F P
0 g
s
.661 .491 .643 r
.45083 .78997 m .45188 .79646 L .43904 .79797 L p F P
0 g
s
.617 .687 .893 r
.60988 .70721 m .59849 .70951 L .5956 .70555 L p F P
0 g
s
.463 0 0 r
.25172 .71094 m .2524 .71135 L p .26274 .71671 L F P
0 g
s
.273 .674 .97 r
.25172 .71094 m .25127 .7109 L .2524 .71135 L closepath p F P
0 g
s
.84 .764 .778 r
.09316 .78727 m .09725 .79007 L .09154 .79708 L p F P
0 g
s
.841 .764 .777 r
.09907 .7802 m .09316 .78727 L .09725 .79007 L p F P
0 g
s
.841 .764 .777 r
.10034 .78108 m .09907 .7802 L p .09725 .79007 L F P
0 g
s
.751 .565 .644 r
.34997 .79144 m .35063 .79006 L p .35687 .7975 L F P
0 g
s
.756 .567 .641 r
.34997 .79144 m .35063 .79006 L .34967 .78994 L closepath p F P
0 g
s
.405 .245 .548 r
.72239 .88807 m .71479 .89239 L .71524 .89812 L p F P
0 g
s
.425 .281 .581 r
.71479 .89239 m .72239 .88807 L .72011 .88301 L p F P
0 g
s
.419 .255 .55 r
.71201 .89986 m .71524 .89812 L .71479 .89239 L p F P
0 g
s
.661 .634 .812 r
.49774 .94279 m .49922 .94565 L .48686 .9475 L p F P
0 g
s
.661 .634 .812 r
.48686 .9475 m .48657 .94696 L .49774 .94279 L p F P
0 g
s
.764 .776 .862 r
.16623 .71929 m .1707 .71627 L .17482 .71914 L p F P
0 g
s
.763 .777 .864 r
.17718 .71194 m .1707 .71627 L .17482 .71914 L p F P
0 g
s
.763 .777 .864 r
.17482 .71914 m .18071 .71519 L .17718 .71194 L p F P
0 g
s
.729 .687 .81 r
.31347 .94746 m .31321 .94706 L .31273 .94737 L closepath p F P
0 g
s
.733 .558 .655 r
.37015 .81146 m .37371 .80573 L .36882 .80538 L closepath p F P
0 g
s
.729 .558 .659 r
.37015 .81146 m .37371 .80573 L p .38056 .81301 L F P
0 g
s
.64 .472 .64 r
.45083 .78997 m .46327 .78806 L p .45622 .79579 L F P
0 g
s
.64 .472 .64 r
.45622 .79579 m .45188 .79646 L .45083 .78997 L p F P
0 g
s
.642 .468 .633 r
.46236 .78172 m .46327 .78806 L .45083 .78997 L p F P
0 g
s
.772 .559 .611 r
.3234 .76635 m .3216 .77221 L .32968 .77377 L p F P
0 g
s
.793 .576 .607 r
.31583 .76464 m .3234 .76635 L .3216 .77221 L p F P
0 g
s
.673 .508 .654 r
.42701 .80593 m .42725 .80568 L .42696 .8057 L closepath p F P
0 g
s
.686 .521 .658 r
.42696 .8057 m .42701 .80593 L .42087 .81292 L p F P
0 g
s
.868 .739 .718 r
.07714 .8266 m .08141 .82931 L .07759 .83576 L p F P
0 g
s
.864 .743 .727 r
.08141 .82931 m .07714 .8266 L .08122 .82007 L p F P
0 g
s
.75 .563 .642 r
.34967 .78994 m .3415 .78884 L p .3475 .79635 L F P
0 g
s
.75 .563 .642 r
.3475 .79635 m .34997 .79144 L .34967 .78994 L p F P
0 g
s
.671 .511 .66 r
.42725 .80568 m .44025 .80462 L p .43884 .81161 L F P
0 g
s
.671 .511 .66 r
.42701 .80593 m .42725 .80568 L p .43884 .81161 L F P
0 g
s
.279 .76 .658 r
.66006 .95028 m .6584 .9512 L .64817 .95527 L p F P
0 g
s
.362 .83 .784 r
.64602 .95571 m .64817 .95527 L .6584 .9512 L p F P
0 g
s
.315 .801 .767 r
.63462 .95958 m .64602 .95571 L .64817 .95527 L p F P
0 g
s
.671 .511 .66 r
.43884 .81161 m .42835 .81253 L .42701 .80593 L p F P
0 g
s
.685 .52 .657 r
.42835 .81253 m .42701 .80593 L .42087 .81292 L closepath p F P
0 g
s
.683 .601 .758 r
.44906 .92434 m .43794 .93034 L .43488 .92335 L p F P
0 g
s
.737 .665 .78 r
.32428 .93927 m .32545 .93839 L .33465 .9395 L p F P
0 g
s
.726 .657 .781 r
.33538 .93095 m .32545 .93839 L .33465 .9395 L p F P
0 g
s
.726 .657 .781 r
.33465 .9395 m .33855 .93674 L .33538 .93095 L p F P
0 g
s
.728 .709 .832 r
.27366 .95874 m .28117 .95425 L .28689 .95516 L p F P
0 g
s
.737 .712 .828 r
.28117 .95425 m .27366 .95874 L .27034 .95473 L p F P
0 g
s
.724 .723 .85 r
.25939 .96081 m .27034 .95473 L .27366 .95874 L p F P
0 g
s
.735 .683 .8 r
.29893 .9496 m .3039 .94616 L .31273 .94737 L p F P
0 g
s
.726 .68 .805 r
.30999 .94199 m .3039 .94616 L .31273 .94737 L p F P
0 g
s
.726 .68 .805 r
.31273 .94737 m .31321 .94706 L .30999 .94199 L p F P
0 g
s
.75 .252 .044 r
.26853 .71902 m .26896 .7194 L .26536 .71964 L p F P
0 g
s
.75 .252 .044 r
.26536 .71964 m .26274 .71671 L .26853 .71902 L p F P
0 g
s
.659 .617 .795 r
.49774 .94279 m .48657 .94696 L .48354 .9409 L p F P
0 g
s
.701 .536 .662 r
.4016 .81862 m .40581 .81341 L .40049 .81348 L closepath p F P
0 g
s
.704 .538 .661 r
.40049 .81348 m .39255 .81339 L p .40016 .82045 L F P
0 g
s
.704 .538 .661 r
.40016 .82045 m .4016 .81862 L .40049 .81348 L p F P
0 g
s
.704 .619 .76 r
.40687 .9237 m .40652 .92292 L .40534 .92371 L closepath p F P
0 g
s
.706 .623 .763 r
.40344 .91573 m .40652 .92292 L .40534 .92371 L p F P
0 g
s
.706 .623 .763 r
.39233 .92354 m .40344 .91573 L p .40534 .92371 L F P
0 g
s
.706 .623 .763 r
.40534 .92371 m .39239 .92367 L .39233 .92354 L p F P
0 g
s
.697 .616 .762 r
.41986 .92339 m .40687 .9237 L .40652 .92292 L p F P
0 g
s
.728 .649 .771 r
.36207 .92248 m .3639 .92632 L .35679 .93157 L p F P
0 g
s
.728 .649 .771 r
.35765 .92218 m .36207 .92248 L p .35679 .93157 L F P
0 g
s
.728 .649 .771 r
.34965 .92844 m .35765 .92218 L p .35679 .93157 L F P
0 g
s
.728 .649 .771 r
.35679 .93157 m .35102 .93109 L .34965 .92844 L p F P
0 g
s
.736 .668 .783 r
.32428 .93927 m .31321 .94706 L .30999 .94199 L p F P
0 g
s
.747 .775 .876 r
.18071 .71519 m .19112 .70886 L .19431 .71108 L p F P
0 g
s
.746 .775 .877 r
.19431 .71108 m .1916 .70857 L .19112 .70886 L closepath p F P
0 g
s
.71 .625 .761 r
.39239 .92367 m .39233 .92354 L .39215 .92367 L closepath p F P
0 g
s
.713 .621 .753 r
.37812 .92468 m .37989 .92338 L .39215 .92367 L p F P
0 g
s
.707 .617 .755 r
.38924 .9165 m .37989 .92338 L .39215 .92367 L p F P
0 g
s
.707 .617 .755 r
.39215 .92367 m .39233 .92354 L .38924 .9165 L p F P
0 g
s
.727 .71 .834 r
.28689 .95516 m .28464 .9522 L .28117 .95425 L closepath p F P
0 g
s
.858 .751 .743 r
.08573 .81342 m .08314 .81719 L .0795 .81363 L p F P
0 g
s
.858 .751 .743 r
.0795 .81363 m .08153 .81067 L .08573 .81342 L p F P
0 g
s
.854 .753 .752 r
.08573 .81342 m .08153 .81067 L .08642 .80391 L p F P
0 g
s
.698 .538 .667 r
.40581 .81341 m .41466 .81323 L p .41437 .82021 L F P
0 g
s
.698 .538 .667 r
.4016 .81862 m .40581 .81341 L p .41437 .82021 L F P
0 g
s
.708 .609 .744 r
.40344 .91573 m .39233 .92354 L .38924 .9165 L p F P
0 g
s
.704 .538 .661 r
.39255 .81339 m .3875 .82026 L .40016 .82045 L p F P
0 g
s
.715 .548 .662 r
.38576 .81323 m .39255 .81339 L .3875 .82026 L p F P
0 g
s
.638 .71 .899 r
.5608 .96022 m .56363 .96388 L p .5494 .963 L F P
0 g
s
.638 .71 .899 r
.5494 .963 m .55142 .96248 L .5608 .96022 L p F P
0 g
s
.638 .684 .877 r
.5494 .963 m .55142 .96248 L .54939 .96298 L closepath p F P
0 g
s
.439 .327 .63 r
.72303 .86749 m .72141 .86849 L .72252 .87488 L p F P
0 g
s
.489 .439 .729 r
.72016 .82217 m .71745 .82124 L .71946 .81987 L closepath p F P
0 g
s
.497 .453 .738 r
.71713 .81263 m .71946 .81987 L .71745 .82124 L p F P
0 g
s
.497 .453 .738 r
.71632 .81239 m .71713 .81263 L p .71745 .82124 L F P
0 g
s
.638 .683 .876 r
.55142 .96248 m .54939 .96298 L .54644 .95875 L p F P
0 g
s
.293 .011 .302 r
.70538 .91877 m .6957 .9236 L .69486 .92811 L p F P
0 g
s
.326 .086 .389 r
.7058 .91387 m .70538 .91877 L .6957 .9236 L p F P
0 g
s
.886 .695 .639 r
.07468 .86589 m .07918 .86847 L .07713 .87444 L p F P
0 g
s
.881 .703 .657 r
.07918 .86847 m .07468 .86589 L .07707 .85982 L p F P
0 g
s
.697 .616 .762 r
.40652 .92292 m .41763 .91557 L p .41986 .92339 L F P
0 g
s
.7 .603 .744 r
.41763 .91557 m .40652 .92292 L .40344 .91573 L p F P
0 g
s
.751 .565 .644 r
.35687 .7975 m .35105 .79679 L .34997 .79144 L p F P
0 g
s
.752 .565 .643 r
.35105 .79679 m .34997 .79144 L .3475 .79635 L closepath p F P
0 g
s
.875 .724 .692 r
.07811 .84542 m .07842 .8448 L .07673 .84378 L closepath p F P
0 g
s
.868 .732 .711 r
.07453 .8413 m .07759 .83576 L p .07842 .8448 L F P
0 g
s
.868 .732 .711 r
.07842 .8448 m .07673 .84378 L .07453 .8413 L p F P
0 g
s
.803 .776 .828 r
.13711 .74233 m .13307 .74587 L .12946 .74262 L p F P
0 g
s
.81 .776 .821 r
.12826 .75028 m .13307 .74587 L .12946 .74262 L p F P
0 g
s
.813 .775 .818 r
.12826 .75028 m .12188 .75626 L .11826 .75302 L p F P
0 g
s
.813 .775 .818 r
.11826 .75302 m .12427 .74739 L .12826 .75028 L p F P
0 g
s
.81 .776 .821 r
.12946 .74262 m .12427 .74739 L .12826 .75028 L p F P
0 g
s
.182 .621 .942 r
.25127 .7109 m .25172 .71094 L .24823 .70886 L p F P
0 g
s
.182 .621 .942 r
.24823 .70886 m .24577 .70847 L .25127 .7109 L p F P
0 g
s
.716 .627 .757 r
.37812 .92468 m .37989 .92338 L .37749 .92329 L closepath p F P
0 g
s
.73 .556 .656 r
.36882 .80538 m .3632 .80492 L p .3696 .81232 L F P
0 g
s
.73 .556 .656 r
.3696 .81232 m .37015 .81146 L .36882 .80538 L p F P
0 g
s
.746 .562 .646 r
.3632 .80492 m .35348 .80388 L .35687 .7975 L p F P
0 g
s
.751 .569 .649 r
.35105 .79679 m .35687 .7975 L .35348 .80388 L p F P
0 g
s
.794 .318 .097 r
.12221 .93924 m .12251 .93969 L .11867 .93918 L p F P
0 g
s
.794 .318 .097 r
.11867 .93918 m .11705 .93697 L .12221 .93924 L p F P
0 g
s
.395 .211 .51 r
.71524 .89812 m .71201 .89986 L .71168 .90561 L p F P
0 g
s
.686 .524 .662 r
.41579 .81855 m .42087 .81292 L .41466 .81323 L closepath p F P
0 g
s
.698 .538 .667 r
.41466 .81323 m .41579 .81855 L .41437 .82021 L p F P
0 g
s
.715 .548 .662 r
.3875 .82026 m .38734 .82025 L .38576 .81323 L p F P
0 g
s
.722 .553 .66 r
.38056 .81301 m .38576 .81323 L .38734 .82025 L p F P
0 g
s
.623 .451 .63 r
.46236 .78172 m .47442 .77943 L p .46634 .78748 L F P
0 g
s
.623 .451 .63 r
.46634 .78748 m .46327 .78806 L .46236 .78172 L p F P
0 g
s
.622 .445 .621 r
.47365 .77323 m .47442 .77943 L .46236 .78172 L p F P
0 g
s
.818 .775 .812 r
.12007 .75803 m .12188 .75626 L .11826 .75302 L p F P
0 g
s
.803 .776 .828 r
.12946 .74262 m .13311 .73943 L .13711 .74233 L p F P
0 g
s
.801 .777 .831 r
.14059 .73301 m .13311 .73943 L .13711 .74233 L p F P
0 g
s
.801 .777 .831 r
.13711 .74233 m .14418 .73625 L .14059 .73301 L p F P
0 g
s
.558 .769 .977 r
.18844 .9642 m .199 .96245 L .20253 .96498 L p F P
0 g
s
.589 .771 .966 r
.199 .96245 m .18844 .9642 L .18487 .962 L p F P
0 g
s
.772 .559 .611 r
.32972 .77377 m .32971 .77369 L .32968 .77377 L closepath p F P
0 g
s
.813 .549 .539 r
.3038 .74963 m .29701 .74766 L .29729 .74229 L p F P
0 g
s
.829 .563 .538 r
.29098 .74016 m .29729 .74229 L .29701 .74766 L p F P
0 g
s
.822 .773 .807 r
.11608 .75515 m .12007 .75803 L .11258 .76557 L p F P
0 g
s
.818 .775 .812 r
.11826 .75302 m .11608 .75515 L .12007 .75803 L p F P
0 g
s
.734 .65 .766 r
.34658 .93073 m .33855 .93674 L .33538 .93095 L p F P
0 g
s
.776 .572 .624 r
.33557 .78131 m .33086 .78041 L .32972 .77377 L p F P
0 g
s
.772 .57 .625 r
.32968 .77377 m .32972 .77377 L .33086 .78041 L p F P
0 g
s
.819 .388 .22 r
.27685 .72581 m .27126 .72344 L .26896 .7194 L p F P
0 g
s
.83 .388 .182 r
.27126 .72344 m .26896 .7194 L .26536 .71964 L p F P
0 g
s
.772 .57 .625 r
.33086 .78041 m .32739 .77979 L .32968 .77377 L p F P
0 g
s
.781 .575 .621 r
.3216 .77221 m .32968 .77377 L .32739 .77979 L p F P
0 g
s
.878 .724 .687 r
.07538 .85104 m .07811 .84542 L .07673 .84378 L p F P
0 g
s
.696 .614 .76 r
.42092 .92336 m .4207 .92287 L .41986 .92339 L closepath p F P
0 g
s
.697 .616 .762 r
.41763 .91557 m .4207 .92287 L .41986 .92339 L p F P
0 g
s
.648 .656 .844 r
.51799 .95571 m .52922 .95234 L .53221 .95727 L p F P
0 g
s
.646 .642 .832 r
.52909 .95212 m .52922 .95234 L .51799 .95571 L p F P
0 g
s
.646 .642 .832 r
.51799 .95571 m .5173 .95451 L .52909 .95212 L p F P
0 g
s
.716 .626 .756 r
.38842 .91457 m .38924 .9165 L .37989 .92338 L p F P
0 g
s
.716 .626 .756 r
.37955 .91432 m .38842 .91457 L p .37989 .92338 L F P
0 g
s
.716 .626 .756 r
.37502 .91784 m .37955 .91432 L p .37989 .92338 L F P
0 g
s
.716 .626 .756 r
.37989 .92338 m .37749 .92329 L .37502 .91784 L p F P
0 g
s
.873 .538 .412 r
.10259 .92259 m .10101 .92187 L .10231 .9211 L closepath p F P
0 g
s
.522 .918 .867 r
.55318 .70868 m .55297 .70864 L .54173 .71398 L p F P
0 g
s
0 0 0 r
.53998 .71526 m .54173 .71398 L .55297 .70864 L p F P
0 g
s
.546 .568 .828 r
.67833 .74558 m .66741 .74548 L .66526 .741 L p F P
0 g
s
.695 .613 .761 r
.43182 .91599 m .43461 .9227 L .42092 .92336 L p F P
0 g
s
.695 .613 .761 r
.42092 .92336 m .4207 .92287 L .43182 .91599 L p F P
0 g
s
.536 .545 .811 r
.68483 .7582 m .68048 .75797 L .68365 .75554 L closepath p F P
0 g
s
.542 .554 .817 r
.68194 .75184 m .68365 .75554 L .68048 .75797 L p F P
0 g
s
.667 .616 .789 r
.48191 .93748 m .48354 .9409 L p .46935 .93928 L F P
0 g
s
.667 .616 .789 r
.46935 .93928 m .47019 .93892 L .48191 .93748 L p F P
0 g
s
.665 .609 .783 r
.46935 .93928 m .47019 .93892 L .46924 .93905 L closepath p F P
0 g
s
.463 0 0 r
.26274 .71671 m .25734 .71426 L .25172 .71094 L p F P
0 g
s
0 .204 .611 r
.25734 .71426 m .25172 .71094 L .24823 .70886 L p F P
0 g
s
.665 .609 .783 r
.47019 .93892 m .46924 .93905 L .4663 .93272 L p F P
0 g
s
.72 .628 .755 r
.37749 .92329 m .37502 .91784 L .36841 .92288 L closepath p F P
0 g
s
.692 .598 .746 r
.43182 .91599 m .4207 .92287 L .41763 .91557 L p F P
0 g
s
.722 .553 .66 r
.38734 .82025 m .37589 .81976 L .38056 .81301 L p F P
0 g
s
.729 .562 .665 r
.37036 .81238 m .38056 .81301 L .37589 .81976 L p F P
0 g
s
.729 .558 .659 r
.38056 .81301 m .37036 .81238 L .37015 .81146 L p F P
0 g
s
.792 .777 .839 r
.14683 .7341 m .14418 .73625 L .14059 .73301 L p F P
0 g
s
.555 .887 .987 r
.62048 .96235 m .62125 .96262 L .63188 .95901 L p F P
0 g
s
.547 .898 .976 r
.63462 .95958 m .63188 .95901 L .62125 .96262 L p F P
0 g
s
.729 .717 .839 r
.27034 .95473 m .25939 .96081 L .25603 .95708 L p F P
0 g
s
.546 .349 .564 r
.49561 .7556 m .49534 .74994 L .50633 .7465 L p F P
0 g
s
.532 .315 .531 r
.50631 .74111 m .50633 .7465 L .49534 .74994 L p F P
0 g
s
.728 .649 .771 r
.35102 .93109 m .34965 .92844 L .34658 .93073 L closepath p F P
0 g
s
.169 .628 .935 r
.16863 .95916 m .1665 .95832 L .15697 .95693 L p F P
0 g
s
.105 .608 .899 r
.1665 .95832 m .15697 .95693 L .15329 .95538 L p F P
0 g
s
.69 .531 .666 r
.42087 .81292 m .42835 .81253 L p .41614 .82016 L F P
0 g
s
.69 .531 .666 r
.41614 .82016 m .41579 .81855 L .42087 .81292 L p F P
0 g
s
.747 .777 .878 r
.19112 .70886 m .18071 .71519 L .17718 .71194 L p F P
0 g
s
.726 .205 0 r
.13175 .9458 m .12638 .94359 L .12251 .93969 L p F P
0 g
s
.727 .21 0 r
.12638 .94359 m .12251 .93969 L .11867 .93918 L p F P
0 g
s
.667 .614 .786 r
.48191 .93748 m .4805 .9345 L .47019 .93892 L closepath p F P
0 g
s
.665 .609 .783 r
.47756 .92798 m .4805 .9345 L .47019 .93892 L p F P
0 g
s
.665 .609 .783 r
.47671 .92808 m .47756 .92798 L p .47019 .93892 L F P
0 g
s
.665 .609 .783 r
.4663 .93272 m .47671 .92808 L p .47019 .93892 L F P
0 g
s
.724 .637 .76 r
.3639 .92632 m .36841 .92288 L .36207 .92248 L closepath p F P
0 g
s
.557 .586 .839 r
.66167 .73386 m .65368 .73412 L .65948 .72955 L closepath p F P
0 g
s
.562 .597 .847 r
.65879 .72824 m .65948 .72955 L .65368 .73412 L p F P
0 g
s
.562 .597 .847 r
.64722 .72886 m .65879 .72824 L p .65368 .73412 L F P
0 g
s
.792 .777 .839 r
.14059 .73301 m .14282 .7312 L .14683 .7341 L p F P
0 g
s
.79 .778 .842 r
.15166 .72415 m .14282 .7312 L .14683 .7341 L p F P
0 g
s
.79 .778 .842 r
.14683 .7341 m .15523 .7274 L .15166 .72415 L p F P
0 g
s
.826 .772 .802 r
.11258 .76557 m .1106 .76762 L .10697 .76435 L p F P
0 g
s
.826 .772 .802 r
.10697 .76435 m .10856 .7627 L .11258 .76557 L p F P
0 g
s
.822 .773 .807 r
.11258 .76557 m .10856 .7627 L .11608 .75515 L p F P
0 g
s
.849 .76 .764 r
.0913 .79739 m .09154 .79708 L .08943 .79565 L closepath p F P
0 g
s
.84 .764 .778 r
.08765 .79401 m .09316 .78727 L p .09154 .79708 L F P
0 g
s
.84 .764 .778 r
.09154 .79708 m .08943 .79565 L .08765 .79401 L p F P
0 g
s
.542 .906 .963 r
.63188 .95901 m .63462 .95958 L .64602 .95571 L p F P
0 g
s
.638 .707 .896 r
.5608 .96022 m .56068 .96007 L .55142 .96248 L closepath p F P
0 g
s
.638 .683 .876 r
.55773 .9558 m .56068 .96007 L .55142 .96248 L p F P
0 g
s
.638 .683 .876 r
.54644 .95875 m .55773 .9558 L p .55142 .96248 L F P
0 g
s
.776 .578 .632 r
.33086 .78041 m .33557 .78131 L .33311 .78739 L p F P
0 g
s
.77 .571 .63 r
.3415 .78884 m .33311 .78739 L .33557 .78131 L p F P
0 g
s
.698 .538 .667 r
.41437 .82021 m .40202 .82046 L .4016 .81862 L p F P
0 g
s
.708 .544 .664 r
.40202 .82046 m .4016 .81862 L .40016 .82045 L closepath p F P
0 g
s
.73 .556 .656 r
.3632 .80492 m .35929 .81145 L .3696 .81232 L p F P
0 g
s
.747 .573 .659 r
.35348 .80388 m .3632 .80492 L .35929 .81145 L p F P
0 g
s
.853 .759 .759 r
.08642 .80391 m .0913 .79739 L .08943 .79565 L p F P
0 g
s
.674 .607 .772 r
.46491 .92959 m .4663 .93272 L p .45212 .93133 L F P
0 g
s
.674 .607 .772 r
.45212 .93133 m .45338 .93071 L .46491 .92959 L p F P
0 g
s
.673 .603 .769 r
.45212 .93133 m .45338 .93071 L .45191 .93086 L closepath p F P
0 g
s
.525 .528 .8 r
.68805 .76548 m .6889 .76482 L p .69592 .77206 L F P
0 g
s
.53 .538 .808 r
.68805 .76548 m .68772 .76472 L .6889 .76482 L closepath p F P
0 g
s
.577 .619 .858 r
.62997 .71951 m .64148 .71837 L .64435 .72349 L p F P
0 g
s
.578 .627 .864 r
.6386 .71332 m .64148 .71837 L .62997 .71951 L p F P
0 g
s
.578 .627 .864 r
.63277 .71394 m .6386 .71332 L p .62997 .71951 L F P
0 g
s
.578 .627 .864 r
.62997 .71951 m .62865 .71723 L .63277 .71394 L p F P
0 g
s
.862 .75 .738 r
.08122 .82007 m .08314 .81719 L .0795 .81363 L p F P
0 g
s
.648 .643 .831 r
.52621 .94698 m .52909 .95212 L .5173 .95451 L p F P
0 g
s
.648 .643 .831 r
.5173 .95451 m .51498 .95045 L .52621 .94698 L p F P
0 g
s
.831 .772 .796 r
.10566 .77293 m .1106 .76762 L .10697 .76435 L p F P
0 g
s
.745 .691 .8 r
.3039 .94616 m .29893 .9496 L .29568 .94488 L p F P
0 g
s
.673 .602 .768 r
.45338 .93071 m .45191 .93086 L .44906 .92434 L p F P
0 g
s
.633 .732 .919 r
.56363 .96388 m .57494 .96104 L .57785 .96442 L p F P
0 g
s
.635 .706 .898 r
.57201 .95724 m .57494 .96104 L .56363 .96388 L p F P
0 g
s
.635 .706 .898 r
.56997 .95775 m .57201 .95724 L p .56363 .96388 L F P
0 g
s
.635 .706 .898 r
.56363 .96388 m .5608 .96022 L .56997 .95775 L p F P
0 g
s
.887 .593 .484 r
.09687 .91499 m .09201 .91259 L .09183 .90719 L p F P
0 g
s
.89 .596 .482 r
.08702 .90477 m .09183 .90719 L .09201 .91259 L p F P
0 g
s
.889 .621 .527 r
.09183 .90719 m .08702 .90477 L .08736 .89924 L p F P
0 g
s
.801 .559 .572 r
.30873 .75668 m .30293 .7552 L .3038 .74963 L p F P
0 g
s
.814 .57 .57 r
.29701 .74766 m .3038 .74963 L .30293 .7552 L p F P
0 g
s
.824 .525 .484 r
.28442 .73283 m .28762 .73386 L .2865 .73848 L p F P
0 g
s
.842 .546 .488 r
.29098 .74016 m .2865 .73848 L .28762 .73386 L p F P
0 g
s
.603 .429 .618 r
.47365 .77323 m .48536 .77057 L p .47978 .77821 L F P
0 g
s
.603 .429 .618 r
.47978 .77821 m .47442 .77943 L .47365 .77323 L p F P
0 g
s
.601 .418 .607 r
.48473 .76452 m .48536 .77057 L .47365 .77323 L p F P
0 g
s
.529 .54 .81 r
.6889 .76482 m .68772 .76472 L .68483 .7582 L p F P
0 g
s
.724 .636 .759 r
.37335 .91405 m .37502 .91784 L .36841 .92288 L p F P
0 g
s
.724 .636 .759 r
.36817 .91378 m .37335 .91405 L p .36841 .92288 L F P
0 g
s
.724 .636 .759 r
.36078 .91975 m .36817 .91378 L p .36841 .92288 L F P
0 g
s
.724 .636 .759 r
.36841 .92288 m .36207 .92248 L .36078 .91975 L p F P
0 g
s
.836 .767 .786 r
.10034 .78108 m .09921 .78004 L .09907 .7802 L closepath p F P
0 g
s
.698 .542 .671 r
.40202 .82046 m .41437 .82021 L .40788 .82749 L p F P
0 g
s
.698 .542 .671 r
.40788 .82749 m .4037 .82758 L .40202 .82046 L p F P
0 g
s
.708 .547 .669 r
.40016 .82045 m .40202 .82046 L .4037 .82758 L p F P
0 g
s
.892 .625 .526 r
.08262 .89678 m .08736 .89924 L .08702 .90477 L p F P
0 g
s
.889 .645 .563 r
.08736 .89924 m .08262 .89678 L .08345 .89112 L p F P
0 g
s
.708 .547 .669 r
.4037 .82758 m .39439 .82753 L .40016 .82045 L p F P
0 g
s
.712 .554 .672 r
.3875 .82026 m .40016 .82045 L .39439 .82753 L p F P
0 g
s
.883 .558 .43 r
.10101 .92187 m .09763 .92023 L .09687 .91499 L p F P
0 g
s
.886 .559 .426 r
.09201 .91259 m .09687 .91499 L .09763 .92023 L p F P
0 g
s
.734 .65 .766 r
.33538 .93095 m .33689 .92975 L .34658 .93073 L p F P
0 g
s
.725 .644 .767 r
.34651 .92215 m .33689 .92975 L .34658 .93073 L p F P
0 g
s
.725 .644 .767 r
.34658 .93073 m .34965 .92844 L .34651 .92215 L p F P
0 g
s
.884 .707 .658 r
.07265 .8572 m .07707 .85982 L .07468 .86589 L p F P
0 g
s
.88 .715 .673 r
.07707 .85982 m .07265 .8572 L .07538 .85104 L p F P
0 g
s
.751 .569 .649 r
.35348 .80388 m .35256 .80377 L .35105 .79679 L p F P
0 g
s
.752 .569 .649 r
.3475 .79635 m .35105 .79679 L .35256 .80377 L p F P
0 g
s
.674 .605 .77 r
.46491 .92959 m .46325 .92582 L .45338 .93071 L closepath p F P
0 g
s
.673 .602 .768 r
.46101 .92049 m .46325 .92582 L .45338 .93071 L p F P
0 g
s
.673 .602 .768 r
.4555 .92101 m .46101 .92049 L p .45338 .93071 L F P
0 g
s
.673 .602 .768 r
.44906 .92434 m .4555 .92101 L p .45338 .93071 L F P
0 g
s
.633 .77 .945 r
.20253 .96498 m .21321 .962 L .21668 .96484 L p F P
0 g
s
.652 .767 .934 r
.21321 .962 m .20253 .96498 L .199 .96245 L p F P
0 g
s
.72 .753 .878 r
.24513 .96262 m .24629 .96202 L .24385 .96133 L closepath p F P
0 g
s
.699 .747 .888 r
.24385 .96133 m .24513 .96262 L p .23089 .96399 L F P
0 g
s
.672 .513 .662 r
.42835 .81253 m .43884 .81161 L .43087 .81931 L p F P
0 g
s
.672 .513 .662 r
.43087 .81931 m .42978 .81941 L .42835 .81253 L p F P
0 g
s
.69 .531 .666 r
.42835 .81253 m .42978 .81941 L .41614 .82016 L p F P
0 g
s
.454 .762 .995 r
.17895 .96219 m .18487 .962 L .1813 .95966 L p F P
0 g
s
.454 .762 .995 r
.1813 .95966 m .17264 .96028 L .17895 .96219 L p F P
0 g
s
.329 .726 .982 r
.17084 .96035 m .17264 .96028 L .17895 .96219 L p F P
0 g
s
.657 .497 .655 r
.44114 .80929 m .44724 .80378 L .44025 .80462 L closepath p F P
0 g
s
.671 .511 .66 r
.44025 .80462 m .44114 .80929 L .43884 .81161 L p F P
0 g
s
.734 .561 .658 r
.37036 .81238 m .37015 .81146 L .3696 .81232 L closepath p F P
0 g
s
.696 .534 .664 r
.41614 .82016 m .41579 .81855 L .41437 .82021 L closepath p F P
0 g
s
.683 .601 .758 r
.44798 .92176 m .44906 .92434 L p .43488 .92335 L F P
0 g
s
.683 .601 .758 r
.43488 .92335 m .43623 .92258 L .44798 .92176 L p F P
0 g
s
.682 .6 .757 r
.43488 .92335 m .43623 .92258 L .43461 .9227 L closepath p F P
0 g
s
.75 .563 .642 r
.3415 .78884 m .3386 .79506 L .3475 .79635 L p F P
0 g
s
.77 .581 .644 r
.33311 .78739 m .3415 .78884 L .3386 .79506 L p F P
0 g
s
.828 .477 .392 r
.28442 .73283 m .27829 .73064 L .27685 .72581 L p F P
0 g
s
.845 .496 .393 r
.27126 .72344 m .27685 .72581 L .27829 .73064 L p F P
0 g
s
.653 .633 .817 r
.50077 .94864 m .51197 .94485 L .51498 .95045 L p F P
0 g
s
.652 .624 .809 r
.51129 .94352 m .51197 .94485 L .50077 .94864 L p F P
0 g
s
.652 .624 .809 r
.50077 .94864 m .49922 .94565 L .51129 .94352 L p F P
0 g
s
.725 .704 .83 r
.28135 .94774 m .27344 .95275 L .28117 .95425 L p F P
0 g
s
.725 .704 .83 r
.28117 .95425 m .28464 .9522 L .28135 .94774 L p F P
0 g
s
.737 .712 .828 r
.27034 .95473 m .27344 .95275 L .28117 .95425 L p F P
0 g
s
.562 .6 .849 r
.65592 .72284 m .65879 .72824 L .64722 .72886 L p F P
0 g
s
.562 .6 .849 r
.64542 .72342 m .65592 .72284 L p .64722 .72886 L F P
0 g
s
.562 .6 .849 r
.64722 .72886 m .64465 .72404 L .64542 .72342 L p F P
0 g
s
.739 .671 .784 r
.32428 .93927 m .32545 .93839 L .32362 .93814 L closepath p F P
0 g
s
.736 .668 .783 r
.32362 .93814 m .32428 .93927 L p .30999 .94199 L F P
0 g
s
.682 .599 .756 r
.43623 .92258 m .43461 .9227 L .43182 .91599 L p F P
0 g
s
.494 .453 .741 r
.71713 .81263 m .71632 .81239 L .71692 .81197 L closepath p F P
0 g
s
.502 .468 .752 r
.71632 .81239 m .71692 .81197 L .71415 .80382 L p F P
0 g
s
.779 .778 .851 r
.15779 .72549 m .15523 .7274 L .15166 .72415 L p F P
0 g
s
.712 .554 .672 r
.38737 .82042 m .3875 .82026 L p .39439 .82753 L F P
0 g
s
.715 .552 .667 r
.38737 .82042 m .3875 .82026 L .38734 .82025 L closepath p F P
0 g
s
.729 .562 .665 r
.37589 .81976 m .37207 .81953 L .37036 .81238 L p F P
0 g
s
.734 .565 .664 r
.3696 .81232 m .37036 .81238 L .37207 .81953 L p F P
0 g
s
.708 .609 .744 r
.40301 .91468 m .40344 .91573 L p .38924 .9165 L F P
0 g
s
.708 .609 .744 r
.38924 .9165 m .39177 .91462 L .40301 .91468 L p F P
0 g
s
.71 .614 .748 r
.38924 .9165 m .39177 .91462 L .38842 .91457 L closepath p F P
0 g
s
.726 .565 .673 r
.38734 .82025 m .38737 .82042 L .38218 .82721 L p F P
0 g
s
.726 .565 .673 r
.37589 .81976 m .38734 .82025 L p .38218 .82721 L F P
0 g
s
.594 .647 .872 r
.61277 .71165 m .62422 .70991 L .62709 .71462 L p F P
0 g
s
.597 .661 .883 r
.62134 .70532 m .62422 .70991 L .61277 .71165 L p F P
0 g
s
.597 .661 .883 r
.61176 .70689 m .62134 .70532 L p .61277 .71165 L F P
0 g
s
.597 .661 .883 r
.61277 .71165 m .61038 .70796 L .61176 .70689 L p F P
0 g
s
.702 .606 .747 r
.40344 .91573 m .40499 .91465 L .40301 .91468 L closepath p F P
0 g
s
.7 .603 .744 r
.41717 .91443 m .41763 .91557 L p .40344 .91573 L F P
0 g
s
.7 .603 .744 r
.40344 .91573 m .40499 .91465 L .41717 .91443 L p F P
0 g
s
.712 .554 .672 r
.39439 .82753 m .38909 .82745 L .38737 .82042 L p F P
0 g
s
.719 .558 .67 r
.38909 .82745 m .38737 .82042 L .38218 .82721 L closepath p F P
0 g
s
.439 .327 .63 r
.72252 .87488 m .72715 .87204 L .72303 .86749 L p F P
0 g
s
.436 .327 .631 r
.73051 .86281 m .72303 .86749 L .72715 .87204 L p F P
0 g
s
.452 .353 .652 r
.72972 .85891 m .73051 .86281 L .72303 .86749 L p F P
0 g
s
.452 .353 .652 r
.72765 .85714 m .72972 .85891 L p .72303 .86749 L F P
0 g
s
.892 .648 .563 r
.07878 .88862 m .08345 .89112 L .08262 .89678 L p F P
0 g
s
.888 .664 .593 r
.08345 .89112 m .07878 .88862 L .08005 .88285 L p F P
0 g
s
.696 .538 .669 r
.41437 .82021 m .41614 .82016 L .41778 .82723 L p F P
0 g
s
.696 .538 .669 r
.41778 .82723 m .40788 .82749 L .41437 .82021 L p F P
0 g
s
.833 .771 .792 r
.10566 .77293 m .09921 .78004 L .09555 .77679 L p F P
0 g
s
.833 .771 .792 r
.09555 .77679 m .10166 .77007 L .10566 .77293 L p F P
0 g
s
.831 .772 .796 r
.10697 .76435 m .10166 .77007 L .10566 .77293 L p F P
0 g
s
.732 .638 .754 r
.35765 .92218 m .34965 .92844 L .34651 .92215 L p F P
0 g
s
.742 .575 .666 r
.35929 .81145 m .3696 .81232 L .36514 .81902 L p F P
0 g
s
.734 .565 .664 r
.37207 .81953 m .36514 .81902 L .3696 .81232 L p F P
0 g
s
.74 .67 .782 r
.3346 .92948 m .33538 .93095 L .32545 .93839 L p F P
0 g
s
.74 .67 .782 r
.32745 .92869 m .3346 .92948 L p .32545 .93839 L F P
0 g
s
.74 .67 .782 r
.32108 .93375 m .32745 .92869 L p .32545 .93839 L F P
0 g
s
.74 .67 .782 r
.32545 .93839 m .32362 .93814 L .32108 .93375 L p F P
0 g
s
.722 .752 .877 r
.25267 .95324 m .25603 .95708 L .24629 .96202 L p F P
0 g
s
.722 .752 .877 r
.24174 .95918 m .25267 .95324 L p .24629 .96202 L F P
0 g
s
.722 .752 .877 r
.24629 .96202 m .24385 .96133 L .24174 .95918 L p F P
0 g
s
.699 .747 .888 r
.23089 .96399 m .23894 .96042 L .24385 .96133 L p F P
0 g
s
.711 .75 .882 r
.23894 .96042 m .23089 .96399 L .22746 .96086 L p F P
0 g
s
.674 .761 .916 r
.21668 .96484 m .22746 .96086 L .23089 .96399 L p F P
0 g
s
.861 .484 .333 r
.1094 .92989 m .10429 .92759 L .10259 .92259 L p F P
0 g
s
.861 .478 .317 r
.10101 .92187 m .10259 .92259 L .10429 .92759 L p F P
0 g
s
.685 .531 .671 r
.41614 .82016 m .42978 .81941 L p .42324 .82692 L F P
0 g
s
.685 .531 .671 r
.42324 .82692 m .41778 .82723 L .41614 .82016 L p F P
0 g
s
.683 .599 .756 r
.44798 .92176 m .44601 .917 L .43623 .92258 L closepath p F P
0 g
s
.682 .599 .756 r
.44439 .91294 m .44601 .917 L .43623 .92258 L p F P
0 g
s
.682 .599 .756 r
.43598 .9135 m .44439 .91294 L p .43623 .92258 L F P
0 g
s
.682 .599 .756 r
.43182 .91599 m .43598 .9135 L p .43623 .92258 L F P
0 g
s
.878 .724 .687 r
.07673 .84378 m .07408 .84214 L p .07538 .85104 L F P
0 g
s
.873 .731 .702 r
.07673 .84378 m .07453 .8413 L .07408 .84214 L closepath p F P
0 g
s
.687 .758 .905 r
.22746 .96086 m .21668 .96484 L .21321 .962 L p F P
0 g
s
.702 .605 .746 r
.40499 .91465 m .40301 .91468 L .40037 .90822 L p F P
0 g
s
.708 .608 .743 r
.40301 .91468 m .40037 .90822 L .39177 .91462 L closepath p F P
0 g
s
.656 .492 .65 r
.45188 .79646 m .45232 .79897 L .44724 .80378 L p F P
0 g
s
.642 .479 .647 r
.45232 .79897 m .45622 .79579 L .45188 .79646 L closepath p F P
0 g
s
.702 .605 .746 r
.41373 .90575 m .41457 .90793 L .40499 .91465 L p F P
0 g
s
.702 .605 .746 r
.40352 .90589 m .41373 .90575 L p .40499 .91465 L F P
0 g
s
.702 .605 .746 r
.40037 .90822 m .40352 .90589 L p .40499 .91465 L F P
0 g
s
.7 .602 .743 r
.41717 .91443 m .41457 .90793 L .40499 .91465 L closepath p F P
0 g
s
.81 .581 .592 r
.3092 .76092 m .31005 .75706 L .30873 .75668 L closepath p F P
0 g
s
.804 .576 .593 r
.3092 .76092 m .31005 .75706 L p .31583 .76464 L F P
0 g
s
.745 .691 .8 r
.29568 .94488 m .29587 .94474 L .3039 .94616 L p F P
0 g
s
.733 .679 .798 r
.30676 .93681 m .29587 .94474 L .3039 .94616 L p F P
0 g
s
.733 .679 .798 r
.3039 .94616 m .30999 .94199 L .30676 .93681 L p F P
0 g
s
.866 .746 .728 r
.07705 .81732 m .08122 .82007 L .07714 .8266 L p F P
0 g
s
.862 .75 .738 r
.0795 .81363 m .07705 .81732 L .08122 .82007 L p F P
0 g
s
.711 .613 .746 r
.39946 .90592 m .40037 .90822 L .39177 .91462 L p F P
0 g
s
.711 .613 .746 r
.39042 .90582 m .39946 .90592 L p .39177 .91462 L F P
0 g
s
.711 .613 .746 r
.38615 .90917 m .39042 .90582 L p .39177 .91462 L F P
0 g
s
.711 .613 .746 r
.39177 .91462 m .38842 .91457 L .38615 .90917 L p F P
0 g
s
.779 .778 .851 r
.15166 .72415 m .15377 .72258 L .15779 .72549 L p F P
0 g
s
.778 .778 .853 r
.16267 .71605 m .15377 .72258 L .15779 .72549 L p F P
0 g
s
.778 .778 .853 r
.15779 .72549 m .16623 .71929 L .16267 .71605 L p F P
0 g
s
.726 .636 .758 r
.36207 .92248 m .36078 .91975 L .35765 .92218 L closepath p F P
0 g
s
.719 .623 .75 r
.37502 .91784 m .37955 .91432 L .37335 .91405 L closepath p F P
0 g
s
.715 .616 .745 r
.38842 .91457 m .38615 .90917 L .37955 .91432 L closepath p F P
0 g
s
.643 .667 .858 r
.53221 .95727 m .54346 .95413 L .54644 .95875 L p F P
0 g
s
.643 .655 .847 r
.54346 .95413 m .53221 .95727 L .52922 .95234 L p F P
0 g
s
.872 .735 .707 r
.07759 .83576 m .07453 .8413 L .07091 .83741 L p F P
0 g
s
.872 .735 .707 r
.07091 .83741 m .07331 .83307 L .07759 .83576 L p F P
0 g
s
.868 .739 .718 r
.07759 .83576 m .07331 .83307 L .07714 .8266 L p F P
0 g
s
.752 .569 .649 r
.35256 .80377 m .34412 .80272 L .3475 .79635 L p F P
0 g
s
.765 .58 .647 r
.3386 .79506 m .3475 .79635 L .34412 .80272 L p F P
0 g
s
.592 .767 .963 r
.22015 .70514 m .23079 .70279 L .23427 .70562 L p F P
0 g
s
.577 .762 .966 r
.23079 .70279 m .22015 .70514 L .21667 .70205 L p F P
0 g
s
.68 .774 .922 r
.20592 .7063 m .21667 .70205 L .22015 .70514 L p F P
0 g
s
.627 .765 .946 r
.57785 .96442 m .58919 .96159 L .59208 .96446 L p F P
0 g
s
.63 .734 .923 r
.58919 .96159 m .57785 .96442 L .57494 .96104 L p F P
0 g
s
.692 .598 .746 r
.43096 .91385 m .43182 .91599 L p .41763 .91557 L F P
0 g
s
.692 .598 .746 r
.41763 .91557 m .41953 .91433 L .43096 .91385 L p F P
0 g
s
.693 .599 .747 r
.41763 .91557 m .41953 .91433 L .41717 .91443 L closepath p F P
0 g
s
.525 .528 .8 r
.6889 .76482 m .69947 .76588 L p .69592 .77206 L F P
0 g
s
.523 .528 .803 r
.6889 .76482 m .69947 .76588 L .69657 .75909 L p F P
0 g
s
.523 .528 .803 r
.69657 .75909 m .69614 .75905 L .6889 .76482 L p F P
0 g
s
.529 .54 .81 r
.68483 .7582 m .69614 .75905 L .6889 .76482 L p F P
0 g
s
.438 .31 .609 r
.72011 .88301 m .72343 .88108 L .72252 .87488 L p F P
0 g
s
.421 .279 .582 r
.72343 .88108 m .72011 .88301 L .72239 .88807 L p F P
0 g
s
0 0 0 r
.67171 .94463 m .67144 .94493 L .66006 .95028 L p F P
0 g
s
0 0 0 r
.6584 .9512 m .66006 .95028 L .67144 .94493 L p F P
0 g
s
.736 .668 .783 r
.30999 .94199 m .31635 .93725 L .32362 .93814 L p F P
0 g
s
.736 .669 .784 r
.32362 .93814 m .32108 .93375 L .31635 .93725 L closepath p F P
0 g
s
.659 .617 .795 r
.48354 .9409 m .49471 .93658 L .49774 .94279 L p F P
0 g
s
.658 .611 .79 r
.49426 .9356 m .49471 .93658 L .48354 .9409 L p F P
0 g
s
.658 .611 .79 r
.48354 .9409 m .48191 .93748 L .49426 .9356 L p F P
0 g
s
.505 .294 .527 r
.50633 .7465 m .50631 .74111 L .51693 .73724 L p F P
0 g
s
.479 .239 .472 r
.51726 .73223 m .51693 .73724 L .50631 .74111 L p F P
0 g
s
0 .425 .754 r
.14911 .95388 m .15329 .95538 L .14961 .95366 L p F P
0 g
s
.48 .434 .729 r
.71946 .81987 m .72565 .81542 L p .7262 .82445 L F P
0 g
s
.48 .434 .729 r
.7262 .82445 m .72016 .82217 L .71946 .81987 L p F P
0 g
s
.486 .448 .74 r
.71946 .81987 m .71713 .81263 L .72565 .81542 L closepath p F P
0 g
s
.693 .598 .746 r
.41953 .91433 m .41717 .91443 L .41457 .90793 L p F P
0 g
s
.555 .887 .987 r
.63188 .95901 m .63188 .95901 L .62048 .96235 L p F P
0 g
s
.58 .868 .995 r
.63188 .95901 m .62048 .96235 L .61768 .96079 L p F P
0 g
s
.588 .856 .994 r
.60629 .96384 m .61768 .96079 L .62048 .96235 L p F P
0 g
s
.485 .448 .741 r
.72565 .81542 m .71713 .81263 L .71692 .81197 L p F P
0 g
s
.491 .461 .752 r
.71419 .80379 m .71415 .80382 L .71692 .81197 L p F P
0 g
s
.491 .461 .752 r
.71692 .81197 m .72418 .80662 L .71419 .80379 L p F P
0 g
s
.485 .448 .741 r
.71692 .81197 m .72418 .80662 L p .72565 .81542 L F P
0 g
s
.675 .773 .924 r
.21667 .70205 m .20592 .7063 L .20242 .70311 L p F P
0 g
s
.776 .578 .632 r
.33311 .78739 m .33217 .78721 L .33086 .78041 L p F P
0 g
s
.772 .576 .633 r
.32739 .77979 m .33086 .78041 L .33217 .78721 L p F P
0 g
s
.74 .69 .803 r
.29568 .94488 m .28464 .9522 L .28135 .94774 L p F P
0 g
s
.48 .434 .728 r
.7218 .82755 m .72016 .82217 L .7262 .82445 L closepath p F P
0 g
s
.546 .568 .828 r
.66526 .741 m .66706 .73954 L p .67833 .74558 L F P
0 g
s
.55 .578 .835 r
.66526 .741 m .66454 .73956 L .66706 .73954 L closepath p F P
0 g
s
.887 .681 .618 r
.08005 .88285 m .07545 .88032 L .07713 .87444 L p F P
0 g
s
.891 .668 .593 r
.07545 .88032 m .08005 .88285 L .07878 .88862 L p F P
0 g
s
.793 .576 .607 r
.3216 .77221 m .31416 .77047 L .31583 .76464 L p F P
0 g
s
.803 .587 .61 r
.30942 .76293 m .31583 .76464 L .31416 .77047 L p F P
0 g
s
.804 .576 .593 r
.31583 .76464 m .30942 .76293 L .3092 .76092 L p F P
0 g
s
.726 .565 .673 r
.37309 .82369 m .37589 .81976 L p .38218 .82721 L F P
0 g
s
.729 .565 .668 r
.37309 .82369 m .37589 .81976 L .37207 .81953 L closepath p F P
0 g
s
.692 .597 .745 r
.43096 .91385 m .42876 .90829 L .41953 .91433 L closepath p F P
0 g
s
.693 .598 .746 r
.4276 .90523 m .42876 .90829 L .41953 .91433 L p F P
0 g
s
.693 .598 .746 r
.41796 .9056 m .4276 .90523 L p .41953 .91433 L F P
0 g
s
.693 .598 .746 r
.41457 .90793 m .41796 .9056 L p .41953 .91433 L F P
0 g
s
.636 .721 .909 r
.58136 .7049 m .59271 .70184 L .5956 .70555 L p F P
0 g
s
.649 .747 .921 r
.59271 .70184 m .58136 .7049 L .57846 .7019 L p F P
0 g
s
.661 .777 .935 r
.56715 .70569 m .57846 .7019 L .58136 .7049 L p F P
0 g
s
.68 .823 .952 r
.57846 .7019 m .56715 .70569 L .56425 .70386 L p F P
0 g
s
.614 .9 .986 r
.56715 .70569 m .56425 .70386 L p .55318 .70868 L F P
0 g
s
.719 .622 .748 r
.38474 .9057 m .38615 .90917 L .37955 .91432 L p F P
0 g
s
.719 .622 .748 r
.37832 .90548 m .38474 .9057 L p .37955 .91432 L F P
0 g
s
.719 .622 .748 r
.37192 .91076 m .37832 .90548 L p .37955 .91432 L F P
0 g
s
.719 .622 .748 r
.37955 .91432 m .37335 .91405 L .37192 .91076 L p F P
0 g
s
.797 .572 .596 r
.30873 .75668 m .30293 .7552 L p .30876 .76277 L F P
0 g
s
.797 .572 .596 r
.30876 .76277 m .3092 .76092 L .30873 .75668 L p F P
0 g
s
.732 .638 .754 r
.34651 .92215 m .34752 .92132 L .35765 .92218 L p F P
0 g
s
.723 .631 .755 r
.35756 .91304 m .34752 .92132 L .35765 .92218 L p F P
0 g
s
.723 .631 .755 r
.3577 .91305 m .35756 .91304 L p .35765 .92218 L F P
0 g
s
.723 .631 .755 r
.35765 .92218 m .36078 .91975 L .3577 .91305 L p F P
0 g
s
.665 .601 .774 r
.4663 .93272 m .47671 .92808 L .46491 .92959 L closepath p F P
0 g
s
.425 .301 .607 r
.72715 .87204 m .72252 .87488 L .72343 .88108 L p F P
0 g
s
.699 .544 .674 r
.40456 .83113 m .40788 .82749 L .4037 .82758 L closepath p F P
0 g
s
.709 .557 .679 r
.4037 .82758 m .40456 .83113 L .40132 .8348 L p F P
0 g
s
.709 .557 .679 r
.39439 .82753 m .4037 .82758 L p .40132 .8348 L F P
0 g
s
.566 0 0 r
.1321 .94745 m .12638 .94359 L .13175 .9458 L p F P
0 g
s
.582 .403 .605 r
.48536 .77057 m .48473 .76452 L .49609 .76148 L p F P
0 g
s
.576 .388 .589 r
.49561 .7556 m .49609 .76148 L .48473 .76452 L p F P
0 g
s
.582 .635 .869 r
.62865 .71723 m .62709 .71462 L .63277 .71394 L closepath p F P
0 g
s
.474 .42 .716 r
.7218 .82755 m .7262 .82445 L p .72583 .83372 L F P
0 g
s
.474 .42 .716 r
.72583 .83372 m .72324 .83259 L .7218 .82755 L p F P
0 g
s
.856 .757 .753 r
.08231 .80111 m .08642 .80391 L .08153 .81067 L p F P
0 g
s
.853 .759 .759 r
.08744 .79428 m .08231 .80111 L .08642 .80391 L p F P
0 g
s
.853 .759 .759 r
.08943 .79565 m .08744 .79428 L p .08642 .80391 L F P
0 g
s
.709 .557 .679 r
.39033 .83241 m .39439 .82753 L p .40132 .8348 L F P
0 g
s
.712 .555 .674 r
.39033 .83241 m .39439 .82753 L .38909 .82745 L closepath p F P
0 g
s
.747 .573 .659 r
.35285 .80499 m .35348 .80388 L p .35929 .81145 L F P
0 g
s
.751 .574 .656 r
.35285 .80499 m .35348 .80388 L .35256 .80377 L closepath p F P
0 g
s
.615 .807 .974 r
.59208 .96446 m .60344 .96157 L .60629 .96384 L p F P
0 g
s
.624 .771 .95 r
.60344 .96157 m .59208 .96446 L .58919 .96159 L p F P
0 g
s
.838 .77 .787 r
.09907 .7802 m .09921 .78004 L .09555 .77679 L p F P
0 g
s
.646 .486 .652 r
.45309 .80311 m .45232 .79897 L .45622 .79579 L p F P
0 g
s
.658 .494 .651 r
.45309 .80311 m .45232 .79897 L .44724 .80378 L closepath p F P
0 g
s
.467 .391 .687 r
.7264 .8444 m .72438 .84326 L .72588 .84228 L closepath p F P
0 g
s
.477 .409 .702 r
.72438 .84326 m .72588 .84228 L .72394 .83502 L p F P
0 g
s
.838 .77 .787 r
.09555 .77679 m .09507 .77734 L .09907 .7802 L p F P
0 g
s
.843 .768 .779 r
.09507 .77734 m .09907 .7802 L .09316 .78727 L p F P
0 g
s
.696 .546 .679 r
.40788 .82749 m .41778 .82723 L p .41568 .83451 L F P
0 g
s
.696 .546 .679 r
.40456 .83113 m .40788 .82749 L p .41568 .83451 L F P
0 g
s
.674 .595 .76 r
.44906 .92434 m .4555 .92101 L .44798 .92176 L closepath p F P
0 g
s
.625 .46 .639 r
.4635 .78949 m .46634 .78748 L .46327 .78806 L closepath p F P
0 g
s
.64 .472 .64 r
.46327 .78806 m .4635 .78949 L .45622 .79579 L p F P
0 g
s
.499 .476 .763 r
.71415 .80382 m .71413 .80378 L .71419 .80379 L closepath p F P
0 g
s
.662 .504 .659 r
.44156 .81138 m .44114 .80929 L .44724 .80378 L p F P
0 g
s
.671 .51 .658 r
.44156 .81138 m .44114 .80929 L .43884 .81161 L closepath p F P
0 g
s
.499 .476 .763 r
.71419 .80379 m .71413 .80378 L .71117 .79547 L p F P
0 g
s
.713 .556 .674 r
.38909 .82745 m .38218 .82721 L p .38849 .83465 L F P
0 g
s
.713 .556 .674 r
.38849 .83465 m .39033 .83241 L .38909 .82745 L p F P
0 g
s
.612 .817 .979 r
.61768 .96079 m .60629 .96384 L .60344 .96157 L p F P
0 g
s
.49 .463 .755 r
.7218 .79807 m .71419 .80379 L .72418 .80662 L p F P
0 g
s
.499 .476 .763 r
.71117 .79547 m .7218 .79807 L .71419 .80379 L p F P
0 g
s
.662 .504 .659 r
.44724 .80378 m .45309 .80311 L p .44156 .81138 L F P
0 g
s
.836 .407 .218 r
.11705 .93697 m .11195 .93468 L .1094 .92989 L p F P
0 g
s
.835 .401 .204 r
.10429 .92759 m .1094 .92989 L .11195 .93468 L p F P
0 g
s
.654 .625 .808 r
.50895 .93885 m .51129 .94352 L .49922 .94565 L p F P
0 g
s
.654 .625 .808 r
.49922 .94565 m .49774 .94279 L .50895 .93885 L p F P
0 g
s
.727 .633 .753 r
.36078 .91975 m .36817 .91378 L .3577 .91305 L closepath p F P
0 g
s
.824 .525 .484 r
.2865 .73848 m .28491 .73796 L .28442 .73283 L p F P
0 g
s
.834 .535 .484 r
.27829 .73064 m .28442 .73283 L .28491 .73796 L p F P
0 g
s
.746 .571 .657 r
.35256 .80377 m .34412 .80272 L p .34966 .81038 L F P
0 g
s
.746 .571 .657 r
.34966 .81038 m .35285 .80499 L .35256 .80377 L p F P
0 g
s
.727 .564 .669 r
.37207 .81953 m .36514 .81902 L p .371 .82659 L F P
0 g
s
.727 .564 .669 r
.371 .82659 m .37309 .82369 L .37207 .81953 L p F P
0 g
s
.883 .719 .674 r
.07104 .84838 m .07538 .85104 L .07265 .8572 L p F P
0 g
s
.878 .724 .687 r
.07408 .84214 m .07104 .84838 L .07538 .85104 L p F P
0 g
s
.781 .575 .621 r
.32739 .77979 m .3195 .77818 L .3216 .77221 L p F P
0 g
s
.796 .587 .619 r
.31416 .77047 m .3216 .77221 L .3195 .77818 L p F P
0 g
s
.672 .514 .663 r
.43884 .81161 m .44156 .81138 L .44302 .81827 L p F P
0 g
s
.672 .514 .663 r
.44302 .81827 m .43087 .81931 L .43884 .81161 L p F P
0 g
s
.738 .657 .77 r
.33538 .93095 m .33689 .92975 L .3346 .92948 L closepath p F P
0 g
s
.745 .674 .781 r
.31635 .93725 m .30999 .94199 L .30676 .93681 L p F P
0 g
s
.722 .624 .747 r
.37335 .91405 m .37192 .91076 L .36817 .91378 L closepath p F P
0 g
s
.684 .593 .748 r
.43182 .91599 m .43598 .9135 L .43096 .91385 L closepath p F P
0 g
s
.698 .747 .89 r
.24385 .96133 m .24174 .95918 L .23894 .96042 L closepath p F P
0 g
s
.646 .486 .652 r
.45622 .79579 m .46436 .79458 L p .45309 .80311 L F P
0 g
s
.643 .477 .643 r
.46436 .79458 m .4635 .78949 L .45622 .79579 L closepath p F P
0 g
s
.431 .701 .978 r
.23427 .70562 m .2407 .70591 L .24577 .70847 L p F P
0 g
s
.391 .683 .977 r
.2407 .70591 m .23427 .70562 L .23079 .70279 L p F P
0 g
s
.704 .601 .739 r
.40037 .90822 m .40352 .90589 L .39946 .90592 L closepath p F P
0 g
s
.672 .518 .667 r
.42995 .82017 m .43087 .81931 L .42978 .81941 L closepath p F P
0 g
s
.685 .531 .671 r
.42978 .81941 m .42995 .82017 L .42324 .82692 L p F P
0 g
s
.549 .58 .838 r
.66706 .73954 m .66454 .73956 L .66167 .73386 L p F P
0 g
s
.747 .573 .659 r
.35929 .81145 m .35424 .8109 L .35285 .80499 L p F P
0 g
s
.748 .573 .659 r
.35424 .8109 m .35285 .80499 L .34966 .81038 L closepath p F P
0 g
s
.474 .419 .716 r
.72394 .83502 m .72324 .83259 L .72583 .83372 L closepath p F P
0 g
s
.861 .478 .317 r
.09823 .92252 m .10101 .92187 L p .10429 .92759 L F P
0 g
s
.876 .516 .363 r
.09823 .92252 m .09763 .92023 L .10101 .92187 L closepath p F P
0 g
s
.738 .656 .769 r
.34603 .92117 m .34651 .92215 L .33689 .92975 L p F P
0 g
s
.738 .656 .769 r
.33767 .92037 m .34603 .92117 L p .33689 .92975 L F P
0 g
s
.738 .656 .769 r
.33221 .92494 m .33767 .92037 L p .33689 .92975 L F P
0 g
s
.738 .656 .769 r
.33689 .92975 m .3346 .92948 L .33221 .92494 L p F P
0 g
s
.521 .516 .791 r
.69592 .77206 m .70238 .77288 L p .70196 .77959 L F P
0 g
s
.519 .517 .794 r
.70238 .77288 m .69592 .77206 L .70057 .76845 L closepath p F P
0 g
s
.525 .528 .8 r
.69947 .76588 m .70057 .76845 L .69592 .77206 L p F P
0 g
s
.685 .533 .674 r
.41875 .83134 m .42324 .82692 L .41778 .82723 L closepath p F P
0 g
s
.696 .546 .679 r
.41778 .82723 m .41875 .83134 L .41568 .83451 L p F P
0 g
s
.713 .61 .74 r
.38615 .90917 m .39042 .90582 L .38474 .9057 L closepath p F P
0 g
s
.696 .546 .679 r
.41568 .83451 m .40548 .83479 L .40456 .83113 L p F P
0 g
s
.706 .552 .677 r
.40548 .83479 m .40456 .83113 L .40132 .8348 L closepath p F P
0 g
s
.742 .575 .666 r
.35578 .81715 m .35929 .81145 L p .36514 .81902 L F P
0 g
s
.746 .575 .663 r
.35578 .81715 m .35929 .81145 L .35424 .8109 L closepath p F P
0 g
s
.713 .556 .674 r
.38218 .82721 m .3768 .83418 L .38849 .83465 L p F P
0 g
s
.725 .568 .676 r
.37388 .82678 m .38218 .82721 L .3768 .83418 L p F P
0 g
s
.726 .565 .673 r
.38218 .82721 m .37388 .82678 L .37309 .82369 L p F P
0 g
s
.671 .521 .673 r
.43087 .81931 m .44302 .81827 L p .44161 .82551 L F P
0 g
s
.671 .521 .673 r
.42995 .82017 m .43087 .81931 L p .44161 .82551 L F P
0 g
s
.671 .521 .673 r
.44161 .82551 m .43139 .82645 L .42995 .82017 L p F P
0 g
s
.684 .529 .67 r
.43139 .82645 m .42995 .82017 L .42324 .82692 L closepath p F P
0 g
s
.847 .763 .769 r
.08943 .79565 m .08765 .79401 L .08744 .79428 L closepath p F P
0 g
s
.764 .778 .864 r
.1707 .71627 m .16623 .71929 L .16267 .71605 L p F P
0 g
s
.38 .2 .507 r
.72345 .89345 m .71524 .89812 L .71542 .9036 L p F P
0 g
s
.405 .245 .548 r
.71524 .89812 m .72345 .89345 L .72239 .88807 L p F P
0 g
s
.395 .211 .51 r
.71168 .90561 m .71542 .9036 L .71524 .89812 L p F P
0 g
s
.629 .467 .644 r
.46436 .79458 m .4635 .78949 L .46634 .78748 L p F P
0 g
s
.674 .595 .759 r
.4555 .92101 m .44798 .92176 L .44601 .917 L p F P
0 g
s
.332 .094 .396 r
.70975 .91179 m .7058 .91387 L .70538 .91877 L p F P
0 g
s
.371 .162 .461 r
.7058 .91387 m .70975 .91179 L .71168 .90561 L p F P
0 g
s
.657 .505 .665 r
.44156 .81138 m .4544 .80986 L p .45172 .8172 L F P
0 g
s
.657 .505 .665 r
.45172 .8172 m .44302 .81827 L .44156 .81138 L p F P
0 g
s
.662 .504 .659 r
.45309 .80311 m .4544 .80986 L .44156 .81138 L p F P
0 g
s
.465 .402 .702 r
.72583 .83372 m .72394 .83502 L .72588 .84228 L p F P
0 g
s
.89 .685 .618 r
.07262 .87187 m .07713 .87444 L .07545 .88032 L p F P
0 g
s
.886 .695 .639 r
.07713 .87444 m .07262 .87187 L .07468 .86589 L p F P
0 g
s
.684 .593 .748 r
.43598 .9135 m .43096 .91385 L .42876 .90829 L p F P
0 g
s
.661 .612 .788 r
.49168 .92997 m .49426 .9356 L .48191 .93748 L p F P
0 g
s
.661 .612 .788 r
.48191 .93748 m .4805 .9345 L .49168 .92997 L p F P
0 g
s
.747 .777 .878 r
.17718 .71194 m .1871 .70594 L .19112 .70886 L p F P
0 g
s
.746 .778 .878 r
.18808 .70536 m .1871 .70594 L .19112 .70886 L p F P
0 g
s
.746 .778 .878 r
.19112 .70886 m .1916 .70857 L .18808 .70536 L p F P
0 g
s
.665 .6 .773 r
.47671 .92808 m .46491 .92959 L .46325 .92582 L p F P
0 g
s
.647 .628 .816 r
.52621 .94698 m .51498 .95045 L .51197 .94485 L p F P
0 g
s
.772 .576 .633 r
.33217 .78721 m .32484 .7859 L .32739 .77979 L p F P
0 g
s
.785 .586 .631 r
.3195 .77818 m .32739 .77979 L .32484 .7859 L p F P
0 g
s
.704 .6 .738 r
.40352 .90589 m .39946 .90592 L .3973 .9004 L p F P
0 g
s
.71 .604 .736 r
.39946 .90592 m .3973 .9004 L .39042 .90582 L closepath p F P
0 g
s
.694 .594 .739 r
.41457 .90793 m .41796 .9056 L .41373 .90575 L closepath p F P
0 g
s
.781 .303 .096 r
.26274 .71671 m .26536 .71964 L .26382 .71988 L p F P
0 g
s
.781 .303 .096 r
.25734 .71426 m .26274 .71671 L p .26382 .71988 L F P
0 g
s
.727 .632 .752 r
.3695 .90504 m .37192 .91076 L .36817 .91378 L p F P
0 g
s
.727 .632 .752 r
.36709 .9049 m .3695 .90504 L p .36817 .91378 L F P
0 g
s
.727 .632 .752 r
.35766 .91296 m .36709 .9049 L p .36817 .91378 L F P
0 g
s
.727 .632 .752 r
.36817 .91378 m .3577 .91305 L .35766 .91296 L p F P
0 g
s
.528 .54 .812 r
.69614 .75905 m .68483 .7582 L .68365 .75554 L p F P
0 g
s
.702 .597 .735 r
.41373 .90575 m .41151 .89995 L .40352 .90589 L closepath p F P
0 g
s
.704 .6 .738 r
.41052 .89727 m .41151 .89995 L .40352 .90589 L p F P
0 g
s
.704 .6 .738 r
.40118 .89735 m .41052 .89727 L p .40352 .90589 L F P
0 g
s
.704 .6 .738 r
.3973 .9004 m .40118 .89735 L p .40352 .90589 L F P
0 g
s
.717 .776 .899 r
.20242 .70311 m .1916 .70857 L .18808 .70536 L p F P
0 g
s
.73 .568 .671 r
.37388 .82678 m .37309 .82369 L .371 .82659 L closepath p F P
0 g
s
.709 .557 .679 r
.40132 .8348 m .39093 .83472 L .39033 .83241 L p F P
0 g
s
.717 .562 .677 r
.39093 .83472 m .39033 .83241 L .38849 .83465 L closepath p F P
0 g
s
.504 .48 .763 r
.71117 .79547 m .7111 .79546 L .71115 .79542 L closepath p F P
0 g
s
.512 .492 .771 r
.70822 .78761 m .71115 .79542 L .7111 .79546 L p F P
0 g
s
.512 .492 .771 r
.70702 .78739 m .70822 .78761 L p .7111 .79546 L F P
0 g
s
.736 .655 .77 r
.3346 .92948 m .33221 .92494 L .32745 .92869 L closepath p F P
0 g
s
.713 .609 .739 r
.39615 .89736 m .3973 .9004 L .39042 .90582 L p F P
0 g
s
.713 .609 .739 r
.38827 .89723 m .39615 .89736 L p .39042 .90582 L F P
0 g
s
.713 .609 .739 r
.38307 .90156 m .38827 .89723 L p .39042 .90582 L F P
0 g
s
.713 .609 .739 r
.39042 .90582 m .38474 .9057 L .38307 .90156 L p F P
0 g
s
.617 .687 .893 r
.5956 .70555 m .607 .70306 L .60988 .70721 L p F P
0 g
s
.625 .702 .901 r
.607 .70306 m .5956 .70555 L .59271 .70184 L p F P
0 g
s
.741 .723 .835 r
.27034 .95473 m .27344 .95275 L .26767 .95142 L closepath p F P
0 g
s
.729 .717 .839 r
.26767 .95142 m .27034 .95473 L p .25603 .95708 L F P
0 g
s
.496 .475 .764 r
.7218 .79807 m .71117 .79547 L .71115 .79542 L p F P
0 g
s
.496 .475 .764 r
.71115 .79542 m .7185 .78976 L p .7218 .79807 L F P
0 g
s
.501 .488 .774 r
.71115 .79542 m .70822 .78761 L .7185 .78976 L closepath p F P
0 g
s
.628 .942 .955 r
.55297 .70864 m .55408 .70813 L .55318 .70868 L closepath p F P
0 g
s
.614 .9 .986 r
.56425 .70386 m .55408 .70813 L .55318 .70868 L p F P
0 g
s
.639 .665 .859 r
.55773 .9558 m .54644 .95875 L .54346 .95413 L p F P
0 g
s
.683 .536 .68 r
.42324 .82692 m .43139 .82645 L p .43231 .8336 L F P
0 g
s
.683 .536 .68 r
.41875 .83134 m .42324 .82692 L p .43231 .8336 L F P
0 g
s
.401 .75 .994 r
.17264 .96028 m .16863 .95916 L .17084 .96035 L closepath p F P
0 g
s
.706 .554 .679 r
.40132 .8348 m .40548 .83479 L .40736 .8421 L p F P
0 g
s
.706 .554 .679 r
.40736 .8421 m .39472 .84212 L .40132 .8348 L p F P
0 g
s
.709 .56 .682 r
.39093 .83472 m .40132 .8348 L .39472 .84212 L p F P
0 g
s
.696 .548 .682 r
.40548 .83479 m .41568 .83451 L .40824 .84207 L p F P
0 g
s
.696 .548 .682 r
.40824 .84207 m .40736 .8421 L .40548 .83479 L p F P
0 g
s
.727 .564 .669 r
.36514 .81902 m .36059 .82575 L .371 .82659 L p F P
0 g
s
.742 .578 .671 r
.35602 .81813 m .36514 .81902 L .36059 .82575 L p F P
0 g
s
.742 .575 .666 r
.36514 .81902 m .35602 .81813 L .35578 .81715 L p F P
0 g
s
.694 .593 .738 r
.41796 .9056 m .41373 .90575 L .41151 .89995 L p F P
0 g
s
.629 .467 .644 r
.46634 .78748 m .47538 .78581 L p .46436 .79458 L F P
0 g
s
.626 .457 .634 r
.47538 .78581 m .47467 .78112 L .46634 .78748 L closepath p F P
0 g
s
.623 .451 .63 r
.47442 .77943 m .47467 .78112 L .46634 .78748 L p F P
0 g
s
.517 .504 .781 r
.70196 .77959 m .70529 .7801 L p .70702 .78739 L F P
0 g
s
.514 .505 .784 r
.70529 .7801 m .70196 .77959 L .70437 .77776 L closepath p F P
0 g
s
.521 .516 .791 r
.70238 .77288 m .70437 .77776 L .70196 .77959 L p F P
0 g
s
.829 .563 .538 r
.29701 .74766 m .29069 .74555 L .29098 .74016 L p F P
0 g
s
.841 .575 .537 r
.2865 .73848 m .29098 .74016 L .29069 .74555 L p F P
0 g
s
.722 .619 .742 r
.37192 .91076 m .37832 .90548 L .3695 .90504 L closepath p F P
0 g
s
.745 .674 .781 r
.30676 .93681 m .30786 .93594 L .31635 .93725 L p F P
0 g
s
.734 .665 .782 r
.31789 .92809 m .30786 .93594 L .31635 .93725 L p F P
0 g
s
.734 .665 .782 r
.31635 .93725 m .32108 .93375 L .31789 .92809 L p F P
0 g
s
.718 .611 .737 r
.38474 .9057 m .38307 .90156 L .37832 .90548 L closepath p F P
0 g
s
.444 .21 .463 r
.526 .72854 m .51726 .73223 L .51693 .73724 L p F P
0 g
s
.395 .119 .372 r
.52763 .72708 m .52836 .72349 L p .51726 .73223 L F P
0 g
s
.395 .119 .372 r
.51726 .73223 m .526 .72854 L .52763 .72708 L p F P
0 g
s
.709 .56 .682 r
.39472 .84212 m .3929 .84211 L .39093 .83472 L p F P
0 g
s
.717 .564 .68 r
.38849 .83465 m .39093 .83472 L .3929 .84211 L p F P
0 g
s
.775 .584 .641 r
.3325 .78875 m .33311 .78739 L .33217 .78721 L closepath p F P
0 g
s
.77 .581 .644 r
.3325 .78875 m .33311 .78739 L p .3386 .79506 L F P
0 g
s
.509 .493 .774 r
.70822 .78761 m .70702 .78739 L .7079 .78674 L closepath p F P
0 g
s
.517 .504 .781 r
.70529 .7801 m .7079 .78674 L .70702 .78739 L p F P
0 g
s
.683 .536 .68 r
.43231 .8336 m .4195 .83439 L .41875 .83134 L p F P
0 g
s
.694 .543 .677 r
.4195 .83439 m .41875 .83134 L .41568 .83451 L closepath p F P
0 g
s
.725 .568 .676 r
.3768 .83418 m .3758 .83413 L .37388 .82678 L p F P
0 g
s
.731 .571 .674 r
.371 .82659 m .37388 .82678 L .3758 .83413 L p F P
0 g
s
.684 .593 .747 r
.44439 .91294 m .44295 .9093 L .43598 .9135 L closepath p F P
0 g
s
.684 .593 .748 r
.44109 .90436 m .44295 .9093 L .43598 .9135 L p F P
0 g
s
.684 .593 .748 r
.43429 .9048 m .44109 .90436 L p .43598 .9135 L F P
0 g
s
.684 .593 .748 r
.42876 .90829 m .43429 .9048 L p .43598 .9135 L F P
0 g
s
.717 .564 .68 r
.3929 .84211 m .38245 .84181 L .38849 .83465 L p F P
0 g
s
.722 .572 .684 r
.3768 .83418 m .38849 .83465 L .38245 .84181 L p F P
0 g
s
.364 .156 .458 r
.71542 .9036 m .71168 .90561 L .70975 .91179 L p F P
0 g
s
.643 .488 .658 r
.45309 .80311 m .46555 .80121 L p .46332 .80846 L F P
0 g
s
.643 .488 .658 r
.46332 .80846 m .4544 .80986 L .45309 .80311 L p F P
0 g
s
.646 .486 .652 r
.46436 .79458 m .46555 .80121 L .45309 .80311 L p F P
0 g
s
.105 .565 .913 r
.24577 .70847 m .24823 .70886 L .24472 .70682 L p F P
0 g
s
.105 .565 .913 r
.24472 .70682 m .2407 .70591 L .24577 .70847 L p F P
0 g
s
.694 .593 .738 r
.42447 .89681 m .42571 .90023 L .41796 .9056 L p F P
0 g
s
.694 .593 .738 r
.41539 .89712 m .42447 .89681 L p .41796 .9056 L F P
0 g
s
.694 .593 .738 r
.41151 .89995 m .41539 .89712 L p .41796 .9056 L F P
0 g
s
.694 .591 .736 r
.4276 .90523 m .42571 .90023 L .41796 .9056 L closepath p F P
0 g
s
.607 .44 .63 r
.47467 .78112 m .47978 .77821 L .47442 .77943 L closepath p F P
0 g
s
.735 .643 .757 r
.34651 .92215 m .34752 .92132 L .34603 .92117 L closepath p F P
0 g
s
.735 .642 .756 r
.34729 .9122 m .35756 .91304 L .34752 .92132 L p F P
0 g
s
.735 .642 .756 r
.34337 .91563 m .34729 .9122 L p .34752 .92132 L F P
0 g
s
.735 .642 .756 r
.34752 .92132 m .34603 .92117 L .34337 .91563 L p F P
0 g
s
.846 .767 .775 r
.09316 .78727 m .08765 .79401 L .08398 .79074 L p F P
0 g
s
.846 .767 .775 r
.08398 .79074 m .08914 .78442 L .09316 .78727 L p F P
0 g
s
.843 .768 .779 r
.09316 .78727 m .08914 .78442 L .09507 .77734 L p F P
0 g
s
.654 .613 .796 r
.50895 .93885 m .49774 .94279 L .49471 .93658 L p F P
0 g
s
.742 .573 .664 r
.35424 .8109 m .34966 .81038 L p .35521 .81804 L F P
0 g
s
.742 .573 .664 r
.35521 .81804 m .35578 .81715 L .35424 .8109 L p F P
0 g
s
.764 .778 .864 r
.16267 .71605 m .16669 .71334 L .1707 .71627 L p F P
0 g
s
.763 .779 .866 r
.17363 .70872 m .16669 .71334 L .1707 .71627 L p F P
0 g
s
.763 .779 .866 r
.1707 .71627 m .17718 .71194 L .17363 .70872 L p F P
0 g
s
.671 .967 .925 r
.55408 .70813 m .55297 .70864 L .55008 .70959 L p F P
0 g
s
0 0 0 r
.55297 .70864 m .55008 .70959 L p .53998 .71526 L F P
0 g
s
.767 .579 .644 r
.33217 .78721 m .32484 .7859 L p .33018 .79362 L F P
0 g
s
.767 .579 .644 r
.33018 .79362 m .3325 .78875 L .33217 .78721 L p F P
0 g
s
.695 .545 .68 r
.41568 .83451 m .4195 .83439 L .42134 .84166 L p F P
0 g
s
.695 .545 .68 r
.42134 .84166 m .40824 .84207 L .41568 .83451 L p F P
0 g
s
.722 .618 .741 r
.38131 .89704 m .38307 .90156 L .37832 .90548 L p F P
0 g
s
.722 .618 .741 r
.37636 .89683 m .38131 .89704 L p .37832 .90548 L F P
0 g
s
.722 .618 .741 r
.36882 .90342 m .37636 .89683 L p .37832 .90548 L F P
0 g
s
.722 .618 .741 r
.37832 .90548 m .3695 .90504 L .36882 .90342 L p F P
0 g
s
.765 .58 .647 r
.34412 .80272 m .33551 .80135 L .3386 .79506 L p F P
0 g
s
.769 .585 .649 r
.33369 .79421 m .3386 .79506 L .33551 .80135 L p F P
0 g
s
.77 .581 .644 r
.3386 .79506 m .33369 .79421 L .3325 .78875 L p F P
0 g
s
.87 .743 .72 r
.07295 .82386 m .07714 .8266 L .07331 .83307 L p F P
0 g
s
.866 .746 .728 r
.07714 .8266 m .07295 .82386 L .07705 .81732 L p F P
0 g
s
.706 .597 .731 r
.3973 .9004 m .40118 .89735 L .39615 .89736 L closepath p F P
0 g
s
.731 .571 .674 r
.3758 .83413 m .36589 .83349 L .371 .82659 L p F P
0 g
s
.738 .581 .679 r
.36059 .82575 m .371 .82659 L .36589 .83349 L p F P
0 g
s
.685 .587 .74 r
.42876 .90829 m .43429 .9048 L .4276 .90523 L closepath p F P
0 g
s
.742 .722 .833 r
.27806 .94319 m .28135 .94774 L .27344 .95275 L p F P
0 g
s
.742 .722 .833 r
.26701 .9506 m .27806 .94319 L p .27344 .95275 L F P
0 g
s
.742 .722 .833 r
.27344 .95275 m .26767 .95142 L .26701 .9506 L p F P
0 g
s
.555 .372 .587 r
.49609 .76148 m .49561 .7556 L .50662 .75217 L p F P
0 g
s
.546 .349 .564 r
.50633 .7465 m .50662 .75217 L .49561 .7556 L p F P
0 g
s
.675 .588 .751 r
.44601 .917 m .45541 .91188 L .44439 .91294 L closepath p F P
0 g
s
.674 .595 .759 r
.44601 .917 m .45541 .91188 L p .4555 .92101 L F P
0 g
s
.875 .734 .703 r
.07408 .84214 m .07453 .8413 L .07091 .83741 L p F P
0 g
s
.783 .295 .059 r
.11705 .93697 m .11867 .93918 L .11484 .9384 L p F P
0 g
s
.783 .295 .059 r
.11484 .9384 m .11195 .93468 L .11705 .93697 L p F P
0 g
s
.567 .609 .854 r
.64465 .72404 m .64435 .72349 L .64542 .72342 L closepath p F P
0 g
s
.795 .569 .595 r
.30942 .76293 m .3092 .76092 L .30876 .76277 L closepath p F P
0 g
s
.735 .642 .756 r
.34603 .92117 m .34337 .91563 L .33767 .92037 L closepath p F P
0 g
s
.814 .57 .57 r
.30293 .7552 m .29619 .75322 L .29701 .74766 L p F P
0 g
s
.829 .583 .568 r
.29069 .74555 m .29701 .74766 L .29619 .75322 L p F P
0 g
s
.533 .551 .819 r
.68365 .75554 m .68194 .75184 L .68777 .75216 L closepath p F P
0 g
s
.528 .54 .812 r
.68365 .75554 m .68777 .75216 L p .69614 .75905 L F P
0 g
s
.665 .6 .773 r
.46325 .92582 m .47441 .92059 L p .47671 .92808 L F P
0 g
s
.667 .594 .764 r
.47374 .91895 m .47441 .92059 L .46325 .92582 L p F P
0 g
s
.667 .594 .764 r
.46325 .92582 m .46101 .92049 L .47374 .91895 L p F P
0 g
s
.66 .602 .779 r
.49002 .92618 m .49168 .92997 L .4805 .9345 L p F P
0 g
s
.66 .602 .779 r
.4805 .9345 m .47756 .92798 L .49002 .92618 L p F P
0 g
s
.457 .384 .687 r
.72588 .84228 m .73296 .8374 L p .73086 .84714 L F P
0 g
s
.457 .384 .687 r
.73086 .84714 m .7264 .8444 L .72588 .84228 L p F P
0 g
s
.465 .402 .702 r
.72588 .84228 m .73296 .8374 L .72583 .83372 L p F P
0 g
s
.683 .538 .682 r
.4195 .83439 m .43231 .8336 L .42359 .84152 L p F P
0 g
s
.683 .538 .682 r
.42359 .84152 m .42134 .84166 L .4195 .83439 L p F P
0 g
s
.745 .66 .767 r
.32745 .92869 m .32108 .93375 L .31789 .92809 L p F P
0 g
s
.746 .694 .801 r
.29568 .94488 m .29587 .94474 L .29555 .94468 L closepath p F P
0 g
s
.74 .69 .803 r
.29555 .94468 m .29568 .94488 L p .28135 .94774 L F P
0 g
s
.889 .699 .64 r
.07024 .86328 m .07468 .86589 L .07262 .87187 L p F P
0 g
s
.884 .707 .658 r
.07468 .86589 m .07024 .86328 L .07265 .8572 L p F P
0 g
s
.671 .523 .675 r
.43292 .83302 m .44161 .82551 L .43139 .82645 L closepath p F P
0 g
s
.683 .536 .68 r
.43139 .82645 m .43292 .83302 L .43231 .8336 L p F P
0 g
s
.582 .641 .875 r
.63277 .71394 m .62709 .71462 L .62422 .70991 L p F P
0 g
s
.767 .58 .645 r
.33369 .79421 m .3325 .78875 L .33018 .79362 L closepath p F P
0 g
s
.696 .589 .731 r
.41151 .89995 m .41539 .89712 L .41052 .89727 L closepath p F P
0 g
s
.856 .757 .753 r
.08153 .81067 m .07741 .80789 L .08231 .80111 L p F P
0 g
s
.861 .754 .744 r
.08153 .81067 m .0795 .81363 L .07584 .81018 L p F P
0 g
s
.861 .754 .744 r
.07584 .81018 m .07741 .80789 L .08153 .81067 L p F P
0 g
s
.747 .693 .8 r
.30606 .93563 m .30676 .93681 L .29587 .94474 L p F P
0 g
s
.747 .693 .8 r
.29936 .93463 m .30606 .93563 L p .29587 .94474 L F P
0 g
s
.747 .693 .8 r
.29242 .93996 m .29936 .93463 L p .29587 .94474 L F P
0 g
s
.747 .693 .8 r
.29587 .94474 m .29555 .94468 L .29242 .93996 L p F P
0 g
s
.716 .606 .733 r
.38307 .90156 m .38827 .89723 L .38131 .89704 L closepath p F P
0 g
s
.671 .967 .925 r
.56253 .70329 m .55408 .70813 L p .55008 .70959 L F P
0 g
s
.639 .923 .976 r
.55408 .70813 m .56253 .70329 L .56425 .70386 L closepath p F P
0 g
s
.746 .571 .657 r
.34412 .80272 m .3406 .80914 L .34966 .81038 L p F P
0 g
s
.764 .588 .659 r
.33551 .80135 m .34412 .80272 L .3406 .80914 L p F P
0 g
s
.74 .69 .803 r
.28135 .94774 m .28752 .94339 L .29555 .94468 L p F P
0 g
s
.739 .691 .804 r
.29555 .94468 m .29242 .93996 L .28752 .94339 L closepath p F P
0 g
s
.706 .596 .73 r
.40118 .89735 m .39615 .89736 L .39424 .89224 L p F P
0 g
s
.712 .599 .728 r
.39615 .89736 m .39424 .89224 L .38827 .89723 L closepath p F P
0 g
s
.675 .597 .76 r
.46101 .92049 m .4602 .91856 L .4555 .92101 L closepath p F P
0 g
s
.674 .595 .759 r
.45746 .91169 m .4602 .91856 L .4555 .92101 L p F P
0 g
s
.674 .595 .759 r
.45541 .91188 m .45746 .91169 L p .4555 .92101 L F P
0 g
s
.704 .592 .728 r
.41052 .89727 m .40845 .89162 L .40118 .89735 L closepath p F P
0 g
s
.706 .596 .73 r
.40752 .88897 m .40845 .89162 L .40118 .89735 L p F P
0 g
s
.706 .596 .73 r
.39813 .889 m .40752 .88897 L p .40118 .89735 L F P
0 g
s
.706 .596 .73 r
.39424 .89224 m .39813 .889 L p .40118 .89735 L F P
0 g
s
.881 .728 .688 r
.06982 .83944 m .07408 .84214 L .07104 .84838 L p F P
0 g
s
.875 .734 .703 r
.07091 .83741 m .06982 .83944 L .07408 .84214 L p F P
0 g
s
.132 0 .004 r
.68281 .93851 m .68958 .93403 L .68369 .93678 L closepath p F P
0 g
s
.218 0 .145 r
.69412 .93057 m .69486 .92811 L p .68369 .93678 L F P
0 g
s
.218 0 .145 r
.68369 .93678 m .68958 .93403 L .69412 .93057 L p F P
0 g
s
.101 0 0 r
.68281 .93851 m .68369 .93678 L p .67171 .94463 L F P
0 g
s
.566 .614 .86 r
.64542 .72342 m .64435 .72349 L .64148 .71837 L p F P
0 g
s
.685 .586 .739 r
.43429 .9048 m .4276 .90523 L .42571 .90023 L p F P
0 g
s
.707 .564 .691 r
.39472 .84212 m .40736 .8421 L p .40084 .84962 L F P
0 g
s
.707 .564 .691 r
.39332 .84364 m .39472 .84212 L p .40084 .84962 L F P
0 g
s
.71 .562 .685 r
.39332 .84364 m .39472 .84212 L .3929 .84211 L closepath p F P
0 g
s
.711 .75 .882 r
.22746 .96086 m .23187 .95873 L .23894 .96042 L p F P
0 g
s
.697 .741 .885 r
.23834 .95563 m .23187 .95873 L .23894 .96042 L p F P
0 g
s
.697 .741 .885 r
.23894 .96042 m .24174 .95918 L .23834 .95563 L p F P
0 g
s
.61 .446 .635 r
.47538 .78581 m .47467 .78112 L .47978 .77821 L p F P
0 g
s
.719 .575 .691 r
.3929 .84211 m .39332 .84364 L .38801 .84948 L p F P
0 g
s
.719 .575 .691 r
.38245 .84181 m .3929 .84211 L p .38801 .84948 L F P
0 g
s
.697 .551 .685 r
.40754 .84277 m .40824 .84207 L .40736 .8421 L closepath p F P
0 g
s
.707 .564 .691 r
.40736 .8421 m .40754 .84277 L .40084 .84962 L p F P
0 g
s
0 0 0 r
.67144 .94493 m .67364 .94378 L .67171 .94463 L closepath p F P
0 g
s
.101 0 0 r
.67171 .94463 m .67364 .94378 L .68281 .93851 L p F P
0 g
s
.729 .717 .839 r
.25603 .95708 m .2661 .95113 L .26767 .95142 L p F P
0 g
s
.737 .716 .831 r
.2661 .95113 m .25603 .95708 L .25267 .95324 L p F P
0 g
s
.695 .554 .691 r
.40824 .84207 m .42134 .84166 L p .41513 .84937 L F P
0 g
s
.695 .554 .691 r
.40754 .84277 m .40824 .84207 L p .41513 .84937 L F P
0 g
s
.546 .568 .828 r
.66706 .73954 m .67619 .73964 L p .67833 .74558 L F P
0 g
s
.544 .569 .831 r
.67619 .73964 m .66706 .73954 L .67354 .73419 L closepath p F P
0 g
s
.549 .58 .838 r
.67331 .73373 m .67354 .73419 L .66706 .73954 L p F P
0 g
s
.549 .58 .838 r
.66167 .73386 m .67331 .73373 L p .66706 .73954 L F P
0 g
s
.722 .572 .684 r
.37606 .8351 m .3768 .83418 L p .38245 .84181 L F P
0 g
s
.725 .571 .68 r
.37606 .8351 m .3768 .83418 L .3758 .83413 L closepath p F P
0 g
s
.729 .632 .751 r
.3577 .91305 m .35766 .91296 L .35756 .91304 L closepath p F P
0 g
s
.696 .588 .73 r
.41539 .89712 m .41052 .89727 L .40845 .89162 L p F P
0 g
s
.726 .626 .747 r
.35454 .9059 m .34729 .9122 L .35756 .91304 L p F P
0 g
s
.726 .626 .747 r
.35756 .91304 m .35766 .91296 L .35454 .9059 L p F P
0 g
s
.73 .619 .735 r
.36709 .9049 m .35766 .91296 L .35454 .9059 L p F P
0 g
s
.695 .554 .691 r
.41513 .84937 m .40941 .84956 L .40754 .84277 L p F P
0 g
s
.704 .559 .688 r
.40941 .84956 m .40754 .84277 L .40084 .84962 L closepath p F P
0 g
s
.6 .668 .887 r
.61038 .70796 m .60988 .70721 L .61176 .70689 L closepath p F P
0 g
s
.804 .78 .83 r
.13311 .73943 m .12946 .74262 L .12584 .73943 L p F P
0 g
s
.811 .779 .823 r
.12427 .74739 m .12946 .74262 L .12584 .73943 L p F P
0 g
s
.814 .779 .82 r
.12427 .74739 m .11826 .75302 L .11462 .74984 L p F P
0 g
s
.814 .779 .82 r
.11462 .74984 m .12037 .74446 L .12427 .74739 L p F P
0 g
s
.811 .779 .823 r
.12584 .73943 m .12037 .74446 L .12427 .74739 L p F P
0 g
s
.501 .488 .774 r
.7185 .78976 m .70822 .78761 L .7079 .78674 L p F P
0 g
s
.457 .384 .686 r
.72762 .84932 m .7264 .8444 L .73086 .84714 L closepath p F P
0 g
s
.716 .605 .731 r
.39306 .88898 m .39424 .89224 L .38827 .89723 L p F P
0 g
s
.716 .605 .731 r
.38547 .88881 m .39306 .88898 L p .38827 .89723 L F P
0 g
s
.716 .605 .731 r
.38 .89365 m .38547 .88881 L p .38827 .89723 L F P
0 g
s
.716 .605 .731 r
.38827 .89723 m .38131 .89704 L .38 .89365 L p F P
0 g
s
.735 .583 .686 r
.3758 .83413 m .37606 .8351 L .37114 .84124 L p F P
0 g
s
.735 .583 .686 r
.36589 .83349 m .3758 .83413 L p .37114 .84124 L F P
0 g
s
.715 .568 .688 r
.39501 .84962 m .39332 .84364 L .38801 .84948 L closepath p F P
0 g
s
.707 .564 .691 r
.40084 .84962 m .39501 .84962 L .39332 .84364 L p F P
0 g
s
.82 .778 .813 r
.11608 .75515 m .11826 .75302 L .11462 .74984 L p F P
0 g
s
.43 .759 .996 r
.17264 .96028 m .1813 .95966 L p .16722 .95837 L F P
0 g
s
.43 .759 .996 r
.16722 .95837 m .16863 .95916 L .17264 .96028 L p F P
0 g
s
.804 .78 .83 r
.12584 .73943 m .1292 .73649 L .13311 .73943 L p F P
0 g
s
.802 .78 .833 r
.13699 .72981 m .1292 .73649 L .13311 .73943 L p F P
0 g
s
.802 .78 .833 r
.13311 .73943 m .14059 .73301 L .13699 .72981 L p F P
0 g
s
.797 .572 .596 r
.30293 .7552 m .3016 .76092 L .30876 .76277 L p F P
0 g
s
.816 .587 .591 r
.29619 .75322 m .30293 .7552 L .3016 .76092 L p F P
0 g
s
.722 .572 .684 r
.38245 .84181 m .37788 .84162 L .37606 .8351 L p F P
0 g
s
.728 .575 .683 r
.37788 .84162 m .37606 .8351 L .37114 .84124 L closepath p F P
0 g
s
.501 .488 .774 r
.7079 .78674 m .71428 .7817 L p .7185 .78976 L F P
0 g
s
.506 .5 .784 r
.7079 .78674 m .70529 .7801 L .71428 .7817 L closepath p F P
0 g
s
.675 .588 .75 r
.45541 .91188 m .44439 .91294 L .44295 .9093 L p F P
0 g
s
.725 .62 .74 r
.3695 .90504 m .36882 .90342 L .36709 .9049 L closepath p F P
0 g
s
.658 .508 .668 r
.44411 .82329 m .45172 .8172 L .44302 .81827 L closepath p F P
0 g
s
.671 .521 .673 r
.44302 .81827 m .44411 .82329 L .44161 .82551 L p F P
0 g
s
.742 .573 .664 r
.34966 .81038 m .34568 .81694 L .35521 .81804 L p F P
0 g
s
.759 .589 .666 r
.3406 .80914 m .34966 .81038 L .34568 .81694 L p F P
0 g
s
.745 .66 .767 r
.31789 .92809 m .31864 .92746 L .32745 .92869 L p F P
0 g
s
.734 .651 .767 r
.32851 .91923 m .31864 .92746 L .32745 .92869 L p F P
0 g
s
.734 .651 .767 r
.32932 .91932 m .32851 .91923 L p .32745 .92869 L F P
0 g
s
.734 .651 .767 r
.32745 .92869 m .33221 .92494 L .32932 .91932 L p F P
0 g
s
.82 .778 .813 r
.11462 .74984 m .11218 .75223 L .11608 .75515 L p F P
0 g
s
.823 .777 .809 r
.11218 .75223 m .11608 .75515 L .10856 .7627 L p F P
0 g
s
.629 .471 .65 r
.46555 .80121 m .46436 .79458 L .47646 .79232 L p F P
0 g
s
.629 .467 .644 r
.47538 .78581 m .47646 .79232 L .46436 .79458 L p F P
0 g
s
.695 .585 .728 r
.42447 .89681 m .42266 .89178 L .41539 .89712 L closepath p F P
0 g
s
.696 .588 .73 r
.42155 .88858 m .42266 .89178 L .41539 .89712 L p F P
0 g
s
.696 .588 .73 r
.41202 .88886 m .42155 .88858 L p .41539 .89712 L F P
0 g
s
.696 .588 .73 r
.40845 .89162 m .41202 .88886 L p .41539 .89712 L F P
0 g
s
.635 .705 .897 r
.5608 .96022 m .56068 .96007 L .56997 .95775 L closepath p F P
0 g
s
.744 .576 .666 r
.35602 .81813 m .35578 .81715 L .35521 .81804 L closepath p F P
0 g
s
.72 .607 .73 r
.38131 .89704 m .38 .89365 L .37636 .89683 L closepath p F P
0 g
s
.719 .575 .691 r
.37906 .84578 m .38245 .84181 L p .38801 .84948 L F P
0 g
s
.722 .573 .686 r
.37906 .84578 m .38245 .84181 L .37788 .84162 L closepath p F P
0 g
s
.803 .587 .61 r
.31416 .77047 m .31045 .76949 L .30942 .76293 L p F P
0 g
s
.794 .581 .613 r
.30876 .76277 m .30942 .76293 L .31045 .76949 L p F P
0 g
s
.635 .681 .876 r
.56997 .95775 m .56068 .96007 L .55773 .9558 L p F P
0 g
s
.333 .049 .324 r
.52763 .72708 m .53371 .72091 L .52836 .72349 L closepath p F P
0 g
s
.212 0 .125 r
.53884 .71723 m .53998 .71526 L p .52836 .72349 L F P
0 g
s
.212 0 .125 r
.52836 .72349 m .53371 .72091 L .53884 .71723 L p F P
0 g
s
.708 .592 .724 r
.39424 .89224 m .39813 .889 L .39306 .88898 L closepath p F P
0 g
s
.722 .614 .736 r
.36531 .8962 m .35648 .90415 L .36709 .9049 L p F P
0 g
s
.722 .614 .736 r
.3659 .89624 m .36531 .8962 L p .36709 .9049 L F P
0 g
s
.722 .614 .736 r
.36709 .9049 m .36882 .90342 L .3659 .89624 L p F P
0 g
s
.73 .619 .735 r
.35454 .9059 m .35648 .90415 L .36709 .9049 L p F P
0 g
s
.742 .578 .671 r
.36059 .82575 m .35796 .8255 L .35602 .81813 L p F P
0 g
s
.744 .58 .671 r
.35521 .81804 m .35602 .81813 L .35796 .8255 L p F P
0 g
s
.686 .581 .732 r
.42571 .90023 m .43143 .8964 L .42447 .89681 L closepath p F P
0 g
s
.685 .586 .739 r
.42571 .90023 m .43143 .8964 L p .43429 .9048 L F P
0 g
s
.845 .496 .393 r
.27829 .73064 m .27255 .72831 L .27126 .72344 L p F P
0 g
s
.86 .513 .394 r
.26598 .72096 m .27126 .72344 L .27255 .72831 L p F P
0 g
s
.83 .388 .182 r
.26536 .71964 m .26598 .72096 L .27126 .72344 L p F P
0 g
s
.793 .78 .841 r
.14282 .7312 m .14059 .73301 L .13699 .72981 L p F P
0 g
s
.725 .616 .735 r
.36882 .90342 m .37636 .89683 L .3659 .89624 L closepath p F P
0 g
s
.643 .655 .847 r
.54072 .94955 m .54346 .95413 L p .52922 .95234 L F P
0 g
s
.643 .655 .847 r
.52922 .95234 m .5335 .95113 L .54072 .94955 L p F P
0 g
s
.641 .636 .83 r
.52922 .95234 m .5335 .95113 L .52909 .95212 L closepath p F P
0 g
s
.564 .606 .854 r
.64542 .72342 m .65592 .72284 L .65305 .71748 L p F P
0 g
s
.564 .606 .854 r
.65305 .71748 m .6525 .71752 L .64542 .72342 L p F P
0 g
s
.566 .614 .86 r
.64148 .71837 m .6525 .71752 L .64542 .72342 L p F P
0 g
s
.698 .584 .724 r
.40845 .89162 m .41202 .88886 L .40752 .88897 L closepath p F P
0 g
s
.705 .568 .698 r
.40084 .84962 m .40941 .84956 L p .40682 .85717 L F P
0 g
s
.705 .568 .698 r
.39632 .85421 m .40084 .84962 L p .40682 .85717 L F P
0 g
s
.707 .565 .692 r
.39632 .85421 m .40084 .84962 L .39501 .84962 L closepath p F P
0 g
s
.716 .578 .699 r
.39501 .84962 m .39632 .85421 L .39342 .85718 L p F P
0 g
s
.716 .578 .699 r
.38801 .84948 m .39501 .84962 L p .39342 .85718 L F P
0 g
s
.744 .58 .671 r
.35796 .8255 m .35074 .82475 L .35521 .81804 L p F P
0 g
s
.755 .587 .668 r
.34568 .81694 m .35521 .81804 L .35074 .82475 L p F P
0 g
s
.864 .754 .739 r
.07705 .81732 m .0795 .81363 L .07584 .81018 L p F P
0 g
s
.685 .586 .739 r
.44109 .90436 m .4399 .90121 L .43429 .9048 L closepath p F P
0 g
s
.685 .586 .739 r
.43803 .896 m .4399 .90121 L .43429 .9048 L p F P
0 g
s
.685 .586 .739 r
.43143 .8964 m .43803 .896 L p .43429 .9048 L F P
0 g
s
.641 .636 .83 r
.5335 .95113 m .52909 .95212 L .52621 .94698 L p F P
0 g
s
.695 .555 .692 r
.41054 .85362 m .41513 .84937 L .40941 .84956 L closepath p F P
0 g
s
.705 .568 .698 r
.40941 .84956 m .41054 .85362 L .40682 .85717 L p F P
0 g
s
.706 .587 .72 r
.40752 .88897 m .40541 .88291 L .39813 .889 L closepath p F P
0 g
s
.709 .591 .723 r
.40471 .88083 m .40541 .88291 L .39813 .889 L p F P
0 g
s
.709 .591 .723 r
.3945 .8808 m .40471 .88083 L p .39813 .889 L F P
0 g
s
.709 .591 .723 r
.39118 .88374 m .3945 .8808 L p .39813 .889 L F P
0 g
s
.709 .591 .723 r
.39813 .889 m .39306 .88898 L .39118 .88374 L p F P
0 g
s
.589 .771 .966 r
.18487 .962 m .19548 .9598 L .199 .96245 L p F P
0 g
s
.613 .771 .956 r
.19548 .9598 m .18487 .962 L .1813 .95966 L p F P
0 g
s
.741 .654 .763 r
.33221 .92494 m .33767 .92037 L .32932 .91932 L closepath p F P
0 g
s
.794 .581 .613 r
.31045 .76949 m .30694 .76864 L .30876 .76277 L p F P
0 g
s
.804 .588 .609 r
.3016 .76092 m .30876 .76277 L .30694 .76864 L p F P
0 g
s
.746 .779 .88 r
.1871 .70594 m .17718 .71194 L .17363 .70872 L p F P
0 g
s
.362 .83 .784 r
.6584 .9512 m .65744 .9515 L .64602 .95571 L p F P
0 g
s
.425 .869 .876 r
.65744 .9515 m .64602 .95571 L .64331 .95542 L p F P
0 g
s
.542 .906 .963 r
.64602 .95571 m .64331 .95542 L p .63188 .95901 L F P
0 g
s
.684 .541 .685 r
.42173 .84317 m .42359 .84152 L .42134 .84166 L closepath p F P
0 g
s
.695 .554 .691 r
.42134 .84166 m .42173 .84317 L .41513 .84937 L p F P
0 g
s
.89 .596 .482 r
.09201 .91259 m .0872 .91016 L .08702 .90477 L p F P
0 g
s
.893 .598 .479 r
.08227 .90231 m .08702 .90477 L .0872 .91016 L p F P
0 g
s
.892 .625 .526 r
.08702 .90477 m .08227 .90231 L .08262 .89678 L p F P
0 g
s
.599 .679 .897 r
.61176 .70689 m .60988 .70721 L .607 .70306 L p F P
0 g
s
.793 .78 .841 r
.13699 .72981 m .13891 .72826 L .14282 .7312 L p F P
0 g
s
.791 .781 .844 r
.14807 .72096 m .13891 .72826 L .14282 .7312 L p F P
0 g
s
.791 .781 .844 r
.14282 .7312 m .15166 .72415 L .14807 .72096 L p F P
0 g
s
.849 .766 .77 r
.08744 .79428 m .08765 .79401 L .08398 .79074 L p F P
0 g
s
.715 .595 .721 r
.39306 .88898 m .39118 .88374 L .38547 .88881 L closepath p F P
0 g
s
.698 .583 .722 r
.41202 .88886 m .40752 .88897 L .40541 .88291 L p F P
0 g
s
.407 .269 .58 r
.73033 .87686 m .72343 .88108 L .72413 .88706 L p F P
0 g
s
.421 .279 .582 r
.72239 .88807 m .72413 .88706 L .72343 .88108 L p F P
0 g
s
.425 .301 .607 r
.72343 .88108 m .73033 .87686 L .72715 .87204 L p F P
0 g
s
.721 .573 .687 r
.37788 .84162 m .37114 .84124 L p .37627 .84902 L F P
0 g
s
.721 .573 .687 r
.37627 .84902 m .37906 .84578 L .37788 .84162 L p F P
0 g
s
.855 .763 .761 r
.08342 .79143 m .08744 .79428 L .08231 .80111 L p F P
0 g
s
.849 .766 .77 r
.08398 .79074 m .08342 .79143 L .08744 .79428 L p F P
0 g
s
.725 .614 .734 r
.37809 .88855 m .38 .89365 L .37636 .89683 L p F P
0 g
s
.725 .614 .734 r
.37379 .88835 m .37809 .88855 L p .37636 .89683 L F P
0 g
s
.725 .614 .734 r
.36573 .89582 m .37379 .88835 L p .37636 .89683 L F P
0 g
s
.725 .614 .734 r
.37636 .89683 m .3659 .89624 L .36573 .89582 L p F P
0 g
s
.463 .403 .704 r
.73274 .82887 m .72583 .83372 L .73296 .8374 L p F P
0 g
s
.474 .42 .716 r
.73222 .8271 m .73274 .82887 L .72583 .83372 L p F P
0 g
s
.474 .42 .716 r
.7262 .82445 m .73222 .8271 L p .72583 .83372 L F P
0 g
s
.675 .588 .75 r
.44295 .9093 m .45355 .90321 L p .45541 .91188 L F P
0 g
s
.676 .582 .742 r
.44295 .9093 m .45355 .90321 L .44109 .90436 L closepath p F P
0 g
s
.67 .595 .762 r
.47136 .91305 m .47374 .91895 L .46101 .92049 L p F P
0 g
s
.67 .595 .762 r
.46101 .92049 m .4602 .91856 L .47136 .91305 L p F P
0 g
s
.827 .776 .804 r
.10856 .7627 m .10697 .76435 L .10331 .76116 L p F P
0 g
s
.827 .776 .804 r
.10331 .76116 m .10463 .7598 L .10856 .7627 L p F P
0 g
s
.823 .777 .809 r
.10856 .7627 m .10463 .7598 L .11218 .75223 L p F P
0 g
s
.716 .578 .699 r
.38207 .85596 m .38801 .84948 L p .39342 .85718 L F P
0 g
s
.719 .576 .693 r
.38207 .85596 m .38801 .84948 L .38006 .84921 L closepath p F P
0 g
s
.719 .575 .691 r
.38801 .84948 m .38006 .84921 L .37906 .84578 L p F P
0 g
s
.686 .581 .731 r
.43143 .8964 m .42447 .89681 L .42266 .89178 L p F P
0 g
s
.886 .559 .426 r
.09763 .92023 m .09277 .91783 L .09201 .91259 L p F P
0 g
s
.889 .561 .422 r
.0872 .91016 m .09201 .91259 L .09277 .91783 L p F P
0 g
s
.586 .416 .618 r
.48585 .7744 m .48536 .77057 L .49673 .76752 L p F P
0 g
s
.582 .403 .605 r
.49609 .76148 m .49673 .76752 L .48536 .77057 L p F P
0 g
s
.603 .429 .618 r
.48536 .77057 m .48585 .7744 L .47978 .77821 L p F P
0 g
s
.895 .628 .525 r
.07794 .89429 m .08262 .89678 L .08227 .90231 L p F P
0 g
s
.892 .648 .563 r
.08262 .89678 m .07794 .89429 L .07878 .88862 L p F P
0 g
s
0 0 0 r
.67364 .94378 m .67144 .94493 L .66888 .94683 L p F P
0 g
s
0 0 0 r
.67144 .94493 m .66888 .94683 L p .6584 .9512 L F P
0 g
s
.719 .602 .725 r
.38 .89365 m .38547 .88881 L .37809 .88855 L closepath p F P
0 g
s
.705 .568 .698 r
.40682 .85717 m .39722 .85724 L .39632 .85421 L p F P
0 g
s
.712 .572 .696 r
.39722 .85724 m .39632 .85421 L .39342 .85718 L closepath p F P
0 g
s
.769 .585 .649 r
.33551 .80135 m .33533 .80132 L .33369 .79421 L p F P
0 g
s
.767 .584 .65 r
.33018 .79362 m .33369 .79421 L .33533 .80132 L p F P
0 g
s
.682 .544 .691 r
.42173 .84317 m .42359 .84152 L p .43158 .84851 L F P
0 g
s
.682 .544 .691 r
.43158 .84851 m .42333 .84906 L .42173 .84317 L p F P
0 g
s
.693 .551 .689 r
.42333 .84906 m .42173 .84317 L .41513 .84937 L closepath p F P
0 g
s
.742 .581 .675 r
.35875 .82839 m .36059 .82575 L .35796 .8255 L closepath p F P
0 g
s
.738 .581 .679 r
.35875 .82839 m .36059 .82575 L p .36589 .83349 L F P
0 g
s
.73 .73 .85 r
.25267 .95324 m .24174 .95918 L .23834 .95563 L p F P
0 g
s
.682 .544 .691 r
.42359 .84152 m .43489 .84081 L p .43158 .84851 L F P
0 g
s
.683 .538 .682 r
.43489 .84081 m .42359 .84152 L .43231 .8336 L p F P
0 g
s
.697 .58 .72 r
.42155 .88858 m .41961 .88293 L .41202 .88886 L closepath p F P
0 g
s
.698 .583 .722 r
.41881 .8805 m .41961 .88293 L .41202 .88886 L p F P
0 g
s
.698 .583 .722 r
.40802 .88076 m .41881 .8805 L p .41202 .88886 L F P
0 g
s
.698 .583 .722 r
.40541 .88291 m .40802 .88076 L p .41202 .88886 L F P
0 g
s
.832 .775 .798 r
.10166 .77007 m .10697 .76435 L .10331 .76116 L p F P
0 g
s
.052 0 0 r
.53884 .71723 m .54623 .71186 L .53998 .71526 L closepath p F P
0 g
s
0 0 0 r
.55008 .70959 m .54623 .71186 L .53998 .71526 L p F P
0 g
s
.683 .535 .678 r
.43305 .83355 m .43292 .83302 L .43231 .8336 L closepath p F P
0 g
s
.675 .53 .68 r
.43305 .83355 m .43292 .83302 L .44161 .82551 L p F P
0 g
s
.683 .538 .682 r
.43231 .8336 m .43305 .83355 L .43489 .84081 L p F P
0 g
s
.693 .558 .698 r
.41513 .84937 m .42333 .84906 L p .42189 .8567 L F P
0 g
s
.693 .558 .698 r
.41054 .85362 m .41513 .84937 L p .42189 .8567 L F P
0 g
s
.796 .587 .619 r
.3195 .77818 m .3122 .7764 L .31416 .77047 L p F P
0 g
s
.801 .594 .621 r
.31045 .76949 m .31416 .77047 L .3122 .7764 L p F P
0 g
s
.719 .601 .724 r
.39015 .88075 m .39118 .88374 L .38547 .88881 L p F P
0 g
s
.719 .601 .724 r
.38215 .88052 m .39015 .88075 L p .38547 .88881 L F P
0 g
s
.719 .601 .724 r
.37693 .88543 m .38215 .88052 L p .38547 .88881 L F P
0 g
s
.719 .601 .724 r
.38547 .88881 m .37809 .88855 L .37693 .88543 L p F P
0 g
s
.742 .653 .762 r
.34147 .91159 m .34337 .91563 L .33767 .92037 L p F P
0 g
s
.742 .653 .762 r
.33765 .91119 m .34147 .91159 L p .33767 .92037 L F P
0 g
s
.742 .653 .762 r
.32905 .91878 m .33765 .91119 L p .33767 .92037 L F P
0 g
s
.742 .653 .762 r
.33767 .92037 m .32932 .91932 L .32905 .91878 L p F P
0 g
s
.706 .57 .699 r
.39722 .85724 m .39342 .85718 L p .39862 .86495 L F P
0 g
s
.706 .57 .699 r
.39862 .86495 m .39934 .86426 L .39722 .85724 L p F P
0 g
s
.705 .569 .7 r
.39934 .86426 m .40682 .85717 L .39722 .85724 L closepath p F P
0 g
s
.693 .558 .698 r
.42189 .8567 m .41155 .85711 L .41054 .85362 L p F P
0 g
s
.702 .564 .695 r
.41155 .85711 m .41054 .85362 L .40682 .85717 L closepath p F P
0 g
s
.533 .552 .82 r
.68777 .75216 m .68194 .75184 L .67906 .7456 L p F P
0 g
s
.67 .53 .685 r
.43305 .83355 m .44623 .83236 L p .4419 .84014 L F P
0 g
s
.67 .53 .685 r
.4419 .84014 m .43489 .84081 L .43305 .83355 L p F P
0 g
s
.675 .53 .68 r
.44456 .82525 m .44623 .83236 L .43305 .83355 L p F P
0 g
s
.675 .53 .68 r
.44161 .82551 m .44456 .82525 L p .43305 .83355 L F P
0 g
s
.447 .365 .671 r
.73086 .84714 m .72762 .84932 L .72917 .85617 L p F P
0 g
s
.459 .373 .671 r
.72765 .85714 m .72917 .85617 L .72762 .84932 L p F P
0 g
s
.725 .578 .69 r
.38006 .84921 m .37906 .84578 L .37627 .84902 L closepath p F P
0 g
s
.883 .719 .674 r
.07265 .8572 m .0683 .85455 L .07104 .84838 L p F P
0 g
s
.887 .712 .658 r
.0683 .85455 m .07265 .8572 L .07024 .86328 L p F P
0 g
s
.644 .492 .662 r
.45529 .81424 m .46332 .80846 L .4544 .80986 L closepath p F P
0 g
s
.657 .505 .665 r
.4544 .80986 m .45529 .81424 L .45172 .8172 L p F P
0 g
s
.7 .579 .716 r
.40541 .88291 m .40802 .88076 L .40471 .88083 L closepath p F P
0 g
s
.706 .57 .699 r
.39342 .85718 m .38599 .86475 L .39862 .86495 L p F P
0 g
s
.716 .58 .701 r
.38236 .85689 m .39342 .85718 L .38599 .86475 L p F P
0 g
s
.716 .578 .699 r
.39342 .85718 m .38236 .85689 L .38207 .85596 L p F P
0 g
s
.711 .588 .717 r
.39118 .88374 m .3945 .8808 L .39015 .88075 L closepath p F P
0 g
s
.702 .572 .705 r
.40682 .85717 m .41155 .85711 L p .41259 .86478 L F P
0 g
s
.702 .572 .705 r
.39934 .86426 m .40682 .85717 L p .41259 .86478 L F P
0 g
s
.548 .582 .84 r
.67044 .72807 m .67331 .73373 L .66167 .73386 L p F P
0 g
s
.548 .582 .84 r
.66108 .72818 m .67044 .72807 L p .66167 .73386 L F P
0 g
s
.548 .582 .84 r
.66167 .73386 m .65948 .72955 L .66108 .72818 L p F P
0 g
s
.735 .583 .686 r
.36174 .83903 m .36589 .83349 L p .37114 .84124 L F P
0 g
s
.738 .583 .681 r
.36174 .83903 m .36589 .83349 L .36002 .83298 L closepath p F P
0 g
s
.738 .581 .679 r
.36589 .83349 m .36002 .83298 L .35875 .82839 L p F P
0 g
s
.7 .578 .715 r
.40802 .88076 m .40471 .88083 L .40237 .87381 L p F P
0 g
s
.708 .582 .713 r
.40471 .88083 m .40237 .87381 L .3945 .8808 L closepath p F P
0 g
s
.447 .35 .653 r
.72972 .85891 m .72765 .85714 L .72917 .85617 L closepath p F P
0 g
s
.75 .697 .801 r
.28752 .94339 m .28135 .94774 L .27806 .94319 L p F P
0 g
s
.668 .586 .754 r
.47027 .9102 m .47136 .91305 L .4602 .91856 L p F P
0 g
s
.668 .586 .754 r
.4602 .91856 m .45746 .91169 L .47027 .9102 L p F P
0 g
s
.711 .587 .715 r
.40205 .87282 m .40237 .87381 L .3945 .8808 L p F P
0 g
s
.711 .587 .715 r
.39042 .87273 m .40205 .87282 L p .3945 .8808 L F P
0 g
s
.711 .587 .715 r
.38813 .87488 m .39042 .87273 L p .3945 .8808 L F P
0 g
s
.711 .587 .715 r
.3945 .8808 m .39015 .88075 L .38813 .87488 L p F P
0 g
s
.686 .581 .731 r
.42266 .89178 m .42765 .88824 L p .43143 .8964 L F P
0 g
s
.688 .576 .724 r
.42266 .89178 m .42765 .88824 L .42155 .88858 L closepath p F P
0 g
s
.607 .434 .623 r
.48616 .77678 m .48585 .7744 L .47978 .77821 L closepath p F P
0 g
s
.61 .446 .635 r
.47978 .77821 m .48616 .77678 L p .47538 .78581 L F P
0 g
s
.878 .512 .348 r
.09763 .92023 m .09823 .92252 L .09435 .92299 L p F P
0 g
s
.878 .512 .348 r
.09277 .91783 m .09763 .92023 L p .09435 .92299 L F P
0 g
s
.693 .56 .699 r
.41355 .86392 m .42189 .8567 L .41155 .85711 L closepath p F P
0 g
s
.702 .572 .705 r
.41155 .85711 m .41355 .86392 L .41259 .86478 L p F P
0 g
s
.719 .576 .694 r
.38006 .84921 m .37627 .84902 L p .38126 .85685 L F P
0 g
s
.719 .576 .694 r
.38126 .85685 m .38207 .85596 L .38006 .84921 L p F P
0 g
s
.225 0 .188 r
.69412 .93057 m .69953 .92579 L .69486 .92811 L closepath p F P
0 g
s
.293 .011 .302 r
.70528 .9194 m .70538 .91877 L p .69486 .92811 L F P
0 g
s
.293 .011 .302 r
.69486 .92811 m .69953 .92579 L .70528 .9194 L p F P
0 g
s
.748 .68 .785 r
.30676 .93681 m .30786 .93594 L .30606 .93563 L closepath p F P
0 g
s
.785 .586 .631 r
.32484 .7859 m .31714 .78424 L .3195 .77818 L p F P
0 g
s
.795 .597 .634 r
.3122 .7764 m .3195 .77818 L .31714 .78424 L p F P
0 g
s
.698 .575 .713 r
.41881 .8805 m .41658 .87367 L .40802 .88076 L closepath p F P
0 g
s
.7 .578 .715 r
.41623 .87256 m .41658 .87367 L .40802 .88076 L p F P
0 g
s
.7 .578 .715 r
.40352 .8728 m .41623 .87256 L p .40802 .88076 L F P
0 g
s
.7 .578 .715 r
.40237 .87381 m .40352 .8728 L p .40802 .88076 L F P
0 g
s
.717 .591 .713 r
.39015 .88075 m .38813 .87488 L .38215 .88052 L closepath p F P
0 g
s
.671 .521 .672 r
.44456 .82525 m .44411 .82329 L .44161 .82551 L closepath p F P
0 g
s
.71 .576 .703 r
.39955 .86496 m .39934 .86426 L .39862 .86495 L closepath p F P
0 g
s
.702 .572 .705 r
.41259 .86478 m .39955 .86496 L .39934 .86426 L p F P
0 g
s
.667 .605 .776 r
.47756 .92798 m .47745 .92775 L .47671 .92808 L closepath p F P
0 g
s
.665 .6 .773 r
.47441 .92059 m .47745 .92775 L .47671 .92808 L p F P
0 g
s
0 .482 .808 r
.14352 .95175 m .14961 .95366 L .14593 .9518 L p F P
0 g
s
.702 .574 .707 r
.39955 .86496 m .41259 .86478 L .40352 .8728 L p F P
0 g
s
.702 .574 .707 r
.40352 .8728 m .40205 .87282 L .39955 .86496 L p F P
0 g
s
.71 .578 .705 r
.39862 .86495 m .39955 .86496 L .40205 .87282 L p F P
0 g
s
.895 .652 .563 r
.07417 .8861 m .07878 .88862 L .07794 .89429 L p F P
0 g
s
.891 .668 .593 r
.07878 .88862 m .07417 .8861 L .07545 .88032 L p F P
0 g
s
.738 .579 .676 r
.35796 .8255 m .35074 .82475 L p .35575 .83257 L F P
0 g
s
.738 .579 .676 r
.35575 .83257 m .35875 .82839 L .35796 .8255 L p F P
0 g
s
.714 .584 .708 r
.38599 .86475 m .39862 .86495 L .39042 .87273 L p F P
0 g
s
.71 .578 .705 r
.40205 .87282 m .39042 .87273 L .39862 .86495 L p F P
0 g
s
0 .204 .611 r
.24823 .70886 m .25226 .7117 L .25734 .71426 L p F P
0 g
s
.469 0 0 r
.25226 .7117 m .24823 .70886 L .24472 .70682 L p F P
0 g
s
.662 .515 .674 r
.44456 .82525 m .44411 .82329 L .45172 .8172 L p F P
0 g
s
.702 .575 .709 r
.40237 .87381 m .40352 .8728 L .40205 .87282 L closepath p F P
0 g
s
.738 .64 .751 r
.34337 .91563 m .34729 .9122 L .34147 .91159 L closepath p F P
0 g
s
.748 .678 .783 r
.31745 .92728 m .31789 .92809 L .30786 .93594 L p F P
0 g
s
.748 .678 .783 r
.30984 .92623 m .31745 .92728 L p .30786 .93594 L F P
0 g
s
.748 .678 .783 r
.30354 .93144 m .30984 .92623 L p .30786 .93594 L F P
0 g
s
.748 .678 .783 r
.30786 .93594 m .30606 .93563 L .30354 .93144 L p F P
0 g
s
.647 .628 .816 r
.51197 .94485 m .5232 .94129 L .52621 .94698 L p F P
0 g
s
.645 .616 .806 r
.52312 .94113 m .5232 .94129 L .51197 .94485 L p F P
0 g
s
.645 .616 .806 r
.51197 .94485 m .51129 .94352 L .52312 .94113 L p F P
0 g
s
.721 .573 .687 r
.37114 .84124 m .36543 .84831 L .37627 .84902 L p F P
0 g
s
.734 .585 .689 r
.36218 .84055 m .37114 .84124 L .36543 .84831 L p F P
0 g
s
.735 .583 .686 r
.37114 .84124 m .36218 .84055 L .36174 .83903 L p F P
0 g
s
.7 .57 .705 r
.41623 .87256 m .40352 .8728 L .41259 .86478 L p F P
0 g
s
.676 .581 .742 r
.45355 .90321 m .44109 .90436 L .4399 .90121 L p F P
0 g
s
.688 .575 .723 r
.42765 .88824 m .42155 .88858 L .41961 .88293 L p F P
0 g
s
.723 .603 .722 r
.37809 .88855 m .37693 .88543 L .37379 .88835 L closepath p F P
0 g
s
0 0 0 r
.68165 .94016 m .67364 .94378 L p .66888 .94683 L F P
0 g
s
.055 0 0 r
.67364 .94378 m .68165 .94016 L .68281 .93851 L closepath p F P
0 g
s
.521 .33 .562 r
.50662 .75217 m .50633 .7465 L .51697 .74263 L p F P
0 g
s
.505 .294 .527 r
.51693 .73724 m .51697 .74263 L .50633 .7465 L p F P
0 g
s
.738 .639 .749 r
.35369 .90392 m .35454 .9059 L .34729 .9122 L p F P
0 g
s
.738 .639 .749 r
.34637 .90327 m .35369 .90392 L p .34729 .9122 L F P
0 g
s
.738 .639 .749 r
.34023 .90893 m .34637 .90327 L p .34729 .9122 L F P
0 g
s
.738 .639 .749 r
.34729 .9122 m .34147 .91159 L .34023 .90893 L p F P
0 g
s
.662 .603 .778 r
.48864 .923 m .49002 .92618 L .47756 .92798 L p F P
0 g
s
.662 .603 .778 r
.47756 .92798 m .47745 .92775 L .48864 .923 L p F P
0 g
s
.506 .5 .785 r
.71428 .7817 m .70529 .7801 L .70437 .77776 L p F P
0 g
s
.682 .546 .693 r
.42474 .8542 m .43158 .84851 L .42333 .84906 L closepath p F P
0 g
s
.693 .558 .698 r
.42333 .84906 m .42474 .8542 L .42189 .8567 L p F P
0 g
s
.714 .585 .71 r
.38813 .87488 m .39042 .87273 L .3874 .87267 L closepath p F P
0 g
s
.714 .584 .708 r
.3851 .86564 m .38599 .86475 L p .39042 .87273 L F P
0 g
s
.714 .584 .708 r
.39042 .87273 m .3874 .87267 L .3851 .86564 L p F P
0 g
s
.686 .58 .73 r
.43803 .896 m .43686 .89273 L .43143 .8964 L closepath p F P
0 g
s
.686 .581 .731 r
.43518 .88782 m .43686 .89273 L .43143 .8964 L p F P
0 g
s
.686 .581 .731 r
.42765 .88824 m .43518 .88782 L p .43143 .8964 L F P
0 g
s
.723 .755 .878 r
.23187 .95873 m .22746 .96086 L .22401 .95763 L p F P
0 g
s
.687 .758 .905 r
.21321 .962 m .22401 .95763 L .22746 .96086 L p F P
0 g
s
.652 .767 .934 r
.199 .96245 m .20972 .95906 L .21321 .962 L p F P
0 g
s
.667 .765 .924 r
.20972 .95906 m .199 .96245 L .19548 .9598 L p F P
0 g
s
.767 .579 .644 r
.32484 .7859 m .32208 .79208 L .33018 .79362 L p F P
0 g
s
.789 .598 .643 r
.31714 .78424 m .32484 .7859 L .32208 .79208 L p F P
0 g
s
.66 .591 .766 r
.48864 .923 m .47745 .92775 L .47441 .92059 L p F P
0 g
s
.78 .781 .853 r
.15377 .72258 m .15166 .72415 L .14807 .72096 L p F P
0 g
s
.721 .597 .717 r
.3874 .87267 m .38813 .87488 L .38215 .88052 L p F P
0 g
s
.202 .66 .944 r
.16111 .95615 m .15329 .95538 L .14961 .95366 L p F P
0 g
s
.105 .608 .899 r
.15329 .95538 m .16111 .95615 L .1665 .95832 L p F P
0 g
s
.719 .576 .694 r
.37627 .84902 m .36997 .85627 L .38126 .85685 L p F P
0 g
s
.731 .588 .696 r
.36543 .84831 m .37627 .84902 L .36997 .85627 L p F P
0 g
s
.722 .581 .697 r
.38236 .85689 m .38207 .85596 L .38126 .85685 L closepath p F P
0 g
s
.834 .535 .484 r
.28491 .73796 m .27872 .73578 L .27829 .73064 L p F P
0 g
s
.849 .55 .482 r
.27255 .72831 m .27829 .73064 L .27872 .73578 L p F P
0 g
s
.716 .58 .701 r
.38599 .86475 m .3848 .86471 L .38236 .85689 L p F P
0 g
s
.722 .583 .699 r
.38126 .85685 m .38236 .85689 L .3848 .86471 L p F P
0 g
s
.7 .57 .705 r
.41259 .86478 m .41381 .86476 L .41623 .87256 L p F P
0 g
s
.7 .568 .703 r
.41381 .86476 m .41355 .86392 L .41259 .86478 L closepath p F P
0 g
s
.741 .582 .678 r
.36002 .83298 m .35875 .82839 L .35575 .83257 L closepath p F P
0 g
s
.721 .597 .717 r
.3784 .87235 m .3874 .87267 L p .38215 .88052 L F P
0 g
s
.719 .587 .706 r
.3874 .87267 m .3851 .86564 L .3784 .87235 L closepath p F P
0 g
s
.697 .566 .704 r
.41381 .86476 m .41355 .86392 L .42189 .8567 L p F P
0 g
s
.835 .774 .794 r
.10166 .77007 m .09555 .77679 L .09188 .77362 L p F P
0 g
s
.835 .774 .794 r
.09188 .77362 m .09774 .76717 L .10166 .77007 L p F P
0 g
s
.832 .775 .798 r
.10331 .76116 m .09774 .76717 L .10166 .77007 L p F P
0 g
s
.691 .565 .708 r
.41381 .86476 m .42761 .86415 L p .41807 .87247 L F P
0 g
s
.691 .565 .708 r
.41807 .87247 m .41623 .87256 L .41381 .86476 L p F P
0 g
s
.697 .566 .704 r
.42541 .85655 m .42761 .86415 L .41381 .86476 L p F P
0 g
s
.697 .566 .704 r
.42189 .8567 m .42541 .85655 L p .41381 .86476 L F P
0 g
s
.63 .734 .923 r
.57494 .96104 m .58629 .95826 L .58919 .96159 L p F P
0 g
s
.631 .708 .902 r
.58629 .95826 m .57494 .96104 L .57201 .95724 L p F P
0 g
s
.654 .613 .796 r
.50639 .9335 m .50895 .93885 L p .49471 .93658 L F P
0 g
s
.654 .613 .796 r
.49471 .93658 m .50043 .93451 L .50639 .9335 L p F P
0 g
s
.651 .602 .786 r
.49471 .93658 m .50043 .93451 L .49426 .9356 L closepath p F P
0 g
s
.716 .581 .703 r
.3851 .86564 m .38599 .86475 L .3848 .86471 L closepath p F P
0 g
s
.841 .575 .537 r
.29069 .74555 m .28624 .74389 L .2865 .73848 L p F P
0 g
s
.826 .561 .539 r
.28491 .73796 m .2865 .73848 L .28624 .74389 L p F P
0 g
s
.688 .575 .723 r
.41961 .88293 m .42314 .88028 L p .42765 .88824 L F P
0 g
s
.689 .571 .717 r
.41961 .88293 m .42314 .88028 L .41881 .8805 L closepath p F P
0 g
s
.721 .598 .718 r
.37693 .88543 m .38215 .88052 L .37506 .88023 L closepath p F P
0 g
s
.721 .597 .717 r
.37387 .87689 m .3784 .87235 L p .38215 .88052 L F P
0 g
s
.721 .597 .717 r
.38215 .88052 m .37506 .88023 L .37387 .87689 L p F P
0 g
s
.722 .583 .699 r
.3848 .86471 m .37432 .86428 L .38126 .85685 L p F P
0 g
s
.728 .591 .703 r
.36997 .85627 m .38126 .85685 L .37432 .86428 L p F P
0 g
s
.612 .453 .642 r
.47646 .79232 m .47538 .78581 L .48714 .78318 L p F P
0 g
s
.61 .446 .635 r
.48616 .77678 m .48714 .78318 L .47538 .78581 L p F P
0 g
s
.597 .663 .884 r
.62134 .70532 m .61176 .70689 L .61878 .70136 L closepath p F P
0 g
s
.599 .679 .897 r
.61846 .70087 m .61878 .70136 L .61176 .70689 L p F P
0 g
s
.599 .679 .897 r
.607 .70306 m .61846 .70087 L p .61176 .70689 L F P
0 g
s
.724 .594 .71 r
.3848 .86471 m .3851 .86564 L .3784 .87235 L p F P
0 g
s
.724 .594 .71 r
.37432 .86428 m .3848 .86471 L p .3784 .87235 L F P
0 g
s
.689 .57 .716 r
.42314 .88028 m .41881 .8805 L .41658 .87367 L p F P
0 g
s
.734 .626 .739 r
.35454 .9059 m .35648 .90415 L .35369 .90392 L closepath p F P
0 g
s
.658 .515 .678 r
.44456 .82525 m .45736 .82369 L p .4533 .83146 L F P
0 g
s
.658 .515 .678 r
.4533 .83146 m .44623 .83236 L .44456 .82525 L p F P
0 g
s
.662 .515 .674 r
.45582 .81671 m .45736 .82369 L .44456 .82525 L p F P
0 g
s
.662 .515 .674 r
.45172 .8172 m .45582 .81671 L p .44456 .82525 L F P
0 g
s
.734 .625 .738 r
.35478 .89543 m .36531 .8962 L .35648 .90415 L p F P
0 g
s
.734 .625 .738 r
.35143 .89862 m .35478 .89543 L p .35648 .90415 L F P
0 g
s
.734 .625 .738 r
.35648 .90415 m .35369 .90392 L .35143 .89862 L p F P
0 g
s
.676 .581 .742 r
.4399 .90121 m .45029 .89491 L p .45355 .90321 L F P
0 g
s
.677 .575 .734 r
.4399 .90121 m .45029 .89491 L .43803 .896 L closepath p F P
0 g
s
.72 .598 .719 r
.37379 .88835 m .37693 .88543 L .37506 .88023 L p F P
0 g
s
.698 .753 .894 r
.22401 .95763 m .21321 .962 L .20972 .95906 L p F P
0 g
s
.869 .75 .73 r
.07294 .81454 m .07705 .81732 L .07295 .82386 L p F P
0 g
s
.864 .754 .739 r
.07584 .81018 m .07294 .81454 L .07705 .81732 L p F P
0 g
s
.514 0 0 r
.12638 .94359 m .1321 .94745 L .13182 .94734 L p F P
0 g
s
.514 0 0 r
.12103 .94137 m .12638 .94359 L p .13182 .94734 L F P
0 g
s
.727 .21 0 r
.11867 .93918 m .12103 .94137 L .12638 .94359 L p F P
0 g
s
.728 .616 .732 r
.3659 .89624 m .36573 .89582 L .36531 .8962 L closepath p F P
0 g
s
.729 .606 .72 r
.37379 .88835 m .36573 .89582 L .36265 .88794 L p F P
0 g
s
.729 .606 .72 r
.36265 .88794 m .36294 .88766 L .37379 .88835 L p F P
0 g
s
.72 .598 .719 r
.37072 .87999 m .36294 .88766 L .37379 .88835 L p F P
0 g
s
.72 .598 .719 r
.37506 .88023 m .37072 .87999 L p .37379 .88835 L F P
0 g
s
.691 .566 .709 r
.41658 .87367 m .41807 .87247 L .41623 .87256 L closepath p F P
0 g
s
.689 .57 .716 r
.41658 .87367 m .41807 .87247 L p .42314 .88028 L F P
0 g
s
.781 .595 .648 r
.32208 .79208 m .33018 .79362 L .32701 .79993 L p F P
0 g
s
.767 .584 .65 r
.33533 .80132 m .32701 .79993 L .33018 .79362 L p F P
0 g
s
.78 .781 .853 r
.14807 .72096 m .14986 .71963 L .15377 .72258 L p F P
0 g
s
.778 .781 .855 r
.15909 .71286 m .14986 .71963 L .15377 .72258 L p F P
0 g
s
.778 .781 .855 r
.15377 .72258 m .16267 .71605 L .15909 .71286 L p F P
0 g
s
.875 .739 .708 r
.07331 .83307 m .07091 .83741 L .06727 .83366 L p F P
0 g
s
.875 .739 .708 r
.06727 .83366 m .0691 .83034 L .07331 .83307 L p F P
0 g
s
.87 .743 .72 r
.07331 .83307 m .0691 .83034 L .07295 .82386 L p F P
0 g
s
.725 .61 .729 r
.36265 .88794 m .35478 .89543 L .36531 .8962 L p F P
0 g
s
.725 .61 .729 r
.36531 .8962 m .36573 .89582 L .36265 .88794 L p F P
0 g
s
.728 .718 .841 r
.26767 .95142 m .26701 .9506 L .2661 .95113 L closepath p F P
0 g
s
.743 .676 .787 r
.30606 .93563 m .30354 .93144 L .29936 .93463 L closepath p F P
0 g
s
.647 .617 .805 r
.52018 .93517 m .52312 .94113 L .51129 .94352 L p F P
0 g
s
.647 .617 .805 r
.51129 .94352 m .50895 .93885 L .52018 .93517 L p F P
0 g
s
.692 .556 .696 r
.42541 .85655 m .42474 .8542 L .42189 .8567 L closepath p F P
0 g
s
.689 .57 .716 r
.41807 .87247 m .42999 .87191 L p .42314 .88028 L F P
0 g
s
.69 .563 .706 r
.42999 .87191 m .42775 .86464 L .41807 .87247 L closepath p F P
0 g
s
.691 .565 .708 r
.42761 .86415 m .42775 .86464 L .41807 .87247 L p F P
0 g
s
.511 .512 .794 r
.70437 .77776 m .70238 .77288 L .70915 .77389 L closepath p F P
0 g
s
.506 .5 .785 r
.70437 .77776 m .70915 .77389 L p .71428 .7817 L F P
0 g
s
.651 .601 .786 r
.50043 .93451 m .49426 .9356 L .49168 .92997 L p F P
0 g
s
.688 .574 .722 r
.43518 .88782 m .43381 .88382 L .42765 .88824 L closepath p F P
0 g
s
.688 .575 .723 r
.43251 .8798 m .43381 .88382 L .42765 .88824 L p F P
0 g
s
.688 .575 .723 r
.42314 .88028 m .43251 .8798 L p .42765 .88824 L F P
0 g
s
.659 .506 .666 r
.45582 .81671 m .45529 .81424 L .45172 .8172 L closepath p F P
0 g
s
.735 .581 .683 r
.36002 .83298 m .35575 .83257 L p .36067 .84042 L F P
0 g
s
.735 .581 .683 r
.36067 .84042 m .36174 .83903 L .36002 .83298 L p F P
0 g
s
.686 .553 .698 r
.42541 .85655 m .42474 .8542 L .43158 .84851 L p F P
0 g
s
.89 .685 .618 r
.07545 .88032 m .07093 .87776 L .07262 .87187 L p F P
0 g
s
.895 .672 .593 r
.07093 .87776 m .07545 .88032 L .07417 .8861 L p F P
0 g
s
.676 .59 .751 r
.45746 .91169 m .45715 .91092 L .45541 .91188 L closepath p F P
0 g
s
.675 .588 .75 r
.4542 .90316 m .45715 .91092 L .45541 .91188 L p F P
0 g
s
.675 .588 .75 r
.45355 .90321 m .4542 .90316 L p .45541 .91188 L F P
0 g
s
.689 .568 .714 r
.43251 .8798 m .43078 .87446 L .42314 .88028 L closepath p F P
0 g
s
.689 .57 .716 r
.42999 .87191 m .43078 .87446 L .42314 .88028 L p F P
0 g
s
.671 .532 .686 r
.43592 .84483 m .4419 .84014 L .43489 .84081 L closepath p F P
0 g
s
.682 .544 .691 r
.43489 .84081 m .43592 .84483 L .43158 .84851 L p F P
0 g
s
.764 .588 .659 r
.33539 .80156 m .33551 .80135 L p .3406 .80914 L F P
0 g
s
.769 .59 .656 r
.33539 .80156 m .33551 .80135 L .33533 .80132 L closepath p F P
0 g
s
.577 .762 .966 r
.21667 .70205 m .2273 .69995 L .23079 .70279 L p F P
0 g
s
.564 .756 .968 r
.2273 .69995 m .21667 .70205 L .21317 .69897 L p F P
0 g
s
.675 .773 .924 r
.20242 .70311 m .21317 .69897 L .21667 .70205 L p F P
0 g
s
.75 .697 .801 r
.27806 .94319 m .27984 .94186 L .28752 .94339 L p F P
0 g
s
.738 .687 .802 r
.28916 .93496 m .27984 .94186 L .28752 .94339 L p F P
0 g
s
.738 .687 .802 r
.28752 .94339 m .29242 .93996 L .28916 .93496 L p F P
0 g
s
.724 .595 .711 r
.37387 .87689 m .3784 .87235 L .3722 .87204 L closepath p F P
0 g
s
.724 .594 .71 r
.37082 .868 m .37432 .86428 L p .3784 .87235 L F P
0 g
s
.724 .594 .71 r
.3784 .87235 m .3722 .87204 L .37082 .868 L p F P
0 g
s
.762 .586 .659 r
.33533 .80132 m .32701 .79993 L p .33193 .80779 L F P
0 g
s
.762 .586 .659 r
.33193 .80779 m .33539 .80156 L .33533 .80132 L p F P
0 g
s
.735 .626 .737 r
.35369 .90392 m .35143 .89862 L .34637 .90327 L closepath p F P
0 g
s
.835 .401 .204 r
.11195 .93468 m .10688 .93236 L .10429 .92759 L p F P
0 g
s
.834 .395 .19 r
.09921 .92526 m .10429 .92759 L .10688 .93236 L p F P
0 g
s
.861 .478 .317 r
.10429 .92759 m .09921 .92526 L .09823 .92252 L p F P
0 g
s
.28 .684 .971 r
.16722 .95837 m .1665 .95832 L .16863 .95916 L closepath p F P
0 g
s
.686 .553 .698 r
.43681 .84816 m .43883 .85559 L .42541 .85655 L p F P
0 g
s
.686 .553 .698 r
.43158 .84851 m .43681 .84816 L p .42541 .85655 L F P
0 g
s
.681 .551 .701 r
.42541 .85655 m .43883 .85559 L p .42846 .86409 L F P
0 g
s
.681 .551 .701 r
.42846 .86409 m .42761 .86415 L .42541 .85655 L p F P
0 g
s
.726 .599 .715 r
.37506 .88023 m .37387 .87689 L .37072 .87999 L closepath p F P
0 g
s
.764 .588 .659 r
.3406 .80914 m .33717 .8086 L .33539 .80156 L p F P
0 g
s
.763 .587 .66 r
.33717 .8086 m .33539 .80156 L .33193 .80779 L closepath p F P
0 g
s
.677 .575 .733 r
.45029 .89491 m .43803 .896 L .43686 .89273 L p F P
0 g
s
.332 .094 .396 r
.70538 .91877 m .70603 .91843 L .70975 .91179 L p F P
0 g
s
.323 .084 .389 r
.71532 .9088 m .70975 .91179 L .70603 .91843 L p F P
0 g
s
.364 .156 .458 r
.70975 .91179 m .71532 .9088 L .71542 .9036 L p F P
0 g
s
.648 .499 .667 r
.45582 .81671 m .45529 .81424 L .46332 .80846 L p F P
0 g
s
.759 .589 .666 r
.33835 .8131 m .3406 .80914 L p .34568 .81694 L F P
0 g
s
.764 .591 .663 r
.33835 .8131 m .3406 .80914 L .33717 .8086 L closepath p F P
0 g
s
.401 .242 .548 r
.72413 .88706 m .72239 .88807 L .72345 .89345 L p F P
0 g
s
0 0 0 r
.66888 .94683 m .666 .94805 L .6584 .9512 L p F P
0 g
s
.321 .797 .719 r
.65744 .9515 m .666 .94805 L .6584 .9512 L closepath p F P
0 g
s
.628 .475 .655 r
.46647 .80609 m .46555 .80121 L .47761 .7989 L p F P
0 g
s
.629 .471 .65 r
.47646 .79232 m .47761 .7989 L .46555 .80121 L p F P
0 g
s
.643 .488 .658 r
.46555 .80121 m .46647 .80609 L .46332 .80846 L p F P
0 g
s
.671 .773 .926 r
.21317 .69897 m .20242 .70311 L .19891 .69994 L p F P
0 g
s
.717 .776 .899 r
.18808 .70536 m .19891 .69994 L .20242 .70311 L p F P
0 g
s
.639 .665 .859 r
.54346 .95413 m .55476 .95115 L .55773 .9558 L p F P
0 g
s
.638 .65 .845 r
.55215 .94676 m .55476 .95115 L .54346 .95413 L p F P
0 g
s
.638 .65 .845 r
.54346 .95413 m .54072 .94955 L .55215 .94676 L p F P
0 g
s
.747 .665 .77 r
.31789 .92809 m .31864 .92746 L .31745 .92728 L closepath p F P
0 g
s
.671 .587 .753 r
.46832 .90512 m .47027 .9102 L .45746 .91169 L p F P
0 g
s
.671 .587 .753 r
.45746 .91169 m .45715 .91092 L .46832 .90512 L p F P
0 g
s
.699 .164 0 r
.12103 .94137 m .11867 .93918 L .11484 .9384 L p F P
0 g
s
.748 .664 .768 r
.31943 .91806 m .32851 .91923 L .31864 .92746 L p F P
0 g
s
.748 .664 .768 r
.3147 .92224 m .31943 .91806 L p .31864 .92746 L F P
0 g
s
.748 .664 .768 r
.31864 .92746 m .31745 .92728 L .3147 .92224 L p F P
0 g
s
.755 .587 .668 r
.35074 .82475 m .34161 .82354 L .34568 .81694 L p F P
0 g
s
.759 .592 .67 r
.33911 .81598 m .34568 .81694 L .34161 .82354 L p F P
0 g
s
.759 .589 .666 r
.34568 .81694 m .33911 .81598 L .33835 .8131 L p F P
0 g
s
.737 .716 .831 r
.25267 .95324 m .25845 .94959 L .2661 .95113 L p F P
0 g
s
.727 .713 .837 r
.26369 .94632 m .25845 .94959 L .2661 .95113 L p F P
0 g
s
.727 .713 .837 r
.2661 .95113 m .26701 .9506 L .26369 .94632 L p F P
0 g
s
.723 .594 .712 r
.37072 .87999 m .37387 .87689 L .3722 .87204 L p F P
0 g
s
.643 .651 .843 r
.54072 .94955 m .54048 .94914 L .5335 .95113 L closepath p F P
0 g
s
.641 .636 .83 r
.53748 .94372 m .54048 .94914 L .5335 .95113 L p F P
0 g
s
.641 .636 .83 r
.52621 .94698 m .53748 .94372 L p .5335 .95113 L F P
0 g
s
.682 .543 .69 r
.43681 .84816 m .43592 .84483 L .43158 .84851 L closepath p F P
0 g
s
.542 .906 .963 r
.64331 .95542 m .63188 .95901 L .63188 .95901 L p F P
0 g
s
.572 .88 .993 r
.63188 .95901 m .63188 .95901 L .6291 .95762 L p F P
0 g
s
.58 .868 .995 r
.61768 .96079 m .6291 .95762 L .63188 .95901 L p F P
0 g
s
.572 .88 .993 r
.64216 .955 m .63188 .95901 L p .6291 .95762 L F P
0 g
s
.572 .894 .987 r
.63188 .95901 m .64216 .955 L .64331 .95542 L closepath p F P
0 g
s
.738 .585 .685 r
.36218 .84055 m .36174 .83903 L .36067 .84042 L closepath p F P
0 g
s
.728 .592 .705 r
.37082 .868 m .37432 .86428 L .36949 .86399 L closepath p F P
0 g
s
.728 .591 .703 r
.36778 .85876 m .36997 .85627 L p .37432 .86428 L F P
0 g
s
.728 .591 .703 r
.37432 .86428 m .36949 .86399 L .36778 .85876 L p F P
0 g
s
.678 .569 .726 r
.43686 .89273 m .44592 .88691 L .43518 .88782 L closepath p F P
0 g
s
.677 .575 .733 r
.43686 .89273 m .44592 .88691 L p .45029 .89491 L F P
0 g
s
.826 .561 .539 r
.28624 .74389 m .28459 .74335 L .28491 .73796 L p F P
0 g
s
.835 .569 .536 r
.27872 .73578 m .28491 .73796 L .28459 .74335 L p F P
0 g
s
.858 .761 .755 r
.07829 .79828 m .08231 .80111 L .07741 .80789 L p F P
0 g
s
.855 .763 .761 r
.08231 .80111 m .07829 .79828 L .08342 .79143 L p F P
0 g
s
.669 .579 .745 r
.46707 .90171 m .46832 .90512 L .45715 .91092 L p F P
0 g
s
.669 .579 .745 r
.45715 .91092 m .4542 .90316 L .46707 .90171 L p F P
0 g
s
.781 .303 .096 r
.26382 .71988 m .26059 .71851 L .25734 .71426 L p F P
0 g
s
.799 .328 .107 r
.25226 .7117 m .25734 .71426 L .26059 .71851 L p F P
0 g
s
.588 .421 .623 r
.48616 .77678 m .48585 .7744 L .49704 .76993 L p F P
0 g
s
.586 .416 .618 r
.49673 .76752 m .49704 .76993 L .48585 .7744 L p F P
0 g
s
.734 .585 .689 r
.36543 .84831 m .36448 .84824 L .36218 .84055 L p F P
0 g
s
.738 .587 .688 r
.36067 .84042 m .36218 .84055 L .36448 .84824 L p F P
0 g
s
.839 .774 .789 r
.09507 .77734 m .09555 .77679 L .09188 .77362 L p F P
0 g
s
.738 .639 .749 r
.34147 .91159 m .34023 .90893 L .33765 .91119 L closepath p F P
0 g
s
.738 .579 .676 r
.35074 .82475 m .34621 .83148 L .35575 .83257 L p F P
0 g
s
.754 .594 .678 r
.34161 .82354 m .35074 .82475 L .34621 .83148 L p F P
0 g
s
.801 .594 .621 r
.3122 .7764 m .31173 .77627 L .31045 .76949 L p F P
0 g
s
.794 .589 .624 r
.30694 .76864 m .31045 .76949 L .31173 .77627 L p F P
0 g
s
.731 .609 .721 r
.36009 .87923 m .37072 .87999 L .36294 .88766 L p F P
0 g
s
.723 .594 .712 r
.36725 .87174 m .36009 .87923 L .37072 .87999 L p F P
0 g
s
.723 .594 .712 r
.3722 .87204 m .36725 .87174 L p .37072 .87999 L F P
0 g
s
.624 .771 .95 r
.58919 .96159 m .60058 .95878 L .60344 .96157 L p F P
0 g
s
.627 .739 .927 r
.60058 .95878 m .58919 .96159 L .58629 .95826 L p F P
0 g
s
.666 .781 .935 r
.58982 .69846 m .57846 .7019 L .57557 .69945 L p F P
0 g
s
.68 .823 .952 r
.56425 .70386 m .57557 .69945 L .57846 .7019 L p F P
0 g
s
.649 .747 .921 r
.57846 .7019 m .58982 .69846 L .59271 .70184 L p F P
0 g
s
.845 .772 .781 r
.09115 .77445 m .09507 .77734 L .08914 .78442 L p F P
0 g
s
.839 .774 .789 r
.09188 .77362 m .09115 .77445 L .09507 .77734 L p F P
0 g
s
.885 .723 .675 r
.06677 .84569 m .07104 .84838 L .0683 .85455 L p F P
0 g
s
.881 .728 .688 r
.07104 .84838 m .06677 .84569 L .06982 .83944 L p F P
0 g
s
.744 .699 .808 r
.27806 .94319 m .26701 .9506 L .26369 .94632 L p F P
0 g
s
.675 .539 .692 r
.43681 .84816 m .43592 .84483 L .4419 .84014 L p F P
0 g
s
.731 .59 .698 r
.36778 .85876 m .36997 .85627 L .36692 .85606 L closepath p F P
0 g
s
.731 .588 .696 r
.36475 .84914 m .36543 .84831 L p .36997 .85627 L F P
0 g
s
.731 .588 .696 r
.36997 .85627 m .36692 .85606 L .36475 .84914 L p F P
0 g
s
.681 .553 .703 r
.42775 .86464 m .42846 .86409 L .42761 .86415 L closepath p F P
0 g
s
.75 .596 .685 r
.34621 .83148 m .35575 .83257 L .35074 .83945 L p F P
0 g
s
.735 .581 .683 r
.35575 .83257 m .35074 .83945 L .36067 .84042 L p F P
0 g
s
.728 .596 .708 r
.3722 .87204 m .37082 .868 L .36725 .87174 L closepath p F P
0 g
s
.422 .3 .608 r
.73165 .86924 m .72715 .87204 L .73033 .87686 L p F P
0 g
s
.436 .327 .631 r
.72715 .87204 m .73165 .86924 L .73051 .86281 L p F P
0 g
s
.678 .568 .725 r
.44592 .88691 m .43518 .88782 L .43381 .88382 L p F P
0 g
s
.68 .557 .709 r
.42775 .86464 m .42846 .86409 L p .43482 .87155 L F P
0 g
s
.68 .557 .709 r
.43482 .87155 m .42999 .87191 L .42775 .86464 L p F P
0 g
s
.744 .663 .771 r
.31745 .92728 m .3147 .92224 L .30984 .92623 L closepath p F P
0 g
s
.38 .2 .507 r
.71542 .9036 m .72318 .89921 L .72345 .89345 L p F P
0 g
s
.348 .143 .454 r
.72318 .89921 m .71542 .9036 L .71532 .9088 L p F P
0 g
s
.562 .389 .604 r
.49673 .76752 m .49609 .76148 L .50712 .75805 L p F P
0 g
s
.555 .372 .587 r
.50662 .75217 m .50712 .75805 L .49609 .76148 L p F P
0 g
s
.738 .587 .688 r
.36448 .84824 m .35515 .84744 L .36067 .84042 L p F P
0 g
s
.746 .598 .692 r
.35074 .83945 m .36067 .84042 L .35515 .84744 L p F P
0 g
s
.734 .587 .692 r
.36475 .84914 m .36543 .84831 L .36448 .84824 L closepath p F P
0 g
s
.68 .557 .709 r
.42846 .86409 m .44103 .8632 L p .43482 .87155 L F P
0 g
s
.681 .551 .701 r
.44103 .8632 m .43893 .85594 L .42846 .86409 L closepath p F P
0 g
s
.681 .551 .701 r
.43883 .85559 m .43893 .85594 L .42846 .86409 L p F P
0 g
s
.644 .5 .672 r
.45582 .81671 m .46827 .8148 L p .46681 .82219 L F P
0 g
s
.644 .5 .672 r
.46681 .82219 m .45736 .82369 L .45582 .81671 L p F P
0 g
s
.648 .499 .667 r
.46684 .80793 m .46827 .8148 L .45582 .81671 L p F P
0 g
s
.648 .499 .667 r
.46332 .80846 m .46684 .80793 L p .45582 .81671 L F P
0 g
s
.436 .343 .652 r
.72917 .85617 m .73645 .85128 L p .73253 .86148 L F P
0 g
s
.436 .343 .652 r
.73253 .86148 m .72972 .85891 L .72917 .85617 L p F P
0 g
s
.447 .365 .671 r
.72917 .85617 m .73645 .85128 L .73086 .84714 L p F P
0 g
s
.74 .652 .763 r
.32932 .91932 m .32905 .91878 L .32851 .91923 L closepath p F P
0 g
s
.725 .591 .705 r
.36725 .87174 m .37082 .868 L .36949 .86399 L p F P
0 g
s
.678 .568 .725 r
.43381 .88382 m .4407 .87914 L p .44592 .88691 L F P
0 g
s
.679 .564 .718 r
.43381 .88382 m .4407 .87914 L .43251 .8798 L closepath p F P
0 g
s
.742 .6 .699 r
.36448 .84824 m .36475 .84914 L .3594 .85548 L p F P
0 g
s
.742 .6 .699 r
.35515 .84744 m .36448 .84824 L p .3594 .85548 L F P
0 g
s
.85 .432 .24 r
.26598 .72096 m .26382 .71988 L .26536 .71964 L closepath p F P
0 g
s
.68 .558 .71 r
.43078 .87446 m .43482 .87155 L .42999 .87191 L closepath p F P
0 g
s
.734 .59 .695 r
.36692 .85606 m .36475 .84914 L .3594 .85548 L closepath p F P
0 g
s
.679 .563 .717 r
.4407 .87914 m .43251 .8798 L .43078 .87446 L p F P
0 g
s
.54 .558 .822 r
.67906 .7456 m .67833 .74558 L .67885 .74516 L closepath p F P
0 g
s
.546 .568 .828 r
.67619 .73964 m .67885 .74516 L .67833 .74558 L p F P
0 g
s
.752 .681 .783 r
.29936 .93463 m .29242 .93996 L .28916 .93496 L p F P
0 g
s
.725 .591 .705 r
.36949 .86399 m .36346 .86358 L p .36725 .87174 L F P
0 g
s
.731 .593 .701 r
.36949 .86399 m .36778 .85876 L .36346 .86358 L closepath p F P
0 g
s
.679 .563 .717 r
.43078 .87446 m .43482 .87155 L p .4407 .87914 L F P
0 g
s
.723 .755 .878 r
.22401 .95763 m .22555 .95683 L .23187 .95873 L p F P
0 g
s
.708 .739 .876 r
.23493 .95198 m .22555 .95683 L .23187 .95873 L p F P
0 g
s
.708 .739 .876 r
.23187 .95873 m .23834 .95563 L .23493 .95198 L p F P
0 g
s
.893 .689 .619 r
.06817 .86927 m .07262 .87187 L .07093 .87776 L p F P
0 g
s
.889 .699 .64 r
.07262 .87187 m .06817 .86927 L .07024 .86328 L p F P
0 g
s
.829 .583 .568 r
.29619 .75322 m .28989 .75109 L .29069 .74555 L p F P
0 g
s
.839 .594 .568 r
.28624 .74389 m .29069 .74555 L .28989 .75109 L p F P
0 g
s
.731 .61 .722 r
.36265 .88794 m .36294 .88766 L .36253 .88763 L closepath p F P
0 g
s
.731 .609 .721 r
.35957 .87978 m .36009 .87923 L p .36294 .88766 L F P
0 g
s
.731 .609 .721 r
.36294 .88766 m .36253 .88763 L .35957 .87978 L p F P
0 g
s
.737 .623 .731 r
.36253 .88763 m .36265 .88794 L .35478 .89543 L p F P
0 g
s
.737 .647 .76 r
.32588 .91241 m .31943 .91806 L .32851 .91923 L p F P
0 g
s
.737 .647 .76 r
.32851 .91923 m .32905 .91878 L .32588 .91241 L p F P
0 g
s
.739 .602 .705 r
.36692 .85606 m .36778 .85876 L .36346 .86358 L p F P
0 g
s
.739 .602 .705 r
.3594 .85548 m .36692 .85606 L p .36346 .86358 L F P
0 g
s
.578 .629 .865 r
.6386 .71332 m .63277 .71394 L .63698 .71053 L closepath p F P
0 g
s
.582 .641 .875 r
.63573 .70843 m .63698 .71053 L .63277 .71394 L p F P
0 g
s
.582 .641 .875 r
.62422 .70991 m .63573 .70843 L p .63277 .71394 L F P
0 g
s
.67 .537 .694 r
.43681 .84816 m .44988 .84686 L p .4395 .85553 L F P
0 g
s
.67 .537 .694 r
.4395 .85553 m .43883 .85559 L .43681 .84816 L p F P
0 g
s
.675 .539 .692 r
.44801 .83957 m .44988 .84686 L .43681 .84816 L p F P
0 g
s
.675 .539 .692 r
.4419 .84014 m .44801 .83957 L p .43681 .84816 L F P
0 g
s
.744 .64 .745 r
.33765 .91119 m .32905 .91878 L .32588 .91241 L p F P
0 g
s
.737 .623 .731 r
.35256 .88683 m .36253 .88763 L p .35478 .89543 L F P
0 g
s
.734 .61 .72 r
.36253 .88763 m .35957 .87978 L .35256 .88683 L closepath p F P
0 g
s
.658 .517 .681 r
.4471 .83596 m .4533 .83146 L .44623 .83236 L closepath p F P
0 g
s
.67 .53 .685 r
.44623 .83236 m .4471 .83596 L .4419 .84014 L p F P
0 g
s
.47 .419 .719 r
.73222 .8271 m .7262 .82445 L .73055 .82134 L closepath p F P
0 g
s
.48 .434 .729 r
.72913 .81675 m .73055 .82134 L .7262 .82445 L p F P
0 g
s
.48 .434 .729 r
.72565 .81542 m .72913 .81675 L p .7262 .82445 L F P
0 g
s
.568 .618 .862 r
.6525 .71752 m .64148 .71837 L .6386 .71332 L p F P
0 g
s
.612 .817 .979 r
.60344 .96157 m .61485 .95864 L .61768 .96079 L p F P
0 g
s
.621 .779 .957 r
.61485 .95864 m .60344 .96157 L .60058 .95878 L p F P
0 g
s
.607 .829 .985 r
.6291 .95762 m .61768 .96079 L .61485 .95864 L p F P
0 g
s
.511 .513 .794 r
.70915 .77389 m .70238 .77288 L .70057 .76845 L p F P
0 g
s
.757 .587 .666 r
.33717 .8086 m .33193 .80779 L p .33681 .81565 L F P
0 g
s
.757 .587 .666 r
.33681 .81565 m .33835 .8131 L .33717 .8086 L p F P
0 g
s
.765 .781 .866 r
.16669 .71334 m .16267 .71605 L .15909 .71286 L p F P
0 g
s
.625 .702 .901 r
.59271 .70184 m .60412 .69911 L .607 .70306 L p F P
0 g
s
.635 .722 .91 r
.60412 .69911 m .59271 .70184 L .58982 .69846 L p F P
0 g
s
.746 .779 .88 r
.17363 .70872 m .18316 .70298 L .1871 .70594 L p F P
0 g
s
.746 .779 .88 r
.18454 .70216 m .18316 .70298 L .1871 .70594 L p F P
0 g
s
.746 .779 .88 r
.1871 .70594 m .18808 .70536 L .18454 .70216 L p F P
0 g
s
.66 .591 .766 r
.4862 .91713 m .48864 .923 L p .47441 .92059 L F P
0 g
s
.66 .591 .766 r
.47441 .92059 m .48041 .91795 L .4862 .91713 L p F P
0 g
s
.658 .583 .76 r
.47441 .92059 m .48041 .91795 L .47374 .91895 L closepath p F P
0 g
s
.737 .624 .733 r
.35143 .89862 m .35478 .89543 L .34992 .89497 L closepath p F P
0 g
s
.737 .623 .731 r
.34833 .89111 m .35256 .88683 L p .35478 .89543 L F P
0 g
s
.737 .623 .731 r
.35478 .89543 m .34992 .89497 L .34833 .89111 L p F P
0 g
s
.735 .606 .714 r
.35688 .87091 m .36725 .87174 L .36009 .87923 L p F P
0 g
s
.725 .591 .705 r
.36346 .86358 m .35688 .87091 L .36725 .87174 L p F P
0 g
s
.671 .53 .684 r
.44801 .83957 m .4471 .83596 L .4419 .84014 L closepath p F P
0 g
s
0 .45 .844 r
.23595 .70323 m .2411 .70477 L p .23765 .70273 L F P
0 g
s
0 .45 .844 r
.2411 .70477 m .24119 .70479 L .23765 .70273 L p F P
0 g
s
0 .398 .81 r
.23144 .70046 m .23765 .70273 L .23411 .7006 L p F P
0 g
s
.665 .125 0 r
.23765 .70273 m .23411 .7006 L p .23455 .7009 L F P
0 g
s
0 .45 .844 r
.23765 .70273 m .23144 .70046 L .23595 .70323 L p F P
0 g
s
.665 .125 0 r
.23842 .70353 m .23765 .70273 L p .23455 .7009 L F P
0 g
s
.619 .067 0 r
.24119 .70479 m .23765 .70273 L p .23776 .7028 L F P
0 g
s
.029 .507 .88 r
.2407 .70591 m .24468 .70681 L p .24119 .70479 L F P
0 g
s
.029 .507 .88 r
.24119 .70479 m .23595 .70323 L .2407 .70591 L p F P
0 g
s
.619 .067 0 r
.24283 .70632 m .24119 .70479 L p .23776 .7028 L F P
0 g
s
.029 .507 .88 r
.24468 .70681 m .24472 .70682 L .24119 .70479 L p F P
0 g
s
.391 .683 .977 r
.23079 .70279 m .23595 .70323 L .2407 .70591 L p F P
0 g
s
.744 .64 .745 r
.32588 .91241 m .32841 .91006 L .33765 .91119 L p F P
0 g
s
.736 .635 .747 r
.33694 .90219 m .32841 .91006 L .33765 .91119 L p F P
0 g
s
.736 .635 .747 r
.33717 .90221 m .33694 .90219 L p .33765 .91119 L F P
0 g
s
.736 .635 .747 r
.33765 .91119 m .34023 .90893 L .33717 .90221 L p F P
0 g
s
.352 .664 .973 r
.23595 .70323 m .23079 .70279 L .2273 .69995 L p F P
0 g
s
.742 .636 .742 r
.34992 .89497 m .35143 .89862 L .34637 .90327 L p F P
0 g
s
.742 .636 .742 r
.34485 .89448 m .34992 .89497 L p .34637 .90327 L F P
0 g
s
.742 .636 .742 r
.3371 .90204 m .34485 .89448 L p .34637 .90327 L F P
0 g
s
.742 .636 .742 r
.34637 .90327 m .33717 .90221 L .3371 .90204 L p F P
0 g
s
.742 .638 .744 r
.34023 .90893 m .34637 .90327 L .33717 .90221 L closepath p F P
0 g
s
.588 .646 .875 r
.63573 .70843 m .62422 .70991 L .62134 .70532 L p F P
0 g
s
.554 .592 .846 r
.65948 .72955 m .65879 .72824 L .66108 .72818 L closepath p F P
0 g
s
.816 .587 .591 r
.3016 .76092 m .29494 .75892 L .29619 .75322 L p F P
0 g
s
.829 .599 .589 r
.28989 .75109 m .29619 .75322 L .29494 .75892 L p F P
0 g
s
.645 .491 .659 r
.46684 .80793 m .46647 .80609 L .46332 .80846 L closepath p F P
0 g
s
.677 .582 .742 r
.4542 .90316 m .4541 .90289 L .45355 .90321 L closepath p F P
0 g
s
.676 .581 .742 r
.4512 .89484 m .4541 .90289 L .45355 .90321 L p F P
0 g
s
.676 .581 .742 r
.45029 .89491 m .4512 .89484 L p .45355 .90321 L F P
0 g
s
.533 .552 .82 r
.67906 .7456 m .6908 .74626 L p .68777 .75216 L F P
0 g
s
.53 .553 .823 r
.68791 .74008 m .6908 .74626 L .67906 .7456 L p F P
0 g
s
.53 .553 .823 r
.68491 .73992 m .68791 .74008 L p .67906 .7456 L F P
0 g
s
.53 .553 .823 r
.67906 .7456 m .67885 .74516 L .68491 .73992 L p F P
0 g
s
.642 .627 .819 r
.53748 .94372 m .52621 .94698 L .5232 .94129 L p F P
0 g
s
.716 .777 .901 r
.19891 .69994 m .18808 .70536 L .18454 .70216 L p F P
0 g
s
.864 .479 .313 r
.09921 .92526 m .09435 .92299 L .09823 .92252 L closepath p F P
0 g
s
.671 .58 .744 r
.46527 .89677 m .46707 .90171 L .4542 .90316 L p F P
0 g
s
.671 .58 .744 r
.4542 .90316 m .4541 .90289 L .46527 .89677 L p F P
0 g
s
.616 .916 .979 r
.56253 .70329 m .56425 .70386 L .57557 .69945 L p F P
0 g
s
.658 .583 .759 r
.48041 .91795 m .47374 .91895 L .47136 .91305 L p F P
0 g
s
.669 .572 .737 r
.4641 .89341 m .46527 .89677 L .4541 .90289 L p F P
0 g
s
.669 .572 .737 r
.4541 .90289 m .4512 .89484 L .4641 .89341 L p F P
0 g
s
.679 .563 .717 r
.43482 .87155 m .44335 .8709 L p .4407 .87914 L F P
0 g
s
.68 .557 .708 r
.44335 .8709 m .44195 .86633 L .43482 .87155 L closepath p F P
0 g
s
.68 .557 .709 r
.44103 .8632 m .44195 .86633 L .43482 .87155 L p F P
0 g
s
.588 .421 .623 r
.49704 .76993 m .49756 .77376 L .48616 .77678 L p F P
0 g
s
.592 .433 .634 r
.48714 .78318 m .48616 .77678 L .49756 .77376 L p F P
0 g
s
.878 .738 .704 r
.06982 .83944 m .07091 .83741 L .06727 .83366 L p F P
0 g
s
0 0 0 r
.68165 .94016 m .68281 .93851 L .68958 .93403 L p F P
0 g
s
.537 .565 .831 r
.67885 .74516 m .67619 .73964 L .68491 .73992 L closepath p F P
0 g
s
.772 .272 .016 r
.11195 .93468 m .11484 .9384 L .11255 .93779 L p F P
0 g
s
.772 .272 .016 r
.10688 .93236 m .11195 .93468 L p .11255 .93779 L F P
0 g
s
.476 .272 .523 r
.52208 .73507 m .51693 .73724 L .51697 .74263 L p F P
0 g
s
.444 .21 .463 r
.51693 .73724 m .52208 .73507 L .526 .72854 L p F P
0 g
s
.804 .588 .609 r
.30694 .76864 m .29991 .76676 L .3016 .76092 L p F P
0 g
s
.818 .6 .607 r
.29494 .75892 m .3016 .76092 L .29991 .76676 L p F P
0 g
s
.738 .604 .708 r
.35347 .86267 m .36346 .86358 L .35688 .87091 L p F P
0 g
s
.739 .602 .705 r
.35344 .86258 m .3594 .85548 L p .36346 .86358 L F P
0 g
s
.739 .602 .705 r
.36346 .86358 m .35347 .86267 L .35344 .86258 L p F P
0 g
s
.662 .525 .686 r
.44801 .83957 m .4471 .83596 L .4533 .83146 L p F P
0 g
s
.651 .601 .786 r
.49168 .92997 m .50288 .92575 L p .50043 .93451 L F P
0 g
s
.651 .593 .776 r
.50217 .92408 m .50288 .92575 L .49168 .92997 L p F P
0 g
s
.651 .593 .776 r
.49168 .92997 m .49002 .92618 L .50217 .92408 L p F P
0 g
s
.758 .589 .667 r
.33911 .81598 m .33835 .8131 L .33681 .81565 L closepath p F P
0 g
s
.338 .708 .984 r
.1665 .95832 m .16722 .95837 L .16359 .95624 L p F P
0 g
s
.338 .708 .984 r
.16359 .95624 m .16111 .95615 L .1665 .95832 L p F P
0 g
s
.752 .681 .783 r
.28916 .93496 m .29136 .93317 L .29936 .93463 L p F P
0 g
s
.741 .673 .784 r
.30031 .92597 m .29136 .93317 L .29936 .93463 L p F P
0 g
s
.741 .673 .784 r
.29936 .93463 m .30354 .93144 L .30031 .92597 L p F P
0 g
s
.437 .343 .651 r
.73051 .86281 m .72972 .85891 L .73253 .86148 L closepath p F P
0 g
s
.628 .475 .655 r
.47761 .7989 m .47766 .79913 L .46647 .80609 L p F P
0 g
s
.632 .482 .661 r
.46684 .80793 m .46647 .80609 L .47766 .79913 L p F P
0 g
s
.67 .54 .697 r
.43893 .85594 m .4395 .85553 L .43883 .85559 L closepath p F P
0 g
s
.287 .019 .321 r
.70528 .9194 m .70603 .91843 L .70538 .91877 L closepath p F P
0 g
s
.646 .607 .795 r
.51831 .93117 m .52018 .93517 L .50895 .93885 L p F P
0 g
s
.646 .607 .795 r
.50895 .93885 m .50639 .9335 L .51831 .93117 L p F P
0 g
s
.669 .544 .703 r
.43893 .85594 m .4395 .85553 L p .44754 .86252 L F P
0 g
s
.669 .544 .703 r
.44754 .86252 m .44103 .8632 L .43893 .85594 L p F P
0 g
s
.735 .607 .716 r
.35957 .87978 m .36009 .87923 L .35935 .87917 L closepath p F P
0 g
s
.735 .606 .714 r
.3565 .87133 m .35688 .87091 L p .36009 .87923 L F P
0 g
s
.735 .606 .714 r
.36009 .87923 m .35935 .87917 L .3565 .87133 L p F P
0 g
s
.653 .61 .793 r
.50639 .9335 m .50592 .9325 L .50043 .93451 L closepath p F P
0 g
s
.651 .601 .786 r
.50288 .92575 m .50592 .9325 L .50043 .93451 L p F P
0 g
s
.671 .539 .695 r
.45192 .85432 m .45011 .84771 L .4395 .85553 L closepath p F P
0 g
s
.67 .537 .694 r
.44988 .84686 m .45011 .84771 L .4395 .85553 L p F P
0 g
s
.669 .544 .703 r
.4395 .85553 m .45192 .85432 L p .44754 .86252 L F P
0 g
s
.794 .589 .624 r
.31173 .77627 m .30483 .77462 L .30694 .76864 L p F P
0 g
s
.807 .6 .622 r
.29991 .76676 m .30694 .76864 L .30483 .77462 L p F P
0 g
s
.741 .62 .724 r
.35935 .87917 m .35957 .87978 L .35256 .88683 L p F P
0 g
s
.747 .722 .829 r
.25845 .94959 m .25267 .95324 L .24931 .94931 L p F P
0 g
s
.73 .73 .85 r
.23834 .95563 m .24931 .94931 L .25267 .95324 L p F P
0 g
s
.765 .781 .866 r
.15909 .71286 m .16279 .71037 L .16669 .71334 L p F P
0 g
s
.763 .782 .868 r
.17007 .70553 m .16279 .71037 L .16669 .71334 L p F P
0 g
s
.763 .782 .868 r
.16669 .71334 m .17363 .70872 L .17007 .70553 L p F P
0 g
s
.611 .457 .648 r
.47646 .79232 m .4882 .78966 L p .47857 .79868 L F P
0 g
s
.611 .457 .648 r
.47857 .79868 m .47761 .7989 L .47646 .79232 L p F P
0 g
s
.612 .453 .642 r
.48714 .78318 m .4882 .78966 L .47646 .79232 L p F P
0 g
s
.848 .771 .776 r
.08914 .78442 m .08398 .79074 L .08028 .78755 L p F P
0 g
s
.848 .771 .776 r
.08028 .78755 m .0852 .78154 L .08914 .78442 L p F P
0 g
s
.845 .772 .781 r
.08914 .78442 m .0852 .78154 L .09115 .77445 L p F P
0 g
s
.742 .601 .701 r
.35344 .86258 m .3594 .85548 L .35076 .85461 L closepath p F P
0 g
s
.742 .6 .699 r
.35039 .85349 m .35515 .84744 L p .3594 .85548 L F P
0 g
s
.742 .6 .699 r
.3594 .85548 m .35076 .85461 L .35039 .85349 L p F P
0 g
s
.738 .623 .731 r
.34992 .89497 m .34833 .89111 L .34485 .89448 L closepath p F P
0 g
s
.741 .62 .724 r
.34991 .87835 m .35935 .87917 L p .35256 .88683 L F P
0 g
s
.737 .607 .713 r
.35935 .87917 m .3565 .87133 L .34991 .87835 L closepath p F P
0 g
s
.759 .592 .67 r
.34161 .82354 m .34118 .82348 L .33911 .81598 L p F P
0 g
s
.758 .592 .671 r
.33681 .81565 m .33911 .81598 L .34118 .82348 L p F P
0 g
s
.553 .595 .85 r
.66108 .72818 m .65879 .72824 L .65592 .72284 L p F P
0 g
s
.386 .231 .546 r
.73249 .88196 m .72413 .88706 L .72459 .8928 L p F P
0 g
s
.407 .269 .58 r
.72413 .88706 m .73249 .88196 L .73033 .87686 L p F P
0 g
s
.401 .242 .548 r
.72345 .89345 m .72459 .8928 L .72413 .88706 L p F P
0 g
s
.873 .747 .721 r
.06883 .82109 m .07295 .82386 L .0691 .83034 L p F P
0 g
s
.869 .75 .73 r
.07295 .82386 m .06883 .82109 L .07294 .81454 L p F P
0 g
s
.678 .568 .725 r
.4407 .87914 m .4458 .87873 L p .44592 .88691 L F P
0 g
s
.679 .563 .717 r
.4458 .87873 m .44498 .87619 L .4407 .87914 L closepath p F P
0 g
s
.679 .563 .717 r
.44335 .8709 m .44498 .87619 L .4407 .87914 L p F P
0 g
s
.635 .681 .876 r
.55773 .9558 m .56906 .95297 L p .56997 .95775 L F P
0 g
s
.634 .663 .861 r
.56906 .95297 m .55773 .9558 L .55476 .95115 L p F P
0 g
s
.677 .576 .733 r
.4512 .89484 m .45106 .89444 L .45029 .89491 L closepath p F P
0 g
s
.677 .575 .733 r
.44841 .8867 m .45106 .89444 L .45029 .89491 L p F P
0 g
s
.677 .575 .733 r
.44592 .88691 m .44841 .8867 L p .45029 .89491 L F P
0 g
s
.892 .703 .641 r
.06588 .86064 m .07024 .86328 L .06817 .86927 L p F P
0 g
s
.887 .712 .658 r
.07024 .86328 m .06588 .86064 L .0683 .85455 L p F P
0 g
s
.795 .597 .634 r
.31192 .77713 m .3122 .7764 L p .31714 .78424 L F P
0 g
s
.8 .601 .633 r
.31192 .77713 m .3122 .7764 L .31173 .77627 L closepath p F P
0 g
s
.753 .669 .768 r
.30984 .92623 m .30354 .93144 L .30031 .92597 L p F P
0 g
s
.658 .524 .689 r
.44801 .83957 m .46075 .83795 L p .45174 .84662 L F P
0 g
s
.658 .524 .689 r
.45174 .84662 m .44988 .84686 L .44801 .83957 L p F P
0 g
s
.662 .525 .686 r
.459 .83077 m .46075 .83795 L .44801 .83957 L p F P
0 g
s
.662 .525 .686 r
.4533 .83146 m .459 .83077 L p .44801 .83957 L F P
0 g
s
.672 .572 .735 r
.46223 .88799 m .4641 .89341 L .4512 .89484 L p F P
0 g
s
.672 .572 .735 r
.4512 .89484 m .45106 .89444 L .46223 .88799 L p F P
0 g
s
.746 .6 .694 r
.35039 .85349 m .35515 .84744 L .34819 .84667 L closepath p F P
0 g
s
.746 .598 .692 r
.34735 .84404 m .35074 .83945 L p .35515 .84744 L F P
0 g
s
.746 .598 .692 r
.35515 .84744 m .34819 .84667 L .34735 .84404 L p F P
0 g
s
.43 .759 .996 r
.1813 .95966 m .17772 .95721 L .16722 .95837 L p F P
0 g
s
.546 .765 .978 r
.17772 .95721 m .16722 .95837 L .16359 .95624 L p F P
0 g
s
.511 .513 .794 r
.70057 .76845 m .70312 .76633 L p .70915 .77389 L F P
0 g
s
.515 .524 .803 r
.70057 .76845 m .69947 .76588 L .70312 .76633 L closepath p F P
0 g
s
.789 .598 .643 r
.31481 .78982 m .31714 .78424 L p .32208 .79208 L F P
0 g
s
.794 .602 .641 r
.31481 .78982 m .31714 .78424 L .31326 .78329 L closepath p F P
0 g
s
.795 .597 .634 r
.31714 .78424 m .31326 .78329 L .31192 .77713 L p F P
0 g
s
.669 .565 .728 r
.46134 .8853 m .46223 .88799 L .45106 .89444 L p F P
0 g
s
.669 .565 .728 r
.45106 .89444 m .44841 .8867 L .46134 .8853 L p F P
0 g
s
.632 .487 .666 r
.46827 .8148 m .46684 .80793 L .47895 .80567 L p F P
0 g
s
.632 .482 .661 r
.47766 .79913 m .47895 .80567 L .46684 .80793 L p F P
0 g
s
.678 .569 .725 r
.44841 .8867 m .44802 .88555 L .44592 .88691 L closepath p F P
0 g
s
.678 .568 .725 r
.4458 .87873 m .44802 .88555 L .44592 .88691 L p F P
0 g
s
.669 .545 .705 r
.44195 .86633 m .44754 .86252 L .44103 .8632 L closepath p F P
0 g
s
.645 .503 .675 r
.45828 .82775 m .46681 .82219 L .45736 .82369 L closepath p F P
0 g
s
.658 .515 .678 r
.45736 .82369 m .45828 .82775 L .4533 .83146 L p F P
0 g
s
.863 .758 .745 r
.07741 .80789 m .07584 .81018 L .07215 .80683 L p F P
0 g
s
.863 .758 .745 r
.07215 .80683 m .07336 .80507 L .07741 .80789 L p F P
0 g
s
.858 .761 .755 r
.07741 .80789 m .07336 .80507 L .07829 .79828 L p F P
0 g
s
.781 .595 .648 r
.32701 .79993 m .31916 .79832 L .32208 .79208 L p F P
0 g
s
.787 .603 .652 r
.31496 .79046 m .32208 .79208 L .31916 .79832 L p F P
0 g
s
.789 .598 .643 r
.32208 .79208 m .31496 .79046 L .31481 .78982 L p F P
0 g
s
.789 .594 .638 r
.31173 .77627 m .30483 .77462 L p .30971 .78249 L F P
0 g
s
.789 .594 .638 r
.30971 .78249 m .31192 .77713 L .31173 .77627 L p F P
0 g
s
.86 .513 .394 r
.27255 .72831 m .26714 .72588 L .26598 .72096 L p F P
0 g
s
.874 .534 .404 r
.26382 .71988 m .26598 .72096 L .26714 .72588 L p F P
0 g
s
.75 .598 .688 r
.34735 .84404 m .35074 .83945 L .34574 .83884 L closepath p F P
0 g
s
.75 .596 .685 r
.34433 .83422 m .34621 .83148 L p .35074 .83945 L F P
0 g
s
.75 .596 .685 r
.35074 .83945 m .34574 .83884 L .34433 .83422 L p F P
0 g
s
.884 .733 .689 r
.06564 .83671 m .06982 .83944 L .06677 .84569 L p F P
0 g
s
.878 .738 .704 r
.06727 .83366 m .06564 .83671 L .06982 .83944 L p F P
0 g
s
.229 0 .271 r
.70603 .91843 m .71489 .91368 L p .70453 .92326 L F P
0 g
s
.229 0 .271 r
.70453 .92326 m .70528 .9194 L .70603 .91843 L p F P
0 g
s
.323 .084 .389 r
.70603 .91843 m .71489 .91368 L .71532 .9088 L p F P
0 g
s
.741 .621 .726 r
.34833 .89111 m .35256 .88683 L .34635 .88619 L closepath p F P
0 g
s
.741 .62 .724 r
.34523 .88337 m .34991 .87835 L p .35256 .88683 L F P
0 g
s
.741 .62 .724 r
.35256 .88683 m .34635 .88619 L .34523 .88337 L p F P
0 g
s
.782 .604 .659 r
.31916 .79832 m .32701 .79993 L .32371 .80629 L p F P
0 g
s
.762 .586 .659 r
.32701 .79993 m .32371 .80629 L .33193 .80779 L p F P
0 g
s
.397 .13 .387 r
.53371 .72091 m .53827 .71879 L p .5275 .72793 L F P
0 g
s
.397 .13 .387 r
.5275 .72793 m .52763 .72708 L .53371 .72091 L p F P
0 g
s
.254 0 .175 r
.53371 .72091 m .53827 .71879 L .53884 .71723 L closepath p F P
0 g
s
.669 .55 .711 r
.44195 .86633 m .44754 .86252 L p .4552 .86963 L F P
0 g
s
.669 .55 .711 r
.4552 .86963 m .44335 .8709 L .44195 .86633 L p F P
0 g
s
.757 .587 .666 r
.33193 .80779 m .32823 .81427 L .33681 .81565 L p F P
0 g
s
.776 .605 .667 r
.32371 .80629 m .33193 .80779 L .32823 .81427 L p F P
0 g
s
.754 .596 .681 r
.34433 .83422 m .34621 .83148 L .3434 .83111 L closepath p F P
0 g
s
.754 .594 .678 r
.34132 .82398 m .34161 .82354 L p .34621 .83148 L F P
0 g
s
.754 .594 .678 r
.34621 .83148 m .3434 .83111 L .34132 .82398 L p F P
0 g
s
.66 .517 .679 r
.459 .83077 m .45828 .82775 L .4533 .83146 L closepath p F P
0 g
s
.788 .593 .637 r
.31326 .78329 m .31192 .77713 L .30971 .78249 L closepath p F P
0 g
s
.758 .592 .671 r
.34118 .82348 m .3327 .82226 L .33681 .81565 L p F P
0 g
s
.771 .601 .669 r
.32823 .81427 m .33681 .81565 L .3327 .82226 L p F P
0 g
s
.658 .583 .759 r
.47136 .91305 m .481 .90863 L p .48041 .91795 L F P
0 g
s
.658 .575 .751 r
.47136 .91305 m .481 .90863 L .47027 .9102 L closepath p F P
0 g
s
.759 .595 .675 r
.34132 .82398 m .34161 .82354 L .34118 .82348 L closepath p F P
0 g
s
.753 .669 .768 r
.30031 .92597 m .30163 .92482 L .30984 .92623 L p F P
0 g
s
.742 .66 .769 r
.31099 .91672 m .30163 .92482 L .30984 .92623 L p F P
0 g
s
.742 .66 .769 r
.3118 .91684 m .31099 .91672 L p .30984 .92623 L F P
0 g
s
.742 .66 .769 r
.30984 .92623 m .3147 .92224 L .3118 .91684 L p F P
0 g
s
.279 0 .288 r
.69953 .92579 m .70453 .92326 L .70528 .9194 L closepath p F P
0 g
s
.738 .605 .71 r
.3565 .87133 m .35688 .87091 L .35634 .87086 L closepath p F P
0 g
s
.738 .604 .708 r
.35688 .87091 m .35634 .87086 L .35347 .86267 L p F P
0 g
s
.672 .566 .727 r
.45919 .87875 m .46134 .8853 L .44841 .8867 L p F P
0 g
s
.672 .566 .727 r
.44841 .8867 m .44802 .88555 L .45919 .87875 L p F P
0 g
s
.669 .551 .712 r
.44498 .87619 m .4552 .86963 L .44335 .8709 L closepath p F P
0 g
s
.744 .699 .808 r
.27662 .94114 m .27806 .94319 L p .26369 .94632 L F P
0 g
s
.753 .704 .806 r
.27806 .94319 m .27984 .94186 L .27662 .94114 L closepath p F P
0 g
s
.653 .593 .775 r
.49985 .91861 m .50217 .92408 L .49002 .92618 L p F P
0 g
s
.653 .593 .775 r
.49002 .92618 m .48864 .923 L .49985 .91861 L p F P
0 g
s
.745 .618 .718 r
.35634 .87086 m .3565 .87133 L .34991 .87835 L p F P
0 g
s
.613 .686 .895 r
.61846 .70087 m .607 .70306 L .60412 .69911 L p F P
0 g
s
.669 .558 .72 r
.45874 .87733 m .45919 .87875 L .44802 .88555 L p F P
0 g
s
.669 .558 .72 r
.44802 .88555 m .4458 .87873 L .45874 .87733 L p F P
0 g
s
.753 .592 .677 r
.34118 .82348 m .3327 .82226 L p .33709 .83027 L F P
0 g
s
.753 .592 .677 r
.33709 .83027 m .34132 .82398 L .34118 .82348 L p F P
0 g
s
.736 .619 .728 r
.34485 .89448 m .34833 .89111 L .34635 .88619 L p F P
0 g
s
.806 .783 .832 r
.1292 .73649 m .12584 .73943 L .1222 .7363 L p F P
0 g
s
.813 .782 .824 r
.12037 .74446 m .12584 .73943 L .1222 .7363 L p F P
0 g
s
.816 .782 .821 r
.12037 .74446 m .11462 .74984 L .11097 .74672 L p F P
0 g
s
.816 .782 .821 r
.11097 .74672 m .11655 .74149 L .12037 .74446 L p F P
0 g
s
.813 .782 .824 r
.1222 .7363 m .11655 .74149 L .12037 .74446 L p F P
0 g
s
.745 .618 .718 r
.34692 .86996 m .35634 .87086 L p .34991 .87835 L F P
0 g
s
.74 .605 .707 r
.35337 .86266 m .35347 .86267 L .35634 .87086 L p F P
0 g
s
.74 .605 .707 r
.35634 .87086 m .34692 .86996 L .35337 .86266 L p F P
0 g
s
.754 .594 .678 r
.3434 .83111 m .34132 .82398 L .33709 .83027 L closepath p F P
0 g
s
.635 .683 .877 r
.57201 .95724 m .56997 .95775 L .57199 .95722 L closepath p F P
0 g
s
.635 .681 .876 r
.56906 .95297 m .57199 .95722 L .56997 .95775 L p F P
0 g
s
.445 .365 .672 r
.73649 .84328 m .73086 .84714 L .73645 .85128 L p F P
0 g
s
.457 .384 .687 r
.7354 .83891 m .73649 .84328 L .73086 .84714 L p F P
0 g
s
.457 .384 .687 r
.73296 .8374 m .7354 .83891 L p .73086 .84714 L F P
0 g
s
.673 .559 .718 r
.45631 .86952 m .45874 .87733 L .4458 .87873 L p F P
0 g
s
.673 .559 .718 r
.4552 .86963 m .45631 .86952 L p .4458 .87873 L F P
0 g
s
.673 .559 .718 r
.4458 .87873 m .44498 .87619 L .4552 .86963 L p F P
0 g
s
0 0 0 r
.68958 .93403 m .69352 .93214 L p .68165 .94016 L F P
0 g
s
.192 0 .116 r
.68958 .93403 m .69352 .93214 L .69412 .93057 L closepath p F P
0 g
s
.821 .781 .815 r
.11218 .75223 m .11462 .74984 L .11097 .74672 L p F P
0 g
s
.806 .783 .832 r
.1222 .7363 m .1254 .73351 L .1292 .73649 L p F P
0 g
s
.803 .783 .835 r
.13337 .72667 m .1254 .73351 L .1292 .73649 L p F P
0 g
s
.803 .783 .835 r
.1292 .73649 m .13699 .72981 L .13337 .72667 L p F P
0 g
s
.745 .627 .728 r
.34485 .89448 m .3371 .90204 L .33397 .89492 L p F P
0 g
s
.745 .627 .728 r
.33397 .89492 m .33547 .89338 L .34485 .89448 L p F P
0 g
s
.736 .619 .728 r
.34283 .88583 m .33547 .89338 L .34485 .89448 L p F P
0 g
s
.736 .619 .728 r
.34635 .88619 m .34283 .88583 L p .34485 .89448 L F P
0 g
s
.753 .703 .804 r
.28752 .93239 m .28916 .93496 L .27984 .94186 L p F P
0 g
s
.753 .703 .804 r
.28352 .93167 m .28752 .93239 L p .27984 .94186 L F P
0 g
s
.753 .703 .804 r
.27477 .9385 m .28352 .93167 L p .27984 .94186 L F P
0 g
s
.753 .703 .804 r
.27984 .94186 m .27662 .94114 L .27477 .9385 L p F P
0 g
s
.454 .221 .47 r
.5275 .72793 m .526 .72854 L .52208 .73507 L p F P
0 g
s
.413 .143 .392 r
.526 .72854 m .5275 .72793 L .52763 .72708 L closepath p F P
0 g
s
.825 .78 .811 r
.10836 .74927 m .11218 .75223 L .10463 .7598 L p F P
0 g
s
.821 .781 .815 r
.11097 .74672 m .10836 .74927 L .11218 .75223 L p F P
0 g
s
.751 .663 .764 r
.3147 .92224 m .31943 .91806 L .3118 .91684 L closepath p F P
0 g
s
.476 .434 .731 r
.72913 .81675 m .72565 .81542 L .72816 .81358 L closepath p F P
0 g
s
.485 .448 .741 r
.7261 .80725 m .72816 .81358 L .72565 .81542 L p F P
0 g
s
.485 .448 .741 r
.72418 .80662 m .7261 .80725 L p .72565 .81542 L F P
0 g
s
.37 .836 .8 r
.666 .94805 m .65744 .9515 L .65477 .95156 L p F P
0 g
s
.425 .869 .876 r
.64331 .95542 m .65477 .95156 L .65744 .9515 L p F P
0 g
s
.423 .318 .63 r
.73253 .86148 m .73051 .86281 L .73165 .86924 L p F P
0 g
s
.893 .598 .479 r
.0872 .91016 m .08245 .90771 L .08227 .90231 L p F P
0 g
s
.897 .601 .477 r
.07758 .89982 m .08227 .90231 L .08245 .90771 L p F P
0 g
s
.895 .628 .525 r
.08227 .90231 m .07758 .89982 L .07794 .89429 L p F P
0 g
s
.658 .575 .75 r
.481 .90863 m .47027 .9102 L .46832 .90512 L p F P
0 g
s
.515 .524 .804 r
.70312 .76633 m .69947 .76588 L .69657 .75909 L p F P
0 g
s
.866 .757 .74 r
.07294 .81454 m .07584 .81018 L .07215 .80683 L p F P
0 g
s
.533 .355 .586 r
.50712 .75805 m .50662 .75217 L .51728 .74832 L p F P
0 g
s
.521 .33 .562 r
.51697 .74263 m .51728 .74832 L .50662 .75217 L p F P
0 g
s
.526 .542 .814 r
.69368 .75261 m .68777 .75216 L .69192 .74869 L closepath p F P
0 g
s
.528 .54 .812 r
.68777 .75216 m .69368 .75261 L p .69614 .75905 L F P
0 g
s
.533 .552 .82 r
.6908 .74626 m .69192 .74869 L .68777 .75216 L p F P
0 g
s
.752 .662 .762 r
.32447 .9095 m .32588 .91241 L .31943 .91806 L p F P
0 g
s
.752 .662 .762 r
.31952 .90884 m .32447 .9095 L p .31943 .91806 L F P
0 g
s
.752 .662 .762 r
.3115 .91628 m .31952 .90884 L p .31943 .91806 L F P
0 g
s
.752 .662 .762 r
.31943 .91806 m .3118 .91684 L .3115 .91628 L p F P
0 g
s
.889 .561 .422 r
.09277 .91783 m .08798 .91541 L .0872 .91016 L p F P
0 g
s
.892 .562 .417 r
.08245 .90771 m .0872 .91016 L .08798 .91541 L p F P
0 g
s
.735 .724 .841 r
.24931 .94931 m .23834 .95563 L .23493 .95198 L p F P
0 g
s
.006 .532 .853 r
.1379 .94963 m .14593 .9518 L .14225 .94979 L p F P
0 g
s
.297 0 0 r
.1321 .94745 m .13224 .9475 L .1379 .94963 L p F P
0 g
s
.741 .636 .743 r
.33717 .90221 m .3371 .90204 L .33694 .90219 L closepath p F P
0 g
s
.749 .593 .684 r
.3434 .83111 m .33709 .83027 L p .34139 .8383 L F P
0 g
s
.749 .593 .684 r
.34139 .8383 m .34433 .83422 L .3434 .83111 L p F P
0 g
s
.649 .51 .681 r
.459 .83077 m .45828 .82775 L .46681 .82219 L p F P
0 g
s
.739 .631 .74 r
.33694 .90219 m .3371 .90204 L .33397 .89492 L p F P
0 g
s
.747 .722 .829 r
.24931 .94931 m .25144 .94787 L .25845 .94959 L p F P
0 g
s
.734 .712 .83 r
.26036 .94196 m .25144 .94787 L .25845 .94959 L p F P
0 g
s
.734 .712 .83 r
.25845 .94959 m .26369 .94632 L .26036 .94196 L p F P
0 g
s
.749 .648 .749 r
.32765 .90107 m .33694 .90219 L .32841 .91006 L p F P
0 g
s
.739 .631 .74 r
.33397 .89492 m .32765 .90107 L .33694 .90219 L p F P
0 g
s
.899 .631 .524 r
.07332 .89177 m .07794 .89429 L .07758 .89982 L p F P
0 g
s
.895 .652 .563 r
.07794 .89429 m .07332 .89177 L .07417 .8861 L p F P
0 g
s
.794 .784 .843 r
.13891 .72826 m .13699 .72981 L .13337 .72667 L p F P
0 g
s
.74 .603 .705 r
.35347 .86267 m .35344 .86258 L .35337 .86266 L closepath p F P
0 g
s
.658 .526 .692 r
.45011 .84771 m .45174 .84662 L .44988 .84686 L closepath p F P
0 g
s
.738 .599 .703 r
.35337 .86266 m .35344 .86258 L .35076 .85461 L p F P
0 g
s
.749 .616 .711 r
.34363 .86164 m .35337 .86266 L .34692 .86996 L p F P
0 g
s
.738 .599 .703 r
.34957 .85449 m .34363 .86164 L .35337 .86266 L p F P
0 g
s
.738 .599 .703 r
.35076 .85461 m .34957 .85449 L p .35337 .86266 L F P
0 g
s
.749 .649 .75 r
.32588 .91241 m .32841 .91006 L .32447 .9095 L closepath p F P
0 g
s
.749 .648 .749 r
.32272 .90589 m .32765 .90107 L p .32841 .91006 L F P
0 g
s
.749 .648 .749 r
.32841 .91006 m .32447 .9095 L .32272 .90589 L p F P
0 g
s
.251 0 .174 r
.53827 .71879 m .53884 .71723 L .54623 .71186 L p F P
0 g
s
.133 0 .091 r
.69352 .93214 m .69412 .93057 L .69953 .92579 L p F P
0 g
s
.66 .588 .763 r
.4862 .91713 m .48559 .91566 L .48041 .91795 L closepath p F P
0 g
s
.658 .583 .759 r
.48274 .90838 m .48559 .91566 L .48041 .91795 L p F P
0 g
s
.658 .583 .759 r
.481 .90863 m .48274 .90838 L p .48041 .91795 L F P
0 g
s
.851 .77 .771 r
.08342 .79143 m .08398 .79074 L .08028 .78755 L p F P
0 g
s
.638 .649 .845 r
.55178 .94613 m .55215 .94676 L .54072 .94955 L p F P
0 g
s
.638 .649 .845 r
.54072 .94955 m .54048 .94914 L .55178 .94613 L p F P
0 g
s
.849 .55 .482 r
.27872 .73578 m .27292 .73348 L .27255 .72831 L p F P
0 g
s
.863 .564 .48 r
.26714 .72588 m .27255 .72831 L .27292 .73348 L p F P
0 g
s
.751 .596 .685 r
.34574 .83884 m .34433 .83422 L .34139 .8383 L closepath p F P
0 g
s
.658 .531 .698 r
.45011 .84771 m .45174 .84662 L p .46219 .85296 L F P
0 g
s
.658 .531 .698 r
.46219 .85296 m .45192 .85432 L .45011 .84771 L p F P
0 g
s
.794 .784 .843 r
.13337 .72667 m .13511 .72526 L .13891 .72826 L p F P
0 g
s
.792 .784 .845 r
.14446 .71781 m .13511 .72526 L .13891 .72826 L p F P
0 g
s
.792 .784 .845 r
.13891 .72826 m .14807 .72096 L .14446 .71781 L p F P
0 g
s
.133 0 .091 r
.69953 .92579 m .70453 .92326 L p .69352 .93214 L F P
0 g
s
.746 .781 .881 r
.18316 .70298 m .17363 .70872 L .17007 .70553 L p F P
0 g
s
.857 .767 .762 r
.07949 .78856 m .08342 .79143 L .07829 .79828 L p F P
0 g
s
.851 .77 .771 r
.08028 .78755 m .07949 .78856 L .08342 .79143 L p F P
0 g
s
.744 .619 .72 r
.34523 .88337 m .34991 .87835 L .34297 .87757 L closepath p F P
0 g
s
.745 .618 .718 r
.34214 .87539 m .34692 .86996 L p .34991 .87835 L F P
0 g
s
.745 .618 .718 r
.34991 .87835 m .34297 .87757 L .34214 .87539 L p F P
0 g
s
.745 .595 .69 r
.34574 .83884 m .34139 .8383 L p .34556 .84637 L F P
0 g
s
.745 .595 .69 r
.34556 .84637 m .34735 .84404 L .34574 .83884 L p F P
0 g
s
.669 .55 .711 r
.44754 .86252 m .45406 .86186 L p .4552 .86963 L F P
0 g
s
.67 .545 .703 r
.45406 .86186 m .45313 .85865 L .44754 .86252 L closepath p F P
0 g
s
.669 .544 .703 r
.45192 .85432 m .45313 .85865 L .44754 .86252 L p F P
0 g
s
.878 .512 .348 r
.09435 .92299 m .0942 .92291 L .09277 .91783 L p F P
0 g
s
.881 .512 .34 r
.08798 .91541 m .09277 .91783 L .0942 .92291 L p F P
0 g
s
.829 .78 .805 r
.10463 .7598 m .10331 .76116 L .09964 .75805 L p F P
0 g
s
.829 .78 .805 r
.09964 .75805 m .1008 .75685 L .10463 .7598 L p F P
0 g
s
.825 .78 .811 r
.10463 .7598 m .1008 .75685 L .10836 .74927 L p F P
0 g
s
.744 .6 .698 r
.35076 .85461 m .35039 .85349 L .34957 .85449 L closepath p F P
0 g
s
.652 .584 .766 r
.49841 .91506 m .49985 .91861 L .48864 .923 L p F P
0 g
s
.652 .584 .766 r
.48864 .923 m .4862 .91713 L .49841 .91506 L p F P
0 g
s
.548 .584 .842 r
.67044 .72807 m .66108 .72818 L .6676 .72251 L closepath p F P
0 g
s
.553 .595 .85 r
.66756 .72244 m .6676 .72251 L .66108 .72818 L p F P
0 g
s
.553 .595 .85 r
.65592 .72284 m .66756 .72244 L p .66108 .72818 L F P
0 g
s
.741 .597 .696 r
.34957 .85449 m .35039 .85349 L .34819 .84667 L p F P
0 g
s
.741 .62 .724 r
.34635 .88619 m .34523 .88337 L .34283 .88583 L closepath p F P
0 g
s
.747 .598 .691 r
.34819 .84667 m .34735 .84404 L .34556 .84637 L closepath p F P
0 g
s
.636 .631 .829 r
.55178 .94613 m .54048 .94914 L .53748 .94372 L p F P
0 g
s
.741 .597 .696 r
.34819 .84667 m .34556 .84637 L p .34957 .85449 L F P
0 g
s
.885 .723 .675 r
.0683 .85455 m .06402 .85187 L .06677 .84569 L p F P
0 g
s
.89 .716 .659 r
.06402 .85187 m .0683 .85455 L .06588 .86064 L p F P
0 g
s
.834 .779 .799 r
.09774 .76717 m .10331 .76116 L .09964 .75805 L p F P
0 g
s
.658 .531 .698 r
.45174 .84662 m .46264 .84526 L p .46219 .85296 L F P
0 g
s
.66 .527 .691 r
.46264 .84526 m .46129 .84011 L .45174 .84662 L closepath p F P
0 g
s
.658 .524 .689 r
.46075 .83795 m .46129 .84011 L .45174 .84662 L p F P
0 g
s
.839 .594 .568 r
.28989 .75109 m .28663 .74989 L .28624 .74389 L p F P
0 g
s
.825 .583 .573 r
.28459 .74335 m .28624 .74389 L .28663 .74989 L p F P
0 g
s
.631 .708 .902 r
.57201 .95724 m .58337 .9545 L .58629 .95826 L p F P
0 g
s
.632 .681 .878 r
.58307 .95406 m .58337 .9545 L .57201 .95724 L p F P
0 g
s
.632 .681 .878 r
.57201 .95724 m .57199 .95722 L .58307 .95406 L p F P
0 g
s
.899 .656 .562 r
.06963 .88354 m .07417 .8861 L .07332 .89177 L p F P
0 g
s
.895 .672 .593 r
.07417 .8861 m .06963 .88354 L .07093 .87776 L p F P
0 g
s
.753 .614 .705 r
.3401 .85339 m .34957 .85449 L .34363 .86164 L p F P
0 g
s
.741 .597 .696 r
.34556 .84637 m .3401 .85339 L .34957 .85449 L p F P
0 g
s
.63 .68 .879 r
.58044 .95027 m .58307 .95406 L .57199 .95722 L p F P
0 g
s
.63 .68 .879 r
.57199 .95722 m .56906 .95297 L .58044 .95027 L p F P
0 g
s
.658 .568 .742 r
.46832 .90512 m .47903 .89997 L .46707 .90171 L closepath p F P
0 g
s
.658 .575 .75 r
.46832 .90512 m .47903 .89997 L p .481 .90863 L F P
0 g
s
.613 .771 .956 r
.1813 .95966 m .19195 .95705 L .19548 .9598 L p F P
0 g
s
.633 .77 .946 r
.19195 .95705 m .1813 .95966 L .17772 .95721 L p F P
0 g
s
.647 .607 .794 r
.51716 .9287 m .51831 .93117 L .50639 .9335 L p F P
0 g
s
.647 .607 .794 r
.50639 .9335 m .50592 .9325 L .51716 .9287 L p F P
0 g
s
.645 .51 .684 r
.459 .83077 m .47143 .82883 L p .4664 .83704 L F P
0 g
s
.645 .51 .684 r
.4664 .83704 m .46075 .83795 L .459 .83077 L p F P
0 g
s
.649 .51 .681 r
.46977 .82174 m .47143 .82883 L .459 .83077 L p F P
0 g
s
.649 .51 .681 r
.46681 .82219 m .46977 .82174 L p .459 .83077 L F P
0 g
s
.568 .403 .618 r
.49704 .76993 m .49673 .76752 L .50778 .76411 L p F P
0 g
s
.562 .389 .604 r
.50712 .75805 m .50778 .76411 L .49673 .76752 L p F P
0 g
s
.514 0 0 r
.13182 .94734 m .12707 .94523 L .12103 .94137 L p F P
0 g
s
.478 0 0 r
.11571 .93914 m .12103 .94137 L .12707 .94523 L p F P
0 g
s
.699 .164 0 r
.11484 .9384 m .11571 .93914 L .12103 .94137 L p F P
0 g
s
.783 .595 .646 r
.31326 .78329 m .30971 .78249 L p .31456 .79037 L F P
0 g
s
.783 .595 .646 r
.31456 .79037 m .31481 .78982 L .31326 .78329 L p F P
0 g
s
.421 .194 .462 r
.52722 .73297 m .5275 .72793 L .53748 .72328 L p F P
0 g
s
.397 .13 .387 r
.53827 .71879 m .53748 .72328 L .5275 .72793 L p F P
0 g
s
.454 .221 .47 r
.52208 .73507 m .52722 .73297 L .5275 .72793 L p F P
0 g
s
.724 .76 .881 r
.22401 .95763 m .22555 .95683 L .22197 .95565 L closepath p F P
0 g
s
.698 .753 .894 r
.22197 .95565 m .22401 .95763 L p .20972 .95906 L F P
0 g
s
.835 .569 .536 r
.28459 .74335 m .27842 .74117 L .27872 .73578 L p F P
0 g
s
.849 .582 .534 r
.27292 .73348 m .27872 .73578 L .27842 .74117 L p F P
0 g
s
.739 .617 .722 r
.34283 .88583 m .34523 .88337 L .34297 .87757 L p F P
0 g
s
.658 .532 .699 r
.45313 .85865 m .46219 .85296 L .45192 .85432 L closepath p F P
0 g
s
.631 .488 .669 r
.46947 .8204 m .46827 .8148 L .48034 .81249 L p F P
0 g
s
.632 .487 .666 r
.47895 .80567 m .48034 .81249 L .46827 .8148 L p F P
0 g
s
.644 .5 .672 r
.46827 .8148 m .46947 .8204 L .46681 .82219 L p F P
0 g
s
.594 .439 .641 r
.4882 .78966 m .48714 .78318 L .49854 .78016 L p F P
0 g
s
.592 .433 .634 r
.49756 .77376 m .49854 .78016 L .48714 .78318 L p F P
0 g
s
.658 .567 .742 r
.47903 .89997 m .46707 .90171 L .46527 .89677 L p F P
0 g
s
.757 .612 .698 r
.33639 .84518 m .34556 .84637 L .3401 .85339 L p F P
0 g
s
.745 .595 .69 r
.34139 .8383 m .33639 .84518 L .34556 .84637 L p F P
0 g
s
.536 .565 .831 r
.68491 .73992 m .67619 .73964 L .67354 .73419 L p F P
0 g
s
.645 .593 .782 r
.51716 .9287 m .50592 .9325 L .50288 .92575 L p F P
0 g
s
.874 .534 .404 r
.26164 .72154 m .26382 .71988 L p .26714 .72588 L F P
0 g
s
.845 .471 .343 r
.26164 .72154 m .26059 .71851 L .26382 .71988 L closepath p F P
0 g
s
.756 .689 .788 r
.28916 .93496 m .29136 .93317 L .28752 .93239 L closepath p F P
0 g
s
.642 .627 .819 r
.53479 .93856 m .53748 .94372 L p .5232 .94129 L F P
0 g
s
.642 .627 .819 r
.5232 .94129 m .52572 .94055 L .53479 .93856 L p F P
0 g
s
.639 .61 .805 r
.5232 .94129 m .52572 .94055 L .52312 .94113 L closepath p F P
0 g
s
.613 .464 .655 r
.47766 .79913 m .47857 .79868 L .47761 .7989 L closepath p F P
0 g
s
.75 .632 .73 r
.33354 .88469 m .34283 .88583 L .33547 .89338 L p F P
0 g
s
.739 .617 .722 r
.3404 .87728 m .33354 .88469 L .34283 .88583 L p F P
0 g
s
.739 .617 .722 r
.34297 .87757 m .3404 .87728 L p .34283 .88583 L F P
0 g
s
.744 .699 .808 r
.26369 .94632 m .27218 .94031 L .27662 .94114 L p F P
0 g
s
.743 .7 .81 r
.27662 .94114 m .27477 .9385 L .27218 .94031 L closepath p F P
0 g
s
.639 .61 .804 r
.52572 .94055 m .52312 .94113 L .52018 .93517 L p F P
0 g
s
.617 .471 .661 r
.47895 .80567 m .47766 .79913 L .47857 .79868 L p F P
0 g
s
.747 .647 .75 r
.32447 .9095 m .32272 .90589 L .31952 .90884 L closepath p F P
0 g
s
.781 .784 .855 r
.14986 .71963 m .14807 .72096 L .14446 .71781 L p F P
0 g
s
.748 .617 .713 r
.34214 .87539 m .34692 .86996 L .33976 .86908 L closepath p F P
0 g
s
.749 .616 .711 r
.33905 .86717 m .34363 .86164 L p .34692 .86996 L F P
0 g
s
.749 .616 .711 r
.34692 .86996 m .33976 .86908 L .33905 .86717 L p F P
0 g
s
.251 0 .174 r
.54623 .71186 m .54953 .71013 L p .53827 .71879 L F P
0 g
s
0 0 0 r
.54623 .71186 m .54953 .71013 L .55008 .70959 L closepath p F P
0 g
s
.756 .688 .786 r
.29941 .92441 m .30031 .92597 L .29136 .93317 L p F P
0 g
s
.756 .688 .786 r
.29346 .9234 m .29941 .92441 L p .29136 .93317 L F P
0 g
s
.756 .688 .786 r
.28591 .92983 m .29346 .9234 L p .29136 .93317 L F P
0 g
s
.756 .688 .786 r
.29136 .93317 m .28752 .93239 L .28591 .92983 L p F P
0 g
s
.834 .395 .19 r
.10688 .93236 m .10186 .93002 L .09921 .92526 L p F P
0 g
s
.832 .388 .175 r
.09435 .92299 m .09921 .92526 L .10186 .93002 L p F P
0 g
s
.837 .778 .795 r
.09774 .76717 m .09188 .77362 L .08819 .77052 L p F P
0 g
s
.837 .778 .795 r
.08819 .77052 m .0939 .76423 L .09774 .76717 L p F P
0 g
s
.834 .779 .799 r
.09964 .75805 m .0939 .76423 L .09774 .76717 L p F P
0 g
s
.761 .611 .692 r
.33252 .83702 m .34139 .8383 L .33639 .84518 L p F P
0 g
s
.749 .593 .684 r
.33709 .83027 m .33252 .83702 L .34139 .8383 L p F P
0 g
s
.752 .702 .804 r
.27218 .94031 m .26369 .94632 L .26036 .94196 L p F P
0 g
s
.667 .765 .924 r
.19548 .9598 m .20624 .95601 L .20972 .95906 L p F P
0 g
s
.68 .764 .914 r
.20624 .95601 m .19548 .9598 L .19195 .95705 L p F P
0 g
s
.662 .54 .705 r
.45406 .86186 m .45313 .85865 L .46219 .85296 L p F P
0 g
s
.698 .753 .894 r
.20972 .95906 m .21894 .955 L .22197 .95565 L p F P
0 g
s
.71 .754 .887 r
.21894 .955 m .20972 .95906 L .20624 .95601 L p F P
0 g
s
.726 .759 .879 r
.23152 .94825 m .23493 .95198 L .22555 .95683 L p F P
0 g
s
.726 .759 .879 r
.22057 .95428 m .23152 .94825 L p .22555 .95683 L F P
0 g
s
.726 .759 .879 r
.22555 .95683 m .22197 .95565 L .22057 .95428 L p F P
0 g
s
.871 .754 .731 r
.06891 .81172 m .07294 .81454 L .06883 .82109 L p F P
0 g
s
.866 .757 .74 r
.07215 .80683 m .06891 .81172 L .07294 .81454 L p F P
0 g
s
.878 .743 .709 r
.0691 .83034 m .06727 .83366 L .0636 .83005 L p F P
0 g
s
.878 .743 .709 r
.0636 .83005 m .06496 .82758 L .0691 .83034 L p F P
0 g
s
.873 .747 .721 r
.0691 .83034 m .06496 .82758 L .06883 .82109 L p F P
0 g
s
.482 .448 .743 r
.7261 .80725 m .72418 .80662 L .72555 .80559 L closepath p F P
0 g
s
.49 .463 .755 r
.7231 .79844 m .7218 .79807 L p .72418 .80662 L F P
0 g
s
.49 .463 .755 r
.72418 .80662 m .72555 .80559 L .7231 .79844 L p F P
0 g
s
.893 .689 .619 r
.07093 .87776 m .06646 .87516 L .06817 .86927 L p F P
0 g
s
.898 .676 .593 r
.06646 .87516 m .07093 .87776 L .06963 .88354 L p F P
0 g
s
.568 .618 .862 r
.6386 .71332 m .65018 .71238 L p .6525 .71752 L F P
0 g
s
.57 .625 .867 r
.64731 .70735 m .65018 .71238 L .6386 .71332 L p F P
0 g
s
.57 .625 .867 r
.6398 .70801 m .64731 .70735 L p .6386 .71332 L F P
0 g
s
.57 .625 .867 r
.6386 .71332 m .63698 .71053 L .6398 .70801 L p F P
0 g
s
.611 .457 .648 r
.4882 .78966 m .48886 .79343 L .47857 .79868 L p F P
0 g
s
.617 .471 .661 r
.47857 .79868 m .48938 .79628 L p .47895 .80567 L F P
0 g
s
.615 .463 .653 r
.48938 .79628 m .48886 .79343 L .47857 .79868 L closepath p F P
0 g
s
.835 .591 .57 r
.27842 .74117 m .28459 .74335 L .2837 .74893 L p F P
0 g
s
.825 .583 .573 r
.28663 .74989 m .2837 .74893 L .28459 .74335 L p F P
0 g
s
.658 .567 .742 r
.46527 .89677 m .47504 .89185 L p .47903 .89997 L F P
0 g
s
.658 .561 .734 r
.46527 .89677 m .47504 .89185 L .4641 .89341 L closepath p F P
0 g
s
.781 .784 .855 r
.14446 .71781 m .14606 .71662 L .14986 .71963 L p F P
0 g
s
.779 .784 .857 r
.1555 .70971 m .14606 .71662 L .14986 .71963 L p F P
0 g
s
.779 .784 .857 r
.14986 .71963 m .15909 .71286 L .1555 .70971 L p F P
0 g
s
.469 0 0 r
.24472 .70682 m .24744 .70905 L .25226 .7117 L p F P
0 g
s
.799 .328 .107 r
.26059 .71851 m .25527 .71603 L .25226 .7117 L p F P
0 g
s
.816 .35 .111 r
.24744 .70905 m .25226 .7117 L .25527 .71603 L p F P
0 g
s
.766 .61 .685 r
.32853 .82889 m .33709 .83027 L .33252 .83702 L p F P
0 g
s
.753 .592 .677 r
.3327 .82226 m .32853 .82889 L .33709 .83027 L p F P
0 g
s
.659 .539 .707 r
.45615 .86901 m .45406 .86186 L .46673 .86019 L p F P
0 g
s
.662 .54 .705 r
.46461 .85265 m .46673 .86019 L .45406 .86186 L p F P
0 g
s
.662 .54 .705 r
.46219 .85296 m .46461 .85265 L p .45406 .86186 L F P
0 g
s
.669 .55 .711 r
.45406 .86186 m .45615 .86901 L .4552 .86963 L p F P
0 g
s
.375 .196 .506 r
.72459 .8928 m .72345 .89345 L .72318 .89921 L p F P
0 g
s
.522 .53 .805 r
.69657 .75909 m .69614 .75905 L .69644 .7588 L closepath p F P
0 g
s
.528 .54 .812 r
.69368 .75261 m .69644 .7588 L .69614 .75905 L p F P
0 g
s
.653 .585 .765 r
.49681 .91108 m .49841 .91506 L .4862 .91713 L p F P
0 g
s
.653 .585 .765 r
.4862 .91713 m .48559 .91566 L .49681 .91108 L p F P
0 g
s
.658 .56 .733 r
.47504 .89185 m .4641 .89341 L .46223 .88799 L p F P
0 g
s
.771 .609 .679 r
.32445 .82078 m .3327 .82226 L .32853 .82889 L p F P
0 g
s
.771 .601 .669 r
.3327 .82226 m .32445 .82078 L .32823 .81427 L p F P
0 g
s
.829 .599 .589 r
.29494 .75892 m .2887 .75678 L .28989 .75109 L p F P
0 g
s
.837 .607 .59 r
.28663 .74989 m .28989 .75109 L .2887 .75678 L p F P
0 g
s
.749 .634 .732 r
.33397 .89492 m .33547 .89338 L .33317 .89308 L closepath p F P
0 g
s
.75 .632 .73 r
.33084 .88761 m .33354 .88469 L p .33547 .89338 L F P
0 g
s
.75 .632 .73 r
.33547 .89338 m .33317 .89308 L .33084 .88761 L p F P
0 g
s
.745 .618 .718 r
.34297 .87757 m .34214 .87539 L .3404 .87728 L closepath p F P
0 g
s
.569 .408 .623 r
.49756 .77376 m .49704 .76993 L .50828 .76796 L p F P
0 g
s
.568 .403 .618 r
.50778 .76411 m .50828 .76796 L .49704 .76993 L p F P
0 g
s
.67 .551 .712 r
.45631 .86952 m .45615 .86901 L .4552 .86963 L closepath p F P
0 g
s
.647 .503 .673 r
.46977 .82174 m .46947 .8204 L .46681 .82219 L closepath p F P
0 g
s
.776 .608 .672 r
.32104 .81285 m .32823 .81427 L .32445 .82078 L p F P
0 g
s
.776 .605 .667 r
.32075 .81183 m .32371 .80629 L p .32823 .81427 L F P
0 g
s
.776 .605 .667 r
.32823 .81427 m .32104 .81285 L .32075 .81183 L p F P
0 g
s
.753 .646 .742 r
.33317 .89308 m .33397 .89492 L .32765 .90107 L p F P
0 g
s
.818 .6 .607 r
.29991 .76676 m .29335 .76472 L .29494 .75892 L p F P
0 g
s
.828 .611 .608 r
.2887 .75678 m .29494 .75892 L .29335 .76472 L p F P
0 g
s
.783 .595 .646 r
.31496 .79046 m .31481 .78982 L .31456 .79037 L closepath p F P
0 g
s
.555 0 0 r
.24744 .70905 m .24472 .70682 L .24119 .70479 L p F P
0 g
s
.646 .513 .687 r
.46129 .84011 m .4664 .83704 L .46075 .83795 L closepath p F P
0 g
s
.627 .739 .927 r
.58629 .95826 m .59769 .95552 L .60058 .95878 L p F P
0 g
s
.628 .712 .907 r
.59769 .95552 m .58629 .95826 L .58337 .9545 L p F P
0 g
s
.564 .756 .968 r
.21317 .69897 m .2238 .6971 L .2273 .69995 L p F P
0 g
s
.552 .75 .969 r
.2238 .6971 m .21317 .69897 L .20966 .69588 L p F P
0 g
s
.671 .773 .926 r
.19891 .69994 m .20966 .69588 L .21317 .69897 L p F P
0 g
s
.752 .615 .707 r
.33905 .86717 m .34363 .86164 L .3367 .86072 L closepath p F P
0 g
s
.753 .614 .705 r
.33597 .85869 m .3401 .85339 L p .34363 .86164 L F P
0 g
s
.753 .614 .705 r
.34363 .86164 m .3367 .86072 L .33597 .85869 L p F P
0 g
s
.588 .646 .875 r
.62134 .70532 m .63285 .70373 L .63573 .70843 L p F P
0 g
s
.59 .659 .886 r
.62998 .69914 m .63285 .70373 L .62134 .70532 L p F P
0 g
s
.59 .659 .886 r
.61952 .70071 m .62998 .69914 L p .62134 .70532 L F P
0 g
s
.59 .659 .886 r
.62134 .70532 m .61878 .70136 L .61952 .70071 L p F P
0 g
s
.781 .607 .664 r
.32075 .81183 m .32371 .80629 L .31888 .80527 L closepath p F P
0 g
s
.782 .604 .659 r
.31776 .80116 m .31916 .79832 L p .32371 .80629 L F P
0 g
s
.782 .604 .659 r
.32371 .80629 m .31888 .80527 L .31776 .80116 L p F P
0 g
s
.807 .6 .622 r
.30483 .77462 m .29794 .77269 L .29991 .76676 L p F P
0 g
s
.82 .611 .62 r
.29335 .76472 m .29991 .76676 L .29794 .77269 L p F P
0 g
s
.515 .524 .804 r
.69657 .75909 m .70841 .76058 L p .70312 .76633 L F P
0 g
s
.511 .524 .806 r
.70551 .75387 m .70841 .76058 L .69657 .75909 L p F P
0 g
s
.511 .524 .806 r
.70251 .75349 m .70551 .75387 L p .69657 .75909 L F P
0 g
s
.511 .524 .806 r
.69657 .75909 m .69644 .7588 L .70251 .75349 L p F P
0 g
s
.662 .547 .713 r
.45631 .86952 m .45615 .86901 L .46734 .86233 L p F P
0 g
s
.659 .539 .707 r
.46673 .86019 m .46734 .86233 L .45615 .86901 L p F P
0 g
s
.652 .576 .757 r
.49499 .90634 m .49681 .91108 L .48559 .91566 L p F P
0 g
s
.652 .576 .757 r
.48559 .91566 m .48274 .90838 L .49499 .90634 L p F P
0 g
s
.658 .56 .733 r
.46223 .88799 m .46948 .88415 L p .47504 .89185 L F P
0 g
s
.658 .554 .725 r
.46223 .88799 m .46948 .88415 L .46134 .8853 L closepath p F P
0 g
s
.658 .546 .716 r
.45631 .86952 m .469 .86785 L p .46272 .87679 L F P
0 g
s
.658 .546 .716 r
.46272 .87679 m .45874 .87733 L .45631 .86952 L p F P
0 g
s
.662 .547 .713 r
.46734 .86233 m .469 .86785 L .45631 .86952 L p F P
0 g
s
.787 .603 .652 r
.31916 .79832 m .31685 .7978 L .31496 .79046 L p F P
0 g
s
.782 .6 .654 r
.31456 .79037 m .31496 .79046 L .31685 .7978 L p F P
0 g
s
.756 .675 .772 r
.30031 .92597 m .30163 .92482 L .29941 .92441 L closepath p F P
0 g
s
.743 .614 .716 r
.3404 .87728 m .34214 .87539 L .33976 .86908 L p F P
0 g
s
.202 .66 .944 r
.14961 .95366 m .15564 .95398 L .16111 .95615 L p F P
0 g
s
.283 .697 .971 r
.15564 .95398 m .14961 .95366 L .14593 .9518 L p F P
0 g
s
.789 .594 .638 r
.30483 .77462 m .30249 .78067 L .30971 .78249 L p F P
0 g
s
.81 .61 .632 r
.29794 .77269 m .30483 .77462 L .30249 .78067 L p F P
0 g
s
.658 .553 .725 r
.46948 .88415 m .46134 .8853 L .45919 .87875 L p F P
0 g
s
.519 .537 .814 r
.69644 .7588 m .69368 .75261 L .70251 .75349 L closepath p F P
0 g
s
.554 .598 .852 r
.66756 .72244 m .65592 .72284 L .65305 .71748 L p F P
0 g
s
.757 .674 .77 r
.30253 .91537 m .31099 .91672 L .30163 .92482 L p F P
0 g
s
.757 .674 .77 r
.29709 .92035 m .30253 .91537 L p .30163 .92482 L F P
0 g
s
.757 .674 .77 r
.30163 .92482 m .29941 .92441 L .29709 .92035 L p F P
0 g
s
.787 .607 .657 r
.31776 .80116 m .31916 .79832 L .31685 .7978 L closepath p F P
0 g
s
.476 .272 .523 r
.51697 .74263 m .52226 .74042 L .52208 .73507 L p F P
0 g
s
.481 .276 .524 r
.52722 .73297 m .52208 .73507 L .52226 .74042 L p F P
0 g
s
.668 .773 .928 r
.20966 .69588 m .19891 .69994 L .19538 .69677 L p F P
0 g
s
.716 .777 .901 r
.18454 .70216 m .19538 .69677 L .19891 .69994 L p F P
0 g
s
.783 .595 .646 r
.30971 .78249 m .307 .78866 L .31456 .79037 L p F P
0 g
s
.801 .609 .642 r
.30249 .78067 m .30971 .78249 L .307 .78866 L p F P
0 g
s
.753 .646 .742 r
.32636 .8922 m .33317 .89308 L p .32765 .90107 L F P
0 g
s
.753 .646 .742 r
.31956 .89923 m .32636 .8922 L p .32765 .90107 L F P
0 g
s
.753 .646 .742 r
.32765 .90107 m .31987 .89988 L .31956 .89923 L p F P
0 g
s
.753 .647 .744 r
.32272 .90589 m .32765 .90107 L .31987 .89988 L closepath p F P
0 g
s
.86 .765 .757 r
.07434 .79541 m .07829 .79828 L .07336 .80507 L p F P
0 g
s
.857 .767 .762 r
.07829 .79828 m .07434 .79541 L .07949 .78856 L p F P
0 g
s
.782 .6 .654 r
.31685 .7978 m .31147 .79666 L .31456 .79037 L p F P
0 g
s
.793 .608 .651 r
.307 .78866 m .31456 .79037 L .31147 .79666 L p F P
0 g
s
.658 .547 .717 r
.45919 .87875 m .46272 .87679 L .45874 .87733 L closepath p F P
0 g
s
.591 .901 .985 r
.64216 .955 m .64331 .95542 L .65477 .95156 L p F P
0 g
s
.658 .553 .725 r
.45919 .87875 m .46272 .87679 L p .46948 .88415 L F P
0 g
s
.888 .727 .676 r
.06257 .84297 m .06677 .84569 L .06402 .85187 L p F P
0 g
s
.884 .733 .689 r
.06677 .84569 m .06257 .84297 L .06564 .83671 L p F P
0 g
s
.841 .777 .79 r
.09115 .77445 m .09188 .77362 L .08819 .77052 L p F P
0 g
s
.671 .967 .925 r
.55008 .70959 m .56136 .70322 L .56253 .70329 L p F P
0 g
s
0 0 0 r
.54953 .71013 m .55008 .70959 L .56136 .70322 L p F P
0 g
s
.747 .66 .764 r
.3118 .91684 m .3115 .91628 L .31099 .91672 L closepath p F P
0 g
s
.641 .623 .816 r
.53479 .93856 m .53448 .93796 L .52572 .94055 L closepath p F P
0 g
s
.639 .61 .804 r
.53146 .93178 m .53448 .93796 L .52572 .94055 L p F P
0 g
s
.639 .61 .804 r
.52018 .93517 m .53146 .93178 L p .52572 .94055 L F P
0 g
s
.42 .317 .631 r
.73945 .85685 m .73253 .86148 L .73641 .8661 L p F P
0 g
s
.436 .343 .652 r
.73873 .85338 m .73945 .85685 L .73253 .86148 L p F P
0 g
s
.436 .343 .652 r
.73645 .85128 m .73873 .85338 L p .73253 .86148 L F P
0 g
s
.423 .318 .63 r
.73165 .86924 m .73641 .8661 L .73253 .86148 L p F P
0 g
s
.65 .52 .693 r
.46264 .84526 m .46129 .84011 L .4664 .83704 L p F P
0 g
s
.754 .631 .724 r
.33123 .8761 m .3404 .87728 L .33354 .88469 L p F P
0 g
s
.743 .614 .716 r
.33761 .86882 m .33123 .8761 L .3404 .87728 L p F P
0 g
s
.743 .614 .716 r
.33976 .86908 m .33761 .86882 L p .3404 .87728 L F P
0 g
s
.748 .632 .731 r
.33317 .89308 m .33084 .88761 L .32636 .8922 L closepath p F P
0 g
s
.634 .495 .675 r
.46977 .82174 m .46947 .8204 L .48067 .81406 L p F P
0 g
s
.631 .488 .669 r
.48034 .81249 m .48067 .81406 L .46947 .8204 L p F P
0 g
s
.633 .955 .928 r
.56136 .70322 m .56674 .70045 L .56253 .70329 L closepath p F P
0 g
s
.616 .916 .979 r
.57268 .69772 m .56674 .70045 L .56253 .70329 L p F P
0 g
s
.616 .916 .979 r
.57557 .69945 m .57268 .69772 L p .56253 .70329 L F P
0 g
s
.841 .777 .79 r
.08819 .77052 m .08731 .77152 L .09115 .77445 L p F P
0 g
s
.847 .775 .782 r
.08731 .77152 m .09115 .77445 L .0852 .78154 L p F P
0 g
s
.745 .644 .748 r
.31952 .90884 m .32272 .90589 L .31987 .89988 L p F P
0 g
s
.754 .65 .746 r
.31952 .90884 m .3115 .91628 L .30831 .91013 L p F P
0 g
s
.754 .65 .746 r
.30831 .91013 m .31101 .9075 L .31952 .90884 L p F P
0 g
s
.745 .644 .748 r
.31901 .89976 m .31101 .9075 L .31952 .90884 L p F P
0 g
s
.745 .644 .748 r
.31987 .89988 m .31901 .89976 L p .31952 .90884 L F P
0 g
s
.352 .664 .973 r
.2273 .69995 m .23144 .70046 L .23595 .70323 L p F P
0 g
s
.745 .656 .762 r
.30831 .91013 m .30253 .91537 L .31099 .91672 L p F P
0 g
s
.745 .656 .762 r
.31099 .91672 m .3115 .91628 L .30831 .91013 L p F P
0 g
s
.897 .693 .619 r
.06379 .86664 m .06817 .86927 L .06646 .87516 L p F P
0 g
s
.892 .703 .641 r
.06817 .86927 m .06379 .86664 L .06588 .86064 L p F P
0 g
s
.305 .071 .384 r
.72142 .90535 m .71532 .9088 L .71489 .91368 L p F P
0 g
s
.348 .143 .454 r
.71532 .9088 m .72142 .90535 L .72318 .89921 L p F P
0 g
s
.407 .29 .607 r
.73641 .8661 m .73165 .86924 L .73259 .87546 L p F P
0 g
s
.422 .3 .608 r
.73033 .87686 m .73259 .87546 L .73165 .86924 L p F P
0 g
s
.488 .462 .755 r
.7231 .79844 m .7218 .79807 L .72272 .79736 L closepath p F P
0 g
s
.496 .475 .764 r
.72012 .79016 m .72272 .79736 L .7218 .79807 L p F P
0 g
s
.496 .475 .764 r
.7185 .78976 m .72012 .79016 L p .7218 .79807 L F P
0 g
s
.634 .663 .861 r
.55476 .95115 m .5661 .94832 L .56906 .95297 L p F P
0 g
s
.632 .646 .846 r
.56337 .94372 m .5661 .94832 L .55476 .95115 L p F P
0 g
s
.632 .646 .846 r
.55476 .95115 m .55215 .94676 L .56337 .94372 L p F P
0 g
s
.757 .612 .698 r
.3329 .84994 m .33639 .84518 L p .3401 .85339 L F P
0 g
s
.757 .612 .698 r
.3401 .85339 m .33378 .85248 L .3329 .84994 L p F P
0 g
s
.756 .614 .701 r
.33597 .85869 m .3401 .85339 L .33378 .85248 L closepath p F P
0 g
s
.635 .499 .68 r
.47143 .82883 m .46977 .82174 L .48188 .81947 L p F P
0 g
s
.634 .495 .675 r
.48067 .81406 m .48188 .81947 L .46977 .82174 L p F P
0 g
s
.383 .727 .99 r
.16111 .95615 m .16359 .95624 L .15997 .95399 L p F P
0 g
s
.383 .727 .99 r
.15997 .95399 m .15564 .95398 L .16111 .95615 L p F P
0 g
s
.495 .311 .561 r
.52226 .74042 m .51697 .74263 L .51728 .74832 L p F P
0 g
s
.752 .702 .804 r
.26036 .94196 m .26471 .93871 L .27218 .94031 L p F P
0 g
s
.742 .696 .808 r
.27147 .93371 m .26471 .93871 L .27218 .94031 L p F P
0 g
s
.742 .696 .808 r
.27218 .94031 m .27477 .9385 L .27147 .93371 L p F P
0 g
s
.511 .513 .794 r
.70312 .76633 m .71132 .76758 L p .70915 .77389 L F P
0 g
s
.508 .514 .797 r
.71132 .76758 m .70312 .76633 L .70882 .76152 L closepath p F P
0 g
s
.515 .524 .804 r
.70841 .76058 m .70882 .76152 L .70312 .76633 L p F P
0 g
s
.748 .686 .791 r
.28752 .93239 m .28591 .92983 L .28352 .93167 L closepath p F P
0 g
s
.772 .272 .016 r
.11255 .93779 m .11054 .93685 L .10688 .93236 L p F P
0 g
s
.763 .256 0 r
.10186 .93002 m .10688 .93236 L .11054 .93685 L p F P
0 g
s
.881 .742 .704 r
.06564 .83671 m .06727 .83366 L .0636 .83005 L p F P
0 g
s
.66 .58 .754 r
.48274 .90838 m .48255 .90791 L .481 .90863 L closepath p F P
0 g
s
.658 .575 .75 r
.47956 .8999 m .48255 .90791 L .481 .90863 L p F P
0 g
s
.658 .575 .75 r
.47903 .89997 m .47956 .8999 L p .481 .90863 L F P
0 g
s
.748 .615 .711 r
.33976 .86908 m .33905 .86717 L .33761 .86882 L closepath p F P
0 g
s
.359 .184 .503 r
.73352 .88738 m .72459 .8928 L .72478 .89829 L p F P
0 g
s
.386 .231 .546 r
.72459 .8928 m .73352 .88738 L .73249 .88196 L p F P
0 g
s
.375 .196 .506 r
.72318 .89921 m .72478 .89829 L .72459 .8928 L p F P
0 g
s
.635 .722 .91 r
.58982 .69846 m .60123 .69541 L .60412 .69911 L p F P
0 g
s
.65 .747 .921 r
.60123 .69541 m .58982 .69846 L .58693 .69549 L p F P
0 g
s
.666 .781 .935 r
.57557 .69945 m .58693 .69549 L .58982 .69846 L p F P
0 g
s
.746 .781 .881 r
.17007 .70553 m .17932 .69998 L .18316 .70298 L p F P
0 g
s
.745 .781 .882 r
.18099 .69899 m .17932 .69998 L .18316 .70298 L p F P
0 g
s
.745 .781 .882 r
.18316 .70298 m .18454 .70216 L .18099 .69899 L p F P
0 g
s
.751 .672 .774 r
.29941 .92441 m .29709 .92035 L .29346 .9234 L closepath p F P
0 g
s
.307 .046 .344 r
.54784 .71366 m .53827 .71879 L .53748 .72328 L p F P
0 g
s
.251 0 .174 r
.54953 .71013 m .54784 .71366 L .53827 .71879 L p F P
0 g
s
.453 .383 .689 r
.7354 .83891 m .73296 .8374 L .73471 .83618 L closepath p F P
0 g
s
.463 .403 .704 r
.73296 .8374 m .73471 .83618 L .73274 .82887 L p F P
0 g
s
.621 .779 .957 r
.60058 .95878 m .612 .95597 L .61485 .95864 L p F P
0 g
s
.625 .746 .934 r
.612 .95597 m .60058 .95878 L .59769 .95552 L p F P
0 g
s
.749 .73 .834 r
.24931 .94931 m .25144 .94787 L .24711 .94669 L closepath p F P
0 g
s
.735 .724 .841 r
.24711 .94669 m .24931 .94931 L p .23493 .95198 L F P
0 g
s
.765 .784 .868 r
.16279 .71037 m .15909 .71286 L .1555 .70971 L p F P
0 g
s
.69 .827 .949 r
.58693 .69549 m .57557 .69945 L .57268 .69772 L p F P
0 g
s
.647 .52 .694 r
.46431 .85159 m .46264 .84526 L .47501 .84327 L p F P
0 g
s
.65 .52 .693 r
.47316 .83599 m .47501 .84327 L .46264 .84526 L p F P
0 g
s
.65 .52 .693 r
.4664 .83704 m .47316 .83599 L p .46264 .84526 L F P
0 g
s
.658 .531 .698 r
.46264 .84526 m .46431 .85159 L .46219 .85296 L p F P
0 g
s
0 0 0 r
.68032 .94143 m .68996 .93626 L .68165 .94016 L closepath p F P
0 g
s
0 0 0 r
.69174 .9352 m .68996 .93626 L .68165 .94016 L p F P
0 g
s
0 0 0 r
.69352 .93214 m .69174 .9352 L p .68165 .94016 L F P
0 g
s
0 0 0 r
.66888 .94683 m .68032 .94143 L .68165 .94016 L p F P
0 g
s
.777 .602 .662 r
.31685 .7978 m .31147 .79666 L p .31588 .80468 L F P
0 g
s
.777 .602 .662 r
.31588 .80468 m .31776 .80116 L .31685 .7978 L p F P
0 g
s
.37 .836 .8 r
.66853 .94696 m .666 .94805 L p .65477 .95156 L F P
0 g
s
.31 .785 .689 r
.666 .94805 m .66853 .94696 L .66888 .94683 L closepath p F P
0 g
s
.746 .612 .71 r
.33761 .86882 m .33905 .86717 L .3367 .86072 L p F P
0 g
s
.404 .268 .58 r
.73259 .87546 m .73033 .87686 L .73249 .88196 L p F P
0 g
s
.467 .428 .731 r
.72816 .81358 m .73305 .80978 L p .73395 .81875 L F P
0 g
s
.467 .428 .731 r
.73395 .81875 m .72913 .81675 L .72816 .81358 L p F P
0 g
s
.473 .442 .743 r
.72816 .81358 m .7261 .80725 L .73305 .80978 L closepath p F P
0 g
s
.617 .471 .661 r
.48938 .79628 m .4907 .80303 L .47895 .80567 L p F P
0 g
s
.615 .472 .664 r
.47895 .80567 m .4907 .80303 L p .48792 .81078 L F P
0 g
s
.615 .472 .664 r
.48792 .81078 m .48034 .81249 L .47895 .80567 L p F P
0 g
s
.645 .593 .782 r
.50288 .92575 m .51413 .92186 L .51716 .9287 L p F P
0 g
s
.643 .585 .774 r
.51406 .9217 m .51413 .92186 L .50288 .92575 L p F P
0 g
s
.643 .585 .774 r
.50288 .92575 m .50217 .92408 L .51406 .9217 L p F P
0 g
s
.761 .613 .695 r
.3329 .84994 m .33639 .84518 L .33099 .84434 L closepath p F P
0 g
s
.761 .611 .692 r
.32984 .84091 m .33252 .83702 L p .33639 .84518 L F P
0 g
s
.761 .611 .692 r
.33639 .84518 m .33099 .84434 L .32984 .84091 L p F P
0 g
s
.756 .687 .785 r
.28352 .93167 m .27477 .9385 L .27147 .93371 L p F P
0 g
s
.473 .443 .743 r
.73305 .80978 m .7261 .80725 L .72555 .80559 L p F P
0 g
s
.467 .428 .731 r
.73055 .82134 m .72913 .81675 L .73395 .81875 L closepath p F P
0 g
s
.753 .632 .726 r
.33084 .88761 m .33354 .88469 L .32937 .8841 L closepath p F P
0 g
s
.754 .631 .724 r
.32772 .88012 m .33123 .8761 L p .33354 .88469 L F P
0 g
s
.754 .631 .724 r
.33354 .88469 m .32937 .8841 L .32772 .88012 L p F P
0 g
s
.66 .549 .718 r
.47139 .87564 m .47038 .87245 L .46272 .87679 L closepath p F P
0 g
s
.658 .546 .716 r
.469 .86785 m .47038 .87245 L .46272 .87679 L p F P
0 g
s
.658 .553 .725 r
.46272 .87679 m .47139 .87564 L p .46948 .88415 L F P
0 g
s
.06 0 0 r
.69174 .9352 m .69352 .93214 L .70321 .92729 L p F P
0 g
s
.133 0 .091 r
.70453 .92326 m .70321 .92729 L .69352 .93214 L p F P
0 g
s
.479 .456 .755 r
.72555 .80559 m .7231 .79844 L .73129 .80104 L closepath p F P
0 g
s
.473 .443 .743 r
.72555 .80559 m .73129 .80104 L p .73305 .80978 L F P
0 g
s
.493 .476 .766 r
.72012 .79016 m .7185 .78976 L .71965 .78885 L closepath p F P
0 g
s
.501 .488 .774 r
.71717 .78231 m .71965 .78885 L .7185 .78976 L p F P
0 g
s
.501 .488 .774 r
.71428 .7817 m .71717 .78231 L p .7185 .78976 L F P
0 g
s
.602 .845 .99 r
.64056 .95431 m .6291 .95762 L .62629 .95564 L p F P
0 g
s
.607 .829 .985 r
.61485 .95864 m .62629 .95564 L .6291 .95762 L p F P
0 g
s
.572 .88 .993 r
.6291 .95762 m .64056 .95431 L .64216 .955 L p F P
0 g
s
.715 .779 .902 r
.19538 .69677 m .18454 .70216 L .18099 .69899 L p F P
0 g
s
.653 .576 .756 r
.49376 .90313 m .49499 .90634 L .48274 .90838 L p F P
0 g
s
.653 .576 .756 r
.48274 .90838 m .48255 .90791 L .49376 .90313 L p F P
0 g
s
.758 .629 .718 r
.32861 .86759 m .33761 .86882 L .33123 .8761 L p F P
0 g
s
.746 .612 .71 r
.33454 .86044 m .32861 .86759 L .33761 .86882 L p F P
0 g
s
.746 .612 .71 r
.3367 .86072 m .33454 .86044 L p .33761 .86882 L F P
0 g
s
.511 .513 .794 r
.71132 .76758 m .71272 .77096 L .70915 .77389 L p F P
0 g
s
.506 .5 .785 r
.70915 .77389 m .71424 .77481 L p .71428 .7817 L F P
0 g
s
.503 .501 .787 r
.71424 .77481 m .70915 .77389 L .71272 .77096 L closepath p F P
0 g
s
.652 .568 .747 r
.49185 .89787 m .49376 .90313 L .48255 .90791 L p F P
0 g
s
.652 .568 .747 r
.48255 .90791 m .47956 .8999 L .49185 .89787 L p F P
0 g
s
.461 .413 .718 r
.73055 .82134 m .73395 .81875 L p .73398 .82795 L F P
0 g
s
.461 .413 .718 r
.73398 .82795 m .73222 .8271 L .73055 .82134 L p F P
0 g
s
.858 .49 .353 r
.26059 .71851 m .26164 .72154 L .26047 .72255 L p F P
0 g
s
.858 .49 .353 r
.25527 .71603 m .26059 .71851 L p .26047 .72255 L F P
0 g
s
.777 .602 .662 r
.31888 .80527 m .31776 .80116 L .31588 .80468 L closepath p F P
0 g
s
.541 .374 .603 r
.50778 .76411 m .50712 .75805 L .51781 .75423 L p F P
0 g
s
.533 .355 .586 r
.51728 .74832 m .51781 .75423 L .50712 .75805 L p F P
0 g
s
.751 .729 .832 r
.25702 .93754 m .26036 .94196 L .25144 .94787 L p F P
0 g
s
.751 .729 .832 r
.24594 .94527 m .25702 .93754 L p .25144 .94787 L F P
0 g
s
.751 .729 .832 r
.25144 .94787 m .24711 .94669 L .24594 .94527 L p F P
0 g
s
.66 .533 .699 r
.46461 .85265 m .46431 .85159 L .46219 .85296 L closepath p F P
0 g
s
.315 .644 .967 r
.23144 .70046 m .2273 .69995 L .2238 .6971 L p F P
0 g
s
.596 .446 .648 r
.48886 .79343 m .4882 .78966 L .4996 .78664 L p F P
0 g
s
.594 .439 .641 r
.49854 .78016 m .4996 .78664 L .4882 .78966 L p F P
0 g
s
.619 .79 .964 r
.62629 .95564 m .61485 .95864 L .612 .95597 L p F P
0 g
s
.575 .633 .872 r
.63698 .71053 m .63573 .70843 L .6398 .70801 L closepath p F P
0 g
s
.645 .585 .773 r
.51109 .91459 m .51406 .9217 L .50217 .92408 L p F P
0 g
s
.645 .585 .773 r
.50217 .92408 m .49985 .91861 L .51109 .91459 L p F P
0 g
s
.636 .631 .829 r
.53748 .94372 m .54879 .94068 L .55178 .94613 L p F P
0 g
s
.635 .62 .818 r
.54624 .93575 m .54879 .94068 L .53748 .94372 L p F P
0 g
s
.635 .62 .818 r
.53748 .94372 m .53479 .93856 L .54624 .93575 L p F P
0 g
s
.498 .489 .777 r
.71717 .78231 m .71428 .7817 L .71632 .78006 L closepath p F P
0 g
s
.506 .5 .785 r
.71424 .77481 m .71632 .78006 L .71428 .7817 L p F P
0 g
s
.747 .629 .729 r
.32636 .8922 m .33084 .88761 L .32937 .8841 L p F P
0 g
s
.648 .514 .686 r
.47316 .83599 m .47249 .8333 L .4664 .83704 L closepath p F P
0 g
s
.645 .51 .684 r
.47143 .82883 m .47249 .8333 L .4664 .83704 L p F P
0 g
s
.573 .419 .634 r
.49854 .78016 m .49756 .77376 L .50861 .77035 L p F P
0 g
s
.569 .408 .623 r
.50828 .76796 m .50861 .77035 L .49756 .77376 L p F P
0 g
s
.536 .565 .831 r
.67354 .73419 m .67406 .73374 L p .68491 .73992 L F P
0 g
s
.54 .575 .838 r
.67354 .73419 m .67331 .73373 L .67406 .73374 L closepath p F P
0 g
s
.765 .612 .688 r
.32984 .84091 m .33252 .83702 L .32832 .83632 L closepath p F P
0 g
s
.766 .61 .685 r
.3268 .83158 m .32853 .82889 L p .33252 .83702 L F P
0 g
s
.766 .61 .685 r
.33252 .83702 m .32832 .83632 L .3268 .83158 L p F P
0 g
s
.639 .6 .794 r
.52998 .92858 m .53146 .93178 L .52018 .93517 L p F P
0 g
s
.639 .6 .794 r
.52018 .93517 m .51831 .93117 L .52998 .92858 L p F P
0 g
s
.697 .753 .895 r
.22197 .95565 m .22057 .95428 L .21894 .955 L closepath p F P
0 g
s
.752 .613 .705 r
.3367 .86072 m .33597 .85869 L .33454 .86044 L closepath p F P
0 g
s
.665 .114 0 r
.11571 .93914 m .11255 .93779 L .11484 .9384 L closepath p F P
0 g
s
.479 .457 .755 r
.73129 .80104 m .7231 .79844 L .72272 .79736 L p F P
0 g
s
.765 .784 .868 r
.1555 .70971 m .159 .70735 L .16279 .71037 L p F P
0 g
s
.764 .784 .87 r
.16649 .70238 m .159 .70735 L .16279 .71037 L p F P
0 g
s
.764 .784 .87 r
.16279 .71037 m .17007 .70553 L .16649 .70238 L p F P
0 g
s
.875 .751 .722 r
.06478 .81828 m .06883 .82109 L .06496 .82758 L p F P
0 g
s
.871 .754 .731 r
.06883 .82109 m .06478 .81828 L .06891 .81172 L p F P
0 g
s
.772 .602 .668 r
.31888 .80527 m .31588 .80468 L p .32024 .81271 L F P
0 g
s
.772 .602 .668 r
.32024 .81271 m .32075 .81183 L .31888 .80527 L p F P
0 g
s
.479 .457 .755 r
.72272 .79736 m .72867 .79252 L p .73129 .80104 L F P
0 g
s
.484 .47 .766 r
.72272 .79736 m .72012 .79016 L .72867 .79252 L closepath p F P
0 g
s
.85 .774 .778 r
.0852 .78154 m .08028 .78755 L .07657 .78445 L p F P
0 g
s
.85 .774 .778 r
.07657 .78445 m .08134 .77862 L .0852 .78154 L p F P
0 g
s
.847 .775 .782 r
.0852 .78154 m .08134 .77862 L .08731 .77152 L p F P
0 g
s
.895 .707 .641 r
.06158 .85796 m .06588 .86064 L .06379 .86664 L p F P
0 g
s
.89 .716 .659 r
.06588 .86064 m .06158 .85796 L .06402 .85187 L p F P
0 g
s
.824 .598 .596 r
.2837 .74893 m .28663 .74989 L .28752 .75635 L p F P
0 g
s
.837 .607 .59 r
.2887 .75678 m .28752 .75635 L .28663 .74989 L p F P
0 g
s
.75 .611 .704 r
.33454 .86044 m .33597 .85869 L .33378 .85248 L p F P
0 g
s
.539 .578 .842 r
.67406 .73374 m .67331 .73373 L .67044 .72807 L p F P
0 g
s
.65 .527 .701 r
.46461 .85265 m .46431 .85159 L .47551 .84521 L p F P
0 g
s
.647 .52 .694 r
.47501 .84327 m .47551 .84521 L .46431 .85159 L p F P
0 g
s
.461 .413 .718 r
.73274 .82887 m .73222 .8271 L .73398 .82795 L closepath p F P
0 g
s
.757 .638 .729 r
.32636 .8922 m .31956 .89923 L .31641 .89238 L p F P
0 g
s
.757 .638 .729 r
.31641 .89238 m .3178 .89087 L .32636 .8922 L p F P
0 g
s
.747 .629 .729 r
.32464 .88345 m .3178 .89087 L .32636 .8922 L p F P
0 g
s
.747 .629 .729 r
.32937 .8841 m .32464 .88345 L p .32636 .8922 L F P
0 g
s
.647 .527 .704 r
.46461 .85265 m .477 .85069 L p .47345 .85908 L F P
0 g
s
.647 .527 .704 r
.47345 .85908 m .46673 .86019 L .46461 .85265 L p F P
0 g
s
.65 .527 .701 r
.47551 .84521 m .477 .85069 L .46461 .85265 L p F P
0 g
s
0 .375 .705 r
.13224 .9475 m .13182 .94734 L .1321 .94745 L closepath p F P
0 g
s
.77 .611 .682 r
.3268 .83158 m .32853 .82889 L .32577 .82839 L closepath p F P
0 g
s
.771 .609 .679 r
.32376 .82192 m .32445 .82078 L p .32853 .82889 L F P
0 g
s
.771 .609 .679 r
.32853 .82889 m .32577 .82839 L .32376 .82192 L p F P
0 g
s
.613 .686 .895 r
.60412 .69911 m .61558 .69672 L .61846 .70087 L p F P
0 g
s
.621 .701 .902 r
.61558 .69672 m .60412 .69911 L .60123 .69541 L p F P
0 g
s
.451 .394 .704 r
.73398 .82795 m .73274 .82887 L .73471 .83618 L p F P
0 g
s
.365 .82 .709 r
.66853 .94696 m .66888 .94683 L .68032 .94143 L p F P
0 g
s
.143 .601 .927 r
.13224 .9475 m .14225 .94979 L .13894 .9479 L p F P
0 g
s
.143 .601 .927 r
.13182 .94734 m .13224 .9475 L p .13894 .9479 L F P
0 g
s
.756 .687 .785 r
.27147 .93371 m .27583 .93012 L .28352 .93167 L p F P
0 g
s
.747 .683 .789 r
.28264 .92458 m .27583 .93012 L .28352 .93167 L p F P
0 g
s
.747 .683 .789 r
.28352 .93167 m .28591 .92983 L .28264 .92458 L p F P
0 g
s
.633 .499 .682 r
.47249 .8333 m .47143 .82883 L .48348 .82651 L p F P
0 g
s
.635 .499 .68 r
.48188 .81947 m .48348 .82651 L .47143 .82883 L p F P
0 g
s
0 0 0 r
.56136 .70322 m .55871 .70453 L p .55312 .70804 L F P
0 g
s
0 0 0 r
.55871 .70453 m .55849 .70481 L .55924 .7042 L p F P
0 g
s
.334 .787 .641 r
.55947 .70401 m .55871 .70453 L p .55871 .70453 L F P
0 g
s
.334 .787 .641 r
.5698 .69729 m .55947 .70401 L p .55871 .70453 L F P
0 g
s
.462 .859 .673 r
.56754 .69848 m .5698 .69729 L .5629 .70178 L p F P
0 g
s
.462 .859 .673 r
.5629 .70178 m .55947 .70401 L .56754 .69848 L p F P
0 g
s
.334 .787 .641 r
.57142 .69734 m .5698 .69729 L p .55871 .70453 L F P
0 g
s
.368 .805 .642 r
.56754 .69848 m .5698 .69729 L .57629 .69366 L p F P
0 g
s
.368 .805 .642 r
.57629 .69366 m .57991 .69085 L p .56754 .69848 L F P
0 g
s
.368 .805 .642 r
.57991 .69085 m .57829 .69073 L p .56754 .69848 L F P
0 g
s
0 0 0 r
.56754 .69848 m .56696 .69927 L .56875 .69761 L p F P
0 g
s
.368 .805 .642 r
.56926 .69714 m .56754 .69848 L p .56777 .69831 L F P
0 g
s
.368 .805 .642 r
.57829 .69073 m .56926 .69714 L p .56777 .69831 L F P
0 g
s
.557 .916 .728 r
.56926 .69714 m .5759 .69181 L .57829 .69073 L closepath p F P
0 g
s
.056 0 .025 r
.56926 .69714 m .5759 .69181 L p .57528 .69243 L F P
0 g
s
.334 .787 .641 r
.56674 .70045 m .57142 .69734 L p .55871 .70453 L F P
0 g
s
.659 .934 .969 r
.56674 .70045 m .57142 .69734 L .57268 .69772 L closepath p F P
0 g
s
.653 .965 .916 r
.5698 .69729 m .57629 .69366 L .57142 .69734 L closepath p F P
0 g
s
.056 0 .025 r
.5658 .70191 m .56926 .69714 L .57528 .69243 L F
0 0 0 r
.56875 .69761 m .56926 .69714 L .56754 .69848 L p F P
0 g
s
.109 0 .045 r
.55947 .70401 m .56754 .69848 L p .56753 .69848 L F P
0 g
s
.334 .787 .641 r
.55871 .70453 m .56136 .70322 L .56674 .70045 L p F P
0 g
s
.109 0 .045 r
.55703 .70806 m .55947 .70401 L .56753 .69848 L F
0 0 0 r
.55924 .7042 m .55947 .70401 L .55871 .70453 L p F P
0 g
s
0 0 0 r
.55871 .70453 m .54953 .71013 L p .55312 .70804 L F P
0 g
s
.048 0 .007 r
.55871 .70453 m .54953 .71013 L .54784 .71366 L p F P
0 g
s
.866 .763 .747 r
.07336 .80507 m .07215 .80683 L .06844 .8036 L p F P
0 g
s
.866 .763 .747 r
.06844 .8036 m .06939 .80221 L .07336 .80507 L p F P
0 g
s
.86 .765 .757 r
.07336 .80507 m .06939 .80221 L .07434 .79541 L p F P
0 g
s
.886 .737 .69 r
.06152 .83395 m .06564 .83671 L .06257 .84297 L p F P
0 g
s
.881 .742 .704 r
.0636 .83005 m .06152 .83395 L .06564 .83671 L p F P
0 g
s
.762 .628 .712 r
.32573 .85915 m .33454 .86044 L .32861 .86759 L p F P
0 g
s
.75 .611 .704 r
.33122 .85212 m .32573 .85915 L .33454 .86044 L p F P
0 g
s
.75 .611 .704 r
.33378 .85248 m .33122 .85212 L p .33454 .86044 L F P
0 g
s
.658 .56 .733 r
.46948 .88415 m .47392 .88355 L p .47504 .89185 L F P
0 g
s
.66 .556 .727 r
.47392 .88355 m .47342 .88204 L .46948 .88415 L closepath p F P
0 g
s
.658 .553 .725 r
.47139 .87564 m .47342 .88204 L .46948 .88415 L p F P
0 g
s
.658 .567 .742 r
.47664 .89163 m .47951 .89974 L .47903 .89997 L p F P
0 g
s
.658 .567 .742 r
.47504 .89185 m .47664 .89163 L p .47903 .89997 L F P
0 g
s
.66 .571 .744 r
.47956 .8999 m .47951 .89974 L .47903 .89997 L closepath p F P
0 g
s
.756 .612 .699 r
.33378 .85248 m .3329 .84994 L .33122 .85212 L closepath p F P
0 g
s
.863 .564 .48 r
.27292 .73348 m .26745 .73106 L .26714 .72588 L p F P
0 g
s
.875 .577 .479 r
.262 .72335 m .26714 .72588 L .26745 .73106 L p F P
0 g
s
.874 .534 .404 r
.26714 .72588 m .262 .72335 L .26164 .72154 L p F P
0 g
s
.772 .603 .669 r
.32104 .81285 m .32075 .81183 L .32024 .81271 L closepath p F P
0 g
s
.752 .63 .725 r
.32937 .8841 m .32772 .88012 L .32464 .88345 L closepath p F P
0 g
s
.775 .611 .676 r
.32376 .82192 m .32445 .82078 L .32334 .82056 L closepath p F P
0 g
s
.776 .608 .672 r
.32445 .82078 m .32334 .82056 L .32104 .81285 L p F P
0 g
s
.653 .567 .746 r
.49072 .89476 m .49185 .89787 L .47956 .8999 L p F P
0 g
s
.653 .567 .746 r
.47956 .8999 m .47951 .89974 L .49072 .89476 L p F P
0 g
s
.651 .559 .738 r
.48894 .88962 m .49072 .89476 L .47951 .89974 L p F P
0 g
s
.651 .559 .738 r
.47951 .89974 m .47664 .89163 L .48894 .88962 L p F P
0 g
s
.772 .606 .674 r
.32024 .81271 m .32104 .81285 L .32334 .82056 L p F P
0 g
s
.536 .565 .831 r
.67406 .73374 m .68504 .7341 L p .68491 .73992 L F P
0 g
s
.535 .569 .836 r
.67406 .73374 m .68504 .7341 L .68216 .72822 L p F P
0 g
s
.535 .569 .836 r
.68216 .72822 m .68016 .72816 L .67406 .73374 L p F P
0 g
s
.539 .578 .842 r
.67044 .72807 m .68016 .72816 L .67406 .73374 L p F P
0 g
s
.75 .645 .744 r
.31987 .89988 m .31956 .89923 L .31901 .89976 L closepath p F P
0 g
s
.743 .725 .835 r
.24453 .94612 m .23493 .95198 L .23152 .94825 L p F P
0 g
s
.735 .724 .841 r
.23493 .95198 m .24453 .94612 L .24711 .94669 L p F P
0 g
s
.759 .676 .77 r
.29346 .9234 m .28591 .92983 L .28264 .92458 L p F P
0 g
s
.518 .537 .815 r
.70251 .75349 m .69368 .75261 L .69192 .74869 L p F P
0 g
s
.754 .609 .698 r
.33122 .85212 m .3329 .84994 L .33099 .84434 L p F P
0 g
s
.317 0 0 r
.12837 .94583 m .12707 .94523 L .13182 .94734 L closepath p F P
0 g
s
.143 .601 .927 r
.12837 .94583 m .13182 .94734 L p .13894 .9479 L F P
0 g
s
.757 .63 .72 r
.32772 .88012 m .33123 .8761 L .32573 .87526 L closepath p F P
0 g
s
.758 .629 .718 r
.3246 .87245 m .32861 .86759 L p .33123 .8761 L F P
0 g
s
.758 .629 .718 r
.33123 .8761 m .32573 .87526 L .3246 .87245 L p F P
0 g
s
.899 .631 .524 r
.07758 .89982 m .07296 .89731 L .07332 .89177 L p F P
0 g
s
.897 .601 .477 r
.08245 .90771 m .07777 .90523 L .07758 .89982 L p F P
0 g
s
.9 .604 .475 r
.07296 .89731 m .07758 .89982 L .07777 .90523 L p F P
0 g
s
.629 .664 .865 r
.58044 .95027 m .56906 .95297 L .5661 .94832 L p F P
0 g
s
.892 .562 .417 r
.08798 .91541 m .08324 .91295 L .08245 .90771 L p F P
0 g
s
.895 .564 .413 r
.07777 .90523 m .08245 .90771 L .08324 .91295 L p F P
0 g
s
.749 .641 .742 r
.31901 .89976 m .31956 .89923 L .31641 .89238 L p F P
0 g
s
.66 .564 .735 r
.47664 .89163 m .47646 .89113 L .47504 .89185 L closepath p F P
0 g
s
.658 .56 .733 r
.47392 .88355 m .47646 .89113 L .47504 .89185 L p F P
0 g
s
.76 .659 .75 r
.31043 .89843 m .31901 .89976 L .31101 .9075 L p F P
0 g
s
.749 .641 .742 r
.31641 .89238 m .31043 .89843 L .31901 .89976 L p F P
0 g
s
.574 .768 .971 r
.17414 .95465 m .16359 .95624 L .15997 .95399 L p F P
0 g
s
.546 .765 .978 r
.16359 .95624 m .17414 .95465 L .17772 .95721 L p F P
0 g
s
.647 .529 .705 r
.46734 .86233 m .47345 .85908 L .46673 .86019 L closepath p F P
0 g
s
.783 .615 .671 r
.31232 .81112 m .32024 .81271 L .31632 .81926 L p F P
0 g
s
.772 .602 .668 r
.31588 .80468 m .31232 .81112 L .32024 .81271 L p F P
0 g
s
.772 .606 .674 r
.32334 .82056 m .31632 .81926 L .32024 .81271 L p F P
0 g
s
.807 .786 .833 r
.1254 .73351 m .1222 .7363 L .11855 .73323 L p F P
0 g
s
.814 .786 .826 r
.11655 .74149 m .1222 .7363 L .11855 .73323 L p F P
0 g
s
.817 .786 .823 r
.11655 .74149 m .11097 .74672 L .10729 .74367 L p F P
0 g
s
.817 .786 .823 r
.10729 .74367 m .11283 .73848 L .11655 .74149 L p F P
0 g
s
.814 .786 .826 r
.11855 .73323 m .11283 .73848 L .11655 .74149 L p F P
0 g
s
.754 .609 .698 r
.33099 .84434 m .32771 .84385 L p .33122 .85212 L F P
0 g
s
.759 .61 .693 r
.33099 .84434 m .32984 .84091 L .32771 .84385 L closepath p F P
0 g
s
.484 .47 .767 r
.72867 .79252 m .72012 .79016 L .71965 .78885 L p F P
0 g
s
.869 .761 .741 r
.06891 .81172 m .07215 .80683 L .06844 .8036 L p F P
0 g
s
.767 .607 .68 r
.32334 .82056 m .31632 .81926 L p .32023 .82743 L F P
0 g
s
.767 .607 .68 r
.32023 .82743 m .32376 .82192 L .32334 .82056 L p F P
0 g
s
.823 .785 .817 r
.10836 .74927 m .11097 .74672 L .10729 .74367 L p F P
0 g
s
.807 .786 .833 r
.11855 .73323 m .12169 .73049 L .1254 .73351 L p F P
0 g
s
.804 .787 .836 r
.12973 .72359 m .12169 .73049 L .1254 .73351 L p F P
0 g
s
.804 .787 .836 r
.1254 .73351 m .13337 .72667 L .12973 .72359 L p F P
0 g
s
.902 .635 .523 r
.06877 .88922 m .07332 .89177 L .07296 .89731 L p F P
0 g
s
.899 .656 .562 r
.07332 .89177 m .06877 .88922 L .06963 .88354 L p F P
0 g
s
.596 .446 .648 r
.4996 .78664 m .50009 .7894 L .48886 .79343 L p F P
0 g
s
.598 .452 .654 r
.48938 .79628 m .48886 .79343 L .50009 .7894 L p F P
0 g
s
.758 .608 .692 r
.32771 .84385 m .32984 .84091 L .32832 .83632 L p F P
0 g
s
.768 .607 .68 r
.32577 .82839 m .32376 .82192 L .32023 .82743 L closepath p F P
0 g
s
.759 .676 .77 r
.28264 .92458 m .28567 .92187 L .29346 .9234 L p F P
0 g
s
.75 .67 .772 r
.29386 .91464 m .28567 .92187 L .29346 .9234 L p F P
0 g
s
.75 .67 .772 r
.29346 .9234 m .29709 .92035 L .29386 .91464 L p F P
0 g
s
.651 .537 .712 r
.469 .86785 m .46734 .86233 L .47345 .85908 L p F P
0 g
s
.849 .582 .534 r
.27842 .74117 m .27262 .73887 L .27292 .73348 L p F P
0 g
s
.862 .594 .532 r
.26745 .73106 m .27292 .73348 L .27262 .73887 L p F P
0 g
s
.484 .47 .767 r
.71965 .78885 m .72519 .78423 L p .72867 .79252 L F P
0 g
s
.49 .483 .777 r
.71965 .78885 m .71717 .78231 L .72519 .78423 L closepath p F P
0 g
s
.79 .615 .664 r
.30826 .803 m .31588 .80468 L .31232 .81112 L p F P
0 g
s
.777 .602 .662 r
.31147 .79666 m .30826 .803 L .31588 .80468 L p F P
0 g
s
.758 .608 .692 r
.32832 .83632 m .32403 .83562 L p .32771 .84385 L F P
0 g
s
.763 .609 .686 r
.32832 .83632 m .3268 .83158 L .32403 .83562 L closepath p F P
0 g
s
.643 .576 .764 r
.51035 .91271 m .51109 .91459 L .49985 .91861 L p F P
0 g
s
.643 .576 .764 r
.49985 .91861 m .49841 .91506 L .51035 .91271 L p F P
0 g
s
.826 .784 .812 r
.10463 .74626 m .10836 .74927 L .1008 .75685 L p F P
0 g
s
.823 .785 .817 r
.10729 .74367 m .10463 .74626 L .10836 .74927 L p F P
0 g
s
.587 .886 .991 r
.64056 .95431 m .64216 .955 L .65245 .95093 L p F P
0 g
s
.591 .901 .985 r
.65477 .95156 m .65245 .95093 L .64216 .955 L p F P
0 g
s
.762 .607 .686 r
.32577 .82839 m .32023 .82743 L p .32403 .83562 L F P
0 g
s
.762 .607 .686 r
.32403 .83562 m .3268 .83158 L .32577 .82839 L p F P
0 g
s
.71 .754 .887 r
.20624 .95601 m .21205 .95323 L .21894 .955 L p F P
0 g
s
.696 .748 .892 r
.21712 .95084 m .21205 .95323 L .21894 .955 L p F P
0 g
s
.696 .748 .892 r
.21894 .955 m .22057 .95428 L .21712 .95084 L p F P
0 g
s
.754 .609 .698 r
.32771 .84385 m .32262 .85076 L .33122 .85212 L p F P
0 g
s
.766 .627 .705 r
.32262 .85076 m .33122 .85212 L .32573 .85915 L p F P
0 g
s
.76 .66 .752 r
.30831 .91013 m .31101 .9075 L .30655 .9067 L closepath p F P
0 g
s
.76 .659 .75 r
.30512 .90388 m .31043 .89843 L p .31101 .9075 L F P
0 g
s
.76 .659 .75 r
.31101 .9075 m .30655 .9067 L .30512 .90388 L p F P
0 g
s
.881 .512 .34 r
.0942 .92291 m .08942 .92048 L .08798 .91541 L p F P
0 g
s
.883 .511 .333 r
.08324 .91295 m .08798 .91541 L .08942 .92048 L p F P
0 g
s
.478 0 0 r
.12707 .94523 m .12197 .94293 L .11571 .93914 L p F P
0 g
s
.433 0 0 r
.11255 .93779 m .11571 .93914 L .12197 .94293 L p F P
0 g
s
.636 .507 .688 r
.47316 .83599 m .47249 .8333 L .4837 .82744 L p F P
0 g
s
.633 .499 .682 r
.48348 .82651 m .4837 .82744 L .47249 .8333 L p F P
0 g
s
.762 .667 .757 r
.30253 .91537 m .29709 .92035 L .29386 .91464 L p F P
0 g
s
.652 .559 .737 r
.48767 .88593 m .48894 .88962 L .47664 .89163 L p F P
0 g
s
.652 .559 .737 r
.47664 .89163 m .47646 .89113 L .48767 .88593 L p F P
0 g
s
.762 .667 .757 r
.29386 .91464 m .29468 .91385 L .30253 .91537 L p F P
0 g
s
.75 .656 .757 r
.30281 .90608 m .29468 .91385 L .30253 .91537 L p F P
0 g
s
.75 .656 .757 r
.30655 .9067 m .30281 .90608 L p .30253 .91537 L F P
0 g
s
.75 .656 .757 r
.30253 .91537 m .30831 .91013 L .30655 .9067 L p F P
0 g
s
.617 .477 .669 r
.48067 .81406 m .48792 .81078 L .48034 .81249 L closepath p F P
0 g
s
.797 .617 .657 r
.30414 .79489 m .31147 .79666 L .30826 .803 L p F P
0 g
s
.793 .608 .651 r
.31147 .79666 m .30414 .79489 L .307 .78866 L p F P
0 g
s
.65 .551 .73 r
.48624 .88154 m .48767 .88593 L .47646 .89113 L p F P
0 g
s
.65 .551 .73 r
.47646 .89113 m .47392 .88355 L .48624 .88154 L p F P
0 g
s
.564 .608 .855 r
.65305 .71748 m .6525 .71752 L .65289 .71719 L closepath p F P
0 g
s
.568 .618 .862 r
.65018 .71238 m .65289 .71719 L .6525 .71752 L p F P
0 g
s
.177 0 .146 r
.71237 .9191 m .70453 .92326 L .70321 .92729 L p F P
0 g
s
.229 0 .271 r
.71435 .91682 m .71237 .9191 L .70453 .92326 L p F P
0 g
s
.229 0 .271 r
.71489 .91368 m .71435 .91682 L p .70453 .92326 L F P
0 g
s
.639 .6 .793 r
.52844 .92523 m .52998 .92858 L .51831 .93117 L p F P
0 g
s
.639 .6 .793 r
.51831 .93117 m .51716 .9287 L .52844 .92523 L p F P
0 g
s
.648 .536 .713 r
.47038 .87245 m .469 .86785 L .48131 .86582 L p F P
0 g
s
.651 .537 .712 r
.47908 .85819 m .48131 .86582 L .469 .86785 L p F P
0 g
s
.651 .537 .712 r
.47345 .85908 m .47908 .85819 L p .469 .86785 L F P
0 g
s
.75 .627 .723 r
.32464 .88345 m .32772 .88012 L .32573 .87526 L p F P
0 g
s
.442 .377 .688 r
.73471 .83618 m .7407 .83176 L p .73911 .84138 L F P
0 g
s
.442 .377 .688 r
.73911 .84138 m .7354 .83891 L .73471 .83618 L p F P
0 g
s
.451 .394 .704 r
.73471 .83618 m .7407 .83176 L .73398 .82795 L p F P
0 g
s
.853 .773 .773 r
.07949 .78856 m .08028 .78755 L .07657 .78445 L p F P
0 g
s
.574 .639 .878 r
.6398 .70801 m .63573 .70843 L .63285 .70373 L p F P
0 g
s
.365 .82 .709 r
.68032 .94143 m .67847 .94246 L .66853 .94696 L p F P
0 g
s
.425 .868 .816 r
.66625 .94734 m .66853 .94696 L .67847 .94246 L p F P
0 g
s
.37 .836 .8 r
.65477 .95156 m .66625 .94734 L .66853 .94696 L p F P
0 g
s
.795 .787 .845 r
.13511 .72526 m .13337 .72667 L .12973 .72359 L p F P
0 g
s
.805 .618 .649 r
.29997 .78679 m .307 .78866 L .30414 .79489 L p F P
0 g
s
.801 .609 .642 r
.307 .78866 m .29997 .78679 L .30249 .78067 L p F P
0 g
s
.761 .709 .803 r
.26471 .93871 m .26036 .94196 L .25702 .93754 L p F P
0 g
s
.835 .591 .57 r
.2837 .74893 m .27757 .74674 L .27842 .74117 L p F P
0 g
s
.848 .603 .567 r
.27262 .73887 m .27842 .74117 L .27757 .74674 L p F P
0 g
s
.651 .544 .72 r
.47139 .87564 m .47038 .87245 L .48159 .86678 L p F P
0 g
s
.648 .536 .713 r
.48131 .86582 m .48159 .86678 L .47038 .87245 L p F P
0 g
s
.652 .551 .728 r
.48463 .87661 m .48624 .88154 L .47392 .88355 L p F P
0 g
s
.652 .551 .728 r
.47392 .88355 m .47342 .88204 L .48463 .87661 L p F P
0 g
s
.812 .62 .643 r
.29575 .7787 m .30249 .78067 L .29997 .78679 L p F P
0 g
s
.81 .61 .632 r
.30249 .78067 m .29575 .7787 L .29794 .77269 L p F P
0 g
s
.651 .544 .72 r
.48159 .86678 m .4837 .87361 L .47139 .87564 L p F P
0 g
s
.649 .543 .721 r
.47342 .88204 m .47139 .87564 L .4837 .87361 L p F P
0 g
s
.795 .787 .845 r
.12973 .72359 m .13141 .72223 L .13511 .72526 L p F P
0 g
s
.793 .787 .847 r
.14084 .71471 m .13141 .72223 L .13511 .72526 L p F P
0 g
s
.793 .787 .847 r
.13511 .72526 m .14446 .71781 L .14084 .71471 L p F P
0 g
s
.902 .66 .562 r
.06515 .88096 m .06963 .88354 L .06877 .88922 L p F P
0 g
s
.898 .676 .593 r
.06963 .88354 m .06515 .88096 L .06646 .87516 L p F P
0 g
s
.746 .783 .883 r
.17932 .69998 m .17007 .70553 L .16649 .70238 L p F P
0 g
s
.859 .771 .764 r
.07563 .78564 m .07949 .78856 L .07434 .79541 L p F P
0 g
s
.853 .773 .773 r
.07657 .78445 m .07563 .78564 L .07949 .78856 L p F P
0 g
s
.649 .543 .721 r
.4837 .87361 m .48463 .87661 L .47342 .88204 L p F P
0 g
s
.893 .72 .66 r
.05981 .84916 m .06402 .85187 L .06158 .85796 L p F P
0 g
s
.888 .727 .676 r
.06402 .85187 m .05981 .84916 L .06257 .84297 L p F P
0 g
s
.554 .598 .852 r
.65305 .71748 m .6647 .71708 L .66756 .72244 L p F P
0 g
s
.555 .603 .857 r
.66182 .71175 m .6647 .71708 L .65305 .71748 L p F P
0 g
s
.555 .603 .857 r
.65855 .71189 m .66182 .71175 L p .65305 .71748 L F P
0 g
s
.555 .603 .857 r
.65305 .71748 m .65289 .71719 L .65855 .71189 L p F P
0 g
s
.62 .484 .675 r
.48188 .81947 m .48067 .81406 L .48792 .81078 L p F P
0 g
s
.819 .62 .634 r
.29149 .77063 m .29794 .77269 L .29575 .7787 L p F P
0 g
s
.82 .611 .62 r
.29794 .77269 m .29149 .77063 L .29335 .76472 L p F P
0 g
s
.831 .783 .807 r
.1008 .75685 m .09964 .75805 L .09594 .755 L p F P
0 g
s
.831 .783 .807 r
.09594 .755 m .09705 .75386 L .1008 .75685 L p F P
0 g
s
.826 .784 .812 r
.1008 .75685 m .09705 .75386 L .10463 .74626 L p F P
0 g
s
.634 .507 .691 r
.47316 .83599 m .48524 .8337 L p .48242 .84184 L F P
0 g
s
.634 .507 .691 r
.48242 .84184 m .47501 .84327 L .47316 .83599 L p F P
0 g
s
.636 .507 .688 r
.4837 .82744 m .48524 .8337 L .47316 .83599 L p F P
0 g
s
.824 .598 .596 r
.28752 .75635 m .28236 .75465 L .2837 .74893 L p F P
0 g
s
.836 .608 .593 r
.27757 .74674 m .2837 .74893 L .28236 .75465 L p F P
0 g
s
.761 .644 .731 r
.31613 .88209 m .32464 .88345 L .3178 .89087 L p F P
0 g
s
.75 .627 .723 r
.32255 .87479 m .31613 .88209 L .32464 .88345 L p F P
0 g
s
.75 .627 .723 r
.32573 .87526 m .32255 .87479 L p .32464 .88345 L F P
0 g
s
.826 .619 .622 r
.28881 .76316 m .29335 .76472 L .29149 .77063 L p F P
0 g
s
.828 .611 .608 r
.28807 .75913 m .2887 .75678 L p .29335 .76472 L F P
0 g
s
.828 .611 .608 r
.29335 .76472 m .28881 .76316 L .28807 .75913 L p F P
0 g
s
.632 .646 .846 r
.56313 .94331 m .56337 .94372 L .55215 .94676 L p F P
0 g
s
.632 .646 .846 r
.55215 .94676 m .55178 .94613 L .56313 .94331 L p F P
0 g
s
.733 .738 .855 r
.23152 .94825 m .22057 .95428 L .21712 .95084 L p F P
0 g
s
.771 .626 .699 r
.31933 .84242 m .32771 .84385 L .32262 .85076 L p F P
0 g
s
.758 .608 .692 r
.32403 .83562 m .31933 .84242 L .32771 .84385 L p F P
0 g
s
.762 .629 .714 r
.3246 .87245 m .32861 .86759 L .32226 .86654 L closepath p F P
0 g
s
.762 .628 .712 r
.32149 .86458 m .32573 .85915 L p .32861 .86759 L F P
0 g
s
.762 .628 .712 r
.32861 .86759 m .32226 .86654 L .32149 .86458 L p F P
0 g
s
.836 .782 .801 r
.0939 .76423 m .09964 .75805 L .09594 .755 L p F P
0 g
s
.835 .617 .608 r
.28807 .75913 m .2887 .75678 L .28752 .75635 L closepath p F P
0 g
s
.832 .388 .175 r
.09423 .92298 m .09435 .92299 L p .10186 .93002 L F P
0 g
s
.863 .458 .266 r
.09423 .92298 m .0942 .92291 L .09435 .92299 L closepath p F P
0 g
s
.644 .576 .763 r
.50805 .90692 m .51035 .91271 L .49841 .91506 L p F P
0 g
s
.644 .576 .763 r
.49841 .91506 m .49681 .91108 L .50805 .90692 L p F P
0 g
s
.594 .666 .889 r
.61878 .70136 m .61846 .70087 L .61952 .70071 L closepath p F P
0 g
s
.56 .613 .862 r
.65289 .71719 m .65018 .71238 L .65855 .71189 L closepath p F P
0 g
s
.341 .137 .451 r
.72478 .89829 m .72318 .89921 L .72142 .90535 L p F P
0 g
s
.388 .257 .578 r
.73943 .87098 m .73259 .87546 L .7333 .88146 L p F P
0 g
s
.404 .268 .58 r
.73249 .88196 m .7333 .88146 L .73259 .87546 L p F P
0 g
s
.407 .29 .607 r
.73259 .87546 m .73943 .87098 L .73641 .8661 L p F P
0 g
s
.734 .725 .843 r
.24711 .94669 m .24594 .94527 L .24453 .94612 L closepath p F P
0 g
s
.45 .251 .518 r
.52727 .73837 m .52722 .73297 L .53718 .7283 L p F P
0 g
s
.481 .276 .524 r
.52226 .74042 m .52727 .73837 L .52722 .73297 L p F P
0 g
s
.421 .194 .462 r
.53748 .72328 m .53718 .7283 L .52722 .73297 L p F P
0 g
s
.443 .377 .688 r
.73649 .84328 m .7354 .83891 L .73911 .84138 L closepath p F P
0 g
s
.449 .395 .705 r
.74134 .8224 m .73398 .82795 L .7407 .83176 L p F P
0 g
s
.461 .413 .718 r
.74131 .82229 m .74134 .8224 L .73398 .82795 L p F P
0 g
s
.461 .413 .718 r
.73395 .81875 m .74131 .82229 L p .73398 .82795 L F P
0 g
s
.6 .458 .66 r
.4907 .80303 m .48938 .79628 L .50081 .79328 L p F P
0 g
s
.598 .452 .654 r
.50009 .7894 m .50081 .79328 L .48938 .79628 L p F P
0 g
s
.862 .45 .245 r
.0942 .92291 m .09423 .92298 L .0903 .9225 L p F P
0 g
s
.862 .45 .245 r
.0903 .9225 m .08942 .92048 L .0942 .92291 L p F P
0 g
s
.761 .709 .803 r
.25702 .93754 m .25775 .93696 L .26471 .93871 L p F P
0 g
s
.748 .696 .802 r
.26817 .92885 m .25775 .93696 L .26471 .93871 L p F P
0 g
s
.748 .696 .802 r
.26471 .93871 m .27147 .93371 L .26817 .92885 L p F P
0 g
s
.832 .388 .175 r
.10186 .93002 m .09689 .92765 L .09423 .92298 L p F P
0 g
s
.832 .388 .176 r
.09689 .92765 m .09423 .92298 L .0903 .9225 L p F P
0 g
s
.523 .548 .823 r
.69192 .74869 m .6908 .74626 L .69432 .74653 L closepath p F P
0 g
s
.518 .537 .815 r
.69192 .74869 m .69432 .74653 L p .70251 .75349 L F P
0 g
s
.638 .592 .785 r
.52844 .92523 m .51716 .9287 L .51413 .92186 L p F P
0 g
s
.63 .629 .831 r
.56313 .94331 m .55178 .94613 L .54879 .94068 L p F P
0 g
s
.633 .77 .946 r
.17772 .95721 m .18841 .9542 L .19195 .95705 L p F P
0 g
s
.649 .77 .937 r
.18841 .9542 m .17772 .95721 L .17414 .95465 L p F P
0 g
s
.816 .35 .111 r
.25527 .71603 m .25024 .71344 L .24744 .70905 L p F P
0 g
s
.831 .369 .114 r
.24283 .70632 m .24744 .70905 L .25024 .71344 L p F P
0 g
s
.555 0 0 r
.24119 .70479 m .24283 .70632 L .24744 .70905 L p F P
0 g
s
.49 .484 .777 r
.72519 .78423 m .71717 .78231 L .71632 .78006 L p F P
0 g
s
.755 .628 .719 r
.32573 .87526 m .3246 .87245 L .32255 .87479 L closepath p F P
0 g
s
.592 .677 .9 r
.61952 .70071 m .61846 .70087 L .61558 .69672 L p F P
0 g
s
.635 .62 .817 r
.54579 .93489 m .54624 .93575 L .53479 .93856 L p F P
0 g
s
.635 .62 .817 r
.53479 .93856 m .53448 .93796 L .54579 .93489 L p F P
0 g
s
.776 .625 .693 r
.3159 .83412 m .32403 .83562 L .31933 .84242 L p F P
0 g
s
.762 .607 .686 r
.32023 .82743 m .3159 .83412 L .32403 .83562 L p F P
0 g
s
.901 .68 .593 r
.06207 .87254 m .06646 .87516 L .06515 .88096 L p F P
0 g
s
.897 .693 .619 r
.06646 .87516 m .06207 .87254 L .06379 .86664 L p F P
0 g
s
.576 .426 .641 r
.4996 .78664 m .49854 .78016 L .5096 .77676 L p F P
0 g
s
.573 .419 .634 r
.50861 .77035 m .5096 .77676 L .49854 .78016 L p F P
0 g
s
.721 .759 .883 r
.21205 .95323 m .20624 .95601 L .20274 .95288 L p F P
0 g
s
.68 .764 .914 r
.19195 .95705 m .20274 .95288 L .20624 .95601 L p F P
0 g
s
.628 .712 .907 r
.58337 .9545 m .59478 .95183 L .59769 .95552 L p F P
0 g
s
.629 .683 .882 r
.59398 .9507 m .59478 .95183 L .58337 .9545 L p F P
0 g
s
.629 .683 .882 r
.58337 .9545 m .58307 .95406 L .59398 .9507 L p F P
0 g
s
.782 .787 .857 r
.14606 .71662 m .14446 .71781 L .14084 .71471 L p F P
0 g
s
.821 .608 .615 r
.28752 .75635 m .28236 .75465 L p .28703 .76261 L F P
0 g
s
.821 .608 .615 r
.28703 .76261 m .28807 .75913 L .28752 .75635 L p F P
0 g
s
.881 .747 .71 r
.06496 .82758 m .0636 .83005 L .0599 .82659 L p F P
0 g
s
.881 .747 .71 r
.0599 .82659 m .0609 .82478 L .06496 .82758 L p F P
0 g
s
.875 .751 .722 r
.06496 .82758 m .0609 .82478 L .06478 .81828 L p F P
0 g
s
.633 .605 .804 r
.54579 .93489 m .53448 .93796 L .53146 .93178 L p F P
0 g
s
.839 .782 .797 r
.0939 .76423 m .08819 .77052 L .08447 .76749 L p F P
0 g
s
.839 .782 .797 r
.08447 .76749 m .09014 .76125 L .0939 .76423 L p F P
0 g
s
.836 .782 .801 r
.09594 .755 m .09014 .76125 L .0939 .76423 L p F P
0 g
s
.49 .484 .777 r
.71632 .78006 m .72086 .77617 L p .72519 .78423 L F P
0 g
s
.495 .496 .787 r
.71632 .78006 m .71424 .77481 L .72086 .77617 L closepath p F P
0 g
s
.642 .567 .755 r
.50695 .904 m .50805 .90692 L .49681 .91108 L p F P
0 g
s
.642 .567 .755 r
.49681 .91108 m .49499 .90634 L .50695 .904 L p F P
0 g
s
.874 .759 .733 r
.06494 .80887 m .06891 .81172 L .06478 .81828 L p F P
0 g
s
.869 .761 .741 r
.06844 .8036 m .06494 .80887 L .06891 .81172 L p F P
0 g
s
.691 .762 .906 r
.20274 .95288 m .19195 .95705 L .18841 .9542 L p F P
0 g
s
.761 .645 .733 r
.31641 .89238 m .3178 .89087 L .31554 .89048 L closepath p F P
0 g
s
.761 .644 .731 r
.31325 .88537 m .31613 .88209 L p .3178 .89087 L F P
0 g
s
.761 .644 .731 r
.3178 .89087 m .31554 .89048 L .31325 .88537 L p F P
0 g
s
.755 .657 .753 r
.30655 .9067 m .30512 .90388 L .30281 .90608 L closepath p F P
0 g
s
.432 .342 .653 r
.73873 .85338 m .73645 .85128 L .73807 .85017 L closepath p F P
0 g
s
.445 .365 .672 r
.73645 .85128 m .73807 .85017 L .73649 .84328 L p F P
0 g
s
.495 .311 .561 r
.51728 .74832 m .52553 .74488 L .52226 .74042 L p F P
0 g
s
.499 .312 .559 r
.52727 .73837 m .52226 .74042 L .52553 .74488 L p F P
0 g
s
.508 .338 .586 r
.51781 .75423 m .51728 .74832 L .52553 .74488 L p F P
0 g
s
.754 .626 .718 r
.32255 .87479 m .3246 .87245 L .32226 .86654 L p F P
0 g
s
.766 .628 .708 r
.32149 .86458 m .32573 .85915 L .31892 .85795 L closepath p F P
0 g
s
.766 .627 .705 r
.31838 .85652 m .32262 .85076 L p .32573 .85915 L F P
0 g
s
.766 .627 .705 r
.32573 .85915 m .31892 .85795 L .31838 .85652 L p F P
0 g
s
.782 .787 .857 r
.14084 .71471 m .14238 .71357 L .14606 .71662 L p F P
0 g
s
.78 .787 .859 r
.1519 .7066 m .14238 .71357 L .14606 .71662 L p F P
0 g
s
.78 .787 .859 r
.14606 .71662 m .1555 .70971 L .1519 .7066 L p F P
0 g
s
.548 .389 .617 r
.50778 .76411 m .5185 .76032 L p .5144 .76827 L F P
0 g
s
.548 .389 .617 r
.5144 .76827 m .50828 .76796 L .50778 .76411 L p F P
0 g
s
.541 .374 .603 r
.51781 .75423 m .5185 .76032 L .50778 .76411 L p F P
0 g
s
.431 .356 .671 r
.73911 .84138 m .73649 .84328 L .73807 .85017 L p F P
0 g
s
.634 .509 .693 r
.47551 .84521 m .48242 .84184 L .47501 .84327 L closepath p F P
0 g
s
.781 .625 .687 r
.31234 .82584 m .32023 .82743 L .3159 .83412 L p F P
0 g
s
.767 .607 .68 r
.31632 .81926 m .31234 .82584 L .32023 .82743 L p F P
0 g
s
.753 .641 .737 r
.31043 .89843 m .31641 .89238 L .31554 .89048 L p F P
0 g
s
.649 .531 .706 r
.47908 .85819 m .47855 .85633 L .47345 .85908 L closepath p F P
0 g
s
.647 .527 .704 r
.477 .85069 m .47855 .85633 L .47345 .85908 L p F P
0 g
s
.618 .485 .678 r
.48188 .81947 m .49364 .81683 L p .48859 .82535 L F P
0 g
s
.618 .485 .678 r
.48859 .82535 m .48348 .82651 L .48188 .81947 L p F P
0 g
s
.62 .484 .675 r
.49209 .80985 m .49364 .81683 L .48188 .81947 L p F P
0 g
s
.62 .484 .675 r
.48792 .81078 m .49209 .80985 L p .48188 .81947 L F P
0 g
s
.598 .674 .894 r
.61952 .70071 m .62998 .69914 L .6271 .69467 L p F P
0 g
s
.598 .674 .894 r
.6271 .69467 m .6261 .69484 L .61952 .70071 L p F P
0 g
s
.592 .677 .9 r
.61558 .69672 m .6261 .69484 L .61952 .70071 L p F P
0 g
s
.626 .681 .882 r
.59185 .94768 m .59398 .9507 L .58307 .95406 L p F P
0 g
s
.626 .681 .882 r
.58307 .95406 m .58044 .95027 L .59185 .94768 L p F P
0 g
s
.765 .695 .785 r
.27583 .93012 m .27147 .93371 L .26817 .92885 L p F P
0 g
s
.743 .725 .835 r
.23152 .94825 m .23745 .94441 L .24453 .94612 L p F P
0 g
s
.733 .721 .84 r
.24257 .94113 m .23745 .94441 L .24453 .94612 L p F P
0 g
s
.733 .721 .84 r
.24453 .94612 m .24594 .94527 L .24257 .94113 L p F P
0 g
s
.882 .54 .396 r
.262 .72335 m .26047 .72255 L .26164 .72154 L closepath p F P
0 g
s
.422 .742 .993 r
.15564 .95398 m .15997 .95399 L .15634 .95163 L p F P
0 g
s
.422 .742 .993 r
.15634 .95163 m .15005 .95184 L .15564 .95398 L p F P
0 g
s
.283 .697 .971 r
.14593 .9518 m .15005 .95184 L .15564 .95398 L p F P
0 g
s
.754 .626 .718 r
.32014 .86621 m .31413 .8734 L .32255 .87479 L p F P
0 g
s
.754 .626 .718 r
.32226 .86654 m .32014 .86621 L p .32255 .87479 L F P
0 g
s
.766 .642 .725 r
.31413 .8734 m .32255 .87479 L .31613 .88209 L p F P
0 g
s
.638 .517 .7 r
.477 .85069 m .47551 .84521 L .48242 .84184 L p F P
0 g
s
.522 .549 .824 r
.69432 .74653 m .6908 .74626 L .68791 .74008 L p F P
0 g
s
.541 .58 .843 r
.68016 .72816 m .67044 .72807 L .6676 .72251 L p F P
0 g
s
.786 .624 .68 r
.30868 .8176 m .31632 .81926 L .31234 .82584 L p F P
0 g
s
.783 .615 .671 r
.31632 .81926 m .30868 .8176 L .31232 .81112 L p F P
0 g
s
.817 .603 .614 r
.28881 .76316 m .28807 .75913 L .28703 .76261 L closepath p F P
0 g
s
.585 .915 .973 r
.65245 .95093 m .65477 .95156 L .66625 .94734 L p F P
0 g
s
.765 .695 .785 r
.26817 .92885 m .26867 .92842 L .27583 .93012 L p F P
0 g
s
.752 .683 .784 r
.27821 .92025 m .26867 .92842 L .27583 .93012 L p F P
0 g
s
.752 .683 .784 r
.28023 .92065 m .27821 .92025 L p .27583 .93012 L F P
0 g
s
.752 .683 .784 r
.27583 .93012 m .28264 .92458 L .28023 .92065 L p F P
0 g
s
.753 .641 .737 r
.3094 .88948 m .30247 .89693 L .31043 .89843 L p F P
0 g
s
.753 .641 .737 r
.31554 .89048 m .3094 .88948 L p .31043 .89843 L F P
0 g
s
.765 .653 .738 r
.31043 .89843 m .30512 .90388 L .30193 .89751 L p F P
0 g
s
.765 .653 .738 r
.30193 .89751 m .30247 .89693 L .31043 .89843 L p F P
0 g
s
0 .398 .81 r
.23411 .7006 m .22713 .69762 L .23144 .70046 L p F P
0 g
s
.315 .644 .967 r
.2238 .6971 m .22713 .69762 L .23144 .70046 L p F P
0 g
s
.643 .567 .754 r
.50501 .89883 m .50695 .904 L .49499 .90634 L p F P
0 g
s
.643 .567 .754 r
.49499 .90634 m .49376 .90313 L .50501 .89883 L p F P
0 g
s
.752 .707 .81 r
.25702 .93754 m .24594 .94527 L .24257 .94113 L p F P
0 g
s
.891 .731 .677 r
.05844 .84022 m .06257 .84297 L .05981 .84916 L p F P
0 g
s
.886 .737 .69 r
.06257 .84297 m .05844 .84022 L .06152 .83395 L p F P
0 g
s
.552 .75 .969 r
.20966 .69588 m .22028 .69421 L .2238 .6971 L p F P
0 g
s
.543 .744 .969 r
.22028 .69421 m .20966 .69588 L .20614 .69279 L p F P
0 g
s
.668 .773 .928 r
.19538 .69677 m .20614 .69279 L .20966 .69588 L p F P
0 g
s
.758 .642 .733 r
.31554 .89048 m .31325 .88537 L .3094 .88948 L closepath p F P
0 g
s
.666 .772 .929 r
.20614 .69279 m .19538 .69677 L .19184 .69362 L p F P
0 g
s
.715 .779 .902 r
.18099 .69899 m .19184 .69362 L .19538 .69677 L p F P
0 g
s
.862 .769 .758 r
.07046 .79251 m .07434 .79541 L .06939 .80221 L p F P
0 g
s
.859 .771 .764 r
.07434 .79541 m .07046 .79251 L .07563 .78564 L p F P
0 g
s
.763 .256 0 r
.11054 .93685 m .1056 .93448 L .10186 .93002 L p F P
0 g
s
.755 .241 0 r
.09689 .92765 m .10186 .93002 L .1056 .93448 L p F P
0 g
s
.843 .781 .791 r
.08731 .77152 m .08819 .77052 L .08447 .76749 L p F P
0 g
s
.9 .697 .62 r
.05948 .86397 m .06379 .86664 L .06207 .87254 L p F P
0 g
s
.895 .707 .641 r
.06379 .86664 m .05948 .86397 L .06158 .85796 L p F P
0 g
s
.53 .556 .826 r
.68791 .74008 m .68491 .73992 L .68698 .7381 L closepath p F P
0 g
s
.536 .565 .831 r
.68504 .7341 m .68698 .7381 L .68491 .73992 L p F P
0 g
s
.323 .124 .447 r
.7333 .89313 m .72478 .89829 L .72468 .90348 L p F P
0 g
s
.341 .137 .451 r
.72142 .90535 m .72468 .90348 L .72478 .89829 L p F P
0 g
s
.359 .184 .503 r
.72478 .89829 m .7333 .89313 L .73352 .88738 L p F P
0 g
s
.771 .628 .702 r
.31838 .85652 m .32262 .85076 L .31572 .84945 L closepath p F P
0 g
s
.771 .626 .699 r
.31528 .84827 m .31933 .84242 L p .32262 .85076 L F P
0 g
s
.771 .626 .699 r
.32262 .85076 m .31572 .84945 L .31528 .84827 L p F P
0 g
s
.884 .746 .705 r
.06152 .83395 m .0636 .83005 L .0599 .82659 L p F P
0 g
s
.792 .624 .674 r
.30495 .80937 m .31232 .81112 L .30868 .8176 L p F P
0 g
s
.79 .615 .664 r
.31232 .81112 m .30495 .80937 L .30826 .803 L p F P
0 g
s
.843 .781 .791 r
.08447 .76749 m .08354 .76855 L .08731 .77152 L p F P
0 g
s
.849 .779 .784 r
.08354 .76855 m .08731 .77152 L .08134 .77862 L p F P
0 g
s
.759 .626 .713 r
.32226 .86654 m .32149 .86458 L .32014 .86621 L closepath p F P
0 g
s
.638 .517 .7 r
.48707 .84096 m .48905 .84837 L .477 .85069 L p F P
0 g
s
.638 .517 .7 r
.48242 .84184 m .48707 .84096 L p .477 .85069 L F P
0 g
s
.636 .517 .701 r
.47855 .85633 m .477 .85069 L .48905 .84837 L p F P
0 g
s
.433 0 0 r
.11102 .93729 m .11255 .93779 L p .12197 .94293 L F P
0 g
s
.685 .138 0 r
.11102 .93729 m .11054 .93685 L .11255 .93779 L closepath p F P
0 g
s
.754 .655 .751 r
.30281 .90608 m .30512 .90388 L .30193 .89751 L p F P
0 g
s
.858 .49 .353 r
.26047 .72255 m .25674 .72084 L .25527 .71603 L p F P
0 g
s
.87 .503 .351 r
.25024 .71344 m .25527 .71603 L .25674 .72084 L p F P
0 g
s
.495 .496 .788 r
.72086 .77617 m .71424 .77481 L .71272 .77096 L p F P
0 g
s
.641 .558 .746 r
.50383 .89554 m .50501 .89883 L .49376 .90313 L p F P
0 g
s
.641 .558 .746 r
.49376 .90313 m .49185 .89787 L .50383 .89554 L p F P
0 g
s
.765 .671 .758 r
.29481 .90459 m .30281 .90608 L .29468 .91385 L p F P
0 g
s
.754 .655 .751 r
.30193 .89751 m .29481 .90459 L .30281 .90608 L p F P
0 g
s
.764 .686 .776 r
.28264 .92458 m .28567 .92187 L .28023 .92065 L closepath p F P
0 g
s
.624 .717 .913 r
.60913 .95281 m .59769 .95552 L .59478 .95183 L p F P
0 g
s
.625 .746 .934 r
.59769 .95552 m .60913 .95281 L .612 .95597 L p F P
0 g
s
.765 .685 .774 r
.29326 .91356 m .29386 .91464 L .28567 .92187 L p F P
0 g
s
.765 .685 .774 r
.28678 .91234 m .29326 .91356 L p .28567 .92187 L F P
0 g
s
.765 .685 .774 r
.27938 .91925 m .28678 .91234 L p .28567 .92187 L F P
0 g
s
.765 .685 .774 r
.28567 .92187 m .28023 .92065 L .27938 .91925 L p F P
0 g
s
.574 .639 .878 r
.64443 .70242 m .64499 .70335 L .6398 .70801 L p F P
0 g
s
.574 .639 .878 r
.63285 .70373 m .64443 .70242 L p .6398 .70801 L F P
0 g
s
.571 .626 .868 r
.64731 .70735 m .6398 .70801 L .64499 .70335 L closepath p F P
0 g
s
.601 .461 .664 r
.49189 .80892 m .4907 .80303 L .50212 .80002 L p F P
0 g
s
.6 .458 .66 r
.50081 .79328 m .50212 .80002 L .4907 .80303 L p F P
0 g
s
.615 .472 .664 r
.4907 .80303 m .49189 .80892 L .48792 .81078 L p F P
0 g
s
.758 .625 .712 r
.32014 .86621 m .32149 .86458 L .31892 .85795 L p F P
0 g
s
0 0 0 r
.67847 .94246 m .68032 .94143 L .68996 .93626 L p F P
0 g
s
.797 .617 .657 r
.30826 .803 m .30114 .80116 L .30414 .79489 L p F P
0 g
s
.798 .625 .667 r
.30114 .80116 m .30826 .803 L .30495 .80937 L p F P
0 g
s
.35 .724 .986 r
.15005 .95184 m .14593 .9518 L .14225 .94979 L p F P
0 g
s
.765 .672 .76 r
.29386 .91464 m .29468 .91385 L .29326 .91356 L closepath p F P
0 g
s
.765 .671 .758 r
.29064 .90878 m .29481 .90459 L p .29468 .91385 L F P
0 g
s
.765 .671 .758 r
.29468 .91385 m .29326 .91356 L .29064 .90878 L p F P
0 g
s
.746 .783 .883 r
.16649 .70238 m .17558 .69693 L .17932 .69998 L p F P
0 g
s
.745 .783 .884 r
.17742 .69584 m .17558 .69693 L .17932 .69998 L p F P
0 g
s
.745 .783 .884 r
.17932 .69998 m .18099 .69899 L .17742 .69584 L p F P
0 g
s
.457 .414 .721 r
.74131 .82229 m .73395 .81875 L .7391 .81479 L closepath p F P
0 g
s
.467 .428 .731 r
.73821 .81195 m .7391 .81479 L .73395 .81875 L p F P
0 g
s
.467 .428 .731 r
.73305 .80978 m .73821 .81195 L p .73395 .81875 L F P
0 g
s
.635 .578 .773 r
.51413 .92186 m .51615 .92123 L .51406 .9217 L closepath p F P
0 g
s
.638 .592 .785 r
.52576 .91912 m .52844 .92523 L p .51413 .92186 L F P
0 g
s
.638 .592 .785 r
.51413 .92186 m .51615 .92123 L .52576 .91912 L p F P
0 g
s
.635 .578 .773 r
.51615 .92123 m .51406 .9217 L .51109 .91459 L p F P
0 g
s
.765 .644 .727 r
.31325 .88537 m .31613 .88209 L .31141 .88122 L closepath p F P
0 g
s
.766 .642 .725 r
.3101 .87824 m .31413 .8734 L p .31613 .88209 L F P
0 g
s
.766 .642 .725 r
.31613 .88209 m .31141 .88122 L .3101 .87824 L p F P
0 g
s
.618 .478 .669 r
.49209 .80985 m .49189 .80892 L .48792 .81078 L closepath p F P
0 g
s
.766 .787 .87 r
.159 .70735 m .1555 .70971 L .1519 .7066 L p F P
0 g
s
.77 .642 .719 r
.31184 .86478 m .32014 .86621 L .31413 .8734 L p F P
0 g
s
.758 .625 .712 r
.31746 .8577 m .31184 .86478 L .32014 .86621 L p F P
0 g
s
.758 .625 .712 r
.31892 .85795 m .31746 .8577 L p .32014 .86621 L F P
0 g
s
.65 .747 .921 r
.58693 .69549 m .59834 .692 L .60123 .69541 L p F P
0 g
s
.669 .78 .932 r
.59834 .692 m .58693 .69549 L .58405 .69304 L p F P
0 g
s
.69 .827 .949 r
.57268 .69772 m .58405 .69304 L .58693 .69549 L p F P
0 g
s
.643 .559 .745 r
.50196 .89031 m .50383 .89554 L .49185 .89787 L p F P
0 g
s
.643 .559 .745 r
.49185 .89787 m .49072 .89476 L .50196 .89031 L p F P
0 g
s
.639 .525 .708 r
.47908 .85819 m .47855 .85633 L .48977 .85106 L p F P
0 g
s
.636 .517 .701 r
.48905 .84837 m .48977 .85106 L .47855 .85633 L p F P
0 g
s
.775 .627 .696 r
.31528 .84827 m .31933 .84242 L .31264 .84106 L closepath p F P
0 g
s
.776 .625 .693 r
.31219 .83981 m .3159 .83412 L p .31933 .84242 L F P
0 g
s
.776 .625 .693 r
.31933 .84242 m .31264 .84106 L .31219 .83981 L p F P
0 g
s
.804 .625 .66 r
.29728 .79296 m .30414 .79489 L .30114 .80116 L p F P
0 g
s
.805 .618 .649 r
.30414 .79489 m .29728 .79296 L .29997 .78679 L p F P
0 g
s
.25 0 .296 r
.71435 .91682 m .71798 .91195 L .71489 .91368 L closepath p F P
0 g
s
.305 .071 .384 r
.71489 .91368 m .71798 .91195 L .72142 .90535 L p F P
0 g
s
.629 .664 .865 r
.5661 .94832 m .57748 .94566 L .58044 .95027 L p F P
0 g
s
.627 .645 .849 r
.57452 .94068 m .57748 .94566 L .5661 .94832 L p F P
0 g
s
.627 .645 .849 r
.57017 .94169 m .57452 .94068 L p .5661 .94832 L F P
0 g
s
.627 .645 .849 r
.5661 .94832 m .56337 .94372 L .57017 .94169 L p F P
0 g
s
.826 .619 .622 r
.29149 .77063 m .29041 .77026 L .28881 .76316 L p F P
0 g
s
.815 .612 .627 r
.28703 .76261 m .28881 .76316 L .29041 .77026 L p F P
0 g
s
.382 .228 .545 r
.7333 .88146 m .73249 .88196 L .73352 .88738 L p F P
0 g
s
.619 .489 .682 r
.4837 .82744 m .48859 .82535 L .48348 .82651 L closepath p F P
0 g
s
.636 .525 .71 r
.47908 .85819 m .49114 .85589 L p .48567 .86497 L F P
0 g
s
.636 .525 .71 r
.48567 .86497 m .48131 .86582 L .47908 .85819 L p F P
0 g
s
.639 .525 .708 r
.48977 .85106 m .49114 .85589 L .47908 .85819 L p F P
0 g
s
.404 .289 .608 r
.74061 .86331 m .73641 .8661 L .73943 .87098 L p F P
0 g
s
.42 .317 .631 r
.73641 .8661 m .74061 .86331 L .73945 .85685 L p F P
0 g
s
.721 .759 .883 r
.20274 .95288 m .20588 .95127 L .21205 .95323 L p F P
0 g
s
.707 .747 .883 r
.21367 .94732 m .20588 .95127 L .21205 .95323 L p F P
0 g
s
.707 .747 .883 r
.21205 .95323 m .21712 .95084 L .21367 .94732 L p F P
0 g
s
.714 .78 .903 r
.19184 .69362 m .18099 .69899 L .17742 .69584 L p F P
0 g
s
.548 .393 .623 r
.50861 .77035 m .50828 .76796 L .5144 .76827 L closepath p F P
0 g
s
.759 .669 .763 r
.29326 .91356 m .29064 .90878 L .28678 .91234 L closepath p F P
0 g
s
.495 .496 .788 r
.71272 .77096 m .71568 .76835 L p .72086 .77617 L F P
0 g
s
.5 .509 .797 r
.71272 .77096 m .71132 .76758 L .71568 .76835 L closepath p F P
0 g
s
.431 .356 .671 r
.73807 .85017 m .74439 .84562 L .73911 .84138 L p F P
0 g
s
.42 .334 .652 r
.73807 .85017 m .74439 .84562 L p .74108 .85569 L F P
0 g
s
.42 .334 .652 r
.74108 .85569 m .73873 .85338 L .73807 .85017 L p F P
0 g
s
.64 .55 .737 r
.50094 .88728 m .50196 .89031 L .49072 .89476 L p F P
0 g
s
.64 .55 .737 r
.49072 .89476 m .48894 .88962 L .50094 .88728 L p F P
0 g
s
0 .321 .678 r
.12707 .94523 m .12837 .94583 L .12462 .94406 L p F P
0 g
s
0 .321 .678 r
.12462 .94406 m .12197 .94293 L .12707 .94523 L p F P
0 g
s
.622 .496 .688 r
.48524 .8337 m .4837 .82744 L .48859 .82535 L p F P
0 g
s
.81 .625 .651 r
.29432 .78509 m .29997 .78679 L .29728 .79296 L p F P
0 g
s
.812 .62 .643 r
.29388 .78345 m .29575 .7787 L p .29997 .78679 L F P
0 g
s
.812 .62 .643 r
.29997 .78679 m .29432 .78509 L .29388 .78345 L p F P
0 g
s
.757 .64 .732 r
.3094 .88948 m .31325 .88537 L .31141 .88122 L p F P
0 g
s
.594 .864 .994 r
.65205 .95079 m .64056 .95431 L .63778 .95253 L p F P
0 g
s
.602 .845 .99 r
.62629 .95564 m .63778 .95253 L .64056 .95431 L p F P
0 g
s
.587 .886 .991 r
.65245 .95093 m .65205 .95079 L .64056 .95431 L p F P
0 g
s
.875 .577 .479 r
.26745 .73106 m .26225 .72855 L .262 .72335 L p F P
0 g
s
.885 .586 .475 r
.26047 .72255 m .262 .72335 L .26225 .72855 L p F P
0 g
s
.619 .79 .964 r
.612 .95597 m .62346 .95312 L .62629 .95564 L p F P
0 g
s
.622 .756 .942 r
.62346 .95312 m .612 .95597 L .60913 .95281 L p F P
0 g
s
.37 .151 .446 r
.54548 .71891 m .53748 .72328 L .53718 .7283 L p F P
0 g
s
.307 .046 .344 r
.54725 .71643 m .54784 .71366 L p .53748 .72328 L F P
0 g
s
.307 .046 .344 r
.53748 .72328 m .54548 .71891 L .54725 .71643 L p F P
0 g
s
.621 .701 .902 r
.60123 .69541 m .61269 .69275 L .61558 .69672 L p F P
0 g
s
.633 .72 .91 r
.61269 .69275 m .60123 .69541 L .59834 .692 L p F P
0 g
s
.898 .712 .642 r
.05735 .85526 m .06158 .85796 L .05948 .86397 L p F P
0 g
s
.893 .72 .66 r
.06158 .85796 m .05735 .85526 L .05981 .84916 L p F P
0 g
s
.58 .435 .648 r
.50009 .7894 m .4996 .78664 L .51068 .78326 L p F P
0 g
s
.576 .426 .641 r
.5096 .77676 m .51068 .78326 L .4996 .78664 L p F P
0 g
s
.763 .625 .707 r
.31892 .85795 m .31838 .85652 L .31746 .8577 L closepath p F P
0 g
s
.818 .625 .642 r
.29388 .78345 m .29575 .7787 L .29226 .77758 L closepath p F P
0 g
s
.819 .62 .634 r
.29092 .77223 m .29149 .77063 L p .29575 .7787 L F P
0 g
s
.819 .62 .634 r
.29575 .7787 m .29226 .77758 L .29092 .77223 L p F P
0 g
s
.642 .55 .736 r
.49892 .88131 m .50094 .88728 L .48894 .88962 L p F P
0 g
s
.642 .55 .736 r
.48894 .88962 m .48767 .88593 L .49892 .88131 L p F P
0 g
s
.752 .731 .832 r
.23745 .94441 m .23152 .94825 L .22811 .94445 L p F P
0 g
s
.733 .738 .855 r
.21712 .95084 m .22811 .94445 L .23152 .94825 L p F P
0 g
s
.282 .624 .961 r
.22713 .69762 m .2238 .6971 L .22028 .69421 L p F P
0 g
s
.878 .756 .724 r
.0608 .81544 m .06478 .81828 L .0609 .82478 L p F P
0 g
s
.874 .759 .733 r
.06478 .81828 m .0608 .81544 L .06494 .80887 L p F P
0 g
s
.636 .526 .712 r
.48159 .86678 m .48567 .86497 L .48131 .86582 L closepath p F P
0 g
s
.766 .787 .87 r
.1519 .7066 m .15533 .70428 L .159 .70735 L p F P
0 g
s
.764 .787 .871 r
.1629 .69926 m .15533 .70428 L .159 .70735 L p F P
0 g
s
.764 .787 .871 r
.159 .70735 m .16649 .70238 L .1629 .69926 L p F P
0 g
s
.78 .627 .69 r
.31219 .83981 m .3159 .83412 L .30967 .83277 L closepath p F P
0 g
s
.781 .625 .687 r
.3091 .83114 m .31234 .82584 L p .3159 .83412 L F P
0 g
s
.781 .625 .687 r
.3159 .83412 m .30967 .83277 L .3091 .83114 L p F P
0 g
s
.64 .534 .719 r
.4837 .87361 m .48159 .86678 L .48567 .86497 L p F P
0 g
s
.633 .605 .804 r
.53146 .93178 m .54278 .92868 L .54579 .93489 L p F P
0 g
s
.631 .594 .794 r
.54143 .92574 m .54278 .92868 L .53146 .93178 L p F P
0 g
s
.631 .594 .794 r
.53146 .93178 m .52998 .92858 L .54143 .92574 L p F P
0 g
s
.852 .778 .779 r
.08134 .77862 m .07657 .78445 L .07283 .78144 L p F P
0 g
s
.852 .778 .779 r
.07283 .78144 m .07756 .77566 L .08134 .77862 L p F P
0 g
s
.849 .779 .784 r
.08134 .77862 m .07756 .77566 L .08354 .76855 L p F P
0 g
s
.635 .578 .773 r
.52238 .91097 m .52541 .91831 L .51615 .92123 L p F P
0 g
s
.635 .578 .773 r
.51109 .91459 m .52238 .91097 L p .51615 .92123 L F P
0 g
s
.638 .587 .781 r
.52576 .91912 m .52541 .91831 L .51615 .92123 L closepath p F P
0 g
s
.762 .624 .706 r
.31746 .8577 m .31838 .85652 L .31572 .84945 L p F P
0 g
s
.862 .594 .532 r
.27262 .73887 m .26713 .73646 L .26745 .73106 L p F P
0 g
s
.873 .606 .53 r
.26225 .72855 m .26745 .73106 L .26713 .73646 L p F P
0 g
s
.56 .616 .866 r
.65855 .71189 m .65018 .71238 L .64731 .70735 L p F P
0 g
s
.296 .061 .378 r
.72468 .90348 m .72142 .90535 L .71798 .91195 L p F P
0 g
s
.615 .805 .973 r
.63778 .95253 m .62629 .95564 L .62346 .95312 L p F P
0 g
s
.639 .542 .728 r
.49823 .8792 m .49892 .88131 L .48767 .88593 L p F P
0 g
s
.639 .542 .728 r
.48767 .88593 m .48624 .88154 L .49823 .8792 L p F P
0 g
s
.581 .644 .878 r
.64443 .70242 m .63285 .70373 L .62998 .69914 L p F P
0 g
s
.768 .657 .739 r
.30142 .88797 m .3094 .88948 L .30247 .89693 L p F P
0 g
s
.757 .64 .732 r
.30797 .88063 m .30142 .88797 L .3094 .88948 L p F P
0 g
s
.757 .64 .732 r
.31141 .88122 m .30797 .88063 L p .3094 .88948 L F P
0 g
s
.825 .625 .633 r
.29092 .77223 m .29149 .77063 L .29041 .77026 L closepath p F P
0 g
s
.63 .629 .831 r
.54879 .94068 m .56014 .93786 L .56313 .94331 L p F P
0 g
s
.628 .616 .819 r
.55746 .93269 m .56014 .93786 L .54879 .94068 L p F P
0 g
s
.628 .616 .819 r
.54879 .94068 m .54624 .93575 L .55746 .93269 L p F P
0 g
s
.641 .542 .727 r
.49587 .87183 m .49823 .8792 L .48624 .88154 L p F P
0 g
s
.641 .542 .727 r
.48624 .88154 m .48463 .87661 L .49587 .87183 L p F P
0 g
s
.64 .534 .719 r
.49335 .86351 m .4957 .87127 L .4837 .87361 L p F P
0 g
s
.64 .534 .719 r
.48567 .86497 m .49335 .86351 L p .4837 .87361 L F P
0 g
s
.638 .534 .72 r
.48463 .87661 m .4837 .87361 L .4957 .87127 L p F P
0 g
s
.763 .713 .806 r
.25702 .93754 m .25775 .93696 L .25632 .93658 L closepath p F P
0 g
s
.752 .707 .81 r
.25632 .93658 m .25702 .93754 L p .24257 .94113 L F P
0 g
s
.638 .534 .72 r
.4957 .87127 m .49587 .87183 L .48463 .87661 L p F P
0 g
s
.764 .712 .803 r
.26773 .92818 m .26817 .92885 L .25775 .93696 L p F P
0 g
s
.764 .712 .803 r
.26127 .92677 m .26773 .92818 L p .25775 .93696 L F P
0 g
s
.764 .712 .803 r
.25369 .93299 m .26127 .92677 L p .25775 .93696 L F P
0 g
s
.764 .712 .803 r
.25775 .93696 m .25632 .93658 L .25369 .93299 L p F P
0 g
s
.848 .603 .567 r
.27757 .74674 m .2718 .74442 L .27262 .73887 L p F P
0 g
s
.86 .614 .565 r
.26713 .73646 m .27262 .73887 L .2718 .74442 L p F P
0 g
s
.889 .741 .691 r
.05746 .83115 m .06152 .83395 L .05844 .84022 L p F P
0 g
s
.884 .746 .705 r
.0599 .82659 m .05746 .83115 L .06152 .83395 L p F P
0 g
s
.776 .637 .708 r
.3093 .85621 m .31746 .8577 L .31184 .86478 L p F P
0 g
s
.762 .624 .706 r
.31456 .84925 m .3093 .85621 L .31746 .8577 L p F P
0 g
s
.762 .624 .706 r
.31572 .84945 m .31456 .84925 L p .31746 .8577 L F P
0 g
s
.815 .612 .627 r
.29041 .77026 m .28496 .76858 L .28703 .76261 L p F P
0 g
s
.827 .621 .625 r
.28068 .76049 m .28703 .76261 L .28496 .76858 L p F P
0 g
s
.821 .608 .615 r
.28236 .75465 m .28068 .76049 L .28703 .76261 L p F P
0 g
s
.9 .604 .475 r
.07777 .90523 m .07314 .90271 L .07296 .89731 L p F P
0 g
s
.904 .607 .472 r
.0684 .89477 m .07296 .89731 L .07314 .90271 L p F P
0 g
s
.902 .635 .523 r
.07296 .89731 m .0684 .89477 L .06877 .88922 L p F P
0 g
s
.365 .217 .543 r
.74148 .87612 m .7333 .88146 L .73378 .88722 L p F P
0 g
s
.388 .257 .578 r
.7333 .88146 m .74148 .87612 L .73943 .87098 L p F P
0 g
s
.382 .228 .545 r
.73352 .88738 m .73378 .88722 L .7333 .88146 L p F P
0 g
s
.636 .512 .695 r
.48707 .84096 m .48673 .83968 L .48242 .84184 L closepath p F P
0 g
s
.634 .507 .691 r
.48524 .8337 m .48673 .83968 L .48242 .84184 L p F P
0 g
s
.895 .564 .413 r
.08324 .91295 m .07855 .91047 L .07777 .90523 L p F P
0 g
s
.898 .565 .409 r
.07314 .90271 m .07777 .90523 L .07855 .91047 L p F P
0 g
s
.862 .769 .758 r
.06939 .80221 m .06551 .79932 L .07046 .79251 L p F P
0 g
s
.868 .767 .748 r
.06939 .80221 m .06844 .8036 L .06471 .80048 L p F P
0 g
s
.868 .767 .748 r
.06471 .80048 m .06551 .79932 L .06939 .80221 L p F P
0 g
s
.836 .608 .593 r
.28236 .75465 m .2763 .75244 L .27757 .74674 L p F P
0 g
s
.848 .619 .59 r
.2718 .74442 m .27757 .74674 L .2763 .75244 L p F P
0 g
s
.837 .621 .61 r
.2763 .75244 m .28236 .75465 L .28068 .76049 L p F P
0 g
s
.626 .924 .974 r
.57142 .69734 m .57268 .69772 L .58405 .69304 L p F P
0 g
s
.657 .101 0 r
.11054 .93685 m .11102 .93729 L .10721 .93589 L p F P
0 g
s
.657 .101 0 r
.10721 .93589 m .1056 .93448 L .11054 .93685 L p F P
0 g
s
.5 .509 .798 r
.71568 .76835 m .71132 .76758 L .70882 .76152 L p F P
0 g
s
.77 .643 .722 r
.3101 .87824 m .31413 .8734 L .30742 .87208 L closepath p F P
0 g
s
.77 .642 .719 r
.30695 .87098 m .31184 .86478 L p .31413 .8734 L F P
0 g
s
.77 .642 .719 r
.31413 .8734 m .30742 .87208 L .30695 .87098 L p F P
0 g
s
.786 .627 .684 r
.3091 .83114 m .31234 .82584 L .30682 .82457 L closepath p F P
0 g
s
.786 .624 .68 r
.30603 .82223 m .30868 .8176 L p .31234 .82584 L F P
0 g
s
.786 .624 .68 r
.31234 .82584 m .30682 .82457 L .30603 .82223 L p F P
0 g
s
.603 .468 .67 r
.49209 .80985 m .49189 .80892 L .50314 .80505 L p F P
0 g
s
.601 .461 .664 r
.50212 .80002 m .50314 .80505 L .49189 .80892 L p F P
0 g
s
.906 .638 .522 r
.06428 .88664 m .06877 .88922 L .0684 .89477 L p F P
0 g
s
.902 .66 .562 r
.06877 .88922 m .06428 .88664 L .06515 .88096 L p F P
0 g
s
.553 .406 .635 r
.5096 .77676 m .50861 .77035 L .5144 .76827 L p F P
0 g
s
.421 .334 .652 r
.73945 .85685 m .73873 .85338 L .74108 .85569 L closepath p F P
0 g
s
.522 .549 .824 r
.68791 .74008 m .69973 .74098 L p .69432 .74653 L F P
0 g
s
.52 .55 .827 r
.69685 .73488 m .69973 .74098 L .68791 .74008 L p F P
0 g
s
.52 .55 .827 r
.69085 .73442 m .69685 .73488 L p .68791 .74008 L F P
0 g
s
.52 .55 .827 r
.68791 .74008 m .68698 .7381 L .69085 .73442 L p F P
0 g
s
.622 .497 .689 r
.48673 .83968 m .48524 .8337 L .49699 .83106 L p F P
0 g
s
.622 .496 .688 r
.49524 .82387 m .49699 .83106 L .48524 .8337 L p F P
0 g
s
.622 .496 .688 r
.48859 .82535 m .49524 .82387 L p .48524 .8337 L F P
0 g
s
.883 .511 .333 r
.08942 .92048 m .0847 .91802 L .08324 .91295 L p F P
0 g
s
.885 .511 .326 r
.07855 .91047 m .08324 .91295 L .0847 .91802 L p F P
0 g
s
.518 .537 .815 r
.69432 .74653 m .70262 .74737 L p .70251 .75349 L F P
0 g
s
.516 .539 .818 r
.70262 .74737 m .69432 .74653 L .69993 .74141 L closepath p F P
0 g
s
.522 .549 .824 r
.69973 .74098 m .69993 .74141 L .69432 .74653 L p F P
0 g
s
.762 .641 .727 r
.31141 .88122 m .3101 .87824 L .30797 .88063 L closepath p F P
0 g
s
.871 .765 .743 r
.06494 .80887 m .06844 .8036 L .06471 .80048 L p F P
0 g
s
.812 .618 .64 r
.29041 .77026 m .28496 .76858 L p .28916 .77668 L F P
0 g
s
.812 .618 .64 r
.28916 .77668 m .29092 .77223 L .29041 .77026 L p F P
0 g
s
.634 .569 .764 r
.52203 .91009 m .52238 .91097 L .51109 .91459 L p F P
0 g
s
.634 .569 .764 r
.51109 .91459 m .51035 .91271 L .52203 .91009 L p F P
0 g
s
.581 .441 .655 r
.50081 .79328 m .50009 .7894 L .51135 .78704 L p F P
0 g
s
.58 .435 .648 r
.51068 .78326 m .51135 .78704 L .50009 .7894 L p F P
0 g
s
.605 .474 .675 r
.49364 .81683 m .49209 .80985 L .50352 .80686 L p F P
0 g
s
.603 .468 .67 r
.50314 .80505 m .50352 .80686 L .49209 .80985 L p F P
0 g
s
.767 .624 .701 r
.31572 .84945 m .31528 .84827 L .31456 .84925 L closepath p F P
0 g
s
.464 .429 .734 r
.73821 .81195 m .73305 .80978 L .73665 .80695 L closepath p F P
0 g
s
.473 .443 .743 r
.73516 .80245 m .73665 .80695 L .73305 .80978 L p F P
0 g
s
.473 .443 .743 r
.73129 .80104 m .73516 .80245 L p .73305 .80978 L F P
0 g
s
.752 .707 .81 r
.24257 .94113 m .25054 .93527 L .25632 .93658 L p F P
0 g
s
.751 .709 .812 r
.25632 .93658 m .25369 .93299 L .25054 .93527 L closepath p F P
0 g
s
.767 .623 .701 r
.31456 .84925 m .31528 .84827 L .31264 .84106 L p F P
0 g
s
.768 .657 .739 r
.29874 .89099 m .30142 .88797 L p .30247 .89693 L F P
0 g
s
.768 .657 .739 r
.30247 .89693 m .30155 .89675 L .29874 .89099 L p F P
0 g
s
.768 .658 .741 r
.30193 .89751 m .30247 .89693 L .30155 .89675 L closepath p F P
0 g
s
.809 .614 .639 r
.29226 .77758 m .29092 .77223 L .28916 .77668 L closepath p F P
0 g
s
.885 .586 .475 r
.26225 .72855 m .25886 .72679 L .26047 .72255 L p F P
0 g
s
.868 .562 .468 r
.25674 .72084 m .26047 .72255 L .25886 .72679 L p F P
0 g
s
.143 .601 .927 r
.13894 .9479 m .13842 .94766 L .12837 .94583 L p F P
0 g
s
.088 .585 .898 r
.13842 .94766 m .12837 .94583 L .12462 .94406 L p F P
0 g
s
.77 .67 .753 r
.30155 .89675 m .30193 .89751 L .29481 .90459 L p F P
0 g
s
.517 .358 .604 r
.5185 .76032 m .51781 .75423 L .52812 .74997 L p F P
0 g
s
.508 .338 .586 r
.52777 .74631 m .52812 .74997 L .51781 .75423 L p F P
0 g
s
.508 .338 .586 r
.52553 .74488 m .52777 .74631 L p .51781 .75423 L F P
0 g
s
.469 .29 .555 r
.52757 .74405 m .52727 .73837 L .53724 .73371 L p F P
0 g
s
.45 .251 .518 r
.53718 .7283 m .53724 .73371 L .52727 .73837 L p F P
0 g
s
.499 .312 .559 r
.52553 .74488 m .52757 .74405 L .52727 .73837 L p F P
0 g
s
.541 .58 .843 r
.6676 .72251 m .66769 .72244 L p .68016 .72816 L F P
0 g
s
.545 .589 .849 r
.6676 .72251 m .66756 .72244 L .66769 .72244 L closepath p F P
0 g
s
.757 .682 .779 r
.28023 .92065 m .27938 .91925 L .27821 .92025 L closepath p F P
0 g
s
.631 .594 .794 r
.53976 .92209 m .54143 .92574 L .52998 .92858 L p F P
0 g
s
.631 .594 .794 r
.52998 .92858 m .52844 .92523 L .53976 .92209 L p F P
0 g
s
.429 .356 .673 r
.74518 .83693 m .73911 .84138 L .74439 .84562 L p F P
0 g
s
.442 .377 .688 r
.74451 .8343 m .74518 .83693 L .73911 .84138 L p F P
0 g
s
.442 .377 .688 r
.7407 .83176 m .74451 .8343 L p .73911 .84138 L F P
0 g
s
.543 .593 .854 r
.66769 .72244 m .66756 .72244 L .6647 .71708 L p F P
0 g
s
.791 .627 .678 r
.30603 .82223 m .30868 .8176 L .30407 .81646 L closepath p F P
0 g
s
.792 .624 .674 r
.30297 .81307 m .30495 .80937 L p .30868 .8176 L F P
0 g
s
.792 .624 .674 r
.30868 .8176 m .30407 .81646 L .30297 .81307 L p F P
0 g
s
.635 .569 .763 r
.51934 .90322 m .52203 .91009 L .51035 .91271 L p F P
0 g
s
.635 .569 .763 r
.51035 .91271 m .50805 .90692 L .51934 .90322 L p F P
0 g
s
.752 .731 .832 r
.22811 .94445 m .23089 .94254 L .23745 .94441 L p F P
0 g
s
.74 .721 .834 r
.23919 .93693 m .23089 .94254 L .23745 .94441 L p F P
0 g
s
.74 .721 .834 r
.23745 .94441 m .24257 .94113 L .23919 .93693 L p F P
0 g
s
.433 0 0 r
.12197 .94293 m .11688 .94062 L .11102 .93729 L p F P
0 g
s
.456 0 0 r
.11688 .94062 m .11102 .93729 L .10721 .93589 L p F P
0 g
s
.574 .768 .971 r
.15997 .95399 m .17056 .95201 L .17414 .95465 L p F P
0 g
s
.596 .77 .963 r
.17056 .95201 m .15997 .95399 L .15634 .95163 L p F P
0 g
s
.541 .58 .843 r
.66769 .72244 m .67929 .72255 L p .68016 .72816 L F P
0 g
s
.54 .585 .848 r
.66769 .72244 m .67929 .72255 L .67642 .71697 L p F P
0 g
s
.54 .585 .848 r
.67642 .71697 m .67331 .71696 L .66769 .72244 L p F P
0 g
s
.543 .593 .854 r
.6647 .71708 m .67331 .71696 L .66769 .72244 L p F P
0 g
s
.906 .664 .562 r
.06075 .87834 m .06515 .88096 L .06428 .88664 L p F P
0 g
s
.901 .68 .593 r
.06515 .88096 m .06075 .87834 L .06207 .87254 L p F P
0 g
s
.739 .737 .849 r
.22811 .94445 m .21712 .95084 L .21367 .94732 L p F P
0 g
s
.767 .623 .701 r
.31147 .84084 m .30657 .84771 L .31456 .84925 L p F P
0 g
s
.767 .623 .701 r
.31264 .84106 m .31147 .84084 L p .31456 .84925 L F P
0 g
s
.779 .636 .702 r
.30657 .84771 m .31456 .84925 L .3093 .85621 L p F P
0 g
s
.855 .777 .774 r
.07563 .78564 m .07657 .78445 L .07283 .78144 L p F P
0 g
s
.763 .655 .742 r
.30155 .89675 m .29874 .89099 L .29446 .89543 L closepath p F P
0 g
s
.77 .67 .753 r
.29446 .89543 m .30155 .89675 L p .29481 .90459 L F P
0 g
s
.767 .699 .787 r
.26817 .92885 m .26867 .92842 L .26773 .92818 L closepath p F P
0 g
s
.891 .731 .677 r
.05981 .84916 m .05566 .84641 L .05844 .84022 L p F P
0 g
s
.896 .724 .661 r
.05566 .84641 m .05981 .84916 L .05735 .85526 L p F P
0 g
s
.624 .665 .869 r
.59185 .94768 m .58044 .95027 L .57748 .94566 L p F P
0 g
s
.768 .698 .785 r
.27068 .91863 m .27821 .92025 L .26867 .92842 L p F P
0 g
s
.768 .698 .785 r
.26487 .92386 m .27068 .91863 L p .26867 .92842 L F P
0 g
s
.768 .698 .785 r
.26867 .92842 m .26773 .92818 L .26487 .92386 L p F P
0 g
s
.861 .441 .225 r
.08942 .92048 m .0903 .9225 L .08638 .92173 L p F P
0 g
s
.861 .441 .225 r
.08638 .92173 m .0847 .91802 L .08942 .92048 L p F P
0 g
s
.621 .491 .683 r
.49524 .82387 m .49493 .82258 L .48859 .82535 L closepath p F P
0 g
s
.618 .485 .678 r
.49364 .81683 m .49493 .82258 L .48859 .82535 L p F P
0 g
s
.639 .53 .714 r
.49335 .86351 m .49282 .86175 L .48567 .86497 L closepath p F P
0 g
s
.636 .525 .71 r
.49114 .85589 m .49282 .86175 L .48567 .86497 L p F P
0 g
s
.761 .639 .727 r
.30797 .88063 m .3101 .87824 L .30742 .87208 L p F P
0 g
s
.599 .691 .907 r
.6261 .69484 m .61558 .69672 L .61269 .69275 L p F P
0 g
s
.769 .672 .755 r
.29064 .90878 m .29481 .90459 L .28746 .90297 L closepath p F P
0 g
s
.77 .67 .753 r
.28741 .90287 m .29446 .89543 L p .29481 .90459 L F P
0 g
s
.77 .67 .753 r
.29481 .90459 m .28746 .90297 L .28741 .90287 L p F P
0 g
s
.527 .562 .834 r
.68698 .7381 m .68504 .7341 L .69085 .73442 L closepath p F P
0 g
s
.861 .775 .765 r
.07184 .7827 m .07563 .78564 L .07046 .79251 L p F P
0 g
s
.855 .777 .774 r
.07283 .78144 m .07184 .7827 L .07563 .78564 L p F P
0 g
s
.747 .785 .884 r
.17558 .69693 m .16649 .70238 L .1629 .69926 L p F P
0 g
s
0 0 0 r
.68996 .93626 m .69149 .93552 L p .67847 .94246 L F P
0 g
s
0 0 0 r
.68996 .93626 m .69149 .93552 L .69174 .9352 L closepath p F P
0 g
s
.619 .067 0 r
.23765 .70273 m .23842 .70353 L .24283 .70632 L p F P
0 g
s
.831 .369 .114 r
.25024 .71344 m .24546 .71077 L .24283 .70632 L p F P
0 g
s
.843 .386 .115 r
.23842 .70353 m .24283 .70632 L .24546 .71077 L p F P
0 g
s
.797 .628 .672 r
.30297 .81307 m .30495 .80937 L .30144 .80845 L closepath p F P
0 g
s
.798 .625 .667 r
.29992 .80362 m .30114 .80116 L p .30495 .80937 L F P
0 g
s
.798 .625 .667 r
.30495 .80937 m .30144 .80845 L .29992 .80362 L p F P
0 g
s
.772 .623 .695 r
.31264 .84106 m .31219 .83981 L .31147 .84084 L closepath p F P
0 g
s
.624 .505 .696 r
.48707 .84096 m .48673 .83968 L .49798 .83505 L p F P
0 g
s
.622 .497 .689 r
.49699 .83106 m .49798 .83505 L .48673 .83968 L p F P
0 g
s
.771 .623 .695 r
.31147 .84084 m .31219 .83981 L .30967 .83277 L p F P
0 g
s
.758 .668 .762 r
.28678 .91234 m .29064 .90878 L .28746 .90297 L p F P
0 g
s
.805 .618 .649 r
.29226 .77758 m .28916 .77668 L p .29329 .7848 L F P
0 g
s
.805 .618 .649 r
.29329 .7848 m .29388 .78345 L .29226 .77758 L p F P
0 g
s
.768 .674 .76 r
.28678 .91234 m .27938 .91925 L .27612 .91381 L p F P
0 g
s
.768 .674 .76 r
.27612 .91381 m .27928 .91072 L .28678 .91234 L p F P
0 g
s
.758 .668 .762 r
.28733 .90295 m .27928 .91072 L .28678 .91234 L p F P
0 g
s
.758 .668 .762 r
.28746 .90297 m .28733 .90295 L p .28678 .91234 L F P
0 g
s
.406 .307 .63 r
.74108 .85569 m .73945 .85685 L .74061 .86331 L p F P
0 g
s
.775 .638 .71 r
.31184 .86478 m .30695 .87098 L .3038 .86357 L p F P
0 g
s
.775 .638 .71 r
.3038 .86357 m .3041 .86317 L .31184 .86478 L p F P
0 g
s
.776 .637 .708 r
.31184 .86478 m .3041 .86317 L .3093 .85621 L p F P
0 g
s
.773 .656 .733 r
.30001 .8791 m .30797 .88063 L .30142 .88797 L p F P
0 g
s
.761 .639 .727 r
.3062 .87186 m .30001 .8791 L .30797 .88063 L p F P
0 g
s
.761 .639 .727 r
.30742 .87208 m .3062 .87186 L p .30797 .88063 L F P
0 g
s
.757 .695 .792 r
.26773 .92818 m .26487 .92386 L .26127 .92677 L closepath p F P
0 g
s
.755 .68 .778 r
.27612 .91381 m .27068 .91863 L .27821 .92025 L p F P
0 g
s
.755 .68 .778 r
.27821 .92025 m .27938 .91925 L .27612 .91381 L p F P
0 g
s
.625 .507 .699 r
.48905 .84837 m .48707 .84096 L .49884 .83834 L p F P
0 g
s
.624 .505 .696 r
.49798 .83505 m .49884 .83834 L .48707 .84096 L p F P
0 g
s
.06 0 0 r
.70321 .92729 m .70312 .92749 L .69174 .9352 L p F P
0 g
s
0 0 0 r
.69149 .93552 m .69174 .9352 L .70312 .92749 L p F P
0 g
s
.583 .446 .66 r
.50212 .80002 m .50081 .79328 L .51189 .78989 L p F P
0 g
s
.581 .441 .655 r
.51135 .78704 m .51189 .78989 L .50081 .79328 L p F P
0 g
s
.456 .754 .993 r
.15005 .95184 m .15634 .95163 L .1527 .94918 L p F P
0 g
s
.456 .754 .993 r
.1527 .94918 m .1443 .94974 L .15005 .95184 L p F P
0 g
s
.35 .724 .986 r
.14225 .94979 m .1443 .94974 L .15005 .95184 L p F P
0 g
s
.783 .635 .697 r
.30366 .83924 m .31147 .84084 L .30657 .84771 L p F P
0 g
s
.771 .623 .695 r
.30822 .83247 m .30366 .83924 L .31147 .84084 L p F P
0 g
s
.771 .623 .695 r
.30967 .83277 m .30822 .83247 L p .31147 .84084 L F P
0 g
s
.905 .685 .595 r
.05774 .86988 m .06207 .87254 L .06075 .87834 L p F P
0 g
s
.9 .697 .62 r
.06207 .87254 m .05774 .86988 L .05948 .86397 L p F P
0 g
s
.5 .509 .798 r
.70882 .76152 m .70966 .76076 L p .71568 .76835 L F P
0 g
s
.505 .52 .806 r
.70882 .76152 m .70841 .76058 L .70966 .76076 L closepath p F P
0 g
s
.803 .628 .665 r
.29992 .80362 m .30114 .80116 L .29893 .80054 L closepath p F P
0 g
s
.804 .625 .66 r
.29688 .79382 m .29728 .79296 L p .30114 .80116 L F P
0 g
s
.804 .625 .66 r
.30114 .80116 m .29893 .80054 L .29688 .79382 L p F P
0 g
s
.731 .763 .878 r
.20588 .95127 m .20274 .95288 L .19925 .94967 L p F P
0 g
s
.691 .762 .906 r
.18841 .9542 m .19925 .94967 L .20274 .95288 L p F P
0 g
s
.633 .559 .754 r
.51865 .90138 m .51934 .90322 L .50805 .90692 L p F P
0 g
s
.633 .559 .754 r
.50805 .90692 m .50695 .904 L .51865 .90138 L p F P
0 g
s
.63 .584 .784 r
.53722 .91627 m .53976 .92209 L .52844 .92523 L p F P
0 g
s
.63 .584 .784 r
.52844 .92523 m .52576 .91912 L .53722 .91627 L p F P
0 g
s
.76 .712 .808 r
.25054 .93527 m .24257 .94113 L .23919 .93693 L p F P
0 g
s
.663 .769 .928 r
.18487 .95127 m .17414 .95465 L .17056 .95201 L p F P
0 g
s
.649 .77 .937 r
.17414 .95465 m .18487 .95127 L .18841 .9542 L p F P
0 g
s
.512 .527 .809 r
.70551 .75387 m .70251 .75349 L .70456 .75168 L closepath p F P
0 g
s
.518 .537 .815 r
.70262 .74737 m .70456 .75168 L .70251 .75349 L p F P
0 g
s
.776 .622 .689 r
.30967 .83277 m .3091 .83114 L .30822 .83247 L closepath p F P
0 g
s
.803 .615 .648 r
.29432 .78509 m .29388 .78345 L .29329 .7848 L closepath p F P
0 g
s
.47 .443 .746 r
.73516 .80245 m .73129 .80104 L .73398 .79887 L closepath p F P
0 g
s
.479 .457 .755 r
.73215 .79363 m .73398 .79887 L .73129 .80104 L p F P
0 g
s
.479 .457 .755 r
.72867 .79252 m .73215 .79363 L p .73129 .80104 L F P
0 g
s
.776 .622 .689 r
.30822 .83247 m .3091 .83114 L .30682 .82457 L p F P
0 g
s
.626 .644 .848 r
.56337 .94372 m .56313 .94331 L .57017 .94169 L closepath p F P
0 g
s
.504 .522 .808 r
.70966 .76076 m .70841 .76058 L .70551 .75387 L p F P
0 g
s
.884 .751 .71 r
.0609 .82478 m .0599 .82659 L .05617 .82328 L p F P
0 g
s
.884 .751 .71 r
.05617 .82328 m .05691 .82195 L .0609 .82478 L p F P
0 g
s
.878 .756 .724 r
.0609 .82478 m .05691 .82195 L .0608 .81544 L p F P
0 g
s
.605 .475 .677 r
.49493 .82258 m .49364 .81683 L .50507 .81384 L p F P
0 g
s
.605 .474 .675 r
.50352 .80686 m .50507 .81384 L .49364 .81683 L p F P
0 g
s
.628 .616 .819 r
.55715 .93208 m .55746 .93269 L .54624 .93575 L p F P
0 g
s
.628 .616 .819 r
.54624 .93575 m .54579 .93489 L .55715 .93208 L p F P
0 g
s
.81 .625 .651 r
.29728 .79296 m .29655 .79274 L .29432 .78509 L p F P
0 g
s
.802 .62 .656 r
.29329 .7848 m .29432 .78509 L .29655 .79274 L p F P
0 g
s
.876 .763 .734 r
.06105 .80598 m .06494 .80887 L .0608 .81544 L p F P
0 g
s
.871 .765 .743 r
.06471 .80048 m .06105 .80598 L .06494 .80887 L p F P
0 g
s
.181 0 .238 r
.71798 .91195 m .72425 .90835 L p .71407 .91818 L F P
0 g
s
.181 0 .238 r
.71407 .91818 m .71435 .91682 L .71798 .91195 L p F P
0 g
s
.296 .061 .378 r
.71798 .91195 m .72425 .90835 L .72468 .90348 L p F P
0 g
s
.701 .758 .896 r
.19925 .94967 m .18841 .9542 L .18487 .95127 L p F P
0 g
s
.634 .56 .753 r
.51629 .89503 m .51865 .90138 L .50695 .904 L p F P
0 g
s
.634 .56 .753 r
.50695 .904 m .50501 .89883 L .51629 .89503 L p F P
0 g
s
.809 .629 .658 r
.29688 .79382 m .29728 .79296 L .29655 .79274 L closepath p F P
0 g
s
.226 0 .275 r
.54725 .71643 m .55044 .71206 L .54784 .71366 L closepath p F P
0 g
s
.048 0 .007 r
.55849 .70481 m .55871 .70453 L p .54784 .71366 L F P
0 g
s
.048 0 .007 r
.54784 .71366 m .55044 .71206 L .55849 .70481 L p F P
0 g
s
.625 .627 .832 r
.57017 .94169 m .56313 .94331 L .56014 .93786 L p F P
0 g
s
.425 .868 .816 r
.67847 .94246 m .67774 .94268 L .66625 .94734 L p F P
0 g
s
.449 .882 .877 r
.67774 .94268 m .66625 .94734 L .66357 .94697 L p F P
0 g
s
.585 .915 .973 r
.66625 .94734 m .66357 .94697 L p .65245 .95093 L F P
0 g
s
.623 .508 .701 r
.48977 .85106 m .48905 .84837 L .50078 .84572 L p F P
0 g
s
.625 .507 .699 r
.49884 .83834 m .50078 .84572 L .48905 .84837 L p F P
0 g
s
.776 .622 .689 r
.30682 .82457 m .30484 .82414 L p .30822 .83247 L F P
0 g
s
.781 .622 .683 r
.30682 .82457 m .30603 .82223 L .30484 .82414 L closepath p F P
0 g
s
.755 .241 0 r
.1056 .93448 m .10071 .9321 L .09689 .92765 L p F P
0 g
s
.745 .226 0 r
.09196 .92526 m .09689 .92765 L .10071 .9321 L p F P
0 g
s
.832 .388 .176 r
.0903 .9225 m .09196 .92526 L .09689 .92765 L p F P
0 g
s
.788 .634 .691 r
.3006 .83081 m .30822 .83247 L .30366 .83924 L p F P
0 g
s
.776 .622 .689 r
.30484 .82414 m .3006 .83081 L .30822 .83247 L p F P
0 g
s
.772 .657 .736 r
.29874 .89099 m .30142 .88797 L .29679 .88699 L closepath p F P
0 g
s
.773 .656 .733 r
.29555 .88438 m .30001 .8791 L p .30142 .88797 L F P
0 g
s
.773 .656 .733 r
.30142 .88797 m .29679 .88699 L .29555 .88438 L p F P
0 g
s
.781 .622 .684 r
.30484 .82414 m .30603 .82223 L .30407 .81646 L p F P
0 g
s
0 .355 .768 r
.22713 .69762 m .23411 .7006 L .23376 .70038 L p F P
0 g
s
0 .355 .768 r
.22299 .69471 m .22713 .69762 L p .23376 .70038 L F P
0 g
s
.282 .624 .961 r
.22028 .69421 m .22299 .69471 L .22713 .69762 L p F P
0 g
s
.626 .602 .806 r
.55715 .93208 m .54579 .93489 L .54278 .92868 L p F P
0 g
s
.766 .64 .722 r
.30742 .87208 m .30695 .87098 L .3062 .87186 L closepath p F P
0 g
s
.779 .642 .71 r
.3017 .85457 m .3093 .85621 L .3041 .86317 L p F P
0 g
s
.779 .636 .702 r
.3093 .85621 m .3017 .85457 L .30657 .84771 L p F P
0 g
s
0 0 0 r
.68924 .93733 m .69149 .93552 L .70115 .93061 L p F P
0 g
s
0 0 0 r
.70312 .92749 m .70115 .93061 L .69149 .93552 L p F P
0 g
s
0 0 0 r
.69149 .93552 m .68924 .93733 L p .67847 .94246 L F P
0 g
s
.87 .503 .351 r
.25674 .72084 m .25162 .71829 L .25024 .71344 L p F P
0 g
s
.883 .517 .347 r
.24546 .71077 m .25024 .71344 L .25162 .71829 L p F P
0 g
s
.798 .623 .665 r
.29655 .79274 m .29036 .79105 L p .2941 .7993 L F P
0 g
s
.798 .623 .665 r
.2941 .7993 m .29688 .79382 L .29655 .79274 L p F P
0 g
s
.802 .62 .656 r
.29655 .79274 m .29036 .79105 L .29329 .7848 L p F P
0 g
s
.813 .629 .654 r
.28655 .78283 m .29329 .7848 L .29036 .79105 L p F P
0 g
s
.805 .618 .649 r
.28916 .77668 m .28655 .78283 L .29329 .7848 L p F P
0 g
s
.796 .621 .664 r
.29893 .80054 m .29688 .79382 L .2941 .7993 L closepath p F P
0 g
s
.626 .515 .708 r
.49114 .85589 m .48977 .85106 L .50103 .84665 L p F P
0 g
s
.623 .508 .701 r
.50078 .84572 m .50103 .84665 L .48977 .85106 L p F P
0 g
s
.781 .622 .684 r
.30407 .81646 m .30135 .81584 L p .30484 .82414 L F P
0 g
s
.785 .621 .677 r
.30407 .81646 m .30297 .81307 L .30135 .81584 L closepath p F P
0 g
s
.624 .717 .913 r
.59478 .95183 m .60623 .94922 L .60913 .95281 L p F P
0 g
s
.625 .686 .887 r
.60469 .94709 m .60623 .94922 L .59478 .95183 L p F P
0 g
s
.625 .686 .887 r
.59478 .95183 m .59398 .9507 L .60469 .94709 L p F P
0 g
s
.731 .763 .878 r
.19925 .94967 m .20015 .94917 L .20588 .95127 L p F P
0 g
s
.716 .746 .876 r
.21021 .94374 m .20015 .94917 L .20588 .95127 L p F P
0 g
s
.716 .746 .876 r
.20588 .95127 m .21367 .94732 L .21021 .94374 L p F P
0 g
s
.786 .622 .678 r
.30135 .81584 m .30297 .81307 L .30144 .80845 L p F P
0 g
s
.765 .638 .721 r
.3062 .87186 m .30695 .87098 L .3038 .86357 L p F P
0 g
s
.894 .735 .678 r
.05438 .83743 m .05844 .84022 L .05566 .84641 L p F P
0 g
s
.889 .741 .691 r
.05844 .84022 m .05438 .83743 L .05746 .83115 L p F P
0 g
s
.886 .75 .705 r
.05746 .83115 m .0599 .82659 L .05617 .82328 L p F P
0 g
s
.558 .414 .642 r
.51068 .78326 m .5096 .77676 L .52032 .77296 L p F P
0 g
s
.553 .406 .635 r
.51957 .76825 m .52032 .77296 L .5096 .77676 L p F P
0 g
s
.553 .406 .635 r
.5144 .76827 m .51957 .76825 L p .5096 .77676 L F P
0 g
s
.791 .621 .671 r
.30144 .80845 m .29992 .80362 L .29776 .80756 L closepath p F P
0 g
s
.792 .623 .671 r
.29776 .80756 m .29992 .80362 L .29893 .80054 L p F P
0 g
s
.792 .623 .671 r
.29893 .80054 m .2941 .7993 L p .29776 .80756 L F P
0 g
s
.631 .551 .745 r
.51554 .89292 m .51629 .89503 L .50501 .89883 L p F P
0 g
s
.631 .551 .745 r
.50501 .89883 m .50383 .89554 L .51554 .89292 L p F P
0 g
s
.903 .703 .623 r
.05524 .86127 m .05948 .86397 L .05774 .86988 L p F P
0 g
s
.898 .712 .642 r
.05948 .86397 m .05524 .86127 L .05735 .85526 L p F P
0 g
s
.786 .622 .678 r
.30144 .80845 m .29776 .80756 L p .30135 .81584 L F P
0 g
s
.762 .654 .742 r
.29446 .89543 m .29874 .89099 L .29679 .88699 L p F P
0 g
s
.821 .63 .645 r
.28268 .77462 m .28916 .77668 L .28655 .78283 L p F P
0 g
s
.812 .618 .64 r
.28496 .76858 m .28268 .77462 L .28916 .77668 L p F P
0 g
s
.765 .638 .721 r
.3038 .86357 m .2983 .87031 L .3062 .87186 L p F P
0 g
s
.778 .652 .723 r
.2983 .87031 m .3062 .87186 L .30001 .8791 L p F P
0 g
s
.626 .924 .974 r
.58116 .69127 m .57629 .69366 L .57142 .69734 L p F P
0 g
s
.626 .924 .974 r
.58405 .69304 m .58116 .69127 L p .57142 .69734 L F P
0 g
s
.476 .458 .758 r
.73215 .79363 m .72867 .79252 L .73107 .79053 L closepath p F P
0 g
s
.484 .47 .767 r
.72917 .78533 m .73107 .79053 L .72867 .79252 L p F P
0 g
s
.484 .47 .767 r
.72519 .78423 m .72917 .78533 L p .72867 .79252 L F P
0 g
s
.865 .774 .759 r
.06666 .78957 m .07046 .79251 L .06551 .79932 L p F P
0 g
s
.861 .775 .765 r
.07046 .79251 m .06666 .78957 L .07184 .7827 L p F P
0 g
s
.543 .744 .969 r
.20614 .69279 m .21676 .69128 L .22028 .69421 L p F P
0 g
s
.536 .739 .969 r
.21676 .69128 m .20614 .69279 L .20261 .68969 L p F P
0 g
s
.666 .772 .929 r
.19184 .69362 m .20261 .68969 L .20614 .69279 L p F P
0 g
s
.76 .712 .808 r
.23919 .93693 m .24364 .93349 L .25054 .93527 L p F P
0 g
s
.75 .707 .811 r
.25035 .92838 m .24364 .93349 L .25054 .93527 L p F P
0 g
s
.75 .707 .811 r
.25054 .93527 m .25369 .93299 L .25035 .92838 L p F P
0 g
s
.664 .771 .929 r
.20261 .68969 m .19184 .69362 L .18829 .69048 L p F P
0 g
s
.714 .78 .903 r
.17742 .69584 m .18829 .69048 L .19184 .69362 L p F P
0 g
s
.5 .509 .798 r
.70966 .76076 m .72035 .76266 L p .71568 .76835 L F P
0 g
s
.497 .51 .801 r
.70966 .76076 m .72035 .76266 L .71744 .75571 L p F P
0 g
s
.497 .51 .801 r
.71744 .75571 m .7155 .75536 L .70966 .76076 L p F P
0 g
s
.504 .522 .808 r
.70551 .75387 m .7155 .75536 L .70966 .76076 L p F P
0 g
s
.526 .563 .835 r
.69085 .73442 m .68504 .7341 L .68216 .72822 L p F P
0 g
s
.511 .339 .584 r
.52777 .74631 m .52553 .74488 L .52757 .74405 L closepath p F P
0 g
s
.088 0 .004 r
.70312 .92749 m .7037 .92703 L .70321 .92729 L closepath p F P
0 g
s
.177 0 .146 r
.70321 .92729 m .7037 .92703 L .71237 .9191 L p F P
0 g
s
.277 .046 .373 r
.73169 .89926 m .72468 .90348 L .72425 .90835 L p F P
0 g
s
.323 .124 .447 r
.72468 .90348 m .73169 .89926 L .7333 .89313 L p F P
0 g
s
.626 .516 .709 r
.49282 .86175 m .49114 .85589 L .50289 .85326 L p F P
0 g
s
.626 .515 .708 r
.50103 .84665 m .50289 .85326 L .49114 .85589 L p F P
0 g
s
.632 .551 .744 r
.51324 .88641 m .51554 .89292 L .50383 .89554 L p F P
0 g
s
.632 .551 .744 r
.50383 .89554 m .50196 .89031 L .51324 .88641 L p F P
0 g
s
.793 .634 .685 r
.29742 .82241 m .30484 .82414 L .3006 .83081 L p F P
0 g
s
.781 .622 .684 r
.30135 .81584 m .29742 .82241 L .30484 .82414 L p F P
0 g
s
.56 .616 .866 r
.64731 .70735 m .65895 .7066 L p .65855 .71189 L F P
0 g
s
.561 .621 .869 r
.65608 .70159 m .65895 .7066 L .64731 .70735 L p F P
0 g
s
.561 .621 .869 r
.64604 .70229 m .65608 .70159 L p .64731 .70735 L F P
0 g
s
.561 .621 .869 r
.64731 .70735 m .64499 .70335 L .64604 .70229 L p F P
0 g
s
.829 .631 .635 r
.27873 .76643 m .28496 .76858 L .28268 .77462 L p F P
0 g
s
.827 .621 .625 r
.28496 .76858 m .27873 .76643 L .28068 .76049 L p F P
0 g
s
.239 0 .258 r
.71237 .9191 m .71407 .91818 L .71435 .91682 L closepath p F P
0 g
s
.772 .661 .74 r
.29446 .89543 m .28741 .90287 L .28418 .89682 L p F P
0 g
s
.772 .661 .74 r
.28418 .89682 m .28692 .8938 L .29446 .89543 L p F P
0 g
s
.762 .654 .742 r
.29371 .88638 m .28692 .8938 L .29446 .89543 L p F P
0 g
s
.762 .654 .742 r
.29679 .88699 m .29371 .88638 L p .29446 .89543 L F P
0 g
s
.827 .371 .141 r
.09196 .92526 m .0903 .9225 L .08638 .92173 L p F P
0 g
s
.607 .482 .684 r
.49524 .82387 m .49493 .82258 L .5062 .81884 L p F P
0 g
s
.605 .475 .677 r
.50507 .81384 m .5062 .81884 L .49493 .82258 L p F P
0 g
s
.578 .899 .984 r
.65205 .95079 m .65551 .94966 L .65245 .95093 L closepath p F P
0 g
s
.585 .915 .973 r
.66357 .94697 m .65551 .94966 L .65245 .95093 L p F P
0 g
s
.868 .562 .468 r
.25886 .72679 m .25715 .726 L .25674 .72084 L p F P
0 g
s
.878 .572 .465 r
.25162 .71829 m .25674 .72084 L .25715 .726 L p F P
0 g
s
.406 .307 .63 r
.74061 .86331 m .74476 .86038 L .74108 .85569 L p F P
0 g
s
.403 .306 .631 r
.74821 .85059 m .74108 .85569 L .74476 .86038 L p F P
0 g
s
.42 .334 .652 r
.74789 .84905 m .74821 .85059 L .74108 .85569 L p F P
0 g
s
.42 .334 .652 r
.74439 .84562 m .74789 .84905 L p .74108 .85569 L F P
0 g
s
.839 .631 .622 r
.27471 .75826 m .28068 .76049 L .27873 .76643 L p F P
0 g
s
.837 .621 .61 r
.28068 .76049 m .27471 .75826 L .2763 .75244 L p F P
0 g
s
.766 .699 .788 r
.26127 .92677 m .25369 .93299 L .25035 .92838 L p F P
0 g
s
0 .372 .73 r
.12197 .94293 m .12462 .94406 L .12088 .94216 L p F P
0 g
s
0 .372 .73 r
.12088 .94216 m .11688 .94062 L .12197 .94293 L p F P
0 g
s
0 0 0 r
.70115 .93061 m .70312 .92749 L .7037 .92703 L p F P
0 g
s
.63 .583 .783 r
.53673 .91514 m .53722 .91627 L .52576 .91912 L p F P
0 g
s
.63 .583 .783 r
.52576 .91912 m .52541 .91831 L .53673 .91514 L p F P
0 g
s
.354 .18 .501 r
.73378 .88722 m .73352 .88738 L .7333 .89313 L p F P
0 g
s
.783 .635 .697 r
.30657 .84771 m .2991 .84601 L .30366 .83924 L p F P
0 g
s
.784 .642 .704 r
.2991 .84601 m .30657 .84771 L .3017 .85457 L p F P
0 g
s
0 0 0 r
.7037 .92703 m .71271 .92217 L p .70115 .93061 L F P
0 g
s
.156 0 .125 r
.71407 .91818 m .71237 .9191 L .7037 .92703 L p F P
0 g
s
.156 0 .125 r
.7037 .92703 m .71271 .92217 L .71407 .91818 L p F P
0 g
s
.481 .471 .77 r
.72917 .78533 m .72519 .78423 L .72792 .78192 L closepath p F P
0 g
s
.49 .484 .777 r
.72622 .77746 m .72792 .78192 L .72519 .78423 L p F P
0 g
s
.49 .484 .777 r
.72086 .77617 m .72622 .77746 L p .72519 .78423 L F P
0 g
s
.63 .542 .736 r
.51265 .88465 m .51324 .88641 L .50196 .89031 L p F P
0 g
s
.63 .542 .736 r
.50196 .89031 m .50094 .88728 L .51265 .88465 L p F P
0 g
s
.626 .516 .709 r
.50289 .85326 m .50408 .85746 L .49282 .86175 L p F P
0 g
s
.628 .524 .716 r
.49335 .86351 m .49282 .86175 L .50408 .85746 L p F P
0 g
s
.495 .496 .788 r
.71568 .76835 m .72328 .76993 L p .72086 .77617 L F P
0 g
s
.492 .498 .791 r
.72328 .76993 m .71568 .76835 L .72081 .76376 L closepath p F P
0 g
s
.5 .509 .798 r
.72035 .76266 m .72081 .76376 L .71568 .76835 L p F P
0 g
s
.581 .644 .878 r
.62998 .69914 m .64156 .69773 L .64443 .70242 L p F P
0 g
s
.584 .651 .882 r
.64156 .69773 m .62998 .69914 L .6271 .69467 L p F P
0 g
s
.608 .486 .688 r
.49699 .83106 m .49524 .82387 L .50669 .8209 L p F P
0 g
s
.607 .482 .684 r
.5062 .81884 m .50669 .8209 L .49524 .82387 L p F P
0 g
s
.747 .785 .884 r
.1629 .69926 m .17194 .69384 L .17558 .69693 L p F P
0 g
s
.745 .785 .885 r
.17385 .69271 m .17194 .69384 L .17558 .69693 L p F P
0 g
s
.745 .785 .885 r
.17558 .69693 m .17742 .69584 L .17385 .69271 L p F P
0 g
s
.849 .631 .607 r
.27058 .75012 m .2763 .75244 L .27471 .75826 L p F P
0 g
s
.848 .619 .59 r
.2763 .75244 m .27058 .75012 L .2718 .74442 L p F P
0 g
s
.626 .524 .718 r
.49335 .86351 m .5051 .86089 L p .50016 .87026 L F P
0 g
s
.626 .524 .718 r
.50016 .87026 m .4957 .87127 L .49335 .86351 L p F P
0 g
s
.628 .524 .716 r
.50408 .85746 m .5051 .86089 L .49335 .86351 L p F P
0 g
s
.585 .451 .664 r
.50314 .80505 m .50212 .80002 L .51323 .79667 L p F P
0 g
s
.583 .446 .66 r
.51189 .78989 m .51323 .79667 L .50212 .80002 L p F P
0 g
s
.439 .376 .691 r
.74451 .8343 m .7407 .83176 L .74336 .82977 L closepath p F P
0 g
s
.449 .395 .705 r
.7407 .83176 m .74336 .82977 L .74134 .8224 L p F P
0 g
s
.631 .542 .735 r
.51019 .87731 m .51265 .88465 L .50094 .88728 L p F P
0 g
s
.631 .542 .735 r
.50094 .88728 m .49892 .88131 L .51019 .87731 L p F P
0 g
s
.554 .403 .63 r
.51957 .76825 m .5144 .76827 L .51932 .76654 L closepath p F P
0 g
s
.548 .389 .617 r
.5185 .76032 m .51932 .76654 L .5144 .76827 L p F P
0 g
s
.761 .736 .83 r
.23089 .94254 m .22811 .94445 L .22469 .94059 L p F P
0 g
s
.739 .737 .849 r
.21367 .94732 m .22469 .94059 L .22811 .94445 L p F P
0 g
s
.628 .572 .773 r
.53673 .91514 m .52541 .91831 L .52238 .91097 L p F P
0 g
s
.526 .373 .617 r
.51932 .76654 m .5185 .76032 L .52885 .7561 L p F P
0 g
s
.517 .358 .604 r
.52812 .74997 m .52885 .7561 L .5185 .76032 L p F P
0 g
s
.487 .485 .78 r
.72622 .77746 m .72086 .77617 L .72451 .773 L closepath p F P
0 g
s
.495 .496 .788 r
.72328 .76993 m .72451 .773 L .72086 .77617 L p F P
0 g
s
.798 .635 .679 r
.29414 .81403 m .30135 .81584 L .29742 .82241 L p F P
0 g
s
.786 .622 .678 r
.29776 .80756 m .29414 .81403 L .30135 .81584 L p F P
0 g
s
.86 .629 .588 r
.26633 .74201 m .2718 .74442 L .27058 .75012 L p F P
0 g
s
.86 .614 .565 r
.2718 .74442 m .26633 .74201 L .26713 .73646 L p F P
0 g
s
.873 .606 .53 r
.26713 .73646 m .26192 .73395 L .26225 .72855 L p F P
0 g
s
.883 .615 .528 r
.25886 .72679 m .26225 .72855 L .26192 .73395 L p F P
0 g
s
.623 .684 .887 r
.60332 .94519 m .60469 .94709 L .59398 .9507 L p F P
0 g
s
.623 .684 .887 r
.59398 .9507 m .59185 .94768 L .60332 .94519 L p F P
0 g
s
.336 .166 .498 r
.74248 .88156 m .73378 .88722 L .73398 .89271 L p F P
0 g
s
.365 .217 .543 r
.73378 .88722 m .74248 .88156 L .74148 .87612 L p F P
0 g
s
.354 .18 .501 r
.7333 .89313 m .73398 .89271 L .73378 .88722 L p F P
0 g
s
.871 .625 .563 r
.26192 .73395 m .26713 .73646 L .26633 .74201 L p F P
0 g
s
.628 .533 .728 r
.50995 .87656 m .51019 .87731 L .49892 .88131 L p F P
0 g
s
.628 .533 .728 r
.49892 .88131 m .49823 .8792 L .50995 .87656 L p F P
0 g
s
.545 .596 .855 r
.67331 .71696 m .6647 .71708 L .66182 .71175 L p F P
0 g
s
.627 .525 .719 r
.49587 .87183 m .50016 .87026 L .4957 .87127 L closepath p F P
0 g
s
.629 .534 .727 r
.50744 .86865 m .50995 .87656 L .49823 .8792 L p F P
0 g
s
.629 .534 .727 r
.50016 .87026 m .50744 .86865 L p .49823 .8792 L F P
0 g
s
.629 .534 .727 r
.49823 .8792 m .49587 .87183 L .50016 .87026 L p F P
0 g
s
.389 .278 .606 r
.74476 .86038 m .74061 .86331 L .74157 .86956 L p F P
0 g
s
.404 .289 .608 r
.73943 .87098 m .74157 .86956 L .74061 .86331 L p F P
0 g
s
.763 .668 .757 r
.28746 .90297 m .28741 .90287 L .28733 .90295 L closepath p F P
0 g
s
.766 .699 .788 r
.25035 .92838 m .25426 .92502 L .26127 .92677 L p F P
0 g
s
.757 .694 .791 r
.26157 .91883 m .25426 .92502 L .26127 .92677 L p F P
0 g
s
.757 .694 .791 r
.26127 .92677 m .26487 .92386 L .26157 .91883 L p F P
0 g
s
.622 .756 .942 r
.60913 .95281 m .62061 .95011 L .62346 .95312 L p F P
0 g
s
.622 .726 .921 r
.62061 .95011 m .60913 .95281 L .60623 .94922 L p F P
0 g
s
.762 .665 .756 r
.28733 .90295 m .28741 .90287 L .28418 .89682 L p F P
0 g
s
.774 .683 .763 r
.27967 .90135 m .28733 .90295 L .27928 .91072 L p F P
0 g
s
.762 .665 .756 r
.28418 .89682 m .27967 .90135 L .28733 .90295 L p F P
0 g
s
.714 .781 .904 r
.18829 .69048 m .17742 .69584 L .17385 .69271 L p F P
0 g
s
.778 .653 .724 r
.30001 .8791 m .29555 .88438 L .29235 .87769 L p F P
0 g
s
.778 .653 .724 r
.29235 .87769 m .29257 .87743 L .30001 .8791 L p F P
0 g
s
.778 .652 .723 r
.30001 .8791 m .29257 .87743 L .2983 .87031 L p F P
0 g
s
.405 .742 .993 r
.1443 .94974 m .13894 .9479 L .14225 .94979 L closepath p F P
0 g
s
.503 .522 .809 r
.7155 .75536 m .70551 .75387 L .70456 .75168 L p F P
0 g
s
.41 .221 .511 r
.54335 .72494 m .53718 .7283 L .53724 .73371 L p F P
0 g
s
.37 .151 .446 r
.53718 .7283 m .54335 .72494 L .54548 .71891 L p F P
0 g
s
.901 .716 .643 r
.0532 .85252 m .05735 .85526 L .05524 .86127 L p F P
0 g
s
.896 .724 .661 r
.05735 .85526 m .0532 .85252 L .05566 .84641 L p F P
0 g
s
.747 .721 .828 r
.23581 .93269 m .22472 .94056 L .23089 .94254 L p F P
0 g
s
.747 .721 .828 r
.23089 .94254 m .23919 .93693 L .23581 .93269 L p F P
0 g
s
.761 .736 .83 r
.22469 .94059 m .22472 .94056 L .23089 .94254 L p F P
0 g
s
.633 .72 .91 r
.59834 .692 m .60981 .689 L .61269 .69275 L p F P
0 g
s
.648 .743 .919 r
.60981 .689 m .59834 .692 L .59546 .68897 L p F P
0 g
s
.669 .78 .932 r
.58405 .69304 m .59546 .68897 L .59834 .692 L p F P
0 g
s
.767 .654 .737 r
.29679 .88699 m .29555 .88438 L .29371 .88638 L closepath p F P
0 g
s
.779 .644 .713 r
.3038 .86357 m .3041 .86317 L .30359 .86306 L closepath p F P
0 g
s
.779 .642 .71 r
.30066 .85601 m .3017 .85457 L p .3041 .86317 L F P
0 g
s
.779 .642 .71 r
.3041 .86317 m .30359 .86306 L .30066 .85601 L p F P
0 g
s
.584 .882 .992 r
.65551 .94966 m .65205 .95079 L .64929 .94927 L p F P
0 g
s
.594 .864 .994 r
.63778 .95253 m .64929 .94927 L .65205 .95079 L p F P
0 g
s
.772 .69 .772 r
.27068 .91863 m .26487 .92386 L .26157 .91883 L p F P
0 g
s
.769 .64 .718 r
.2983 .87031 m .3038 .86357 L .30359 .86306 L p F P
0 g
s
.804 .635 .673 r
.29077 .80568 m .29776 .80756 L .29414 .81403 L p F P
0 g
s
.792 .623 .671 r
.2941 .7993 m .29077 .80568 L .29776 .80756 L p F P
0 g
s
.773 .685 .765 r
.27612 .91381 m .27928 .91072 L .2734 .90926 L closepath p F P
0 g
s
.774 .683 .763 r
.27285 .90832 m .27967 .90135 L p .27928 .91072 L F P
0 g
s
.774 .683 .763 r
.27928 .91072 m .2734 .90926 L .27285 .90832 L p F P
0 g
s
0 0 0 r
.68924 .93733 m .6828 .94041 L .67847 .94246 L p F P
0 g
s
.375 .831 .737 r
.67774 .94268 m .6828 .94041 L .67847 .94246 L closepath p F P
0 g
s
.696 .823 .943 r
.59546 .68897 m .58405 .69304 L .58116 .69127 L p F P
0 g
s
.772 .69 .772 r
.26157 .91883 m .26365 .91688 L .27068 .91863 L p F P
0 g
s
.761 .681 .774 r
.27213 .90898 m .26365 .91688 L .27068 .91863 L p F P
0 g
s
.761 .681 .774 r
.2734 .90926 m .27213 .90898 L p .27068 .91863 L F P
0 g
s
.761 .681 .774 r
.27068 .91863 m .27612 .91381 L .2734 .90926 L p F P
0 g
s
.487 .322 .582 r
.52757 .74405 m .53758 .73941 L p .53037 .74891 L F P
0 g
s
.487 .322 .582 r
.53037 .74891 m .52777 .74631 L .52757 .74405 L p F P
0 g
s
.469 .29 .555 r
.53724 .73371 m .53758 .73941 L .52757 .74405 L p F P
0 g
s
.535 .57 .837 r
.68216 .72822 m .68016 .72816 L .68151 .72691 L closepath p F P
0 g
s
.541 .58 .843 r
.67929 .72255 m .68151 .72691 L .68016 .72816 L p F P
0 g
s
.627 .063 0 r
.1056 .93448 m .10721 .93589 L .1034 .93432 L p F P
0 g
s
.627 .063 0 r
.1034 .93432 m .10071 .9321 L .1056 .93448 L p F P
0 g
s
.769 .64 .718 r
.30359 .86306 m .29634 .86157 L p .2983 .87031 L F P
0 g
s
.774 .64 .713 r
.30359 .86306 m .30066 .85601 L .29634 .86157 L closepath p F P
0 g
s
.88 .76 .725 r
.0569 .81256 m .0608 .81544 L .05691 .82195 L p F P
0 g
s
.876 .763 .734 r
.0608 .81544 m .0569 .81256 L .06105 .80598 L p F P
0 g
s
.789 .642 .699 r
.29635 .83748 m .30366 .83924 L .2991 .84601 L p F P
0 g
s
.788 .634 .691 r
.30366 .83924 m .29635 .83748 L .3006 .83081 L p F P
0 g
s
.385 .255 .578 r
.74157 .86956 m .73943 .87098 L .74148 .87612 L p F P
0 g
s
.898 .565 .409 r
.07855 .91047 m .07393 .90796 L .07314 .90271 L p F P
0 g
s
.901 .567 .404 r
.06858 .90017 m .07314 .90271 L .07393 .90796 L p F P
0 g
s
.904 .607 .472 r
.07314 .90271 m .06858 .90017 L .0684 .89477 L p F P
0 g
s
.907 .61 .47 r
.06391 .89219 m .0684 .89477 L .06858 .90017 L p F P
0 g
s
.906 .638 .522 r
.0684 .89477 m .06391 .89219 L .06428 .88664 L p F P
0 g
s
.622 .648 .855 r
.58891 .94313 m .57748 .94566 L .57452 .94068 L p F P
0 g
s
.624 .665 .869 r
.57748 .94566 m .58891 .94313 L .59185 .94768 L p F P
0 g
s
.254 .606 .954 r
.22299 .69471 m .22028 .69421 L .21676 .69128 L p F P
0 g
s
.892 .745 .692 r
.05348 .82832 m .05746 .83115 L .05438 .83743 L p F P
0 g
s
.886 .75 .705 r
.05617 .82328 m .05348 .82832 L .05746 .83115 L p F P
0 g
s
.325 .064 .356 r
.55044 .71206 m .55703 .70806 L p .547 .71809 L F P
0 g
s
.325 .064 .356 r
.547 .71809 m .54725 .71643 L .55044 .71206 L p F P
0 g
s
.066 0 .026 r
.55044 .71206 m .55703 .70806 L .55849 .70481 L closepath p F P
0 g
s
.885 .511 .326 r
.0847 .91802 m .08004 .91554 L .07855 .91047 L p F P
0 g
s
.888 .511 .318 r
.07393 .90796 m .07855 .91047 L .08004 .91554 L p F P
0 g
s
.615 .805 .973 r
.62346 .95312 m .63496 .9502 L .63778 .95253 L p F P
0 g
s
.619 .768 .951 r
.63496 .9502 m .62346 .95312 L .62061 .95011 L p F P
0 g
s
.91 .642 .521 r
.05988 .88403 m .06428 .88664 L .06391 .89219 L p F P
0 g
s
.906 .664 .562 r
.05987 .88399 m .06075 .87834 L p .06428 .88664 L F P
0 g
s
.906 .664 .562 r
.06428 .88664 m .05988 .88403 L .05987 .88399 L p F P
0 g
s
.865 .774 .759 r
.06551 .79932 m .06169 .79639 L .06666 .78957 L p F P
0 g
s
.871 .771 .749 r
.06551 .79932 m .06471 .80048 L .06095 .79748 L p F P
0 g
s
.871 .771 .749 r
.06095 .79748 m .06169 .79639 L .06551 .79932 L p F P
0 g
s
.608 .488 .69 r
.49798 .83505 m .49699 .83106 L .50844 .82809 L p F P
0 g
s
.608 .486 .688 r
.50669 .8209 m .50844 .82809 L .49699 .83106 L p F P
0 g
s
.503 .522 .809 r
.70456 .75168 m .70833 .74808 L p .7155 .75536 L F P
0 g
s
.508 .533 .818 r
.70456 .75168 m .70262 .74737 L .70833 .74808 L closepath p F P
0 g
s
.109 0 .045 r
.55703 .70806 m .55849 .70481 L .55947 .70401 L p F P
0 g
s
.81 .636 .667 r
.28732 .79734 m .2941 .7993 L .29077 .80568 L p F P
0 g
s
.798 .623 .665 r
.29036 .79105 m .28732 .79734 L .2941 .7993 L p F P
0 g
s
.626 .602 .806 r
.54278 .92868 m .55414 .92587 L .55715 .93208 L p F P
0 g
s
.624 .59 .795 r
.55266 .92266 m .55414 .92587 L .54278 .92868 L p F P
0 g
s
.624 .59 .795 r
.54278 .92868 m .54143 .92574 L .55266 .92266 L p F P
0 g
s
.611 .824 .982 r
.64929 .94927 m .63778 .95253 L .63496 .9502 L p F P
0 g
s
.767 .653 .737 r
.29371 .88638 m .29555 .88438 L .29235 .87769 L p F P
0 g
s
.555 .605 .858 r
.66182 .71175 m .65855 .71189 L .66076 .70981 L closepath p F P
0 g
s
.56 .616 .866 r
.65895 .7066 m .66076 .70981 L .65855 .71189 L p F P
0 g
s
.587 .457 .671 r
.50352 .80686 m .50314 .80505 L .51443 .80257 L p F P
0 g
s
.585 .451 .664 r
.51323 .79667 m .51443 .80257 L .50314 .80505 L p F P
0 g
s
.562 .423 .649 r
.51068 .78326 m .52144 .77951 L p .52175 .78643 L F P
0 g
s
.562 .423 .649 r
.52175 .78643 m .51135 .78704 L .51068 .78326 L p F P
0 g
s
.558 .414 .642 r
.52032 .77296 m .52144 .77951 L .51068 .78326 L p F P
0 g
s
.133 0 .116 r
.72345 .91286 m .71407 .91818 L .71271 .92217 L p F P
0 g
s
.181 0 .238 r
.72425 .90835 m .72345 .91286 L .71407 .91818 L p F P
0 g
s
.745 .732 .84 r
.22469 .94059 m .21367 .94732 L .21021 .94374 L p F P
0 g
s
.874 .769 .744 r
.06105 .80598 m .06471 .80048 L .06095 .79748 L p F P
0 g
s
.625 .627 .832 r
.56014 .93786 m .57154 .93527 L p .57017 .94169 L F P
0 g
s
.621 .614 .821 r
.56855 .92953 m .57154 .93527 L .56014 .93786 L p F P
0 g
s
.621 .614 .821 r
.566 .93011 m .56855 .92953 L p .56014 .93786 L F P
0 g
s
.621 .614 .821 r
.56014 .93786 m .55746 .93269 L .566 .93011 L p F P
0 g
s
.779 .669 .743 r
.28613 .88475 m .29371 .88638 L .28692 .8938 L p F P
0 g
s
.767 .653 .737 r
.29235 .87769 m .28613 .88475 L .29371 .88638 L p F P
0 g
s
.795 .643 .693 r
.29347 .829 m .3006 .83081 L .29635 .83748 L p F P
0 g
s
.793 .634 .685 r
.3006 .83081 m .29347 .829 L .29742 .82241 L p F P
0 g
s
.628 .572 .773 r
.52238 .91097 m .5337 .90777 L .53673 .91514 L p F P
0 g
s
.626 .562 .764 r
.53348 .90722 m .5337 .90777 L .52238 .91097 L p F P
0 g
s
.626 .562 .764 r
.52238 .91097 m .52203 .91009 L .53348 .90722 L p F P
0 g
s
.454 .423 .734 r
.73665 .80695 m .73981 .8043 L p .74102 .81322 L F P
0 g
s
.454 .423 .734 r
.74102 .81322 m .73821 .81195 L .73665 .80695 L p F P
0 g
s
.461 .437 .746 r
.73665 .80695 m .73516 .80245 L .73981 .8043 L closepath p F P
0 g
s
.599 .691 .907 r
.61269 .69275 m .62422 .69048 L p .6261 .69484 L F P
0 g
s
.616 .698 .902 r
.62422 .69048 m .61269 .69275 L .60981 .689 L p F P
0 g
s
.784 .644 .707 r
.30066 .85601 m .3017 .85457 L .29988 .85414 L closepath p F P
0 g
s
.784 .642 .704 r
.29752 .84834 m .2991 .84601 L p .3017 .85457 L F P
0 g
s
.784 .642 .704 r
.3017 .85457 m .29988 .85414 L .29752 .84834 L p F P
0 g
s
.817 .637 .66 r
.2838 .78902 m .29036 .79105 L .28732 .79734 L p F P
0 g
s
.813 .629 .654 r
.29036 .79105 m .2838 .78902 L .28655 .78283 L p F P
0 g
s
.91 .668 .561 r
.05987 .88399 m .06075 .87834 L .05859 .87702 L closepath p F P
0 g
s
.905 .685 .595 r
.05692 .8735 m .05774 .86988 L p .06075 .87834 L F P
0 g
s
.905 .685 .595 r
.06075 .87834 m .05859 .87702 L .05692 .8735 L p F P
0 g
s
.626 .562 .763 r
.53066 .89997 m .53348 .90722 L .52203 .91009 L p F P
0 g
s
.626 .562 .763 r
.52203 .91009 m .51934 .90322 L .53066 .89997 L p F P
0 g
s
.454 .422 .733 r
.7391 .81479 m .73821 .81195 L .74102 .81322 L closepath p F P
0 g
s
.86 .433 .204 r
.0847 .91802 m .08638 .92173 L .0833 .92092 L p F P
0 g
s
.86 .433 .204 r
.08004 .91554 m .0847 .91802 L p .0833 .92092 L F P
0 g
s
.46 .437 .746 r
.73981 .8043 m .73516 .80245 L .73398 .79887 L p F P
0 g
s
.589 .462 .676 r
.50507 .81384 m .50352 .80686 L .51463 .8035 L p F P
0 g
s
.587 .457 .671 r
.51443 .80257 m .51463 .8035 L .50352 .80686 L p F P
0 g
s
.611 .495 .697 r
.49884 .83834 m .49798 .83505 L .50926 .83141 L p F P
0 g
s
.608 .488 .69 r
.50844 .82809 m .50926 .83141 L .49798 .83505 L p F P
0 g
s
.448 .407 .721 r
.7391 .81479 m .74102 .81322 L p .74141 .82235 L F P
0 g
s
.448 .407 .721 r
.74141 .82235 m .74131 .82229 L .7391 .81479 L p F P
0 g
s
.432 .75 .994 r
.1443 .94974 m .1527 .94918 L p .13856 .94767 L F P
0 g
s
.432 .75 .994 r
.13856 .94767 m .13894 .9479 L .1443 .94974 L p F P
0 g
s
.467 .452 .758 r
.73398 .79887 m .73215 .79363 L .73779 .7956 L closepath p F P
0 g
s
.46 .437 .746 r
.73398 .79887 m .73779 .7956 L p .73981 .8043 L F P
0 g
s
.782 .656 .724 r
.29092 .86861 m .2983 .87031 L .29257 .87743 L p F P
0 g
s
.769 .64 .718 r
.29634 .86157 m .29092 .86861 L .2983 .87031 L p F P
0 g
s
.483 .321 .586 r
.52812 .74997 m .52777 .74631 L .53037 .74891 L closepath p F P
0 g
s
.584 .882 .992 r
.66248 .94654 m .65551 .94966 L p .64929 .94927 L F P
0 g
s
.593 .898 .987 r
.65551 .94966 m .66248 .94654 L .66357 .94697 L closepath p F P
0 g
s
.629 .531 .724 r
.50744 .86865 m .50714 .86768 L .50016 .87026 L closepath p F P
0 g
s
.626 .524 .718 r
.5051 .86089 m .50714 .86768 L .50016 .87026 L p F P
0 g
s
.768 .718 .806 r
.24364 .93349 m .23919 .93693 L .23581 .93269 L p F P
0 g
s
.843 .386 .115 r
.24546 .71077 m .2409 .70801 L .23842 .70353 L p F P
0 g
s
.853 .4 .114 r
.23416 .70066 m .23842 .70353 L .2409 .70801 L p F P
0 g
s
.665 .125 0 r
.23411 .7006 m .23416 .70066 L .23842 .70353 L p F P
0 g
s
.626 .63 .834 r
.57452 .94068 m .57017 .94169 L .57439 .94046 L closepath p F P
0 g
s
.625 .627 .832 r
.57154 .93527 m .57439 .94046 L .57017 .94169 L p F P
0 g
s
.899 .729 .662 r
.05158 .84363 m .05566 .84641 L .0532 .85252 L p F P
0 g
s
.894 .735 .678 r
.05566 .84641 m .05158 .84363 L .05438 .83743 L p F P
0 g
s
.774 .64 .713 r
.29634 .86157 m .30066 .85601 L .29988 .85414 L p F P
0 g
s
.524 .564 .838 r
.69109 .72303 m .69397 .72885 L .68216 .72822 L p F P
0 g
s
.524 .564 .838 r
.68561 .72275 m .69109 .72303 L p .68216 .72822 L F P
0 g
s
.524 .564 .838 r
.68216 .72822 m .68151 .72691 L .68561 .72275 L p F P
0 g
s
.526 .563 .835 r
.68216 .72822 m .69397 .72885 L p .69085 .73442 L F P
0 g
s
.624 .59 .795 r
.55112 .9193 m .55266 .92266 L .54143 .92574 L p F P
0 g
s
.624 .59 .795 r
.54143 .92574 m .53976 .92209 L .55112 .9193 L p F P
0 g
s
.824 .639 .652 r
.28022 .78072 m .28655 .78283 L .2838 .78902 L p F P
0 g
s
.821 .63 .645 r
.28655 .78283 m .28022 .78072 L .28268 .77462 L p F P
0 g
s
.32 .061 .355 r
.54548 .71891 m .547 .71809 L .54725 .71643 L closepath p F P
0 g
s
.611 .497 .699 r
.50078 .84572 m .49884 .83834 L .51029 .83538 L p F P
0 g
s
.611 .495 .697 r
.50926 .83141 m .51029 .83538 L .49884 .83834 L p F P
0 g
s
.566 .63 .874 r
.64499 .70335 m .64443 .70242 L .64604 .70229 L closepath p F P
0 g
s
.596 .77 .963 r
.15634 .95163 m .16696 .94928 L .17056 .95201 L p F P
0 g
s
.615 .771 .955 r
.16696 .94928 m .15634 .95163 L .1527 .94918 L p F P
0 g
s
.466 .452 .758 r
.73779 .7956 m .73215 .79363 L .73107 .79053 L p F P
0 g
s
.8 .643 .687 r
.29047 .82053 m .29742 .82241 L .29347 .829 L p F P
0 g
s
.798 .635 .679 r
.29742 .82241 m .29047 .82053 L .29414 .81403 L p F P
0 g
s
.448 .407 .72 r
.74134 .8224 m .74131 .82229 L .74141 .82235 L closepath p F P
0 g
s
.436 .386 .705 r
.74141 .82235 m .74134 .8224 L .74336 .82977 L p F P
0 g
s
.774 .64 .713 r
.29988 .85414 m .29415 .8529 L p .29634 .86157 L F P
0 g
s
.778 .639 .708 r
.29988 .85414 m .29752 .84834 L .29415 .8529 L closepath p F P
0 g
s
.436 .386 .705 r
.74336 .82977 m .74776 .82627 L .74141 .82235 L p F P
0 g
s
.435 .389 .708 r
.74806 .81693 m .74141 .82235 L .74776 .82627 L p F P
0 g
s
.448 .407 .721 r
.74102 .81322 m .74806 .81693 L .74141 .82235 L p F P
0 g
s
.778 .671 .745 r
.28418 .89682 m .28692 .8938 L .28193 .89259 L closepath p F P
0 g
s
.779 .669 .743 r
.28094 .89072 m .28613 .88475 L p .28692 .8938 L F P
0 g
s
.779 .669 .743 r
.28692 .8938 m .28193 .89259 L .28094 .89072 L p F P
0 g
s
.768 .718 .806 r
.23581 .93269 m .23716 .93159 L .24364 .93349 L p F P
0 g
s
.756 .707 .806 r
.247 .92374 m .23716 .93159 L .24364 .93349 L p F P
0 g
s
.756 .707 .806 r
.24364 .93349 m .25035 .92838 L .247 .92374 L p F P
0 g
s
.466 .452 .758 r
.73107 .79053 m .73496 .7871 L p .73779 .7956 L F P
0 g
s
.472 .466 .769 r
.73107 .79053 m .72917 .78533 L .73496 .7871 L closepath p F P
0 g
s
.088 .585 .898 r
.12462 .94406 m .13345 .94532 L .13842 .94766 L p F P
0 g
s
.165 .627 .933 r
.13345 .94532 m .12462 .94406 L .12088 .94216 L p F P
0 g
s
.731 .766 .88 r
.19925 .94967 m .20015 .94917 L .1977 .94823 L closepath p F P
0 g
s
.701 .758 .896 r
.1977 .94823 m .19925 .94967 L p .18487 .95127 L F P
0 g
s
.832 .64 .643 r
.27657 .77243 m .28268 .77462 L .28022 .78072 L p F P
0 g
s
.829 .631 .635 r
.28268 .77462 m .27657 .77243 L .27873 .76643 L p F P
0 g
s
.909 .689 .592 r
.05692 .8735 m .05774 .86988 L .05373 .86735 L closepath p F P
0 g
s
.903 .703 .623 r
.05353 .86706 m .05524 .86127 L p .05774 .86988 L F P
0 g
s
.903 .703 .623 r
.05774 .86988 m .05373 .86735 L .05353 .86706 L p F P
0 g
s
.531 .576 .845 r
.68151 .72691 m .67929 .72255 L .68561 .72275 L closepath p F P
0 g
s
.563 .428 .655 r
.51189 .78989 m .51135 .78704 L .52175 .78643 L closepath p F P
0 g
s
.392 .848 .791 r
.6828 .94041 m .67774 .94268 L .6751 .94275 L p F P
0 g
s
.449 .882 .877 r
.66357 .94697 m .6751 .94275 L .67774 .94268 L p F P
0 g
s
.789 .642 .699 r
.29438 .84054 m .29635 .83748 L p .2991 .84601 L F P
0 g
s
.789 .642 .699 r
.2991 .84601 m .29628 .8453 L .29438 .84054 L p F P
0 g
s
.789 .644 .702 r
.29752 .84834 m .2991 .84601 L .29628 .8453 L closepath p F P
0 g
s
.508 .534 .818 r
.70833 .74808 m .70262 .74737 L .69993 .74141 L p F P
0 g
s
.378 .159 .45 r
.547 .71809 m .54548 .71891 L .54335 .72494 L p F P
0 g
s
.534 .389 .63 r
.51932 .76654 m .52972 .76238 L p .52804 .76983 L F P
0 g
s
.534 .389 .63 r
.52804 .76983 m .51957 .76825 L .51932 .76654 L p F P
0 g
s
.526 .373 .617 r
.52885 .7561 m .52972 .76238 L .51932 .76654 L p F P
0 g
s
.767 .667 .752 r
.27967 .90135 m .28418 .89682 L .28193 .89259 L p F P
0 g
s
.733 .765 .878 r
.20674 .94011 m .21021 .94374 L .20015 .94917 L p F P
0 g
s
.733 .765 .878 r
.19574 .94638 m .20674 .94011 L p .20015 .94917 L F P
0 g
s
.733 .765 .878 r
.20015 .94917 m .1977 .94823 L .19574 .94638 L p F P
0 g
s
.62 .669 .875 r
.60332 .94519 m .59185 .94768 L .58891 .94313 L p F P
0 g
s
.624 .553 .754 r
.53011 .8985 m .53066 .89997 L .51934 .90322 L p F P
0 g
s
.624 .553 .754 r
.51934 .90322 m .51865 .90138 L .53011 .8985 L p F P
0 g
s
.883 .615 .528 r
.26192 .73395 m .25858 .73223 L .25886 .72679 L p F P
0 g
s
.868 .6 .532 r
.25715 .726 m .25886 .72679 L .25858 .73223 L p F P
0 g
s
.456 0 0 r
.10721 .93589 m .11182 .93829 L .11688 .94062 L p F P
0 g
s
.389 0 0 r
.11182 .93829 m .10721 .93589 L .1034 .93432 L p F P
0 g
s
.565 .636 .881 r
.64604 .70229 m .64443 .70242 L .64156 .69773 L p F P
0 g
s
.745 .226 0 r
.10071 .9321 m .09587 .92968 L .09196 .92526 L p F P
0 g
s
.735 .21 0 r
.08709 .92285 m .09196 .92526 L .09587 .92968 L p F P
0 g
s
.827 .371 .141 r
.08638 .92173 m .08709 .92285 L .09196 .92526 L p F P
0 g
s
.839 .631 .622 r
.27873 .76643 m .27285 .76416 L .27471 .75826 L p F P
0 g
s
.84 .641 .633 r
.27285 .76416 m .27873 .76643 L .27657 .77243 L p F P
0 g
s
.806 .644 .681 r
.28737 .81209 m .29414 .81403 L .29047 .82053 L p F P
0 g
s
.804 .635 .673 r
.29414 .81403 m .28737 .81209 L .29077 .80568 L p F P
0 g
s
.624 .553 .754 r
.52761 .89175 m .53011 .8985 L .51865 .90138 L p F P
0 g
s
.624 .553 .754 r
.51865 .90138 m .51629 .89503 L .52761 .89175 L p F P
0 g
s
.883 .517 .347 r
.25162 .71829 m .24675 .71564 L .24546 .71077 L p F P
0 g
s
.894 .529 .343 r
.2409 .70801 m .24546 .71077 L .24675 .71564 L p F P
0 g
s
.663 .769 .928 r
.17056 .95201 m .18132 .94827 L .18487 .95127 L p F P
0 g
s
.675 .769 .921 r
.18132 .94827 m .17056 .95201 L .16696 .94928 L p F P
0 g
s
.887 .755 .711 r
.05691 .82195 m .05617 .82328 L .05242 .82013 L p F P
0 g
s
.887 .755 .711 r
.05242 .82013 m .053 .81908 L .05691 .82195 L p F P
0 g
s
.88 .76 .725 r
.05691 .82195 m .053 .81908 L .0569 .81256 L p F P
0 g
s
.777 .674 .751 r
.27967 .90135 m .27285 .90832 L .26958 .90272 L p F P
0 g
s
.777 .674 .751 r
.26958 .90272 m .2725 .89961 L .27967 .90135 L p F P
0 g
s
.767 .667 .752 r
.27964 .89209 m .2725 .89961 L .27967 .90135 L p F P
0 g
s
.767 .667 .752 r
.28193 .89259 m .27964 .89209 L p .27967 .90135 L F P
0 g
s
.712 .761 .891 r
.19385 .94723 m .18487 .95127 L .18132 .94827 L p F P
0 g
s
.701 .758 .896 r
.18487 .95127 m .19385 .94723 L .1977 .94823 L p F P
0 g
s
.598 .674 .894 r
.6271 .69467 m .6261 .69484 L .62679 .69422 L closepath p F P
0 g
s
.599 .691 .907 r
.62422 .69048 m .62679 .69422 L .6261 .69484 L p F P
0 g
s
.389 .278 .606 r
.74157 .86956 m .74762 .86531 L .74476 .86038 L p F P
0 g
s
.368 .243 .576 r
.74762 .86531 m .74157 .86956 L .74231 .87558 L p F P
0 g
s
.385 .255 .578 r
.74148 .87612 m .74231 .87558 L .74157 .86956 L p F P
0 g
s
.765 .68 .769 r
.2734 .90926 m .27285 .90832 L .27213 .90898 L closepath p F P
0 g
s
.472 .466 .77 r
.73496 .7871 m .72917 .78533 L .72792 .78192 L p F P
0 g
s
.611 .499 .701 r
.50103 .84665 m .50078 .84572 L .51223 .84276 L p F P
0 g
s
.611 .497 .699 r
.51029 .83538 m .51223 .84276 L .50078 .84572 L p F P
0 g
s
.878 .767 .735 r
.05724 .80306 m .06105 .80598 L .0569 .81256 L p F P
0 g
s
.874 .769 .744 r
.06095 .79748 m .05724 .80306 L .06105 .80598 L p F P
0 g
s
.787 .656 .719 r
.28902 .85984 m .29634 .86157 L .29092 .86861 L p F P
0 g
s
.774 .64 .713 r
.29415 .8529 m .28902 .85984 L .29634 .86157 L p F P
0 g
s
.775 .706 .787 r
.25426 .92502 m .25035 .92838 L .247 .92374 L p F P
0 g
s
.622 .579 .785 r
.54845 .91316 m .55112 .9193 L .53976 .92209 L p F P
0 g
s
.622 .579 .785 r
.53976 .92209 m .53722 .91627 L .54845 .91316 L p F P
0 g
s
.781 .658 .727 r
.29235 .87769 m .29257 .87743 L .29219 .87734 L closepath p F P
0 g
s
.782 .656 .724 r
.28916 .87086 m .29092 .86861 L p .29257 .87743 L F P
0 g
s
.782 .656 .724 r
.29257 .87743 m .29219 .87734 L .28916 .87086 L p F P
0 g
s
.614 .506 .708 r
.50289 .85326 m .50103 .84665 L .51232 .8431 L p F P
0 g
s
.611 .499 .701 r
.51223 .84276 m .51232 .8431 L .50103 .84665 L p F P
0 g
s
.428 .369 .69 r
.74336 .82977 m .74776 .82627 L p .74662 .8358 L F P
0 g
s
.428 .369 .69 r
.74662 .8358 m .74451 .8343 L .74336 .82977 L p F P
0 g
s
.849 .641 .62 r
.26905 .75592 m .27471 .75826 L .27285 .76416 L p F P
0 g
s
.849 .631 .607 r
.27471 .75826 m .26905 .75592 L .27058 .75012 L p F P
0 g
s
.771 .654 .733 r
.28613 .88475 m .29235 .87769 L .29219 .87734 L p F P
0 g
s
0 .355 .768 r
.23376 .70038 m .22975 .69784 L .22299 .69471 L p F P
0 g
s
0 .343 .768 r
.219 .69174 m .22299 .69471 L .22975 .69784 L p F P
0 g
s
.254 .606 .954 r
.21676 .69128 m .219 .69174 L .22299 .69471 L p F P
0 g
s
.52 .552 .829 r
.69685 .73488 m .69085 .73442 L .69482 .73059 L closepath p F P
0 g
s
.526 .563 .835 r
.69397 .72885 m .69482 .73059 L .69085 .73442 L p F P
0 g
s
.416 .333 .655 r
.74789 .84905 m .74439 .84562 L .74679 .84386 L closepath p F P
0 g
s
.429 .356 .673 r
.74439 .84562 m .74679 .84386 L .74518 .83693 L p F P
0 g
s
.59 .465 .678 r
.5062 .81884 m .50507 .81384 L .5162 .81051 L p F P
0 g
s
.589 .462 .676 r
.51463 .8035 m .5162 .81051 L .50507 .81384 L p F P
0 g
s
.779 .64 .708 r
.29415 .8529 m .29752 .84834 L .29628 .8453 L p F P
0 g
s
.545 .596 .855 r
.66182 .71175 m .67354 .71156 L p .67331 .71696 L F P
0 g
s
.545 .6 .859 r
.67067 .70627 m .67354 .71156 L .66182 .71175 L p F P
0 g
s
.545 .6 .859 r
.664 .70641 m .67067 .70627 L p .66182 .71175 L F P
0 g
s
.545 .6 .859 r
.66182 .71175 m .66076 .70981 L .664 .70641 L p F P
0 g
s
.775 .706 .787 r
.247 .92374 m .24766 .92314 L .25426 .92502 L p F P
0 g
s
.762 .694 .786 r
.25673 .91508 m .24766 .92314 L .25426 .92502 L p F P
0 g
s
.762 .694 .786 r
.25956 .91576 m .25673 .91508 L p .25426 .92502 L F P
0 g
s
.762 .694 .786 r
.25426 .92502 m .26157 .91883 L .25956 .91576 L p F P
0 g
s
.771 .654 .733 r
.29219 .87734 m .28503 .87577 L p .28613 .88475 L F P
0 g
s
.775 .654 .728 r
.29219 .87734 m .28916 .87086 L .28503 .87577 L closepath p F P
0 g
s
.533 .393 .636 r
.52032 .77296 m .51957 .76825 L .52804 .76983 L closepath p F P
0 g
s
.566 .435 .662 r
.51323 .79667 m .51189 .78989 L .52175 .78643 L p F P
0 g
s
.317 .118 .444 r
.73398 .89271 m .7333 .89313 L .73169 .89926 L p F P
0 g
s
.472 .466 .77 r
.72792 .78192 m .73133 .77883 L p .73496 .7871 L F P
0 g
s
.478 .479 .78 r
.72792 .78192 m .72622 .77746 L .73133 .77883 L closepath p F P
0 g
s
.889 .754 .706 r
.05348 .82832 m .05617 .82328 L .05242 .82013 L p F P
0 g
s
.859 .641 .605 r
.26515 .74769 m .27058 .75012 L .26905 .75592 L p F P
0 g
s
.86 .629 .588 r
.27058 .75012 m .26515 .74769 L .26633 .74201 L p F P
0 g
s
.764 .679 .768 r
.27213 .90898 m .27285 .90832 L .26958 .90272 L p F P
0 g
s
.777 .696 .774 r
.26485 .90728 m .27213 .90898 L .26365 .91688 L p F P
0 g
s
.764 .679 .768 r
.26958 .90272 m .26485 .90728 L .27213 .90898 L p F P
0 g
s
.794 .645 .697 r
.29438 .84054 m .29635 .83748 L .29277 .83654 L closepath p F P
0 g
s
.795 .643 .693 r
.29124 .83264 m .29347 .829 L p .29635 .83748 L F P
0 g
s
.795 .643 .693 r
.29635 .83748 m .29277 .83654 L .29124 .83264 L p F P
0 g
s
.584 .651 .882 r
.6271 .69467 m .63868 .69313 L .64156 .69773 L p F P
0 g
s
.589 .67 .896 r
.6358 .68865 m .63868 .69313 L .6271 .69467 L p F P
0 g
s
.589 .67 .896 r
.63148 .68931 m .6358 .68865 L p .6271 .69467 L F P
0 g
s
.589 .67 .896 r
.6271 .69467 m .62679 .69422 L .63148 .68931 L p F P
0 g
s
.812 .645 .675 r
.28419 .80367 m .29077 .80568 L .28737 .81209 L p F P
0 g
s
.81 .636 .667 r
.29077 .80568 m .28419 .80367 L .28732 .79734 L p F P
0 g
s
.878 .572 .465 r
.25715 .726 m .25199 .72346 L .25162 .71829 L p F P
0 g
s
.89 .584 .461 r
.24675 .71564 m .25162 .71829 L .25199 .72346 L p F P
0 g
s
.907 .706 .619 r
.05524 .86127 m .05353 .86706 L .04994 .86237 L p F P
0 g
s
.907 .706 .619 r
.04994 .86237 m .05107 .85854 L .05524 .86127 L p F P
0 g
s
.901 .716 .643 r
.05524 .86127 m .05107 .85854 L .0532 .85252 L p F P
0 g
s
.776 .698 .777 r
.26157 .91883 m .26365 .91688 L .25956 .91576 L closepath p F P
0 g
s
.777 .696 .774 r
.25826 .91374 m .26485 .90728 L p .26365 .91688 L F P
0 g
s
.777 .696 .774 r
.26365 .91688 m .25956 .91576 L .25826 .91374 L p F P
0 g
s
.897 .74 .678 r
.05038 .83461 m .05438 .83743 L .05158 .84363 L p F P
0 g
s
.892 .745 .692 r
.05438 .83743 m .05038 .83461 L .05348 .82832 L p F P
0 g
s
.622 .544 .745 r
.527 .89002 m .52761 .89175 L .51629 .89503 L p F P
0 g
s
.622 .544 .745 r
.51629 .89503 m .51554 .89292 L .527 .89002 L p F P
0 g
s
.613 .507 .709 r
.50408 .85746 m .50289 .85326 L .51435 .85031 L p F P
0 g
s
.614 .506 .708 r
.51232 .8431 m .51435 .85031 L .50289 .85326 L p F P
0 g
s
.783 .639 .703 r
.29628 .8453 m .29438 .84054 L .29177 .84427 L closepath p F P
0 g
s
.779 .64 .708 r
.29628 .8453 m .29177 .84427 L p .29415 .8529 L F P
0 g
s
.494 .344 .606 r
.53037 .74891 m .52812 .74997 L .52885 .7561 L p F P
0 g
s
.621 .613 .821 r
.55746 .93269 m .55715 .93208 L .566 .93011 L closepath p F P
0 g
s
0 .418 .776 r
.11688 .94062 m .12088 .94216 L .11714 .94015 L p F P
0 g
s
0 .418 .776 r
.11714 .94015 m .11182 .93829 L .11688 .94062 L p F P
0 g
s
.869 .639 .587 r
.26113 .73951 m .26633 .74201 L .26515 .74769 L p F P
0 g
s
.871 .625 .563 r
.26633 .74201 m .26113 .73951 L .26192 .73395 L p F P
0 g
s
.566 .631 .875 r
.64604 .70229 m .65608 .70159 L .65321 .69664 L p F P
0 g
s
.566 .631 .875 r
.65321 .69664 m .65142 .69679 L .64604 .70229 L p F P
0 g
s
.565 .636 .881 r
.64156 .69773 m .65142 .69679 L .64604 .70229 L p F P
0 g
s
.622 .543 .745 r
.52456 .88308 m .527 .89002 L .51554 .89292 L p F P
0 g
s
.622 .543 .745 r
.51554 .89292 m .51324 .88641 L .52456 .88308 L p F P
0 g
s
.912 .669 .559 r
.05859 .87702 m .05644 .87568 L p .05987 .88403 L F P
0 g
s
.912 .669 .559 r
.05987 .88403 m .05987 .88399 L .05859 .87702 L p F P
0 g
s
.908 .685 .59 r
.05859 .87702 m .05692 .8735 L .05644 .87568 L closepath p F P
0 g
s
.761 .738 .831 r
.22469 .94059 m .22472 .94056 L .22465 .94054 L closepath p F P
0 g
s
.745 .732 .84 r
.22465 .94054 m .22469 .94059 L p .21021 .94374 L F P
0 g
s
.763 .737 .829 r
.23421 .93066 m .23581 .93269 L .22472 .94056 L p F P
0 g
s
.763 .737 .829 r
.2306 .9297 m .23421 .93066 L p .22472 .94056 L F P
0 g
s
.763 .737 .829 r
.22127 .93663 m .2306 .9297 L p .22472 .94056 L F P
0 g
s
.763 .737 .829 r
.22472 .94056 m .22465 .94054 L .22127 .93663 L p F P
0 g
s
.333 .123 .438 r
.54673 .72313 m .547 .71809 L .55618 .71247 L p F P
0 g
s
.325 .064 .356 r
.55703 .70806 m .55618 .71247 L .547 .71809 L p F P
0 g
s
.378 .159 .45 r
.54335 .72494 m .54673 .72313 L .547 .71809 L p F P
0 g
s
.745 .732 .84 r
.21021 .94374 m .21795 .93874 L .22465 .94054 L p F P
0 g
s
.743 .733 .842 r
.22465 .94054 m .22127 .93663 L .21795 .93874 L closepath p F P
0 g
s
.622 .648 .855 r
.57452 .94068 m .58596 .93822 L .58891 .94313 L p F P
0 g
s
.62 .627 .836 r
.58528 .93701 m .58596 .93822 L .57452 .94068 L p F P
0 g
s
.62 .627 .836 r
.57452 .94068 m .57439 .94046 L .58528 .93701 L p F P
0 g
s
.879 .633 .562 r
.25858 .73223 m .26192 .73395 L .26113 .73951 L p F P
0 g
s
.868 .6 .532 r
.25858 .73223 m .2568 .73141 L .25715 .726 L p F P
0 g
s
.877 .609 .528 r
.25199 .72346 m .25715 .726 L .2568 .73141 L p F P
0 g
s
.593 .677 .899 r
.62679 .69422 m .62422 .69048 L .63148 .68931 L closepath p F P
0 g
s
.714 .781 .904 r
.17385 .69271 m .18472 .68734 L .18829 .69048 L p F P
0 g
s
.664 .771 .929 r
.18829 .69048 m .19906 .68657 L .20261 .68969 L p F P
0 g
s
.664 .771 .929 r
.19906 .68657 m .18829 .69048 L .18472 .68734 L p F P
0 g
s
.536 .739 .969 r
.20261 .68969 m .21323 .68829 L .21676 .69128 L p F P
0 g
s
.534 .734 .967 r
.21323 .68829 m .20261 .68969 L .19906 .68657 L p F P
0 g
s
.428 .369 .69 r
.74518 .83693 m .74451 .8343 L .74662 .8358 L closepath p F P
0 g
s
.62 .599 .808 r
.566 .93011 m .55715 .93208 L .55414 .92587 L p F P
0 g
s
.618 .626 .836 r
.58299 .9329 m .58528 .93701 L .57439 .94046 L p F P
0 g
s
.618 .626 .836 r
.57439 .94046 m .57154 .93527 L .58299 .9329 L p F P
0 g
s
.613 .507 .709 r
.51435 .85031 m .51538 .85397 L .50408 .85746 L p F P
0 g
s
.616 .515 .717 r
.5051 .86089 m .50408 .85746 L .51538 .85397 L p F P
0 g
s
.392 .848 .791 r
.68826 .93774 m .6828 .94041 L p .6751 .94275 L F P
0 g
s
.343 .801 .679 r
.6828 .94041 m .68826 .93774 L .68924 .93733 L closepath p F P
0 g
s
.336 .166 .498 r
.73398 .89271 m .74232 .88731 L .74248 .88156 L p F P
0 g
s
.297 .103 .439 r
.74232 .88731 m .73398 .89271 L .73389 .89791 L p F P
0 g
s
.317 .118 .444 r
.73169 .89926 m .73389 .89791 L .73398 .89271 L p F P
0 g
s
.783 .665 .733 r
.28613 .88475 m .28094 .89072 L .27771 .88454 L p F P
0 g
s
.783 .665 .733 r
.27771 .88454 m .27902 .88298 L .28613 .88475 L p F P
0 g
s
.771 .654 .733 r
.28503 .87577 m .27902 .88298 L .28613 .88475 L p F P
0 g
s
.819 .646 .668 r
.28094 .79527 m .28732 .79734 L .28419 .80367 L p F P
0 g
s
.817 .637 .66 r
.28732 .79734 m .28094 .79527 L .2838 .78902 L p F P
0 g
s
.443 .406 .722 r
.74744 .80789 m .74102 .81322 L .74806 .81693 L p F P
0 g
s
.454 .423 .734 r
.74739 .80774 m .74744 .80789 L .74102 .81322 L p F P
0 g
s
.454 .423 .734 r
.73981 .8043 m .74739 .80774 L p .74102 .81322 L F P
0 g
s
.616 .516 .718 r
.50714 .86768 m .5051 .86089 L .51657 .85796 L p F P
0 g
s
.616 .515 .717 r
.51538 .85397 m .51657 .85796 L .5051 .86089 L p F P
0 g
s
.478 .479 .781 r
.73133 .77883 m .72622 .77746 L .72451 .773 L p F P
0 g
s
.592 .472 .685 r
.50669 .8209 m .5062 .81884 L .51751 .81628 L p F P
0 g
s
.59 .465 .678 r
.5162 .81051 m .51751 .81628 L .5062 .81884 L p F P
0 g
s
.62 .535 .737 r
.52411 .88174 m .52456 .88308 L .51324 .88641 L p F P
0 g
s
.62 .535 .737 r
.51324 .88641 m .51265 .88465 L .52411 .88174 L p F P
0 g
s
.435 .266 .552 r
.54349 .73032 m .53724 .73371 L .53758 .73941 L p F P
0 g
s
.41 .221 .511 r
.53724 .73371 m .54349 .73032 L .54335 .72494 L p F P
0 g
s
.792 .657 .714 r
.28693 .85112 m .29415 .8529 L .28902 .85984 L p F P
0 g
s
.779 .64 .708 r
.29177 .84427 m .28693 .85112 L .29415 .8529 L p F P
0 g
s
.622 .726 .921 r
.60623 .94922 m .61773 .94665 L .62061 .95011 L p F P
0 g
s
.62 .691 .894 r
.6151 .94314 m .61773 .94665 L .60623 .94922 L p F P
0 g
s
.62 .691 .894 r
.60623 .94922 m .60469 .94709 L .6151 .94314 L p F P
0 g
s
.7 .759 .898 r
.1977 .94823 m .19574 .94638 L .19385 .94723 L closepath p F P
0 g
s
.62 .534 .736 r
.5215 .87394 m .52411 .88174 L .51265 .88465 L p F P
0 g
s
.62 .534 .736 r
.51265 .88465 m .51019 .87731 L .5215 .87394 L p F P
0 g
s
.771 .667 .748 r
.28193 .89259 m .28094 .89072 L .27964 .89209 L closepath p F P
0 g
s
.551 .61 .865 r
.66076 .70981 m .65895 .7066 L .664 .70641 L closepath p F P
0 g
s
.799 .646 .691 r
.29124 .83264 m .29347 .829 L .28934 .82784 L closepath p F P
0 g
s
.8 .643 .687 r
.28811 .82463 m .29047 .82053 L p .29347 .829 L F P
0 g
s
.8 .643 .687 r
.29347 .829 m .28934 .82784 L .28811 .82463 L p F P
0 g
s
.415 .346 .672 r
.74662 .8358 m .74518 .83693 L .74679 .84386 L p F P
0 g
s
.783 .64 .703 r
.29177 .84427 m .29438 .84054 L .29277 .83654 L p F P
0 g
s
.618 .524 .726 r
.50744 .86865 m .50714 .86768 L .51844 .86424 L p F P
0 g
s
.616 .516 .718 r
.51657 .85796 m .51844 .86424 L .50714 .86768 L p F P
0 g
s
.618 .525 .727 r
.50995 .87656 m .50744 .86865 L .51891 .86573 L p F P
0 g
s
.618 .524 .726 r
.51844 .86424 m .51891 .86573 L .50744 .86865 L p F P
0 g
s
.213 0 .273 r
.7285 .9058 m .72425 .90835 L .72345 .91286 L p F P
0 g
s
.277 .046 .373 r
.72425 .90835 m .7285 .9058 L .73169 .89926 L p F P
0 g
s
.618 .526 .728 r
.51019 .87731 m .50995 .87656 L .52141 .87364 L p F P
0 g
s
.618 .525 .727 r
.51891 .86573 m .52141 .87364 L .50995 .87656 L p F P
0 g
s
.618 .526 .728 r
.52141 .87364 m .5215 .87394 L .51019 .87731 L p F P
0 g
s
.787 .656 .719 r
.28597 .86398 m .28902 .85984 L p .29092 .86861 L F P
0 g
s
.787 .656 .719 r
.29092 .86861 m .28773 .8678 L .28597 .86398 L p F P
0 g
s
.786 .658 .722 r
.28916 .87086 m .29092 .86861 L .28773 .8678 L closepath p F P
0 g
s
.621 .578 .784 r
.5481 .91235 m .54845 .91316 L .53722 .91627 L p F P
0 g
s
.621 .578 .784 r
.53722 .91627 m .53673 .91514 L .5481 .91235 L p F P
0 g
s
.593 .476 .689 r
.50844 .82809 m .50669 .8209 L .51782 .81757 L p F P
0 g
s
.592 .472 .685 r
.51751 .81628 m .51782 .81757 L .50669 .8209 L p F P
0 g
s
.513 .545 .826 r
.69993 .74141 m .69973 .74098 L .70031 .74104 L closepath p F P
0 g
s
.508 .534 .818 r
.69993 .74141 m .70031 .74104 L p .70833 .74808 L F P
0 g
s
.91 .689 .589 r
.05644 .87568 m .05692 .8735 L .05373 .86735 L p F P
0 g
s
.53 .577 .847 r
.68561 .72275 m .67929 .72255 L .67642 .71697 L p F P
0 g
s
.595 .025 0 r
.10071 .9321 m .1034 .93432 L .09959 .93261 L p F P
0 g
s
.595 .025 0 r
.09959 .93261 m .09587 .92968 L .10071 .9321 L p F P
0 g
s
.684 .936 .966 r
.57629 .69366 m .57991 .69085 L .58116 .69127 L closepath p F P
0 g
s
.826 .647 .66 r
.27762 .78688 m .2838 .78902 L .28094 .79527 L p F P
0 g
s
.824 .639 .652 r
.2838 .78902 m .27762 .78688 L .28022 .78072 L p F P
0 g
s
.512 .547 .829 r
.70031 .74104 m .69973 .74098 L .69685 .73488 L p F P
0 g
s
.262 .665 .967 r
.13856 .94767 m .13842 .94766 L .13894 .9479 L closepath p F P
0 g
s
.905 .721 .643 r
.04911 .84975 m .0532 .85252 L .05107 .85854 L p F P
0 g
s
.899 .729 .662 r
.0532 .85252 m .04911 .84975 L .05158 .84363 L p F P
0 g
s
.619 .568 .775 r
.5481 .91235 m .53673 .91514 L .5337 .90777 L p F P
0 g
s
.616 .906 .984 r
.66248 .94654 m .66357 .94697 L .6751 .94275 L p F P
0 g
s
.901 .567 .404 r
.07393 .90796 m .06937 .90542 L .06858 .90017 L p F P
0 g
s
.905 .569 .4 r
.06408 .8976 m .06858 .90017 L .06937 .90542 L p F P
0 g
s
.907 .61 .47 r
.06858 .90017 m .06408 .8976 L .06391 .89219 L p F P
0 g
s
.478 .479 .781 r
.72451 .773 m .7269 .77077 L p .73133 .77883 L F P
0 g
s
.484 .492 .79 r
.72451 .773 m .72328 .76993 L .7269 .77077 L closepath p F P
0 g
s
.91 .642 .521 r
.05986 .88408 m .05988 .88403 L p .06391 .89219 L F P
0 g
s
.91 .642 .521 r
.06391 .89219 m .05948 .88959 L .05986 .88408 L p F P
0 g
s
.911 .613 .467 r
.05948 .88959 m .06391 .89219 L .06408 .8976 L p F P
0 g
s
.537 .402 .644 r
.52144 .77951 m .52032 .77296 L .52804 .76983 L p F P
0 g
s
.386 .277 .606 r
.7494 .85708 m .74476 .86038 L .74762 .86531 L p F P
0 g
s
.403 .306 .631 r
.74476 .86038 m .7494 .85708 L .74821 .85059 L p F P
0 g
s
.783 .64 .703 r
.29277 .83654 m .28922 .83567 L p .29177 .84427 L F P
0 g
s
.788 .639 .697 r
.29277 .83654 m .29124 .83264 L .28922 .83567 L closepath p F P
0 g
s
.771 .666 .747 r
.27964 .89209 m .28094 .89072 L .27771 .88454 L p F P
0 g
s
.775 .654 .728 r
.28503 .87577 m .28916 .87086 L .28773 .8678 L p F P
0 g
s
.648 .743 .919 r
.59546 .68897 m .60693 .68552 L .60981 .689 L p F P
0 g
s
.668 .773 .928 r
.60693 .68552 m .59546 .68897 L .59258 .68642 L p F P
0 g
s
.696 .823 .943 r
.58116 .69127 m .59258 .68642 L .59546 .68897 L p F P
0 g
s
.771 .666 .747 r
.27771 .88454 m .27238 .89036 L .27964 .89209 L p F P
0 g
s
.783 .683 .753 r
.27238 .89036 m .27964 .89209 L .2725 .89961 L p F P
0 g
s
.805 .647 .686 r
.28811 .82463 m .29047 .82053 L .28599 .8192 L closepath p F P
0 g
s
.806 .644 .681 r
.28498 .81651 m .28737 .81209 L p .29047 .82053 L F P
0 g
s
.806 .644 .681 r
.29047 .82053 m .28599 .8192 L .28498 .81651 L p F P
0 g
s
.888 .511 .318 r
.08004 .91554 m .07543 .91302 L .07393 .90796 L p F P
0 g
s
.89 .51 .31 r
.06937 .90542 m .07393 .90796 L .07543 .91302 L p F P
0 g
s
.508 .534 .818 r
.70031 .74104 m .71164 .74246 L p .70833 .74808 L F P
0 g
s
.505 .536 .822 r
.70031 .74104 m .71164 .74246 L .70875 .73613 L p F P
0 g
s
.505 .536 .822 r
.70875 .73613 m .70554 .73574 L .70031 .74104 L p F P
0 g
s
.512 .547 .829 r
.69685 .73488 m .70554 .73574 L .70031 .74104 L p F P
0 g
s
.883 .764 .726 r
.05307 .80965 m .0569 .81256 L .053 .81908 L p F P
0 g
s
.878 .767 .735 r
.0569 .81256 m .05307 .80965 L .05724 .80306 L p F P
0 g
s
.57 .441 .665 r
.51323 .79667 m .52401 .79294 L p .51844 .80219 L F P
0 g
s
.57 .441 .665 r
.51844 .80219 m .51443 .80257 L .51323 .79667 L p F P
0 g
s
.566 .435 .662 r
.52268 .78636 m .52401 .79294 L .51323 .79667 L p F P
0 g
s
.566 .435 .662 r
.52175 .78643 m .52268 .78636 L p .51323 .79667 L F P
0 g
s
.361 .214 .542 r
.74231 .87558 m .74148 .87612 L .74248 .88156 L p F P
0 g
s
.31 .685 .977 r
.13842 .94766 m .13856 .94767 L .13487 .94542 L p F P
0 g
s
.31 .685 .977 r
.13487 .94542 m .13345 .94532 L .13842 .94766 L p F P
0 g
s
.833 .648 .652 r
.27423 .7785 m .28022 .78072 L .27762 .78688 L p F P
0 g
s
.832 .64 .643 r
.28022 .78072 m .27423 .7785 L .27657 .77243 L p F P
0 g
s
.909 .666 .559 r
.05988 .88403 m .05987 .88399 L .05987 .88403 L closepath p F P
0 g
s
.494 .344 .606 r
.52885 .7561 m .5361 .7527 L .53037 .74891 L p F P
0 g
s
.496 .343 .602 r
.53813 .74534 m .53037 .74891 L .5361 .7527 L p F P
0 g
s
.487 .322 .582 r
.53758 .73941 m .53813 .74534 L .53037 .74891 L p F P
0 g
s
.912 .647 .522 r
.05986 .88408 m .05987 .88403 L .05988 .88403 L closepath p F P
0 g
s
.916 .65 .52 r
.05987 .88403 m .05986 .88408 L .05785 .8886 L p F P
0 g
s
.916 .65 .52 r
.05558 .88137 m .05987 .88403 L p .05785 .8886 L F P
0 g
s
.912 .669 .559 r
.05644 .87568 m .05558 .88137 L .05987 .88403 L p F P
0 g
s
.797 .654 .704 r
.28467 .84245 m .29177 .84427 L .28693 .85112 L p F P
0 g
s
.783 .64 .703 r
.28922 .83567 m .28467 .84245 L .29177 .84427 L p F P
0 g
s
.432 .75 .994 r
.1527 .94918 m .14905 .94665 L .13856 .94767 L p F P
0 g
s
.529 .758 .98 r
.14905 .94665 m .13856 .94767 L .13487 .94542 L p F P
0 g
s
.913 .646 .519 r
.05948 .88959 m .05785 .8886 L .05986 .88408 L closepath p F P
0 g
s
.753 .738 .838 r
.21795 .93874 m .21021 .94374 L .20674 .94011 L p F P
0 g
s
.619 .768 .951 r
.62061 .95011 m .63213 .94737 L .63496 .9502 L p F P
0 g
s
.619 .736 .93 r
.63213 .94737 m .62061 .95011 L .61773 .94665 L p F P
0 g
s
.895 .749 .693 r
.04957 .82546 m .05348 .82832 L .05038 .83461 L p F P
0 g
s
.889 .754 .706 r
.05242 .82013 m .04957 .82546 L .05348 .82832 L p F P
0 g
s
.766 .693 .782 r
.25956 .91576 m .25826 .91374 L .25673 .91508 L closepath p F P
0 g
s
.771 .724 .809 r
.23581 .93269 m .23716 .93159 L .23421 .93066 L closepath p F P
0 g
s
.415 .225 .512 r
.54673 .72313 m .54335 .72494 L .54349 .73032 L p F P
0 g
s
.789 .641 .698 r
.28922 .83567 m .29124 .83264 L .28934 .82784 L p F P
0 g
s
.54 .586 .849 r
.67642 .71697 m .67331 .71696 L .67536 .71494 L closepath p F P
0 g
s
.545 .596 .855 r
.67354 .71156 m .67536 .71494 L .67331 .71696 L p F P
0 g
s
.772 .723 .807 r
.24628 .92272 m .247 .92374 L .23716 .93159 L p F P
0 g
s
.772 .723 .807 r
.24085 .92131 m .24628 .92272 L p .23716 .93159 L F P
0 g
s
.772 .723 .807 r
.23242 .92837 m .24085 .92131 L p .23716 .93159 L F P
0 g
s
.772 .723 .807 r
.23716 .93159 m .23421 .93066 L .23242 .92837 L p F P
0 g
s
.82 .353 .105 r
.08709 .92285 m .0833 .92092 L .08638 .92173 L closepath p F P
0 g
s
.483 .493 .791 r
.7269 .77077 m .72328 .76993 L .72081 .76376 L p F P
0 g
s
.234 .591 .948 r
.219 .69174 m .21676 .69128 L .21323 .68829 L p F P
0 g
s
.451 .423 .737 r
.74739 .80774 m .73981 .8043 L .74492 .79996 L closepath p F P
0 g
s
.46 .437 .746 r
.74433 .7982 m .74492 .79996 L .73981 .8043 L p F P
0 g
s
.46 .437 .746 r
.73779 .7956 m .74433 .7982 L p .73981 .8043 L F P
0 g
s
.616 .698 .902 r
.60981 .689 m .62134 .68646 L .62422 .69048 L p F P
0 g
s
.627 .715 .909 r
.62134 .68646 m .60981 .689 L .60693 .68552 L p F P
0 g
s
.595 .479 .691 r
.50926 .83141 m .50844 .82809 L .51959 .82479 L p F P
0 g
s
.593 .476 .689 r
.51782 .81757 m .51959 .82479 L .50844 .82809 L p F P
0 g
s
.84 .649 .643 r
.27078 .77015 m .27657 .77243 L .27423 .7785 L p F P
0 g
s
.84 .641 .633 r
.27657 .77243 m .27078 .77015 L .27285 .76416 L p F P
0 g
s
.86 .433 .204 r
.0833 .92092 m .08232 .92039 L .08004 .91554 L p F P
0 g
s
.86 .429 .191 r
.07543 .91302 m .08004 .91554 L .08232 .92039 L p F P
0 g
s
.788 .67 .734 r
.27792 .87399 m .28503 .87577 L .27902 .88298 L p F P
0 g
s
.775 .654 .728 r
.28365 .86686 m .27792 .87399 L .28503 .87577 L p F P
0 g
s
.775 .654 .728 r
.28773 .8678 m .28365 .86686 L p .28503 .87577 L F P
0 g
s
.782 .684 .756 r
.26958 .90272 m .2725 .89961 L .26687 .89809 L closepath p F P
0 g
s
.783 .683 .753 r
.2663 .89711 m .27238 .89036 L p .2725 .89961 L F P
0 g
s
.783 .683 .753 r
.2725 .89961 m .26687 .89809 L .2663 .89711 L p F P
0 g
s
.78 .653 .723 r
.28773 .8678 m .28597 .86398 L .28365 .86686 L closepath p F P
0 g
s
.791 .658 .717 r
.28597 .86398 m .28902 .85984 L .28336 .85833 L closepath p F P
0 g
s
.792 .657 .714 r
.28278 .85704 m .28693 .85112 L p .28902 .85984 L F P
0 g
s
.792 .657 .714 r
.28902 .85984 m .28336 .85833 L .28278 .85704 L p F P
0 g
s
0 0 0 r
.70115 .93061 m .70071 .93107 L .68924 .93733 L p F P
0 g
s
.416 .845 .704 r
.68826 .93774 m .68924 .93733 L .70071 .93107 L p F P
0 g
s
.584 .882 .992 r
.64929 .94927 m .66084 .94579 L .66248 .94654 L p F P
0 g
s
.606 .845 .989 r
.66084 .94579 m .64929 .94927 L .6465 .94717 L p F P
0 g
s
.611 .824 .982 r
.63496 .9502 m .6465 .94717 L .64929 .94927 L p F P
0 g
s
.811 .648 .68 r
.28498 .81651 m .28737 .81209 L .28272 .81062 L closepath p F P
0 g
s
.812 .645 .675 r
.28185 .80827 m .28419 .80367 L p .28737 .81209 L F P
0 g
s
.812 .645 .675 r
.28737 .81209 m .28272 .81062 L .28185 .80827 L p F P
0 g
s
.916 .674 .557 r
.05222 .87299 m .05644 .87568 L .05558 .88137 L p F P
0 g
s
.91 .689 .589 r
.05349 .86719 m .05222 .87299 L .05644 .87568 L p F P
0 g
s
.91 .689 .589 r
.05373 .86735 m .05349 .86719 L p .05644 .87568 L F P
0 g
s
.617 .785 .962 r
.6465 .94717 m .63496 .9502 L .63213 .94737 L p F P
0 g
s
.712 .761 .891 r
.18132 .94827 m .18752 .94528 L .19385 .94723 L p F P
0 g
s
.7 .756 .896 r
.19223 .94303 m .18752 .94528 L .19385 .94723 L p F P
0 g
s
.7 .756 .896 r
.19385 .94723 m .19574 .94638 L .19223 .94303 L p F P
0 g
s
.415 .346 .672 r
.74679 .84386 m .75162 .84012 L .74662 .8358 L p F P
0 g
s
.404 .325 .653 r
.74679 .84386 m .75162 .84012 L p .74887 .85008 L F P
0 g
s
.404 .325 .653 r
.74887 .85008 m .74789 .84905 L .74679 .84386 L p F P
0 g
s
.698 .168 0 r
.23416 .70066 m .23376 .70038 L .23411 .7006 L closepath p F P
0 g
s
.62 .669 .875 r
.58891 .94313 m .60039 .94074 L .60332 .94519 L p F P
0 g
s
.617 .651 .861 r
.60039 .94074 m .58891 .94313 L .58596 .93822 L p F P
0 g
s
.853 .4 .114 r
.2409 .70801 m .23652 .70519 L .23416 .70066 L p F P
0 g
s
.864 .419 .122 r
.23376 .70038 m .23416 .70066 L .23652 .70519 L p F P
0 g
s
.343 .201 .539 r
.74958 .87049 m .74231 .87558 L .7428 .88135 L p F P
0 g
s
.368 .243 .576 r
.74231 .87558 m .74958 .87049 L .74762 .86531 L p F P
0 g
s
.361 .214 .542 r
.74248 .88156 m .7428 .88135 L .74231 .87558 L p F P
0 g
s
.77 .681 .765 r
.26485 .90728 m .26958 .90272 L .26687 .89809 L p F P
0 g
s
.413 .347 .673 r
.75352 .83037 m .74662 .8358 L .75162 .84012 L p F P
0 g
s
.428 .369 .69 r
.74776 .82627 m .75352 .83037 L .74662 .8358 L p F P
0 g
s
.641 .924 .975 r
.57991 .69085 m .58116 .69127 L .59258 .68642 L p F P
0 g
s
.789 .641 .698 r
.28934 .82784 m .28654 .82711 L p .28922 .83567 L F P
0 g
s
.792 .64 .692 r
.28934 .82784 m .28811 .82463 L .28654 .82711 L closepath p F P
0 g
s
.62 .599 .808 r
.55414 .92587 m .56555 .92336 L p .566 .93011 L F P
0 g
s
.617 .587 .798 r
.56368 .91932 m .56555 .92336 L .55414 .92587 L p F P
0 g
s
.617 .587 .798 r
.55414 .92587 m .55266 .92266 L .56368 .91932 L p F P
0 g
s
.62 .69 .894 r
.61483 .94277 m .6151 .94314 L .60469 .94709 L p F P
0 g
s
.62 .69 .894 r
.60469 .94709 m .60332 .94519 L .61483 .94277 L p F P
0 g
s
.569 .644 .885 r
.65142 .69679 m .64156 .69773 L .63868 .69313 L p F P
0 g
s
.848 .649 .633 r
.26727 .7618 m .27285 .76416 L .27078 .77015 L p F P
0 g
s
.849 .641 .62 r
.27285 .76416 m .26727 .7618 L .26905 .75592 L p F P
0 g
s
.78 .688 .762 r
.26485 .90728 m .25826 .91374 L .25495 .90857 L p F P
0 g
s
.78 .688 .762 r
.25495 .90857 m .25801 .90545 L .26485 .90728 L p F P
0 g
s
.77 .681 .765 r
.26563 .89779 m .25801 .90545 L .26485 .90728 L p F P
0 g
s
.77 .681 .765 r
.26687 .89809 m .26563 .89779 L p .26485 .90728 L F P
0 g
s
.597 .486 .698 r
.51029 .83538 m .50926 .83141 L .52058 .82878 L p F P
0 g
s
.595 .479 .691 r
.51959 .82479 m .52058 .82878 L .50926 .83141 L p F P
0 g
s
.619 .568 .775 r
.5337 .90777 m .54507 .90498 L .5481 .91235 L p F P
0 g
s
.617 .557 .765 r
.54472 .90409 m .54507 .90498 L .5337 .90777 L p F P
0 g
s
.617 .557 .765 r
.5337 .90777 m .53348 .90722 L .54472 .90409 L p F P
0 g
s
.55 .613 .869 r
.664 .70641 m .65895 .7066 L .65608 .70159 L p F P
0 g
s
.902 .733 .662 r
.04758 .84082 m .05158 .84363 L .04911 .84975 L p F P
0 g
s
.897 .74 .678 r
.05158 .84363 m .04758 .84082 L .05038 .83461 L p F P
0 g
s
.777 .711 .79 r
.247 .92374 m .24766 .92314 L .24628 .92272 L closepath p F P
0 g
s
.801 .653 .699 r
.28225 .83381 m .28922 .83567 L .28467 .84245 L p F P
0 g
s
.789 .641 .698 r
.28654 .82711 m .28225 .83381 L .28922 .83567 L p F P
0 g
s
.778 .709 .787 r
.24981 .91328 m .25673 .91508 L .24766 .92314 L p F P
0 g
s
.778 .709 .787 r
.24365 .919 m .24981 .91328 L p .24766 .92314 L F P
0 g
s
.778 .709 .787 r
.24766 .92314 m .24628 .92272 L .24365 .919 L p F P
0 g
s
.617 .557 .764 r
.54202 .89719 m .54472 .90409 L .53348 .90722 L p F P
0 g
s
.617 .557 .764 r
.53348 .90722 m .53066 .89997 L .54202 .89719 L p F P
0 g
s
.268 .038 .367 r
.73389 .89791 m .73169 .89926 L .7285 .9058 L p F P
0 g
s
.501 .359 .62 r
.52972 .76238 m .52885 .7561 L .5361 .7527 L p F P
0 g
s
.879 .633 .562 r
.26113 .73951 m .2593 .73857 L .25858 .73223 L p F P
0 g
s
.865 .623 .57 r
.2568 .73141 m .25858 .73223 L .2593 .73857 L p F P
0 g
s
.864 .419 .122 r
.23054 .69861 m .23376 .70038 L p .23652 .70519 L F P
0 g
s
.653 .105 0 r
.23054 .69861 m .22975 .69784 L .23376 .70038 L closepath p F P
0 g
s
.765 .692 .782 r
.25495 .90857 m .24981 .91328 L .25673 .91508 L p F P
0 g
s
.765 .692 .782 r
.25673 .91508 m .25826 .91374 L .25495 .90857 L p F P
0 g
s
.503 .522 .809 r
.70833 .74808 m .71454 .74901 L p .7155 .75536 L F P
0 g
s
.501 .523 .812 r
.71454 .74901 m .70833 .74808 L .7124 .74413 L closepath p F P
0 g
s
.508 .534 .818 r
.71164 .74246 m .7124 .74413 L .70833 .74808 L p F P
0 g
s
.794 .642 .693 r
.28654 .82711 m .28811 .82463 L .28599 .8192 L p F P
0 g
s
.906 .702 .616 r
.05373 .86735 m .05353 .86706 L .05349 .86719 L closepath p F P
0 g
s
.739 .747 .859 r
.20674 .94011 m .19574 .94638 L .19223 .94303 L p F P
0 g
s
.616 .615 .828 r
.58299 .9329 m .57154 .93527 L .56855 .92953 L p F P
0 g
s
.818 .649 .674 r
.28185 .80827 m .28419 .80367 L .27952 .8021 L closepath p F P
0 g
s
.819 .646 .668 r
.27873 .79991 m .28094 .79527 L p .28419 .80367 L F P
0 g
s
.819 .646 .668 r
.28419 .80367 m .27952 .8021 L .27873 .79991 L p F P
0 g
s
.57 .447 .672 r
.51463 .8035 m .51443 .80257 L .51844 .80219 L closepath p F P
0 g
s
.857 .65 .621 r
.26367 .75348 m .26905 .75592 L .26727 .7618 L p F P
0 g
s
.859 .641 .605 r
.26905 .75592 m .26367 .75348 L .26515 .74769 L p F P
0 g
s
.909 .706 .616 r
.05349 .86719 m .05353 .86706 L .04994 .86237 L p F P
0 g
s
.597 .487 .699 r
.51223 .84276 m .51029 .83538 L .52145 .83209 L p F P
0 g
s
.597 .486 .698 r
.52058 .82878 m .52145 .83209 L .51029 .83538 L p F P
0 g
s
.78 .654 .724 r
.28365 .86686 m .28597 .86398 L .28336 .85833 L p F P
0 g
s
.915 .693 .588 r
.04935 .86446 m .05349 .86719 L .05222 .87299 L p F P
0 g
s
.909 .706 .616 r
.04994 .86237 m .04935 .86446 L .05349 .86719 L p F P
0 g
s
.457 .438 .75 r
.74433 .7982 m .73779 .7956 L .74218 .79177 L closepath p F P
0 g
s
.466 .452 .758 r
.74131 .78933 m .74218 .79177 L .73779 .7956 L p F P
0 g
s
.466 .452 .758 r
.73496 .7871 m .74131 .78933 L p .73779 .7956 L F P
0 g
s
.735 .21 0 r
.09587 .92968 m .09108 .92725 L .08709 .92285 L p F P
0 g
s
.723 .191 0 r
.0833 .92092 m .08709 .92285 L .09108 .92725 L p F P
0 g
s
.743 .732 .842 r
.21784 .93263 m .21164 .93678 L .21795 .93874 L p F P
0 g
s
.743 .732 .842 r
.21795 .93874 m .22127 .93663 L .21784 .93263 L p F P
0 g
s
.753 .738 .838 r
.20674 .94011 m .21164 .93678 L .21795 .93874 L p F P
0 g
s
.483 .493 .791 r
.72081 .76376 m .72168 .76293 L p .7269 .77077 L F P
0 g
s
.489 .505 .8 r
.72081 .76376 m .72035 .76266 L .72168 .76293 L closepath p F P
0 g
s
.615 .771 .955 r
.1527 .94918 m .16337 .94648 L .16696 .94928 L p F P
0 g
s
.631 .772 .948 r
.16337 .94648 m .1527 .94918 L .14905 .94665 L p F P
0 g
s
.573 .452 .678 r
.5162 .81051 m .51463 .8035 L .51844 .80219 L p F P
0 g
s
.177 0 .269 r
.56176 .70476 m .55703 .70806 L .55618 .71247 L p F P
0 g
s
.109 0 .045 r
.56696 .69927 m .56176 .70476 L .55703 .70806 L p F P
0 g
s
.109 0 .045 r
.56754 .69848 m .56696 .69927 L p .55703 .70806 L F P
0 g
s
.894 .529 .343 r
.24675 .71564 m .24211 .71291 L .2409 .70801 L p F P
0 g
s
.903 .54 .338 r
.23652 .70519 m .2409 .70801 L .24211 .71291 L p F P
0 g
s
.787 .672 .736 r
.27771 .88454 m .27902 .88298 L .27655 .88232 L closepath p F P
0 g
s
.788 .67 .734 r
.27447 .87829 m .27792 .87399 L p .27902 .88298 L F P
0 g
s
.788 .67 .734 r
.27902 .88298 m .27655 .88232 L .27447 .87829 L p F P
0 g
s
.765 .706 .797 r
.24628 .92272 m .24365 .919 L .24085 .92131 L closepath p F P
0 g
s
.797 .655 .706 r
.28693 .85112 m .28278 .85704 L .27959 .85003 L p F P
0 g
s
.797 .655 .706 r
.27959 .85003 m .28013 .84922 L .28693 .85112 L p F P
0 g
s
.797 .654 .704 r
.28693 .85112 m .28013 .84922 L .28467 .84245 L p F P
0 g
s
.756 .72 .818 r
.23421 .93066 m .23242 .92837 L .2306 .9297 L closepath p F P
0 g
s
.866 .649 .606 r
.26077 .74558 m .26515 .74769 L .26367 .75348 L p F P
0 g
s
.869 .639 .587 r
.26033 .74336 m .26113 .73951 L p .26515 .74769 L F P
0 g
s
.869 .639 .587 r
.26515 .74769 m .26077 .74558 L .26033 .74336 L p F P
0 g
s
.603 .888 .99 r
.66084 .94579 m .66248 .94654 L .6725 .94206 L p F P
0 g
s
.616 .906 .984 r
.6751 .94275 m .6725 .94206 L .66248 .94654 L p F P
0 g
s
.542 .41 .65 r
.52264 .78613 m .52144 .77951 L .53186 .77535 L p F P
0 g
s
.537 .402 .644 r
.53094 .7702 m .53186 .77535 L .52144 .77951 L p F P
0 g
s
.537 .402 .644 r
.52804 .76983 m .53094 .7702 L p .52144 .77951 L F P
0 g
s
.562 .423 .649 r
.52144 .77951 m .52264 .78613 L .52175 .78643 L p F P
0 g
s
.488 .506 .802 r
.72168 .76293 m .72035 .76266 L .71744 .75571 L p F P
0 g
s
.616 .586 .797 r
.56254 .91684 m .56368 .91932 L .55266 .92266 L p F P
0 g
s
.616 .586 .797 r
.55266 .92266 m .55112 .9193 L .56254 .91684 L p F P
0 g
s
0 0 0 r
.70071 .93107 m .70331 .92946 L .70115 .93061 L closepath p F P
0 g
s
0 0 0 r
.71214 .9233 m .70331 .92946 L .70115 .93061 L p F P
0 g
s
0 0 0 r
.71271 .92217 m .71214 .9233 L p .70115 .93061 L F P
0 g
s
.512 .548 .829 r
.70554 .73574 m .69685 .73488 L .69482 .73059 L p F P
0 g
s
.794 .642 .693 r
.28599 .8192 m .28374 .81858 L p .28654 .82711 L F P
0 g
s
.798 .64 .686 r
.28599 .8192 m .28498 .81651 L .28374 .81858 L closepath p F P
0 g
s
.776 .668 .744 r
.27238 .89036 m .27771 .88454 L .27655 .88232 L p F P
0 g
s
.591 .687 .908 r
.63148 .68931 m .62422 .69048 L .62134 .68646 L p F P
0 g
s
.805 .653 .694 r
.27971 .8252 m .28654 .82711 L .28225 .83381 L p F P
0 g
s
.794 .642 .693 r
.28374 .81858 m .27971 .8252 L .28654 .82711 L p F P
0 g
s
.722 .766 .888 r
.18752 .94528 m .18132 .94827 L .17777 .94521 L p F P
0 g
s
.675 .769 .921 r
.16696 .94928 m .17777 .94521 L .18132 .94827 L p F P
0 g
s
.824 .651 .667 r
.27873 .79991 m .28094 .79527 L .27641 .79365 L closepath p F P
0 g
s
.826 .647 .66 r
.27561 .7914 m .27762 .78688 L p .28094 .79527 L F P
0 g
s
.826 .647 .66 r
.28094 .79527 m .27641 .79365 L .27561 .7914 L p F P
0 g
s
.793 .67 .729 r
.27657 .86506 m .28365 .86686 L .27792 .87399 L p F P
0 g
s
.78 .654 .724 r
.28204 .85801 m .27657 .86506 L .28365 .86686 L p F P
0 g
s
.78 .654 .724 r
.28336 .85833 m .28204 .85801 L p .28365 .86686 L F P
0 g
s
.889 .76 .712 r
.053 .81908 m .05242 .82013 L .04863 .81713 L p F P
0 g
s
.889 .76 .712 r
.04863 .81713 m .04916 .81617 L .053 .81908 L p F P
0 g
s
.883 .764 .726 r
.053 .81908 m .04916 .81617 L .05307 .80965 L p F P
0 g
s
.53 .577 .847 r
.67642 .71697 m .68822 .71731 L p .68561 .72275 L F P
0 g
s
.529 .58 .85 r
.68535 .71177 m .68822 .71731 L .67642 .71697 L p F P
0 g
s
.529 .58 .85 r
.67843 .71159 m .68535 .71177 L p .67642 .71697 L F P
0 g
s
.529 .58 .85 r
.67642 .71697 m .67536 .71494 L .67843 .71159 L p F P
0 g
s
.876 .646 .587 r
.26033 .74336 m .26113 .73951 L .2593 .73857 L closepath p F P
0 g
s
.89 .584 .461 r
.25199 .72346 m .24709 .72082 L .24675 .71564 L p F P
0 g
s
.901 .594 .457 r
.24211 .71291 m .24675 .71564 L .24709 .72082 L p F P
0 g
s
.686 .768 .914 r
.17777 .94521 m .16696 .94928 L .16337 .94648 L p F P
0 g
s
.405 .325 .653 r
.74821 .85059 m .74789 .84905 L .74887 .85008 L closepath p F P
0 g
s
.615 .547 .756 r
.54134 .89535 m .54202 .89719 L .53066 .89997 L p F P
0 g
s
.615 .547 .756 r
.53066 .89997 m .53011 .8985 L .54134 .89535 L p F P
0 g
s
.165 .627 .933 r
.12088 .94216 m .12848 .94297 L .13345 .94532 L p F P
0 g
s
.231 .66 .958 r
.12848 .94297 m .12088 .94216 L .11714 .94015 L p F P
0 g
s
0 .343 .768 r
.22554 .69494 m .219 .69174 L p .229 .69741 L F P
0 g
s
0 .337 .773 r
.21515 .68872 m .219 .69174 L .22554 .69494 L p F P
0 g
s
0 .337 .773 r
.22152 .69196 m .21515 .68872 L p .22484 .69452 L F P
0 g
s
0 .337 .773 r
.22554 .69494 m .22152 .69196 L p .22484 .69452 L F P
0 g
s
0 .337 .782 r
.21142 .68564 m .21515 .68872 L .22152 .69196 L p F P
0 g
s
0 .337 .782 r
.2177 .68892 m .21142 .68564 L p .22086 .69155 L F P
0 g
s
0 .337 .782 r
.22152 .69196 m .2177 .68892 L p .22086 .69155 L F P
0 g
s
0 .345 .795 r
.20781 .68252 m .21142 .68564 L .2177 .68892 L p F P
0 g
s
0 .345 .795 r
.2177 .68892 m .21406 .6858 L .20781 .68252 L p F P
0 g
s
.655 .138 0 r
.21627 .68839 m .21431 .68609 L p .2177 .68892 L F P
0 g
s
.655 .138 0 r
.21431 .68609 m .21406 .6858 L .2177 .68892 L p F P
0 g
s
.672 .148 0 r
.21983 .69138 m .21796 .68921 L p .22152 .69196 L F P
0 g
s
.672 .148 0 r
.21796 .68921 m .2177 .68892 L .22152 .69196 L p F P
0 g
s
.676 .146 0 r
.22339 .69406 m .2218 .69227 L p .22554 .69494 L F P
0 g
s
.676 .146 0 r
.2218 .69227 m .22152 .69196 L .22554 .69494 L p F P
0 g
s
0 .343 .768 r
.22975 .69784 m .22554 .69494 L p .229 .69741 L F P
0 g
s
.234 .591 .948 r
.21323 .68829 m .21515 .68872 L .219 .69174 L p F P
0 g
s
.764 .721 .812 r
.2306 .9297 m .22127 .93663 L .21784 .93263 L p F P
0 g
s
.8 .643 .687 r
.28374 .81858 m .28498 .81651 L .28272 .81062 L p F P
0 g
s
.496 .511 .802 r
.71744 .75571 m .7155 .75536 L .71679 .75415 L closepath p F P
0 g
s
.503 .522 .809 r
.71454 .74901 m .71679 .75415 L .7155 .75536 L p F P
0 g
s
.451 .297 .58 r
.53813 .74534 m .53758 .73941 L .54534 .73522 L p F P
0 g
s
.435 .266 .552 r
.53758 .73941 m .54534 .73522 L .54349 .73032 L p F P
0 g
s
0 .459 .815 r
.11182 .93829 m .11714 .94015 L .11338 .93803 L p F P
0 g
s
.389 0 0 r
.1034 .93432 m .10679 .93594 L .11182 .93829 L p F P
0 g
s
0 .459 .815 r
.11338 .93803 m .10679 .93594 L .11182 .93829 L p F P
0 g
s
.614 .547 .755 r
.53898 .88898 m .54134 .89535 L .53011 .8985 L p F P
0 g
s
.614 .547 .755 r
.53011 .8985 m .52761 .89175 L .53898 .88898 L p F P
0 g
s
.463 .453 .762 r
.74131 .78933 m .73496 .7871 L .73919 .78332 L closepath p F P
0 g
s
.472 .466 .77 r
.73832 .78097 m .73919 .78332 L .73496 .7871 L p F P
0 g
s
.472 .466 .77 r
.73133 .77883 m .73832 .78097 L p .73496 .7871 L F P
0 g
s
.877 .609 .528 r
.2568 .73141 m .25165 .72886 L .25199 .72346 L p F P
0 g
s
.889 .62 .525 r
.24709 .72082 m .25199 .72346 L .25165 .72886 L p F P
0 g
s
.865 .623 .57 r
.2593 .73857 m .25589 .737 L .2568 .73141 L p F P
0 g
s
.875 .632 .567 r
.25165 .72886 m .2568 .73141 L .25589 .737 L p F P
0 g
s
.599 .491 .702 r
.51232 .8431 m .51223 .84276 L .5234 .83949 L p F P
0 g
s
.597 .487 .699 r
.52145 .83209 m .5234 .83949 L .51223 .84276 L p F P
0 g
s
.601 .498 .71 r
.51435 .85031 m .51232 .8431 L .52366 .84043 L p F P
0 g
s
.599 .491 .702 r
.5234 .83949 m .52366 .84043 L .51232 .8431 L p F P
0 g
s
.892 .758 .707 r
.04957 .82546 m .05242 .82013 L .04863 .81713 L p F P
0 g
s
.387 .296 .629 r
.74887 .85008 m .74821 .85059 L .7494 .85708 L p F P
0 g
s
.616 .674 .883 r
.61483 .94277 m .60332 .94519 L .60039 .94074 L p F P
0 g
s
.911 .71 .619 r
.05107 .85854 m .04994 .86237 L .0463 .85805 L p F P
0 g
s
.911 .71 .619 r
.0463 .85805 m .04697 .85578 L .05107 .85854 L p F P
0 g
s
.905 .721 .643 r
.05107 .85854 m .04697 .85578 L .04911 .84975 L p F P
0 g
s
.786 .676 .743 r
.27238 .89036 m .2663 .89711 L .26302 .89141 L p F P
0 g
s
.786 .676 .743 r
.26302 .89141 m .26553 .88852 L .27238 .89036 L p F P
0 g
s
.776 .668 .744 r
.27193 .88119 m .26553 .88852 L .27238 .89036 L p F P
0 g
s
.776 .668 .744 r
.27655 .88232 m .27193 .88119 L p .27238 .89036 L F P
0 g
s
.027 0 0 r
.71214 .9233 m .71546 .92062 L .71271 .92217 L closepath p F P
0 g
s
.133 0 .116 r
.72343 .91292 m .72345 .91286 L p .71271 .92217 L F P
0 g
s
.133 0 .116 r
.71271 .92217 m .71546 .92062 L .72343 .91292 L p F P
0 g
s
.621 .601 .81 r
.56855 .92953 m .566 .93011 L .56847 .92937 L closepath p F P
0 g
s
.62 .599 .808 r
.56555 .92336 m .56847 .92937 L .566 .93011 L p F P
0 g
s
.831 .652 .66 r
.27561 .7914 m .27762 .78688 L .27338 .78527 L closepath p F P
0 g
s
.833 .648 .652 r
.2725 .78273 m .27423 .7785 L p .27762 .78688 L F P
0 g
s
.833 .648 .652 r
.27762 .78688 m .27338 .78527 L .2725 .78273 L p F P
0 g
s
.9 .744 .679 r
.04646 .83175 m .05038 .83461 L .04758 .84082 L p F P
0 g
s
.895 .749 .693 r
.05038 .83461 m .04646 .83175 L .04957 .82546 L p F P
0 g
s
.779 .667 .739 r
.27655 .88232 m .27447 .87829 L .27193 .88119 L closepath p F P
0 g
s
.319 0 0 r
.10679 .93594 m .1034 .93432 L .09959 .93261 L p F P
0 g
s
.488 .506 .802 r
.71744 .75571 m .72705 .75767 L .72168 .76293 L p F P
0 g
s
.483 .493 .791 r
.72168 .76293 m .73241 .76544 L p .7269 .77077 L F P
0 g
s
.48 .493 .794 r
.72168 .76293 m .73241 .76544 L .72948 .75824 L p F P
0 g
s
.48 .493 .794 r
.72948 .75824 m .72705 .75767 L .72168 .76293 L p F P
0 g
s
.371 .191 .503 r
.54681 .72855 m .54673 .72313 L .55588 .71746 L p F P
0 g
s
.415 .225 .512 r
.54349 .73032 m .54681 .72855 L .54673 .72313 L p F P
0 g
s
.333 .123 .438 r
.55618 .71247 m .55588 .71746 L .54673 .72313 L p F P
0 g
s
.469 .467 .773 r
.73832 .78097 m .73133 .77883 L .73596 .77458 L closepath p F P
0 g
s
.478 .479 .781 r
.73536 .77304 m .73596 .77458 L .73133 .77883 L p F P
0 g
s
.478 .479 .781 r
.7269 .77077 m .73536 .77304 L p .73133 .77883 L F P
0 g
s
.613 .575 .787 r
.55951 .90994 m .56254 .91684 L .55112 .9193 L p F P
0 g
s
.613 .575 .787 r
.55747 .91038 m .55951 .90994 L p .55112 .9193 L F P
0 g
s
.613 .575 .787 r
.55112 .9193 m .54845 .91316 L .55747 .91038 L p F P
0 g
s
.81 .653 .689 r
.27706 .81661 m .28374 .81858 L .27971 .8252 L p F P
0 g
s
.8 .643 .687 r
.28084 .81008 m .27706 .81661 L .28374 .81858 L p F P
0 g
s
.8 .643 .687 r
.28272 .81062 m .28084 .81008 L p .28374 .81858 L F P
0 g
s
.803 .641 .681 r
.28272 .81062 m .28185 .80827 L .28084 .81008 L closepath p F P
0 g
s
.801 .653 .699 r
.28467 .84245 m .27797 .84051 L .28225 .83381 L p F P
0 g
s
.802 .659 .706 r
.27797 .84051 m .28467 .84245 L .28013 .84922 L p F P
0 g
s
.784 .654 .719 r
.28336 .85833 m .28278 .85704 L .28204 .85801 L closepath p F P
0 g
s
.475 .481 .784 r
.73536 .77304 m .7269 .77077 L .73245 .76553 L closepath p F P
0 g
s
.483 .493 .791 r
.73241 .76544 m .73245 .76553 L .7269 .77077 L p F P
0 g
s
.774 .68 .76 r
.26687 .89809 m .2663 .89711 L .26563 .89779 L closepath p F P
0 g
s
.601 .499 .71 r
.51538 .85397 m .51435 .85031 L .52553 .84705 L p F P
0 g
s
.601 .498 .71 r
.52366 .84043 m .52553 .84705 L .51435 .85031 L p F P
0 g
s
.612 .538 .747 r
.53822 .88685 m .53898 .88898 L .52761 .89175 L p F P
0 g
s
.612 .538 .747 r
.52761 .89175 m .527 .89002 L .53822 .88685 L p F P
0 g
s
.576 .456 .68 r
.5162 .81051 m .52701 .80682 L p .52391 .81549 L F P
0 g
s
.576 .456 .68 r
.52391 .81549 m .51751 .81628 L .5162 .81051 L p F P
0 g
s
.573 .452 .678 r
.52578 .80137 m .52701 .80682 L .5162 .81051 L p F P
0 g
s
.573 .452 .678 r
.51844 .80219 m .52578 .80137 L p .5162 .81051 L F P
0 g
s
.805 .644 .682 r
.28084 .81008 m .28185 .80827 L .27952 .8021 L p F P
0 g
s
.664 .771 .929 r
.18472 .68734 m .19551 .68344 L .19906 .68657 L p F P
0 g
s
.534 .734 .967 r
.19906 .68657 m .20969 .68524 L .21323 .68829 L p F P
0 g
s
.534 .73 .965 r
.20969 .68524 m .19906 .68657 L .19551 .68344 L p F P
0 g
s
.612 .537 .746 r
.53592 .88032 m .53822 .88685 L .527 .89002 L p F P
0 g
s
.612 .537 .746 r
.527 .89002 m .52456 .88308 L .53592 .88032 L p F P
0 g
s
.536 .591 .856 r
.67536 .71494 m .67354 .71156 L .67843 .71159 L closepath p F P
0 g
s
.416 .845 .704 r
.70071 .93107 m .6982 .93273 L p .68826 .93774 L F P
0 g
s
.416 .845 .704 r
.6982 .93273 m .69666 .93348 L .68826 .93774 L p F P
0 g
s
.449 .879 .806 r
.68665 .93806 m .69666 .93348 L .68826 .93774 L closepath p F P
0 g
s
.392 .848 .791 r
.6751 .94275 m .68665 .93806 L .68826 .93774 L p F P
0 g
s
.785 .654 .719 r
.28204 .85801 m .28278 .85704 L .27959 .85003 L p F P
0 g
s
0 0 0 r
.70331 .92946 m .70071 .93107 L .6982 .93273 L p F P
0 g
s
.246 .021 .361 r
.74084 .89342 m .73389 .89791 L .73346 .90277 L p F P
0 g
s
.297 .103 .439 r
.73389 .89791 m .74084 .89342 L .74232 .88731 L p F P
0 g
s
.268 .038 .367 r
.7285 .9058 m .73346 .90277 L .73389 .89791 L p F P
0 g
s
.424 .37 .693 r
.7518 .82301 m .74776 .82627 L .75352 .83037 L p F P
0 g
s
.435 .389 .708 r
.75053 .81845 m .74806 .81693 L p .74776 .82627 L F P
0 g
s
.435 .389 .708 r
.74776 .82627 m .7518 .82301 L .75053 .81845 L p F P
0 g
s
.839 .654 .652 r
.2725 .78273 m .27423 .7785 L .27046 .77699 L closepath p F P
0 g
s
.84 .649 .643 r
.26941 .77382 m .27078 .77015 L p .27423 .7785 L F P
0 g
s
.84 .649 .643 r
.27423 .7785 m .27046 .77699 L .26941 .77382 L p F P
0 g
s
.603 .507 .718 r
.51657 .85796 m .51538 .85397 L .52673 .85128 L p F P
0 g
s
.601 .499 .71 r
.52553 .84705 m .52673 .85128 L .51538 .85397 L p F P
0 g
s
.764 .721 .812 r
.21784 .93263 m .22406 .9278 L .2306 .9297 L p F P
0 g
s
.756 .718 .818 r
.22902 .924 m .22406 .9278 L .2306 .9297 L p F P
0 g
s
.756 .718 .818 r
.2306 .9297 m .23242 .92837 L .22902 .924 L p F P
0 g
s
.792 .672 .732 r
.27447 .87829 m .27792 .87399 L .27127 .87211 L closepath p F P
0 g
s
.793 .67 .729 r
.27123 .87204 m .27657 .86506 L p .27792 .87399 L F P
0 g
s
.793 .67 .729 r
.27792 .87399 m .27127 .87211 L .27123 .87204 L p F P
0 g
s
.566 .432 .658 r
.52268 .78636 m .52175 .78643 L .52264 .78613 L closepath p F P
0 g
s
.561 0 0 r
.09587 .92968 m .09959 .93261 L .09578 .93076 L p F P
0 g
s
.561 0 0 r
.09578 .93076 m .09108 .92725 L .09587 .92968 L p F P
0 g
s
.525 .567 .84 r
.69109 .72303 m .68561 .72275 L .68915 .71913 L closepath p F P
0 g
s
.53 .577 .847 r
.68822 .71731 m .68915 .71913 L .68561 .72275 L p F P
0 g
s
.213 0 .273 r
.72345 .91286 m .72353 .91281 L .7285 .9058 L p F P
0 g
s
.201 0 .263 r
.73346 .90277 m .7285 .9058 L .72353 .91281 L p F P
0 g
s
.387 .296 .629 r
.7494 .85708 m .75237 .85484 L .74887 .85008 L p F P
0 g
s
.386 .297 .631 r
.75594 .84464 m .74887 .85008 L .75237 .85484 L p F P
0 g
s
.404 .325 .653 r
.75162 .84012 m .75594 .84464 L .74887 .85008 L p F P
0 g
s
.773 .679 .76 r
.26563 .89779 m .2663 .89711 L .26302 .89141 L p F P
0 g
s
.796 .666 .72 r
.27501 .85617 m .28204 .85801 L .27657 .86506 L p F P
0 g
s
.785 .654 .719 r
.27959 .85003 m .27501 .85617 L .28204 .85801 L p F P
0 g
s
.786 .696 .765 r
.25863 .89598 m .26563 .89779 L .25801 .90545 L p F P
0 g
s
.773 .679 .76 r
.26302 .89141 m .25863 .89598 L .26563 .89779 L p F P
0 g
s
.683 .97 .922 r
.57829 .69073 m .584 .68739 L .57991 .69085 L closepath p F P
0 g
s
.641 .924 .975 r
.5897 .68449 m .584 .68739 L .57991 .69085 L p F P
0 g
s
.641 .924 .975 r
.59258 .68642 m .5897 .68449 L p .57991 .69085 L F P
0 g
s
.604 .508 .719 r
.51844 .86424 m .51657 .85796 L .52775 .85472 L p F P
0 g
s
.603 .507 .718 r
.52673 .85128 m .52775 .85472 L .51657 .85796 L p F P
0 g
s
.863 .639 .597 r
.2593 .73857 m .25589 .737 L p .2599 .7452 L F P
0 g
s
.863 .639 .597 r
.2599 .7452 m .26033 .74336 L .2593 .73857 L p F P
0 g
s
.512 .548 .829 r
.69482 .73059 m .6963 .72903 L p .70554 .73574 L F P
0 g
s
.516 .558 .837 r
.69482 .73059 m .69397 .72885 L .6963 .72903 L closepath p F P
0 g
s
.773 .71 .792 r
.24085 .92131 m .23242 .92837 L .22902 .924 L p F P
0 g
s
.573 .448 .672 r
.52578 .80137 m .51844 .80219 L .52544 .7998 L closepath p F P
0 g
s
.57 .441 .665 r
.52401 .79294 m .52544 .7998 L .51844 .80219 L p F P
0 g
s
.612 .927 .968 r
.6725 .94206 m .6751 .94275 L .68665 .93806 L p F P
0 g
s
.486 .506 .803 r
.72705 .75767 m .71744 .75571 L .71679 .75415 L p F P
0 g
s
.61 .528 .738 r
.53533 .87856 m .53592 .88032 L .52456 .88308 L p F P
0 g
s
.61 .528 .738 r
.52456 .88308 m .52411 .88174 L .53533 .87856 L p F P
0 g
s
.508 .372 .63 r
.5307 .76877 m .52972 .76238 L .53974 .75775 L p F P
0 g
s
.534 .389 .63 r
.52972 .76238 m .5307 .76877 L .52804 .76983 L p F P
0 g
s
.501 .359 .62 r
.53923 .75423 m .53974 .75775 L .52972 .76238 L p F P
0 g
s
.501 .359 .62 r
.5361 .7527 m .53923 .75423 L p .52972 .76238 L F P
0 g
s
.609 .528 .737 r
.53286 .87119 m .53533 .87856 L .52411 .88174 L p F P
0 g
s
.609 .528 .737 r
.52411 .88174 m .5215 .87394 L .53286 .87119 L p F P
0 g
s
.815 .654 .683 r
.27431 .80805 m .28084 .81008 L .27706 .81661 L p F P
0 g
s
.805 .644 .682 r
.27784 .80159 m .27431 .80805 L .28084 .81008 L p F P
0 g
s
.805 .644 .682 r
.27952 .8021 m .27784 .80159 L p .28084 .81008 L F P
0 g
s
.809 .641 .674 r
.27952 .8021 m .27873 .79991 L .27784 .80159 L closepath p F P
0 g
s
0 0 0 r
.71064 .92545 m .70331 .92946 L p .6982 .93273 L F P
0 g
s
0 0 0 r
.70331 .92946 m .71064 .92545 L .71214 .9233 L closepath p F P
0 g
s
.905 .569 .4 r
.06937 .90542 m .06488 .90285 L .06408 .8976 L p F P
0 g
s
.908 .571 .395 r
.05965 .895 m .06408 .8976 L .06488 .90285 L p F P
0 g
s
.911 .613 .467 r
.06408 .8976 m .05965 .895 L .05948 .88959 L p F P
0 g
s
.617 .651 .861 r
.58596 .93822 m .59744 .93592 L .60039 .94074 L p F P
0 g
s
.615 .628 .841 r
.59595 .93331 m .59744 .93592 L .58596 .93822 L p F P
0 g
s
.615 .628 .841 r
.58596 .93822 m .58528 .93701 L .59595 .93331 L p F P
0 g
s
.606 .517 .727 r
.51891 .86573 m .51844 .86424 L .5298 .86153 L p F P
0 g
s
.604 .508 .719 r
.52775 .85472 m .5298 .86153 L .51844 .86424 L p F P
0 g
s
.616 .615 .828 r
.56855 .92953 m .58 .92722 L .58299 .9329 L p F P
0 g
s
.614 .598 .811 r
.57934 .92587 m .58 .92722 L .56855 .92953 L p F P
0 g
s
.614 .598 .811 r
.56855 .92953 m .56847 .92937 L .57934 .92587 L p F P
0 g
s
.606 .517 .727 r
.5298 .86153 m .5301 .8625 L .51891 .86573 L p F P
0 g
s
.606 .518 .728 r
.52141 .87364 m .51891 .86573 L .5301 .8625 L p F P
0 g
s
.548 .42 .658 r
.52268 .78636 m .52264 .78613 L .53311 .78203 L p F P
0 g
s
.542 .41 .65 r
.53186 .77535 m .53311 .78203 L .52264 .78613 L p F P
0 g
s
.348 .702 .984 r
.13345 .94532 m .13487 .94542 L .13117 .94308 L p F P
0 g
s
.348 .702 .984 r
.13117 .94308 m .12848 .94297 L .13345 .94532 L p F P
0 g
s
.915 .615 .462 r
.05785 .8886 m .05948 .88959 L .05965 .895 L p F P
0 g
s
.612 .597 .811 r
.57701 .92114 m .57934 .92587 L .56847 .92937 L p F P
0 g
s
.612 .597 .811 r
.56847 .92937 m .56555 .92336 L .57701 .92114 L p F P
0 g
s
.549 .426 .665 r
.52401 .79294 m .52268 .78636 L .53407 .78695 L p F P
0 g
s
.548 .42 .658 r
.53311 .78203 m .53407 .78695 L .52268 .78636 L p F P
0 g
s
.607 .519 .729 r
.5215 .87394 m .52141 .87364 L .53262 .87044 L p F P
0 g
s
.606 .518 .728 r
.5301 .8625 m .53262 .87044 L .52141 .87364 L p F P
0 g
s
.607 .519 .729 r
.53262 .87044 m .53286 .87119 L .5215 .87394 L p F P
0 g
s
.812 .645 .676 r
.27784 .80159 m .27873 .79991 L .27641 .79365 L p F P
0 g
s
.722 .766 .888 r
.17777 .94521 m .18173 .94317 L .18752 .94528 L p F P
0 g
s
.709 .756 .889 r
.18871 .93963 m .18173 .94317 L .18752 .94528 L p F P
0 g
s
.709 .756 .889 r
.18752 .94528 m .19223 .94303 L .18871 .93963 L p F P
0 g
s
.908 .725 .644 r
.04509 .84694 m .04911 .84975 L .04697 .85578 L p F P
0 g
s
.902 .733 .662 r
.04911 .84975 m .04509 .84694 L .04758 .84082 L p F P
0 g
s
.846 .655 .643 r
.26941 .77382 m .27078 .77015 L .26767 .76882 L closepath p F P
0 g
s
.848 .649 .633 r
.26633 .76456 m .26727 .7618 L p .27078 .77015 L F P
0 g
s
.848 .649 .633 r
.27078 .77015 m .26767 .76882 L .26633 .76456 L p F P
0 g
s
.807 .66 .7 r
.27567 .83182 m .28225 .83381 L .27797 .84051 L p F P
0 g
s
.805 .653 .694 r
.28225 .83381 m .27567 .83182 L .27971 .8252 L p F P
0 g
s
.785 .698 .768 r
.25495 .90857 m .25801 .90545 L .25173 .90357 L closepath p F P
0 g
s
.786 .696 .765 r
.25163 .90341 m .25863 .89598 L p .25801 .90545 L F P
0 g
s
.786 .696 .765 r
.25801 .90545 m .25173 .90357 L .25163 .90341 L p F P
0 g
s
.438 .268 .552 r
.54681 .72855 m .54349 .73032 L .54534 .73522 L p F P
0 g
s
.331 .163 .496 r
.7428 .88135 m .74248 .88156 L .74232 .88731 L p F P
0 g
s
.761 .743 .836 r
.21164 .93678 m .20674 .94011 L .20326 .93644 L p F P
0 g
s
.739 .747 .859 r
.19223 .94303 m .20326 .93644 L .20674 .94011 L p F P
0 g
s
.546 .602 .86 r
.67067 .70627 m .664 .70641 L .66829 .70192 L closepath p F P
0 g
s
.55 .613 .869 r
.6678 .70105 m .66829 .70192 L .664 .70641 L p F P
0 g
s
.55 .613 .869 r
.65608 .70159 m .6678 .70105 L p .664 .70641 L F P
0 g
s
.89 .51 .31 r
.07543 .91302 m .07089 .91048 L .06937 .90542 L p F P
0 g
s
.892 .51 .303 r
.06488 .90285 m .06937 .90542 L .07089 .91048 L p F P
0 g
s
.486 .506 .803 r
.71679 .75415 m .72077 .7501 L p .72705 .75767 L F P
0 g
s
.492 .518 .812 r
.71679 .75415 m .71454 .74901 L .72077 .7501 L closepath p F P
0 g
s
.773 .71 .792 r
.22902 .924 m .23428 .91941 L .24085 .92131 L p F P
0 g
s
.765 .706 .797 r
.24029 .91424 m .23428 .91941 L .24085 .92131 L p F P
0 g
s
.765 .706 .797 r
.24085 .92131 m .24365 .919 L .24029 .91424 L p F P
0 g
s
.619 .736 .93 r
.61773 .94665 m .62927 .94408 L .63213 .94737 L p F P
0 g
s
.617 .699 .903 r
.62638 .94037 m .62927 .94408 L .61773 .94665 L p F P
0 g
s
.617 .699 .903 r
.61715 .94229 m .62638 .94037 L p .61773 .94665 L F P
0 g
s
.617 .699 .903 r
.61773 .94665 m .6151 .94314 L .61715 .94229 L p F P
0 g
s
.78 .668 .74 r
.27193 .88119 m .27447 .87829 L .27127 .87211 L p F P
0 g
s
.781 .701 .776 r
.24981 .91328 m .24365 .919 L .24029 .91424 L p F P
0 g
s
.781 .701 .776 r
.24029 .91424 m .24327 .91136 L .24981 .91328 L p F P
0 g
s
.771 .694 .778 r
.25151 .90351 m .24327 .91136 L .24981 .91328 L p F P
0 g
s
.771 .694 .778 r
.25173 .90357 m .25151 .90351 L p .24981 .91328 L F P
0 g
s
.771 .694 .778 r
.24981 .91328 m .25495 .90857 L .25173 .90357 L p F P
0 g
s
.554 .617 .87 r
.6678 .70105 m .65608 .70159 L .65321 .69664 L p F P
0 g
s
.577 .463 .687 r
.51782 .81757 m .51751 .81628 L .52391 .81549 L closepath p F P
0 g
s
.916 .65 .52 r
.05785 .8886 m .05516 .88694 L .05558 .88137 L p F P
0 g
s
.92 .654 .518 r
.05136 .87867 m .05558 .88137 L .05516 .88694 L p F P
0 g
s
.916 .674 .557 r
.05558 .88137 m .05136 .87867 L .05222 .87299 L p F P
0 g
s
.311 .148 .492 r
.75055 .87595 m .7428 .88135 L .74302 .88685 L p F P
0 g
s
.343 .201 .539 r
.7428 .88135 m .75055 .87595 L .74958 .87049 L p F P
0 g
s
.331 .163 .496 r
.74232 .88731 m .74302 .88685 L .7428 .88135 L p F P
0 g
s
.515 .56 .84 r
.6963 .72903 m .69397 .72885 L .69109 .72303 L p F P
0 g
s
.613 .574 .787 r
.54845 .91316 m .5481 .91235 L .55747 .91038 L closepath p F P
0 g
s
.569 .644 .885 r
.63868 .69313 m .65033 .69191 L p .65142 .69679 L F P
0 g
s
.576 .648 .884 r
.65033 .69191 m .63868 .69313 L .6358 .68865 L p F P
0 g
s
.539 .401 .641 r
.53094 .7702 m .52804 .76983 L .5307 .76877 L closepath p F P
0 g
s
.613 .627 .841 r
.59448 .93072 m .59595 .93331 L .58528 .93701 L p F P
0 g
s
.613 .627 .841 r
.58528 .93701 m .58299 .9329 L .59448 .93072 L p F P
0 g
s
.855 .63 .596 r
.26077 .74558 m .26033 .74336 L .2599 .7452 L closepath p F P
0 g
s
.578 .467 .691 r
.51959 .82479 m .51782 .81757 L .52391 .81549 L p F P
0 g
s
.365 .242 .576 r
.75038 .86335 m .74762 .86531 L .74958 .87049 L p F P
0 g
s
.386 .277 .606 r
.74762 .86531 m .75038 .86335 L .7494 .85708 L p F P
0 g
s
.812 .645 .676 r
.27641 .79365 m .27477 .79312 L p .27784 .80159 L F P
0 g
s
.815 .642 .668 r
.27641 .79365 m .27561 .7914 L .27477 .79312 L closepath p F P
0 g
s
.857 .65 .621 r
.26328 .75475 m .26367 .75348 L p .26727 .7618 L F P
0 g
s
.857 .65 .621 r
.26727 .7618 m .26507 .76081 L .26328 .75475 L p F P
0 g
s
.855 .656 .633 r
.26633 .76456 m .26727 .7618 L .26507 .76081 L closepath p F P
0 g
s
.82 .655 .678 r
.27148 .7995 m .27784 .80159 L .27431 .80805 L p F P
0 g
s
.812 .645 .676 r
.27477 .79312 m .27148 .7995 L .27784 .80159 L p F P
0 g
s
.897 .754 .694 r
.04572 .82256 m .04957 .82546 L .04646 .83175 L p F P
0 g
s
.892 .758 .707 r
.04863 .81713 m .04572 .82256 L .04957 .82546 L p F P
0 g
s
.792 .684 .745 r
.26504 .87934 m .27193 .88119 L .26553 .88852 L p F P
0 g
s
.78 .668 .74 r
.27119 .87209 m .26504 .87934 L .27193 .88119 L p F P
0 g
s
.78 .668 .74 r
.27127 .87211 m .27119 .87209 L p .27193 .88119 L F P
0 g
s
.611 .564 .777 r
.55747 .91038 m .5481 .91235 L .54507 .90498 L p F P
0 g
s
.86 .429 .191 r
.08232 .92039 m .07774 .91787 L .07543 .91302 L p F P
0 g
s
.86 .425 .178 r
.07089 .91048 m .07543 .91302 L .07774 .91787 L p F P
0 g
s
.818 .646 .669 r
.27477 .79312 m .27561 .7914 L .27338 .78527 L p F P
0 g
s
.627 .715 .909 r
.60693 .68552 m .61845 .68264 L .62134 .68646 L p F P
0 g
s
.642 .736 .917 r
.61845 .68264 m .60693 .68552 L .60404 .68238 L p F P
0 g
s
.668 .773 .928 r
.59258 .68642 m .60404 .68238 L .60693 .68552 L p F P
0 g
s
.912 .71 .615 r
.04935 .86446 m .04994 .86237 L .0463 .85805 L p F P
0 g
s
.723 .191 0 r
.08248 .92065 m .0833 .92092 L p .09108 .92725 L F P
0 g
s
.819 .347 .08 r
.08248 .92065 m .08232 .92039 L .0833 .92092 L closepath p F P
0 g
s
.695 .812 .937 r
.60404 .68238 m .59258 .68642 L .5897 .68449 L p F P
0 g
s
.801 .661 .709 r
.27959 .85003 m .28013 .84922 L .27907 .84891 L closepath p F P
0 g
s
.802 .659 .706 r
.27639 .84295 m .27797 .84051 L p .28013 .84922 L F P
0 g
s
.802 .659 .706 r
.28013 .84922 m .27907 .84891 L .27639 .84295 L p F P
0 g
s
.75 .732 .836 r
.2144 .92861 m .20568 .93472 L .21164 .93678 L p F P
0 g
s
.75 .732 .836 r
.21164 .93678 m .21784 .93263 L .2144 .92861 L p F P
0 g
s
.761 .743 .836 r
.20326 .93644 m .20568 .93472 L .21164 .93678 L p F P
0 g
s
.529 .758 .98 r
.13487 .94542 m .1454 .94405 L .14905 .94665 L p F P
0 g
s
.553 .762 .975 r
.1454 .94405 m .13487 .94542 L .13117 .94308 L p F P
0 g
s
.144 0 .165 r
.72343 .91292 m .72353 .91281 L .72345 .91286 L closepath p F P
0 g
s
.67 .131 0 r
.22975 .69784 m .23054 .69861 L .22696 .69646 L p F P
0 g
s
.67 .131 0 r
.22696 .69646 m .22554 .69494 L .22975 .69784 L p F P
0 g
s
.796 .666 .72 r
.27657 .86506 m .26988 .86313 L .27501 .85617 L p F P
0 g
s
.796 .666 .72 r
.27657 .86506 m .27123 .87204 L .26799 .86569 L p F P
0 g
s
.796 .666 .72 r
.26799 .86569 m .26988 .86313 L .27657 .86506 L p F P
0 g
s
.221 .579 .943 r
.21515 .68872 m .21323 .68829 L .20969 .68524 L p F P
0 g
s
.369 .265 .604 r
.75237 .85484 m .7494 .85708 L .75038 .86335 L p F P
0 g
s
.037 0 .065 r
.72353 .91281 m .73265 .90725 L p .72207 .9168 L F P
0 g
s
.037 0 .065 r
.72207 .9168 m .72343 .91292 L .72353 .91281 L p F P
0 g
s
.201 0 .263 r
.72353 .91281 m .73265 .90725 L .73346 .90277 L p F P
0 g
s
.866 .649 .606 r
.26367 .75348 m .26274 .75303 L .26077 .74558 L p F P
0 g
s
.853 .642 .616 r
.2599 .7452 m .26077 .74558 L .26274 .75303 L p F P
0 g
s
.114 0 .096 r
.71546 .92062 m .72207 .9168 L .72343 .91292 L closepath p F P
0 g
s
.92 .678 .556 r
.04807 .87026 m .05222 .87299 L .05136 .87867 L p F P
0 g
s
.915 .693 .588 r
.05222 .87299 m .04807 .87026 L .04935 .86446 L p F P
0 g
s
.813 .662 .695 r
.27325 .82316 m .27971 .8252 L .27567 .83182 L p F P
0 g
s
.81 .653 .689 r
.27971 .8252 m .27325 .82316 L .27706 .81661 L p F P
0 g
s
.789 .657 .717 r
.27501 .85617 m .27959 .85003 L .27907 .84891 L p F P
0 g
s
0 0 0 r
.71064 .92545 m .71214 .9233 L .71546 .92062 L p F P
0 g
s
.535 .593 .859 r
.67843 .71159 m .67354 .71156 L .67067 .70627 L p F P
0 g
s
.863 .657 .621 r
.26328 .75475 m .26367 .75348 L .26274 .75303 L closepath p F P
0 g
s
.617 .785 .962 r
.63213 .94737 m .64369 .94455 L .6465 .94717 L p F P
0 g
s
.617 .751 .941 r
.64369 .94455 m .63213 .94737 L .62927 .94408 L p F P
0 g
s
.603 .888 .99 r
.6725 .94206 m .67241 .94203 L .66084 .94579 L p F P
0 g
s
.598 .87 .993 r
.67241 .94203 m .66084 .94579 L .65808 .94397 L p F P
0 g
s
.606 .845 .989 r
.6465 .94717 m .65808 .94397 L .66084 .94579 L p F P
0 g
s
.818 .646 .669 r
.27338 .78527 m .27161 .78467 L p .27477 .79312 L F P
0 g
s
.821 .643 .66 r
.27338 .78527 m .2725 .78273 L .27161 .78467 L closepath p F P
0 g
s
0 0 0 r
.71546 .92062 m .72207 .9168 L p .71064 .92545 L F P
0 g
s
.826 .648 .662 r
.27161 .78467 m .2725 .78273 L .27046 .77699 L p F P
0 g
s
.789 .657 .717 r
.27907 .84891 m .27327 .84734 L p .27501 .85617 L F P
0 g
s
.793 .656 .711 r
.27907 .84891 m .27639 .84295 L .27327 .84734 L closepath p F P
0 g
s
.463 .319 .599 r
.53884 .75144 m .53813 .74534 L .54772 .7402 L p F P
0 g
s
.451 .297 .58 r
.54753 .73828 m .54772 .7402 L .53813 .74534 L p F P
0 g
s
.451 .297 .58 r
.54534 .73522 m .54753 .73828 L p .53813 .74534 L F P
0 g
s
.496 .343 .602 r
.5361 .7527 m .53884 .75144 L .53813 .74534 L p F P
0 g
s
.818 .646 .669 r
.27161 .78467 m .26857 .79097 L .27477 .79312 L p F P
0 g
s
.826 .656 .672 r
.26857 .79097 m .27477 .79312 L .27148 .7995 L p F P
0 g
s
.744 .747 .854 r
.20326 .93644 m .19223 .94303 L .18871 .93963 L p F P
0 g
s
.432 .387 .708 r
.75053 .81845 m .74806 .81693 L .74972 .81557 L closepath p F P
0 g
s
.443 .406 .722 r
.74806 .81693 m .74972 .81557 L .74744 .80789 L p F P
0 g
s
.905 .738 .663 r
.04365 .83797 m .04758 .84082 L .04509 .84694 L p F P
0 g
s
.9 .744 .679 r
.04758 .84082 m .04365 .83797 L .04646 .83175 L p F P
0 g
s
.915 .615 .462 r
.05519 .88953 m .05785 .8886 L p .05965 .895 L F P
0 g
s
.918 .625 .474 r
.05519 .88953 m .05516 .88694 L .05785 .8886 L closepath p F P
0 g
s
.615 .805 .973 r
.65808 .94397 m .6465 .94717 L .64369 .94455 L p F P
0 g
s
.853 .642 .616 r
.26274 .75303 m .25819 .75106 L .2599 .7452 L p F P
0 g
s
.863 .651 .614 r
.25457 .74273 m .2599 .7452 L .25819 .75106 L p F P
0 g
s
.863 .639 .597 r
.25589 .737 m .25457 .74273 L .2599 .7452 L p F P
0 g
s
.812 .332 .052 r
.08232 .92039 m .08248 .92065 L .07859 .91917 L p F P
0 g
s
.812 .332 .052 r
.07859 .91917 m .07774 .91787 L .08232 .92039 L p F P
0 g
s
.55 .429 .668 r
.52544 .7998 m .52401 .79294 L .53445 .78881 L p F P
0 g
s
.549 .426 .665 r
.53407 .78695 m .53445 .78881 L .52401 .79294 L p F P
0 g
s
.792 .684 .745 r
.25974 .88571 m .26504 .87934 L p .26553 .88852 L F P
0 g
s
.792 .684 .745 r
.26553 .88852 m .26048 .88701 L .25974 .88571 L p F P
0 g
s
.792 .685 .747 r
.26302 .89141 m .26553 .88852 L .26048 .88701 L closepath p F P
0 g
s
.492 .518 .812 r
.72077 .7501 m .71454 .74901 L .7124 .74413 L p F P
0 g
s
.58 .47 .692 r
.52058 .82878 m .51959 .82479 L .53044 .82114 L p F P
0 g
s
.578 .467 .691 r
.52887 .81484 m .53044 .82114 L .51959 .82479 L p F P
0 g
s
.578 .467 .691 r
.52391 .81549 m .52887 .81484 L p .51959 .82479 L F P
0 g
s
.826 .648 .662 r
.27046 .77699 m .26839 .77624 L p .27161 .78467 L F P
0 g
s
.828 .643 .652 r
.27046 .77699 m .26941 .77382 L .26839 .77624 L closepath p F P
0 g
s
.833 .649 .654 r
.26839 .77624 m .26941 .77382 L .26767 .76882 L p F P
0 g
s
.85 .651 .633 r
.26274 .75303 m .25819 .75106 L p .26169 .75943 L F P
0 g
s
.85 .651 .633 r
.26169 .75943 m .26328 .75475 L .26274 .75303 L p F P
0 g
s
.59 .669 .894 r
.6358 .68865 m .63148 .68931 L .63434 .68645 L closepath p F P
0 g
s
.591 .687 .908 r
.63292 .68436 m .63434 .68645 L .63148 .68931 L p F P
0 g
s
.591 .687 .908 r
.62134 .68646 m .63292 .68436 L p .63148 .68931 L F P
0 g
s
.844 .643 .631 r
.26507 .76081 m .26328 .75475 L .26169 .75943 L closepath p F P
0 g
s
.903 .54 .338 r
.24211 .71291 m .23767 .71011 L .23652 .70519 L p F P
0 g
s
.912 .549 .332 r
.23232 .7023 m .23652 .70519 L .23767 .71011 L p F P
0 g
s
.864 .419 .122 r
.23652 .70519 m .23232 .7023 L .23054 .69861 L p F P
0 g
s
.918 .697 .587 r
.04527 .86169 m .04935 .86446 L .04807 .87026 L p F P
0 g
s
.912 .71 .615 r
.0463 .85805 m .04527 .86169 L .04935 .86446 L p F P
0 g
s
.723 .191 0 r
.09108 .92725 m .08633 .92479 L .08248 .92065 L p F P
0 g
s
.725 .194 0 r
.08633 .92479 m .08248 .92065 L .07859 .91917 L p F P
0 g
s
.874 .648 .593 r
.25077 .73445 m .25589 .737 L .25457 .74273 L p F P
0 g
s
.875 .632 .567 r
.25589 .737 m .25077 .73445 L .25165 .72886 L p F P
0 g
s
.51 .551 .833 r
.6963 .72903 m .70587 .72999 L .70299 .72395 L p F P
0 g
s
.51 .551 .833 r
.70299 .72395 m .7012 .72378 L .6963 .72903 L p F P
0 g
s
.515 .56 .84 r
.69109 .72303 m .7012 .72378 L .6963 .72903 L p F P
0 g
s
.512 .548 .829 r
.6963 .72903 m .70587 .72999 L p .70554 .73574 L F P
0 g
s
.609 .693 .902 r
.63292 .68436 m .62134 .68646 L .61845 .68264 L p F P
0 g
s
.772 .727 .811 r
.22406 .9278 m .21784 .93263 L .2144 .92861 L p F P
0 g
s
.836 .643 .642 r
.26767 .76882 m .26633 .76456 L .26508 .76782 L closepath p F P
0 g
s
.841 .65 .644 r
.26508 .76782 m .26633 .76456 L .26507 .76081 L p F P
0 g
s
.056 0 .025 r
.5658 .70191 m .56696 .69927 L .56926 .69714 L p F P
0 g
s
0 0 0 r
.56176 .70476 m .5658 .70191 L .56696 .69927 L closepath p F P
0 g
s
.833 .649 .654 r
.26767 .76882 m .26508 .76782 L p .26839 .77624 L F P
0 g
s
.819 .661 .687 r
.27074 .81453 m .27706 .81661 L .27325 .82316 L p F P
0 g
s
.815 .654 .683 r
.27706 .81661 m .27074 .81453 L .27431 .80805 L p F P
0 g
s
.806 .663 .704 r
.27639 .84295 m .27797 .84051 L .27483 .83952 L closepath p F P
0 g
s
.807 .66 .7 r
.27319 .83584 m .27567 .83182 L p .27797 .84051 L F P
0 g
s
.807 .66 .7 r
.27797 .84051 m .27483 .83952 L .27319 .83584 L p F P
0 g
s
.612 .655 .868 r
.61191 .93844 m .60039 .94074 L .59744 .93592 L p F P
0 g
s
.616 .674 .883 r
.60039 .94074 m .61191 .93844 L .61483 .94277 L p F P
0 g
s
.841 .65 .644 r
.26507 .76081 m .26169 .75943 L p .26508 .76782 L F P
0 g
s
.52 .388 .641 r
.5307 .76877 m .54079 .76421 L p .53839 .77236 L F P
0 g
s
.52 .388 .641 r
.53839 .77236 m .53094 .7702 L .5307 .76877 L p F P
0 g
s
.508 .372 .63 r
.53974 .75775 m .54079 .76421 L .5307 .76877 L p F P
0 g
s
.864 .416 .09 r
.23232 .7023 m .23054 .69861 L .22696 .69646 L p F P
0 g
s
.779 .682 .757 r
.25863 .89598 m .26302 .89141 L .26048 .88701 L p F P
0 g
s
.611 .564 .777 r
.54507 .90498 m .55648 .90261 L p .55747 .91038 L F P
0 g
s
.609 .553 .767 r
.55573 .90071 m .55648 .90261 L .54507 .90498 L p F P
0 g
s
.609 .553 .767 r
.54507 .90498 m .54472 .90409 L .55573 .90071 L p F P
0 g
s
.832 .657 .665 r
.2656 .78246 m .27161 .78467 L .26857 .79097 L p F P
0 g
s
.826 .648 .662 r
.26839 .77624 m .2656 .78246 L .27161 .78467 L p F P
0 g
s
.609 .585 .801 r
.57447 .91572 m .57701 .92114 L .56555 .92336 L p F P
0 g
s
.609 .585 .801 r
.56555 .92336 m .56368 .91932 L .57447 .91572 L p F P
0 g
s
.886 .642 .564 r
.24675 .72623 m .25165 .72886 L .25077 .73445 L p F P
0 g
s
.889 .62 .525 r
.25165 .72886 m .24675 .72623 L .24709 .72082 L p F P
0 g
s
.901 .594 .457 r
.24709 .72082 m .24243 .7181 L .24211 .71291 L p F P
0 g
s
.911 .605 .452 r
.23767 .71011 m .24211 .71291 L .24243 .7181 L p F P
0 g
s
.607 .552 .767 r
.55344 .89488 m .55573 .90071 L .54472 .90409 L p F P
0 g
s
.607 .552 .767 r
.54472 .90409 m .54202 .89719 L .55344 .89488 L p F P
0 g
s
.645 .773 .941 r
.15976 .94362 m .14905 .94665 L .1454 .94405 L p F P
0 g
s
.631 .772 .948 r
.14905 .94665 m .15976 .94362 L .16337 .94648 L p F P
0 g
s
.504 .36 .618 r
.53923 .75423 m .5361 .7527 L .53884 .75144 L closepath p F P
0 g
s
.319 0 0 r
.09959 .93261 m .10179 .93357 L .10679 .93594 L p F P
0 g
s
0 .495 .848 r
.10679 .93594 m .11338 .93803 L .10963 .93582 L p F P
0 g
s
0 .495 .848 r
.10963 .93582 m .10179 .93357 L .10679 .93594 L p F P
0 g
s
.899 .63 .521 r
.24243 .7181 m .24709 .72082 L .24675 .72623 L p F P
0 g
s
.582 .477 .7 r
.52145 .83209 m .52058 .82878 L .53196 .82716 L p F P
0 g
s
.58 .47 .692 r
.53044 .82114 m .53196 .82716 L .52058 .82878 L p F P
0 g
s
.731 .769 .884 r
.18173 .94317 m .17777 .94521 L .1742 .9421 L p F P
0 g
s
.686 .768 .914 r
.16337 .94648 m .1742 .9421 L .17777 .94521 L p F P
0 g
s
.802 .673 .721 r
.26838 .85422 m .27501 .85617 L .26988 .86313 L p F P
0 g
s
.789 .657 .717 r
.27327 .84734 m .26838 .85422 L .27501 .85617 L p F P
0 g
s
.784 .667 .735 r
.27127 .87211 m .27123 .87204 L .27119 .87209 L closepath p F P
0 g
s
.784 .668 .735 r
.27119 .87209 m .27123 .87204 L .26799 .86569 L p F P
0 g
s
.796 .679 .736 r
.26429 .87023 m .27119 .87209 L .26504 .87934 L p F P
0 g
s
.784 .668 .735 r
.26799 .86569 m .26429 .87023 L .27119 .87209 L p F P
0 g
s
.788 .688 .754 r
.25863 .89598 m .25163 .90341 L .2483 .89815 L p F P
0 g
s
.788 .688 .754 r
.2483 .89815 m .25202 .89407 L .25863 .89598 L p F P
0 g
s
.779 .682 .757 r
.25892 .88659 m .25202 .89407 L .25863 .89598 L p F P
0 g
s
.779 .682 .757 r
.26048 .88701 m .25892 .88659 L p .25863 .89598 L F P
0 g
s
.177 0 .269 r
.55618 .71247 m .55781 .71133 L .56176 .70476 L p F P
0 g
s
.168 0 .262 r
.5658 .70191 m .56176 .70476 L .55781 .71133 L p F P
0 g
s
.566 .631 .875 r
.65321 .69664 m .65142 .69679 L .65258 .6956 L closepath p F P
0 g
s
.569 .644 .885 r
.65033 .69191 m .65258 .6956 L .65142 .69679 L p F P
0 g
s
.518 .391 .647 r
.53186 .77535 m .53094 .7702 L .53839 .77236 L closepath p F P
0 g
s
.772 .727 .811 r
.2144 .92861 m .21788 .92579 L .22406 .9278 L p F P
0 g
s
.762 .72 .813 r
.22562 .91961 m .21788 .92579 L .22406 .9278 L p F P
0 g
s
.762 .72 .813 r
.22406 .9278 m .22902 .924 L .22562 .91961 L p F P
0 g
s
.413 .347 .673 r
.75375 .83057 m .75352 .83037 L p .75162 .84012 L F P
0 g
s
.413 .347 .673 r
.75162 .84012 m .75532 .83722 L .75375 .83057 L p F P
0 g
s
.399 .324 .655 r
.75532 .83722 m .75162 .84012 L .75594 .84464 L p F P
0 g
s
.221 .579 .943 r
.20969 .68524 m .21142 .68564 L .21515 .68872 L p F P
0 g
s
.398 .238 .545 r
.54715 .73425 m .54681 .72855 L .55597 .72289 L p F P
0 g
s
.371 .191 .503 r
.55588 .71746 m .55597 .72289 L .54681 .72855 L p F P
0 g
s
.438 .268 .552 r
.54534 .73522 m .54715 .73425 L .54681 .72855 L p F P
0 g
s
.61 .616 .833 r
.59448 .93072 m .58299 .9329 L .58 .92722 L p F P
0 g
s
.695 .768 .908 r
.1742 .9421 m .16337 .94648 L .15976 .94362 L p F P
0 g
s
.583 .479 .701 r
.5234 .83949 m .52145 .83209 L .5323 .82845 L p F P
0 g
s
.582 .477 .7 r
.53196 .82716 m .5323 .82845 L .52145 .83209 L p F P
0 g
s
.795 .658 .712 r
.27327 .84734 m .27639 .84295 L .27483 .83952 L p F P
0 g
s
.839 .658 .658 r
.26255 .77396 m .26839 .77624 L .2656 .78246 L p F P
0 g
s
.833 .649 .654 r
.26508 .76782 m .26255 .77396 L .26839 .77624 L p F P
0 g
s
.278 .075 .415 r
.55781 .71133 m .55618 .71247 L .55588 .71746 L p F P
0 g
s
.824 .662 .681 r
.26813 .80591 m .27431 .80805 L .27074 .81453 L p F P
0 g
s
.82 .655 .678 r
.27431 .80805 m .26813 .80591 L .27148 .7995 L p F P
0 g
s
.516 .562 .841 r
.7012 .72378 m .69109 .72303 L .68915 .71913 L p F P
0 g
s
.914 .714 .618 r
.04697 .85578 m .0463 .85805 L .04261 .85412 L p F P
0 g
s
.914 .714 .618 r
.04261 .85412 m .04294 .85298 L .04697 .85578 L p F P
0 g
s
.908 .725 .644 r
.04697 .85578 m .04294 .85298 L .04509 .84694 L p F P
0 g
s
.775 .693 .774 r
.25173 .90357 m .25163 .90341 L .25151 .90351 L closepath p F P
0 g
s
.781 .716 .791 r
.23428 .91941 m .22902 .924 L .22562 .91961 L p F P
0 g
s
.441 .417 .737 r
.74492 .79996 m .74605 .79894 L p .74753 .80781 L F P
0 g
s
.441 .417 .737 r
.74753 .80781 m .74739 .80774 L .74492 .79996 L p F P
0 g
s
.447 .432 .749 r
.74492 .79996 m .74433 .7982 L .74605 .79894 L closepath p F P
0 g
s
.812 .664 .699 r
.27319 .83584 m .27567 .83182 L .27061 .83014 L closepath p F P
0 g
s
.813 .662 .695 r
.26999 .82874 m .27325 .82316 L p .27567 .83182 L F P
0 g
s
.813 .662 .695 r
.27567 .83182 m .27061 .83014 L .26999 .82874 L p F P
0 g
s
.441 .417 .736 r
.74744 .80789 m .74739 .80774 L .74753 .80781 L closepath p F P
0 g
s
.428 .397 .722 r
.74753 .80781 m .74744 .80789 L .74972 .81557 L p F P
0 g
s
.492 .518 .812 r
.7124 .74413 m .7137 .74276 L p .72077 .7501 L F P
0 g
s
.497 .53 .821 r
.7124 .74413 m .71164 .74246 L .7137 .74276 L closepath p F P
0 g
s
.447 .432 .749 r
.74605 .79894 m .74433 .7982 L .74218 .79177 L p F P
0 g
s
.774 .693 .773 r
.25151 .90351 m .25163 .90341 L .2483 .89815 L p F P
0 g
s
.789 .708 .775 r
.24475 .90164 m .25151 .90351 L .24327 .91136 L p F P
0 g
s
.774 .693 .773 r
.2483 .89815 m .24475 .90164 L .25151 .90351 L p F P
0 g
s
.231 .66 .958 r
.11714 .94015 m .12351 .94061 L .12848 .94297 L p F P
0 g
s
.287 .684 .973 r
.12351 .94061 m .11714 .94015 L .11338 .93803 L p F P
0 g
s
.903 .748 .68 r
.0426 .82886 m .04646 .83175 L .04365 .83797 L p F P
0 g
s
.897 .754 .694 r
.04646 .83175 m .0426 .82886 L .04572 .82256 L p F P
0 g
s
.781 .716 .791 r
.22562 .91961 m .22805 .9174 L .23428 .91941 L p F P
0 g
s
.77 .708 .793 r
.23692 .90948 m .22805 .9174 L .23428 .91941 L p F P
0 g
s
.77 .708 .793 r
.23428 .91941 m .24029 .91424 L .23692 .90948 L p F P
0 g
s
.441 .856 .698 r
.5759 .69181 m .57829 .69073 L .584 .68739 L p F P
0 g
s
.429 .401 .725 r
.75335 .80257 m .74753 .80781 L .75419 .81164 L p F P
0 g
s
.441 .417 .737 r
.74605 .79894 m .75335 .80257 L .74753 .80781 L p F P
0 g
s
.428 .397 .722 r
.74972 .81557 m .75419 .81164 L .74753 .80781 L p F P
0 g
s
.605 .543 .758 r
.55234 .89194 m .55344 .89488 L .54202 .89719 L p F P
0 g
s
.605 .543 .758 r
.54202 .89719 m .54134 .89535 L .55234 .89194 L p F P
0 g
s
.555 .437 .673 r
.52578 .80137 m .52544 .7998 L .53594 .79574 L p F P
0 g
s
.55 .429 .668 r
.53445 .78881 m .53594 .79574 L .52544 .7998 L p F P
0 g
s
.789 .708 .775 r
.24327 .91136 m .24029 .91424 L .23692 .90948 L p F P
0 g
s
.789 .708 .775 r
.23692 .90948 m .23706 .90934 L .24327 .91136 L p F P
0 g
s
.789 .708 .775 r
.24327 .91136 m .23706 .90934 L .24475 .90164 L p F P
0 g
s
.608 .584 .801 r
.574 .91471 m .57447 .91572 L .56368 .91932 L p F P
0 g
s
.608 .584 .801 r
.56368 .91932 m .56254 .91684 L .574 .91471 L p F P
0 g
s
.443 .879 .839 r
.69666 .93348 m .68665 .93806 L .68401 .93782 L p F P
0 g
s
.612 .927 .968 r
.68665 .93806 m .68401 .93782 L p .6725 .94206 L F P
0 g
s
.447 .432 .749 r
.74218 .79177 m .7438 .79027 L p .74605 .79894 L F P
0 g
s
.454 .447 .761 r
.74218 .79177 m .74131 .78933 L .7438 .79027 L closepath p F P
0 g
s
.516 0 0 r
.09108 .92725 m .09578 .93076 L .09217 .9289 L p F P
0 g
s
.516 0 0 r
.08633 .92479 m .09108 .92725 L p .09217 .9289 L F P
0 g
s
.554 .617 .87 r
.65321 .69664 m .66493 .69606 L .6678 .70105 L p F P
0 g
s
.554 .625 .877 r
.66206 .69112 m .66493 .69606 L .65321 .69664 L p F P
0 g
s
.554 .625 .877 r
.65605 .69149 m .66206 .69112 L p .65321 .69664 L F P
0 g
s
.554 .625 .877 r
.65321 .69664 m .65258 .6956 L .65605 .69149 L p F P
0 g
s
.604 .542 .757 r
.55039 .88673 m .55234 .89194 L .54134 .89535 L p F P
0 g
s
.604 .542 .757 r
.54134 .89535 m .53898 .88898 L .55039 .88673 L p F P
0 g
s
.731 .769 .884 r
.1742 .9421 m .1763 .94096 L .18173 .94317 L p F P
0 g
s
.718 .756 .883 r
.18519 .9362 m .1763 .94096 L .18173 .94317 L p F P
0 g
s
.718 .756 .883 r
.18173 .94317 m .18871 .93963 L .18519 .9362 L p F P
0 g
s
.846 .659 .65 r
.25943 .76547 m .26508 .76782 L .26255 .77396 L p F P
0 g
s
.841 .65 .644 r
.26169 .75943 m .25943 .76547 L .26508 .76782 L p F P
0 g
s
.795 .658 .712 r
.27483 .83952 m .27137 .83853 L p .27327 .84734 L F P
0 g
s
.798 .657 .707 r
.27483 .83952 m .27319 .83584 L .27137 .83853 L closepath p F P
0 g
s
.617 .698 .902 r
.6151 .94314 m .61483 .94277 L .61715 .94229 L closepath p F P
0 g
s
.586 .483 .704 r
.52366 .84043 m .5234 .83949 L .5343 .8359 L p F P
0 g
s
.583 .479 .701 r
.5323 .82845 m .5343 .8359 L .5234 .83949 L p F P
0 g
s
.291 .098 .436 r
.74302 .88685 m .74232 .88731 L .74084 .89342 L p F P
0 g
s
.796 .679 .736 r
.26504 .87934 m .25974 .88571 L .25645 .87995 L p F P
0 g
s
.796 .679 .736 r
.25645 .87995 m .25852 .87738 L .26504 .87934 L p F P
0 g
s
.796 .679 .736 r
.26504 .87934 m .25852 .87738 L .26429 .87023 L p F P
0 g
s
.42 .38 .707 r
.74972 .81557 m .75419 .81164 L p .75426 .8209 L F P
0 g
s
.42 .38 .707 r
.75426 .8209 m .75053 .81845 L .74972 .81557 L p F P
0 g
s
.454 .447 .761 r
.7438 .79027 m .74131 .78933 L .73919 .78332 L p F P
0 g
s
.369 .265 .604 r
.75038 .86335 m .75508 .85981 L .75237 .85484 L p F P
0 g
s
.347 .229 .573 r
.75508 .85981 m .75038 .86335 L .75113 .8694 L p F P
0 g
s
.365 .242 .576 r
.74958 .87049 m .75113 .8694 L .75038 .86335 L p F P
0 g
s
.587 .491 .712 r
.52553 .84705 m .52366 .84043 L .53504 .83862 L p F P
0 g
s
.586 .483 .704 r
.5343 .8359 m .53504 .83862 L .52366 .84043 L p F P
0 g
s
.556 .443 .68 r
.52701 .80682 m .52578 .80137 L .53719 .80139 L p F P
0 g
s
.555 .437 .673 r
.53594 .79574 m .53719 .80139 L .52578 .80137 L p F P
0 g
s
.578 .463 .685 r
.52887 .81484 m .52391 .81549 L .52865 .8139 L closepath p F P
0 g
s
.576 .456 .68 r
.52701 .80682 m .52865 .8139 L .52391 .81549 L p F P
0 g
s
.534 .73 .965 r
.19551 .68344 m .20614 .68212 L .20969 .68524 L p F P
0 g
s
.496 .531 .823 r
.7137 .74276 m .71164 .74246 L .70875 .73613 L p F P
0 g
s
.505 .537 .823 r
.70875 .73613 m .70554 .73574 L .7076 .73363 L closepath p F P
0 g
s
.512 .548 .829 r
.70587 .72999 m .7076 .73363 L .70554 .73574 L p F P
0 g
s
.808 .672 .713 r
.2667 .84535 m .27327 .84734 L .26838 .85422 L p F P
0 g
s
.795 .658 .712 r
.27137 .83853 m .2667 .84535 L .27327 .84734 L p F P
0 g
s
.83 .663 .676 r
.26545 .7973 m .27148 .7995 L .26813 .80591 L p F P
0 g
s
.826 .656 .672 r
.27148 .7995 m .26545 .7973 L .26857 .79097 L p F P
0 g
s
.38 .715 .987 r
.12848 .94297 m .13117 .94308 L .12747 .94066 L p F P
0 g
s
.38 .715 .987 r
.12747 .94066 m .12351 .94061 L .12848 .94297 L p F P
0 g
s
.619 .675 .882 r
.61715 .94229 m .61483 .94277 L .61191 .93844 L p F P
0 g
s
.421 .38 .707 r
.7518 .82301 m .75053 .81845 L .75426 .8209 L closepath p F P
0 g
s
.769 .747 .833 r
.20568 .93472 m .20326 .93644 L .19978 .93275 L p F P
0 g
s
.744 .747 .854 r
.18871 .93963 m .19978 .93275 L .20326 .93644 L p F P
0 g
s
.802 .675 .724 r
.26799 .86569 m .26988 .86313 L .26605 .86194 L closepath p F P
0 g
s
.802 .673 .721 r
.26474 .85936 m .26838 .85422 L p .26988 .86313 L F P
0 g
s
.802 .673 .721 r
.26988 .86313 m .26605 .86194 L .26474 .85936 L p F P
0 g
s
.579 .664 .896 r
.64458 .68279 m .64746 .6873 L .6358 .68865 L p F P
0 g
s
.579 .664 .896 r
.63649 .68386 m .64458 .68279 L p .6358 .68865 L F P
0 g
s
.579 .664 .896 r
.6358 .68865 m .63434 .68645 L .63649 .68386 L p F P
0 g
s
.576 .648 .884 r
.6358 .68865 m .64746 .6873 L .65033 .69191 L p F P
0 g
s
0 .321 .686 r
.10179 .93357 m .09959 .93261 L .09578 .93076 L p F P
0 g
s
.908 .571 .395 r
.06488 .90285 m .06045 .90025 L .05965 .895 L p F P
0 g
s
.912 .574 .39 r
.05529 .89236 m .05965 .895 L .06045 .90025 L p F P
0 g
s
.915 .615 .462 r
.05965 .895 m .05529 .89236 L .05519 .88953 L p F P
0 g
s
.535 .593 .859 r
.67067 .70627 m .68247 .70628 L p .67843 .71159 L F P
0 g
s
.534 .595 .862 r
.6796 .70103 m .68247 .70628 L .67067 .70627 L p F P
0 g
s
.534 .595 .862 r
.66905 .70103 m .6796 .70103 L p .67067 .70627 L F P
0 g
s
.534 .595 .862 r
.67067 .70627 m .66829 .70192 L .66905 .70103 L p F P
0 g
s
.782 .681 .752 r
.26048 .88701 m .25974 .88571 L .25892 .88659 L closepath p F P
0 g
s
.53 .582 .852 r
.68535 .71177 m .67843 .71159 L .68278 .70685 L closepath p F P
0 g
s
.535 .593 .859 r
.68247 .70628 m .68278 .70685 L .67843 .71159 L p F P
0 g
s
.854 .66 .64 r
.25622 .75701 m .26169 .75943 L .25943 .76547 L p F P
0 g
s
.85 .651 .633 r
.25819 .75106 m .25622 .75701 L .26169 .75943 L p F P
0 g
s
.483 .345 .617 r
.53884 .75144 m .5485 .74638 L p .54235 .75637 L F P
0 g
s
.483 .345 .617 r
.54235 .75637 m .53923 .75423 L .53884 .75144 L p F P
0 g
s
.463 .319 .599 r
.54772 .7402 m .5485 .74638 L .53884 .75144 L p F P
0 g
s
.606 .575 .793 r
.574 .91471 m .56254 .91684 L .55951 .90994 L p F P
0 g
s
.454 .447 .761 r
.73919 .78332 m .74079 .7818 L p .7438 .79027 L F P
0 g
s
.46 .461 .772 r
.73919 .78332 m .73832 .78097 L .74079 .7818 L closepath p F P
0 g
s
.521 .399 .654 r
.53311 .78203 m .53186 .77535 L .53839 .77236 L p F P
0 g
s
.602 .533 .749 r
.54921 .88341 m .55039 .88673 L .53898 .88898 L p F P
0 g
s
.602 .533 .749 r
.53898 .88898 m .53822 .88685 L .54921 .88341 L p F P
0 g
s
.818 .663 .69 r
.27325 .82316 m .26999 .82874 L .26679 .82162 L p F P
0 g
s
.818 .663 .69 r
.26679 .82162 m .26713 .82103 L .27325 .82316 L p F P
0 g
s
.819 .661 .687 r
.27325 .82316 m .26713 .82103 L .27074 .81453 L p F P
0 g
s
.56 .635 .882 r
.65258 .6956 m .65033 .69191 L .65605 .69149 L closepath p F P
0 g
s
.922 .628 .469 r
.05516 .88694 m .05519 .88953 L .0516 .89007 L p F P
0 g
s
.922 .628 .469 r
.05094 .88425 m .05516 .88694 L p .0516 .89007 L F P
0 g
s
.92 .654 .518 r
.05516 .88694 m .05094 .88425 L .05136 .87867 L p F P
0 g
s
.588 .492 .712 r
.52673 .85128 m .52553 .84705 L .53643 .84348 L p F P
0 g
s
.587 .491 .712 r
.53504 .83862 m .53643 .84348 L .52553 .84705 L p F P
0 g
s
.892 .51 .303 r
.07089 .91048 m .0664 .90791 L .06488 .90285 L p F P
0 g
s
.895 .511 .295 r
.06045 .90025 m .06488 .90285 L .0664 .90791 L p F P
0 g
s
.756 .733 .832 r
.21095 .92457 m .20001 .93257 L .20568 .93472 L p F P
0 g
s
.756 .733 .832 r
.20568 .93472 m .2144 .92861 L .21095 .92457 L p F P
0 g
s
.769 .747 .833 r
.19978 .93275 m .20001 .93257 L .20568 .93472 L p F P
0 g
s
.916 .714 .615 r
.04527 .86169 m .0463 .85805 L .04261 .85412 L p F P
0 g
s
.601 .532 .748 r
.54733 .87814 m .54921 .88341 L .53822 .88685 L p F P
0 g
s
.601 .532 .748 r
.53822 .88685 m .53592 .88032 L .54733 .87814 L p F P
0 g
s
.269 .081 .431 r
.75043 .88171 m .74302 .88685 L .74293 .89205 L p F P
0 g
s
.291 .098 .436 r
.74084 .89342 m .74293 .89205 L .74302 .88685 L p F P
0 g
s
.311 .148 .492 r
.74302 .88685 m .75043 .88171 L .75055 .87595 L p F P
0 g
s
.8 .66 .708 r
.27137 .83853 m .27319 .83584 L .27061 .83014 L p F P
0 g
s
.177 0 .255 r
.73788 .89992 m .73346 .90277 L .73265 .90725 L p F P
0 g
s
.246 .021 .361 r
.73346 .90277 m .73788 .89992 L .74084 .89342 L p F P
0 g
s
.911 .73 .644 r
.04115 .8441 m .04509 .84694 L .04294 .85298 L p F P
0 g
s
.905 .738 .663 r
.04509 .84694 m .04115 .8441 L .04365 .83797 L p F P
0 g
s
.408 .359 .692 r
.75426 .8209 m .7518 .82301 L .75368 .83024 L p F P
0 g
s
.424 .37 .693 r
.75352 .83037 m .75368 .83024 L .7518 .82301 L p F P
0 g
s
.46 .461 .773 r
.74079 .7818 m .73832 .78097 L .73596 .77458 L p F P
0 g
s
.278 .075 .415 r
.55588 .71746 m .55623 .71722 L .55781 .71133 L p F P
0 g
s
.271 .069 .412 r
.56494 .7063 m .55781 .71133 L .55623 .71722 L p F P
0 g
s
.168 0 .262 r
.55781 .71133 m .56494 .7063 L .5658 .70191 L p F P
0 g
s
.366 .264 .604 r
.758 .85053 m .75237 .85484 L .75508 .85981 L p F P
0 g
s
.386 .297 .631 r
.75722 .84636 m .75594 .84464 L p .75237 .85484 L F P
0 g
s
.386 .297 .631 r
.75237 .85484 m .758 .85053 L .75722 .84636 L p F P
0 g
s
.441 .856 .698 r
.584 .68739 m .58793 .68375 L p .5759 .69181 L F P
0 g
s
.706 .927 .965 r
.584 .68739 m .58793 .68375 L .5897 .68449 L closepath p F P
0 g
s
.588 .492 .712 r
.53643 .84348 m .53812 .84938 L .52673 .85128 L p F P
0 g
s
.591 .5 .72 r
.52775 .85472 m .52673 .85128 L .53812 .84938 L p F P
0 g
s
.454 .299 .58 r
.54753 .73828 m .54534 .73522 L .54715 .73425 L closepath p F P
0 g
s
.789 .671 .733 r
.26429 .87023 m .26799 .86569 L .26605 .86194 L p F P
0 g
s
.832 .657 .665 r
.26857 .79097 m .2627 .78872 L .2656 .78246 L p F P
0 g
s
.835 .664 .67 r
.2627 .78872 m .26857 .79097 L .26545 .7973 L p F P
0 g
s
.782 .681 .752 r
.25892 .88659 m .25974 .88571 L .25645 .87995 L p F P
0 g
s
.437 .417 .739 r
.75172 .79371 m .74605 .79894 L .75335 .80257 L p F P
0 g
s
.447 .432 .749 r
.7438 .79027 m .75172 .79371 L .74605 .79894 L p F P
0 g
s
.923 .658 .517 r
.0472 .87595 m .05136 .87867 L .05094 .88425 L p F P
0 g
s
.92 .678 .556 r
.05136 .87867 m .0472 .87595 L .04807 .87026 L p F P
0 g
s
.863 .661 .627 r
.25292 .74857 m .25819 .75106 L .25622 .75701 L p F P
0 g
s
.863 .651 .614 r
.25819 .75106 m .25292 .74857 L .25457 .74273 L p F P
0 g
s
.593 .502 .721 r
.52775 .85472 m .53866 .85115 L p .53685 .8603 L F P
0 g
s
.593 .502 .721 r
.53685 .8603 m .5298 .86153 L .52775 .85472 L p F P
0 g
s
.591 .5 .72 r
.53812 .84938 m .53866 .85115 L .52775 .85472 L p F P
0 g
s
.796 .695 .754 r
.25222 .88469 m .25892 .88659 L .25202 .89407 L p F P
0 g
s
.782 .681 .752 r
.25645 .87995 m .25222 .88469 L .25892 .88659 L p F P
0 g
s
.516 .562 .841 r
.68915 .71913 m .69065 .71744 L p .7012 .72378 L F P
0 g
s
.521 .572 .848 r
.68915 .71913 m .68822 .71731 L .69065 .71744 L closepath p F P
0 g
s
.599 .523 .74 r
.5463 .87509 m .54733 .87814 L .53592 .88032 L p F P
0 g
s
.599 .523 .74 r
.53592 .88032 m .53533 .87856 L .5463 .87509 L p F P
0 g
s
.558 .446 .682 r
.52865 .8139 m .52701 .80682 L .5375 .80274 L p F P
0 g
s
.556 .443 .68 r
.53719 .80139 m .5375 .80274 L .52701 .80682 L p F P
0 g
s
.86 .425 .178 r
.07774 .91787 m .07322 .91533 L .07089 .91048 L p F P
0 g
s
.86 .422 .165 r
.0664 .90791 m .07089 .91048 L .07322 .91533 L p F P
0 g
s
.598 .522 .739 r
.54427 .86908 m .5463 .87509 L .53533 .87856 L p F P
0 g
s
.598 .522 .739 r
.53533 .87856 m .53286 .87119 L .54427 .86908 L p F P
0 g
s
.619 .686 .891 r
.62638 .94037 m .61715 .94229 L .6255 .9391 L closepath p F P
0 g
s
.619 .675 .882 r
.62348 .93622 m .6255 .9391 L .61715 .94229 L p F P
0 g
s
.619 .675 .882 r
.61191 .93844 m .62348 .93622 L p .61715 .94229 L F P
0 g
s
.612 .566 .778 r
.55951 .90994 m .55747 .91038 L .55944 .90978 L closepath p F P
0 g
s
.611 .564 .777 r
.55648 .90261 m .55944 .90978 L .55747 .91038 L p F P
0 g
s
.339 .198 .539 r
.75113 .8694 m .74958 .87049 L .75055 .87595 L p F P
0 g
s
.594 .51 .729 r
.5301 .8625 m .5298 .86153 L .53685 .8603 L closepath p F P
0 g
s
.594 .511 .73 r
.53262 .87044 m .5301 .8625 L .53685 .8603 L p F P
0 g
s
.597 .513 .731 r
.53286 .87119 m .53262 .87044 L .54358 .86695 L p F P
0 g
s
.594 .511 .73 r
.5412 .85952 m .54358 .86695 L .53262 .87044 L p F P
0 g
s
.594 .511 .73 r
.53685 .8603 m .5412 .85952 L p .53262 .87044 L F P
0 g
s
.597 .513 .731 r
.54358 .86695 m .54427 .86908 L .53286 .87119 L p F P
0 g
s
.811 .671 .708 r
.26488 .83651 m .27137 .83853 L .2667 .84535 L p F P
0 g
s
.8 .66 .708 r
.26934 .82976 m .26488 .83651 L .27137 .83853 L p F P
0 g
s
.8 .66 .708 r
.27061 .83014 m .26934 .82976 L p .27137 .83853 L F P
0 g
s
.676 .146 0 r
.22554 .69494 m .22696 .69646 L .22339 .69406 L p F P
0 g
s
.612 .655 .868 r
.59744 .93592 m .60898 .93375 L .61191 .93844 L p F P
0 g
s
.608 .63 .848 r
.60637 .9293 m .60898 .93375 L .59744 .93592 L p F P
0 g
s
.608 .63 .848 r
.59744 .93592 m .59595 .93331 L .60637 .9293 L p F P
0 g
s
.492 .518 .812 r
.7137 .74276 m .72366 .7445 L p .72077 .7501 L F P
0 g
s
.489 .52 .816 r
.7137 .74276 m .72366 .7445 L .72076 .73796 L p F P
0 g
s
.489 .52 .816 r
.72076 .73796 m .71854 .73758 L .7137 .74276 L p F P
0 g
s
.496 .531 .823 r
.70875 .73613 m .71854 .73758 L .7137 .74276 L p F P
0 g
s
.824 .667 .688 r
.26474 .81234 m .27074 .81453 L .26713 .82103 L p F P
0 g
s
.824 .662 .681 r
.27074 .81453 m .26474 .81234 L .26813 .80591 L p F P
0 g
s
.61 .616 .833 r
.58 .92722 m .5915 .92513 L .59448 .93072 L p F P
0 g
s
.607 .598 .816 r
.58998 .9221 m .5915 .92513 L .58 .92722 L p F P
0 g
s
.607 .598 .816 r
.58 .92722 m .57934 .92587 L .58998 .9221 L p F P
0 g
s
.642 .736 .917 r
.60404 .68238 m .61557 .67906 L .61845 .68264 L p F P
0 g
s
.662 .762 .924 r
.61557 .67906 m .60404 .68238 L .60116 .67965 L p F P
0 g
s
.695 .812 .937 r
.5897 .68449 m .60116 .67965 L .60404 .68238 L p F P
0 g
s
.873 .66 .612 r
.24949 .74017 m .25457 .74273 L .25292 .74857 L p F P
0 g
s
.874 .648 .593 r
.25457 .74273 m .24949 .74017 L .25077 .73445 L p F P
0 g
s
.479 .346 .622 r
.53974 .75775 m .53923 .75423 L .54235 .75637 L closepath p F P
0 g
s
.617 .751 .941 r
.62927 .94408 m .64085 .94147 L .64369 .94455 L p F P
0 g
s
.614 .721 .922 r
.64085 .94147 m .62927 .94408 L .62638 .94037 L p F P
0 g
s
.46 .461 .773 r
.73596 .77458 m .73702 .77353 L p .74079 .7818 L F P
0 g
s
.466 .475 .783 r
.73596 .77458 m .73536 .77304 L .73702 .77353 L closepath p F P
0 g
s
.595 .907 .982 r
.67241 .94203 m .67298 .94183 L .6725 .94206 L closepath p F P
0 g
s
.612 .927 .968 r
.68401 .93782 m .67298 .94183 L .6725 .94206 L p F P
0 g
s
.923 .682 .555 r
.04398 .8675 m .04807 .87026 L .0472 .87595 L p F P
0 g
s
.918 .697 .587 r
.04807 .87026 m .04398 .8675 L .04527 .86169 L p F P
0 g
s
.409 .344 .673 r
.75375 .83057 m .75352 .83037 L .75368 .83024 L closepath p F P
0 g
s
.802 .686 .737 r
.25777 .86826 m .26429 .87023 L .25852 .87738 L p F P
0 g
s
.789 .671 .733 r
.26333 .86116 m .25777 .86826 L .26429 .87023 L p F P
0 g
s
.789 .671 .733 r
.26605 .86194 m .26333 .86116 L p .26429 .87023 L F P
0 g
s
.842 .665 .663 r
.25989 .78014 m .2656 .78246 L .2627 .78872 L p F P
0 g
s
.839 .658 .658 r
.2656 .78246 m .25989 .78014 L .26255 .77396 L p F P
0 g
s
.807 .673 .715 r
.26838 .85422 m .26474 .85936 L .26149 .85302 L p F P
0 g
s
.807 .673 .715 r
.26149 .85302 m .26208 .85217 L .26838 .85422 L p F P
0 g
s
.808 .672 .713 r
.26838 .85422 m .26208 .85217 L .2667 .84535 L p F P
0 g
s
.75 .744 .847 r
.19978 .93275 m .18871 .93963 L .18519 .9362 L p F P
0 g
s
.589 .892 .989 r
.67298 .94183 m .67241 .94203 L .66969 .94054 L p F P
0 g
s
.598 .87 .993 r
.65808 .94397 m .66969 .94054 L .67241 .94203 L p F P
0 g
s
.217 .572 .94 r
.21142 .68564 m .20969 .68524 L .20614 .68212 L p F P
0 g
s
.796 .695 .754 r
.25202 .89407 m .2483 .89815 L .24497 .89293 L p F P
0 g
s
.796 .695 .754 r
.24497 .89293 m .24574 .89205 L .25202 .89407 L p F P
0 g
s
.796 .695 .754 r
.25202 .89407 m .24574 .89205 L .25222 .88469 L p F P
0 g
s
.396 .336 .672 r
.75368 .83024 m .75971 .8251 L p .75827 .83476 L F P
0 g
s
.396 .336 .672 r
.75827 .83476 m .75375 .83057 L .75368 .83024 L p F P
0 g
s
.408 .359 .692 r
.75368 .83024 m .75971 .8251 L .75426 .8209 L p F P
0 g
s
.466 .475 .784 r
.73702 .77353 m .73536 .77304 L .73245 .76553 L p F P
0 g
s
.779 .732 .809 r
.21788 .92579 m .2144 .92861 L .21095 .92457 L p F P
0 g
s
.397 .336 .672 r
.75532 .83722 m .75375 .83057 L .75827 .83476 L closepath p F P
0 g
s
.519 .575 .851 r
.69065 .71744 m .68822 .71731 L .68535 .71177 L p F P
0 g
s
.553 .762 .975 r
.13117 .94308 m .14174 .94139 L .1454 .94405 L p F P
0 g
s
.572 .766 .97 r
.14174 .94139 m .13117 .94308 L .12747 .94066 L p F P
0 g
s
.886 .642 .564 r
.25077 .73445 m .24589 .73181 L .24675 .72623 L p F P
0 g
s
.884 .658 .591 r
.24589 .73181 m .25077 .73445 L .24949 .74017 L p F P
0 g
s
.589 .892 .989 r
.68218 .93717 m .67298 .94183 L p .66969 .94054 L F P
0 g
s
.602 .911 .981 r
.67298 .94183 m .68218 .93717 L .68401 .93782 L closepath p F P
0 g
s
.454 .447 .761 r
.74079 .7818 m .74931 .78505 L .7438 .79027 L p F P
0 g
s
.444 .433 .752 r
.74931 .78505 m .7438 .79027 L .75172 .79371 L p F P
0 g
s
.605 .597 .816 r
.58851 .91918 m .58998 .9221 L .57934 .92587 L p F P
0 g
s
.605 .597 .816 r
.57934 .92587 m .57701 .92114 L .58851 .91918 L p F P
0 g
s
.803 .658 .702 r
.27061 .83014 m .26999 .82874 L .26934 .82976 L closepath p F P
0 g
s
.805 .317 .025 r
.07774 .91787 m .07859 .91917 L .07472 .91752 L p F P
0 g
s
.805 .317 .025 r
.07472 .91752 m .07322 .91533 L .07774 .91787 L p F P
0 g
s
.779 .732 .809 r
.21095 .92457 m .21201 .92368 L .21788 .92579 L p F P
0 g
s
.767 .721 .809 r
.22209 .91532 m .21201 .92368 L .21788 .92579 L p F P
0 g
s
.767 .721 .809 r
.22234 .91539 m .22209 .91532 L p .21788 .92579 L F P
0 g
s
.767 .721 .809 r
.21788 .92579 m .22562 .91961 L .22234 .91539 L p F P
0 g
s
.584 .671 .9 r
.63434 .68645 m .63292 .68436 L .63649 .68386 L closepath p F P
0 g
s
.793 .67 .728 r
.26605 .86194 m .26474 .85936 L .26333 .86116 L closepath p F P
0 g
s
.604 .561 .78 r
.57027 .90618 m .57098 .90787 L .55951 .90994 L p F P
0 g
s
.604 .561 .78 r
.55951 .90994 m .55944 .90978 L .57027 .90618 L p F P
0 g
s
.606 .575 .793 r
.55951 .90994 m .57098 .90787 L .574 .91471 L p F P
0 g
s
.602 .56 .78 r
.56795 .90064 m .57027 .90618 L .55944 .90978 L p F P
0 g
s
.602 .56 .78 r
.55944 .90978 m .55648 .90261 L .56795 .90064 L p F P
0 g
s
.609 .693 .902 r
.61845 .68264 m .63004 .68028 L .63292 .68436 L p F P
0 g
s
.62 .708 .908 r
.63004 .68028 m .61845 .68264 L .61557 .67906 L p F P
0 g
s
.909 .742 .664 r
.03978 .83509 m .04365 .83797 L .04115 .8441 L p F P
0 g
s
.903 .748 .68 r
.04365 .83797 m .03978 .83509 L .0426 .82886 L p F P
0 g
s
.432 .283 .577 r
.54715 .73425 m .55636 .72864 L p .54842 .73977 L F P
0 g
s
.432 .283 .577 r
.54842 .73977 m .54753 .73828 L .54715 .73425 L p F P
0 g
s
.398 .238 .545 r
.55597 .72289 m .55636 .72864 L .54715 .73425 L p F P
0 g
s
.495 .532 .824 r
.71854 .73758 m .70875 .73613 L .7076 .73363 L p F P
0 g
s
.805 .661 .703 r
.26934 .82976 m .26999 .82874 L .26679 .82162 L p F P
0 g
s
.78 .695 .77 r
.24475 .90164 m .2483 .89815 L .24497 .89293 L p F P
0 g
s
.912 .549 .332 r
.23767 .71011 m .23342 .70723 L .23232 .7023 L p F P
0 g
s
.92 .558 .326 r
.22828 .69935 m .23232 .7023 L .23342 .70723 L p F P
0 g
s
.864 .416 .09 r
.22696 .69646 m .22828 .69935 L .23232 .7023 L p F P
0 g
s
.896 .652 .561 r
.24208 .72351 m .24675 .72623 L .24589 .73181 L p F P
0 g
s
.899 .63 .521 r
.24675 .72623 m .24208 .72351 L .24243 .7181 L p F P
0 g
s
.531 .409 .659 r
.53311 .78203 m .54321 .7775 L p .5373 .78754 L F P
0 g
s
.531 .409 .659 r
.5373 .78754 m .53407 .78695 L .53311 .78203 L p F P
0 g
s
.521 .399 .654 r
.5424 .77331 m .54321 .7775 L .53311 .78203 L p F P
0 g
s
.521 .399 .654 r
.53839 .77236 m .5424 .77331 L p .53311 .78203 L F P
0 g
s
.615 .805 .973 r
.64369 .94455 m .65529 .94161 L .65808 .94397 L p F P
0 g
s
.616 .768 .953 r
.65529 .94161 m .64369 .94455 L .64085 .94147 L p F P
0 g
s
.486 .506 .803 r
.72077 .7501 m .72657 .75128 L p .72705 .75767 L F P
0 g
s
.484 .507 .806 r
.72657 .75128 m .72077 .7501 L .72446 .74632 L closepath p F P
0 g
s
.492 .518 .812 r
.72366 .7445 m .72446 .74632 L .72077 .7501 L p F P
0 g
s
.919 .619 .46 r
.05529 .89236 m .0516 .89007 L .05519 .88953 L closepath p F P
0 g
s
.654 .914 .979 r
.58793 .68375 m .5897 .68449 L .60116 .67965 L p F P
0 g
s
.562 .452 .686 r
.52887 .81484 m .52865 .8139 L .5392 .8099 L p F P
0 g
s
.558 .446 .682 r
.5375 .80274 m .5392 .8099 L .52865 .8139 L p F P
0 g
s
.028 .526 .875 r
.10179 .93357 m .10963 .93582 L .10586 .93353 L p F P
0 g
s
.028 .526 .875 r
.10586 .93353 m .09683 .93118 L .10179 .93357 L p F P
0 g
s
0 .321 .686 r
.09578 .93076 m .09683 .93118 L .10179 .93357 L p F P
0 g
s
.831 .669 .682 r
.26226 .80367 m .26813 .80591 L .26474 .81234 L p F P
0 g
s
.83 .663 .676 r
.26813 .80591 m .26226 .80367 L .26545 .7973 L p F P
0 g
s
.792 .71 .774 r
.23836 .89966 m .24475 .90164 L .23706 .90934 L p F P
0 g
s
.78 .695 .77 r
.24497 .89293 m .23836 .89966 L .24475 .90164 L p F P
0 g
s
.848 .667 .656 r
.257 .77158 m .26255 .77396 L .25989 .78014 L p F P
0 g
s
.846 .659 .65 r
.26255 .77396 m .257 .77158 L .25943 .76547 L p F P
0 g
s
.909 .64 .518 r
.23796 .71531 m .24243 .7181 L .24208 .72351 L p F P
0 g
s
.911 .605 .452 r
.24243 .7181 m .23796 .71531 L .23767 .71011 L p F P
0 g
s
.612 .83 .984 r
.66969 .94054 m .65808 .94397 L .65529 .94161 L p F P
0 g
s
.92 .614 .448 r
.23342 .70723 m .23767 .71011 L .23796 .71531 L p F P
0 g
s
.916 .714 .615 r
.04261 .85412 m .04125 .85889 L .04527 .86169 L p F P
0 g
s
.922 .701 .587 r
.04125 .85889 m .04527 .86169 L .04398 .8675 L p F P
0 g
s
.417 .855 .75 r
.69666 .93348 m .69794 .93281 L .6982 .93273 L closepath p F P
0 g
s
.443 .879 .839 r
.69794 .93281 m .69666 .93348 L p .68401 .93782 L F P
0 g
s
.814 .67 .704 r
.26295 .8277 m .26934 .82976 L .26488 .83651 L p F P
0 g
s
.805 .661 .703 r
.26679 .82162 m .26295 .8277 L .26934 .82976 L p F P
0 g
s
.564 .459 .694 r
.53044 .82114 m .52887 .81484 L .54029 .81441 L p F P
0 g
s
.562 .452 .686 r
.5392 .8099 m .54029 .81441 L .52887 .81484 L p F P
0 g
s
0 0 0 r
.70972 .92633 m .71471 .92313 L .71064 .92545 L closepath p F P
0 g
s
0 0 0 r
.72119 .91844 m .71471 .92313 L .71064 .92545 L p F P
0 g
s
0 0 0 r
.72207 .9168 m .72119 .91844 L p .71064 .92545 L F P
0 g
s
0 0 0 r
.6982 .93273 m .70972 .92633 L .71064 .92545 L p F P
0 g
s
.451 .449 .765 r
.74612 .7766 m .74079 .7818 L .74931 .78505 L p F P
0 g
s
.46 .461 .773 r
.73702 .77353 m .74612 .7766 L .74079 .7818 L p F P
0 g
s
.785 .724 .796 r
.22562 .91961 m .22805 .9174 L .22234 .91539 L closepath p F P
0 g
s
.787 .723 .793 r
.23675 .90924 m .23692 .90948 L .22805 .9174 L p F P
0 g
s
.787 .723 .793 r
.23057 .90739 m .23675 .90924 L p .22805 .9174 L F P
0 g
s
.787 .723 .793 r
.22221 .91522 m .23057 .90739 L p .22805 .9174 L F P
0 g
s
.787 .723 .793 r
.22805 .9174 m .22234 .91539 L .22221 .91522 L p F P
0 g
s
.541 .606 .867 r
.66829 .70192 m .6678 .70105 L .66905 .70103 L closepath p F P
0 g
s
.239 .013 .356 r
.74293 .89205 m .74084 .89342 L .73788 .89992 L p F P
0 g
s
.108 0 .24 r
.57045 .69821 m .5658 .70191 L .56494 .7063 L p F P
0 g
s
.056 0 .025 r
.57546 .69236 m .57045 .69821 L .5658 .70191 L p F P
0 g
s
.056 0 .025 r
.5759 .69181 m .57546 .69236 L p .5658 .70191 L F P
0 g
s
.739 .772 .88 r
.1763 .94096 m .1742 .9421 L .17063 .93894 L p F P
0 g
s
.695 .768 .908 r
.15976 .94362 m .17063 .93894 L .1742 .9421 L p F P
0 g
s
.608 .63 .847 r
.60602 .92871 m .60637 .9293 L .59595 .93331 L p F P
0 g
s
.608 .63 .847 r
.59595 .93331 m .59448 .93072 L .60602 .92871 L p F P
0 g
s
.486 .361 .634 r
.54235 .75637 m .53974 .75775 L .54079 .76421 L p F P
0 g
s
.791 .712 .777 r
.23692 .90948 m .23706 .90934 L .23675 .90924 L closepath p F P
0 g
s
.792 .71 .774 r
.23355 .90465 m .23836 .89966 L p .23706 .90934 L F P
0 g
s
.792 .71 .774 r
.23706 .90934 m .23675 .90924 L .23355 .90465 L p F P
0 g
s
.801 .688 .74 r
.25645 .87995 m .25852 .87738 L .25414 .87595 L closepath p F P
0 g
s
.802 .686 .737 r
.25315 .87421 m .25777 .86826 L p .25852 .87738 L F P
0 g
s
.802 .686 .737 r
.25852 .87738 m .25414 .87595 L .25315 .87421 L p F P
0 g
s
.319 .184 .535 r
.75695 .86503 m .75113 .8694 L .75164 .87519 L p F P
0 g
s
.347 .229 .573 r
.75113 .8694 m .75695 .86503 L .75508 .85981 L p F P
0 g
s
.339 .198 .539 r
.75055 .87595 m .75164 .87519 L .75113 .8694 L p F P
0 g
s
.486 .893 .768 r
.69794 .93281 m .6982 .93273 L .70972 .92633 L p F P
0 g
s
.486 .506 .803 r
.72657 .75128 m .72861 .75611 L .72705 .75767 L p F P
0 g
s
.479 .494 .796 r
.72948 .75824 m .72705 .75767 L .72861 .75611 L closepath p F P
0 g
s
.794 .672 .729 r
.26333 .86116 m .26474 .85936 L .26149 .85302 L p F P
0 g
s
.778 .707 .785 r
.23675 .90924 m .23355 .90465 L .23057 .90739 L closepath p F P
0 g
s
.645 .773 .941 r
.1454 .94405 m .15614 .94072 L .15976 .94362 L p F P
0 g
s
.657 .774 .935 r
.15614 .94072 m .1454 .94405 L .14174 .94139 L p F P
0 g
s
.559 .639 .887 r
.65605 .69149 m .65033 .69191 L .64746 .6873 L p F P
0 g
s
.458 .464 .777 r
.74216 .76836 m .73702 .77353 L .74612 .7766 L p F P
0 g
s
.466 .475 .784 r
.73251 .76547 m .74216 .76836 L .73702 .77353 L p F P
0 g
s
.466 .475 .784 r
.73245 .76553 m .73251 .76547 L p .73702 .77353 L F P
0 g
s
.813 .677 .714 r
.26046 .84327 m .2667 .84535 L .26208 .85217 L p F P
0 g
s
.811 .671 .708 r
.2667 .84535 m .26046 .84327 L .26488 .83651 L p F P
0 g
s
.501 .543 .832 r
.7076 .73363 m .70587 .72999 L .71036 .73054 L closepath p F P
0 g
s
.495 .532 .824 r
.7076 .73363 m .71036 .73054 L p .71854 .73758 L F P
0 g
s
.472 .488 .794 r
.73245 .76553 m .73241 .76544 L .73251 .76547 L closepath p F P
0 g
s
.471 .489 .795 r
.73251 .76547 m .73241 .76544 L .72948 .75824 L p F P
0 g
s
.856 .668 .648 r
.25405 .76303 m .25943 .76547 L .257 .77158 L p F P
0 g
s
.854 .66 .64 r
.25943 .76547 m .25405 .76303 L .25622 .75701 L p F P
0 g
s
.464 .478 .788 r
.73743 .76033 m .73251 .76547 L .74216 .76836 L p F P
0 g
s
.471 .489 .795 r
.72948 .75824 m .73743 .76033 L .73251 .76547 L p F P
0 g
s
.217 .572 .94 r
.20614 .68212 m .20781 .68252 L .21142 .68564 L p F P
0 g
s
.704 .767 .901 r
.17063 .93894 m .15976 .94362 L .15614 .94072 L p F P
0 g
s
.539 .61 .872 r
.66905 .70103 m .6678 .70105 L .66493 .69606 L p F P
0 g
s
.794 .672 .729 r
.26149 .85302 m .25681 .85917 L .26333 .86116 L p F P
0 g
s
.806 .683 .729 r
.25681 .85917 m .26333 .86116 L .25777 .86826 L p F P
0 g
s
.399 .324 .655 r
.75594 .84464 m .75677 .844 L .75532 .83722 L p F P
0 g
s
.382 .312 .653 r
.75827 .83476 m .75532 .83722 L .75677 .844 L p F P
0 g
s
.838 .671 .676 r
.25972 .79501 m .26545 .7973 L .26226 .80367 L p F P
0 g
s
.835 .664 .67 r
.26545 .7973 m .25972 .79501 L .2627 .78872 L p F P
0 g
s
.739 .772 .88 r
.17063 .93894 m .17112 .93867 L .1763 .94096 L p F P
0 g
s
.726 .757 .877 r
.18165 .93274 m .17112 .93867 L .1763 .94096 L p F P
0 g
s
.726 .757 .877 r
.1763 .94096 m .18519 .9362 L .18165 .93274 L p F P
0 g
s
.333 .163 .495 r
.55623 .71722 m .55588 .71746 L .55597 .72289 L p F P
0 g
s
.788 .684 .75 r
.25222 .88469 m .25645 .87995 L .25414 .87595 L p F P
0 g
s
.516 .562 .841 r
.69065 .71744 m .70011 .71814 L p .7012 .72378 L F P
0 g
s
.515 .566 .845 r
.69065 .71744 m .70011 .71814 L .69723 .7124 L p F P
0 g
s
.515 .566 .845 r
.69723 .7124 m .69517 .71225 L .69065 .71744 L p F P
0 g
s
.519 .575 .851 r
.68535 .71177 m .69517 .71225 L .69065 .71744 L p F P
0 g
s
.873 .431 .098 r
.22828 .69935 m .22696 .69646 L .22339 .69406 L p F P
0 g
s
.725 .194 0 r
.07859 .91917 m .08165 .9223 L .08633 .92479 L p F P
0 g
s
.702 .163 0 r
.08165 .9223 m .07859 .91917 L .07472 .91752 L p F P
0 g
s
.567 .463 .695 r
.53044 .82114 m .54098 .81714 L p .53634 .82692 L F P
0 g
s
.567 .463 .695 r
.53634 .82692 m .53196 .82716 L .53044 .82114 L p F P
0 g
s
.564 .459 .694 r
.54029 .81441 m .54098 .81714 L .53044 .82114 L p F P
0 g
s
.608 .661 .876 r
.62348 .93622 m .61191 .93844 L .60898 .93375 L p F P
0 g
s
.6 .55 .77 r
.56651 .89705 m .56795 .90064 L .55648 .90261 L p F P
0 g
s
.6 .55 .77 r
.55648 .90261 m .55573 .90071 L .56651 .89705 L p F P
0 g
s
.486 .893 .768 r
.70972 .92633 m .70743 .92761 L .69794 .93281 L p F P
0 g
s
.507 .911 .852 r
.69561 .93308 m .69794 .93281 L .70743 .92761 L p F P
0 g
s
.443 .879 .839 r
.68401 .93782 m .69561 .93308 L .69794 .93281 L p F P
0 g
s
.918 .719 .618 r
.04294 .85298 m .04261 .85412 L .03886 .8506 L p F P
0 g
s
.918 .719 .618 r
.03886 .8506 m .03899 .85015 L .04294 .85298 L p F P
0 g
s
.911 .73 .644 r
.04294 .85298 m .03899 .85015 L .04115 .8441 L p F P
0 g
s
.529 .414 .666 r
.53445 .78881 m .53407 .78695 L .5373 .78754 L closepath p F P
0 g
s
.823 .67 .693 r
.26679 .82162 m .26713 .82103 L .26639 .82075 L closepath p F P
0 g
s
.824 .667 .688 r
.26358 .81447 m .26474 .81234 L p .26713 .82103 L F P
0 g
s
.824 .667 .688 r
.26713 .82103 m .26639 .82075 L .26358 .81447 L p F P
0 g
s
.516 0 0 r
.09217 .9289 m .09192 .92876 L .08633 .92479 L p F P
0 g
s
.488 0 0 r
.08165 .9223 m .08633 .92479 L .09192 .92876 L p F P
0 g
s
0 0 0 r
.72119 .91844 m .72583 .91452 L .72207 .9168 L closepath p F P
0 g
s
.037 0 .065 r
.73251 .90774 m .72583 .91452 L .72207 .9168 L p F P
0 g
s
.037 0 .065 r
.73265 .90725 m .73251 .90774 L p .72207 .9168 L F P
0 g
s
.601 .584 .806 r
.58551 .91286 m .58851 .91918 L .57701 .92114 L p F P
0 g
s
.601 .584 .806 r
.57963 .91382 m .58551 .91286 L p .57701 .92114 L F P
0 g
s
.601 .584 .806 r
.57701 .92114 m .57447 .91572 L .57963 .91382 L p F P
0 g
s
.333 .163 .495 r
.55597 .72289 m .55637 .72262 L .55623 .71722 L p F P
0 g
s
.328 .16 .494 r
.56464 .7113 m .55623 .71722 L .55637 .72262 L p F P
0 g
s
.271 .069 .412 r
.55623 .71722 m .56464 .7113 L .56494 .7063 L p F P
0 g
s
.407 .36 .693 r
.76003 .81589 m .75426 .8209 L .75971 .8251 L p F P
0 g
s
.42 .38 .707 r
.75987 .81533 m .76003 .81589 L .75426 .8209 L p F P
0 g
s
.42 .38 .707 r
.75419 .81164 m .75987 .81533 L p .75426 .8209 L F P
0 g
s
.811 .665 .702 r
.26295 .8277 m .26679 .82162 L .26639 .82075 L p F P
0 g
s
.598 .549 .77 r
.56491 .89302 m .56651 .89705 L .55573 .90071 L p F P
0 g
s
.598 .549 .77 r
.55573 .90071 m .55344 .89488 L .56491 .89302 L p F P
0 g
s
.582 .68 .908 r
.63649 .68386 m .63292 .68436 L .63004 .68028 L p F P
0 g
s
.863 .661 .627 r
.25622 .75701 m .25102 .7545 L .25292 .74857 L p F P
0 g
s
.864 .669 .638 r
.25102 .7545 m .25622 .75701 L .25405 .76303 L p F P
0 g
s
.409 .726 .989 r
.12351 .94061 m .12747 .94066 L .12376 .93818 L p F P
0 g
s
.409 .726 .989 r
.12376 .93818 m .11852 .93824 L .12351 .94061 L p F P
0 g
s
.287 .684 .973 r
.11338 .93803 m .11852 .93824 L .12351 .94061 L p F P
0 g
s
.77 .75 .835 r
.19978 .93275 m .20001 .93257 L .19938 .93232 L closepath p F P
0 g
s
.75 .744 .847 r
.19938 .93232 m .19978 .93275 L p .18519 .9362 L F P
0 g
s
.8 .699 .753 r
.24586 .88268 m .25222 .88469 L .24574 .89205 L p F P
0 g
s
.788 .684 .75 r
.25216 .87537 m .24586 .88268 L .25222 .88469 L p F P
0 g
s
.788 .684 .75 r
.25414 .87595 m .25216 .87537 L p .25222 .88469 L F P
0 g
s
.772 .748 .832 r
.20932 .92267 m .21095 .92457 L .20001 .93257 L p F P
0 g
s
.772 .748 .832 r
.20601 .9216 m .20932 .92267 L p .20001 .93257 L F P
0 g
s
.772 .748 .832 r
.19629 .92899 m .20601 .9216 L p .20001 .93257 L F P
0 g
s
.772 .748 .832 r
.20001 .93257 m .19938 .93232 L .19629 .92899 L p F P
0 g
s
.538 .604 .867 r
.66905 .70103 m .6796 .70103 L .67673 .69582 L p F P
0 g
s
.538 .604 .867 r
.67673 .69582 m .67333 .69585 L .66905 .70103 L p F P
0 g
s
.539 .61 .872 r
.66493 .69606 m .67333 .69585 L .66905 .70103 L p F P
0 g
s
.811 .665 .702 r
.26639 .82075 m .2609 .81891 L p .26295 .8277 L F P
0 g
s
.814 .663 .696 r
.26639 .82075 m .26358 .81447 L .2609 .81891 L closepath p F P
0 g
s
.532 .421 .672 r
.53594 .79574 m .53445 .78881 L .5373 .78754 L p F P
0 g
s
.382 .294 .631 r
.75722 .84636 m .75594 .84464 L .75677 .844 L closepath p F P
0 g
s
.424 .28 .58 r
.54772 .7402 m .54753 .73828 L .54842 .73977 L closepath p F P
0 g
s
.604 .619 .839 r
.60602 .92871 m .59448 .93072 L .5915 .92513 L p F P
0 g
s
.845 .672 .668 r
.25711 .78637 m .2627 .78872 L .25972 .79501 L p F P
0 g
s
.842 .665 .663 r
.2627 .78872 m .25711 .78637 L .25989 .78014 L p F P
0 g
s
.919 .718 .614 r
.04125 .85889 m .04261 .85412 L .03886 .8506 L p F P
0 g
s
.335 .703 .983 r
.11852 .93824 m .11338 .93803 L .10963 .93582 L p F P
0 g
s
.568 .469 .702 r
.5323 .82845 m .53196 .82716 L .53634 .82692 L closepath p F P
0 g
s
.818 .679 .709 r
.25872 .83439 m .26488 .83651 L .26046 .84327 L p F P
0 g
s
.814 .67 .704 r
.26488 .83651 m .25872 .83439 L .26295 .8277 L p F P
0 g
s
.75 .744 .847 r
.18519 .9362 m .19386 .93054 L .19938 .93232 L p F P
0 g
s
.748 .745 .849 r
.19938 .93232 m .19629 .92899 L .19386 .93054 L closepath p F P
0 g
s
.912 .574 .39 r
.06045 .90025 m .05609 .89762 L .05529 .89236 L p F P
0 g
s
.915 .576 .385 r
.0516 .89007 m .05529 .89236 L .05609 .89762 L p F P
0 g
s
.569 .472 .705 r
.5343 .8359 m .5323 .82845 L .53634 .82692 L p F P
0 g
s
.5 .544 .833 r
.71036 .73054 m .70587 .72999 L .70299 .72395 L p F P
0 g
s
.873 .67 .625 r
.24789 .746 m .25292 .74857 L .25102 .7545 L p F P
0 g
s
.873 .66 .612 r
.25292 .74857 m .24789 .746 L .24949 .74017 L p F P
0 g
s
.895 .511 .295 r
.0664 .90791 m .06198 .90531 L .06045 .90025 L p F P
0 g
s
.897 .511 .287 r
.05609 .89762 m .06045 .90025 L .06198 .90531 L p F P
0 g
s
.52 .577 .852 r
.69517 .71225 m .68535 .71177 L .68278 .70685 L p F P
0 g
s
.593 .502 .721 r
.53866 .85115 m .54103 .85896 L .53685 .8603 L p F P
0 g
s
.594 .506 .724 r
.5412 .85952 m .53685 .8603 L .54103 .85896 L closepath p F P
0 g
s
.922 .628 .469 r
.0516 .89007 m .05101 .88969 L .05094 .88425 L p F P
0 g
s
.925 .631 .467 r
.04677 .88153 m .05094 .88425 L .05101 .88969 L p F P
0 g
s
.923 .658 .517 r
.05094 .88425 m .04677 .88153 L .0472 .87595 L p F P
0 g
s
.806 .684 .73 r
.25777 .86826 m .25315 .87421 L .24985 .86845 L p F P
0 g
s
.806 .684 .73 r
.24985 .86845 m .25156 .86619 L .25777 .86826 L p F P
0 g
s
.806 .683 .729 r
.25777 .86826 m .25156 .86619 L .25681 .85917 L p F P
0 g
s
.829 .672 .688 r
.26358 .81447 m .26474 .81234 L .26213 .81132 L closepath p F P
0 g
s
.831 .669 .682 r
.26036 .80736 m .26226 .80367 L p .26474 .81234 L F P
0 g
s
.831 .669 .682 r
.26474 .81234 m .26213 .81132 L .26036 .80736 L p F P
0 g
s
.469 .488 .796 r
.73743 .76033 m .72948 .75824 L .72861 .75611 L p F P
0 g
s
.596 .539 .761 r
.56309 .88823 m .56491 .89302 L .55344 .89488 L p F P
0 g
s
.596 .539 .761 r
.55344 .89488 m .55234 .89194 L .56309 .88823 L p F P
0 g
s
.524 .399 .652 r
.5424 .77331 m .53839 .77236 L .54193 .77078 L closepath p F P
0 g
s
.52 .388 .641 r
.54079 .76421 m .54193 .77078 L .53839 .77236 L p F P
0 g
s
.486 .361 .634 r
.54079 .76421 m .54885 .76 L .54235 .75637 L p F P
0 g
s
.488 .36 .632 r
.54943 .75271 m .54235 .75637 L .54885 .76 L p F P
0 g
s
.483 .345 .617 r
.5485 .74638 m .54943 .75271 L .54235 .75637 L p F P
0 g
s
.811 .679 .717 r
.26149 .85302 m .26208 .85217 L .26082 .85174 L closepath p F P
0 g
s
.813 .677 .714 r
.25823 .84666 m .26046 .84327 L p .26208 .85217 L F P
0 g
s
.813 .677 .714 r
.26208 .85217 m .26082 .85174 L .25823 .84666 L p F P
0 g
s
.214 0 .349 r
.74907 .8878 m .74293 .89205 L .74251 .89691 L p F P
0 g
s
.269 .081 .431 r
.74293 .89205 m .74907 .8878 L .75043 .88171 L p F P
0 g
s
.239 .013 .356 r
.73788 .89992 m .74251 .89691 L .74293 .89205 L p F P
0 g
s
.799 .7 .756 r
.24497 .89293 m .24574 .89205 L .24404 .89147 L closepath p F P
0 g
s
.8 .699 .753 r
.24163 .88766 m .24586 .88268 L p .24574 .89205 L F P
0 g
s
.8 .699 .753 r
.24574 .89205 m .24404 .89147 L .24163 .88766 L p F P
0 g
s
.915 .735 .644 r
.03728 .84123 m .04115 .8441 L .03899 .85015 L p F P
0 g
s
.909 .742 .664 r
.04115 .8441 m .03728 .84123 L .03978 .83509 L p F P
0 g
s
.491 .37 .642 r
.54193 .77078 m .54079 .76421 L .54885 .76 L p F P
0 g
s
.785 .697 .767 r
.23836 .89966 m .24497 .89293 L .24404 .89147 L p F P
0 g
s
.799 .675 .727 r
.25681 .85917 m .26149 .85302 L .26082 .85174 L p F P
0 g
s
.851 .673 .662 r
.25444 .77773 m .25989 .78014 L .25711 .78637 L p F P
0 g
s
.848 .667 .656 r
.25989 .78014 m .25444 .77773 L .257 .77158 L p F P
0 g
s
.439 .307 .603 r
.54842 .73977 m .54772 .7402 L .5485 .74638 L p F P
0 g
s
.595 .538 .761 r
.56186 .88499 m .56309 .88823 L .55234 .89194 L p F P
0 g
s
.595 .538 .761 r
.55234 .89194 m .55039 .88673 L .56186 .88499 L p F P
0 g
s
.167 0 .247 r
.74251 .89691 m .73788 .89992 L .73325 .90686 L p F P
0 g
s
.177 0 .255 r
.73265 .90725 m .73325 .90686 L .73788 .89992 L p F P
0 g
s
.86 .422 .165 r
.07322 .91533 m .06876 .91275 L .0664 .90791 L p F P
0 g
s
.86 .418 .152 r
.06198 .90531 m .0664 .90791 L .06876 .91275 L p F P
0 g
s
.791 .683 .745 r
.25414 .87595 m .25315 .87421 L .25216 .87537 L closepath p F P
0 g
s
.927 .661 .515 r
.0431 .8732 m .0472 .87595 L .04677 .88153 L p F P
0 g
s
.923 .682 .555 r
.0472 .87595 m .0431 .8732 L .04398 .8675 L p F P
0 g
s
.307 .145 .491 r
.75164 .87519 m .75055 .87595 L .75043 .88171 L p F P
0 g
s
.368 .284 .629 r
.75677 .844 m .76237 .83935 L p .75936 .84943 L F P
0 g
s
.368 .284 .629 r
.75936 .84943 m .75722 .84636 L .75677 .844 L p F P
0 g
s
.382 .312 .653 r
.75677 .844 m .76237 .83935 L .75827 .83476 L p F P
0 g
s
.882 .669 .609 r
.24464 .73752 m .24949 .74017 L .24789 .746 L p F P
0 g
s
.884 .658 .591 r
.24949 .74017 m .24464 .73752 L .24589 .73181 L p F P
0 g
s
.475 .501 .806 r
.72861 .75611 m .72657 .75128 L .73195 .75252 L closepath p F P
0 g
s
.469 .488 .796 r
.72861 .75611 m .73195 .75252 L p .73743 .76033 L F P
0 g
s
0 .373 .742 r
.09683 .93118 m .09217 .9289 L .09578 .93076 L closepath p F P
0 g
s
.614 .721 .922 r
.62638 .94037 m .63798 .93795 L .64085 .94147 L p F P
0 g
s
.612 .683 .893 r
.6356 .93472 m .63798 .93795 L .62638 .94037 L p F P
0 g
s
.612 .683 .893 r
.62638 .94037 m .6255 .9391 L .6356 .93472 L p F P
0 g
s
.569 .472 .705 r
.54339 .82645 m .54491 .83198 L .5343 .8359 L p F P
0 g
s
.569 .472 .705 r
.53634 .82692 m .54339 .82645 L p .5343 .8359 L F P
0 g
s
.572 .476 .707 r
.53504 .83862 m .5343 .8359 L .54491 .83198 L p F P
0 g
s
.782 .737 .812 r
.21095 .92457 m .21201 .92368 L .20932 .92267 L closepath p F P
0 g
s
.366 .264 .604 r
.75508 .85981 m .759 .85683 L .758 .85053 L p F P
0 g
s
.344 .227 .573 r
.759 .85683 m .75508 .85981 L .75695 .86503 L p F P
0 g
s
.601 .584 .806 r
.57447 .91572 m .574 .91471 L .57963 .91382 L closepath p F P
0 g
s
.783 .736 .809 r
.2158 .91331 m .22209 .91532 L .21201 .92368 L p F P
0 g
s
.783 .736 .809 r
.20749 .9205 m .2158 .91331 L p .21201 .92368 L F P
0 g
s
.783 .736 .809 r
.21201 .92368 m .20932 .92267 L .20749 .9205 L p F P
0 g
s
.817 .668 .698 r
.2609 .81891 m .26358 .81447 L .26213 .81132 L p F P
0 g
s
.431 .837 .646 r
.70743 .92761 m .70972 .92633 L .71471 .92313 L p F P
0 g
s
.799 .675 .727 r
.26082 .85174 m .2557 .85013 L p .25681 .85917 L F P
0 g
s
.802 .674 .722 r
.26082 .85174 m .25823 .84666 L .2557 .85013 L closepath p F P
0 g
s
.796 .706 .766 r
.23836 .89966 m .23355 .90465 L .23017 .89983 L p F P
0 g
s
.796 .706 .766 r
.23017 .89983 m .23227 .89759 L .23836 .89966 L p F P
0 g
s
.785 .697 .767 r
.23936 .89005 m .23227 .89759 L .23836 .89966 L p F P
0 g
s
.785 .697 .767 r
.24404 .89147 m .23936 .89005 L p .23836 .89966 L F P
0 g
s
.672 .148 0 r
.22152 .69196 m .22339 .69406 L .21983 .69138 L p F P
0 g
s
.574 .483 .714 r
.53643 .84348 m .53504 .83862 L .54649 .83767 L p F P
0 g
s
.572 .476 .707 r
.54491 .83198 m .54649 .83767 L .53504 .83862 L p F P
0 g
s
.823 .678 .702 r
.25688 .82554 m .26295 .8277 L .25872 .83439 L p F P
0 g
s
.811 .665 .702 r
.2609 .81891 m .25688 .82554 L .26295 .8277 L p F P
0 g
s
.54 .428 .675 r
.53594 .79574 m .54609 .79126 L p .53991 .80169 L F P
0 g
s
.54 .428 .675 r
.53991 .80169 m .53719 .80139 L .53594 .79574 L p F P
0 g
s
.532 .421 .672 r
.54554 .78876 m .54609 .79126 L .53594 .79574 L p F P
0 g
s
.532 .421 .672 r
.5373 .78754 m .54554 .78876 L p .53594 .79574 L F P
0 g
s
.757 .748 .845 r
.19386 .93054 m .18519 .9362 L .18165 .93274 L p F P
0 g
s
.635 .921 .977 r
.68218 .93717 m .68401 .93782 L .69561 .93308 L p F P
0 g
s
.893 .667 .588 r
.24123 .72909 m .24589 .73181 L .24464 .73752 L p F P
0 g
s
.896 .652 .561 r
.24589 .73181 m .24123 .72909 L .24208 .72351 L p F P
0 g
s
.592 .528 .752 r
.55993 .87967 m .56186 .88499 L .55039 .88673 L p F P
0 g
s
.592 .528 .752 r
.55039 .88673 m .54921 .88341 L .55993 .87967 L p F P
0 g
s
.589 .676 .9 r
.63649 .68386 m .64458 .68279 L .6417 .67839 L p F P
0 g
s
.589 .676 .9 r
.6417 .67839 m .64123 .67847 L .63649 .68386 L p F P
0 g
s
.582 .68 .908 r
.63004 .68028 m .64123 .67847 L .63649 .68386 L p F P
0 g
s
.6 .572 .794 r
.57963 .91382 m .574 .91471 L .57098 .90787 L p F P
0 g
s
.439 .307 .603 r
.5485 .74638 m .55223 .74414 L .54842 .73977 L p F P
0 g
s
.44 .307 .603 r
.55698 .73464 m .54842 .73977 L .55223 .74414 L p F P
0 g
s
.432 .283 .577 r
.55636 .72864 m .55698 .73464 L .54842 .73977 L p F P
0 g
s
.836 .674 .682 r
.26036 .80736 m .26226 .80367 L .25781 .80183 L closepath p F P
0 g
s
.838 .671 .676 r
.25714 .80032 m .25972 .79501 L p .26226 .80367 L F P
0 g
s
.838 .671 .676 r
.26226 .80367 m .25781 .80183 L .25714 .80032 L p F P
0 g
s
.509 .552 .835 r
.70299 .72395 m .7012 .72378 L .70232 .72256 L closepath p F P
0 g
s
.516 .562 .841 r
.70011 .71814 m .70232 .72256 L .7012 .72378 L p F P
0 g
s
.417 .381 .711 r
.75987 .81533 m .75419 .81164 L .75788 .80836 L closepath p F P
0 g
s
.429 .401 .725 r
.75671 .80449 m .75335 .80257 L p .75419 .81164 L F P
0 g
s
.429 .401 .725 r
.75419 .81164 m .75788 .80836 L .75671 .80449 L p F P
0 g
s
.667 .972 .813 r
.58326 .68498 m .57697 .69086 L p .58176 .6864 L F P
0 g
s
.667 .972 .813 r
.58399 .68431 m .58326 .68498 L p .58176 .6864 L F P
0 g
s
.441 .856 .698 r
.58683 .68355 m .57697 .69086 L p .5761 .69165 L F P
0 g
s
.441 .856 .698 r
.58793 .68375 m .58683 .68355 L p .5759 .69181 L F P
0 g
s
.667 .972 .813 r
.57697 .69086 m .58683 .68355 L .58399 .68431 L p F P
0 g
s
0 0 0 r
.58326 .68498 m .57747 .69212 L p .58366 .68461 L F P
0 g
s
.558 .877 .598 r
.58326 .68498 m .58375 .68449 L .58399 .68431 L closepath p F P
0 g
s
0 0 0 r
.58375 .68449 m .58326 .68498 L p .58366 .68461 L F P
0 g
s
0 0 0 r
.57697 .69086 m .58326 .68498 L p .58238 .68596 L F P
0 g
s
0 0 0 r
.57411 .69517 m .57697 .69086 L .58238 .68596 L F
.441 .856 .698 r
.57697 .69086 m .5759 .69181 L p .5761 .69165 L F P
0 g
s
0 0 0 r
.57546 .69236 m .57697 .69086 L .5759 .69181 L closepath p F P
0 g
s
.788 .696 .763 r
.24404 .89147 m .24163 .88766 L .23936 .89005 L closepath p F P
0 g
s
.927 .686 .554 r
.03996 .8647 m .04398 .8675 L .0431 .8732 L p F P
0 g
s
.922 .701 .587 r
.04398 .8675 m .03996 .8647 L .04125 .85889 L p F P
0 g
s
.711 .965 .939 r
.58683 .68355 m .59031 .6815 L .58793 .68375 L closepath p F P
0 g
s
.654 .914 .979 r
.59828 .67744 m .59031 .6815 L .58793 .68375 L p F P
0 g
s
.654 .914 .979 r
.60116 .67965 m .59828 .67744 L p .58793 .68375 L F P
0 g
s
.792 .684 .746 r
.25216 .87537 m .25315 .87421 L .24985 .86845 L p F P
0 g
s
.77 .72 .806 r
.22234 .91539 m .22221 .91522 L .22209 .91532 L closepath p F P
0 g
s
.779 .708 .785 r
.23057 .90739 m .23355 .90465 L .23017 .89983 L p F P
0 g
s
.787 .712 .781 r
.23057 .90739 m .22221 .91522 L .21879 .91077 L p F P
0 g
s
.787 .712 .781 r
.21879 .91077 m .22437 .90535 L .23057 .90739 L p F P
0 g
s
.779 .708 .785 r
.23017 .89983 m .22437 .90535 L .23057 .90739 L p F P
0 g
s
.857 .675 .654 r
.25171 .76911 m .257 .77158 L .25444 .77773 L p F P
0 g
s
.856 .668 .648 r
.257 .77158 m .25171 .76911 L .25405 .76303 L p F P
0 g
s
.577 .486 .715 r
.53643 .84348 m .54703 .83955 L p .5454 .84867 L F P
0 g
s
.577 .486 .715 r
.5454 .84867 m .53812 .84938 L .53643 .84348 L p F P
0 g
s
.574 .483 .714 r
.54649 .83767 m .54703 .83955 L .53643 .84348 L p F P
0 g
s
.369 .285 .629 r
.758 .85053 m .75722 .84636 L .75936 .84943 L closepath p F P
0 g
s
.591 .527 .752 r
.5588 .87652 m .55993 .87967 L .54921 .88341 L p F P
0 g
s
.591 .527 .752 r
.54921 .88341 m .54733 .87814 L .5588 .87652 L p F P
0 g
s
.534 .419 .669 r
.54554 .78876 m .5373 .78754 L .54461 .78433 L closepath p F P
0 g
s
.531 .409 .659 r
.54321 .7775 m .54461 .78433 L .5373 .78754 L p F P
0 g
s
.797 .303 0 r
.07322 .91533 m .07472 .91752 L .07084 .9157 L p F P
0 g
s
.797 .303 0 r
.07084 .9157 m .06876 .91275 L .07322 .91533 L p F P
0 g
s
.77 .72 .805 r
.21879 .91077 m .2158 .91331 L .22209 .91532 L p F P
0 g
s
.77 .72 .805 r
.22209 .91532 m .22221 .91522 L .21879 .91077 L p F P
0 g
s
.804 .697 .747 r
.24575 .87336 m .25216 .87537 L .24586 .88268 L p F P
0 g
s
.792 .684 .746 r
.24985 .86845 m .24575 .87336 L .25216 .87537 L p F P
0 g
s
.905 .661 .558 r
.23761 .72073 m .24208 .72351 L .24123 .72909 L p F P
0 g
s
.909 .64 .518 r
.24208 .72351 m .23761 .72073 L .23796 .71531 L p F P
0 g
s
.662 .762 .924 r
.60116 .67965 m .61269 .67576 L .61557 .67906 L p F P
0 g
s
.688 .795 .931 r
.61269 .67576 m .60116 .67965 L .59828 .67744 L p F P
0 g
s
.101 0 .138 r
.73251 .90774 m .73325 .90686 L .73265 .90725 L closepath p F P
0 g
s
.559 .639 .887 r
.65918 .68629 m .65975 .68722 L .65605 .69149 L p F P
0 g
s
.559 .639 .887 r
.64746 .6873 m .65918 .68629 L p .65605 .69149 L F P
0 g
s
.556 .626 .877 r
.66206 .69112 m .65605 .69149 L .65975 .68722 L closepath p F P
0 g
s
0 .458 .82 r
.09683 .93118 m .10586 .93353 L p .09196 .92879 L F P
0 g
s
0 .458 .82 r
.09196 .92879 m .09217 .9289 L .09683 .93118 L p F P
0 g
s
.817 .668 .698 r
.26213 .81132 m .25878 .81013 L p .2609 .81891 L F P
0 g
s
.82 .665 .691 r
.26213 .81132 m .26036 .80736 L .25878 .81013 L closepath p F P
0 g
s
.817 .681 .713 r
.25823 .84666 m .26046 .84327 L .25552 .84147 L closepath p F P
0 g
s
.818 .679 .709 r
.25496 .84037 m .25872 .83439 L p .26046 .84327 L F P
0 g
s
.818 .679 .709 r
.26046 .84327 m .25552 .84147 L .25496 .84037 L p F P
0 g
s
.62 .708 .908 r
.61557 .67906 m .62716 .67637 L .63004 .68028 L p F P
0 g
s
.634 .726 .914 r
.62716 .67637 m .61557 .67906 L .61269 .67576 L p F P
0 g
s
.285 .129 .486 r
.7579 .87051 m .75164 .87519 L .75187 .8807 L p F P
0 g
s
.319 .184 .535 r
.75164 .87519 m .7579 .87051 L .75695 .86503 L p F P
0 g
s
.307 .145 .491 r
.75043 .88171 m .75187 .8807 L .75164 .87519 L p F P
0 g
s
.431 .837 .646 r
.71471 .92313 m .71999 .92005 L p .70743 .92761 L F P
0 g
s
0 0 0 r
.71471 .92313 m .71999 .92005 L .72119 .91844 L closepath p F P
0 g
s
.611 .682 .892 r
.6351 .93403 m .6356 .93472 L .6255 .9391 L p F P
0 g
s
.611 .682 .892 r
.6255 .9391 m .62348 .93622 L .6351 .93403 L p F P
0 g
s
.588 .518 .743 r
.55701 .87132 m .5588 .87652 L .54733 .87814 L p F P
0 g
s
.588 .518 .743 r
.54733 .87814 m .5463 .87509 L .55701 .87132 L p F P
0 g
s
.578 .494 .723 r
.53866 .85115 m .53812 .84938 L .5454 .84867 L closepath p F P
0 g
s
.799 .675 .727 r
.2557 .85013 m .25062 .85708 L .25681 .85917 L p F P
0 g
s
.812 .69 .73 r
.25062 .85708 m .25681 .85917 L .25156 .86619 L p F P
0 g
s
.92 .558 .326 r
.23342 .70723 m .22934 .7043 L .22828 .69935 L p F P
0 g
s
.927 .565 .317 r
.22438 .69634 m .22828 .69935 L .22934 .7043 L p F P
0 g
s
.873 .431 .098 r
.22339 .69406 m .22438 .69634 L .22828 .69935 L p F P
0 g
s
.542 .615 .875 r
.67333 .69585 m .66493 .69606 L .66206 .69112 L p F P
0 g
s
.578 .495 .724 r
.54103 .85896 m .53866 .85115 L .5454 .84867 L p F P
0 g
s
.918 .649 .514 r
.23368 .71245 m .23796 .71531 L .23761 .72073 L p F P
0 g
s
.92 .614 .448 r
.23796 .71531 m .23368 .71245 L .23342 .70723 L p F P
0 g
s
.568 .644 .886 r
.65918 .68629 m .64746 .6873 L .64458 .68279 L p F P
0 g
s
.587 .517 .743 r
.55573 .86758 m .55701 .87132 L .5463 .87509 L p F P
0 g
s
.587 .517 .743 r
.5463 .87509 m .54427 .86908 L .55573 .86758 L p F P
0 g
s
.475 .502 .806 r
.73195 .75252 m .72657 .75128 L .72446 .74632 L p F P
0 g
s
.572 .766 .97 r
.12747 .94066 m .13808 .93867 L .14174 .94139 L p F P
0 g
s
.589 .768 .965 r
.13808 .93867 m .12747 .94066 L .12376 .93818 L p F P
0 g
s
.616 .768 .953 r
.64085 .94147 m .65247 .93877 L .65529 .94161 L p F P
0 g
s
.613 .736 .934 r
.65247 .93877 m .64085 .94147 L .63798 .93795 L p F P
0 g
s
.928 .623 .443 r
.22934 .7043 m .23342 .70723 L .23368 .71245 L p F P
0 g
s
.608 .661 .876 r
.60898 .93375 m .62056 .93168 L .62348 .93622 L p F P
0 g
s
.604 .635 .855 r
.61762 .9268 m .62056 .93168 L .60898 .93375 L p F P
0 g
s
.604 .635 .855 r
.60886 .92825 m .61762 .9268 L p .60898 .93375 L F P
0 g
s
.604 .635 .855 r
.60898 .93375 m .60637 .9293 L .60886 .92825 L p F P
0 g
s
.585 .508 .734 r
.55428 .86315 m .55573 .86758 L .54427 .86908 L p F P
0 g
s
.585 .508 .734 r
.54427 .86908 m .54358 .86695 L .55428 .86315 L p F P
0 g
s
.582 .498 .726 r
.5412 .85952 m .54103 .85896 L .55172 .85514 L p F P
0 g
s
.578 .495 .724 r
.54958 .84823 m .55172 .85514 L .54103 .85896 L p F P
0 g
s
.578 .495 .724 r
.5454 .84867 m .54958 .84823 L p .54103 .85896 L F P
0 g
s
.583 .506 .734 r
.55266 .85817 m .55428 .86315 L .54358 .86695 L p F P
0 g
s
.583 .506 .734 r
.54358 .86695 m .5412 .85952 L .55266 .85817 L p F P
0 g
s
.582 .498 .726 r
.55172 .85514 m .55266 .85817 L .5412 .85952 L p F P
0 g
s
.843 .675 .674 r
.25972 .79501 m .25714 .80032 L .25391 .79333 L p F P
0 g
s
.843 .675 .674 r
.25391 .79333 m .25424 .79263 L .25972 .79501 L p F P
0 g
s
.845 .672 .668 r
.25972 .79501 m .25424 .79263 L .25711 .78637 L p F P
0 g
s
.865 .676 .646 r
.24892 .7605 m .25405 .76303 L .25171 .76911 L p F P
0 g
s
.864 .669 .638 r
.25405 .76303 m .24892 .7605 L .25102 .7545 L p F P
0 g
s
.604 .619 .839 r
.5915 .92513 m .60306 .92324 L .60602 .92871 L p F P
0 g
s
.6 .599 .823 r
.60036 .91801 m .60306 .92324 L .5915 .92513 L p F P
0 g
s
.6 .599 .823 r
.5915 .92513 m .58998 .9221 L .60036 .91801 L p F P
0 g
s
0 0 .031 r
.73325 .90686 m .74169 .90137 L p .73127 .91117 L F P
0 g
s
0 0 .031 r
.73127 .91117 m .73251 .90774 L .73325 .90686 L p F P
0 g
s
.167 0 .247 r
.73325 .90686 m .74169 .90137 L .74251 .89691 L p F P
0 g
s
.925 .705 .586 r
.0373 .85606 m .04125 .85889 L .03996 .8647 L p F P
0 g
s
.919 .718 .614 r
.03886 .8506 m .0373 .85606 L .04125 .85889 L p F P
0 g
s
.57 .469 .701 r
.54339 .82645 m .53634 .82692 L .54288 .82449 L closepath p F P
0 g
s
.567 .463 .695 r
.54098 .81714 m .54288 .82449 L .53634 .82692 L p F P
0 g
s
.827 .678 .698 r
.25493 .8167 m .2609 .81891 L .25688 .82554 L p F P
0 g
s
.817 .668 .698 r
.25878 .81013 m .25493 .8167 L .2609 .81891 L p F P
0 g
s
.539 .433 .682 r
.5375 .80274 m .53719 .80139 L .53991 .80169 L closepath p F P
0 g
s
.069 0 .065 r
.72583 .91452 m .73127 .91117 L .73251 .90774 L closepath p F P
0 g
s
.5 .544 .833 r
.70299 .72395 m .7149 .72539 L .71036 .73054 L p F P
0 g
s
.5 .546 .836 r
.7149 .72539 m .70299 .72395 L .70232 .72256 L p F P
0 g
s
.589 .892 .989 r
.66969 .94054 m .68132 .9368 L .68218 .93717 L p F P
0 g
s
.607 .858 .991 r
.68132 .9368 m .66969 .94054 L .66692 .93849 L p F P
0 g
s
.612 .83 .984 r
.65529 .94161 m .66692 .93849 L .66969 .94054 L p F P
0 g
s
.739 .774 .881 r
.17063 .93894 m .17112 .93867 L .16948 .93792 L closepath p F P
0 g
s
.704 .767 .901 r
.16948 .93792 m .17063 .93894 L p .15614 .94072 L F P
0 g
s
.367 .219 .544 r
.55637 .72262 m .55597 .72289 L .55636 .72864 L p F P
0 g
s
.742 .773 .879 r
.1781 .92926 m .18165 .93274 L .17112 .93867 L p F P
0 g
s
.742 .773 .879 r
.16705 .93574 m .1781 .92926 L p .17112 .93867 L F P
0 g
s
.742 .773 .879 r
.17112 .93867 m .16948 .93792 L .16705 .93574 L p F P
0 g
s
.381 .312 .654 r
.76364 .83023 m .75827 .83476 L .76237 .83935 L p F P
0 g
s
.396 .336 .672 r
.76316 .82825 m .76364 .83023 L .75827 .83476 L p F P
0 g
s
.396 .336 .672 r
.75971 .8251 m .76316 .82825 L p .75827 .83476 L F P
0 g
s
.764 .733 .824 r
.20932 .92267 m .20749 .9205 L .20601 .9216 L closepath p F P
0 g
s
.52 .577 .852 r
.68278 .70685 m .68323 .70631 L p .69517 .71225 L F P
0 g
s
.525 .587 .859 r
.68278 .70685 m .68247 .70628 L .68323 .70631 L closepath p F P
0 g
s
0 0 0 r
.71999 .92005 m .72119 .91844 L .72583 .91452 L p F P
0 g
s
.615 .791 .966 r
.66692 .93849 m .65529 .94161 L .65247 .93877 L p F P
0 g
s
0 0 0 r
.57411 .69517 m .57546 .69236 L .57697 .69086 L p F P
0 g
s
.804 .697 .746 r
.24586 .88268 m .24163 .88766 L .23828 .88241 L p F P
0 g
s
.804 .697 .746 r
.23828 .88241 m .2398 .88057 L .24586 .88268 L p F P
0 g
s
.804 .697 .747 r
.24586 .88268 m .2398 .88057 L .24575 .87336 L p F P
0 g
s
.823 .67 .693 r
.25878 .81013 m .26036 .80736 L .25781 .80183 L p F P
0 g
s
.505 .386 .652 r
.54193 .77078 m .55167 .7658 L p .54763 .77524 L F P
0 g
s
.505 .386 .652 r
.54763 .77524 m .5424 .77331 L .54193 .77078 L p F P
0 g
s
.491 .37 .642 r
.55077 .76089 m .55167 .7658 L .54193 .77078 L p F P
0 g
s
.491 .37 .642 r
.54885 .76 m .55077 .76089 L p .54193 .77078 L F P
0 g
s
.541 .439 .687 r
.5392 .8099 m .5375 .80274 L .53991 .80169 L p F P
0 g
s
0 0 0 r
.57045 .69821 m .57411 .69517 L .57546 .69236 L closepath p F P
0 g
s
.804 .677 .723 r
.2557 .85013 m .25823 .84666 L .25552 .84147 L p F P
0 g
s
.757 .748 .845 r
.18165 .93274 m .18798 .92843 L .19386 .93054 L p F P
0 g
s
.748 .745 .849 r
.19279 .92521 m .18798 .92843 L .19386 .93054 L p F P
0 g
s
.748 .745 .849 r
.19386 .93054 m .19629 .92899 L .19279 .92521 L p F P
0 g
s
0 0 0 r
.72583 .91452 m .73127 .91117 L p .71999 .92005 L F P
0 g
s
.425 .398 .726 r
.75671 .80449 m .75335 .80257 L .75553 .80058 L closepath p F P
0 g
s
.437 .417 .739 r
.75362 .79466 m .75172 .79371 L p .75335 .80257 L F P
0 g
s
.437 .417 .739 r
.75335 .80257 m .75553 .80058 L .75362 .79466 L p F P
0 g
s
.348 .251 .602 r
.75936 .84943 m .758 .85053 L .759 .85683 L p F P
0 g
s
.524 .59 .863 r
.68323 .70631 m .68247 .70628 L .6796 .70103 L p F P
0 g
s
.367 .219 .544 r
.55636 .72864 m .55779 .72765 L .55637 .72262 L p F P
0 g
s
.363 .216 .544 r
.56475 .71673 m .55637 .72262 L .55779 .72765 L p F P
0 g
s
.328 .16 .494 r
.55637 .72262 m .56475 .71673 L .56464 .7113 L p F P
0 g
s
.657 .774 .935 r
.14174 .94139 m .15252 .93777 L .15614 .94072 L p F P
0 g
s
.667 .774 .93 r
.15252 .93777 m .14174 .94139 L .13808 .93867 L p F P
0 g
s
.5 .546 .836 r
.70232 .72256 m .70554 .71867 L p .7149 .72539 L F P
0 g
s
.505 .558 .843 r
.70232 .72256 m .70011 .71814 L .70554 .71867 L closepath p F P
0 g
s
.6 .572 .794 r
.57098 .90787 m .5825 .90614 L p .57963 .91382 L F P
0 g
s
.595 .56 .784 r
.58085 .90229 m .5825 .90614 L .57098 .90787 L p F P
0 g
s
.595 .56 .784 r
.57098 .90787 m .57027 .90618 L .58085 .90229 L p F P
0 g
s
.495 .532 .824 r
.71036 .73054 m .71787 .73164 L p .71854 .73758 L F P
0 g
s
.494 .534 .827 r
.71036 .73054 m .71787 .73164 L .71498 .7254 L p F P
0 g
s
.494 .534 .827 r
.71498 .7254 m .7149 .72539 L .71036 .73054 L p F P
0 g
s
.873 .67 .625 r
.25102 .7545 m .24604 .75191 L .24789 .746 L p F P
0 g
s
.873 .678 .636 r
.24604 .75191 m .25102 .7545 L .24892 .7605 L p F P
0 g
s
.704 .767 .901 r
.15614 .94072 m .16527 .93655 L .16948 .93792 L p F P
0 g
s
.712 .77 .897 r
.16527 .93655 m .15614 .94072 L .15252 .93777 L p F P
0 g
s
.823 .679 .704 r
.25872 .83439 m .25496 .84037 L .25169 .83407 L p F P
0 g
s
.823 .679 .704 r
.25169 .83407 m .25285 .83218 L .25872 .83439 L p F P
0 g
s
.823 .678 .702 r
.25872 .83439 m .25285 .83218 L .25688 .82554 L p F P
0 g
s
.488 0 0 r
.09192 .92876 m .08735 .92624 L .08165 .9223 L p F P
0 g
s
.463 0 0 r
.07702 .91978 m .08165 .9223 L .08735 .92624 L p F P
0 g
s
.702 .163 0 r
.07472 .91752 m .07702 .91978 L .08165 .9223 L p F P
0 g
s
.589 .694 .915 r
.64123 .67847 m .63004 .68028 L .62716 .67637 L p F P
0 g
s
.851 .673 .662 r
.25711 .78637 m .25177 .78394 L .25444 .77773 L p F P
0 g
s
.85 .678 .669 r
.25177 .78394 m .25711 .78637 L .25424 .79263 L p F P
0 g
s
.772 .735 .819 r
.20601 .9216 m .19629 .92899 L .19279 .92521 L p F P
0 g
s
.449 .325 .618 r
.55223 .74414 m .5485 .74638 L .54943 .75271 L p F P
0 g
s
.434 .735 .99 r
.11852 .93824 m .12376 .93818 L .12004 .93564 L p F P
0 g
s
.434 .735 .99 r
.12004 .93564 m .11351 .93587 L .11852 .93824 L p F P
0 g
s
.335 .703 .983 r
.10963 .93582 m .11351 .93587 L .11852 .93824 L p F P
0 g
s
.475 .502 .806 r
.72446 .74632 m .72571 .74491 L p .73195 .75252 L F P
0 g
s
.48 .514 .815 r
.72446 .74632 m .72366 .7445 L .72571 .74491 L closepath p F P
0 g
s
.502 .389 .658 r
.54321 .7775 m .5424 .77331 L .54763 .77524 L closepath p F P
0 g
s
.593 .558 .784 r
.57947 .89906 m .58085 .90229 L .57027 .90618 L p F P
0 g
s
.593 .558 .784 r
.57027 .90618 m .56795 .90064 L .57947 .89906 L p F P
0 g
s
.52 .577 .852 r
.68323 .70631 m .69436 .70685 L p .69517 .71225 L F P
0 g
s
.52 .583 .858 r
.68323 .70631 m .69436 .70685 L .69149 .70139 L p F P
0 g
s
.52 .583 .858 r
.69149 .70139 m .68726 .70122 L .68323 .70631 L p F P
0 g
s
.524 .59 .863 r
.6796 .70103 m .68726 .70122 L .68323 .70631 L p F P
0 g
s
.789 .698 .764 r
.23936 .89005 m .24163 .88766 L .23828 .88241 L p F P
0 g
s
.221 .031 .397 r
.56704 .70464 m .56494 .7063 L .56464 .7113 L p F P
0 g
s
.108 0 .24 r
.56494 .7063 m .56704 .70464 L .57045 .69821 L p F P
0 g
s
.811 .691 .733 r
.24985 .86845 m .25156 .86619 L .24774 .86482 L closepath p F P
0 g
s
.812 .69 .73 r
.24654 .86272 m .25062 .85708 L p .25156 .86619 L F P
0 g
s
.812 .69 .73 r
.25156 .86619 m .24774 .86482 L .24654 .86272 L p F P
0 g
s
.922 .724 .618 r
.03899 .85015 m .03886 .8506 L .03504 .8475 L p F P
0 g
s
.922 .724 .618 r
.03504 .8475 m .03511 .84728 L .03899 .85015 L p F P
0 g
s
.915 .735 .644 r
.03899 .85015 m .03511 .84728 L .03728 .84123 L p F P
0 g
s
.599 .598 .822 r
.60008 .91746 m .60036 .91801 L .58998 .9221 L p F P
0 g
s
.599 .598 .822 r
.58998 .9221 m .58851 .91918 L .60008 .91746 L p F P
0 g
s
.816 .688 .723 r
.24954 .84802 m .2557 .85013 L .25062 .85708 L p F P
0 g
s
.804 .677 .723 r
.25444 .84111 m .24954 .84802 L .2557 .85013 L p F P
0 g
s
.804 .677 .723 r
.25552 .84147 m .25444 .84111 L p .2557 .85013 L F P
0 g
s
.074 0 .216 r
.57411 .69517 m .57045 .69821 L .56704 .70464 L p F P
0 g
s
.831 .679 .694 r
.25292 .80788 m .25878 .81013 L .25493 .8167 L p F P
0 g
s
.823 .67 .693 r
.25657 .80137 m .25292 .80788 L .25878 .81013 L p F P
0 g
s
.823 .67 .693 r
.25781 .80183 m .25657 .80137 L p .25878 .81013 L F P
0 g
s
.915 .576 .385 r
.05104 .88996 m .0516 .89007 L p .05609 .89762 L F P
0 g
s
.92 .596 .413 r
.05104 .88996 m .05101 .88969 L .0516 .89007 L closepath p F P
0 g
s
.801 .712 .767 r
.23314 .88799 m .23936 .89005 L .23227 .89759 L p F P
0 g
s
.789 .698 .764 r
.23828 .88241 m .23314 .88799 L .23936 .89005 L p F P
0 g
s
.923 .722 .614 r
.0373 .85606 m .03886 .8506 L .03504 .8475 L p F P
0 g
s
.702 .767 .903 r
.16948 .93792 m .16705 .93574 L .16527 .93655 L closepath p F P
0 g
s
.728 .989 .87 r
.59031 .6815 m .58683 .68355 L .58399 .68431 L p F P
0 g
s
.882 .678 .623 r
.24308 .74334 m .24789 .746 L .24604 .75191 L p F P
0 g
s
.882 .669 .609 r
.24789 .746 m .24308 .74334 L .24464 .73752 L p F P
0 g
s
.879 .442 .098 r
.22438 .69634 m .22339 .69406 L .21983 .69138 L p F P
0 g
s
.548 .445 .689 r
.5392 .8099 m .54942 .8055 L p .54653 .81475 L F P
0 g
s
.548 .445 .689 r
.54653 .81475 m .54029 .81441 L .5392 .8099 L p F P
0 g
s
.541 .439 .687 r
.54867 .80244 m .54942 .8055 L .5392 .8099 L p F P
0 g
s
.541 .439 .687 r
.53991 .80169 m .54867 .80244 L p .5392 .8099 L F P
0 g
s
.48 .515 .816 r
.72571 .74491 m .72366 .7445 L .72076 .73796 L p F P
0 g
s
.797 .688 .744 r
.24575 .87336 m .24985 .86845 L .24774 .86482 L p F P
0 g
s
.602 .577 .798 r
.58551 .91286 m .57963 .91382 L .58506 .91187 L closepath p F P
0 g
s
.6 .572 .794 r
.5825 .90614 m .58506 .91187 L .57963 .91382 L p F P
0 g
s
.826 .667 .686 r
.25781 .80183 m .25714 .80032 L .25657 .80137 L closepath p F P
0 g
s
.678 .131 0 r
.07702 .91978 m .07472 .91752 L .07084 .9157 L p F P
0 g
s
.264 .076 .428 r
.75187 .8807 m .75043 .88171 L .74907 .8878 L p F P
0 g
s
.923 .597 .407 r
.05101 .88969 m .05104 .88996 L .04704 .88879 L p F P
0 g
s
.923 .597 .407 r
.04704 .88879 m .04684 .88698 L .05101 .88969 L p F P
0 g
s
.925 .631 .467 r
.05101 .88969 m .04684 .88698 L .04677 .88153 L p F P
0 g
s
.858 .681 .661 r
.24923 .77525 m .25444 .77773 L .25177 .78394 L p F P
0 g
s
.857 .675 .654 r
.25444 .77773 m .24923 .77525 L .25171 .76911 L p F P
0 g
s
.433 .415 .74 r
.75362 .79466 m .75172 .79371 L .75295 .79256 L closepath p F P
0 g
s
.444 .433 .752 r
.75059 .78562 m .74931 .78505 L p .75172 .79371 L F P
0 g
s
.444 .433 .752 r
.75172 .79371 m .75295 .79256 L .75059 .78562 L p F P
0 g
s
.543 .437 .684 r
.54867 .80244 m .53991 .80169 L .54771 .79833 L closepath p F P
0 g
s
.54 .428 .675 r
.54609 .79126 m .54771 .79833 L .53991 .80169 L p F P
0 g
s
.897 .511 .287 r
.06198 .90531 m .05763 .90267 L .05609 .89762 L p F P
0 g
s
.9 .511 .278 r
.0518 .89495 m .05609 .89762 L .05763 .90267 L p F P
0 g
s
.915 .576 .385 r
.05609 .89762 m .0518 .89495 L .05104 .88996 L p F P
0 g
s
.605 .67 .886 r
.6351 .93403 m .62348 .93622 L .62056 .93168 L p F P
0 g
s
.772 .735 .819 r
.19279 .92521 m .20001 .91951 L .20601 .9216 L p F P
0 g
s
.764 .733 .824 r
.20403 .9164 m .20001 .91951 L .20601 .9216 L p F P
0 g
s
.764 .733 .824 r
.20601 .9216 m .20749 .9205 L .20403 .9164 L p F P
0 g
s
.8 .714 .77 r
.23017 .89983 m .23227 .89759 L .22729 .89576 L closepath p F P
0 g
s
.801 .712 .767 r
.22678 .89503 m .23314 .88799 L p .23227 .89759 L F P
0 g
s
.801 .712 .767 r
.23227 .89759 m .22729 .89576 L .22678 .89503 L p F P
0 g
s
.83 .672 .688 r
.25657 .80137 m .25714 .80032 L .25391 .79333 L p F P
0 g
s
.918 .578 .381 r
.0518 .89495 m .05104 .88996 L .04704 .88879 L p F P
0 g
s
.488 .521 .818 r
.72076 .73796 m .71854 .73758 L .71992 .73607 L closepath p F P
0 g
s
.495 .532 .824 r
.71787 .73164 m .71992 .73607 L .71854 .73758 L p F P
0 g
s
.929 .634 .464 r
.04267 .87878 m .04677 .88153 L .04684 .88698 L p F P
0 g
s
.927 .661 .515 r
.04677 .88153 m .04267 .87878 L .0431 .8732 L p F P
0 g
s
.829 .684 .703 r
.25109 .82329 m .25688 .82554 L .25285 .83218 L p F P
0 g
s
.827 .678 .698 r
.25688 .82554 m .25109 .82329 L .25493 .8167 L p F P
0 g
s
.784 .725 .798 r
.2158 .91331 m .20749 .9205 L .20403 .9164 L p F P
0 g
s
.891 .678 .607 r
.24 .7348 m .24464 .73752 L .24308 .74334 L p F P
0 g
s
.893 .667 .588 r
.24464 .73752 m .24 .7348 L .24123 .72909 L p F P
0 g
s
.506 .396 .664 r
.54461 .78433 m .54321 .7775 L .54763 .77524 L p F P
0 g
s
.807 .675 .718 r
.25552 .84147 m .25496 .84037 L .25444 .84111 L closepath p F P
0 g
s
.728 .989 .87 r
.58399 .68431 m .59527 .67599 L .59031 .6815 L p F P
0 g
s
.718 .907 .962 r
.59541 .67591 m .59527 .67599 L .59031 .6815 L p F P
0 g
s
.718 .907 .962 r
.59031 .6815 m .59828 .67744 L .59541 .67591 L p F P
0 g
s
.375 .718 .988 r
.11351 .93587 m .10963 .93582 L .10586 .93353 L p F P
0 g
s
.784 .711 .783 r
.22437 .90535 m .23017 .89983 L .22729 .89576 L p F P
0 g
s
.59 .547 .775 r
.57704 .89309 m .57947 .89906 L .56795 .90064 L p F P
0 g
s
.59 .547 .775 r
.56795 .90064 m .56651 .89705 L .57704 .89309 L p F P
0 g
s
.346 .252 .603 r
.76578 .84414 m .75936 .84943 L .76195 .85445 L p F P
0 g
s
.368 .284 .629 r
.76237 .83935 m .76578 .84414 L .75936 .84943 L p F P
0 g
s
.348 .251 .602 r
.759 .85683 m .76195 .85445 L .75936 .84943 L p F P
0 g
s
.595 .589 .816 r
.60008 .91746 m .58851 .91918 L .58551 .91286 L p F P
0 g
s
.548 .451 .697 r
.54098 .81714 m .54029 .81441 L .54653 .81475 L closepath p F P
0 g
s
.794 .718 .78 r
.22437 .90535 m .21879 .91077 L .21536 .90633 L p F P
0 g
s
.794 .718 .78 r
.21536 .90633 m .21847 .90323 L .22437 .90535 L p F P
0 g
s
.784 .711 .783 r
.22636 .89545 m .21847 .90323 L .22437 .90535 L p F P
0 g
s
.784 .711 .783 r
.22729 .89576 m .22636 .89545 L p .22437 .90535 L F P
0 g
s
.809 .702 .747 r
.23965 .87125 m .24575 .87336 L .2398 .88057 L p F P
0 g
s
.797 .688 .744 r
.24545 .86407 m .23965 .87125 L .24575 .87336 L p F P
0 g
s
.797 .688 .744 r
.24774 .86482 m .24545 .86407 L p .24575 .87336 L F P
0 g
s
.836 .68 .689 r
.25083 .79907 m .25657 .80137 L .25292 .80788 L p F P
0 g
s
.83 .672 .688 r
.25391 .79333 m .25083 .79907 L .25657 .80137 L p F P
0 g
s
.784 .725 .798 r
.20403 .9164 m .20982 .91121 L .2158 .91331 L p F P
0 g
s
.776 .722 .802 r
.21536 .90633 m .20982 .91121 L .2158 .91331 L p F P
0 g
s
.776 .722 .802 r
.2158 .91331 m .21879 .91077 L .21536 .90633 L p F P
0 g
s
.86 .418 .152 r
.06876 .91275 m .06436 .91014 L .06198 .90531 L p F P
0 g
s
.86 .415 .14 r
.05763 .90267 m .06198 .90531 L .06436 .91014 L p F P
0 g
s
.604 .635 .855 r
.60637 .9293 m .60602 .92871 L .60886 .92825 L closepath p F P
0 g
s
.507 .911 .852 r
.70743 .92761 m .70721 .92768 L .69561 .93308 L p F P
0 g
s
.484 .9 .873 r
.70721 .92768 m .69561 .93308 L .69296 .9326 L p F P
0 g
s
.635 .921 .977 r
.69561 .93308 m .69296 .9326 L p .68218 .93717 L F P
0 g
s
.809 .678 .719 r
.25444 .84111 m .25496 .84037 L .25169 .83407 L p F P
0 g
s
.931 .665 .513 r
.03907 .87041 m .0431 .8732 L .04267 .87878 L p F P
0 g
s
.927 .686 .554 r
.0431 .8732 m .03907 .87041 L .03996 .8647 L p F P
0 g
s
.613 .901 .986 r
.68132 .9368 m .68642 .93499 L .68218 .93717 L closepath p F P
0 g
s
.635 .921 .977 r
.69296 .9326 m .68642 .93499 L .68218 .93717 L p F P
0 g
s
.504 .559 .845 r
.70554 .71867 m .70011 .71814 L .69723 .7124 L p F P
0 g
s
.549 .454 .699 r
.54288 .82449 m .54098 .81714 L .54653 .81475 L p F P
0 g
s
.866 .683 .653 r
.24665 .76657 m .25171 .76911 L .24923 .77525 L p F P
0 g
s
.865 .676 .646 r
.25171 .76911 m .24665 .76657 L .24892 .7605 L p F P
0 g
s
.818 .687 .72 r
.24833 .83897 m .25444 .84111 L .24954 .84802 L p F P
0 g
s
.809 .678 .719 r
.25169 .83407 m .24833 .83897 L .25444 .84111 L p F P
0 g
s
.393 .337 .676 r
.76316 .82825 m .75971 .8251 L .76193 .82317 L closepath p F P
0 g
s
.407 .36 .693 r
.75971 .8251 m .76193 .82317 L .76003 .81589 L p F P
0 g
s
.902 .676 .586 r
.23677 .7263 m .24123 .72909 L .24 .7348 L p F P
0 g
s
.905 .661 .558 r
.24123 .72909 m .23677 .7263 L .23761 .72073 L p F P
0 g
s
.604 .619 .839 r
.60886 .92825 m .60602 .92871 L .60306 .92324 L p F P
0 g
s
.816 .688 .723 r
.25062 .85708 m .24471 .85491 L .24954 .84802 L p F P
0 g
s
.816 .689 .724 r
.25062 .85708 m .24654 .86272 L .24322 .85701 L p F P
0 g
s
.816 .689 .724 r
.24322 .85701 m .24471 .85491 L .25062 .85708 L p F P
0 g
s
.542 .615 .875 r
.66206 .69112 m .67386 .69076 L p .67333 .69585 L F P
0 g
s
.543 .619 .878 r
.67099 .68584 m .67386 .69076 L .66206 .69112 L p F P
0 g
s
.543 .619 .878 r
.66048 .68622 m .67099 .68584 L p .66206 .69112 L F P
0 g
s
.543 .619 .878 r
.66206 .69112 m .65975 .68722 L .66048 .68622 L p F P
0 g
s
.764 .753 .843 r
.18798 .92843 m .18165 .93274 L .1781 .92926 L p F P
0 g
s
.44 .431 .753 r
.75059 .78562 m .74931 .78505 L .75013 .78427 L closepath p F P
0 g
s
.451 .449 .765 r
.74758 .77717 m .74612 .7766 L p .74931 .78505 L F P
0 g
s
.451 .449 .765 r
.74931 .78505 m .75013 .78427 L .74758 .77717 L p F P
0 g
s
.589 .546 .775 r
.57643 .8916 m .57704 .89309 L .56651 .89705 L p F P
0 g
s
.589 .546 .775 r
.56651 .89705 m .56491 .89302 L .57643 .8916 L p F P
0 g
s
.316 .182 .534 r
.75977 .8629 m .75695 .86503 L .7579 .87051 L p F P
0 g
s
.344 .227 .573 r
.75695 .86503 m .75977 .8629 L .759 .85683 L p F P
0 g
s
.655 .138 0 r
.2177 .68892 m .21983 .69138 L .21627 .68839 L p F P
0 g
s
.475 .502 .806 r
.72571 .74491 m .73579 .74722 L p .73195 .75252 L F P
0 g
s
.471 .503 .81 r
.72571 .74491 m .73579 .74722 L .73288 .74047 L p F P
0 g
s
.471 .503 .81 r
.73288 .74047 m .73016 .73984 L .72571 .74491 L p F P
0 g
s
.48 .515 .816 r
.72076 .73796 m .73016 .73984 L .72571 .74491 L p F P
0 g
s
.14 0 .238 r
.74634 .89426 m .74251 .89691 L .74169 .90137 L p F P
0 g
s
.214 0 .349 r
.74251 .89691 m .74634 .89426 L .74907 .8878 L p F P
0 g
s
0 .235 .623 r
.09196 .92879 m .09192 .92876 L .09217 .9289 L closepath p F P
0 g
s
.568 .644 .886 r
.64458 .68279 m .65631 .68167 L .65918 .68629 L p F P
0 g
s
.571 .651 .89 r
.65631 .68167 m .64458 .68279 L .6417 .67839 L p F P
0 g
s
.324 .213 .57 r
.76195 .85445 m .759 .85683 L .75977 .8629 L p F P
0 g
s
.8 .687 .739 r
.24774 .86482 m .24654 .86272 L .24545 .86407 L closepath p F P
0 g
s
.914 .67 .556 r
.23332 .71787 m .23761 .72073 L .23677 .7263 L p F P
0 g
s
.918 .649 .514 r
.23761 .72073 m .23332 .71787 L .23368 .71245 L p F P
0 g
s
0 .272 .665 r
.09192 .92876 m .09196 .92879 L .08815 .92665 L p F P
0 g
s
0 .272 .665 r
.08815 .92665 m .08735 .92624 L .09192 .92876 L p F P
0 g
s
.788 .289 0 r
.06876 .91275 m .07084 .9157 L .06696 .91374 L p F P
0 g
s
.788 .289 0 r
.06696 .91374 m .06436 .91014 L .06876 .91275 L p F P
0 g
s
.449 .325 .618 r
.54943 .75271 m .55677 .74832 L .55223 .74414 L p F P
0 g
s
.456 .338 .63 r
.55047 .75916 m .54943 .75271 L .55677 .74832 L p F P
0 g
s
.488 .36 .632 r
.54885 .76 m .55047 .75916 L .54943 .75271 L p F P
0 g
s
0 .458 .82 r
.10586 .93353 m .10209 .93117 L .09196 .92879 L p F P
0 g
s
.153 .588 .932 r
.09196 .92879 m .10209 .93117 L .09832 .92874 L p F P
0 g
s
.153 .588 .932 r
.08815 .92665 m .09196 .92879 L p .09832 .92874 L F P
0 g
s
.835 .685 .696 r
.24924 .81441 m .25493 .8167 L .25109 .82329 L p F P
0 g
s
.831 .679 .694 r
.25493 .8167 m .24924 .81441 L .25292 .80788 L p F P
0 g
s
.93 .69 .553 r
.036 .86188 m .03996 .8647 L .03907 .87041 L p F P
0 g
s
.925 .705 .586 r
.03996 .8647 m .036 .86188 L .0373 .85606 L p F P
0 g
s
.24 .058 .422 r
.75781 .87627 m .75187 .8807 L .75179 .8859 L p F P
0 g
s
.264 .076 .428 r
.74907 .8878 m .75179 .8859 L .75187 .8807 L p F P
0 g
s
.285 .129 .486 r
.75187 .8807 m .75781 .87627 L .7579 .87051 L p F P
0 g
s
.221 .031 .397 r
.56464 .7113 m .56569 .71047 L .56704 .70464 L p F P
0 g
s
.199 .012 .387 r
.57322 .69952 m .56704 .70464 L .56569 .71047 L p F P
0 g
s
.074 0 .216 r
.56704 .70464 m .57322 .69952 L .57411 .69517 L p F P
0 g
s
.389 .256 .576 r
.55779 .72765 m .55636 .72864 L .55698 .73464 L p F P
0 g
s
.579 .491 .72 r
.54958 .84823 m .5454 .84867 L .54929 .84726 L closepath p F P
0 g
s
.577 .486 .715 r
.54703 .83955 m .54929 .84726 L .5454 .84867 L p F P
0 g
s
.848 .682 .676 r
.25391 .79333 m .25424 .79263 L .25338 .79224 L closepath p F P
0 g
s
.85 .678 .669 r
.25067 .78636 m .25177 .78394 L p .25424 .79263 L F P
0 g
s
.85 .678 .669 r
.25424 .79263 m .25338 .79224 L .25067 .78636 L p F P
0 g
s
.447 .447 .765 r
.74758 .77717 m .74612 .7766 L .74705 .77568 L closepath p F P
0 g
s
.458 .464 .777 r
.74461 .7692 m .74216 .76836 L p .74612 .7766 L F P
0 g
s
.458 .464 .777 r
.74612 .7766 m .74705 .77568 L .74461 .7692 L p F P
0 g
s
.585 .536 .766 r
.57357 .88421 m .57643 .8916 L .56491 .89302 L p F P
0 g
s
.585 .536 .766 r
.56491 .89302 m .56309 .88823 L .57357 .88421 L p F P
0 g
s
.413 .391 .725 r
.75553 .80058 m .75877 .79742 L p .75991 .80643 L F P
0 g
s
.413 .391 .725 r
.75991 .80643 m .75671 .80449 L .75553 .80058 L p F P
0 g
s
.422 .408 .739 r
.75553 .80058 m .75362 .79466 L .75877 .79742 L closepath p F P
0 g
s
.525 .593 .865 r
.68726 .70122 m .6796 .70103 L .67673 .69582 L p F P
0 g
s
.421 .408 .739 r
.75877 .79742 m .75362 .79466 L .75295 .79256 L p F P
0 g
s
.421 .408 .739 r
.75295 .79256 m .75689 .7886 L p .75877 .79742 L F P
0 g
s
.429 .424 .752 r
.75295 .79256 m .75059 .78562 L .75689 .7886 L closepath p F P
0 g
s
.808 .704 .75 r
.23828 .88241 m .2398 .88057 L .23624 .87925 L closepath p F P
0 g
s
.809 .702 .747 r
.23493 .87719 m .23965 .87125 L p .2398 .88057 L F P
0 g
s
.809 .702 .747 r
.2398 .88057 m .23624 .87925 L .23493 .87719 L p F P
0 g
s
.613 .736 .934 r
.63798 .93795 m .64963 .93549 L .65247 .93877 L p F P
0 g
s
.61 .695 .904 r
.64676 .9318 m .64963 .93549 L .63798 .93795 L p F P
0 g
s
.61 .695 .904 r
.63832 .93342 m .64676 .9318 L p .63798 .93795 L F P
0 g
s
.61 .695 .904 r
.63798 .93795 m .6356 .93472 L .63832 .93342 L p F P
0 g
s
.469 .488 .796 r
.73195 .75252 m .73872 .75429 L p .73743 .76033 L F P
0 g
s
.466 .49 .799 r
.73872 .75429 m .73195 .75252 L .73612 .74797 L closepath p F P
0 g
s
.475 .502 .806 r
.73579 .74722 m .73612 .74797 L .73195 .75252 L p F P
0 g
s
.478 .515 .818 r
.73016 .73984 m .72076 .73796 L .71992 .73607 L p F P
0 g
s
.873 .685 .644 r
.244 .7579 m .24892 .7605 L .24665 .76657 L p F P
0 g
s
.873 .678 .636 r
.24892 .7605 m .244 .7579 L .24604 .75191 L p F P
0 g
s
.712 .77 .897 r
.15252 .93777 m .1595 .9344 L .16527 .93655 L p F P
0 g
s
.702 .766 .902 r
.16346 .93251 m .1595 .9344 L .16527 .93655 L p F P
0 g
s
.702 .766 .902 r
.16527 .93655 m .16705 .93574 L .16346 .93251 L p F P
0 g
s
.553 .459 .702 r
.54339 .82645 m .54288 .82449 L .55318 .82018 L p F P
0 g
s
.549 .454 .699 r
.55179 .81496 m .55318 .82018 L .54288 .82449 L p F P
0 g
s
.549 .454 .699 r
.54653 .81475 m .55179 .81496 L p .54288 .82449 L F P
0 g
s
.926 .658 .51 r
.22958 .70952 m .23368 .71245 L .23332 .71787 L p F P
0 g
s
.928 .623 .443 r
.23368 .71245 m .22958 .70952 L .22934 .7043 L p F P
0 g
s
.414 .391 .725 r
.75788 .80836 m .75671 .80449 L .75991 .80643 L closepath p F P
0 g
s
.835 .678 .688 r
.25083 .79907 m .25391 .79333 L .25338 .79224 L p F P
0 g
s
.634 .726 .914 r
.61269 .67576 m .62428 .67266 L .62716 .67637 L p F P
0 g
s
.651 .748 .92 r
.62428 .67266 m .61269 .67576 L .6098 .6728 L p F P
0 g
s
.688 .795 .931 r
.59828 .67744 m .6098 .6728 L .61269 .67576 L p F P
0 g
s
.764 .753 .843 r
.1781 .92926 m .18238 .92623 L .18798 .92843 L p F P
0 g
s
.754 .746 .845 r
.18927 .92143 m .18238 .92623 L .18798 .92843 L p F P
0 g
s
.754 .746 .845 r
.18798 .92843 m .19279 .92521 L .18927 .92143 L p F P
0 g
s
.454 .462 .777 r
.74461 .7692 m .74216 .76836 L .7437 .76679 L closepath p F P
0 g
s
.464 .478 .788 r
.74166 .7616 m .73743 .76033 L p .74216 .76836 L F P
0 g
s
.464 .478 .788 r
.74216 .76836 m .7437 .76679 L .74166 .7616 L p F P
0 g
s
.927 .565 .317 r
.22934 .7043 m .22541 .7013 L .22438 .69634 L p F P
0 g
s
.932 .571 .307 r
.22062 .69327 m .22438 .69634 L .22541 .7013 L p F P
0 g
s
.879 .442 .098 r
.21983 .69138 m .22062 .69327 L .22438 .69634 L p F P
0 g
s
.406 .374 .71 r
.75788 .80836 m .75991 .80643 L p .76031 .81564 L F P
0 g
s
.406 .374 .71 r
.76031 .81564 m .75987 .81533 L .75788 .80836 L p F P
0 g
s
.46 .476 .789 r
.74166 .7616 m .73743 .76033 L .74006 .75756 L closepath p F P
0 g
s
.469 .488 .796 r
.73872 .75429 m .74006 .75756 L .73743 .76033 L p F P
0 g
s
.794 .701 .762 r
.23314 .88799 m .23828 .88241 L .23624 .87925 L p F P
0 g
s
.936 .631 .437 r
.22541 .7013 m .22934 .7043 L .22958 .70952 L p F P
0 g
s
.517 .408 .669 r
.54461 .78433 m .55439 .7794 L p .54922 .78971 L F P
0 g
s
.517 .408 .669 r
.54922 .78971 m .54554 .78876 L .54461 .78433 L p F P
0 g
s
.506 .396 .664 r
.55394 .77729 m .55439 .7794 L .54461 .78433 L p F P
0 g
s
.506 .396 .664 r
.54763 .77524 m .55394 .77729 L p .54461 .78433 L F P
0 g
s
.429 .424 .752 r
.75689 .7886 m .75059 .78562 L .75013 .78427 L p F P
0 g
s
.555 .466 .709 r
.54491 .83198 m .54339 .82645 L .5549 .8266 L p F P
0 g
s
.553 .459 .702 r
.55318 .82018 m .5549 .8266 L .54339 .82645 L p F P
0 g
s
.515 .567 .847 r
.69723 .7124 m .69517 .71225 L .69642 .71079 L closepath p F P
0 g
s
.52 .577 .852 r
.69436 .70685 m .69642 .71079 L .69517 .71225 L p F P
0 g
s
.436 .44 .765 r
.75013 .78427 m .74758 .77717 L .75428 .77997 L closepath p F P
0 g
s
.429 .424 .752 r
.75013 .78427 m .75428 .77997 L p .75689 .7886 L F P
0 g
s
.835 .678 .688 r
.25338 .79224 m .24869 .79027 L p .25083 .79907 L F P
0 g
s
.838 .675 .68 r
.25338 .79224 m .25067 .78636 L .24869 .79027 L closepath p F P
0 g
s
.802 .689 .74 r
.24545 .86407 m .24654 .86272 L .24322 .85701 L p F P
0 g
s
.585 .535 .765 r
.57338 .88373 m .57357 .88421 L .56309 .88823 L p F P
0 g
s
.585 .535 .765 r
.56309 .88823 m .56186 .88499 L .57338 .88373 L p F P
0 g
s
.604 .619 .839 r
.61466 .92152 m .61667 .92511 L .60886 .92825 L p F P
0 g
s
.604 .619 .839 r
.60306 .92324 m .61466 .92152 L p .60886 .92825 L F P
0 g
s
.605 .627 .847 r
.61762 .9268 m .60886 .92825 L .61667 .92511 L closepath p F P
0 g
s
.449 .324 .618 r
.55777 .74082 m .55223 .74414 L .55677 .74832 L p F P
0 g
s
.44 .307 .603 r
.55223 .74414 m .55777 .74082 L .55698 .73464 L p F P
0 g
s
.828 .686 .707 r
.25169 .83407 m .25285 .83218 L .25008 .83107 L closepath p F P
0 g
s
.829 .684 .703 r
.2484 .82784 m .25109 .82329 L p .25285 .83218 L F P
0 g
s
.829 .684 .703 r
.25285 .83218 m .25008 .83107 L .2484 .82784 L p F P
0 g
s
.744 .759 .865 r
.1781 .92926 m .16705 .93574 L .16346 .93251 L p F P
0 g
s
.478 .515 .818 r
.71992 .73607 m .7229 .7325 L p .73016 .73984 L F P
0 g
s
.484 .528 .827 r
.71992 .73607 m .71787 .73164 L .7229 .7325 L closepath p F P
0 g
s
.603 .771 .96 r
.1344 .93591 m .12376 .93818 L .12004 .93564 L p F P
0 g
s
.589 .768 .965 r
.12376 .93818 m .1344 .93591 L .13808 .93867 L p F P
0 g
s
.812 .7 .741 r
.23934 .86196 m .24545 .86407 L .23965 .87125 L p F P
0 g
s
.802 .689 .74 r
.24322 .85701 m .23934 .86196 L .24545 .86407 L p F P
0 g
s
.929 .71 .586 r
.03342 .8532 m .0373 .85606 L .036 .86188 L p F P
0 g
s
.923 .722 .614 r
.03504 .8475 m .03342 .8532 L .0373 .85606 L p F P
0 g
s
.494 .373 .643 r
.55077 .76089 m .54885 .76 L .55047 .75916 L closepath p F P
0 g
s
.722 .834 .934 r
.6098 .6728 m .59828 .67744 L .59541 .67591 L p F P
0 g
s
.6 .886 .991 r
.68642 .93499 m .68132 .9368 L .67859 .9351 L p F P
0 g
s
.607 .858 .991 r
.66692 .93849 m .67859 .9351 L .68132 .9368 L p F P
0 g
s
.822 .694 .724 r
.24366 .84581 m .24954 .84802 L .24471 .85491 L p F P
0 g
s
.818 .687 .72 r
.24954 .84802 m .24366 .84581 L .24833 .83897 L p F P
0 g
s
.595 .589 .816 r
.58551 .91286 m .59708 .91127 L .60008 .91746 L p F P
0 g
s
.593 .572 .8 r
.59547 .90778 m .59708 .91127 L .58551 .91286 L p F P
0 g
s
.593 .572 .8 r
.58551 .91286 m .58506 .91187 L .59547 .90778 L p F P
0 g
s
0 0 0 r
.71877 .92111 m .72478 .91711 L .71999 .92005 L closepath p F P
0 g
s
0 0 0 r
.73027 .91295 m .72478 .91711 L .71999 .92005 L p F P
0 g
s
0 0 0 r
.73127 .91117 m .73027 .91295 L p .71999 .92005 L F P
0 g
s
.431 .837 .646 r
.71999 .92005 m .71877 .92111 L p .70743 .92761 L F P
0 g
s
.555 .466 .709 r
.5549 .8266 m .5552 .82767 L .54491 .83198 L p F P
0 g
s
.56 .47 .71 r
.54491 .83198 m .5552 .82767 L p .55171 .83761 L F P
0 g
s
.56 .47 .71 r
.55171 .83761 m .54649 .83767 L .54491 .83198 L p F P
0 g
s
.856 .685 .669 r
.25067 .78636 m .25177 .78394 L .24879 .78249 L closepath p F P
0 g
s
.858 .681 .661 r
.24742 .77954 m .24923 .77525 L p .25177 .78394 L F P
0 g
s
.858 .681 .661 r
.25177 .78394 m .24879 .78249 L .24742 .77954 L p F P
0 g
s
.881 .686 .634 r
.24128 .74925 m .24604 .75191 L .244 .7579 L p F P
0 g
s
.882 .678 .623 r
.24604 .75191 m .24128 .74925 L .24308 .74334 L p F P
0 g
s
.803 .706 .759 r
.23314 .88799 m .22678 .89503 L .22339 .89021 L p F P
0 g
s
.803 .706 .759 r
.22339 .89021 m .22721 .88585 L .23314 .88799 L p F P
0 g
s
.794 .701 .762 r
.23381 .87844 m .22721 .88585 L .23314 .88799 L p F P
0 g
s
.794 .701 .762 r
.23624 .87925 m .23381 .87844 L p .23314 .88799 L F P
0 g
s
.406 .373 .71 r
.76003 .81589 m .75987 .81533 L .76031 .81564 L closepath p F P
0 g
s
.538 .604 .867 r
.67673 .69582 m .67333 .69585 L .67537 .69339 L closepath p F P
0 g
s
.542 .615 .875 r
.67386 .69076 m .67537 .69339 L .67333 .69585 L p F P
0 g
s
.581 .524 .757 r
.57038 .87559 m .57338 .88373 L .56186 .88499 L p F P
0 g
s
.581 .524 .757 r
.56186 .88499 m .55993 .87967 L .57038 .87559 L p F P
0 g
s
.39 .349 .692 r
.76031 .81564 m .76003 .81589 L .76193 .82317 L p F P
0 g
s
.84 .686 .692 r
.24732 .80554 m .25292 .80788 L .24924 .81441 L p F P
0 g
s
.836 .68 .689 r
.25292 .80788 m .24732 .80554 L .25083 .79907 L p F P
0 g
s
.615 .791 .966 r
.65247 .93877 m .66413 .93593 L .66692 .93849 L p F P
0 g
s
.613 .756 .947 r
.66413 .93593 m .65247 .93877 L .64963 .93549 L p F P
0 g
s
.778 .74 .817 r
.20001 .91951 m .19279 .92521 L .18927 .92143 L p F P
0 g
s
.436 .44 .765 r
.75428 .77997 m .74758 .77717 L .74705 .77568 L p F P
0 g
s
.59 .57 .8 r
.59407 .90473 m .59547 .90778 L .58506 .91187 L p F P
0 g
s
.59 .57 .8 r
.58506 .91187 m .5825 .90614 L .59407 .90473 L p F P
0 g
s
.815 .683 .718 r
.24833 .83897 m .25169 .83407 L .25008 .83107 L p F P
0 g
s
.456 .743 .99 r
.11351 .93587 m .12004 .93564 L .11631 .93304 L p F P
0 g
s
.456 .743 .99 r
.11631 .93304 m .10847 .93349 L .11351 .93587 L p F P
0 g
s
.375 .718 .988 r
.10586 .93353 m .10847 .93349 L .11351 .93587 L p F P
0 g
s
.589 .694 .915 r
.62716 .67637 m .63882 .67424 L p .64123 .67847 L F P
0 g
s
.61 .699 .907 r
.63882 .67424 m .62716 .67637 L .62428 .67266 L p F P
0 g
s
.208 0 .345 r
.75179 .8859 m .74907 .8878 L .74634 .89426 L p F P
0 g
s
.363 .216 .544 r
.55779 .72765 m .56516 .7225 L .56475 .71673 L p F P
0 g
s
.389 .256 .576 r
.55698 .73464 m .5602 .73242 L .55779 .72765 L p F P
0 g
s
.385 .254 .577 r
.56516 .7225 m .55779 .72765 L .5602 .73242 L p F P
0 g
s
.436 .44 .765 r
.74705 .77568 m .75093 .77153 L p .75428 .77997 L F P
0 g
s
.443 .455 .777 r
.74705 .77568 m .74461 .7692 L .75093 .77153 L closepath p F P
0 g
s
.787 .71 .779 r
.22729 .89576 m .22678 .89503 L .22636 .89545 L closepath p F P
0 g
s
.463 0 0 r
.08735 .92624 m .08283 .92369 L .07702 .91978 L p F P
0 g
s
.437 0 0 r
.07246 .91723 m .07702 .91978 L .08283 .92369 L p F P
0 g
s
.678 .131 0 r
.07084 .9157 m .07246 .91723 L .07702 .91978 L p F P
0 g
s
.515 .412 .676 r
.54609 .79126 m .54554 .78876 L .54922 .78971 L closepath p F P
0 g
s
.614 .817 .978 r
.67859 .9351 m .66692 .93849 L .66413 .93593 L p F P
0 g
s
.392 .353 .696 r
.76572 .81052 m .76031 .81564 L .76547 .81992 L p F P
0 g
s
.406 .374 .71 r
.75991 .80643 m .76572 .81052 L .76031 .81564 L p F P
0 g
s
.39 .349 .692 r
.76193 .82317 m .76547 .81992 L .76031 .81564 L p F P
0 g
s
.58 .524 .756 r
.57032 .87543 m .57038 .87559 L .55993 .87967 L p F P
0 g
s
.58 .524 .756 r
.55993 .87967 m .5588 .87652 L .57032 .87543 L p F P
0 g
s
.56 .477 .718 r
.54703 .83955 m .54649 .83767 L .55171 .83761 L closepath p F P
0 g
s
.72 .774 .895 r
.1595 .9344 m .15252 .93777 L .14889 .93479 L p F P
0 g
s
.667 .774 .93 r
.13808 .93867 m .14889 .93479 L .15252 .93777 L p F P
0 g
s
.676 .775 .925 r
.14889 .93479 m .13808 .93867 L .1344 .93591 L p F P
0 g
s
.561 .479 .72 r
.54929 .84726 m .54703 .83955 L .55171 .83761 L p F P
0 g
s
.456 .877 .76 r
.70721 .92768 m .70834 .92708 L .70743 .92761 L closepath p F P
0 g
s
.431 .837 .646 r
.71877 .92111 m .70834 .92708 L .70743 .92761 L p F P
0 g
s
.605 .67 .886 r
.62056 .93168 m .63219 .92968 L .6351 .93403 L p F P
0 g
s
.6 .651 .872 r
.63219 .92968 m .62056 .93168 L .61762 .9268 L p F P
0 g
s
.576 .513 .747 r
.56743 .8672 m .57032 .87543 L .5588 .87652 L p F P
0 g
s
.576 .513 .747 r
.5588 .87652 m .55701 .87132 L .56743 .8672 L p F P
0 g
s
.501 .559 .848 r
.70634 .70786 m .70922 .71353 L .69723 .7124 L p F P
0 g
s
.501 .559 .848 r
.69916 .7072 m .70634 .70786 L p .69723 .7124 L F P
0 g
s
.501 .559 .848 r
.69723 .7124 m .69642 .71079 L .69916 .7072 L p F P
0 g
s
.504 .559 .845 r
.69723 .7124 m .70922 .71353 L p .70554 .71867 L F P
0 g
s
.778 .74 .817 r
.18927 .92143 m .19428 .91734 L .20001 .91951 L p F P
0 g
s
.77 .735 .821 r
.20055 .91231 m .19428 .91734 L .20001 .91951 L p F P
0 g
s
.77 .735 .821 r
.20001 .91951 m .20403 .9164 L .20055 .91231 L p F P
0 g
s
.89 .687 .622 r
.23847 .74062 m .24308 .74334 L .24128 .74925 L p F P
0 g
s
.891 .678 .607 r
.24308 .74334 m .23847 .74062 L .24 .7348 L p F P
0 g
s
.285 .127 .484 r
.56569 .71047 m .56464 .7113 L .56475 .71673 L p F P
0 g
s
.787 .711 .779 r
.22636 .89545 m .22678 .89503 L .22339 .89021 L p F P
0 g
s
.8 .724 .78 r
.22026 .89336 m .22636 .89545 L .21847 .90323 L p F P
0 g
s
.787 .711 .779 r
.22339 .89021 m .22026 .89336 L .22636 .89545 L p F P
0 g
s
.549 .629 .883 r
.65975 .68722 m .65918 .68629 L .66048 .68622 L closepath p F P
0 g
s
.364 .284 .632 r
.76512 .83704 m .76237 .83935 L .76578 .84414 L p F P
0 g
s
.381 .312 .654 r
.76237 .83935 m .76512 .83704 L .76364 .83023 L p F P
0 g
s
.594 .602 .83 r
.61169 .9159 m .61466 .92152 L .60306 .92324 L p F P
0 g
s
.594 .602 .83 r
.60234 .91716 m .61169 .9159 L p .60306 .92324 L F P
0 g
s
.594 .602 .83 r
.60306 .92324 m .60036 .91801 L .60234 .91716 L p F P
0 g
s
.023 0 .195 r
.57747 .69212 m .57411 .69517 L .57322 .69952 L p F P
0 g
s
0 0 0 r
.58326 .68498 m .57747 .69212 L .57411 .69517 L p F P
0 g
s
.864 .687 .661 r
.24923 .77525 m .24742 .77954 L .24415 .7729 L p F P
0 g
s
.864 .687 .661 r
.24415 .7729 m .24424 .77269 L .24923 .77525 L p F P
0 g
s
.866 .683 .653 r
.24923 .77525 m .24424 .77269 L .24665 .76657 L p F P
0 g
s
.843 .681 .682 r
.24869 .79027 m .25067 .78636 L .24879 .78249 L p F P
0 g
s
.517 .418 .681 r
.54771 .79833 m .54609 .79126 L .54922 .78971 L p F P
0 g
s
.507 .397 .662 r
.55394 .77729 m .54763 .77524 L .55298 .77255 L closepath p F P
0 g
s
.505 .386 .652 r
.55167 .7658 m .55298 .77255 L .54763 .77524 L p F P
0 g
s
.834 .687 .7 r
.25109 .82329 m .2484 .82784 L .24511 .82171 L p F P
0 g
s
.834 .687 .7 r
.24511 .82171 m .24555 .82095 L .25109 .82329 L p F P
0 g
s
.835 .685 .696 r
.25109 .82329 m .24555 .82095 L .24924 .81441 L p F P
0 g
s
.576 .512 .747 r
.56725 .86669 m .56743 .8672 L .55701 .87132 L p F P
0 g
s
.576 .512 .747 r
.55701 .87132 m .55573 .86758 L .56725 .86669 L p F P
0 g
s
.565 .483 .721 r
.54958 .84823 m .54929 .84726 L .55968 .84308 L p F P
0 g
s
.561 .479 .72 r
.558 .83748 m .55968 .84308 L .54929 .84726 L p F P
0 g
s
.561 .479 .72 r
.55171 .83761 m .558 .83748 L p .54929 .84726 L F P
0 g
s
.475 .36 .642 r
.55047 .75916 m .5598 .75369 L p .55539 .76364 L F P
0 g
s
.475 .36 .642 r
.55539 .76364 m .55077 .76089 L .55047 .75916 L p F P
0 g
s
.456 .338 .63 r
.5592 .75017 m .5598 .75369 L .55047 .75916 L p F P
0 g
s
.456 .338 .63 r
.55677 .74832 m .5592 .75017 L p .55047 .75916 L F P
0 g
s
.567 .491 .729 r
.55172 .85514 m .54958 .84823 L .56109 .84774 L p F P
0 g
s
.565 .483 .721 r
.55968 .84308 m .56109 .84774 L .54958 .84823 L p F P
0 g
s
.812 .7 .74 r
.23965 .87125 m .23493 .87719 L .23156 .87197 L p F P
0 g
s
.812 .7 .74 r
.23156 .87197 m .23382 .86906 L .23965 .87125 L p F P
0 g
s
.812 .7 .741 r
.23965 .87125 m .23382 .86906 L .23934 .86196 L p F P
0 g
s
.797 .699 .757 r
.23624 .87925 m .23493 .87719 L .23381 .87844 L closepath p F P
0 g
s
.38 .329 .675 r
.76193 .82317 m .76547 .81992 L p .76446 .8295 L F P
0 g
s
.38 .329 .675 r
.76446 .8295 m .76316 .82825 L .76193 .82317 L p F P
0 g
s
.79 .731 .797 r
.20982 .91121 m .20403 .9164 L .20055 .91231 L p F P
0 g
s
.572 .503 .739 r
.56469 .85901 m .56725 .86669 L .55573 .86758 L p F P
0 g
s
.572 .503 .739 r
.55573 .86758 m .55428 .86315 L .56469 .85901 L p F P
0 g
s
.8 .723 .779 r
.21847 .90323 m .21536 .90633 L .21193 .90192 L p F P
0 g
s
.8 .723 .779 r
.21193 .90192 m .2128 .90102 L .21847 .90323 L p F P
0 g
s
.8 .724 .78 r
.21847 .90323 m .2128 .90102 L .22026 .89336 L p F P
0 g
s
.433 .868 .776 r
.70834 .92708 m .70721 .92768 L .70462 .92779 L p F P
0 g
s
.484 .9 .873 r
.69296 .9326 m .70462 .92779 L .70721 .92768 L p F P
0 g
s
.79 .731 .797 r
.20055 .91231 m .2041 .90902 L .20982 .91121 L p F P
0 g
s
.781 .724 .8 r
.21193 .90192 m .2041 .90902 L .20982 .91121 L p F P
0 g
s
.781 .724 .8 r
.20982 .91121 m .21536 .90633 L .21193 .90192 L p F P
0 g
s
.571 .502 .738 r
.56418 .85747 m .56469 .85901 L .55428 .86315 L p F P
0 g
s
.571 .502 .738 r
.55428 .86315 m .55266 .85817 L .56418 .85747 L p F P
0 g
s
.569 .493 .73 r
.55266 .85817 m .55172 .85514 L .56211 .85097 L p F P
0 g
s
.567 .491 .729 r
.56109 .84774 m .56211 .85097 L .55172 .85514 L p F P
0 g
s
.844 .687 .688 r
.24535 .79669 m .25083 .79907 L .24732 .80554 L p F P
0 g
s
.835 .678 .688 r
.24869 .79027 m .24535 .79669 L .25083 .79907 L p F P
0 g
s
.443 .455 .777 r
.75093 .77153 m .74461 .7692 L .7437 .76679 L p F P
0 g
s
0 0 0 r
.73027 .91295 m .73507 .90869 L .73127 .91117 L closepath p F P
0 g
s
0 0 .031 r
.7416 .90168 m .73507 .90869 L .73127 .91117 L p F P
0 g
s
0 0 .031 r
.74169 .90137 m .7416 .90168 L p .73127 .91117 L F P
0 g
s
.569 .493 .73 r
.56211 .85097 m .56418 .85747 L .55266 .85817 L p F P
0 g
s
.815 .683 .718 r
.25008 .83107 m .24702 .82994 L p .24833 .83897 L F P
0 g
s
.817 .681 .713 r
.25008 .83107 m .2484 .82784 L .24702 .82994 L closepath p F P
0 g
s
.484 .528 .827 r
.7229 .7325 m .71787 .73164 L .71498 .7254 L p F P
0 g
s
.397 .825 .663 r
.70834 .92708 m .71673 .92212 L .71877 .92111 L closepath p F P
0 g
s
.433 .868 .776 r
.71673 .92212 m .70834 .92708 L p .70462 .92779 L F P
0 g
s
.826 .694 .718 r
.2425 .83674 m .24833 .83897 L .24366 .84581 L p F P
0 g
s
.815 .683 .718 r
.24702 .82994 m .2425 .83674 L .24833 .83897 L p F P
0 g
s
.509 .572 .854 r
.69642 .71079 m .69436 .70685 L .69916 .7072 L closepath p F P
0 g
s
.548 .635 .889 r
.66048 .68622 m .65918 .68629 L .65631 .68167 L p F P
0 g
s
.9 .687 .606 r
.23556 .73201 m .24 .7348 L .23847 .74062 L p F P
0 g
s
.902 .676 .586 r
.24 .7348 m .23556 .73201 L .23677 .7263 L p F P
0 g
s
.926 .599 .401 r
.04684 .88698 m .04704 .88879 L .04307 .88721 L p F P
0 g
s
.926 .599 .401 r
.04307 .88721 m .04274 .88423 L .04684 .88698 L p F P
0 g
s
.929 .634 .464 r
.04684 .88698 m .04274 .88423 L .04267 .87878 L p F P
0 g
s
.471 .362 .648 r
.55167 .7658 m .55077 .76089 L .55539 .76364 L closepath p F P
0 g
s
.822 .694 .724 r
.23989 .85136 m .24366 .84581 L p .24471 .85491 L F P
0 g
s
.822 .694 .724 r
.24471 .85491 m .24114 .8535 L .23989 .85136 L p F P
0 g
s
.82 .696 .727 r
.24322 .85701 m .24471 .85491 L .24114 .8535 L closepath p F P
0 g
s
.9 .511 .278 r
.05763 .90267 m .05335 .90001 L .0518 .89495 L p F P
0 g
s
.902 .512 .27 r
.04758 .89225 m .0518 .89495 L .05335 .90001 L p F P
0 g
s
.918 .578 .381 r
.04704 .88879 m .04758 .89225 L .0518 .89495 L p F P
0 g
s
.443 .455 .777 r
.7437 .76679 m .74686 .7633 L p .75093 .77153 L F P
0 g
s
.45 .47 .788 r
.7437 .76679 m .74166 .7616 L .74686 .7633 L closepath p F P
0 g
s
.6 .886 .991 r
.69176 .93209 m .68642 .93499 L p .67859 .9351 L F P
0 g
s
.618 .905 .984 r
.68642 .93499 m .69176 .93209 L .69296 .9326 L closepath p F P
0 g
s
.316 .182 .534 r
.7579 .87051 m .76029 .8687 L .75977 .8629 L p F P
0 g
s
.294 .166 .53 r
.76374 .8597 m .75977 .8629 L .76029 .8687 L p F P
0 g
s
.324 .213 .57 r
.75977 .8629 m .76374 .8597 L .76195 .85445 L p F P
0 g
s
.5 .546 .836 r
.70554 .71867 m .7121 .71945 L p .7149 .72539 L F P
0 g
s
.498 .548 .838 r
.7121 .71945 m .70554 .71867 L .70943 .71396 L closepath p F P
0 g
s
.504 .559 .845 r
.70922 .71353 m .70943 .71396 L .70554 .71867 L p F P
0 g
s
.881 .447 .09 r
.22062 .69327 m .21983 .69138 L .21627 .68839 L p F P
0 g
s
.55 .453 .696 r
.55179 .81496 m .54653 .81475 L .55123 .81277 L closepath p F P
0 g
s
.548 .445 .689 r
.54942 .8055 m .55123 .81277 L .54653 .81475 L p F P
0 g
s
.586 .558 .79 r
.59115 .89807 m .59407 .90473 L .5825 .90614 L p F P
0 g
s
.586 .558 .79 r
.5825 .90614 m .58085 .90229 L .59115 .89807 L p F P
0 g
s
.404 .282 .598 r
.5602 .73242 m .55698 .73464 L .55777 .74082 L p F P
0 g
s
.932 .638 .461 r
.03864 .876 m .04267 .87878 L .04274 .88423 L p F P
0 g
s
.931 .665 .513 r
.04267 .87878 m .03864 .876 L .03907 .87041 L p F P
0 g
s
.589 .676 .901 r
.6417 .67839 m .64123 .67847 L .64152 .67813 L closepath p F P
0 g
s
.589 .694 .915 r
.63882 .67424 m .64152 .67813 L .64123 .67847 L p F P
0 g
s
.872 .69 .653 r
.24179 .76395 m .24665 .76657 L .24424 .77269 L p F P
0 g
s
.873 .685 .644 r
.24665 .76657 m .24179 .76395 L .244 .7579 L p F P
0 g
s
.285 .127 .484 r
.56475 .71673 m .56583 .71588 L .56569 .71047 L p F P
0 g
s
.269 .116 .48 r
.57291 .7045 m .56569 .71047 L .56583 .71588 L p F P
0 g
s
.199 .012 .387 r
.56569 .71047 m .57291 .7045 L .57322 .69952 L p F P
0 g
s
.525 .593 .865 r
.67673 .69582 m .68862 .69605 L p .68726 .70122 L F P
0 g
s
.524 .596 .868 r
.68574 .69088 m .68862 .69605 L .67673 .69582 L p F P
0 g
s
.524 .596 .868 r
.67725 .69075 m .68574 .69088 L p .67673 .69582 L F P
0 g
s
.524 .596 .868 r
.67673 .69582 m .67537 .69339 L .67725 .69075 L p F P
0 g
s
.86 .415 .14 r
.06436 .91014 m .06003 .90751 L .05763 .90267 L p F P
0 g
s
.859 .412 .127 r
.05335 .90001 m .05763 .90267 L .06003 .90751 L p F P
0 g
s
.61 .695 .903 r
.6356 .93472 m .6351 .93403 L .63832 .93342 L closepath p F P
0 g
s
.845 .677 .674 r
.24879 .78249 m .24742 .77954 L .2465 .78147 L closepath p F P
0 g
s
.843 .681 .682 r
.24879 .78249 m .2465 .78147 L p .24869 .79027 L F P
0 g
s
.807 .693 .739 r
.23934 .86196 m .24322 .85701 L .24114 .8535 L p F P
0 g
s
.571 .651 .89 r
.6417 .67839 m .65343 .67713 L .65631 .68167 L p F P
0 g
s
.574 .669 .903 r
.65055 .67269 m .65343 .67713 L .6417 .67839 L p F P
0 g
s
.574 .669 .903 r
.64462 .67345 m .65055 .67269 L p .6417 .67839 L F P
0 g
s
.574 .669 .903 r
.6417 .67839 m .64152 .67813 L .64462 .67345 L p F P
0 g
s
.381 .329 .674 r
.76364 .83023 m .76316 .82825 L .76446 .8295 L closepath p F P
0 g
s
.77 .757 .841 r
.18238 .92623 m .1781 .92926 L .17455 .92577 L p F P
0 g
s
.744 .759 .865 r
.16346 .93251 m .17455 .92577 L .1781 .92926 L p F P
0 g
s
.798 .701 .758 r
.23381 .87844 m .23493 .87719 L .23156 .87197 L p F P
0 g
s
.401 .372 .712 r
.76522 .80132 m .75991 .80643 L .76572 .81052 L p F P
0 g
s
.413 .391 .725 r
.75877 .79742 m .76522 .80132 L .75991 .80643 L p F P
0 g
s
.91 .685 .584 r
.23249 .72345 m .23677 .7263 L .23556 .73201 L p F P
0 g
s
.914 .67 .556 r
.23677 .7263 m .23249 .72345 L .23332 .71787 L p F P
0 g
s
.281 .126 .485 r
.76029 .8687 m .7579 .87051 L .75781 .87627 L p F P
0 g
s
.653 .101 0 r
.07246 .91723 m .07084 .9157 L .06696 .91374 L p F P
0 g
s
.549 .63 .885 r
.66048 .68622 m .67099 .68584 L .66811 .68097 L p F P
0 g
s
.549 .63 .885 r
.66811 .68097 m .66409 .68118 L .66048 .68622 L p F P
0 g
s
.548 .635 .889 r
.65631 .68167 m .66409 .68118 L .66048 .68622 L p F P
0 g
s
.841 .691 .697 r
.24379 .81204 m .24924 .81441 L .24555 .82095 L p F P
0 g
s
.84 .686 .692 r
.24924 .81441 m .24379 .81204 L .24732 .80554 L p F P
0 g
s
.346 .252 .603 r
.76678 .84607 m .76578 .84414 L p .76195 .85445 L F P
0 g
s
.346 .252 .603 r
.76195 .85445 m .76742 .84998 L .76678 .84607 L p F P
0 g
s
.321 .211 .57 r
.76742 .84998 m .76195 .85445 L .76374 .8597 L p F P
0 g
s
.527 .426 .684 r
.54771 .79833 m .55756 .79349 L p .55381 .80336 L F P
0 g
s
.527 .426 .684 r
.55381 .80336 m .54867 .80244 L .54771 .79833 L p F P
0 g
s
.517 .418 .681 r
.55709 .7915 m .55756 .79349 L .54771 .79833 L p F P
0 g
s
.517 .418 .681 r
.54922 .78971 m .55709 .7915 L p .54771 .79833 L F P
0 g
s
.809 .713 .759 r
.2278 .8763 m .23381 .87844 L .22721 .88585 L p F P
0 g
s
.798 .701 .758 r
.23156 .87197 m .2278 .8763 L .23381 .87844 L p F P
0 g
s
.579 .677 .906 r
.64152 .67813 m .63882 .67424 L .64462 .67345 L closepath p F P
0 g
s
.408 .728 .99 r
.10847 .93349 m .10586 .93353 L .10209 .93117 L p F P
0 g
s
.934 .669 .511 r
.03511 .86759 m .03907 .87041 L .03864 .876 L p F P
0 g
s
.93 .69 .553 r
.03907 .87041 m .03511 .86759 L .036 .86188 L p F P
0 g
s
.849 .689 .684 r
.24333 .78783 m .24869 .79027 L .24535 .79669 L p F P
0 g
s
.843 .681 .682 r
.2465 .78147 m .24333 .78783 L .24869 .79027 L p F P
0 g
s
.82 .685 .715 r
.24702 .82994 m .2484 .82784 L .24511 .82171 L p F P
0 g
s
.362 .3 .652 r
.76446 .8295 m .76364 .83023 L .76512 .83704 L p F P
0 g
s
.72 .774 .895 r
.14889 .93479 m .15412 .93213 L .1595 .9344 L p F P
0 g
s
.71 .767 .897 r
.15986 .92926 m .15412 .93213 L .1595 .9344 L p F P
0 g
s
.71 .767 .897 r
.1595 .9344 m .16346 .93251 L .15986 .92926 L p F P
0 g
s
.45 .47 .788 r
.74686 .7633 m .74166 .7616 L .74006 .75756 L p F P
0 g
s
.585 .558 .79 r
.59105 .89784 m .59115 .89807 L .58085 .90229 L p F P
0 g
s
.585 .558 .79 r
.58085 .90229 m .57947 .89906 L .59105 .89784 L p F P
0 g
s
.14 0 .238 r
.74169 .90137 m .74203 .90113 L .74634 .89426 L p F P
0 g
s
.101 0 .188 r
.75137 .89075 m .74634 .89426 L .74203 .90113 L p F P
0 g
s
.208 0 .345 r
.74634 .89426 m .75137 .89075 L .75179 .8859 L p F P
0 g
s
.613 .673 .884 r
.63832 .93342 m .6351 .93403 L .63219 .92968 L p F P
0 g
s
.851 .684 .676 r
.2465 .78147 m .24742 .77954 L .24415 .7729 L p F P
0 g
s
0 .303 .699 r
.08735 .92624 m .08815 .92665 L .08433 .92442 L p F P
0 g
s
0 .303 .699 r
.08433 .92442 m .08283 .92369 L .08735 .92624 L p F P
0 g
s
.77 .757 .841 r
.17455 .92577 m .17702 .92395 L .18238 .92623 L p F P
0 g
s
.76 .748 .842 r
.18575 .91766 m .17702 .92395 L .18238 .92623 L p F P
0 g
s
.76 .748 .842 r
.18238 .92623 m .18927 .92143 L .18575 .91766 L p F P
0 g
s
.922 .679 .553 r
.22921 .71494 m .23332 .71787 L .23249 .72345 L p F P
0 g
s
.926 .658 .51 r
.23332 .71787 m .22921 .71494 L .22958 .70952 L p F P
0 g
s
.881 .692 .643 r
.23928 .75523 m .244 .7579 L .24179 .76395 L p F P
0 g
s
.881 .686 .634 r
.244 .7579 m .23928 .75523 L .24128 .74925 L p F P
0 g
s
.78 .275 0 r
.06436 .91014 m .06696 .91374 L .06308 .91164 L p F P
0 g
s
.78 .275 0 r
.06308 .91164 m .06003 .90751 L .06436 .91014 L p F P
0 g
s
.921 .579 .372 r
.04758 .89225 m .04704 .88879 L .04307 .88721 L p F P
0 g
s
.829 .694 .715 r
.24126 .82768 m .24702 .82994 L .2425 .83674 L p F P
0 g
s
.82 .685 .715 r
.24511 .82171 m .24126 .82768 L .24702 .82994 L p F P
0 g
s
.476 .37 .655 r
.55539 .76364 m .55167 .7658 L .55298 .77255 L p F P
0 g
s
.82 .705 .739 r
.2335 .85975 m .23934 .86196 L .23382 .86906 L p F P
0 g
s
.807 .693 .739 r
.23888 .85269 m .2335 .85975 L .23934 .86196 L p F P
0 g
s
.807 .693 .739 r
.24114 .8535 m .23888 .85269 L p .23934 .86196 L F P
0 g
s
.525 .431 .691 r
.54942 .8055 m .54867 .80244 L .55381 .80336 L closepath p F P
0 g
s
.594 .602 .829 r
.60036 .91801 m .60008 .91746 L .60234 .91716 L closepath p F P
0 g
s
.934 .694 .552 r
.03211 .85902 m .036 .86188 L .03511 .86759 L p F P
0 g
s
.929 .71 .586 r
.036 .86188 m .03211 .85902 L .03342 .8532 L p F P
0 g
s
.18 0 .337 r
.75657 .88235 m .75179 .8859 L .75137 .89075 L p F P
0 g
s
.24 .058 .422 r
.75179 .8859 m .75657 .88235 L .75781 .87627 L p F P
0 g
s
.826 .694 .719 r
.24366 .84581 m .23989 .85136 L .23656 .84575 L p F P
0 g
s
.826 .694 .719 r
.23656 .84575 m .23803 .84353 L .24366 .84581 L p F P
0 g
s
.826 .694 .718 r
.24366 .84581 m .23803 .84353 L .2425 .83674 L p F P
0 g
s
.519 .417 .679 r
.55709 .7915 m .54922 .78971 L .55594 .78641 L closepath p F P
0 g
s
.517 .408 .669 r
.55439 .7794 m .55594 .78641 L .54922 .78971 L p F P
0 g
s
.934 .667 .506 r
.22563 .70652 m .22958 .70952 L .22921 .71494 L p F P
0 g
s
.936 .631 .437 r
.22958 .70952 m .22563 .70652 L .22541 .7013 L p F P
0 g
s
.809 .713 .758 r
.22721 .88585 m .22339 .89021 L .21998 .88543 L p F P
0 g
s
.809 .713 .758 r
.21998 .88543 m .22152 .88363 L .22721 .88585 L p F P
0 g
s
.809 .713 .759 r
.22721 .88585 m .22152 .88363 L .2278 .8763 L p F P
0 g
s
.45 .47 .788 r
.74006 .75756 m .74208 .75526 L p .74686 .7633 L F P
0 g
s
.457 .484 .799 r
.74006 .75756 m .73872 .75429 L .74208 .75526 L closepath p F P
0 g
s
.594 .588 .816 r
.60234 .91716 m .60008 .91746 L .59708 .91127 L p F P
0 g
s
.581 .546 .781 r
.58801 .89053 m .59105 .89784 L .57947 .89906 L p F P
0 g
s
.581 .546 .781 r
.58178 .89112 m .58801 .89053 L p .57947 .89906 L F P
0 g
s
.581 .546 .781 r
.57947 .89906 m .57704 .89309 L .58178 .89112 L p F P
0 g
s
.532 .607 .874 r
.67537 .69339 m .67386 .69076 L .67725 .69075 L closepath p F P
0 g
s
.509 .574 .856 r
.69916 .7072 m .69436 .70685 L .69149 .70139 L p F P
0 g
s
.562 .477 .716 r
.558 .83748 m .55171 .83761 L .55737 .83531 L closepath p F P
0 g
s
.56 .47 .71 r
.5552 .82767 m .55737 .83531 L .55171 .83761 L p F P
0 g
s
.493 .536 .829 r
.71498 .7254 m .7149 .72539 L .71495 .72533 L closepath p F P
0 g
s
.5 .546 .836 r
.7121 .71945 m .71495 .72533 L .7149 .72539 L p F P
0 g
s
.847 .693 .691 r
.24197 .80313 m .24732 .80554 L .24379 .81204 L p F P
0 g
s
.844 .687 .688 r
.24732 .80554 m .24197 .80313 L .24535 .79669 L p F P
0 g
s
.851 .684 .676 r
.24415 .7729 m .24126 .77898 L .2465 .78147 L p F P
0 g
s
.854 .691 .679 r
.24126 .77898 m .2465 .78147 L .24333 .78783 L p F P
0 g
s
.484 .528 .827 r
.71498 .7254 m .72708 .72746 L p .7229 .7325 L F P
0 g
s
.478 .528 .83 r
.72419 .72133 m .72708 .72746 L .71498 .7254 L p F P
0 g
s
.478 .528 .83 r
.71876 .72041 m .72419 .72133 L p .71498 .7254 L F P
0 g
s
.478 .528 .83 r
.71498 .7254 m .71495 .72533 L .71876 .72041 L p F P
0 g
s
.944 .639 .43 r
.22163 .69824 m .22541 .7013 L .22563 .70652 L p F P
0 g
s
.932 .571 .307 r
.22541 .7013 m .22163 .69824 L .22062 .69327 L p F P
0 g
s
.488 .542 .838 r
.71495 .72533 m .7121 .71945 L .71876 .72041 L closepath p F P
0 g
s
.527 .435 .694 r
.55123 .81277 m .54942 .8055 L .55381 .80336 L p F P
0 g
s
.937 .575 .294 r
.217 .69014 m .22062 .69327 L .22163 .69824 L p F P
0 g
s
.881 .447 .09 r
.21627 .68839 m .217 .69014 L .22062 .69327 L p F P
0 g
s
.153 .588 .932 r
.09832 .92874 m .09831 .92873 L .08815 .92665 L p F P
0 g
s
.125 .583 .921 r
.09831 .92873 m .08815 .92665 L .08433 .92442 L p F P
0 g
s
.49 .877 .69 r
.71673 .92212 m .71877 .92111 L .72478 .91711 L p F P
0 g
s
.362 .3 .652 r
.76512 .83704 m .76835 .83416 L .76446 .8295 L p F P
0 g
s
.363 .303 .656 r
.77007 .82437 m .76446 .8295 L .76835 .83416 L p F P
0 g
s
.38 .329 .675 r
.76547 .81992 m .77007 .82437 L .76446 .8295 L p F P
0 g
s
.41 .392 .728 r
.76338 .79287 m .75877 .79742 L .76522 .80132 L p F P
0 g
s
.421 .408 .739 r
.76304 .79185 m .76338 .79287 L .75877 .79742 L p F P
0 g
s
.421 .408 .739 r
.75689 .7886 m .76304 .79185 L p .75877 .79742 L F P
0 g
s
.52 .583 .858 r
.69149 .70139 m .68726 .70122 L .68974 .6981 L closepath p F P
0 g
s
.525 .593 .865 r
.68862 .69605 m .68974 .6981 L .68726 .70122 L p F P
0 g
s
.6 .651 .872 r
.61762 .9268 m .62926 .92498 L .63219 .92968 L p F P
0 g
s
.596 .623 .849 r
.6267 .92059 m .62926 .92498 L .61762 .9268 L p F P
0 g
s
.596 .623 .849 r
.61762 .9268 m .61667 .92511 L .6267 .92059 L p F P
0 g
s
.81 .691 .734 r
.24114 .8535 m .23989 .85136 L .23888 .85269 L closepath p F P
0 g
s
.749 .761 .862 r
.17455 .92577 m .16346 .93251 L .15986 .92926 L p F P
0 g
s
.651 .748 .92 r
.6098 .6728 m .62139 .66918 L .62428 .67266 L p F P
0 g
s
.675 .775 .926 r
.62139 .66918 m .6098 .6728 L .60692 .67026 L p F P
0 g
s
.722 .834 .934 r
.59541 .67591 m .60692 .67026 L .6098 .6728 L p F P
0 g
s
.889 .694 .633 r
.2367 .74652 m .24128 .74925 L .23928 .75523 L p F P
0 g
s
.89 .687 .622 r
.24128 .74925 m .2367 .74652 L .23847 .74062 L p F P
0 g
s
.651 .915 .979 r
.69176 .93209 m .69296 .9326 L .70462 .92779 L p F P
0 g
s
.785 .744 .816 r
.19428 .91734 m .18927 .92143 L .18575 .91766 L p F P
0 g
s
.793 .714 .777 r
.22026 .89336 m .22339 .89021 L .21998 .88543 L p F P
0 g
s
0 0 0 r
.58375 .68449 m .58399 .68431 L .59527 .67599 L p F P
0 g
s
.475 .749 .989 r
.10847 .93349 m .11631 .93304 L .11258 .9304 L p F P
0 g
s
.475 .749 .989 r
.11258 .9304 m .10341 .93111 L .10847 .93349 L p F P
0 g
s
.408 .728 .99 r
.10209 .93117 m .10341 .93111 L .10847 .93349 L p F P
0 g
s
.805 .727 .779 r
.21445 .89118 m .22026 .89336 L .2128 .90102 L p F P
0 g
s
.793 .714 .777 r
.21998 .88543 m .21445 .89118 L .22026 .89336 L p F P
0 g
s
.059 0 .117 r
.7416 .90168 m .74203 .90113 L .74169 .90137 L closepath p F P
0 g
s
.613 .756 .947 r
.64963 .93549 m .66131 .93291 L .66413 .93593 L p F P
0 g
s
.608 .726 .928 r
.66131 .93291 m .64963 .93549 L .64676 .9318 L p F P
0 g
s
.456 .484 .799 r
.74208 .75526 m .73872 .75429 L .73612 .74797 L p F P
0 g
s
.612 .687 .896 r
.64676 .9318 m .63832 .93342 L .64561 .93016 L closepath p F P
0 g
s
.613 .673 .884 r
.64387 .92769 m .64561 .93016 L .63832 .93342 L p F P
0 g
s
.613 .673 .884 r
.63219 .92968 m .64387 .92769 L p .63832 .93342 L F P
0 g
s
.785 .744 .816 r
.18575 .91766 m .18879 .91509 L .19428 .91734 L p F P
0 g
s
.775 .737 .818 r
.19707 .90824 m .18879 .91509 L .19428 .91734 L p F P
0 g
s
.775 .737 .818 r
.19428 .91734 m .20055 .91231 L .19707 .90824 L p F P
0 g
s
.603 .771 .96 r
.12004 .93564 m .13072 .93312 L .1344 .93591 L p F P
0 g
s
.615 .773 .956 r
.13072 .93312 m .12004 .93564 L .11631 .93304 L p F P
0 g
s
.61 .699 .907 r
.62428 .67266 m .63594 .67024 L .63882 .67424 L p F P
0 g
s
.622 .714 .912 r
.63594 .67024 m .62428 .67266 L .62139 .66918 L p F P
0 g
s
.437 0 0 r
.08283 .92369 m .07837 .92111 L .07246 .91723 L p F P
0 g
s
.413 0 0 r
.06796 .91465 m .07246 .91723 L .07837 .92111 L p F P
0 g
s
.653 .101 0 r
.06696 .91374 m .06796 .91465 L .07246 .91723 L p F P
0 g
s
.415 .301 .614 r
.56338 .73699 m .55777 .74082 L .55871 .74717 L p F P
0 g
s
.404 .282 .598 r
.55777 .74082 m .56338 .73699 L .5602 .73242 L p F P
0 g
s
.449 .324 .618 r
.55677 .74832 m .55871 .74717 L .55777 .74082 L p F P
0 g
s
.344 .271 .629 r
.76835 .83416 m .76512 .83704 L .76639 .84364 L p F P
0 g
s
.364 .284 .632 r
.76578 .84414 m .76639 .84364 L .76512 .83704 L p F P
0 g
s
.323 .187 .536 r
.56583 .71588 m .56475 .71673 L .56516 .7225 L p F P
0 g
s
.839 .693 .702 r
.24511 .82171 m .24555 .82095 L .2444 .82045 L closepath p F P
0 g
s
.841 .691 .697 r
.2418 .81563 m .24379 .81204 L p .24555 .82095 L F P
0 g
s
.841 .691 .697 r
.24555 .82095 m .2444 .82045 L .2418 .81563 L p F P
0 g
s
0 0 .005 r
.74203 .90113 m .74995 .8956 L p .74029 .90525 L F P
0 g
s
0 0 .005 r
.74029 .90525 m .7416 .90168 L .74203 .90113 L p F P
0 g
s
.101 0 .188 r
.75069 .89452 m .75137 .89075 L p .74203 .90113 L F P
0 g
s
.101 0 .188 r
.74203 .90113 m .74995 .8956 L .75069 .89452 L p F P
0 g
s
.819 .706 .74 r
.23382 .86906 m .23156 .87197 L .22818 .86684 L p F P
0 g
s
.819 .706 .74 r
.22818 .86684 m .22822 .86679 L .23382 .86906 L p F P
0 g
s
.82 .705 .739 r
.23382 .86906 m .22822 .86679 L .2335 .85975 L p F P
0 g
s
.595 .596 .823 r
.61169 .9159 m .60234 .91716 L .61061 .91373 L closepath p F P
0 g
s
.594 .588 .816 r
.6087 .90991 m .61061 .91373 L .60234 .91716 L p F P
0 g
s
.594 .588 .816 r
.59708 .91127 m .6087 .90991 L p .60234 .91716 L F P
0 g
s
.58 .545 .78 r
.57704 .89309 m .57643 .8916 L .58178 .89112 L closepath p F P
0 g
s
.027 0 .043 r
.73507 .90869 m .74029 .90525 L .7416 .90168 L closepath p F P
0 g
s
.49 .877 .69 r
.72478 .91711 m .72917 .91437 L p .71673 .92212 L F P
0 g
s
0 0 0 r
.72478 .91711 m .72917 .91437 L .73027 .91295 L closepath p F P
0 g
s
.595 .622 .849 r
.62632 .91993 m .6267 .92059 L .61667 .92511 L p F P
0 g
s
.595 .622 .849 r
.61667 .92511 m .61466 .92152 L .62632 .91993 L p F P
0 g
s
.803 .729 .782 r
.21193 .90192 m .2128 .90102 L .21047 .90007 L closepath p F P
0 g
s
.805 .727 .779 r
.20848 .8975 m .21445 .89118 L p .2128 .90102 L F P
0 g
s
.805 .727 .779 r
.2128 .90102 m .21047 .90007 L .20848 .8975 L p F P
0 g
s
0 0 0 r
.58876 .6793 m .58375 .68449 L p .58731 .68099 L F P
0 g
s
0 0 0 r
.59256 .67583 m .58876 .6793 L p .58731 .68099 L F P
0 g
s
0 0 0 r
.59536 .67589 m .59256 .67583 L p .58375 .68449 L F P
0 g
s
0 0 0 r
.59527 .67599 m .59536 .67589 L p .58375 .68449 L F P
0 g
s
.702 .97 .745 r
.58876 .6793 m .59109 .67649 L .59256 .67583 L closepath p F P
0 g
s
0 0 0 r
.58876 .6793 m .58319 .6864 L p .58996 .67791 L F P
0 g
s
0 0 0 r
.59109 .67649 m .58876 .6793 L p .58996 .67791 L F P
0 g
s
0 0 0 r
.58876 .6793 m .58375 .68449 L .58188 .68775 L p F P
0 g
s
0 0 0 r
.57747 .69212 m .58188 .68775 L .58375 .68449 L p F P
0 g
s
.797 .735 .796 r
.2041 .90902 m .20055 .91231 L .19707 .90824 L p F P
0 g
s
.797 .735 .796 r
.19707 .90824 m .19861 .90677 L .2041 .90902 L p F P
0 g
s
.786 .726 .797 r
.20705 .89883 m .19861 .90677 L .2041 .90902 L p F P
0 g
s
.786 .726 .797 r
.21047 .90007 m .20705 .89883 L p .2041 .90902 L F P
0 g
s
.786 .726 .797 r
.2041 .90902 m .21193 .90192 L .21047 .90007 L p F P
0 g
s
.898 .695 .62 r
.23405 .73782 m .23847 .74062 L .2367 .74652 L p F P
0 g
s
.9 .687 .606 r
.23847 .74062 m .23405 .73782 L .23556 .73201 L p F P
0 g
s
.869 .694 .663 r
.24415 .7729 m .24424 .77269 L .24396 .77254 L closepath p F P
0 g
s
.872 .69 .653 r
.24088 .76628 m .24179 .76395 L p .24424 .77269 L F P
0 g
s
.872 .69 .653 r
.24424 .77269 m .24396 .77254 L .24088 .76628 L p F P
0 g
s
.812 .695 .736 r
.23888 .85269 m .23989 .85136 L .23656 .84575 L p F P
0 g
s
.536 .443 .697 r
.55123 .81277 m .56118 .80804 L p .56166 .81614 L F P
0 g
s
.536 .443 .697 r
.56166 .81614 m .55179 .81496 L .55123 .81277 L p F P
0 g
s
.527 .435 .694 r
.56023 .80437 m .56118 .80804 L .55123 .81277 L p F P
0 g
s
.527 .435 .694 r
.55381 .80336 m .56023 .80437 L p .55123 .81277 L F P
0 g
s
.826 .69 .714 r
.24126 .82768 m .24511 .82171 L .2444 .82045 L p F P
0 g
s
.728 .777 .892 r
.15412 .93213 m .14889 .93479 L .14524 .93178 L p F P
0 g
s
.676 .775 .925 r
.1344 .93591 m .14524 .93178 L .14889 .93479 L p F P
0 g
s
.852 .695 .686 r
.24011 .79422 m .24535 .79669 L .24197 .80313 L p F P
0 g
s
.849 .689 .684 r
.24535 .79669 m .24011 .79422 L .24333 .78783 L p F P
0 g
s
.857 .692 .677 r
.24126 .77898 m .24415 .7729 L .24396 .77254 L p F P
0 g
s
.58 .537 .771 r
.58178 .89112 m .57643 .8916 L .57357 .88421 L p F P
0 g
s
.476 .517 .821 r
.72998 .73391 m .7229 .7325 L .72708 .72747 L closepath p F P
0 g
s
.484 .528 .827 r
.72708 .72746 m .72708 .72747 L .7229 .7325 L p F P
0 g
s
.478 .515 .818 r
.7229 .7325 m .72998 .73391 L p .73016 .73984 L F P
0 g
s
.832 .7 .718 r
.23693 .83442 m .2425 .83674 L .23803 .84353 L p F P
0 g
s
.829 .694 .715 r
.2425 .83674 m .23693 .83442 L .24126 .82768 L p F P
0 g
s
.419 .41 .743 r
.76304 .79185 m .75689 .7886 L .7607 .78472 L closepath p F P
0 g
s
.429 .424 .752 r
.75998 .78264 m .7607 .78472 L .75689 .7886 L p F P
0 g
s
.429 .424 .752 r
.75428 .77997 m .75998 .78264 L p .75689 .7886 L F P
0 g
s
.491 .385 .662 r
.55298 .77255 m .56216 .76724 L p .55633 .77831 L F P
0 g
s
.491 .385 .662 r
.55633 .77831 m .55394 .77729 L .55298 .77255 L p F P
0 g
s
.476 .37 .655 r
.55298 .77255 m .56216 .76724 L .55539 .76364 L p F P
0 g
s
.857 .692 .677 r
.24396 .77254 m .23916 .77014 L p .24126 .77898 L F P
0 g
s
.859 .687 .667 r
.24396 .77254 m .24088 .76628 L .23916 .77014 L closepath p F P
0 g
s
.552 .642 .893 r
.66409 .68118 m .65631 .68167 L .65343 .67713 L p F P
0 g
s
.6 .886 .991 r
.67859 .9351 m .69027 .93137 L .69176 .93209 L p F P
0 g
s
.611 .848 .988 r
.69027 .93137 m .67859 .9351 L .67582 .93288 L p F P
0 g
s
.614 .817 .978 r
.66413 .93593 m .67582 .93288 L .67859 .9351 L p F P
0 g
s
.684 .776 .921 r
.14524 .93178 m .1344 .93591 L .13072 .93312 L p F P
0 g
s
.401 .281 .599 r
.5658 .72852 m .5602 .73242 L .56338 .73699 L p F P
0 g
s
.385 .254 .577 r
.5602 .73242 m .5658 .72852 L .56516 .7225 L p F P
0 g
s
.613 .78 .961 r
.67582 .93288 m .66413 .93593 L .66131 .93291 L p F P
0 g
s
.812 .695 .736 r
.23656 .84575 m .23305 .85047 L .23888 .85269 L p F P
0 g
s
.821 .704 .736 r
.23305 .85047 m .23888 .85269 L .2335 .85975 L p F P
0 g
s
.534 .448 .705 r
.55318 .82018 m .55179 .81496 L .56166 .81614 L closepath p F P
0 g
s
.257 .108 .479 r
.76465 .8652 m .76029 .8687 L .76053 .87422 L p F P
0 g
s
.294 .166 .53 r
.76029 .8687 m .76465 .8652 L .76374 .8597 L p F P
0 g
s
.281 .126 .485 r
.75781 .87627 m .76053 .87422 L .76029 .8687 L p F P
0 g
s
.803 .705 .757 r
.2278 .8763 m .23156 .87197 L .22818 .86684 L p F P
0 g
s
.53 .611 .878 r
.67725 .69075 m .67386 .69076 L .67099 .68584 L p F P
0 g
s
0 0 0 r
.72917 .91437 m .73027 .91295 L .73507 .90869 L p F P
0 g
s
.458 .34 .632 r
.5592 .75017 m .55677 .74832 L .55871 .74717 L closepath p F P
0 g
s
0 0 0 r
.73507 .90869 m .74029 .90525 L p .72917 .91437 L F P
0 g
s
.027 0 .235 r
.58188 .68775 m .57747 .69212 L .57437 .69847 L p F P
0 g
s
.023 0 .195 r
.57322 .69952 m .57437 .69847 L .57747 .69212 L p F P
0 g
s
.826 .69 .714 r
.2444 .82045 m .23994 .81863 L p .24126 .82768 L F P
0 g
s
.828 .688 .708 r
.2444 .82045 m .2418 .81563 L .23994 .81863 L closepath p F P
0 g
s
.74 .954 .944 r
.59527 .67599 m .59536 .67589 L .59541 .67591 L closepath p F P
0 g
s
.675 .941 .964 r
.59536 .67589 m .59541 .67591 L .60692 .67026 L p F P
0 g
s
.734 .986 .897 r
.59256 .67583 m .60025 .67045 L .59536 .67589 L closepath p F P
0 g
s
.675 .941 .964 r
.60405 .66825 m .60025 .67045 L .59536 .67589 L p F P
0 g
s
.675 .941 .964 r
.60692 .67026 m .60405 .66825 L p .59536 .67589 L F P
0 g
s
.907 .695 .604 r
.23128 .72915 m .23556 .73201 L .23405 .73782 L p F P
0 g
s
.91 .685 .584 r
.23556 .73201 m .23128 .72915 L .23249 .72345 L p F P
0 g
s
.583 .573 .807 r
.6057 .90358 m .6087 .90991 L .59708 .91127 L p F P
0 g
s
.583 .573 .807 r
.60482 .90367 m .6057 .90358 L p .59708 .91127 L F P
0 g
s
.583 .573 .807 r
.59708 .91127 m .59547 .90778 L .60482 .90367 L p F P
0 g
s
.542 .454 .706 r
.55318 .82018 m .56166 .81614 L p .55709 .82678 L F P
0 g
s
.542 .454 .706 r
.55709 .82678 m .5549 .8266 L .55318 .82018 L p F P
0 g
s
.463 .497 .809 r
.73612 .74797 m .73579 .74722 L .73658 .74742 L closepath p F P
0 g
s
.456 .484 .799 r
.73612 .74797 m .73658 .74742 L p .74208 .75526 L F P
0 g
s
.323 .187 .536 r
.56516 .7225 m .56709 .72098 L .56583 .71588 L p F P
0 g
s
.311 .18 .536 r
.57303 .70995 m .56583 .71588 L .56709 .72098 L p F P
0 g
s
.269 .116 .48 r
.56583 .71588 m .57303 .70995 L .57291 .7045 L p F P
0 g
s
.815 .718 .758 r
.22204 .87408 m .2278 .8763 L .22152 .88363 L p F P
0 g
s
.803 .705 .757 r
.22818 .86684 m .22204 .87408 L .2278 .8763 L p F P
0 g
s
.236 .055 .42 r
.76053 .87422 m .75781 .87627 L .75657 .88235 L p F P
0 g
s
.877 .697 .654 r
.24088 .76628 m .24179 .76395 L .23869 .76218 L closepath p F P
0 g
s
.881 .692 .643 r
.23758 .75994 m .23928 .75523 L p .24179 .76395 L F P
0 g
s
.881 .692 .643 r
.24179 .76395 m .23869 .76218 L .23758 .75994 L p F P
0 g
s
.426 .426 .756 r
.75998 .78264 m .75428 .77997 L .75779 .77629 L closepath p F P
0 g
s
.436 .44 .765 r
.75696 .77403 m .75779 .77629 L .75428 .77997 L p F P
0 g
s
.436 .44 .765 r
.75093 .77153 m .75696 .77403 L p .75428 .77997 L F P
0 g
s
.341 .248 .603 r
.76678 .84607 m .76578 .84414 L .76639 .84364 L closepath p F P
0 g
s
.47 .504 .811 r
.73288 .74047 m .73016 .73984 L .73179 .73795 L closepath p F P
0 g
s
.478 .515 .818 r
.72998 .73391 m .73179 .73795 L .73016 .73984 L p F P
0 g
s
.846 .695 .695 r
.24379 .81204 m .2418 .81563 L .23848 .80973 L p F P
0 g
s
.846 .695 .695 r
.23848 .80973 m .23856 .80959 L .24379 .81204 L p F P
0 g
s
.847 .693 .691 r
.24379 .81204 m .23856 .80959 L .24197 .80313 L p F P
0 g
s
.929 .601 .395 r
.04274 .88423 m .04307 .88721 L .03912 .88525 L p F P
0 g
s
.929 .601 .395 r
.03912 .88525 m .0387 .88146 L .04274 .88423 L p F P
0 g
s
.932 .638 .461 r
.04274 .88423 m .0387 .88146 L .03864 .876 L p F P
0 g
s
.902 .512 .27 r
.05335 .90001 m .04913 .89731 L .04758 .89225 L p F P
0 g
s
.904 .513 .262 r
.04344 .88952 m .04758 .89225 L .04913 .89731 L p F P
0 g
s
.921 .579 .372 r
.04307 .88721 m .04344 .88952 L .04758 .89225 L p F P
0 g
s
.462 .498 .81 r
.73658 .74742 m .73579 .74722 L .73288 .74047 L p F P
0 g
s
.58 .537 .771 r
.57357 .88421 m .57498 .88361 L p .58178 .89112 L F P
0 g
s
.576 .533 .771 r
.57357 .88421 m .57338 .88373 L .57498 .88361 L closepath p F P
0 g
s
.577 .685 .914 r
.64462 .67345 m .63882 .67424 L .63594 .67024 L p F P
0 g
s
.576 .525 .761 r
.57498 .88361 m .57338 .88373 L .57038 .87559 L p F P
0 g
s
.857 .696 .682 r
.2382 .78532 m .24333 .78783 L .24011 .79422 L p F P
0 g
s
.854 .691 .679 r
.24333 .78783 m .2382 .78532 L .24126 .77898 L p F P
0 g
s
.375 .327 .676 r
.76997 .81572 m .76547 .81992 L .77007 .82437 L p F P
0 g
s
.392 .353 .696 r
.76938 .8135 m .76572 .81052 L p .76547 .81992 L F P
0 g
s
.392 .353 .696 r
.76547 .81992 m .76997 .81572 L .76938 .8135 L p F P
0 g
s
.488 .542 .839 r
.71876 .72041 m .7121 .71945 L .70943 .71396 L p F P
0 g
s
.597 .66 .882 r
.64387 .92769 m .63219 .92968 L .62926 .92498 L p F P
0 g
s
.156 0 .373 r
.57437 .69847 m .57322 .69952 L .57291 .7045 L p F P
0 g
s
.487 .388 .668 r
.55439 .7794 m .55394 .77729 L .55633 .77831 L closepath p F P
0 g
s
.776 .76 .839 r
.17702 .92395 m .17455 .92577 L .17098 .92228 L p F P
0 g
s
.749 .761 .862 r
.15986 .92926 m .17098 .92228 L .17455 .92577 L p F P
0 g
s
.934 .669 .511 r
.03864 .876 m .03467 .87318 L .03511 .86759 L p F P
0 g
s
.936 .641 .458 r
.03467 .87318 m .03864 .876 L .0387 .88146 L p F P
0 g
s
.788 .725 .793 r
.21047 .90007 m .20848 .8975 L .20705 .89883 L closepath p F P
0 g
s
.476 .37 .655 r
.56104 .76036 m .55539 .76364 L .56216 .76724 L p F P
0 g
s
.475 .36 .642 r
.5598 .75369 m .56104 .76036 L .55539 .76364 L p F P
0 g
s
.728 .777 .892 r
.14524 .93178 m .14902 .92978 L .15412 .93213 L p F P
0 g
s
.717 .768 .893 r
.15625 .926 m .14902 .92978 L .15412 .93213 L p F P
0 g
s
.717 .768 .893 r
.15412 .93213 m .15986 .92926 L .15625 .926 L p F P
0 g
s
.859 .412 .127 r
.06003 .90751 m .05576 .90484 L .05335 .90001 L p F P
0 g
s
.859 .409 .114 r
.04913 .89731 m .05335 .90001 L .05576 .90484 L p F P
0 g
s
.626 .895 .987 r
.69027 .93137 m .69811 .92857 L .69176 .93209 L closepath p F P
0 g
s
.651 .915 .979 r
.70198 .92714 m .69811 .92857 L .69176 .93209 L p F P
0 g
s
.651 .915 .979 r
.70462 .92779 m .70198 .92714 L p .69176 .93209 L F P
0 g
s
.918 .693 .582 r
.22837 .72052 m .23249 .72345 L .23128 .72915 L p F P
0 g
s
.922 .679 .553 r
.23249 .72345 m .22837 .72052 L .22921 .71494 L p F P
0 g
s
.509 .574 .856 r
.69149 .70139 m .703 .70216 L .69916 .7072 L p F P
0 g
s
.509 .577 .859 r
.703 .70216 m .69149 .70139 L .68974 .6981 L p F P
0 g
s
.541 .46 .713 r
.5552 .82767 m .5549 .8266 L .55709 .82678 L closepath p F P
0 g
s
.434 .442 .769 r
.75696 .77403 m .75093 .77153 L .75461 .76756 L closepath p F P
0 g
s
.443 .455 .777 r
.75397 .7659 m .75461 .76756 L .75093 .77153 L p F P
0 g
s
.443 .455 .777 r
.74686 .7633 m .75397 .7659 L p .75093 .77153 L F P
0 g
s
.836 .7 .713 r
.23574 .82533 m .24126 .82768 L .23693 .83442 L p F P
0 g
s
.826 .69 .714 r
.23994 .81863 m .23574 .82533 L .24126 .82768 L p F P
0 g
s
.542 .463 .716 r
.55737 .83531 m .5552 .82767 L .55709 .82678 L p F P
0 g
s
.456 .484 .799 r
.73658 .74742 m .74638 .75026 L .74208 .75526 L p F P
0 g
s
.456 .489 .804 r
.74065 .74246 m .73658 .74742 L .74638 .75026 L p F P
0 g
s
.462 .498 .81 r
.73288 .74047 m .74065 .74246 L .73658 .74742 L p F P
0 g
s
.776 .76 .839 r
.17098 .92228 m .17185 .92162 L .17702 .92395 L p F P
0 g
s
.765 .75 .839 r
.18222 .91389 m .17185 .92162 L .17702 .92395 L p F P
0 g
s
.765 .75 .839 r
.17702 .92395 m .18575 .91766 L .18222 .91389 L p F P
0 g
s
.824 .709 .738 r
.2279 .85747 m .2335 .85975 L .22822 .86679 L p F P
0 g
s
.821 .704 .736 r
.2335 .85975 m .2279 .85747 L .23305 .85047 L p F P
0 g
s
.589 .614 .844 r
.62632 .91993 m .61466 .92152 L .61169 .9159 L p F P
0 g
s
.291 .164 .53 r
.76821 .85606 m .76374 .8597 L .76465 .8652 L p F P
0 g
s
.321 .211 .57 r
.76374 .8597 m .76821 .85606 L .76742 .84998 L p F P
0 g
s
.325 .237 .6 r
.76639 .84364 m .77159 .83901 L p .76833 .84919 L F P
0 g
s
.325 .237 .6 r
.76833 .84919 m .76678 .84607 L .76639 .84364 L p F P
0 g
s
.344 .271 .629 r
.76639 .84364 m .77159 .83901 L .76835 .83416 L p F P
0 g
s
.504 .565 .851 r
.69916 .7072 m .70634 .70786 L .70346 .7022 L p F P
0 g
s
.504 .565 .851 r
.70346 .7022 m .703 .70216 L .69916 .7072 L p F P
0 g
s
.491 .396 .675 r
.55633 .77831 m .55439 .7794 L .55594 .78641 L p F P
0 g
s
.583 .572 .807 r
.59547 .90778 m .59407 .90473 L .60482 .90367 L closepath p F P
0 g
s
.441 .458 .781 r
.75397 .7659 m .74686 .7633 L .75115 .75851 L closepath p F P
0 g
s
.45 .47 .788 r
.751 .75815 m .75115 .75851 L .74686 .7633 L p F P
0 g
s
.45 .47 .788 r
.74208 .75526 m .751 .75815 L p .74686 .7633 L F P
0 g
s
.446 .471 .791 r
.74208 .75526 m .751 .75815 L .74806 .75081 L p F P
0 g
s
.446 .471 .791 r
.74806 .75081 m .74638 .75026 L .74208 .75526 L p F P
0 g
s
.831 .702 .722 r
.23656 .84575 m .23803 .84353 L .23417 .84185 L closepath p F P
0 g
s
.832 .7 .718 r
.2332 .84024 m .23693 .83442 L p .23803 .84353 L F P
0 g
s
.832 .7 .718 r
.23803 .84353 m .23417 .84185 L .2332 .84024 L p F P
0 g
s
.938 .673 .509 r
.03121 .86474 m .03511 .86759 L .03467 .87318 L p F P
0 g
s
.934 .694 .552 r
.03511 .86759 m .03121 .86474 L .03211 .85902 L p F P
0 g
s
.886 .699 .644 r
.23928 .75523 m .23758 .75994 L .23426 .75382 L p F P
0 g
s
.886 .699 .644 r
.23426 .75382 m .23474 .75249 L .23928 .75523 L p F P
0 g
s
.889 .694 .633 r
.23928 .75523 m .23474 .75249 L .2367 .74652 L p F P
0 g
s
.813 .72 .761 r
.21998 .88543 m .22152 .88363 L .21744 .88193 L closepath p F P
0 g
s
.815 .718 .758 r
.21656 .8807 m .22204 .87408 L p .22152 .88363 L F P
0 g
s
.815 .718 .758 r
.22152 .88363 m .21744 .88193 L .21656 .8807 L p F P
0 g
s
.576 .525 .761 r
.57038 .87559 m .57081 .87541 L p .57498 .88361 L F P
0 g
s
.57 .522 .761 r
.57038 .87559 m .57032 .87543 L .57081 .87541 L closepath p F P
0 g
s
.529 .435 .693 r
.56023 .80437 m .55381 .80336 L .55932 .80071 L closepath p F P
0 g
s
.527 .426 .684 r
.55756 .79349 m .55932 .80071 L .55381 .80336 L p F P
0 g
s
.58 .537 .771 r
.57498 .88361 m .58497 .88284 L p .58178 .89112 L F P
0 g
s
.577 .531 .767 r
.58497 .88284 m .57498 .88361 L .58387 .87994 L closepath p F P
0 g
s
.576 .525 .761 r
.58191 .87476 m .58387 .87994 L .57498 .88361 L p F P
0 g
s
.576 .525 .761 r
.57081 .87541 m .58191 .87476 L p .57498 .88361 L F P
0 g
s
.865 .695 .669 r
.23916 .77014 m .24088 .76628 L .23869 .76218 L p F P
0 g
s
.571 .514 .752 r
.57081 .87541 m .57032 .87543 L .56743 .8672 L p F P
0 g
s
.415 .301 .614 r
.55871 .74717 m .56717 .7414 L .56338 .73699 L p F P
0 g
s
.441 .329 .63 r
.55871 .74717 m .56717 .7414 L p .56175 .7524 L F P
0 g
s
.441 .329 .63 r
.56175 .7524 m .5592 .75017 L .55871 .74717 L p F P
0 g
s
0 .331 .73 r
.08283 .92369 m .08433 .92442 L .08051 .9221 L p F P
0 g
s
0 .331 .73 r
.08051 .9221 m .07837 .92111 L .08283 .92369 L p F P
0 g
s
.93 .688 .55 r
.22526 .71195 m .22921 .71494 L .22837 .72052 L p F P
0 g
s
.934 .667 .506 r
.22921 .71494 m .22526 .71195 L .22563 .70652 L p F P
0 g
s
.546 .467 .717 r
.558 .83748 m .55737 .83531 L .56743 .83071 L p F P
0 g
s
.542 .463 .716 r
.56647 .82745 m .56743 .83071 L .55737 .83531 L p F P
0 g
s
.542 .463 .716 r
.55709 .82678 m .56647 .82745 L p .55737 .83531 L F P
0 g
s
.436 .737 .99 r
.10341 .93111 m .09832 .92874 L .10209 .93117 L closepath p F P
0 g
s
.798 .717 .775 r
.21445 .89118 m .21998 .88543 L .21744 .88193 L p F P
0 g
s
.832 .694 .71 r
.23994 .81863 m .2418 .81563 L .23848 .80973 L p F P
0 g
s
.572 .52 .758 r
.58191 .87476 m .57081 .87541 L .58065 .87128 L closepath p F P
0 g
s
.571 .514 .752 r
.57884 .86625 m .58065 .87128 L .57081 .87541 L p F P
0 g
s
.571 .514 .752 r
.56872 .86664 m .57884 .86625 L p .57081 .87541 L F P
0 g
s
.571 .514 .752 r
.56743 .8672 m .56872 .86664 L p .57081 .87541 L F P
0 g
s
.77 .261 0 r
.06003 .90751 m .06308 .91164 L .05935 .9095 L p F P
0 g
s
.77 .261 0 r
.05576 .90484 m .06003 .90751 L p .05935 .9095 L F P
0 g
s
.529 .604 .873 r
.67725 .69075 m .68574 .69088 L .68287 .68574 L p F P
0 g
s
.529 .604 .873 r
.68287 .68574 m .68084 .68573 L .67725 .69075 L p F P
0 g
s
.53 .611 .878 r
.67099 .68584 m .68084 .68573 L .67725 .69075 L p F P
0 g
s
.852 .699 .691 r
.23683 .80063 m .24197 .80313 L .23856 .80959 L p F P
0 g
s
.852 .695 .686 r
.24197 .80313 m .23683 .80063 L .24011 .79422 L p F P
0 g
s
.549 .475 .725 r
.55968 .84308 m .558 .83748 L .56958 .83798 L p F P
0 g
s
.546 .467 .717 r
.56743 .83071 m .56958 .83798 L .558 .83748 L p F P
0 g
s
.627 .071 0 r
.06796 .91465 m .06696 .91374 L .06308 .91164 L p F P
0 g
s
.862 .699 .678 r
.23626 .77642 m .24126 .77898 L .2382 .78532 L p F P
0 g
s
.857 .692 .677 r
.23916 .77014 m .23626 .77642 L .24126 .77898 L p F P
0 g
s
.817 .699 .735 r
.23305 .85047 m .23656 .84575 L .23417 .84185 L p F P
0 g
s
.565 .51 .752 r
.56743 .8672 m .56725 .86669 L .56872 .86664 L closepath p F P
0 g
s
.565 .502 .743 r
.56872 .86664 m .56725 .86669 L .56469 .85901 L p F P
0 g
s
.555 .48 .726 r
.55968 .84308 m .56974 .8385 L p .56901 .84787 L F P
0 g
s
.555 .48 .726 r
.56901 .84787 m .56109 .84774 L .55968 .84308 L p F P
0 g
s
.549 .475 .725 r
.56958 .83798 m .56974 .8385 L .55968 .84308 L p F P
0 g
s
.433 .868 .776 r
.70462 .92779 m .71626 .92224 L .71673 .92212 L p F P
0 g
s
.515 .914 .894 r
.71626 .92224 m .70462 .92779 L .70198 .92714 L p F P
0 g
s
.806 .723 .772 r
.21445 .89118 m .20848 .8975 L .20502 .89311 L p F P
0 g
s
.806 .723 .772 r
.20502 .89311 m .20886 .88893 L .21445 .89118 L p F P
0 g
s
.798 .717 .775 r
.21593 .88137 m .20886 .88893 L .21445 .89118 L p F P
0 g
s
.798 .717 .775 r
.21744 .88193 m .21593 .88137 L p .21445 .89118 L F P
0 g
s
.942 .675 .502 r
.22185 .70347 m .22563 .70652 L .22526 .71195 L p F P
0 g
s
.944 .639 .43 r
.22563 .70652 m .22185 .70347 L .22163 .69824 L p F P
0 g
s
.326 .238 .6 r
.76742 .84998 m .76678 .84607 L .76833 .84919 L closepath p F P
0 g
s
.146 0 .378 r
.58036 .69268 m .57437 .69847 L .57316 .70428 L p F P
0 g
s
.027 0 .235 r
.58125 .69044 m .58188 .68775 L p .57437 .69847 L F P
0 g
s
.027 0 .235 r
.57437 .69847 m .58036 .69268 L .58125 .69044 L p F P
0 g
s
.156 0 .373 r
.57291 .7045 m .57316 .70428 L .57437 .69847 L p F P
0 g
s
.583 .563 .797 r
.60482 .90367 m .59407 .90473 L .59115 .89807 L p F P
0 g
s
.554 .487 .734 r
.56211 .85097 m .56109 .84774 L .56901 .84787 L closepath p F P
0 g
s
.565 .502 .743 r
.56469 .85901 m .56825 .85743 L p .56872 .86664 L F P
0 g
s
.56 .498 .743 r
.56469 .85901 m .56418 .85747 L .56825 .85743 L closepath p F P
0 g
s
.582 .542 .776 r
.58801 .89053 m .58178 .89112 L .58735 .88886 L closepath p F P
0 g
s
.58 .537 .771 r
.58497 .88284 m .58735 .88886 L .58178 .89112 L p F P
0 g
s
.56 .491 .734 r
.56211 .85097 m .56901 .84787 L p .56825 .85743 L F P
0 g
s
.56 .491 .734 r
.56825 .85743 m .56418 .85747 L .56211 .85097 L p F P
0 g
s
.791 .749 .815 r
.18879 .91509 m .18575 .91766 L .18222 .91389 L p F P
0 g
s
.349 .228 .571 r
.56709 .72098 m .56516 .7225 L .5658 .72852 L p F P
0 g
s
.896 .701 .631 r
.2323 .74372 m .2367 .74652 L .23474 .75249 L p F P
0 g
s
.898 .695 .62 r
.2367 .74652 m .2323 .74372 L .23405 .73782 L p F P
0 g
s
.543 .462 .713 r
.56647 .82745 m .55709 .82678 L .56523 .82304 L closepath p F P
0 g
s
.542 .454 .706 r
.56336 .81632 m .56523 .82304 L .55709 .82678 L p F P
0 g
s
.542 .454 .706 r
.56166 .81614 m .56336 .81632 L p .55709 .82678 L F P
0 g
s
.791 .749 .815 r
.18222 .91389 m .18351 .91278 L .18879 .91509 L p F P
0 g
s
.78 .739 .815 r
.19323 .90447 m .18351 .91278 L .18879 .91509 L p F P
0 g
s
.78 .739 .815 r
.19409 .9048 m .19323 .90447 L p .18879 .91509 L F P
0 g
s
.78 .739 .815 r
.18879 .91509 m .19707 .90824 L .19409 .9048 L p F P
0 g
s
.46 .498 .811 r
.74065 .74246 m .73288 .74047 L .73179 .73795 L p F P
0 g
s
.435 .329 .635 r
.5598 .75369 m .5592 .75017 L .56175 .7524 L closepath p F P
0 g
s
.456 .743 .99 r
.10341 .93111 m .11258 .9304 L p .09831 .92873 L F P
0 g
s
.456 .743 .99 r
.09831 .92873 m .09832 .92874 L .10341 .93111 L p F P
0 g
s
.753 .759 .857 r
.17098 .92228 m .15986 .92926 L .15625 .926 L p F P
0 g
s
.951 .646 .422 r
.218 .69511 m .22163 .69824 L .22185 .70347 L p F P
0 g
s
.937 .575 .294 r
.22163 .69824 m .218 .69511 L .217 .69014 L p F P
0 g
s
.608 .726 .928 r
.64676 .9318 m .65846 .92948 L .66131 .93291 L p F P
0 g
s
.604 .684 .898 r
.6556 .92565 m .65846 .92948 L .64676 .9318 L p F P
0 g
s
.604 .684 .898 r
.65377 .92597 m .6556 .92565 L p .64676 .9318 L F P
0 g
s
.604 .684 .898 r
.64676 .9318 m .64561 .93016 L .65377 .92597 L p F P
0 g
s
.839 .701 .71 r
.2345 .81624 m .23994 .81863 L .23574 .82533 L p F P
0 g
s
.832 .694 .71 r
.23848 .80973 m .2345 .81624 L .23994 .81863 L p F P
0 g
s
.822 .711 .742 r
.22818 .86684 m .22822 .86679 L .22812 .86674 L closepath p F P
0 g
s
.824 .709 .738 r
.2248 .8617 m .2279 .85747 L p .22822 .86679 L F P
0 g
s
.824 .709 .738 r
.22822 .86679 m .22812 .86674 L .2248 .8617 L p F P
0 g
s
.808 .708 .755 r
.22204 .87408 m .22818 .86684 L .22812 .86674 L p F P
0 g
s
.808 .708 .755 r
.22812 .86674 m .22244 .86456 L p .22204 .87408 L F P
0 g
s
.81 .707 .751 r
.22812 .86674 m .2248 .8617 L .22244 .86456 L closepath p F P
0 g
s
.387 .35 .696 r
.76938 .8135 m .76572 .81052 L .76799 .80835 L closepath p F P
0 g
s
.401 .372 .712 r
.76616 .80199 m .76522 .80132 L p .76572 .81052 L F P
0 g
s
.401 .372 .712 r
.76572 .81052 m .76799 .80835 L .76616 .80199 L p F P
0 g
s
.509 .577 .859 r
.68974 .6981 m .69109 .69617 L p .703 .70216 L F P
0 g
s
.514 .587 .865 r
.68974 .6981 m .68862 .69605 L .69109 .69617 L closepath p F P
0 g
s
.789 .727 .794 r
.20705 .89883 m .20848 .8975 L .20502 .89311 L p F P
0 g
s
.801 .74 .796 r
.20135 .89661 m .20705 .89883 L .19861 .90677 L p F P
0 g
s
.789 .727 .794 r
.20502 .89311 m .20135 .89661 L .20705 .89883 L p F P
0 g
s
.503 .407 .679 r
.55594 .78641 m .56461 .78152 L p .55969 .79232 L F P
0 g
s
.503 .407 .679 r
.55969 .79232 m .55709 .7915 L .55594 .78641 L p F P
0 g
s
.491 .396 .675 r
.55594 .78641 m .56461 .78152 L .55633 .77831 L p F P
0 g
s
.103 0 .224 r
.75069 .89452 m .75404 .88877 L .75137 .89075 L closepath p F P
0 g
s
.18 0 .337 r
.75137 .89075 m .75404 .88877 L .75657 .88235 L p F P
0 g
s
.925 .581 .364 r
.04344 .88952 m .04307 .88721 L .03912 .88525 L p F P
0 g
s
.567 .509 .749 r
.57884 .86625 m .56872 .86664 L .57766 .86283 L closepath p F P
0 g
s
.565 .502 .743 r
.57576 .85731 m .57766 .86283 L .56872 .86664 L p F P
0 g
s
.565 .502 .743 r
.56825 .85743 m .57576 .85731 L p .56872 .86664 L F P
0 g
s
.491 .395 .674 r
.56385 .77407 m .55633 .77831 L .56461 .78152 L p F P
0 g
s
.491 .385 .662 r
.56241 .76736 m .56385 .77407 L .55633 .77831 L p F P
0 g
s
.491 .385 .662 r
.56216 .76724 m .56241 .76736 L p .55633 .77831 L F P
0 g
s
.799 .741 .799 r
.19707 .90824 m .19861 .90677 L .19409 .9048 L closepath p F P
0 g
s
.801 .74 .796 r
.19357 .90419 m .20135 .89661 L p .19861 .90677 L F P
0 g
s
.801 .74 .796 r
.19861 .90677 m .19409 .9048 L .19357 .90419 L p F P
0 g
s
.533 .616 .881 r
.68084 .68573 m .67099 .68584 L .66811 .68097 L p F P
0 g
s
.865 .695 .669 r
.23869 .76218 m .23702 .7613 L p .23916 .77014 L F P
0 g
s
.868 .689 .658 r
.23869 .76218 m .23758 .75994 L .23702 .7613 L closepath p F P
0 g
s
.836 .701 .715 r
.23693 .83442 m .2332 .84024 L .22984 .83479 L p F P
0 g
s
.836 .701 .715 r
.22984 .83479 m .23157 .83203 L .23693 .83442 L p F P
0 g
s
.836 .7 .713 r
.23693 .83442 m .23157 .83203 L .23574 .82533 L p F P
0 g
s
.125 .583 .921 r
.08433 .92442 m .09387 .92616 L .09831 .92873 L p F P
0 g
s
.167 .604 .937 r
.09387 .92616 m .08433 .92442 L .08051 .9221 L p F P
0 g
s
.488 .542 .839 r
.70943 .71396 m .70971 .71358 L p .71876 .72041 L F P
0 g
s
.493 .554 .846 r
.70943 .71396 m .70922 .71353 L .70971 .71358 L closepath p F P
0 g
s
.817 .699 .735 r
.23252 .8412 m .22747 .84817 L .23305 .85047 L p F P
0 g
s
.817 .699 .735 r
.23417 .84185 m .23252 .8412 L p .23305 .85047 L F P
0 g
s
.828 .71 .734 r
.22747 .84817 m .23305 .85047 L .2279 .85747 L p F P
0 g
s
.552 .642 .893 r
.65343 .67713 m .66523 .67624 L p .66409 .68118 L F P
0 g
s
.561 .646 .892 r
.66523 .67624 m .65343 .67713 L .65055 .67269 L p F P
0 g
s
.868 .701 .673 r
.23429 .76752 m .23916 .77014 L .23626 .77642 L p F P
0 g
s
.865 .695 .669 r
.23702 .7613 m .23429 .76752 L .23916 .77014 L p F P
0 g
s
.859 .702 .685 r
.23507 .79168 m .24011 .79422 L .23683 .80063 L p F P
0 g
s
.857 .696 .682 r
.24011 .79422 m .23507 .79168 L .2382 .78532 L p F P
0 g
s
.622 .714 .912 r
.62139 .66918 m .63305 .66639 L .63594 .67024 L p F P
0 g
s
.637 .732 .917 r
.63305 .66639 m .62139 .66918 L .61851 .66597 L p F P
0 g
s
.675 .775 .926 r
.60692 .67026 m .61851 .66597 L .62139 .66918 L p F P
0 g
s
.413 0 0 r
.07837 .92111 m .07397 .9185 L .06796 .91465 L p F P
0 g
s
.389 0 0 r
.06354 .91204 m .06796 .91465 L .07397 .9185 L p F P
0 g
s
.627 .071 0 r
.06308 .91164 m .06354 .91204 L .06796 .91465 L p F P
0 g
s
.46 .498 .811 r
.73179 .73795 m .73422 .73486 L p .74065 .74246 L F P
0 g
s
.466 .511 .821 r
.73179 .73795 m .72998 .73391 L .73422 .73486 L closepath p F P
0 g
s
.492 .556 .849 r
.70971 .71358 m .70922 .71353 L .70634 .70786 L p F P
0 g
s
.704 .807 .929 r
.61851 .66597 m .60692 .67026 L .60405 .66825 L p F P
0 g
s
.905 .703 .619 r
.22979 .73496 m .23405 .73782 L .2323 .74372 L p F P
0 g
s
.907 .695 .604 r
.23405 .73782 m .22979 .73496 L .23128 .72915 L p F P
0 g
s
.615 .773 .956 r
.11631 .93304 m .12702 .93029 L .13072 .93312 L p F P
0 g
s
.625 .774 .952 r
.12702 .93029 m .11631 .93304 L .11258 .9304 L p F P
0 g
s
.176 0 .334 r
.76047 .87943 m .75657 .88235 L .75404 .88877 L p F P
0 g
s
.236 .055 .42 r
.75657 .88235 m .76047 .87943 L .76053 .87422 L p F P
0 g
s
.342 .27 .63 r
.77325 .82973 m .76835 .83416 L .77159 .83901 L p F P
0 g
s
.363 .303 .656 r
.77277 .82754 m .77007 .82437 L p .76835 .83416 L F P
0 g
s
.363 .303 .656 r
.76835 .83416 m .77325 .82973 L .77277 .82754 L p F P
0 g
s
.577 .666 .899 r
.65055 .67269 m .64462 .67345 L .64806 .66895 L closepath p F P
0 g
s
.577 .685 .914 r
.64767 .66837 m .64806 .66895 L .64462 .67345 L p F P
0 g
s
.577 .685 .914 r
.63594 .67024 m .64767 .66837 L p .64462 .67345 L F P
0 g
s
.486 .547 .844 r
.70971 .71358 m .7213 .71524 L .71842 .70939 L p F P
0 g
s
.486 .547 .844 r
.71842 .70939 m .71322 .70867 L .70971 .71358 L p F P
0 g
s
.492 .556 .849 r
.70634 .70786 m .71322 .70867 L .70971 .71358 L p F P
0 g
s
.488 .542 .839 r
.70971 .71358 m .7213 .71524 L p .71876 .72041 L F P
0 g
s
.209 .034 .413 r
.7646 .87096 m .76053 .87422 L .76047 .87943 L p F P
0 g
s
.257 .108 .479 r
.76053 .87422 m .7646 .87096 L .76465 .8652 L p F P
0 g
s
0 0 0 r
.72787 .91545 m .73375 .91135 L .72917 .91437 L closepath p F P
0 g
s
0 0 0 r
.73939 .90685 m .73375 .91135 L .72917 .91437 L p F P
0 g
s
0 0 0 r
.74029 .90525 m .73939 .90685 L p .72917 .91437 L F P
0 g
s
.49 .877 .69 r
.72917 .91437 m .72787 .91545 L p .71673 .92212 L F P
0 g
s
.734 .78 .889 r
.14902 .92978 m .14524 .93178 L .14159 .92875 L p F P
0 g
s
.684 .776 .921 r
.13072 .93312 m .14159 .92875 L .14524 .93178 L p F P
0 g
s
.442 .342 .646 r
.56175 .7524 m .5598 .75369 L .56104 .76036 L p F P
0 g
s
.874 .698 .66 r
.23702 .7613 m .23758 .75994 L .23426 .75382 L p F P
0 g
s
.589 .614 .844 r
.61169 .9159 m .62336 .91449 L .62632 .91993 L p F P
0 g
s
.584 .591 .826 r
.62057 .9091 m .62336 .91449 L .61169 .9159 L p F P
0 g
s
.584 .591 .826 r
.61169 .9159 m .61061 .91373 L .62057 .9091 L p F P
0 g
s
.817 .715 .752 r
.22204 .87408 m .21656 .8807 L .21313 .87598 L p F P
0 g
s
.817 .715 .752 r
.21313 .87598 m .21652 .87179 L .22204 .87408 L p F P
0 g
s
.808 .708 .755 r
.22244 .86456 m .21652 .87179 L .22204 .87408 L p F P
0 g
s
.299 .196 .566 r
.76833 .84919 m .76742 .84998 L .76821 .85606 L p F P
0 g
s
.501 .411 .685 r
.55756 .79349 m .55709 .7915 L .55969 .79232 L closepath p F P
0 g
s
.613 .78 .961 r
.66131 .93291 m .67303 .93017 L .67582 .93288 L p F P
0 g
s
.609 .747 .943 r
.67303 .93017 m .66131 .93291 L .65846 .92948 L p F P
0 g
s
.607 .881 .991 r
.69811 .92857 m .69027 .93137 L .68755 .92952 L p F P
0 g
s
.611 .848 .988 r
.67582 .93288 m .68755 .92952 L .69027 .93137 L p F P
0 g
s
.597 .66 .882 r
.62926 .92498 m .64096 .9232 L .64387 .92769 L p F P
0 g
s
.592 .632 .859 r
.63803 .91837 m .64096 .9232 L .62926 .92498 L p F P
0 g
s
.592 .632 .859 r
.62867 .91963 m .63803 .91837 L p .62926 .92498 L F P
0 g
s
.592 .632 .859 r
.62926 .92498 m .6267 .92059 L .62867 .91963 L p F P
0 g
s
.513 .59 .869 r
.69109 .69617 m .68862 .69605 L .68574 .69088 L p F P
0 g
s
.82 .697 .73 r
.23417 .84185 m .2332 .84024 L .23252 .8412 L closepath p F P
0 g
s
.549 .628 .883 r
.66811 .68097 m .66409 .68118 L .66638 .67809 L closepath p F P
0 g
s
.552 .642 .893 r
.66523 .67624 m .66638 .67809 L .66409 .68118 L p F P
0 g
s
.583 .563 .797 r
.59115 .89807 m .59182 .89778 L p .60482 .90367 L F P
0 g
s
.578 .559 .797 r
.59115 .89807 m .59105 .89784 L .59182 .89778 L closepath p F P
0 g
s
.691 .777 .917 r
.14159 .92875 m .13072 .93312 L .12702 .93029 L p F P
0 g
s
.578 .549 .786 r
.59182 .89778 m .59105 .89784 L .58801 .89053 L p F P
0 g
s
.604 .683 .897 r
.64561 .93016 m .64387 .92769 L .65377 .92597 L closepath p F P
0 g
s
.502 .904 .792 r
.71626 .92224 m .71844 .92105 L .71673 .92212 L closepath p F P
0 g
s
.49 .877 .69 r
.72787 .91545 m .71844 .92105 L .71673 .92212 L p F P
0 g
s
.8 .716 .771 r
.21744 .88193 m .21656 .8807 L .21593 .88137 L closepath p F P
0 g
s
.85 .701 .697 r
.23848 .80973 m .23856 .80959 L .23833 .80947 L closepath p F P
0 g
s
.852 .699 .691 r
.23514 .80388 m .23683 .80063 L p .23856 .80959 L F P
0 g
s
.852 .699 .691 r
.23856 .80959 m .23833 .80947 L .23514 .80388 L p F P
0 g
s
.503 .416 .69 r
.55932 .80071 m .55756 .79349 L .55969 .79232 L p F P
0 g
s
.838 .699 .71 r
.2345 .81624 m .23848 .80973 L .23833 .80947 L p F P
0 g
s
.875 .704 .667 r
.23229 .75862 m .23702 .7613 L .23429 .76752 L p F P
0 g
s
.874 .698 .66 r
.23426 .75382 m .23229 .75862 L .23702 .7613 L p F P
0 g
s
.915 .703 .602 r
.22718 .72623 m .23128 .72915 L .22979 .73496 L p F P
0 g
s
.918 .693 .582 r
.23128 .72915 m .22718 .72623 L .22837 .72052 L p F P
0 g
s
.838 .699 .71 r
.23833 .80947 m .23322 .80716 L p .2345 .81624 L F P
0 g
s
.84 .696 .704 r
.23833 .80947 m .23514 .80388 L .23322 .80716 L closepath p F P
0 g
s
.614 .809 .975 r
.68755 .92952 m .67582 .93288 L .67303 .93017 L p F P
0 g
s
.864 .704 .681 r
.23328 .78273 m .2382 .78532 L .23507 .79168 L p F P
0 g
s
.862 .699 .678 r
.2382 .78532 m .23328 .78273 L .23626 .77642 L p F P
0 g
s
.598 .69 .907 r
.64767 .66837 m .63594 .67024 L .63305 .66639 L p F P
0 g
s
.583 .563 .797 r
.59182 .89778 m .60269 .89685 L p .60482 .90367 L F P
0 g
s
.579 .557 .793 r
.60269 .89685 m .59182 .89778 L .60131 .89364 L closepath p F P
0 g
s
.578 .549 .786 r
.59966 .88978 m .60131 .89364 L .59182 .89778 L p F P
0 g
s
.578 .549 .786 r
.58801 .89053 m .59966 .88978 L p .59182 .89778 L F P
0 g
s
.349 .228 .571 r
.5658 .72852 m .5692 .72585 L .56709 .72098 L p F P
0 g
s
.338 .223 .572 r
.57347 .71575 m .56709 .72098 L .5692 .72585 L p F P
0 g
s
.311 .18 .536 r
.56709 .72098 m .57347 .71575 L .57303 .70995 L p F P
0 g
s
.396 .37 .712 r
.76616 .80199 m .76522 .80132 L .7658 .80074 L closepath p F P
0 g
s
.41 .392 .728 r
.76522 .80132 m .7658 .80074 L .76338 .79287 L p F P
0 g
s
.466 .511 .821 r
.73422 .73486 m .72998 .73391 L .72708 .72747 L p F P
0 g
s
.412 .3 .616 r
.56662 .73474 m .56338 .73699 L .56717 .7414 L p F P
0 g
s
.401 .281 .599 r
.56338 .73699 m .56662 .73474 L .5658 .72852 L p F P
0 g
s
.583 .59 .825 r
.62038 .90874 m .62057 .9091 L .61061 .91373 L p F P
0 g
s
.583 .59 .825 r
.61061 .91373 m .6087 .90991 L .62038 .90874 L p F P
0 g
s
.843 .707 .713 r
.23045 .82291 m .23574 .82533 L .23157 .83203 L p F P
0 g
s
.839 .701 .71 r
.23574 .82533 m .23045 .82291 L .2345 .81624 L p F P
0 g
s
.828 .71 .735 r
.2279 .85747 m .2248 .8617 L .2214 .85667 L p F P
0 g
s
.828 .71 .735 r
.2214 .85667 m .22251 .85511 L .2279 .85747 L p F P
0 g
s
.828 .71 .734 r
.2279 .85747 m .22251 .85511 L .22747 .84817 L p F P
0 g
s
.734 .78 .889 r
.14159 .92875 m .14411 .92736 L .14902 .92978 L p F P
0 g
s
.724 .77 .889 r
.15263 .92273 m .14411 .92736 L .14902 .92978 L p F P
0 g
s
.724 .77 .889 r
.14902 .92978 m .15625 .926 L .15263 .92273 L p F P
0 g
s
.562 .498 .741 r
.57576 .85731 m .56825 .85743 L .57486 .85456 L closepath p F P
0 g
s
.56 .491 .734 r
.57268 .8479 m .57486 .85456 L .56825 .85743 L p F P
0 g
s
.56 .491 .734 r
.56901 .84787 m .57268 .8479 L p .56825 .85743 L F P
0 g
s
.822 .701 .732 r
.23252 .8412 m .2332 .84024 L .22984 .83479 L p F P
0 g
s
.753 .759 .857 r
.16883 .92019 m .17098 .92228 L p .15625 .926 L F P
0 g
s
.778 .764 .841 r
.17098 .92228 m .17185 .92162 L .16883 .92019 L closepath p F P
0 g
s
.904 .513 .262 r
.04913 .89731 m .04499 .89458 L .04344 .88952 L p F P
0 g
s
.906 .513 .254 r
.03937 .88676 m .04344 .88952 L .04499 .89458 L p F P
0 g
s
.925 .581 .364 r
.03912 .88525 m .03937 .88676 L .04344 .88952 L p F P
0 g
s
.933 .603 .39 r
.0387 .88146 m .03912 .88525 L .0352 .88292 L p F P
0 g
s
.933 .603 .39 r
.0352 .88292 m .03472 .87865 L .0387 .88146 L p F P
0 g
s
.936 .641 .458 r
.0387 .88146 m .03472 .87865 L .03467 .87318 L p F P
0 g
s
.78 .763 .838 r
.17934 .91085 m .18222 .91389 L .17185 .92162 L p F P
0 g
s
.78 .763 .838 r
.17829 .91043 m .17934 .91085 L p .17185 .92162 L F P
0 g
s
.78 .763 .838 r
.1674 .91878 m .17829 .91043 L p .17185 .92162 L F P
0 g
s
.78 .763 .838 r
.17185 .92162 m .16883 .92019 L .1674 .91878 L p F P
0 g
s
.801 .718 .773 r
.21593 .88137 m .21656 .8807 L .21313 .87598 L p F P
0 g
s
.83 .71 .732 r
.22696 .83887 m .23252 .8412 L .22747 .84817 L p F P
0 g
s
.822 .701 .732 r
.22984 .83479 m .22696 .83887 L .23252 .8412 L p F P
0 g
s
.812 .729 .773 r
.21025 .87913 m .21593 .88137 L .20886 .88893 L p F P
0 g
s
.801 .718 .773 r
.21313 .87598 m .21025 .87913 L .21593 .88137 L p F P
0 g
s
.325 .237 .6 r
.77159 .83901 m .77413 .84406 L .76833 .84919 L p F P
0 g
s
.299 .196 .566 r
.76821 .85606 m .77004 .85447 L .76833 .84919 L p F P
0 g
s
.298 .196 .567 r
.77413 .84406 m .76833 .84919 L .77004 .85447 L p F P
0 g
s
.231 .087 .47 r
.57316 .70428 m .57291 .7045 L .57303 .70995 L p F P
0 g
s
.393 .381 .727 r
.76388 .79233 m .76338 .79287 L .7658 .80074 L p F P
0 g
s
.407 .402 .742 r
.76338 .79287 m .76304 .79185 L .76388 .79233 L closepath p F P
0 g
s
.254 .106 .478 r
.76874 .86188 m .76465 .8652 L .7646 .87096 L p F P
0 g
s
.291 .164 .53 r
.76465 .8652 m .76874 .86188 L .76821 .85606 L p F P
0 g
s
.926 .702 .58 r
.22442 .71754 m .22837 .72052 L .22718 .72623 L p F P
0 g
s
.93 .688 .55 r
.22837 .72052 m .22442 .71754 L .22526 .71195 L p F P
0 g
s
.407 .403 .742 r
.76388 .79233 m .76304 .79185 L .7607 .78472 L p F P
0 g
s
.859 .409 .114 r
.05576 .90484 m .05156 .90214 L .04913 .89731 L p F P
0 g
s
.858 .406 .101 r
.04499 .89458 m .04913 .89731 L .05156 .90214 L p F P
0 g
s
.366 .256 .594 r
.5692 .72585 m .5658 .72852 L .56662 .73474 L p F P
0 g
s
.939 .645 .455 r
.03076 .87034 m .03467 .87318 L .03472 .87865 L p F P
0 g
s
.938 .673 .509 r
.03467 .87318 m .03076 .87034 L .03121 .86474 L p F P
0 g
s
.465 .886 .796 r
.71844 .92105 m .71626 .92224 L .71368 .92222 L p F P
0 g
s
.515 .914 .894 r
.70198 .92714 m .71368 .92222 L .71626 .92224 L p F P
0 g
s
.407 .403 .742 r
.7607 .78472 m .76178 .78354 L p .76388 .79233 L F P
0 g
s
.415 .419 .755 r
.7607 .78472 m .75998 .78264 L .76178 .78354 L closepath p F P
0 g
s
.481 .532 .833 r
.72419 .72133 m .71876 .72041 L .72186 .7164 L closepath p F P
0 g
s
.488 .542 .839 r
.7213 .71524 m .72186 .7164 L .71876 .72041 L p F P
0 g
s
0 0 0 r
.73939 .90685 m .74342 .90307 L .74029 .90525 L closepath p F P
0 g
s
0 0 .005 r
.74995 .8956 m .74342 .90307 L .74029 .90525 L p F P
0 g
s
.383 .361 .711 r
.7658 .80074 m .76999 .79633 L p .7708 .80548 L F P
0 g
s
.383 .361 .711 r
.7708 .80548 m .76616 .80199 L .7658 .80074 L p F P
0 g
s
.393 .381 .727 r
.7658 .80074 m .76999 .79633 L .76388 .79233 L p F P
0 g
s
.213 .074 .464 r
.57935 .69844 m .57316 .70428 L .57331 .7097 L p F P
0 g
s
.146 0 .378 r
.57316 .70428 m .57935 .69844 L .58036 .69268 L p F P
0 g
s
.231 .087 .47 r
.57303 .70995 m .57331 .7097 L .57316 .70428 L p F P
0 g
s
.514 .426 .693 r
.55932 .80071 m .56887 .79549 L p .56564 .80564 L F P
0 g
s
.514 .426 .693 r
.56564 .80564 m .56023 .80437 L .55932 .80071 L p F P
0 g
s
.503 .416 .69 r
.56873 .79495 m .56887 .79549 L .55932 .80071 L p F P
0 g
s
.503 .416 .69 r
.55969 .79232 m .56873 .79495 L p .55932 .80071 L F P
0 g
s
.892 .707 .645 r
.23426 .75382 m .23474 .75249 L .23269 .75118 L closepath p F P
0 g
s
.896 .701 .631 r
.23092 .74795 m .2323 .74372 L p .23474 .75249 L F P
0 g
s
.896 .701 .631 r
.23474 .75249 m .23269 .75118 L .23092 .74795 L p F P
0 g
s
.415 .419 .756 r
.76178 .78354 m .75998 .78264 L .75779 .77629 L p F P
0 g
s
.383 .361 .711 r
.76799 .80835 m .76616 .80199 L .7708 .80548 L closepath p F P
0 g
s
.509 .577 .859 r
.69109 .69617 m .70059 .69679 L p .703 .70216 L F P
0 g
s
.51 .582 .864 r
.69109 .69617 m .70059 .69679 L .69772 .69142 L p F P
0 g
s
.51 .582 .864 r
.69772 .69142 m .69445 .69123 L .69109 .69617 L p F P
0 g
s
.513 .59 .869 r
.68574 .69088 m .69445 .69123 L .69109 .69617 L p F P
0 g
s
.858 .704 .69 r
.23683 .80063 m .23514 .80388 L .23178 .79828 L p F P
0 g
s
.858 .704 .69 r
.23178 .79828 m .23189 .79807 L .23683 .80063 L p F P
0 g
s
.859 .702 .685 r
.23683 .80063 m .23189 .79807 L .23507 .79168 L p F P
0 g
s
.442 .342 .646 r
.56104 .76036 m .56703 .75641 L .56175 .7524 L p F P
0 g
s
.44 .342 .648 r
.56874 .74771 m .56175 .7524 L .56703 .75641 L p F P
0 g
s
.441 .329 .63 r
.56771 .74191 m .56874 .74771 L .56175 .7524 L p F P
0 g
s
.441 .329 .63 r
.56717 .7414 m .56771 .74191 L p .56175 .7524 L F P
0 g
s
.57 .536 .778 r
.59742 .88432 m .59966 .88978 L .58801 .89053 L p F P
0 g
s
.57 .536 .778 r
.58801 .89053 m .58735 .88886 L .59742 .88432 L p F P
0 g
s
.813 .711 .753 r
.22244 .86456 m .2248 .8617 L .2214 .85667 L p F P
0 g
s
.476 .37 .655 r
.56216 .76724 m .56236 .76712 L .56104 .76036 L p F P
0 g
s
.446 .35 .653 r
.56236 .76712 m .56104 .76036 L .56703 .75641 L p F P
0 g
s
.87 .706 .677 r
.23146 .77378 m .23626 .77642 L .23328 .78273 L p F P
0 g
s
.868 .701 .673 r
.23626 .77642 m .23146 .77378 L .23429 .76752 L p F P
0 g
s
0 .356 .756 r
.07837 .92111 m .08051 .9221 L .07668 .91971 L p F P
0 g
s
0 .356 .756 r
.07668 .91971 m .07397 .9185 L .07837 .92111 L p F P
0 g
s
.812 .728 .772 r
.20886 .88893 m .20502 .89311 L .20155 .88876 L p F P
0 g
s
.812 .728 .772 r
.20155 .88876 m .20348 .8866 L .20886 .88893 L p F P
0 g
s
.812 .729 .773 r
.20886 .88893 m .20348 .8866 L .21025 .87913 L p F P
0 g
s
.465 .886 .796 r
.72586 .91637 m .71844 .92105 L p .71368 .92222 L F P
0 g
s
.44 .854 .691 r
.71844 .92105 m .72586 .91637 L .72787 .91545 L closepath p F P
0 g
s
.568 .534 .777 r
.59661 .88234 m .59742 .88432 L .58735 .88886 L p F P
0 g
s
.568 .534 .777 r
.58735 .88886 m .58497 .88284 L .59661 .88234 L p F P
0 g
s
.415 .419 .756 r
.75779 .77629 m .75899 .77493 L p .76178 .78354 L F P
0 g
s
.423 .435 .768 r
.75779 .77629 m .75696 .77403 L .75899 .77493 L closepath p F P
0 g
s
.938 .696 .547 r
.22146 .7089 m .22526 .71195 L .22442 .71754 L p F P
0 g
s
.942 .675 .502 r
.22526 .71195 m .22146 .7089 L .22185 .70347 L p F P
0 g
s
.395 .386 .731 r
.76846 .78736 m .76388 .79233 L .76999 .79633 L p F P
0 g
s
.407 .403 .742 r
.76178 .78354 m .76846 .78736 L .76388 .79233 L p F P
0 g
s
.504 .416 .689 r
.56873 .79495 m .55969 .79232 L .56711 .78826 L closepath p F P
0 g
s
.503 .407 .679 r
.56558 .78186 m .56711 .78826 L .55969 .79232 L p F P
0 g
s
.503 .407 .679 r
.56461 .78152 m .56558 .78186 L p .55969 .79232 L F P
0 g
s
.492 .557 .85 r
.71322 .70867 m .70634 .70786 L .70346 .7022 L p F P
0 g
s
.001 0 .147 r
.75404 .88877 m .76005 .88427 L p .75054 .89518 L F P
0 g
s
.001 0 .147 r
.75054 .89518 m .75069 .89452 L .75404 .88877 L p F P
0 g
s
.176 0 .334 r
.75404 .88877 m .76005 .88427 L .76047 .87943 L p F P
0 g
s
.512 .43 .7 r
.56118 .80804 m .56023 .80437 L .56564 .80564 L closepath p F P
0 g
s
.77 .261 0 r
.05935 .9095 m .05919 .9094 L .05576 .90484 L p F P
0 g
s
.764 .253 0 r
.05156 .90214 m .05576 .90484 L .05919 .9094 L p F P
0 g
s
.373 .342 .695 r
.76799 .80835 m .7708 .80548 L p .77089 .81481 L F P
0 g
s
.373 .342 .695 r
.77089 .81481 m .76938 .8135 L .76799 .80835 L p F P
0 g
s
0 0 .121 r
.58125 .69044 m .58319 .6864 L .58188 .68775 L closepath p F P
0 g
s
0 0 0 r
.58188 .68775 m .58319 .6864 L .58876 .6793 L p F P
0 g
s
.881 .707 .661 r
.23229 .75862 m .23426 .75382 L .23269 .75118 L p F P
0 g
s
.782 .738 .813 r
.19409 .9048 m .19357 .90419 L .19323 .90447 L closepath p F P
0 g
s
.375 .327 .676 r
.77007 .82437 m .77172 .82284 L .76997 .81572 L p F P
0 g
s
.358 .3 .655 r
.77277 .82754 m .77007 .82437 L .77172 .82284 L closepath p F P
0 g
s
.793 .754 .817 r
.18222 .91389 m .18351 .91278 L .17934 .91085 L closepath p F P
0 g
s
.823 .721 .752 r
.21689 .86226 m .22244 .86456 L .21652 .87179 L p F P
0 g
s
.813 .711 .753 r
.2214 .85667 m .21689 .86226 L .22244 .86456 L p F P
0 g
s
.422 .435 .768 r
.75899 .77493 m .75696 .77403 L .75461 .76756 L p F P
0 g
s
.578 .583 .822 r
.62038 .90874 m .6087 .90991 L .6057 .90358 L p F P
0 g
s
.795 .753 .814 r
.18764 .90222 m .19323 .90447 L .18351 .91278 L p F P
0 g
s
.795 .753 .814 r
.17867 .91014 m .18764 .90222 L p .18351 .91278 L F P
0 g
s
.795 .753 .814 r
.18351 .91278 m .17934 .91085 L .17867 .91014 L p F P
0 g
s
.794 .73 .793 r
.20135 .89661 m .20502 .89311 L .20155 .88876 L p F P
0 g
s
.606 .664 .88 r
.65377 .92597 m .64387 .92769 L .64096 .9232 L p F P
0 g
s
.847 .708 .709 r
.22928 .81378 m .2345 .81624 L .23045 .82291 L p F P
0 g
s
.838 .699 .71 r
.23322 .80716 m .22928 .81378 L .2345 .81624 L p F P
0 g
s
.533 .616 .881 r
.66811 .68097 m .68 .68078 L p .68084 .68573 L F P
0 g
s
.533 .62 .885 r
.67712 .67593 m .68 .68078 L .66811 .68097 L p F P
0 g
s
.533 .62 .885 r
.66754 .67616 m .67712 .67593 L p .66811 .68097 L F P
0 g
s
.533 .62 .885 r
.66811 .68097 m .66638 .67809 L .66754 .67616 L p F P
0 g
s
.801 .733 .788 r
.20135 .89661 m .19357 .90419 L .19006 .90013 L p F P
0 g
s
.801 .733 .788 r
.19006 .90013 m .19586 .89433 L .20135 .89661 L p F P
0 g
s
.794 .73 .793 r
.20155 .88876 m .19586 .89433 L .20135 .89661 L p F P
0 g
s
.295 .663 .972 r
.09831 .92873 m .09831 .92873 L .09453 .92622 L p F P
0 g
s
.295 .663 .972 r
.09453 .92622 m .09387 .92616 L .09831 .92873 L p F P
0 g
s
.456 .743 .99 r
.11258 .9304 m .10883 .92773 L .09831 .92873 L p F P
0 g
s
.516 .75 .98 r
.10883 .92773 m .09831 .92873 L .09453 .92622 L p F P
0 g
s
.537 .451 .705 r
.56336 .81632 m .56166 .81614 L .56312 .81546 L closepath p F P
0 g
s
.536 .443 .697 r
.56118 .80804 m .56312 .81546 L .56166 .81614 L p F P
0 g
s
.902 .709 .633 r
.2323 .74372 m .23092 .74795 L .22754 .74245 L p F P
0 g
s
.902 .709 .633 r
.22754 .74245 m .22806 .74086 L .2323 .74372 L p F P
0 g
s
.905 .703 .619 r
.2323 .74372 m .22806 .74086 L .22979 .73496 L p F P
0 g
s
.513 .433 .702 r
.56312 .81546 m .56118 .80804 L .56564 .80564 L p F P
0 g
s
.592 .631 .859 r
.6267 .92059 m .62632 .91993 L .62867 .91963 L closepath p F P
0 g
s
.95 .683 .497 r
.21821 .70035 m .22185 .70347 L .22146 .7089 L p F P
0 g
s
.951 .646 .422 r
.22185 .70347 m .21821 .70035 L .218 .69511 L p F P
0 g
s
.782 .739 .814 r
.19006 .90013 m .18764 .90222 L .19323 .90447 L p F P
0 g
s
.782 .739 .814 r
.19323 .90447 m .19357 .90419 L .19006 .90013 L p F P
0 g
s
.834 .715 .734 r
.2221 .84579 m .22747 .84817 L .22251 .85511 L p F P
0 g
s
.83 .71 .732 r
.22747 .84817 m .2221 .84579 L .22696 .83887 L p F P
0 g
s
.546 .91 .724 r
.59109 .67649 m .59256 .67583 L .60025 .67045 L p F P
0 g
s
.607 .881 .991 r
.7012 .92678 m .69811 .92857 L p .68755 .92952 L F P
0 g
s
.629 .901 .985 r
.69811 .92857 m .7012 .92678 L .70198 .92714 L closepath p F P
0 g
s
.561 .646 .892 r
.65055 .67269 m .66236 .67168 L .66523 .67624 L p F P
0 g
s
.56 .658 .902 r
.65948 .6672 m .66236 .67168 L .65055 .67269 L p F P
0 g
s
.56 .658 .902 r
.64843 .66829 m .65948 .6672 L p .65055 .67269 L F P
0 g
s
.56 .658 .902 r
.65055 .67269 m .64806 .66895 L .64843 .66829 L p F P
0 g
s
.759 .762 .855 r
.16659 .91929 m .15625 .926 L .15263 .92273 L p F P
0 g
s
.753 .759 .857 r
.15625 .926 m .16659 .91929 L .16883 .92019 L p F P
0 g
s
.841 .709 .717 r
.22984 .83479 m .23157 .83203 L .22654 .82964 L closepath p F P
0 g
s
.843 .707 .713 r
.22645 .8295 m .23045 .82291 L p .23157 .83203 L F P
0 g
s
.843 .707 .713 r
.23157 .83203 m .22654 .82964 L .22645 .8295 L p F P
0 g
s
.466 .511 .821 r
.72708 .72747 m .72708 .72746 L p .73422 .73486 L F P
0 g
s
.472 .524 .83 r
.72708 .72747 m .72708 .72746 L .72708 .72746 L closepath p F P
0 g
s
.374 .342 .694 r
.76997 .81572 m .76938 .8135 L .77089 .81481 L closepath p F P
0 g
s
.47 .526 .832 r
.72708 .72746 m .72708 .72746 L .72419 .72133 L p F P
0 g
s
.466 .511 .821 r
.72708 .72746 m .73804 .72992 L .73422 .73486 L p F P
0 g
s
.467 .517 .826 r
.73063 .72258 m .72708 .72746 L .73804 .72992 L p F P
0 g
s
.47 .526 .832 r
.72419 .72133 m .73063 .72258 L .72708 .72746 L p F P
0 g
s
.844 .703 .706 r
.23322 .80716 m .23514 .80388 L .23178 .79828 L p F P
0 g
s
.601 .043 0 r
.06354 .91204 m .05935 .9095 L .06308 .91164 L closepath p F P
0 g
s
.267 .147 .524 r
.77004 .85447 m .76821 .85606 L .76874 .86188 L p F P
0 g
s
.563 .523 .769 r
.59387 .87531 m .59661 .88234 L .58497 .88284 L p F P
0 g
s
.563 .523 .769 r
.58497 .88284 m .58387 .87994 L .59387 .87531 L p F P
0 g
s
.422 .435 .768 r
.75461 .76756 m .75551 .76651 L p .75899 .77493 L F P
0 g
s
.43 .451 .78 r
.75461 .76756 m .75397 .7659 L .75551 .76651 L closepath p F P
0 g
s
.865 .707 .685 r
.23023 .78908 m .23507 .79168 L .23189 .79807 L p F P
0 g
s
.864 .704 .681 r
.23507 .79168 m .23023 .78908 L .23328 .78273 L p F P
0 g
s
.593 .616 .844 r
.62867 .91963 m .62632 .91993 L .62336 .91449 L p F P
0 g
s
.876 .709 .672 r
.22961 .76483 m .23429 .76752 L .23146 .77378 L p F P
0 g
s
.875 .704 .667 r
.23429 .76752 m .22961 .76483 L .23229 .75862 L p F P
0 g
s
.515 .593 .871 r
.69445 .69123 m .68574 .69088 L .68287 .68574 L p F P
0 g
s
.356 .314 .674 r
.77089 .81481 m .76997 .81572 L .77172 .82284 L p F P
0 g
s
.404 .404 .746 r
.76622 .77858 m .76178 .78354 L .76846 .78736 L p F P
0 g
s
.415 .419 .756 r
.75899 .77493 m .76622 .77858 L .76178 .78354 L p F P
0 g
s
.555 .48 .726 r
.56974 .8385 m .57222 .84646 L .56901 .84787 L p F P
0 g
s
.556 .487 .733 r
.57268 .8479 m .56901 .84787 L .57222 .84646 L closepath p F P
0 g
s
.43 .451 .78 r
.75551 .76651 m .75397 .7659 L .75115 .75851 L p F P
0 g
s
.751 .76 .86 r
.16883 .92019 m .1674 .91878 L .16659 .91929 L closepath p F P
0 g
s
.562 .522 .768 r
.59356 .87452 m .59387 .87531 L .58387 .87994 L p F P
0 g
s
.562 .522 .768 r
.58387 .87994 m .58191 .87476 L .59356 .87452 L p F P
0 g
s
.881 .707 .661 r
.23269 .75118 m .23025 .74972 L p .23229 .75862 L F P
0 g
s
.884 .7 .649 r
.23269 .75118 m .23092 .74795 L .23025 .74972 L closepath p F P
0 g
s
.389 0 0 r
.07397 .9185 m .06963 .91587 L .06354 .91204 L p F P
0 g
s
0 .191 .607 r
.05935 .9095 m .06354 .91204 L .06816 .91495 L p F P
0 g
s
.662 .117 0 r
.0592 .90941 m .05919 .9094 L .05935 .9095 L closepath p F P
0 g
s
.647 .101 0 r
.05919 .9094 m .0592 .90941 L .05533 .90701 L p F P
0 g
s
0 .189 .604 r
.06535 .9132 m .05936 .90951 L p .05533 .90701 L F P
0 g
s
0 .191 .607 r
.0592 .90941 m .05935 .9095 L p .06963 .91587 L F P
0 g
s
0 .189 .604 r
.05936 .90951 m .0592 .90941 L .05908 .90934 L p F P
0 g
s
0 .189 .604 r
.05908 .90934 m .05533 .90701 L p .05936 .90951 L F P
0 g
s
0 .191 .607 r
.06816 .91495 m .06963 .91587 L p .0613 .91071 L F P
0 g
s
0 .191 .607 r
.0613 .91071 m .05935 .9095 L .06816 .91495 L F
.482 .381 .664 r
.56241 .76736 m .56216 .76724 L .56236 .76712 L closepath p F P
0 g
s
.823 .721 .752 r
.21652 .87179 m .2112 .86943 L .21689 .86226 L p F P
0 g
s
.823 .721 .752 r
.21652 .87179 m .21313 .87598 L .20968 .87134 L p F P
0 g
s
.823 .721 .752 r
.20968 .87134 m .2112 .86943 L .21652 .87179 L p F P
0 g
s
.524 .442 .706 r
.56312 .81546 m .5728 .81039 L p .57441 .81823 L F P
0 g
s
.524 .442 .706 r
.57441 .81823 m .56336 .81632 L .56312 .81546 L p F P
0 g
s
.513 .433 .702 r
.57188 .807 m .5728 .81039 L .56312 .81546 L p F P
0 g
s
.513 .433 .702 r
.56564 .80564 m .57188 .807 L p .56312 .81546 L F P
0 g
s
.828 .707 .731 r
.22696 .83887 m .22984 .83479 L .22654 .82964 L p F P
0 g
s
.913 .71 .616 r
.22569 .73204 m .22979 .73496 L .22806 .74086 L p F P
0 g
s
.915 .703 .602 r
.22979 .73496 m .22569 .73204 L .22718 .72623 L p F P
0 g
s
.522 .447 .713 r
.56523 .82304 m .56336 .81632 L .57441 .81823 L closepath p F P
0 g
s
.466 .371 .663 r
.56236 .76712 m .57139 .76125 L p .56881 .7709 L F P
0 g
s
.466 .371 .663 r
.56881 .7709 m .56241 .76736 L .56236 .76712 L p F P
0 g
s
.446 .35 .653 r
.57095 .75911 m .57139 .76125 L .56236 .76712 L p F P
0 g
s
.446 .35 .653 r
.56703 .75641 m .57095 .75911 L p .56236 .76712 L F P
0 g
s
.657 .754 .922 r
.63017 .66273 m .61851 .66597 L .61563 .66309 L p F P
0 g
s
.704 .807 .929 r
.60405 .66825 m .61563 .66309 L .61851 .66597 L p F P
0 g
s
.637 .732 .917 r
.61851 .66597 m .63017 .66273 L .63305 .66639 L p F P
0 g
s
.462 .373 .669 r
.56385 .77407 m .56241 .76736 L .56881 .7709 L closepath p F P
0 g
s
.092 0 .18 r
.74995 .8956 m .75054 .89518 L .75069 .89452 L closepath p F P
0 g
s
.536 .903 .714 r
.72586 .91637 m .72787 .91545 L .73375 .91135 L p F P
0 g
s
.457 .5 .815 r
.73422 .73486 m .74221 .73688 L .73929 .73024 L p F P
0 g
s
.457 .5 .815 r
.73929 .73024 m .73804 .72992 L .73422 .73486 L p F P
0 g
s
.46 .498 .811 r
.73422 .73486 m .74221 .73688 L p .74065 .74246 L F P
0 g
s
.546 .91 .724 r
.60025 .67045 m .60234 .6674 L p .59109 .67649 L F P
0 g
s
.747 .922 .949 r
.60025 .67045 m .60234 .6674 L .60405 .66825 L closepath p F P
0 g
s
.167 .604 .937 r
.08051 .9221 m .08948 .92356 L .09387 .92616 L p F P
0 g
s
.203 .621 .949 r
.08948 .92356 m .08051 .9221 L .07668 .91971 L p F P
0 g
s
.85 .709 .707 r
.22808 .80466 m .23322 .80716 L .22928 .81378 L p F P
0 g
s
.844 .703 .706 r
.23178 .79828 m .22808 .80466 L .23322 .80716 L p F P
0 g
s
.379 .277 .611 r
.57198 .73054 m .56662 .73474 L .56758 .74111 L p F P
0 g
s
.366 .256 .594 r
.56662 .73474 m .57198 .73054 L .5692 .72585 L p F P
0 g
s
.412 .3 .616 r
.56717 .7414 m .56758 .74111 L .56662 .73474 L p F P
0 g
s
.584 .569 .802 r
.6057 .90358 m .60482 .90367 L .60559 .90334 L closepath p F P
0 g
s
.583 .563 .797 r
.60269 .89685 m .60559 .90334 L .60482 .90367 L p F P
0 g
s
.556 .511 .76 r
.5906 .86658 m .59356 .87452 L .58191 .87476 L p F P
0 g
s
.556 .511 .76 r
.58191 .87476 m .58065 .87128 L .5906 .86658 L p F P
0 g
s
.609 .747 .943 r
.65846 .92948 m .67021 .92702 L .67303 .93017 L p F P
0 g
s
.603 .718 .926 r
.67021 .92702 m .65846 .92948 L .6556 .92565 L p F P
0 g
s
.412 .422 .76 r
.76326 .76999 m .75899 .77493 L .76622 .77858 L p F P
0 g
s
.422 .435 .768 r
.75551 .76651 m .76326 .76999 L .75899 .77493 L p F P
0 g
s
0 0 .024 r
.75054 .89518 m .74995 .8956 L .74342 .90307 L p F P
0 g
s
.928 .582 .356 r
.03937 .88676 m .03912 .88525 L .0352 .88292 L p F P
0 g
s
.74 .782 .887 r
.14411 .92736 m .14159 .92875 L .13792 .92571 L p F P
0 g
s
.691 .777 .917 r
.12702 .93029 m .13792 .92571 L .14159 .92875 L p F P
0 g
s
.663 .911 .978 r
.7012 .92678 m .70198 .92714 L .71368 .92222 L p F P
0 g
s
.097 0 .249 r
.58319 .6864 m .58801 .68091 L p .58096 .69206 L F P
0 g
s
.097 0 .249 r
.58096 .69206 m .58125 .69044 L .58319 .6864 L p F P
0 g
s
0 0 0 r
.58976 .67819 m .59109 .67649 L p .58319 .6864 L F P
0 g
s
0 0 0 r
.58319 .6864 m .58801 .68091 L .58976 .67819 L p F P
0 g
s
.625 .774 .952 r
.11258 .9304 m .12331 .92743 L .12702 .93029 L p F P
0 g
s
.634 .776 .949 r
.12331 .92743 m .11258 .9304 L .10883 .92773 L p F P
0 g
s
.145 0 .324 r
.76347 .87702 m .76047 .87943 L .76005 .88427 L p F P
0 g
s
.209 .034 .413 r
.76047 .87943 m .76347 .87702 L .7646 .87096 L p F P
0 g
s
.593 .627 .855 r
.63803 .91837 m .62867 .91963 L .63661 .91587 L closepath p F P
0 g
s
.593 .616 .844 r
.63509 .91319 m .63661 .91587 L .62867 .91963 L p F P
0 g
s
.593 .616 .844 r
.62336 .91449 m .63509 .91319 L p .62867 .91963 L F P
0 g
s
.531 .454 .714 r
.56523 .82304 m .57441 .81823 L p .57228 .82822 L F P
0 g
s
.531 .454 .714 r
.57228 .82822 m .56647 .82745 L .56523 .82304 L p F P
0 g
s
.806 .722 .772 r
.21025 .87913 m .21313 .87598 L .20968 .87134 L p F P
0 g
s
.556 .51 .759 r
.5905 .86631 m .5906 .86658 L .58065 .87128 L p F P
0 g
s
.556 .51 .759 r
.58065 .87128 m .57884 .86625 L .5905 .86631 L p F P
0 g
s
.883 .712 .666 r
.22775 .75587 m .23229 .75862 L .22961 .76483 L p F P
0 g
s
.881 .707 .661 r
.23025 .74972 m .22775 .75587 L .23229 .75862 L p F P
0 g
s
.872 .711 .68 r
.22854 .78008 m .23328 .78273 L .23023 .78908 L p F P
0 g
s
.87 .706 .677 r
.23328 .78273 m .22854 .78008 L .23146 .77378 L p F P
0 g
s
.832 .717 .738 r
.2214 .85667 m .22251 .85511 L .21928 .85362 L closepath p F P
0 g
s
.834 .715 .734 r
.21798 .85171 m .2221 .84579 L p .22251 .85511 L F P
0 g
s
.834 .715 .734 r
.22251 .85511 m .21928 .85362 L .21798 .85171 L p F P
0 g
s
.54 .63 .889 r
.66638 .67809 m .66523 .67624 L .66754 .67616 L closepath p F P
0 g
s
.575 .564 .804 r
.61558 .8987 m .61739 .9026 L .6057 .90358 L p F P
0 g
s
.575 .564 .804 r
.6057 .90358 m .60559 .90334 L .61558 .8987 L p F P
0 g
s
.578 .583 .822 r
.6057 .90358 m .61739 .9026 L .62038 .90874 L p F P
0 g
s
.456 .489 .804 r
.74513 .74375 m .74065 .74246 L p .74638 .75026 L F P
0 g
s
.451 .486 .804 r
.74513 .74375 m .74065 .74246 L .74324 .73926 L closepath p F P
0 g
s
.46 .498 .811 r
.74221 .73688 m .74324 .73926 L .74065 .74246 L p F P
0 g
s
.32 .236 .602 r
.77454 .83635 m .77159 .83901 L .77413 .84406 L p F P
0 g
s
.342 .27 .63 r
.77159 .83901 m .77454 .83635 L .77325 .82973 L p F P
0 g
s
.846 .708 .71 r
.23045 .82291 m .22645 .8295 L .22306 .82426 L p F P
0 g
s
.846 .708 .71 r
.22306 .82426 m .22535 .82042 L .23045 .82291 L p F P
0 g
s
.847 .708 .709 r
.23045 .82291 m .22535 .82042 L .22928 .81378 L p F P
0 g
s
.43 .451 .78 r
.75115 .75851 m .75135 .75827 L p .75551 .76651 L F P
0 g
s
.437 .466 .791 r
.75115 .75851 m .751 .75815 L .75135 .75827 L closepath p F P
0 g
s
.572 .562 .804 r
.61438 .89613 m .61558 .8987 L .60559 .90334 L p F P
0 g
s
.572 .562 .804 r
.60559 .90334 m .60269 .89685 L .61438 .89613 L p F P
0 g
s
.503 .567 .853 r
.70346 .7022 m .703 .70216 L .70326 .70181 L closepath p F P
0 g
s
.509 .577 .859 r
.70059 .69679 m .70326 .70181 L .703 .70216 L p F P
0 g
s
.697 .779 .914 r
.13792 .92571 m .12702 .93029 L .12331 .92743 L p F P
0 g
s
.356 .314 .674 r
.77172 .82284 m .77526 .81933 L .77089 .81481 L p F P
0 g
s
.358 .319 .678 r
.77581 .80981 m .77089 .81481 L .77526 .81933 L p F P
0 g
s
.373 .342 .695 r
.7708 .80548 m .77581 .80981 L .77089 .81481 L p F P
0 g
s
.598 .69 .907 r
.63305 .66639 m .64478 .66427 L .64767 .66837 L p F P
0 g
s
.608 .702 .911 r
.64478 .66427 m .63305 .66639 L .63017 .66273 L p F P
0 g
s
.343 .29 .653 r
.77172 .82284 m .77526 .81933 L p .77397 .82903 L F P
0 g
s
.343 .29 .653 r
.77397 .82903 m .77277 .82754 L .77172 .82284 L p F P
0 g
s
.421 .439 .773 r
.75961 .76159 m .75551 .76651 L .76326 .76999 L p F P
0 g
s
.43 .451 .78 r
.75135 .75827 m .75961 .76159 L .75551 .76651 L p F P
0 g
s
.436 .466 .793 r
.75135 .75827 m .751 .75815 L .74806 .75081 L p F P
0 g
s
0 0 0 r
.73375 .91135 m .73816 .9084 L .73939 .90685 L closepath p F P
0 g
s
.536 .903 .714 r
.73375 .91135 m .73816 .9084 L p .72586 .91637 L F P
0 g
s
.818 .733 .771 r
.20479 .87681 m .21025 .87913 L .20348 .8866 L p F P
0 g
s
.806 .722 .772 r
.20968 .87134 m .20479 .87681 L .21025 .87913 L p F P
0 g
s
.922 .712 .601 r
.22323 .72325 m .22718 .72623 L .22569 .73204 L p F P
0 g
s
.926 .702 .58 r
.22718 .72623 m .22323 .72325 L .22442 .71754 L p F P
0 g
s
.529 .459 .722 r
.56743 .83071 m .56647 .82745 L .57228 .82822 L closepath p F P
0 g
s
.837 .716 .731 r
.22163 .83647 m .22696 .83887 L .2221 .84579 L p F P
0 g
s
.828 .707 .731 r
.2264 .82958 m .22163 .83647 L .22696 .83887 L p F P
0 g
s
.828 .707 .731 r
.22654 .82964 m .2264 .82958 L p .22696 .83887 L F P
0 g
s
0 0 .009 r
.75709 .89025 m .75054 .89518 L .74914 .89904 L p F P
0 g
s
0 0 .024 r
.74342 .90307 m .74914 .89904 L .75054 .89518 L p F P
0 g
s
.001 0 .147 r
.75975 .88601 m .75709 .89025 L .75054 .89518 L p F P
0 g
s
.001 0 .147 r
.76005 .88427 m .75975 .88601 L p .75054 .89518 L F P
0 g
s
.74 .782 .887 r
.13792 .92571 m .13937 .92488 L .14411 .92736 L p F P
0 g
s
.73 .771 .886 r
.14899 .91947 m .13937 .92488 L .14411 .92736 L p F P
0 g
s
.73 .771 .886 r
.14411 .92736 m .15263 .92273 L .14899 .91947 L p F P
0 g
s
.678 .909 .975 r
.60234 .6674 m .60405 .66825 L .61563 .66309 L p F P
0 g
s
.759 .762 .855 r
.15263 .92273 m .16119 .917 L .16659 .91929 L p F P
0 g
s
.752 .761 .861 r
.16381 .91527 m .16119 .917 L .16659 .91929 L p F P
0 g
s
.752 .761 .861 r
.16659 .91929 m .1674 .91878 L .16381 .91527 L p F P
0 g
s
.891 .71 .65 r
.23025 .74972 m .23092 .74795 L .22754 .74245 L p F P
0 g
s
.551 .499 .751 r
.58756 .85807 m .5905 .86631 L .57884 .86625 L p F P
0 g
s
.551 .499 .751 r
.57884 .86625 m .57766 .86283 L .58756 .85807 L p F P
0 g
s
.444 .472 .793 r
.74806 .75081 m .74638 .75026 L .74736 .74908 L closepath p F P
0 g
s
.456 .489 .804 r
.74638 .75026 m .74736 .74908 L .74513 .74375 L p F P
0 g
s
.818 .715 .752 r
.21689 .86226 m .2214 .85667 L .21928 .85362 L p F P
0 g
s
.254 .106 .478 r
.7646 .87096 m .769 .86741 L .76874 .86188 L p F P
0 g
s
.206 .032 .411 r
.769 .86741 m .7646 .87096 L .76347 .87702 L p F P
0 g
s
.537 .466 .723 r
.56743 .83071 m .57228 .82822 L p .57058 .83808 L F P
0 g
s
.537 .466 .723 r
.57058 .83808 m .56958 .83798 L .56743 .83071 L p F P
0 g
s
.492 .557 .85 r
.70346 .7022 m .71554 .7036 L p .71322 .70867 L F P
0 g
s
.487 .558 .854 r
.71266 .69803 m .71554 .7036 L .70346 .7022 L p F P
0 g
s
.487 .558 .854 r
.70617 .6973 m .71266 .69803 L p .70346 .7022 L F P
0 g
s
.487 .558 .854 r
.70346 .7022 m .70326 .70181 L .70617 .6973 L p F P
0 g
s
.428 .455 .785 r
.75526 .75338 m .75135 .75827 L .75961 .76159 L p F P
0 g
s
.436 .466 .793 r
.74806 .75081 m .75526 .75338 L .75135 .75827 L p F P
0 g
s
.778 .751 .829 r
.17829 .91043 m .1674 .91878 L .16381 .91527 L p F P
0 g
s
.276 .155 .528 r
.57331 .7097 m .57303 .70995 L .57347 .71575 L p F P
0 g
s
0 0 0 r
.74342 .90307 m .74914 .89904 L p .73816 .9084 L F P
0 g
s
0 0 0 r
.73816 .9084 m .73939 .90685 L .74342 .90307 L p F P
0 g
s
.55 .498 .75 r
.58742 .85766 m .58756 .85807 L .57766 .86283 L p F P
0 g
s
.55 .498 .75 r
.57766 .86283 m .57576 .85731 L .58742 .85766 L p F P
0 g
s
.614 .809 .975 r
.67303 .93017 m .68478 .92717 L .68755 .92952 L p F P
0 g
s
.61 .772 .958 r
.68478 .92717 m .67303 .93017 L .67021 .92702 L p F P
0 g
s
.529 .605 .873 r
.68287 .68574 m .68084 .68573 L .68196 .68414 L closepath p F P
0 g
s
.533 .616 .881 r
.68 .68078 m .68196 .68414 L .68084 .68573 L p F P
0 g
s
.497 .571 .861 r
.70326 .70181 m .70059 .69679 L .70617 .6973 L closepath p F P
0 g
s
.607 .881 .991 r
.68755 .92952 m .69929 .92577 L .7012 .92678 L p F P
0 g
s
.614 .842 .986 r
.69929 .92577 m .68755 .92952 L .68478 .92717 L p F P
0 g
s
.357 .253 .597 r
.57414 .72181 m .5692 .72585 L .57198 .73054 L p F P
0 g
s
.338 .223 .572 r
.5692 .72585 m .57414 .72181 L .57347 .71575 L p F P
0 g
s
.536 .472 .731 r
.56974 .8385 m .56958 .83798 L .57058 .83808 L closepath p F P
0 g
s
.545 .488 .742 r
.58473 .84975 m .58742 .85766 L .57576 .85731 L p F P
0 g
s
.545 .488 .742 r
.57576 .85731 m .57486 .85456 L .58473 .84975 L p F P
0 g
s
.537 .474 .733 r
.57222 .84646 m .56974 .8385 L .57058 .83808 L p F P
0 g
s
.47 .526 .833 r
.73063 .72258 m .72419 .72133 L .72186 .7164 L p F P
0 g
s
.276 .155 .528 r
.57347 .71575 m .57448 .71484 L .57331 .7097 L p F P
0 g
s
.251 .133 .518 r
.5795 .70387 m .57331 .7097 L .57448 .71484 L p F P
0 g
s
.213 .074 .464 r
.57331 .7097 m .5795 .70387 L .57935 .69844 L p F P
0 g
s
.544 .486 .742 r
.58433 .84857 m .58473 .84975 L .57486 .85456 L p F P
0 g
s
.544 .486 .742 r
.57486 .85456 m .57268 .8479 L .58433 .84857 L p F P
0 g
s
.906 .513 .254 r
.04499 .89458 m .04092 .89182 L .03937 .88676 L p F P
0 g
s
.909 .514 .245 r
.03537 .88396 m .03937 .88676 L .04092 .89182 L p F P
0 g
s
.928 .582 .356 r
.0352 .88292 m .03537 .88396 L .03937 .88676 L p F P
0 g
s
.464 .377 .673 r
.5654 .78108 m .56385 .77407 L .56881 .7709 L p F P
0 g
s
.491 .395 .674 r
.56461 .78152 m .5654 .78108 L .56385 .77407 L p F P
0 g
s
.771 .75 .834 r
.17934 .91085 m .17867 .91014 L .17829 .91043 L closepath p F P
0 g
s
.54 .477 .734 r
.57268 .8479 m .57222 .84646 L .58207 .84161 L p F P
0 g
s
.537 .474 .733 r
.58123 .839 m .58207 .84161 L .57222 .84646 L p F P
0 g
s
.537 .474 .733 r
.57058 .83808 m .58123 .839 L p .57222 .84646 L F P
0 g
s
.936 .606 .386 r
.03472 .87865 m .0352 .88292 L .03131 .88024 L p F P
0 g
s
.936 .606 .386 r
.03131 .88024 m .03081 .87581 L .03472 .87865 L p F P
0 g
s
.939 .645 .455 r
.03472 .87865 m .03081 .87581 L .03076 .87034 L p F P
0 g
s
.54 .477 .734 r
.58207 .84161 m .58433 .84857 L .57268 .8479 L p F P
0 g
s
.267 .147 .524 r
.76874 .86188 m .77094 .85999 L .77004 .85447 L p F P
0 g
s
.265 .147 .525 r
.7759 .84934 m .77004 .85447 L .77094 .85999 L p F P
0 g
s
.298 .196 .567 r
.77004 .85447 m .7759 .84934 L .77413 .84406 L p F P
0 g
s
.863 .71 .692 r
.23178 .79828 m .23189 .79807 L .23154 .79788 L closepath p F P
0 g
s
.865 .707 .685 r
.22841 .79276 m .23023 .78908 L p .23189 .79807 L F P
0 g
s
.865 .707 .685 r
.23189 .79807 m .23154 .79788 L .22841 .79276 L p F P
0 g
s
.818 .733 .771 r
.20348 .8866 m .20155 .88876 L .19806 .88447 L p F P
0 g
s
.818 .733 .771 r
.19806 .88447 m .19829 .88422 L .20348 .8866 L p F P
0 g
s
.818 .733 .771 r
.20348 .8866 m .19829 .88422 L .20479 .87681 L p F P
0 g
s
.933 .71 .578 r
.22062 .71449 m .22442 .71754 L .22323 .72325 L p F P
0 g
s
.938 .696 .547 r
.22442 .71754 m .22062 .71449 L .22146 .7089 L p F P
0 g
s
.85 .709 .707 r
.22808 .80466 m .23178 .79828 L .23154 .79788 L p F P
0 g
s
.89 .716 .659 r
.22587 .74691 m .23025 .74972 L .22775 .75587 L p F P
0 g
s
.891 .71 .65 r
.22754 .74245 m .22587 .74691 L .23025 .74972 L p F P
0 g
s
0 0 .204 r
.58036 .69268 m .58096 .69206 L .58125 .69044 L closepath p F P
0 g
s
.858 .406 .101 r
.05156 .90214 m .04742 .89941 L .04499 .89458 L p F P
0 g
s
.857 .404 .089 r
.04092 .89182 m .04499 .89458 L .04742 .89941 L p F P
0 g
s
.636 .891 .986 r
.69929 .92577 m .7083 .9225 L .7012 .92678 L closepath p F P
0 g
s
.663 .911 .978 r
.71104 .92147 m .7083 .9225 L .7012 .92678 L p F P
0 g
s
.663 .911 .978 r
.71368 .92222 m .71104 .92147 L p .7012 .92678 L F P
0 g
s
.606 .664 .88 r
.64096 .9232 m .65271 .92141 L p .65377 .92597 L F P
0 g
s
.589 .653 .88 r
.65271 .92141 m .64096 .9232 L .63803 .91837 L p F P
0 g
s
.877 .714 .676 r
.22684 .77107 m .23146 .77378 L .22854 .78008 L p F P
0 g
s
.876 .709 .672 r
.23146 .77378 m .22684 .77107 L .22961 .76483 L p F P
0 g
s
.343 .29 .653 r
.77325 .82973 m .77277 .82754 L .77397 .82903 L closepath p F P
0 g
s
.58 .598 .835 r
.63212 .90765 m .63509 .91319 L .62336 .91449 L p F P
0 g
s
.58 .598 .835 r
.62147 .90864 m .63212 .90765 L p .62336 .91449 L F P
0 g
s
.58 .598 .835 r
.62336 .91449 m .62057 .9091 L .62147 .90864 L p F P
0 g
s
.85 .709 .707 r
.23154 .79788 m .22687 .79552 L p .22808 .80466 L F P
0 g
s
.852 .706 .7 r
.23154 .79788 m .22841 .79276 L .22687 .79552 L closepath p F P
0 g
s
.799 .733 .791 r
.19586 .89433 m .20155 .88876 L .19806 .88447 L p F P
0 g
s
.539 .635 .894 r
.66754 .67616 m .66523 .67624 L .66236 .67168 L p F P
0 g
s
.829 .726 .751 r
.21155 .85989 m .21689 .86226 L .2112 .86943 L p F P
0 g
s
.818 .715 .752 r
.21718 .85273 m .21155 .85989 L .21689 .86226 L p F P
0 g
s
.818 .715 .752 r
.21928 .85362 m .21718 .85273 L p .21689 .86226 L F P
0 g
s
.538 .473 .731 r
.58123 .839 m .57058 .83808 L .57956 .83361 L closepath p F P
0 g
s
.537 .466 .723 r
.57812 .82893 m .57956 .83361 L .57058 .83808 L p F P
0 g
s
.537 .466 .723 r
.57228 .82822 m .57812 .82893 L p .57058 .83808 L F P
0 g
s
.566 .666 .905 r
.64806 .66895 m .64767 .66837 L .64843 .66829 L closepath p F P
0 g
s
.423 .32 .632 r
.56771 .74191 m .56717 .7414 L .56758 .74111 L closepath p F P
0 g
s
0 .377 .778 r
.07397 .9185 m .07668 .91971 L .07284 .91725 L p F P
0 g
s
0 .377 .778 r
.07284 .91725 m .06963 .91587 L .07397 .9185 L p F P
0 g
s
.778 .751 .829 r
.16381 .91527 m .17286 .90813 L .17829 .91043 L p F P
0 g
s
.772 .752 .835 r
.17512 .90638 m .17286 .90813 L .17829 .91043 L p F P
0 g
s
.772 .752 .835 r
.17829 .91043 m .17867 .91014 L .17512 .90638 L p F P
0 g
s
.807 .738 .788 r
.19586 .89433 m .19006 .90013 L .18654 .89611 L p F P
0 g
s
.807 .738 .788 r
.18654 .89611 m .19058 .89197 L .19586 .89433 L p F P
0 g
s
.799 .733 .791 r
.19806 .88447 m .19058 .89197 L .19586 .89433 L p F P
0 g
s
.794 .744 .807 r
.18764 .90222 m .17867 .91014 L .17512 .90638 L p F P
0 g
s
.854 .714 .708 r
.22426 .81125 m .22928 .81378 L .22535 .82042 L p F P
0 g
s
.85 .709 .707 r
.22928 .81378 m .22426 .81125 L .22808 .80466 L p F P
0 g
s
.433 .465 .793 r
.75526 .75338 m .74806 .75081 L .74736 .74908 L p F P
0 g
s
.495 .403 .68 r
.56558 .78186 m .56461 .78152 L .5654 .78108 L closepath p F P
0 g
s
.515 .434 .703 r
.57188 .807 m .56564 .80564 L .5708 .8029 L closepath p F P
0 g
s
.514 .426 .693 r
.56887 .79549 m .5708 .8029 L .56564 .80564 L p F P
0 g
s
.512 .596 .875 r
.69197 .68109 m .69484 .68618 L .68287 .68574 L p F P
0 g
s
.512 .596 .875 r
.68391 .68084 m .69197 .68109 L p .68287 .68574 L F P
0 g
s
.512 .596 .875 r
.68287 .68574 m .68196 .68414 L .68391 .68084 L p F P
0 g
s
.515 .593 .871 r
.68287 .68574 m .69484 .68618 L p .69445 .69123 L F P
0 g
s
.794 .744 .807 r
.17512 .90638 m .18228 .8999 L .18764 .90222 L p F P
0 g
s
.787 .742 .812 r
.18654 .89611 m .18228 .8999 L .18764 .90222 L p F P
0 g
s
.787 .742 .812 r
.18764 .90222 m .19006 .90013 L .18654 .89611 L p F P
0 g
s
.321 .256 .626 r
.77397 .82903 m .77325 .82973 L .77454 .83635 L p F P
0 g
s
.566 .549 .795 r
.61136 .88933 m .61438 .89613 L .60269 .89685 L p F P
0 g
s
.566 .549 .795 r
.61003 .88938 m .61136 .88933 L p .60269 .89685 L F P
0 g
s
.566 .549 .795 r
.60269 .89685 m .60131 .89364 L .61003 .88938 L p F P
0 g
s
.41 .311 .631 r
.56758 .74111 m .5753 .7351 L p .5714 .7457 L F P
0 g
s
.41 .311 .631 r
.5714 .7457 m .56771 .74191 L .56758 .74111 L p F P
0 g
s
.379 .277 .611 r
.56758 .74111 m .5753 .7351 L .57198 .73054 L p F P
0 g
s
.837 .716 .731 r
.2221 .84579 m .21693 .84335 L .22163 .83647 L p F P
0 g
s
.837 .716 .731 r
.2221 .84579 m .21798 .85171 L .21455 .84683 L p F P
0 g
s
.837 .716 .731 r
.21455 .84683 m .21693 .84335 L .2221 .84579 L p F P
0 g
s
.945 .705 .544 r
.21782 .70579 m .22146 .7089 L .22062 .71449 L p F P
0 g
s
.95 .683 .497 r
.22146 .7089 m .21782 .70579 L .21821 .70035 L p F P
0 g
s
.227 .086 .472 r
.77094 .85999 m .76874 .86188 L .769 .86741 L p F P
0 g
s
.764 .253 0 r
.05919 .9094 m .05501 .90669 L .05156 .90214 L p F P
0 g
s
.758 .246 0 r
.04742 .89941 m .05156 .90214 L .05501 .90669 L p F P
0 g
s
.83 .705 .726 r
.22654 .82964 m .22645 .8295 L .2264 .82958 L closepath p F P
0 g
s
.368 .341 .697 r
.77562 .80048 m .7708 .80548 L .77581 .80981 L p F P
0 g
s
.383 .361 .711 r
.76999 .79633 m .77562 .80048 L .7708 .80548 L p F P
0 g
s
.564 .674 .913 r
.64843 .66829 m .64767 .66837 L .64478 .66427 L p F P
0 g
s
.433 .465 .793 r
.74736 .74908 m .75023 .74536 L p .75526 .75338 L F P
0 g
s
.44 .479 .804 r
.74736 .74908 m .74513 .74375 L .75023 .74536 L closepath p F P
0 g
s
.833 .709 .728 r
.2264 .82958 m .22645 .8295 L .22306 .82426 L p F P
0 g
s
.839 .716 .729 r
.22112 .82715 m .2264 .82958 L .22163 .83647 L p F P
0 g
s
.833 .709 .728 r
.22306 .82426 m .22112 .82715 L .2264 .82958 L p F P
0 g
s
.099 0 .357 r
.58096 .69206 m .58036 .69268 L .57935 .69844 L p F P
0 g
s
.317 .672 .976 r
.09387 .92616 m .09453 .92622 L .09073 .92366 L p F P
0 g
s
.317 .672 .976 r
.09073 .92366 m .08948 .92356 L .09387 .92616 L p F P
0 g
s
.403 .31 .635 r
.56874 .74771 m .56771 .74191 L .5714 .7457 L closepath p F P
0 g
s
.546 .91 .724 r
.59328 .6739 m .59109 .67649 L p .59217 .67548 L F P
0 g
s
.546 .91 .724 r
.60118 .66707 m .59328 .6739 L p .59217 .67548 L F P
0 g
s
0 0 0 r
.59328 .6739 m .59694 .66873 L p .59552 .67068 L F P
0 g
s
.546 .91 .724 r
.60234 .6674 m .60118 .66707 L p .59109 .67649 L F P
0 g
s
0 0 0 r
.58976 .67819 m .59328 .6739 L .59109 .67649 L closepath p F P
0 g
s
0 0 0 r
.58907 .67958 m .58976 .67819 L .59328 .6739 L p F P
0 g
s
0 0 0 r
.58907 .67958 m .59328 .6739 L .59552 .67068 L F
.486 .547 .844 r
.71842 .70939 m .71322 .70867 L .71608 .70466 L closepath p F P
0 g
s
.492 .557 .85 r
.71554 .7036 m .71608 .70466 L .71322 .70867 L p F P
0 g
s
.82 .713 .748 r
.21928 .85362 m .21798 .85171 L .21718 .85273 L closepath p F P
0 g
s
.913 .71 .616 r
.22412 .73742 m .22569 .73204 L p .22806 .74086 L F P
0 g
s
.913 .71 .616 r
.22806 .74086 m .22484 .73856 L .22412 .73742 L p F P
0 g
s
.908 .718 .633 r
.22754 .74245 m .22806 .74086 L .22484 .73856 L closepath p F P
0 g
s
.481 .393 .68 r
.5654 .78108 m .57452 .77532 L p .5726 .78485 L F P
0 g
s
.481 .393 .68 r
.5726 .78485 m .56558 .78186 L .5654 .78108 L p F P
0 g
s
.464 .377 .673 r
.57414 .77367 m .57452 .77532 L .5654 .78108 L p F P
0 g
s
.464 .377 .673 r
.56881 .7709 m .57414 .77367 L p .5654 .78108 L F P
0 g
s
.57 .674 .909 r
.64843 .66829 m .65948 .6672 L .65659 .66281 L p F P
0 g
s
.57 .674 .909 r
.65659 .66281 m .65097 .66348 L .64843 .66829 L p F P
0 g
s
.564 .674 .913 r
.64478 .66427 m .65097 .66348 L .64843 .66829 L p F P
0 g
s
.87 .713 .685 r
.23023 .78908 m .22841 .79276 L .22502 .78752 L p F P
0 g
s
.87 .713 .685 r
.22502 .78752 m .22556 .78641 L .23023 .78908 L p F P
0 g
s
.872 .711 .68 r
.23023 .78908 m .22556 .78641 L .22854 .78008 L p F P
0 g
s
.605 .678 .893 r
.6556 .92565 m .65377 .92597 L .6553 .92522 L closepath p F P
0 g
s
.606 .664 .88 r
.65271 .92141 m .6553 .92522 L .65377 .92597 L p F P
0 g
s
.765 .766 .854 r
.16119 .917 m .15263 .92273 L .14899 .91947 L p F P
0 g
s
.477 .396 .686 r
.56711 .78826 m .56558 .78186 L .5726 .78485 L closepath p F P
0 g
s
.883 .717 .671 r
.22513 .76206 m .22961 .76483 L .22684 .77107 L p F P
0 g
s
.883 .712 .666 r
.22961 .76483 m .22513 .76206 L .22775 .75587 L p F P
0 g
s
.516 .75 .98 r
.09453 .92622 m .10507 .92502 L .10883 .92773 L p F P
0 g
s
.529 .753 .978 r
.10507 .92502 m .09453 .92622 L .09073 .92366 L p F P
0 g
s
.566 .548 .794 r
.60131 .89364 m .59966 .88978 L .61003 .88938 L closepath p F P
0 g
s
.54 .631 .89 r
.66754 .67616 m .67712 .67593 L .67424 .67114 L p F P
0 g
s
.54 .631 .89 r
.67424 .67114 m .67044 .67128 L .66754 .67616 L p F P
0 g
s
.539 .635 .894 r
.66236 .67168 m .67044 .67128 L .66754 .67616 L p F P
0 g
s
.47 .526 .833 r
.72186 .7164 m .72252 .71545 L p .73063 .72258 L F P
0 g
s
.476 .538 .841 r
.72186 .7164 m .7213 .71524 L .72252 .71545 L closepath p F P
0 g
s
.829 .726 .751 r
.20622 .86678 m .21155 .85989 L p .2112 .86943 L F P
0 g
s
.829 .726 .751 r
.2112 .86943 m .20657 .86725 L .20622 .86678 L p F P
0 g
s
.827 .728 .755 r
.20968 .87134 m .2112 .86943 L .20657 .86725 L closepath p F P
0 g
s
.521 .607 .88 r
.68196 .68414 m .68 .68078 L .68391 .68084 L closepath p F P
0 g
s
.321 .258 .63 r
.77904 .82404 m .77397 .82903 L .77705 .83394 L p F P
0 g
s
.343 .29 .653 r
.77526 .81933 m .77904 .82404 L .77397 .82903 L p F P
0 g
s
.321 .256 .626 r
.77454 .83635 m .77705 .83394 L .77397 .82903 L p F P
0 g
s
.069 0 .345 r
.58553 .68711 m .58096 .69206 L .58069 .69707 L p F P
0 g
s
.097 0 .249 r
.58801 .68091 m .58553 .68711 L .58096 .69206 L p F P
0 g
s
.099 0 .357 r
.57935 .69844 m .58069 .69707 L .58096 .69206 L p F P
0 g
s
.811 .726 .771 r
.20479 .87681 m .20968 .87134 L .20657 .86725 L p F P
0 g
s
.899 .72 .651 r
.22587 .74691 m .22754 .74245 L .22484 .73856 L p F P
0 g
s
.446 .352 .656 r
.57095 .75911 m .56703 .75641 L .57001 .75442 L closepath p F P
0 g
s
.44 .342 .648 r
.56703 .75641 m .57001 .75442 L .56874 .74771 L p F P
0 g
s
.465 .886 .796 r
.71368 .92222 m .72537 .91648 L .72586 .91637 L p F P
0 g
s
.536 .923 .903 r
.72537 .91648 m .71368 .92222 L .71104 .92147 L p F P
0 g
s
.647 .101 0 r
.05533 .90701 m .05501 .90669 L .05919 .9094 L p F P
0 g
s
.474 .539 .843 r
.72252 .71545 m .7213 .71524 L .71842 .70939 L p F P
0 g
s
.857 .716 .706 r
.22315 .80209 m .22808 .80466 L .22426 .81125 L p F P
0 g
s
.85 .709 .707 r
.22687 .79552 m .22315 .80209 L .22808 .80466 L p F P
0 g
s
0 .191 .607 r
.06963 .91587 m .06535 .9132 L .0592 .90941 L p F P
0 g
s
.497 .573 .862 r
.70617 .6973 m .70059 .69679 L .69772 .69142 L p F P
0 g
s
.603 .718 .926 r
.6556 .92565 m .66737 .92348 L .67021 .92702 L p F P
0 g
s
.6 .676 .894 r
.66488 .92008 m .66737 .92348 L .6556 .92565 L p F P
0 g
s
.6 .676 .894 r
.6556 .92565 m .6553 .92522 L .66488 .92008 L p F P
0 g
s
.918 .719 .618 r
.22569 .73204 m .22412 .73742 L .22068 .73271 L p F P
0 g
s
.918 .719 .618 r
.22068 .73271 m .22175 .72906 L .22569 .73204 L p F P
0 g
s
.922 .712 .601 r
.22569 .73204 m .22175 .72906 L .22323 .72325 L p F P
0 g
s
.44 .48 .804 r
.75023 .74536 m .74513 .74375 L .74324 .73926 L p F P
0 g
s
.822 .717 .749 r
.21718 .85273 m .21798 .85171 L .21455 .84683 L p F P
0 g
s
.126 0 .303 r
.76894 .87262 m .76347 .87702 L .76114 .88341 L p F P
0 g
s
.206 .032 .411 r
.76347 .87702 m .76894 .87262 L .769 .86741 L p F P
0 g
s
.145 0 .324 r
.76005 .88427 m .76114 .88341 L .76347 .87702 L p F P
0 g
s
.566 .54 .785 r
.61003 .88938 m .59966 .88978 L .59742 .88432 L p F P
0 g
s
.83 .725 .749 r
.21184 .85034 m .21718 .85273 L .21155 .85989 L p F P
0 g
s
.822 .717 .749 r
.21455 .84683 m .21184 .85034 L .21718 .85273 L p F P
0 g
s
.38 .364 .716 r
.77343 .79265 m .76999 .79633 L .77562 .80048 L p F P
0 g
s
.395 .386 .731 r
.77261 .79005 m .76846 .78736 L p .76999 .79633 L F P
0 g
s
.395 .386 .731 r
.76999 .79633 m .77343 .79265 L .77261 .79005 L p F P
0 g
s
.306 .199 .565 r
.57448 .71484 m .57347 .71575 L .57414 .72181 L p F P
0 g
s
.75 .959 .938 r
.60118 .66707 m .60408 .66524 L .60234 .6674 L closepath p F P
0 g
s
.678 .909 .975 r
.61274 .66059 m .60408 .66524 L .60234 .6674 L p F P
0 g
s
.678 .909 .975 r
.61563 .66309 m .61274 .66059 L p .60234 .6674 L F P
0 g
s
.49 .407 .689 r
.56711 .78826 m .5726 .78485 L p .56938 .79518 L F P
0 g
s
.49 .407 .689 r
.56938 .79518 m .56873 .79495 L .56711 .78826 L p F P
0 g
s
.598 .674 .894 r
.6645 .91956 m .66488 .92008 L .6553 .92522 L p F P
0 g
s
.598 .674 .894 r
.6553 .92522 m .65271 .92141 L .6645 .91956 L p F P
0 g
s
.579 .597 .835 r
.62057 .9091 m .62038 .90874 L .62147 .90864 L closepath p F P
0 g
s
.854 .714 .708 r
.22535 .82042 m .22044 .81786 L .22426 .81125 L p F P
0 g
s
.853 .715 .711 r
.22535 .82042 m .22306 .82426 L .21964 .81922 L p F P
0 g
s
.853 .715 .711 r
.21964 .81922 m .22044 .81786 L .22535 .82042 L p F P
0 g
s
.822 .736 .77 r
.19953 .87443 m .20479 .87681 L .19829 .88422 L p F P
0 g
s
.811 .726 .771 r
.20602 .86701 m .19953 .87443 L .20479 .87681 L p F P
0 g
s
.811 .726 .771 r
.20657 .86725 m .20602 .86701 L p .20479 .87681 L F P
0 g
s
.878 .717 .679 r
.22398 .77736 m .22854 .78008 L .22556 .78641 L p F P
0 g
s
.877 .714 .676 r
.22854 .78008 m .22398 .77736 L .22684 .77107 L p F P
0 g
s
.58 .585 .821 r
.62147 .90864 m .62038 .90874 L .61739 .9026 L p F P
0 g
s
.843 .721 .729 r
.2165 .834 m .22163 .83647 L .21693 .84335 L p F P
0 g
s
.839 .716 .729 r
.22163 .83647 m .2165 .834 L .22112 .82715 L p F P
0 g
s
.745 .784 .884 r
.13937 .92488 m .13792 .92571 L .13424 .92266 L p F P
0 g
s
.697 .779 .914 r
.12331 .92743 m .13424 .92266 L .13792 .92571 L p F P
0 g
s
.857 .713 .703 r
.22687 .79552 m .22841 .79276 L .22502 .78752 L p F P
0 g
s
.89 .721 .665 r
.2234 .75305 m .22775 .75587 L .22513 .76206 L p F P
0 g
s
.89 .716 .659 r
.22775 .75587 m .2234 .75305 L .22587 .74691 L p F P
0 g
s
.657 .754 .922 r
.61563 .66309 m .62728 .65927 L .63017 .66273 L p F P
0 g
s
.682 .779 .925 r
.62728 .65927 m .61563 .66309 L .61274 .66059 L p F P
0 g
s
.757 .763 .858 r
.16021 .91178 m .156 .91463 L .16119 .917 L p F P
0 g
s
.757 .763 .858 r
.16119 .917 m .16381 .91527 L .16021 .91178 L p F P
0 g
s
.765 .766 .854 r
.14899 .91947 m .156 .91463 L .16119 .917 L p F P
0 g
s
.41 .322 .645 r
.5714 .7457 m .56874 .74771 L .57001 .75442 L p F P
0 g
s
.297 .219 .598 r
.77705 .83394 m .77454 .83635 L .77561 .84274 L p F P
0 g
s
.32 .236 .602 r
.77413 .84406 m .77561 .84274 L .77454 .83635 L p F P
0 g
s
.474 .539 .843 r
.71842 .70939 m .72576 .71061 L .72252 .71545 L p F P
0 g
s
.467 .529 .838 r
.72252 .71545 m .7335 .71756 L .73061 .71153 L p F P
0 g
s
.467 .529 .838 r
.73061 .71153 m .72576 .71061 L .72252 .71545 L p F P
0 g
s
.47 .526 .833 r
.72252 .71545 m .7335 .71756 L p .73063 .72258 L F P
0 g
s
.51 .583 .864 r
.69772 .69142 m .69445 .69123 L .69621 .68863 L closepath p F P
0 g
s
.515 .593 .871 r
.69484 .68618 m .69621 .68863 L .69445 .69123 L p F P
0 g
s
.634 .776 .949 r
.10883 .92773 m .11959 .92456 L .12331 .92743 L p F P
0 g
s
.642 .778 .946 r
.11959 .92456 m .10883 .92773 L .10507 .92502 L p F P
0 g
s
.531 .462 .723 r
.57812 .82893 m .57228 .82822 L .57718 .82574 L closepath p F P
0 g
s
.531 .454 .714 r
.57501 .81833 m .57718 .82574 L .57228 .82822 L p F P
0 g
s
.531 .454 .714 r
.57441 .81823 m .57501 .81833 L p .57228 .82822 L F P
0 g
s
.203 .621 .949 r
.07668 .91971 m .08513 .92093 L .08948 .92356 L p F P
0 g
s
.234 .634 .958 r
.08513 .92093 m .07668 .91971 L .07284 .91725 L p F P
0 g
s
.745 .784 .884 r
.13424 .92266 m .13475 .92236 L .13937 .92488 L p F P
0 g
s
.736 .773 .883 r
.14535 .91621 m .13475 .92236 L .13937 .92488 L p F P
0 g
s
.736 .773 .883 r
.13937 .92488 m .14899 .91947 L .14535 .91621 L p F P
0 g
s
.621 .717 .915 r
.6419 .6603 m .63017 .66273 L .62728 .65927 L p F P
0 g
s
.608 .702 .911 r
.63017 .66273 m .6419 .6603 L .64478 .66427 L p F P
0 g
s
.589 .653 .88 r
.63803 .91837 m .64979 .91682 L .65271 .92141 L p F P
0 g
s
.583 .622 .857 r
.64686 .91192 m .64979 .91682 L .63803 .91837 L p F P
0 g
s
.583 .622 .857 r
.64331 .91231 m .64686 .91192 L p .63803 .91837 L F P
0 g
s
.583 .622 .857 r
.63803 .91837 m .63661 .91587 L .64331 .91231 L p F P
0 g
s
.931 .584 .349 r
.03537 .88396 m .0352 .88292 L .03131 .88024 L p F P
0 g
s
.581 .595 .832 r
.63212 .90765 m .62147 .90864 L .63039 .90426 L closepath p F P
0 g
s
.58 .585 .821 r
.62914 .90178 m .63039 .90426 L .62147 .90864 L p F P
0 g
s
.58 .585 .821 r
.61739 .9026 m .62914 .90178 L p .62147 .90864 L F P
0 g
s
.784 .756 .828 r
.17286 .90813 m .16381 .91527 L .16021 .91178 L p F P
0 g
s
.929 .72 .6 r
.21943 .72021 m .22323 .72325 L .22175 .72906 L p F P
0 g
s
.933 .71 .578 r
.22323 .72325 m .21943 .72021 L .22062 .71449 L p F P
0 g
s
.702 .779 .911 r
.13424 .92266 m .12331 .92743 L .11959 .92456 L p F P
0 g
s
.293 .194 .567 r
.77561 .84274 m .77413 .84406 L .7759 .84934 L p F P
0 g
s
.447 .494 .814 r
.74324 .73926 m .74221 .73688 L .74452 .73753 L closepath p F P
0 g
s
.44 .48 .804 r
.74324 .73926 m .74452 .73753 L p .75023 .74536 L F P
0 g
s
.566 .54 .785 r
.59742 .88432 m .60155 .88227 L p .61003 .88938 L F P
0 g
s
.56 .536 .785 r
.59742 .88432 m .59661 .88234 L .60155 .88227 L closepath p F P
0 g
s
.07 0 .218 r
.75975 .88601 m .76114 .88341 L .76005 .88427 L closepath p F P
0 g
s
.61 .772 .958 r
.67021 .92702 m .68199 .92435 L .68478 .92717 L p F P
0 g
s
.605 .74 .941 r
.68199 .92435 m .67021 .92702 L .66737 .92348 L p F P
0 g
s
0 0 0 r
.737 .90935 m .74185 .90578 L .73816 .9084 L closepath p F P
0 g
s
0 0 0 r
.74853 .90012 m .74185 .90578 L .73816 .9084 L p F P
0 g
s
0 0 0 r
.74914 .89904 m .74853 .90012 L p .73816 .9084 L F P
0 g
s
.536 .903 .714 r
.73816 .9084 m .737 .90935 L p .72586 .91637 L F P
0 g
s
.82 .738 .773 r
.19806 .88447 m .19829 .88422 L .19757 .88387 L closepath p F P
0 g
s
.822 .736 .77 r
.19457 .88021 m .19953 .87443 L p .19829 .88422 L F P
0 g
s
.822 .736 .77 r
.19829 .88422 m .19757 .88387 L .19457 .88021 L p F P
0 g
s
.487 .41 .696 r
.56887 .79549 m .56873 .79495 L .56938 .79518 L closepath p F P
0 g
s
.803 .736 .79 r
.19058 .89197 m .19806 .88447 L .19757 .88387 L p F P
0 g
s
.861 .719 .704 r
.22204 .79291 m .22687 .79552 L .22315 .80209 L p F P
0 g
s
.857 .713 .703 r
.22502 .78752 m .22204 .79291 L .22687 .79552 L p F P
0 g
s
.543 .642 .898 r
.67044 .67128 m .66236 .67168 L .65948 .6672 L p F P
0 g
s
.227 .086 .472 r
.769 .86741 m .77092 .86576 L .77094 .85999 L p F P
0 g
s
.223 .083 .47 r
.77682 .85486 m .77094 .85999 L .77092 .86576 L p F P
0 g
s
.265 .147 .525 r
.77094 .85999 m .77682 .85486 L .7759 .84934 L p F P
0 g
s
.49 .416 .7 r
.56938 .79518 m .56887 .79549 L .5708 .8029 L p F P
0 g
s
.282 .185 .563 r
.58053 .70906 m .57448 .71484 L .57641 .71977 L p F P
0 g
s
.251 .133 .518 r
.57448 .71484 m .58053 .70906 L .5795 .70387 L p F P
0 g
s
.306 .199 .565 r
.57414 .72181 m .57641 .71977 L .57448 .71484 L p F P
0 g
s
.612 .879 .991 r
.7083 .9225 m .69929 .92577 L .69657 .92382 L p F P
0 g
s
.614 .842 .986 r
.68478 .92717 m .69657 .92382 L .69929 .92577 L p F P
0 g
s
.538 .922 .809 r
.72537 .91648 m .72749 .91527 L .72586 .91637 L closepath p F P
0 g
s
.536 .903 .714 r
.737 .90935 m .72749 .91527 L .72586 .91637 L p F P
0 g
s
.39 .383 .731 r
.77261 .79005 m .76846 .78736 L .77092 .78466 L closepath p F P
0 g
s
.404 .404 .746 r
.76952 .78047 m .76622 .77858 L p .76846 .78736 L F P
0 g
s
.404 .404 .746 r
.76846 .78736 m .77092 .78466 L .76952 .78047 L p F P
0 g
s
.839 .716 .728 r
.22112 .82715 m .22306 .82426 L .21964 .81922 L p F P
0 g
s
.52 .611 .884 r
.68391 .68084 m .68 .68078 L .67712 .67593 L p F P
0 g
s
.561 .528 .776 r
.60155 .88227 m .59661 .88234 L .59387 .87531 L p F P
0 g
s
.83 .724 .748 r
.21155 .85989 m .20622 .86678 L .20275 .86226 L p F P
0 g
s
.83 .724 .748 r
.20275 .86226 m .2064 .85745 L .21155 .85989 L p F P
0 g
s
.83 .725 .749 r
.21155 .85989 m .2064 .85745 L .21184 .85034 L p F P
0 g
s
.898 .725 .659 r
.22167 .74402 m .22587 .74691 L .2234 .75305 L p F P
0 g
s
.899 .72 .651 r
.22395 .73795 m .22167 .74402 L .22587 .74691 L p F P
0 g
s
.899 .72 .651 r
.22484 .73856 m .22395 .73795 L p .22587 .74691 L F P
0 g
s
.909 .514 .245 r
.04092 .89182 m .03692 .88902 L .03537 .88396 L p F P
0 g
s
.911 .516 .237 r
.03145 .88112 m .03537 .88396 L .03692 .88902 L p F P
0 g
s
.931 .584 .349 r
.03131 .88024 m .03145 .88112 L .03537 .88396 L p F P
0 g
s
.784 .756 .828 r
.16021 .91178 m .16763 .90577 L .17286 .90813 L p F P
0 g
s
.777 .754 .833 r
.17155 .90266 m .16763 .90577 L .17286 .90813 L p F P
0 g
s
.777 .754 .833 r
.17286 .90813 m .17512 .90638 L .17155 .90266 L p F P
0 g
s
.884 .721 .675 r
.2224 .7683 m .22684 .77107 L .22398 .77736 L p F P
0 g
s
.883 .717 .671 r
.22684 .77107 m .2224 .7683 L .22513 .76206 L p F P
0 g
s
.812 .743 .787 r
.19058 .89197 m .18654 .89611 L .183 .89214 L p F P
0 g
s
.812 .743 .787 r
.183 .89214 m .18548 .88956 L .19058 .89197 L p F P
0 g
s
.803 .736 .79 r
.19294 .88187 m .18548 .88956 L .19058 .89197 L p F P
0 g
s
.803 .736 .79 r
.19757 .88387 m .19294 .88187 L p .19058 .89197 L F P
0 g
s
.446 .494 .815 r
.74452 .73753 m .74221 .73688 L .73929 .73024 L p F P
0 g
s
.613 .803 .973 r
.69657 .92382 m .68478 .92717 L .68199 .92435 L p F P
0 g
s
.179 .049 .455 r
.58069 .69707 m .57935 .69844 L .5795 .70387 L p F P
0 g
s
.805 .735 .786 r
.19757 .88387 m .19457 .88021 L .19294 .88187 L closepath p F P
0 g
s
.49 .417 .701 r
.57811 .78987 m .56938 .79518 L .57852 .79824 L p F P
0 g
s
.49 .407 .689 r
.57731 .78675 m .57811 .78987 L .56938 .79518 L p F P
0 g
s
.49 .407 .689 r
.5726 .78485 m .57731 .78675 L p .56938 .79518 L F P
0 g
s
.49 .416 .7 r
.5708 .8029 m .57852 .79824 L .56938 .79518 L p F P
0 g
s
.358 .319 .678 r
.77908 .81314 m .77581 .80981 L p .77526 .81933 L F P
0 g
s
.358 .319 .678 r
.77526 .81933 m .77955 .81503 L .77908 .81314 L p F P
0 g
s
.337 .288 .655 r
.77955 .81503 m .77526 .81933 L .77904 .82404 L p F P
0 g
s
.467 .517 .826 r
.7364 .72386 m .73063 .72258 L p .73804 .72992 L F P
0 g
s
.462 .515 .827 r
.7364 .72386 m .73063 .72258 L .7338 .71819 L closepath p F P
0 g
s
.47 .526 .833 r
.7335 .71756 m .7338 .71819 L .73063 .72258 L p F P
0 g
s
.859 .72 .707 r
.21943 .80866 m .22426 .81125 L .22044 .81786 L p F P
0 g
s
.857 .716 .706 r
.22426 .81125 m .21943 .80866 L .22315 .80209 L p F P
0 g
s
.94 .719 .576 r
.21698 .71139 m .22062 .71449 L .21943 .72021 L p F P
0 g
s
.945 .705 .544 r
.22062 .71449 m .21698 .71139 L .21782 .70579 L p F P
0 g
s
.799 .749 .806 r
.18228 .8999 m .17512 .90638 L .17155 .90266 L p F P
0 g
s
.464 .379 .675 r
.57414 .77367 m .56881 .7709 L .57292 .76824 L closepath p F P
0 g
s
.466 .371 .663 r
.57139 .76125 m .57292 .76824 L .56881 .7709 L p F P
0 g
s
.799 .749 .806 r
.17155 .90266 m .1771 .89751 L .18228 .8999 L p F P
0 g
s
.792 .746 .81 r
.183 .89214 m .1771 .89751 L .18228 .8999 L p F P
0 g
s
.792 .746 .81 r
.18228 .8999 m .18654 .89611 L .183 .89214 L p F P
0 g
s
.857 .404 .089 r
.04742 .89941 m .04336 .89664 L .04092 .89182 L p F P
0 g
s
.857 .402 .076 r
.03692 .88902 m .04092 .89182 L .04336 .89664 L p F P
0 g
s
.371 .274 .614 r
.57501 .72808 m .57198 .73054 L .5753 .7351 L p F P
0 g
s
.357 .253 .597 r
.57198 .73054 m .57501 .72808 L .57414 .72181 L p F P
0 g
s
.902 .712 .635 r
.22484 .73856 m .22412 .73742 L .22395 .73795 L closepath p F P
0 g
s
.843 .721 .729 r
.21693 .84335 m .21194 .84084 L .2165 .834 L p F P
0 g
s
.842 .722 .731 r
.21693 .84335 m .21455 .84683 L .2111 .84208 L p F P
0 g
s
.842 .722 .731 r
.2111 .84208 m .21194 .84084 L .21693 .84335 L p F P
0 g
s
0 .396 .797 r
.06963 .91587 m .07284 .91725 L .06899 .91472 L p F P
0 g
s
0 .396 .797 r
.06899 .91472 m .06535 .9132 L .06963 .91587 L p F P
0 g
s
.583 .622 .856 r
.63661 .91587 m .63509 .91319 L .64331 .91231 L closepath p F P
0 g
s
.845 .722 .728 r
.21605 .82464 m .22112 .82715 L .2165 .834 L p F P
0 g
s
.839 .716 .728 r
.21964 .81922 m .21605 .82464 L .22112 .82715 L p F P
0 g
s
.474 .54 .844 r
.72576 .71061 m .71842 .70939 L .71608 .70466 L p F P
0 g
s
.794 .997 .857 r
.59694 .66873 m .59328 .6739 L p .59596 .67037 L F P
0 g
s
.794 .997 .857 r
.59328 .6739 m .60118 .66707 L .59834 .66724 L p F P
0 g
s
0 0 0 r
.59224 .67558 m .58907 .67958 L p .59117 .67667 L F P
0 g
s
0 0 0 r
.59694 .66873 m .59224 .67558 L p .59117 .67667 L F P
0 g
s
0 0 .076 r
.59224 .67558 m .58975 .68179 L p .59356 .67424 L F P
0 g
s
0 0 0 r
.59694 .66873 m .59224 .67558 L p .5974 .66794 L F P
0 g
s
0 0 0 r
.59556 .6703 m .59767 .66754 L p .59224 .67558 L F P
0 g
s
0 0 .076 r
.59543 .67054 m .59224 .67558 L p .59356 .67424 L F P
0 g
s
0 0 0 r
.59767 .66754 m .59694 .66873 L p .5974 .66794 L F P
0 g
s
.794 .997 .857 r
.59834 .66724 m .59694 .66873 L p .59596 .67037 L F P
0 g
s
.571 .686 .918 r
.65097 .66348 m .64478 .66427 L .6419 .6603 L p F P
0 g
s
.176 .01 .403 r
.77092 .86576 m .769 .86741 L .76894 .87262 L p F P
0 g
s
.502 .426 .703 r
.5708 .8029 m .57852 .79824 L p .57642 .80826 L F P
0 g
s
.502 .426 .703 r
.57642 .80826 m .57188 .807 L .5708 .8029 L p F P
0 g
s
.434 .344 .655 r
.57001 .75442 m .57599 .74992 L p .57261 .76036 L F P
0 g
s
.434 .344 .655 r
.57261 .76036 m .57095 .75911 L .57001 .75442 L p F P
0 g
s
.41 .322 .645 r
.57001 .75442 m .57599 .74992 L .5714 .7457 L p F P
0 g
s
.398 .401 .746 r
.76952 .78047 m .76622 .77858 L .76815 .77638 L closepath p F P
0 g
s
.412 .422 .76 r
.76647 .77161 m .76326 .76999 L p .76622 .77858 L F P
0 g
s
.412 .422 .76 r
.76622 .77858 m .76815 .77638 L .76647 .77161 L p F P
0 g
s
0 0 .141 r
.76114 .88341 m .76761 .87819 L p .75919 .88866 L F P
0 g
s
0 0 .141 r
.75919 .88866 m .75975 .88601 L .76114 .88341 L p F P
0 g
s
.126 0 .303 r
.76873 .87535 m .76894 .87262 L p .76114 .88341 L F P
0 g
s
.126 0 .303 r
.76114 .88341 m .76761 .87819 L .76873 .87535 L p F P
0 g
s
.789 .987 .893 r
.60408 .66524 m .60118 .66707 L .59834 .66724 L p F P
0 g
s
.813 .724 .767 r
.20657 .86725 m .20622 .86678 L .20602 .86701 L closepath p F P
0 g
s
.561 .528 .776 r
.59387 .87531 m .59539 .87454 L p .60155 .88227 L F P
0 g
s
.553 .523 .776 r
.59387 .87531 m .59356 .87452 L .59539 .87454 L closepath p F P
0 g
s
.567 .568 .814 r
.62614 .89558 m .62914 .90178 L .61739 .9026 L p F P
0 g
s
.567 .568 .814 r
.62111 .89583 m .62614 .89558 L p .61739 .9026 L F P
0 g
s
.567 .568 .814 r
.61739 .9026 m .61558 .8987 L .62111 .89583 L p F P
0 g
s
.497 .573 .862 r
.69772 .69142 m .70934 .69242 L .70617 .6973 L p F P
0 g
s
.497 .576 .865 r
.70934 .69242 m .69772 .69142 L .69621 .68863 L p F P
0 g
s
.554 .516 .767 r
.59539 .87454 m .59356 .87452 L .5906 .86658 L p F P
0 g
s
.91 .722 .635 r
.22395 .73795 m .22412 .73742 L .22068 .73271 L p F P
0 g
s
.49 .9 .804 r
.72749 .91527 m .72537 .91648 L .72279 .91639 L p F P
0 g
s
.536 .923 .903 r
.71104 .92147 m .72279 .91639 L .72537 .91648 L p F P
0 g
s
.758 .246 0 r
.05501 .90669 m .05089 .90396 L .04742 .89941 L p F P
0 g
s
.752 .239 0 r
.04336 .89664 m .04742 .89941 L .05089 .90396 L p F P
0 g
s
.335 .679 .978 r
.08948 .92356 m .09073 .92366 L .08693 .92106 L p F P
0 g
s
.335 .679 .978 r
.08693 .92106 m .08513 .92093 L .08948 .92356 L p F P
0 g
s
.499 .43 .71 r
.5728 .81039 m .57188 .807 L .57642 .80826 L closepath p F P
0 g
s
.875 .721 .687 r
.22502 .78752 m .22556 .78641 L .22332 .78506 L closepath p F P
0 g
s
.878 .717 .679 r
.2216 .78248 m .22398 .77736 L p .22556 .78641 L F P
0 g
s
.878 .717 .679 r
.22556 .78641 m .22332 .78506 L .2216 .78248 L p F P
0 g
s
.455 .501 .817 r
.73929 .73024 m .73804 .72992 L .73874 .72899 L closepath p F P
0 g
s
.467 .517 .826 r
.73804 .72992 m .73874 .72899 L .7364 .72386 L p F P
0 g
s
.815 .728 .768 r
.20602 .86701 m .20622 .86678 L .20275 .86226 L p F P
0 g
s
.815 .728 .768 r
.20275 .86226 m .20072 .86463 L .20602 .86701 L p F P
0 g
s
.823 .736 .769 r
.20072 .86463 m .20602 .86701 L .19953 .87443 L p F P
0 g
s
.91 .722 .635 r
.22068 .73271 m .21991 .735 L .22395 .73795 L p F P
0 g
s
.907 .729 .65 r
.21991 .735 m .22395 .73795 L .22167 .74402 L p F P
0 g
s
.326 .231 .591 r
.57641 .71977 m .57414 .72181 L .57501 .72808 L p F P
0 g
s
0 0 0 r
.58801 .68091 m .58907 .67958 L .58976 .67819 L closepath p F P
0 g
s
.827 .723 .749 r
.21184 .85034 m .21455 .84683 L .2111 .84208 L p F P
0 g
s
.297 .219 .598 r
.77561 .84274 m .77947 .83903 L .77705 .83394 L p F P
0 g
s
.267 .176 .562 r
.77947 .83903 m .77561 .84274 L .77643 .84886 L p F P
0 g
s
.293 .194 .567 r
.7759 .84934 m .77643 .84886 L .77561 .84274 L p F P
0 g
s
.77 .769 .853 r
.156 .91463 m .14899 .91947 L .14535 .91621 L p F P
0 g
s
.89 .725 .67 r
.22081 .75924 m .22513 .76206 L .2224 .7683 L p F P
0 g
s
.89 .721 .665 r
.22513 .76206 m .22081 .75924 L .2234 .75305 L p F P
0 g
s
.789 .987 .893 r
.59834 .66724 m .60735 .66016 L .60408 .66524 L p F P
0 g
s
.737 .879 .946 r
.60986 .65857 m .60735 .66016 L .60408 .66524 L p F P
0 g
s
.737 .879 .946 r
.60408 .66524 m .61274 .66059 L .60986 .65857 L p F P
0 g
s
.49 .9 .804 r
.73482 .91032 m .72749 .91527 L p .72279 .91639 L F P
0 g
s
.473 .873 .704 r
.72749 .91527 m .73482 .91032 L .737 .90935 L closepath p F P
0 g
s
.501 .432 .712 r
.57491 .81798 m .5728 .81039 L .57642 .80826 L p F P
0 g
s
.524 .442 .706 r
.5728 .81039 m .57491 .81798 L .57441 .81823 L p F P
0 g
s
.407 .419 .76 r
.76647 .77161 m .76326 .76999 L .76513 .76781 L closepath p F P
0 g
s
.421 .439 .773 r
.76346 .76331 m .75961 .76159 L p .76326 .76999 L F P
0 g
s
.421 .439 .773 r
.76326 .76999 m .76513 .76781 L .76346 .76331 L p F P
0 g
s
.588 .667 .893 r
.6645 .91956 m .65271 .92141 L .64979 .91682 L p F P
0 g
s
.863 .721 .703 r
.22204 .79291 m .22502 .78752 L .22332 .78506 L p F P
0 g
s
0 0 0 r
.74853 .90012 m .75103 .89761 L .74914 .89904 L closepath p F P
0 g
s
0 0 .009 r
.74914 .89904 m .75103 .89761 L .75709 .89025 L p F P
0 g
s
.062 0 .176 r
.75709 .89025 m .75919 .88866 L .75975 .88601 L closepath p F P
0 g
s
.492 .564 .857 r
.70617 .6973 m .71266 .69803 L .70979 .69247 L p F P
0 g
s
.492 .564 .857 r
.70979 .69247 m .70934 .69242 L .70617 .6973 L p F P
0 g
s
.405 .321 .648 r
.57722 .74115 m .5714 .7457 L .57599 .74992 L p F P
0 g
s
.41 .311 .631 r
.57633 .73628 m .57722 .74115 L .5714 .7457 L p F P
0 g
s
.41 .311 .631 r
.5753 .7351 m .57633 .73628 L p .5714 .7457 L F P
0 g
s
.524 .45 .714 r
.57501 .81833 m .57441 .81823 L .57491 .81798 L closepath p F P
0 g
s
.864 .723 .705 r
.21841 .79945 m .22315 .80209 L .21943 .80866 L p F P
0 g
s
.861 .719 .704 r
.22315 .80209 m .21841 .79945 L .22204 .79291 L p F P
0 g
s
.44 .485 .809 r
.748 .73269 m .74452 .73753 L .75394 .74048 L p F P
0 g
s
.44 .48 .804 r
.74452 .73753 m .75394 .74048 L .75023 .74536 L p F P
0 g
s
.446 .494 .815 r
.73929 .73024 m .748 .73269 L .74452 .73753 L p F P
0 g
s
.547 .51 .767 r
.5906 .86658 m .5905 .86631 L .59108 .86633 L closepath p F P
0 g
s
.554 .516 .767 r
.5906 .86658 m .59108 .86633 L p .59539 .87454 L F P
0 g
s
.548 .503 .758 r
.59108 .86633 m .5905 .86631 L .58756 .85807 L p F P
0 g
s
.529 .753 .978 r
.09073 .92366 m .10131 .92228 L .10507 .92502 L p F P
0 g
s
.54 .756 .976 r
.10131 .92228 m .09073 .92366 L .08693 .92106 L p F P
0 g
s
.585 .609 .843 r
.64331 .91231 m .63509 .91319 L .63212 .90765 L p F P
0 g
s
.428 .344 .66 r
.57139 .76125 m .57095 .75911 L .57261 .76036 L closepath p F P
0 g
s
.151 .028 .446 r
.58456 .69287 m .58069 .69707 L .58081 .70253 L p F P
0 g
s
.179 .049 .455 r
.5795 .70387 m .58081 .70253 L .58069 .69707 L p F P
0 g
s
.069 0 .345 r
.58069 .69707 m .58456 .69287 L .58553 .68711 L p F P
0 g
s
0 0 .089 r
.58907 .67958 m .58801 .68091 L .58553 .68711 L p F P
0 g
s
.415 .436 .773 r
.76346 .76331 m .75961 .76159 L .76182 .7589 L closepath p F P
0 g
s
.428 .455 .785 r
.76048 .75545 m .75526 .75338 L p .75961 .76159 L F P
0 g
s
.428 .455 .785 r
.75961 .76159 m .76182 .7589 L .76048 .75545 L p F P
0 g
s
.836 .731 .748 r
.2067 .84788 m .21184 .85034 L .2064 .85745 L p F P
0 g
s
.827 .723 .749 r
.2111 .84208 m .2067 .84788 L .21184 .85034 L p F P
0 g
s
.561 .528 .776 r
.59539 .87454 m .60528 .87458 L p .60155 .88227 L F P
0 g
s
.555 .523 .775 r
.60528 .87458 m .59539 .87454 L .60366 .8704 L closepath p F P
0 g
s
.554 .516 .767 r
.60222 .86666 m .60366 .8704 L .59539 .87454 L p F P
0 g
s
.554 .516 .767 r
.59108 .86633 m .60222 .86666 L p .59539 .87454 L F P
0 g
s
.443 .494 .817 r
.748 .73269 m .73929 .73024 L .73874 .72899 L p F P
0 g
s
.566 .567 .813 r
.61558 .8987 m .61438 .89613 L .62111 .89583 L closepath p F P
0 g
s
.519 .604 .878 r
.68391 .68084 m .69197 .68109 L .68909 .67603 L p F P
0 g
s
.519 .604 .878 r
.68909 .67603 m .68678 .67599 L .68391 .68084 L p F P
0 g
s
.52 .611 .884 r
.67712 .67593 m .68678 .67599 L .68391 .68084 L p F P
0 g
s
.433 .465 .793 r
.75023 .74536 m .75752 .74793 L p .75526 .75338 L F P
0 g
s
.429 .466 .796 r
.75023 .74536 m .75752 .74793 L .75457 .74071 L p F P
0 g
s
.429 .466 .796 r
.75457 .74071 m .75394 .74048 L .75023 .74536 L p F P
0 g
s
.512 .443 .715 r
.57491 .81798 m .58431 .81255 L p .58599 .82069 L F P
0 g
s
.512 .443 .715 r
.58599 .82069 m .57501 .81833 L .57491 .81798 L p F P
0 g
s
.501 .432 .712 r
.58361 .81015 m .58431 .81255 L .57491 .81798 L p F P
0 g
s
.501 .432 .712 r
.57642 .80826 m .58361 .81015 L p .57491 .81798 L F P
0 g
s
.51 .447 .722 r
.57718 .82574 m .57501 .81833 L .58599 .82069 L closepath p F P
0 g
s
.824 .735 .766 r
.19953 .87443 m .19457 .88021 L .19105 .87601 L p F P
0 g
s
.824 .735 .766 r
.19105 .87601 m .19444 .87198 L .19953 .87443 L p F P
0 g
s
.823 .736 .769 r
.19953 .87443 m .19444 .87198 L .20072 .86463 L p F P
0 g
s
.633 .087 0 r
.05501 .90669 m .05533 .90701 L .05145 .90451 L p F P
0 g
s
.633 .087 0 r
.05145 .90451 m .05089 .90396 L .05501 .90669 L p F P
0 g
s
.423 .452 .785 r
.76048 .75545 m .75526 .75338 L .75822 .74965 L closepath p F P
0 g
s
.433 .465 .793 r
.75752 .74793 m .75822 .74965 L .75526 .75338 L p F P
0 g
s
.549 .511 .766 r
.60222 .86666 m .59108 .86633 L .60034 .86159 L closepath p F P
0 g
s
.548 .503 .758 r
.59915 .85836 m .60034 .86159 L .59108 .86633 L p F P
0 g
s
.548 .503 .758 r
.58823 .85772 m .59915 .85836 L p .59108 .86633 L F P
0 g
s
.548 .503 .758 r
.58756 .85807 m .58823 .85772 L p .59108 .86633 L F P
0 g
s
.352 .315 .678 r
.77908 .81314 m .77581 .80981 L .77774 .80783 L closepath p F P
0 g
s
.368 .341 .697 r
.77578 .80061 m .77562 .80048 L p .77581 .80981 L F P
0 g
s
.368 .341 .697 r
.77581 .80981 m .77774 .80783 L .77578 .80061 L p F P
0 g
s
.857 .722 .713 r
.21964 .81922 m .22044 .81786 L .21757 .81628 L closepath p F P
0 g
s
.859 .72 .707 r
.21621 .81432 m .21943 .80866 L p .22044 .81786 L F P
0 g
s
.859 .72 .707 r
.22044 .81786 m .21757 .81628 L .21621 .81432 L p F P
0 g
s
.849 .726 .728 r
.21155 .83146 m .2165 .834 L .21194 .84084 L p F P
0 g
s
.845 .722 .728 r
.2165 .834 m .21155 .83146 L .21605 .82464 L p F P
0 g
s
.925 .728 .618 r
.22175 .72906 m .22068 .73271 L .21717 .72865 L p F P
0 g
s
.925 .728 .618 r
.21717 .72865 m .21795 .72602 L .22175 .72906 L p F P
0 g
s
.929 .72 .6 r
.22175 .72906 m .21795 .72602 L .21943 .72021 L p F P
0 g
s
.296 .22 .599 r
.78221 .82892 m .77705 .83394 L .77947 .83903 L p F P
0 g
s
.321 .258 .63 r
.77705 .83394 m .78221 .82892 L .77904 .82404 L p F P
0 g
s
.77 .769 .853 r
.14535 .91621 m .15101 .9122 L .156 .91463 L p F P
0 g
s
.762 .766 .856 r
.15659 .90831 m .15101 .9122 L .156 .91463 L p F P
0 g
s
.762 .766 .856 r
.156 .91463 m .16021 .91178 L .15659 .90831 L p F P
0 g
s
.443 .494 .817 r
.73874 .72899 m .74139 .7251 L p .748 .73269 L F P
0 g
s
.451 .508 .826 r
.73874 .72899 m .7364 .72386 L .74139 .7251 L closepath p F P
0 g
s
.497 .576 .865 r
.69621 .68863 m .69752 .68636 L p .70934 .69242 L F P
0 g
s
.503 .586 .871 r
.69621 .68863 m .69484 .68618 L .69752 .68636 L closepath p F P
0 g
s
.434 .355 .669 r
.57261 .76036 m .57139 .76125 L .57292 .76824 L p F P
0 g
s
.54 .498 .757 r
.58756 .85807 m .58742 .85766 L .58823 .85772 L closepath p F P
0 g
s
.882 .723 .68 r
.22398 .77736 m .2216 .78248 L .21815 .77767 L p F P
0 g
s
.882 .723 .68 r
.21815 .77767 m .21958 .77458 L .22398 .77736 L p F P
0 g
s
.884 .721 .675 r
.22398 .77736 m .21958 .77458 L .2224 .7683 L p F P
0 g
s
.566 .54 .785 r
.60155 .88227 m .60833 .88213 L p .61003 .88938 L F P
0 g
s
.561 .535 .784 r
.60833 .88213 m .60155 .88227 L .60725 .87947 L closepath p F P
0 g
s
.561 .528 .776 r
.60528 .87458 m .60725 .87947 L .60155 .88227 L p F P
0 g
s
.541 .491 .749 r
.58823 .85772 m .58742 .85766 L .58473 .84975 L p F P
0 g
s
.52 .455 .723 r
.57718 .82574 m .58599 .82069 L p .5856 .83022 L F P
0 g
s
.52 .455 .723 r
.5856 .83022 m .57812 .82893 L .57718 .82574 L p F P
0 g
s
0 .189 .604 r
.05533 .90701 m .06114 .91051 L .06535 .9132 L p F P
0 g
s
0 .213 .635 r
.06114 .91051 m .05533 .90701 L .05145 .90451 L p F P
0 g
s
.474 .54 .844 r
.71608 .70466 m .71665 .70375 L p .72576 .71061 L F P
0 g
s
.48 .552 .852 r
.71608 .70466 m .71554 .7036 L .71665 .70375 L closepath p F P
0 g
s
0 0 .005 r
.75919 .88866 m .75709 .89025 L .75103 .89761 L p F P
0 g
s
.897 .729 .665 r
.21923 .75016 m .2234 .75305 L .22081 .75924 L p F P
0 g
s
.898 .725 .659 r
.2234 .75305 m .21923 .75016 L .22167 .74402 L p F P
0 g
s
.612 .879 .991 r
.71045 .92118 m .7083 .9225 L p .69657 .92382 L F P
0 g
s
.637 .899 .985 r
.7083 .9225 m .71045 .92118 L .71104 .92147 L closepath p F P
0 g
s
.844 .722 .729 r
.21605 .82464 m .21964 .81922 L .21757 .81628 L p F P
0 g
s
.518 .46 .731 r
.57956 .83361 m .57812 .82893 L .5856 .83022 L closepath p F P
0 g
s
.746 .786 .885 r
.13424 .92266 m .13475 .92236 L .13204 .92084 L closepath p F P
0 g
s
.702 .779 .911 r
.13204 .92084 m .13424 .92266 L p .11959 .92456 L F P
0 g
s
.541 .491 .749 r
.58473 .84975 m .58653 .84879 L p .58823 .85772 L F P
0 g
s
.533 .485 .748 r
.58473 .84975 m .58433 .84857 L .58653 .84879 L closepath p F P
0 g
s
.527 .467 .732 r
.57956 .83361 m .5856 .83022 L p .58572 .8396 L F P
0 g
s
.527 .467 .732 r
.58572 .8396 m .58123 .839 L .57956 .83361 L p F P
0 g
s
.567 .558 .803 r
.62111 .89583 m .61438 .89613 L .61136 .88933 L p F P
0 g
s
.535 .479 .74 r
.58653 .84879 m .58433 .84857 L .58207 .84161 L p F P
0 g
s
.749 .785 .883 r
.14169 .91297 m .14535 .91621 L .13475 .92236 L p F P
0 g
s
.749 .785 .883 r
.13055 .9196 m .14169 .91297 L p .13475 .92236 L F P
0 g
s
.749 .785 .883 r
.13475 .92236 m .13204 .92084 L .13055 .9196 L p F P
0 g
s
.522 .615 .886 r
.68678 .67599 m .67712 .67593 L .67424 .67114 L p F P
0 g
s
.526 .473 .74 r
.58207 .84161 m .58123 .839 L .58572 .8396 L closepath p F P
0 g
s
.535 .479 .74 r
.58207 .84161 m .58572 .8396 L p .58653 .84879 L F P
0 g
s
.807 .738 .788 r
.19294 .88187 m .19457 .88021 L .19105 .87601 L p F P
0 g
s
.542 .499 .758 r
.59915 .85836 m .58823 .85772 L .59725 .85301 L closepath p F P
0 g
s
.541 .491 .749 r
.59606 .84965 m .59725 .85301 L .58823 .85772 L p F P
0 g
s
.541 .491 .749 r
.58653 .84879 m .59606 .84965 L p .58823 .85772 L F P
0 g
s
.863 .721 .703 r
.22332 .78506 m .22094 .78371 L p .22204 .79291 L F P
0 g
s
.865 .717 .696 r
.22332 .78506 m .2216 .78248 L .22094 .78371 L closepath p F P
0 g
s
.571 .92 .724 r
.73482 .91032 m .737 .90935 L .74185 .90578 L p F P
0 g
s
.543 .642 .898 r
.65948 .6672 m .67136 .66646 L p .67044 .67128 L F P
0 g
s
.553 .647 .897 r
.67136 .66646 m .65948 .6672 L .65659 .66281 L p F P
0 g
s
.789 .76 .827 r
.16763 .90577 m .16021 .91178 L .15659 .90831 L p F P
0 g
s
.176 .01 .403 r
.76894 .87262 m .7699 .8718 L .77092 .86576 L p F P
0 g
s
.165 0 .396 r
.77681 .86064 m .77092 .86576 L .7699 .8718 L p F P
0 g
s
.223 .083 .47 r
.77092 .86576 m .77681 .86064 L .77682 .85486 L p F P
0 g
s
.479 .554 .855 r
.71665 .70375 m .71554 .7036 L .71266 .69803 L p F P
0 g
s
.816 .748 .788 r
.18773 .87946 m .19294 .88187 L .18548 .88956 L p F P
0 g
s
.807 .738 .788 r
.19105 .87601 m .18773 .87946 L .19294 .88187 L p F P
0 g
s
.621 .717 .915 r
.62728 .65927 m .63901 .65647 L .6419 .6603 L p F P
0 g
s
.637 .734 .919 r
.63901 .65647 m .62728 .65927 L .62439 .65606 L p F P
0 g
s
.682 .779 .925 r
.61274 .66059 m .62439 .65606 L .62728 .65927 L p F P
0 g
s
.642 .778 .946 r
.10507 .92502 m .11586 .92167 L .11959 .92456 L p F P
0 g
s
.648 .779 .943 r
.11586 .92167 m .10507 .92502 L .10131 .92228 L p F P
0 g
s
.605 .74 .941 r
.66737 .92348 m .67917 .92113 L .68199 .92435 L p F P
0 g
s
.601 .694 .909 r
.67633 .91751 m .67917 .92113 L .66737 .92348 L p F P
0 g
s
.601 .694 .909 r
.66632 .91924 m .67633 .91751 L p .66737 .92348 L F P
0 g
s
.601 .694 .909 r
.66737 .92348 m .66488 .92008 L .66632 .91924 L p F P
0 g
s
.479 .402 .691 r
.57731 .78675 m .5726 .78485 L .57627 .78255 L closepath p F P
0 g
s
.481 .393 .68 r
.57452 .77532 m .57627 .78255 L .5726 .78485 L p F P
0 g
s
.868 .726 .703 r
.21739 .79022 m .22204 .79291 L .21841 .79945 L p F P
0 g
s
.863 .721 .703 r
.22094 .78371 m .21739 .79022 L .22204 .79291 L p F P
0 g
s
.936 .729 .598 r
.21577 .71711 m .21943 .72021 L .21795 .72602 L p F P
0 g
s
.94 .719 .576 r
.21943 .72021 m .21577 .71711 L .21698 .71139 L p F P
0 g
s
.836 .73 .748 r
.2064 .85745 m .20275 .86226 L .19926 .85785 L p F P
0 g
s
.836 .73 .748 r
.19926 .85785 m .20142 .85495 L .2064 .85745 L p F P
0 g
s
.836 .731 .748 r
.2064 .85745 m .20142 .85495 L .2067 .84788 L p F P
0 g
s
.234 .634 .958 r
.07284 .91725 m .08084 .91828 L .08513 .92093 L p F P
0 g
s
.26 .644 .964 r
.08084 .91828 m .07284 .91725 L .06899 .91472 L p F P
0 g
s
.259 .142 .524 r
.77643 .84886 m .7759 .84934 L .77682 .85486 L p F P
0 g
s
.702 .779 .911 r
.11959 .92456 m .1299 .91989 L .13204 .92084 L p F P
0 g
s
.708 .781 .909 r
.1299 .91989 m .11959 .92456 L .11586 .92167 L p F P
0 g
s
.712 .808 .925 r
.62439 .65606 m .61274 .66059 L .60986 .65857 L p F P
0 g
s
.673 .91 .976 r
.71045 .92118 m .71104 .92147 L .72279 .91639 L p F P
0 g
s
0 0 0 r
.74185 .90578 m .74697 .90212 L .74853 .90012 L closepath p F P
0 g
s
.571 .92 .724 r
.74185 .90578 m .74697 .90212 L p .73482 .91032 L F P
0 g
s
.789 .76 .827 r
.15659 .90831 m .16259 .90334 L .16763 .90577 L p F P
0 g
s
.782 .757 .831 r
.16797 .89898 m .16259 .90334 L .16763 .90577 L p F P
0 g
s
.782 .757 .831 r
.16763 .90577 m .17155 .90266 L .16797 .89898 L p F P
0 g
s
.376 .375 .73 r
.77092 .78466 m .77278 .78245 L p .77455 .79137 L F P
0 g
s
.376 .375 .73 r
.77455 .79137 m .77261 .79005 L .77092 .78466 L p F P
0 g
s
.386 .393 .745 r
.77092 .78466 m .76952 .78047 L .77278 .78245 L closepath p F P
0 g
s
.229 .12 .515 r
.58081 .70253 m .5795 .70387 L .58053 .70906 L p F P
0 g
s
.377 .375 .73 r
.77343 .79265 m .77261 .79005 L .77455 .79137 L closepath p F P
0 g
s
.817 .748 .787 r
.18548 .88956 m .183 .89214 L .17945 .88823 L p F P
0 g
s
.817 .748 .787 r
.17945 .88823 m .18053 .88709 L .18548 .88956 L p F P
0 g
s
.816 .748 .788 r
.18548 .88956 m .18053 .88709 L .18773 .87946 L p F P
0 g
s
.341 .253 .609 r
.57895 .72454 m .57501 .72808 L .57602 .73451 L p F P
0 g
s
.326 .231 .591 r
.57501 .72808 m .57895 .72454 L .57641 .71977 L p F P
0 g
s
.371 .274 .614 r
.5753 .7351 m .57602 .73451 L .57501 .72808 L p F P
0 g
s
.572 .668 .903 r
.65659 .66281 m .65097 .66348 L .65393 .65885 L closepath p F P
0 g
s
.571 .686 .918 r
.65371 .65852 m .65393 .65885 L .65097 .66348 L p F P
0 g
s
.571 .686 .918 r
.6419 .6603 m .65371 .65852 L p .65097 .66348 L F P
0 g
s
.434 .355 .669 r
.57292 .76824 m .57836 .76429 L .57261 .76036 L p F P
0 g
s
.43 .356 .672 r
.57999 .75483 m .57261 .76036 L .57836 .76429 L p F P
0 g
s
.434 .344 .655 r
.57958 .75294 m .57999 .75483 L .57261 .76036 L p F P
0 g
s
.434 .344 .655 r
.57599 .74992 m .57958 .75294 L p .57261 .76036 L F P
0 g
s
.361 .351 .714 r
.77455 .79137 m .77343 .79265 L .77571 .80038 L p F P
0 g
s
.38 .364 .716 r
.77562 .80048 m .77571 .80038 L .77343 .79265 L p F P
0 g
s
0 0 0 r
.75103 .89761 m .75779 .89251 L p .74697 .90212 L F P
0 g
s
0 0 0 r
.74697 .90212 m .74853 .90012 L .75103 .89761 L p F P
0 g
s
0 0 .005 r
.75103 .89761 m .75779 .89251 L .75919 .88866 L p F P
0 g
s
.386 .393 .745 r
.77278 .78245 m .76952 .78047 L .76815 .77638 L p F P
0 g
s
0 0 .085 r
.59224 .67558 m .58907 .67958 L .58812 .68384 L p F P
0 g
s
0 0 .089 r
.58553 .68711 m .58812 .68384 L .58907 .67958 L p F P
0 g
s
.474 .54 .844 r
.71665 .70375 m .72772 .70556 L p .72576 .71061 L F P
0 g
s
.472 .545 .85 r
.71665 .70375 m .72772 .70556 L .72484 .69982 L p F P
0 g
s
.472 .545 .85 r
.72484 .69982 m .71954 .69897 L .71665 .70375 L p F P
0 g
s
.479 .554 .855 r
.71266 .69803 m .71954 .69897 L .71665 .70375 L p F P
0 g
s
.501 .589 .874 r
.69752 .68636 m .69484 .68618 L .69197 .68109 L p F P
0 g
s
.804 .753 .806 r
.1771 .89751 m .17155 .90266 L .16797 .89898 L p F P
0 g
s
.804 .753 .806 r
.16797 .89898 m .1721 .89506 L .1771 .89751 L p F P
0 g
s
.797 .749 .809 r
.17945 .88823 m .1721 .89506 L .1771 .89751 L p F P
0 g
s
.797 .749 .809 r
.1771 .89751 m .183 .89214 L .17945 .88823 L p F P
0 g
s
.386 .393 .745 r
.76815 .77638 m .77034 .77369 L p .77278 .78245 L F P
0 g
s
.395 .411 .759 r
.76815 .77638 m .76647 .77161 L .77034 .77369 L closepath p F P
0 g
s
.89 .728 .675 r
.21812 .76547 m .2224 .7683 L .21958 .77458 L p F P
0 g
s
.89 .725 .67 r
.2224 .7683 m .21812 .76547 L .22081 .75924 L p F P
0 g
s
.863 .723 .707 r
.21943 .80866 m .21621 .81432 L .21275 .80956 L p F P
0 g
s
.863 .723 .707 r
.21275 .80956 m .21476 .806 L .21943 .80866 L p F P
0 g
s
.864 .723 .705 r
.21943 .80866 m .21476 .806 L .21841 .79945 L p F P
0 g
s
.567 .548 .792 r
.61136 .88933 m .61003 .88938 L .61116 .88884 L closepath p F P
0 g
s
.566 .54 .785 r
.60833 .88213 m .61116 .88884 L .61003 .88938 L p F P
0 g
s
.905 .733 .658 r
.21764 .74108 m .22167 .74402 L .21923 .75016 L p F P
0 g
s
.907 .729 .65 r
.22167 .74402 m .21764 .74108 L .21991 .735 L p F P
0 g
s
.452 .371 .674 r
.57292 .76824 m .57836 .76429 L p .57563 .77454 L F P
0 g
s
.452 .371 .674 r
.57563 .77454 m .57414 .77367 L .57292 .76824 L p F P
0 g
s
.308 .223 .594 r
.58195 .71441 m .57641 .71977 L .57895 .72454 L p F P
0 g
s
.282 .185 .563 r
.58172 .71245 m .58053 .70906 L p .57641 .71977 L F P
0 g
s
.282 .185 .563 r
.57641 .71977 m .58195 .71441 L .58172 .71245 L p F P
0 g
s
.541 .629 .888 r
.67424 .67114 m .67044 .67128 L .67239 .66811 L closepath p F P
0 g
s
.543 .642 .898 r
.67136 .66646 m .67239 .66811 L .67044 .67128 L p F P
0 g
s
.362 .337 .696 r
.77578 .80061 m .77562 .80048 L .77571 .80038 L closepath p F P
0 g
s
.849 .726 .728 r
.20764 .83745 m .21155 .83146 L p .21194 .84084 L F P
0 g
s
.849 .726 .728 r
.21194 .84084 m .209 .83929 L .20764 .83745 L p F P
0 g
s
.846 .728 .733 r
.2111 .84208 m .21194 .84084 L .209 .83929 L closepath p F P
0 g
s
.851 .728 .727 r
.21116 .82207 m .21605 .82464 L .21155 .83146 L p F P
0 g
s
.844 .722 .729 r
.21559 .81527 m .21116 .82207 L .21605 .82464 L p F P
0 g
s
.844 .722 .729 r
.21757 .81628 m .21559 .81527 L p .21605 .82464 L F P
0 g
s
.231 .122 .517 r
.78116 .84434 m .77643 .84886 L .77699 .85471 L p F P
0 g
s
.267 .176 .562 r
.77643 .84886 m .78116 .84434 L .77947 .83903 L p F P
0 g
s
.259 .142 .524 r
.77682 .85486 m .77699 .85471 L .77643 .84886 L p F P
0 g
s
.918 .732 .636 r
.21991 .735 m .22068 .73271 L .21717 .72865 L p F P
0 g
s
.347 .327 .694 r
.77571 .80038 m .77988 .79561 L p .78039 .80489 L F P
0 g
s
.347 .327 .694 r
.78039 .80489 m .77578 .80061 L .77571 .80038 L p F P
0 g
s
.361 .351 .714 r
.77571 .80038 m .77988 .79561 L .77455 .79137 L p F P
0 g
s
.45 .508 .827 r
.74139 .7251 m .7364 .72386 L .7338 .71819 L p F P
0 g
s
.348 .327 .694 r
.77774 .80783 m .77578 .80061 L .78039 .80489 L closepath p F P
0 g
s
.911 .516 .237 r
.03692 .88902 m .033 .88619 L .03145 .88112 L p F P
0 g
s
.394 .411 .759 r
.77034 .77369 m .76647 .77161 L .76513 .76781 L p F P
0 g
s
.535 .487 .749 r
.59606 .84965 m .58653 .84879 L .59435 .84461 L closepath p F P
0 g
s
.535 .479 .74 r
.59297 .84051 m .59435 .84461 L .58653 .84879 L p F P
0 g
s
.535 .479 .74 r
.58572 .8396 m .59297 .84051 L p .58653 .84879 L F P
0 g
s
.608 .768 .957 r
.69381 .92139 m .68199 .92435 L .67917 .92113 L p F P
0 g
s
.613 .803 .973 r
.68199 .92435 m .69381 .92139 L .69657 .92382 L p F P
0 g
s
.593 .691 .91 r
.65371 .65852 m .6419 .6603 L .63901 .65647 L p F P
0 g
s
.82 .732 .768 r
.20072 .86463 m .20275 .86226 L .19926 .85785 L p F P
0 g
s
.832 .728 .749 r
.2067 .84788 m .2111 .84208 L .209 .83929 L p F P
0 g
s
.501 .434 .713 r
.58361 .81015 m .57642 .80826 L .58214 .80488 L closepath p F P
0 g
s
.502 .426 .703 r
.58047 .79885 m .58214 .80488 L .57642 .80826 L p F P
0 g
s
.502 .426 .703 r
.57852 .79824 m .58047 .79885 L p .57642 .80826 L F P
0 g
s
.857 .402 .076 r
.04336 .89664 m .03936 .89385 L .03692 .88902 L p F P
0 g
s
.856 .4 .065 r
.033 .88619 m .03692 .88902 L .03936 .89385 L p F P
0 g
s
0 0 .306 r
.58812 .68384 m .58553 .68711 L .58456 .69287 L p F P
0 g
s
.585 .609 .843 r
.63212 .90765 m .64391 .90664 L p .64331 .91231 L F P
0 g
s
.57 .59 .834 r
.64095 .90105 m .64391 .90664 L .63212 .90765 L p F P
0 g
s
.57 .59 .834 r
.63563 .90139 m .64095 .90105 L p .63212 .90765 L F P
0 g
s
.57 .59 .834 r
.63212 .90765 m .63039 .90426 L .63563 .90139 L p F P
0 g
s
.87 .725 .699 r
.22094 .78371 m .2216 .78248 L .21815 .77767 L p F P
0 g
s
.612 .879 .991 r
.69657 .92382 m .70836 .92002 L .71045 .92118 L p F P
0 g
s
.616 .84 .985 r
.70836 .92002 m .69657 .92382 L .69381 .92139 L p F P
0 g
s
0 .411 .813 r
.06535 .9132 m .06899 .91472 L .06514 .91213 L p F P
0 g
s
0 .411 .813 r
.06514 .91213 m .06114 .91051 L .06535 .9132 L p F P
0 g
s
.846 .719 .724 r
.21757 .81628 m .21621 .81432 L .21559 .81527 L closepath p F P
0 g
s
.394 .411 .759 r
.76513 .76781 m .76723 .76512 L p .77034 .77369 L F P
0 g
s
.403 .428 .772 r
.76513 .76781 m .76346 .76331 L .76723 .76512 L closepath p F P
0 g
s
.567 .558 .803 r
.61136 .88933 m .62313 .88902 L p .62111 .89583 L F P
0 g
s
.556 .541 .794 r
.62082 .88376 m .62313 .88902 L .61136 .88933 L p F P
0 g
s
.556 .541 .794 r
.61136 .88933 m .61116 .88884 L .62082 .88376 L p F P
0 g
s
.588 .667 .893 r
.64979 .91682 m .66161 .91523 L .6645 .91956 L p F P
0 g
s
.581 .647 .88 r
.66161 .91523 m .64979 .91682 L .64686 .91192 L p F P
0 g
s
.644 .889 .984 r
.70836 .92002 m .71723 .91673 L .71045 .92118 L closepath p F P
0 g
s
.673 .91 .976 r
.72017 .9156 m .71723 .91673 L .71045 .92118 L p F P
0 g
s
.673 .91 .976 r
.72279 .91639 m .72017 .9156 L p .71045 .92118 L F P
0 g
s
.82 .732 .768 r
.19926 .85785 m .19561 .86217 L .20072 .86463 L p F P
0 g
s
.829 .741 .767 r
.19561 .86217 m .20072 .86463 L .19444 .87198 L p F P
0 g
s
.554 .54 .793 r
.62011 .88215 m .62082 .88376 L .61116 .88884 L p F P
0 g
s
.554 .54 .793 r
.61116 .88884 m .60833 .88213 L .62011 .88215 L p F P
0 g
s
.113 0 .317 r
.76873 .87535 m .7699 .8718 L .76894 .87262 L closepath p F P
0 g
s
.872 .729 .702 r
.21641 .78098 m .22094 .78371 L .21739 .79022 L p F P
0 g
s
.87 .725 .699 r
.21815 .77767 m .21641 .78098 L .22094 .78371 L p F P
0 g
s
0 0 0 r
.76369 .88501 m .75919 .88866 L .75779 .89251 L p F P
0 g
s
0 0 .141 r
.76761 .87819 m .76369 .88501 L .75919 .88866 L p F P
0 g
s
.317 .257 .631 r
.78112 .82197 m .77904 .82404 L .78221 .82892 L p F P
0 g
s
.337 .288 .655 r
.77904 .82404 m .78112 .82197 L .77955 .81503 L p F P
0 g
s
.447 .373 .68 r
.57452 .77532 m .57414 .77367 L .57563 .77454 L closepath p F P
0 g
s
.351 .685 .98 r
.08513 .92093 m .08693 .92106 L .08312 .91841 L p F P
0 g
s
.351 .685 .98 r
.08312 .91841 m .08084 .91828 L .08513 .92093 L p F P
0 g
s
.336 .305 .676 r
.77774 .80783 m .78039 .80489 L p .78019 .81434 L F P
0 g
s
.336 .305 .676 r
.78019 .81434 m .77908 .81314 L .77774 .80783 L p F P
0 g
s
.384 .295 .631 r
.57633 .73628 m .5753 .7351 L .57602 .73451 L closepath p F P
0 g
s
.403 .428 .772 r
.76723 .76512 m .76346 .76331 L .76182 .7589 L p F P
0 g
s
.752 .239 0 r
.05089 .90396 m .04684 .90119 L .04336 .89664 L p F P
0 g
s
.747 .233 0 r
.03936 .89385 m .04336 .89664 L .04684 .90119 L p F P
0 g
s
.7 .779 .912 r
.13204 .92084 m .13055 .9196 L .1299 .91989 L closepath p F P
0 g
s
.897 .732 .67 r
.21666 .75635 m .22081 .75924 L .21812 .76547 L p F P
0 g
s
.897 .729 .665 r
.22081 .75924 m .21666 .75635 L .21923 .75016 L p F P
0 g
s
.914 .738 .65 r
.21605 .73198 m .21991 .735 L .21764 .74108 L p F P
0 g
s
.918 .732 .636 r
.21717 .72865 m .21605 .73198 L .21991 .735 L p F P
0 g
s
.774 .773 .851 r
.15101 .9122 m .14535 .91621 L .14169 .91297 L p F P
0 g
s
.452 .381 .686 r
.57563 .77454 m .57452 .77532 L .57627 .78255 L p F P
0 g
s
.467 .53 .838 r
.73061 .71153 m .72576 .71061 L .72832 .70676 L closepath p F P
0 g
s
.474 .54 .844 r
.72772 .70556 m .72832 .70676 L .72576 .71061 L p F P
0 g
s
.229 .12 .515 r
.58053 .70906 m .58125 .70833 L .58081 .70253 L p F P
0 g
s
.202 .1 .508 r
.5847 .69831 m .58081 .70253 L .58125 .70833 L p F P
0 g
s
.151 .028 .446 r
.58081 .70253 m .5847 .69831 L .58456 .69287 L p F P
0 g
s
.497 .576 .865 r
.69752 .68636 m .70691 .68715 L p .70934 .69242 L F P
0 g
s
.498 .582 .87 r
.69752 .68636 m .70691 .68715 L .70404 .68187 L p F P
0 g
s
.498 .582 .87 r
.70404 .68187 m .70022 .68158 L .69752 .68636 L p F P
0 g
s
.501 .589 .874 r
.69197 .68109 m .70022 .68158 L .69752 .68636 L p F P
0 g
s
.363 .356 .718 r
.77868 .78651 m .77455 .79137 L .77988 .79561 L p F P
0 g
s
.376 .375 .73 r
.77278 .78245 m .77868 .78651 L .77455 .79137 L p F P
0 g
s
.87 .729 .704 r
.21383 .79675 m .21841 .79945 L .21476 .806 L p F P
0 g
s
.868 .726 .703 r
.21841 .79945 m .21383 .79675 L .21739 .79022 L p F P
0 g
s
.841 .736 .747 r
.20175 .84536 m .2067 .84788 L .20142 .85495 L p F P
0 g
s
.832 .728 .749 r
.207 .83831 m .20175 .84536 L .2067 .84788 L p F P
0 g
s
.832 .728 .749 r
.209 .83929 m .207 .83831 L p .2067 .84788 L F P
0 g
s
.403 .428 .772 r
.76182 .7589 m .76347 .75672 L p .76723 .76512 L F P
0 g
s
.412 .444 .784 r
.76182 .7589 m .76048 .75545 L .76347 .75672 L closepath p F P
0 g
s
.85 .725 .726 r
.21559 .81527 m .21621 .81432 L .21275 .80956 L p F P
0 g
s
.479 .555 .856 r
.71954 .69897 m .71266 .69803 L .70979 .69247 L p F P
0 g
s
.829 .74 .766 r
.19444 .87198 m .19105 .87601 L .18752 .87189 L p F P
0 g
s
.829 .74 .766 r
.18752 .87189 m .18952 .86948 L .19444 .87198 L p F P
0 g
s
.829 .741 .767 r
.19444 .87198 m .18952 .86948 L .19561 .86217 L p F P
0 g
s
.569 .589 .833 r
.63039 .90426 m .62914 .90178 L .63563 .90139 L closepath p F P
0 g
s
.527 .475 .741 r
.59297 .84051 m .58572 .8396 L .59162 .83638 L closepath p F P
0 g
s
.527 .467 .732 r
.58986 .83091 m .59162 .83638 L .58572 .8396 L p F P
0 g
s
.527 .467 .732 r
.5856 .83022 m .58986 .83091 L p .58572 .8396 L F P
0 g
s
.584 .62 .854 r
.64686 .91192 m .64331 .91231 L .64623 .91079 L closepath p F P
0 g
s
.585 .609 .843 r
.64391 .90664 m .64623 .91079 L .64331 .91231 L p F P
0 g
s
.377 .29 .63 r
.57602 .73451 m .58197 .7292 L p .5791 .73954 L F P
0 g
s
.377 .29 .63 r
.5791 .73954 m .57633 .73628 L .57602 .73451 L p F P
0 g
s
.341 .253 .609 r
.57602 .73451 m .58197 .7292 L .57895 .72454 L p F P
0 g
s
.851 .728 .727 r
.21155 .83146 m .20764 .83745 L .20416 .83292 L p F P
0 g
s
.851 .728 .727 r
.20416 .83292 m .20677 .82887 L .21155 .83146 L p F P
0 g
s
.851 .728 .727 r
.21155 .83146 m .20677 .82887 L .21116 .82207 L p F P
0 g
s
.85 .725 .726 r
.21275 .80956 m .21078 .81267 L .21559 .81527 L p F P
0 g
s
.854 .731 .727 r
.21078 .81267 m .21559 .81527 L .21116 .82207 L p F P
0 g
s
.337 .306 .676 r
.77955 .81503 m .77908 .81314 L .78019 .81434 L closepath p F P
0 g
s
.03 0 .268 r
.7699 .8718 m .77573 .86671 L p .76852 .87745 L F P
0 g
s
.03 0 .268 r
.76852 .87745 m .76873 .87535 L .7699 .8718 L p F P
0 g
s
.165 0 .396 r
.7699 .8718 m .77573 .86671 L .77681 .86064 L p F P
0 g
s
.766 .768 .854 r
.15296 .90488 m .14617 .90971 L .15101 .9122 L p F P
0 g
s
.766 .768 .854 r
.15101 .9122 m .15659 .90831 L .15296 .90488 L p F P
0 g
s
.774 .773 .851 r
.14169 .91297 m .14617 .90971 L .15101 .9122 L p F P
0 g
s
.45 .508 .827 r
.7338 .71819 m .73412 .71769 L p .74139 .7251 L F P
0 g
s
.457 .521 .835 r
.7338 .71819 m .7335 .71756 L .73412 .71769 L closepath p F P
0 g
s
.522 .615 .886 r
.67424 .67114 m .68622 .67113 L p .68678 .67599 L F P
0 g
s
.521 .619 .89 r
.68334 .66635 m .68622 .67113 L .67424 .67114 L p F P
0 g
s
.521 .619 .89 r
.67319 .66642 m .68334 .66635 L p .67424 .67114 L F P
0 g
s
.521 .619 .89 r
.67424 .67114 m .67239 .66811 L .67319 .66642 L p F P
0 g
s
.547 .527 .785 r
.61707 .87492 m .62011 .88215 L .60833 .88213 L p F P
0 g
s
.547 .527 .785 r
.61563 .87489 m .61707 .87492 L p .60833 .88213 L F P
0 g
s
.547 .527 .785 r
.60833 .88213 m .60725 .87947 L .61563 .87489 L p F P
0 g
s
.54 .756 .976 r
.08693 .92106 m .09753 .91951 L .10131 .92228 L p F P
0 g
s
.548 .758 .975 r
.09753 .91951 m .08693 .92106 L .08312 .91841 L p F P
0 g
s
.62 .075 0 r
.05089 .90396 m .05145 .90451 L .04757 .9019 L p F P
0 g
s
.62 .075 0 r
.04757 .9019 m .04684 .90119 L .05089 .90396 L p F P
0 g
s
.411 .445 .785 r
.76347 .75672 m .76048 .75545 L .75822 .74965 L p F P
0 g
s
.834 .726 .745 r
.209 .83929 m .20764 .83745 L .207 .83831 L closepath p F P
0 g
s
.315 .273 .651 r
.78019 .81434 m .77955 .81503 L .78112 .82197 L p F P
0 g
s
.601 .694 .908 r
.66488 .92008 m .6645 .91956 L .66632 .91924 L closepath p F P
0 g
s
.456 .523 .838 r
.73412 .71769 m .7335 .71756 L .73061 .71153 L p F P
0 g
s
.568 .566 .812 r
.62614 .89558 m .62111 .89583 L .62528 .8937 L closepath p F P
0 g
s
.567 .558 .803 r
.62313 .88902 m .62528 .8937 L .62111 .89583 L p F P
0 g
s
.888 .731 .681 r
.21958 .77458 m .21815 .77767 L .21467 .77317 L p F P
0 g
s
.888 .731 .681 r
.21467 .77317 m .21533 .77174 L .21958 .77458 L p F P
0 g
s
.89 .728 .675 r
.21958 .77458 m .21533 .77174 L .21812 .76547 L p F P
0 g
s
.811 .742 .788 r
.18773 .87946 m .19105 .87601 L .18752 .87189 L p F P
0 g
s
.452 .381 .686 r
.57627 .78255 m .58246 .7782 L .57563 .77454 L p F P
0 g
s
.449 .382 .69 r
.58324 .76905 m .57563 .77454 L .58246 .7782 L p F P
0 g
s
.452 .371 .674 r
.58279 .76715 m .58324 .76905 L .57563 .77454 L p F P
0 g
s
.452 .371 .674 r
.57836 .76429 m .58279 .76715 L p .57563 .77454 L F P
0 g
s
.369 .289 .634 r
.57722 .74115 m .57633 .73628 L .5791 .73954 L closepath p F P
0 g
s
.931 .736 .618 r
.21795 .72602 m .21717 .72865 L .21361 .72522 L p F P
0 g
s
.931 .736 .618 r
.21361 .72522 m .21429 .72293 L .21795 .72602 L p F P
0 g
s
.936 .729 .598 r
.21795 .72602 m .21429 .72293 L .21577 .71711 L p F P
0 g
s
.553 .647 .897 r
.65659 .66281 m .66849 .66195 L .67136 .66646 L p F P
0 g
s
.55 .658 .907 r
.6656 .65751 m .66849 .66195 L .65659 .66281 L p F P
0 g
s
.55 .658 .907 r
.65408 .65848 m .6656 .65751 L p .65659 .66281 L F P
0 g
s
.55 .658 .907 r
.65659 .66281 m .65393 .65885 L .65408 .65848 L p F P
0 g
s
.468 .394 .691 r
.57627 .78255 m .58246 .7782 L p .58054 .78822 L F P
0 g
s
.468 .394 .691 r
.58054 .78822 m .57731 .78675 L .57627 .78255 L p F P
0 g
s
.904 .737 .665 r
.21522 .74721 m .21923 .75016 L .21666 .75635 L p F P
0 g
s
.905 .733 .658 r
.21923 .75016 m .21522 .74721 L .21764 .74108 L p F P
0 g
s
.708 .781 .909 r
.11586 .92167 m .12481 .91748 L .1299 .91989 L p F P
0 g
s
.7 .78 .913 r
.12685 .91653 m .12481 .91748 L .1299 .91989 L p F P
0 g
s
.7 .78 .913 r
.1299 .91989 m .13055 .9196 L .12685 .91653 L p F P
0 g
s
.546 .526 .784 r
.60725 .87947 m .60528 .87458 L .61563 .87489 L closepath p F P
0 g
s
.822 .751 .785 r
.1827 .877 m .18773 .87946 L .18053 .88709 L p F P
0 g
s
.811 .742 .788 r
.18752 .87189 m .1827 .877 L .18773 .87946 L p F P
0 g
s
.266 .175 .562 r
.78356 .83509 m .77947 .83903 L .78116 .84434 L p F P
0 g
s
.296 .22 .599 r
.78268 .82991 m .78221 .82892 L p .77947 .83903 L F P
0 g
s
.296 .22 .599 r
.77947 .83903 m .78356 .83509 L .78268 .82991 L p F P
0 g
s
.373 .377 .734 r
.77679 .77759 m .77278 .78245 L .77868 .78651 L p F P
0 g
s
.386 .393 .745 r
.77034 .77369 m .77679 .77759 L .77278 .78245 L p F P
0 g
s
.452 .515 .832 r
.73708 .71294 m .73412 .71769 L .74462 .72029 L p F P
0 g
s
.456 .523 .838 r
.73061 .71153 m .73708 .71294 L .73412 .71769 L p F P
0 g
s
.45 .508 .827 r
.73412 .71769 m .74462 .72029 L .74139 .7251 L p F P
0 g
s
.604 .674 .89 r
.66632 .91924 m .6645 .91956 L .66161 .91523 L p F P
0 g
s
.503 .592 .876 r
.70022 .68158 m .69197 .68109 L .68909 .67603 L p F P
0 g
s
.571 .578 .822 r
.63563 .90139 m .62914 .90178 L .62614 .89558 L p F P
0 g
s
.748 .778 .877 r
.14169 .91297 m .13055 .9196 L .12685 .91653 L p F P
0 g
s
.49 .9 .804 r
.72279 .91639 m .73452 .91038 L .73482 .91032 L p F P
0 g
s
.55 .929 .903 r
.73452 .91038 m .72279 .91639 L .72017 .9156 L p F P
0 g
s
.793 .764 .827 r
.16259 .90334 m .15659 .90831 L .15296 .90488 L p F P
0 g
s
.411 .332 .657 r
.57958 .75294 m .57599 .74992 L .57855 .74793 L closepath p F P
0 g
s
.405 .321 .648 r
.57599 .74992 m .57855 .74793 L .57722 .74115 L p F P
0 g
s
0 .213 .635 r
.05145 .90451 m .057 .90778 L .06114 .91051 L p F P
0 g
s
0 .234 .661 r
.057 .90778 m .05145 .90451 L .04757 .9019 L p F P
0 g
s
.841 .736 .748 r
.20142 .85495 m .19926 .85785 L .19575 .85355 L p F P
0 g
s
.841 .736 .748 r
.19575 .85355 m .1966 .85239 L .20142 .85495 L p F P
0 g
s
.841 .736 .747 r
.20142 .85495 m .1966 .85239 L .20175 .84536 L p F P
0 g
s
.874 .733 .703 r
.21292 .78747 m .21739 .79022 L .21383 .79675 L p F P
0 g
s
.872 .729 .702 r
.21739 .79022 m .21292 .78747 L .21641 .78098 L p F P
0 g
s
.216 .078 .468 r
.77699 .85471 m .77682 .85486 L .77681 .86064 L p F P
0 g
s
.464 .397 .697 r
.57811 .78987 m .57731 .78675 L .58054 .78822 L closepath p F P
0 g
s
.492 .421 .705 r
.58047 .79885 m .57852 .79824 L .58005 .79731 L closepath p F P
0 g
s
.49 .417 .701 r
.57852 .79824 m .58005 .79731 L .57811 .78987 L p F P
0 g
s
.793 .764 .827 r
.15296 .90488 m .15771 .90086 L .16259 .90334 L p F P
0 g
s
.786 .76 .83 r
.16437 .89534 m .15771 .90086 L .16259 .90334 L p F P
0 g
s
.786 .76 .83 r
.16259 .90334 m .16797 .89898 L .16437 .89534 L p F P
0 g
s
.61 .937 .731 r
.59767 .66754 m .59834 .66724 L .60735 .66016 L p F P
0 g
s
.775 .986 .739 r
.59694 .66873 m .59767 .66754 L .59834 .66724 L closepath p F P
0 g
s
.336 .305 .676 r
.78039 .80489 m .78463 .80947 L .78019 .81434 L p F P
0 g
s
.315 .273 .651 r
.78112 .82197 m .78379 .81911 L .78019 .81434 L p F P
0 g
s
.315 .276 .655 r
.78463 .80947 m .78019 .81434 L .78379 .81911 L p F P
0 g
s
.411 .445 .785 r
.75822 .74965 m .75905 .74851 L p .76347 .75672 L F P
0 g
s
.419 .46 .796 r
.75822 .74965 m .75752 .74793 L .75905 .74851 L closepath p F P
0 g
s
.82 .753 .789 r
.17945 .88823 m .18053 .88709 L .17638 .88491 L closepath p F P
0 g
s
.822 .751 .785 r
.17589 .88438 m .1827 .877 L p .18053 .88709 L F P
0 g
s
.822 .751 .785 r
.18053 .88709 m .17638 .88491 L .17589 .88438 L p F P
0 g
s
.637 .734 .919 r
.62439 .65606 m .63612 .6528 L .63901 .65647 L p F P
0 g
s
.656 .753 .922 r
.63612 .6528 m .62439 .65606 L .6215 .65313 L p F P
0 g
s
.712 .808 .925 r
.60986 .65857 m .6215 .65313 L .62439 .65606 L p F P
0 g
s
.185 .055 .459 r
.78206 .84988 m .77699 .85471 L .77725 .86025 L p F P
0 g
s
.231 .122 .517 r
.77699 .85471 m .78206 .84988 L .78116 .84434 L p F P
0 g
s
.216 .078 .468 r
.77681 .86064 m .77725 .86025 L .77699 .85471 L p F P
0 g
s
.801 .752 .808 r
.1721 .89506 m .17945 .88823 L .17638 .88491 L p F P
0 g
s
.119 0 .298 r
.76761 .87819 m .76852 .87745 L .76873 .87535 L closepath p F P
0 g
s
.648 .779 .943 r
.10131 .92228 m .11212 .91877 L .11586 .92167 L p F P
0 g
s
.654 .781 .941 r
.11212 .91877 m .10131 .92228 L .09753 .91951 L p F P
0 g
s
.548 .519 .776 r
.61563 .87489 m .60528 .87458 L .60366 .8704 L p F P
0 g
s
.809 .758 .805 r
.1721 .89506 m .16797 .89898 L .16437 .89534 L p F P
0 g
s
.809 .758 .805 r
.16437 .89534 m .16724 .89256 L .1721 .89506 L p F P
0 g
s
.801 .752 .808 r
.17568 .88458 m .16724 .89256 L .1721 .89506 L p F P
0 g
s
.801 .752 .808 r
.17638 .88491 m .17568 .88458 L p .1721 .89506 L F P
0 g
s
.263 .169 .556 r
.58172 .71245 m .58053 .70906 L .58125 .70833 L closepath p F P
0 g
s
.837 .731 .747 r
.207 .83831 m .20764 .83745 L .20416 .83292 L p F P
0 g
s
.089 0 .428 r
.58781 .68881 m .58456 .69287 L .5847 .69831 L p F P
0 g
s
0 0 .306 r
.58456 .69287 m .58781 .68881 L .58812 .68384 L p F P
0 g
s
.877 .733 .7 r
.21641 .78098 m .21815 .77767 L .21467 .77317 L p F P
0 g
s
.581 .647 .88 r
.64686 .91192 m .65869 .91059 L .66161 .91523 L p F P
0 g
s
.575 .616 .855 r
.65576 .90564 m .65869 .91059 L .64686 .91192 L p F P
0 g
s
.575 .616 .855 r
.6551 .9057 m .65576 .90564 L p .64686 .91192 L F P
0 g
s
.575 .616 .855 r
.64686 .91192 m .64623 .91079 L .6551 .9057 L p F P
0 g
s
.466 .401 .7 r
.58054 .78822 m .57811 .78987 L .58005 .79731 L p F P
0 g
s
.383 .396 .75 r
.77421 .76886 m .77034 .77369 L .77679 .77759 L p F P
0 g
s
.394 .411 .759 r
.76723 .76512 m .77421 .76886 L .77034 .77369 L p F P
0 g
s
.713 .784 .908 r
.12481 .91748 m .11586 .92167 L .11212 .91877 L p F P
0 g
s
.602 .693 .907 r
.67633 .91751 m .66632 .91924 L .67429 .91468 L closepath p F P
0 g
s
.604 .674 .89 r
.67346 .91353 m .67429 .91468 L .66632 .91924 L p F P
0 g
s
.604 .674 .89 r
.66161 .91523 m .67346 .91353 L p .66632 .91924 L F P
0 g
s
.825 .737 .768 r
.19561 .86217 m .19926 .85785 L .19575 .85355 L p F P
0 g
s
.868 .73 .707 r
.21476 .806 m .21275 .80956 L .20927 .80503 L p F P
0 g
s
.868 .73 .707 r
.20927 .80503 m .21024 .80329 L .21476 .806 L p F P
0 g
s
.87 .729 .704 r
.21476 .806 m .21024 .80329 L .21383 .79675 L p F P
0 g
s
.419 .46 .797 r
.75905 .74851 m .75752 .74793 L .75457 .74071 L p F P
0 g
s
.443 .494 .817 r
.74139 .7251 m .74873 .72713 L p .748 .73269 L F P
0 g
s
.441 .496 .82 r
.74139 .7251 m .74873 .72713 L .74582 .72062 L p F P
0 g
s
.441 .496 .82 r
.74582 .72062 m .74462 .72029 L .74139 .7251 L p F P
0 g
s
.52 .463 .733 r
.58986 .83091 m .5856 .83022 L .58904 .8283 L closepath p F P
0 g
s
.52 .455 .723 r
.58674 .82084 m .58904 .8283 L .5856 .83022 L p F P
0 g
s
.52 .455 .723 r
.58599 .82069 m .58674 .82084 L p .5856 .83022 L F P
0 g
s
.837 .731 .747 r
.20416 .83292 m .20208 .83576 L .207 .83831 L p F P
0 g
s
.842 .737 .747 r
.20208 .83576 m .207 .83831 L .20175 .84536 L p F P
0 g
s
.925 .742 .636 r
.21605 .73198 m .21717 .72865 L .21361 .72522 L p F P
0 g
s
.896 .736 .674 r
.21399 .76258 m .21812 .76547 L .21533 .77174 L p F P
0 g
s
.897 .732 .67 r
.21812 .76547 m .21399 .76258 L .21666 .75635 L p F P
0 g
s
.857 .734 .727 r
.20644 .81944 m .21116 .82207 L .20677 .82887 L p F P
0 g
s
.854 .731 .727 r
.21116 .82207 m .20644 .81944 L .21078 .81267 L p F P
0 g
s
.26 .644 .964 r
.06899 .91472 m .0766 .9156 L .08084 .91828 L p F P
0 g
s
.281 .652 .968 r
.0766 .9156 m .06899 .91472 L .06514 .91213 L p F P
0 g
s
.377 .303 .645 r
.5791 .73954 m .57722 .74115 L .57855 .74793 L p F P
0 g
s
.292 .24 .626 r
.78379 .81911 m .78112 .82197 L .78247 .82867 L p F P
0 g
s
.317 .257 .631 r
.78221 .82892 m .78247 .82867 L .78112 .82197 L p F P
0 g
s
.912 .742 .659 r
.21379 .73806 m .21764 .74108 L .21522 .74721 L p F P
0 g
s
.914 .738 .65 r
.21764 .74108 m .21379 .73806 L .21605 .73198 L p F P
0 g
s
.61 .937 .731 r
.60735 .66016 m .60848 .65785 L p .59767 .66754 L F P
0 g
s
.769 .92 .937 r
.60735 .66016 m .60848 .65785 L .60986 .65857 L closepath p F P
0 g
s
.548 .519 .776 r
.60366 .8704 m .60959 .86709 L p .61563 .87489 L F P
0 g
s
.539 .514 .776 r
.60366 .8704 m .60222 .86666 L .60959 .86709 L closepath p F P
0 g
s
.491 .566 .859 r
.70979 .69247 m .70934 .69242 L .70957 .69206 L closepath p F P
0 g
s
.497 .576 .865 r
.70691 .68715 m .70957 .69206 L .70934 .69242 L p F P
0 g
s
.593 .691 .91 r
.63901 .65647 m .65082 .65444 L .65371 .65852 L p F P
0 g
s
.603 .702 .914 r
.65082 .65444 m .63901 .65647 L .63612 .6528 L p F P
0 g
s
.575 .615 .855 r
.64623 .91079 m .64391 .90664 L .6551 .9057 L closepath p F P
0 g
s
.53 .63 .895 r
.67239 .66811 m .67136 .66646 L .67319 .66642 L closepath p F P
0 g
s
.608 .768 .957 r
.67917 .92113 m .69102 .91852 L .69381 .92139 L p F P
0 g
s
.601 .737 .94 r
.69102 .91852 m .67917 .92113 L .67633 .91751 L p F P
0 g
s
.403 .428 .772 r
.76347 .75672 m .77095 .7603 L .76723 .76512 L p F P
0 g
s
.393 .415 .764 r
.77095 .7603 m .76723 .76512 L .77421 .76886 L p F P
0 g
s
.834 .745 .766 r
.19067 .85965 m .19561 .86217 L .18952 .86948 L p F P
0 g
s
.825 .737 .768 r
.19575 .85355 m .19067 .85965 L .19561 .86217 L p F P
0 g
s
.44 .485 .809 r
.75165 .73384 m .748 .73269 L p .75394 .74048 L F P
0 g
s
.435 .482 .81 r
.75165 .73384 m .748 .73269 L .74997 .72991 L closepath p F P
0 g
s
.443 .494 .817 r
.74873 .72713 m .74997 .72991 L .748 .73269 L p F P
0 g
s
.479 .555 .856 r
.70979 .69247 m .72196 .69411 L p .71954 .69897 L F P
0 g
s
.473 .556 .86 r
.71908 .68864 m .72196 .69411 L .70979 .69247 L p F P
0 g
s
.473 .556 .86 r
.7119 .6877 m .71908 .68864 L p .70979 .69247 L F P
0 g
s
.473 .556 .86 r
.70979 .69247 m .70957 .69206 L .7119 .6877 L p F P
0 g
s
.325 .248 .614 r
.58288 .72076 m .57895 .72454 L .58197 .7292 L p F P
0 g
s
.308 .223 .594 r
.57895 .72454 m .58288 .72076 L .58195 .71441 L p F P
0 g
s
.693 .907 .971 r
.60848 .65785 m .60986 .65857 L .6215 .65313 L p F P
0 g
s
.519 .605 .879 r
.68909 .67603 m .68678 .67599 L .68794 .67403 L closepath p F P
0 g
s
.522 .615 .886 r
.68622 .67113 m .68794 .67403 L .68678 .67599 L p F P
0 g
s
.269 .173 .558 r
.58125 .70833 m .58569 .70352 L p .58229 .71405 L F P
0 g
s
.269 .173 .558 r
.58229 .71405 m .58172 .71245 L .58125 .70833 L p F P
0 g
s
.202 .1 .508 r
.58125 .70833 m .58569 .70352 L .5847 .69831 L p F P
0 g
s
.482 .414 .705 r
.58005 .79731 m .58839 .79164 L p .58743 .80138 L F P
0 g
s
.482 .414 .705 r
.58743 .80138 m .58047 .79885 L .58005 .79731 L p F P
0 g
s
.466 .401 .7 r
.58005 .79731 m .58839 .79164 L .58054 .78822 L p F P
0 g
s
.03 0 .171 r
.76852 .87745 m .76761 .87819 L .76369 .88501 L p F P
0 g
s
.617 .88 .99 r
.71723 .91673 m .70836 .92002 L .70564 .91802 L p F P
0 g
s
.616 .84 .985 r
.69381 .92139 m .70564 .91802 L .70836 .92002 L p F P
0 g
s
0 .423 .826 r
.06114 .91051 m .06514 .91213 L .06128 .90948 L p F P
0 g
s
0 .423 .826 r
.06128 .90948 m .057 .90778 L .06114 .91051 L p F P
0 g
s
.541 .507 .767 r
.60959 .86709 m .60222 .86666 L .60034 .86159 L p F P
0 g
s
.484 .57 .866 r
.70957 .69206 m .70691 .68715 L .7119 .6877 L closepath p F P
0 g
s
.856 .4 .065 r
.03936 .89385 m .03544 .89102 L .033 .88619 L p F P
0 g
s
.478 .418 .711 r
.58214 .80488 m .58047 .79885 L .58743 .80138 L closepath p F P
0 g
s
.402 .433 .778 r
.76701 .75192 m .76347 .75672 L .77095 .7603 L p F P
0 g
s
.411 .445 .785 r
.75905 .74851 m .76701 .75192 L .76347 .75672 L p F P
0 g
s
.455 .523 .839 r
.73708 .71294 m .73061 .71153 L .72832 .70676 L p F P
0 g
s
.878 .737 .702 r
.21205 .77818 m .21641 .78098 L .21292 .78747 L p F P
0 g
s
.877 .733 .7 r
.21467 .77317 m .21205 .77818 L .21641 .78098 L p F P
0 g
s
.427 .467 .799 r
.75457 .74071 m .75394 .74048 L .75429 .74001 L closepath p F P
0 g
s
.44 .485 .809 r
.75394 .74048 m .75429 .74001 L .75165 .73384 L p F P
0 g
s
0 0 .302 r
.58975 .68179 m .58812 .68384 L .58781 .68881 L p F P
0 g
s
0 0 .085 r
.58812 .68384 m .58975 .68179 L .59224 .67558 L p F P
0 g
s
.855 .732 .726 r
.21078 .81267 m .21275 .80956 L .20927 .80503 L p F P
0 g
s
.566 .935 .816 r
.73452 .91038 m .7357 .90968 L .73482 .91032 L closepath p F P
0 g
s
.571 .92 .724 r
.74697 .90212 m .74618 .90278 L p .73482 .91032 L F P
0 g
s
.571 .92 .724 r
.74618 .90278 m .7357 .90968 L .73482 .91032 L p F P
0 g
s
.411 .45 .79 r
.7624 .74373 m .75905 .74851 L .76701 .75192 L p F P
0 g
s
.419 .46 .797 r
.75457 .74071 m .7624 .74373 L .75905 .74851 L p F P
0 g
s
.612 .802 .972 r
.70564 .91802 m .69381 .92139 L .69102 .91852 L p F P
0 g
s
.608 .833 .445 r
.59556 .6703 m .60039 .66359 L .59767 .66754 L closepath p F P
0 g
s
.61 .937 .731 r
.607 .65735 m .60039 .66359 L .59767 .66754 L p F P
0 g
s
.61 .937 .731 r
.60848 .65785 m .607 .65735 L p .59767 .66754 L F P
0 g
s
.571 .578 .822 r
.62614 .89558 m .63797 .89512 L p .63563 .90139 L F P
0 g
s
.555 .56 .813 r
.63497 .88889 m .63797 .89512 L .62614 .89558 L p F P
0 g
s
.555 .56 .813 r
.63373 .88891 m .63497 .88889 L p .62614 .89558 L F P
0 g
s
.555 .56 .813 r
.62614 .89558 m .62528 .8937 L .63373 .88891 L p F P
0 g
s
0 0 0 r
.59224 .67558 m .59543 .67054 L .59556 .6703 L p F P
0 g
s
0 0 0 r
.74618 .90278 m .74925 .90037 L .74697 .90212 L closepath p F P
0 g
s
0 0 0 r
.75769 .89269 m .74925 .90037 L p .74698 .90212 L F P
0 g
s
0 0 0 r
.75779 .89251 m .75769 .89269 L p .74697 .90212 L F P
0 g
s
0 0 0 r
.74925 .90037 m .75558 .89553 L .75769 .89269 L closepath p F P
0 g
s
0 0 0 r
.74371 .90392 m .75556 .89554 L .74925 .90037 L F
.75558 .89553 m .74925 .90037 L p .75556 .89554 L F P
0 g
s
0 0 0 r
.74925 .90037 m .74697 .90212 L p .74698 .90212 L F P
0 g
s
.364 .69 .981 r
.08084 .91828 m .08312 .91841 L .0793 .91573 L p F P
0 g
s
.364 .69 .981 r
.0793 .91573 m .0766 .9156 L .08084 .91828 L p F P
0 g
s
.532 .501 .767 r
.60034 .86159 m .59915 .85836 L .60508 .85889 L closepath p F P
0 g
s
.541 .507 .767 r
.60034 .86159 m .60508 .85889 L p .60959 .86709 L F P
0 g
s
.847 .74 .746 r
.19695 .84278 m .20175 .84536 L .1966 .85239 L p F P
0 g
s
.842 .737 .747 r
.20175 .84536 m .19695 .84278 L .20208 .83576 L p F P
0 g
s
.778 .776 .851 r
.14617 .90971 m .14169 .91297 L .13801 .90975 L p F P
0 g
s
.748 .778 .877 r
.12685 .91653 m .13801 .90975 L .14169 .91297 L p F P
0 g
s
.903 .74 .67 r
.21267 .7534 m .21666 .75635 L .21399 .76258 L p F P
0 g
s
.904 .737 .665 r
.21666 .75635 m .21267 .7534 L .21522 .74721 L p F P
0 g
s
.331 .304 .678 r
.78474 .80001 m .78039 .80489 L .78463 .80947 L p F P
0 g
s
.347 .327 .694 r
.77988 .79561 m .78474 .80001 L .78039 .80489 L p F P
0 g
s
.491 .428 .713 r
.58214 .80488 m .58743 .80138 L p .58661 .81107 L F P
0 g
s
.491 .428 .713 r
.58661 .81107 m .58361 .81015 L .58214 .80488 L p F P
0 g
s
.414 .459 .798 r
.7624 .74373 m .75457 .74071 L .75429 .74001 L p F P
0 g
s
.875 .736 .704 r
.20941 .79399 m .21383 .79675 L .21024 .80329 L p F P
0 g
s
.874 .733 .703 r
.21383 .79675 m .20941 .79399 L .21292 .78747 L p F P
0 g
s
.747 .233 0 r
.04684 .90119 m .04285 .89839 L .03936 .89385 L p F P
0 g
s
.742 .228 0 r
.03544 .89102 m .03936 .89385 L .04285 .89839 L p F P
0 g
s
.921 .748 .65 r
.21237 .7289 m .21605 .73198 L .21379 .73806 L p F P
0 g
s
.925 .742 .636 r
.21361 .72522 m .21237 .7289 L .21605 .73198 L p F P
0 g
s
.528 .635 .9 r
.67319 .66642 m .67136 .66646 L .66849 .66195 L p F P
0 g
s
.434 .362 .677 r
.58279 .76715 m .57836 .76429 L .58157 .76189 L closepath p F P
0 g
s
.43 .356 .672 r
.57836 .76429 m .58157 .76189 L .57999 .75483 L p F P
0 g
s
.414 .459 .798 r
.75429 .74001 m .75715 .73573 L p .7624 .74373 L F P
0 g
s
.423 .475 .809 r
.75429 .74001 m .75165 .73384 L .75715 .73573 L closepath p F P
0 g
s
.834 .745 .766 r
.18952 .86948 m .18752 .87189 L .18398 .86787 L p F P
0 g
s
.834 .745 .766 r
.18398 .86787 m .18475 .86692 L .18952 .86948 L p F P
0 g
s
.834 .745 .766 r
.18952 .86948 m .18475 .86692 L .19067 .85965 L p F P
0 g
s
.534 .494 .758 r
.60508 .85889 m .59915 .85836 L .59725 .85301 L p F P
0 g
s
.555 .559 .813 r
.62528 .8937 m .62313 .88902 L .63373 .88891 L closepath p F P
0 g
s
.289 .215 .598 r
.78268 .82991 m .78221 .82892 L .78247 .82867 L closepath p F P
0 g
s
.615 .956 .897 r
.7357 .90968 m .73452 .91038 L .73196 .9103 L p F P
0 g
s
.55 .929 .903 r
.72017 .9156 m .73196 .9103 L .73452 .91038 L p F P
0 g
s
0 0 .155 r
.77347 .87311 m .76852 .87745 L .76763 .88181 L p F P
0 g
s
.03 0 .268 r
.77573 .86671 m .77347 .87311 L .76852 .87745 L p F P
0 g
s
.03 0 .171 r
.76369 .88501 m .76763 .88181 L .76852 .87745 L p F P
0 g
s
.856 .735 .728 r
.20677 .82887 m .20416 .83292 L .20065 .82855 L p F P
0 g
s
.856 .735 .728 r
.20065 .82855 m .20215 .82621 L .20677 .82887 L p F P
0 g
s
.857 .734 .727 r
.20677 .82887 m .20215 .82621 L .20644 .81944 L p F P
0 g
s
.404 .327 .656 r
.57855 .74793 m .58325 .7439 L p .58089 .75408 L F P
0 g
s
.404 .327 .656 r
.58089 .75408 m .57958 .75294 L .57855 .74793 L p F P
0 g
s
.377 .303 .645 r
.57855 .74793 m .58325 .7439 L .5791 .73954 L p F P
0 g
s
.855 .732 .726 r
.20927 .80503 m .20614 .80999 L .21078 .81267 L p F P
0 g
s
.86 .737 .726 r
.20614 .80999 m .21078 .81267 L .20644 .81944 L p F P
0 g
s
.488 .432 .72 r
.58431 .81255 m .58361 .81015 L .58661 .81107 L closepath p F P
0 g
s
.558 .666 .91 r
.65393 .65885 m .65371 .65852 L .65408 .65848 L closepath p F P
0 g
s
.778 .776 .851 r
.13801 .90975 m .14148 .90718 L .14617 .90971 L p F P
0 g
s
.771 .771 .853 r
.14932 .90147 m .14148 .90718 L .14617 .90971 L p F P
0 g
s
.771 .771 .853 r
.14617 .90971 m .15296 .90488 L .14932 .90147 L p F P
0 g
s
.512 .451 .725 r
.58674 .82084 m .58599 .82069 L .58659 .82034 L closepath p F P
0 g
s
.512 .443 .715 r
.58431 .81255 m .58659 .82034 L .58599 .82069 L p F P
0 g
s
.816 .747 .787 r
.1827 .877 m .18752 .87189 L .18398 .86787 L p F P
0 g
s
.494 .881 .7 r
.74371 .90392 m .74313 .90426 L .7357 .90968 L p F P
0 g
s
.494 .881 .7 r
.7357 .90968 m .74618 .90278 L .74371 .90392 L p F P
0 g
s
.615 .956 .897 r
.73196 .9103 m .74313 .90426 L .7357 .90968 L p F P
0 g
s
.503 .592 .876 r
.68909 .67603 m .70116 .67668 L p .70022 .68158 L F P
0 g
s
.499 .594 .88 r
.69829 .67167 m .70116 .67668 L .68909 .67603 L p F P
0 g
s
.499 .594 .88 r
.68925 .67123 m .69829 .67167 L p .68909 .67603 L F P
0 g
s
.499 .594 .88 r
.68909 .67603 m .68794 .67403 L .68925 .67123 L p F P
0 g
s
.489 .434 .722 r
.58659 .82034 m .58431 .81255 L .58661 .81107 L p F P
0 g
s
.534 .494 .758 r
.59725 .85301 m .6018 .85035 L p .60508 .85889 L F P
0 g
s
.524 .488 .758 r
.59725 .85301 m .59606 .84965 L .6018 .85035 L closepath p F P
0 g
s
.464 .403 .703 r
.58695 .78375 m .58054 .78822 L .58839 .79164 L p F P
0 g
s
.468 .394 .691 r
.58597 .78 m .58695 .78375 L .58054 .78822 L p F P
0 g
s
.468 .394 .691 r
.58246 .7782 m .58597 .78 L p .58054 .78822 L F P
0 g
s
.269 .202 .594 r
.78247 .82867 m .7868 .82405 L p .78456 .83405 L F P
0 g
s
.269 .202 .594 r
.78456 .83405 m .78268 .82991 L .78247 .82867 L p F P
0 g
s
.292 .24 .626 r
.78247 .82867 m .7868 .82405 L .78379 .81911 L p F P
0 g
s
.555 .673 .917 r
.65408 .65848 m .65371 .65852 L .65082 .65444 L p F P
0 g
s
.367 .301 .651 r
.58519 .73395 m .5791 .73954 L .58325 .7439 L p F P
0 g
s
.377 .29 .63 r
.58508 .73334 m .58519 .73395 L .5791 .73954 L p F P
0 g
s
.377 .29 .63 r
.58197 .7292 m .58508 .73334 L p .5791 .73954 L F P
0 g
s
.526 .482 .75 r
.6018 .85035 m .59606 .84965 L .59435 .84461 L p F P
0 g
s
.581 .663 .894 r
.67346 .91353 m .66161 .91523 L .65869 .91059 L p F P
0 g
s
.57 .589 .832 r
.64095 .90105 m .63563 .90139 L .63994 .89906 L closepath p F P
0 g
s
.571 .578 .822 r
.63797 .89512 m .63994 .89906 L .63563 .90139 L p F P
0 g
s
.472 .545 .85 r
.72484 .69982 m .71954 .69897 L .7222 .69457 L closepath p F P
0 g
s
.479 .555 .856 r
.72196 .69411 m .7222 .69457 L .71954 .69897 L p F P
0 g
s
.561 .674 .914 r
.65408 .65848 m .6656 .65751 L .66271 .65315 L p F P
0 g
s
.561 .674 .914 r
.66271 .65315 m .65583 .65387 L .65408 .65848 L p F P
0 g
s
.555 .673 .917 r
.65082 .65444 m .65583 .65387 L .65408 .65848 L p F P
0 g
s
.502 .445 .725 r
.58659 .82034 m .5957 .81454 L p .59698 .82334 L F P
0 g
s
.502 .445 .725 r
.59698 .82334 m .58674 .82084 L .58659 .82034 L p F P
0 g
s
.489 .434 .722 r
.59543 .81368 m .5957 .81454 L .58659 .82034 L p F P
0 g
s
.489 .434 .722 r
.58661 .81107 m .59543 .81368 L p .58659 .82034 L F P
0 g
s
.713 .784 .908 r
.11212 .91877 m .11997 .91498 L .12481 .91748 L p F P
0 g
s
.706 .782 .911 r
.12314 .91347 m .11997 .91498 L .12481 .91748 L p F P
0 g
s
.706 .782 .911 r
.12481 .91748 m .12685 .91653 L .12314 .91347 L p F P
0 g
s
.822 .749 .783 r
.1827 .877 m .17589 .88438 L .17231 .88056 L p F P
0 g
s
.822 .749 .783 r
.17231 .88056 m .17784 .87447 L .1827 .877 L p F P
0 g
s
.816 .747 .787 r
.18398 .86787 m .17784 .87447 L .1827 .877 L p F P
0 g
s
.576 .604 .843 r
.6551 .9057 m .64391 .90664 L .64095 .90105 L p F P
0 g
s
.526 .482 .75 r
.59435 .84461 m .59948 .84155 L p .6018 .85035 L F P
0 g
s
.516 .475 .749 r
.59435 .84461 m .59297 .84051 L .59948 .84155 L closepath p F P
0 g
s
.499 .449 .732 r
.58904 .8283 m .58674 .82084 L .59698 .82334 L closepath p F P
0 g
s
.894 .738 .681 r
.21533 .77174 m .21467 .77317 L .21116 .76899 L p F P
0 g
s
.894 .738 .681 r
.21116 .76899 m .21123 .76885 L .21533 .77174 L p F P
0 g
s
.896 .736 .674 r
.21533 .77174 m .21123 .76885 L .21399 .76258 L p F P
0 g
s
.257 .167 .557 r
.58195 .71441 m .58172 .71245 L .58229 .71405 L closepath p F P
0 g
s
.271 .203 .594 r
.78356 .83509 m .78268 .82991 L .78456 .83405 L closepath p F P
0 g
s
0 0 0 r
.75779 .89251 m .75807 .89228 L .76369 .88501 L p F P
0 g
s
0 0 0 r
.76763 .88181 m .76369 .88501 L .75807 .89228 L p F P
0 g
s
.609 .065 0 r
.04684 .90119 m .04757 .9019 L .04368 .8992 L p F P
0 g
s
.609 .065 0 r
.04368 .8992 m .04285 .89839 L .04684 .90119 L p F P
0 g
s
.529 .631 .896 r
.67319 .66642 m .68334 .66635 L .68046 .66162 L p F P
0 g
s
.529 .631 .896 r
.68046 .66162 m .67535 .66172 L .67319 .66642 L p F P
0 g
s
.528 .635 .9 r
.66849 .66195 m .67535 .66172 L .67319 .66642 L p F P
0 g
s
.519 .47 .741 r
.59948 .84155 m .59297 .84051 L .59162 .83638 L p F P
0 g
s
.511 .457 .733 r
.58904 .8283 m .59698 .82334 L p .59794 .83253 L F P
0 g
s
.511 .457 .733 r
.59794 .83253 m .58986 .83091 L .58904 .8283 L p F P
0 g
s
.508 .462 .741 r
.59162 .83638 m .58986 .83091 L .59794 .83253 L closepath p F P
0 g
s
.519 .47 .741 r
.59162 .83638 m .59794 .83253 L p .59948 .84155 L F P
0 g
s
.161 0 .394 r
.77725 .86025 m .77681 .86064 L .77573 .86671 L p F P
0 g
s
.802 .751 .806 r
.17638 .88491 m .17589 .88438 L .17568 .88458 L closepath p F P
0 g
s
.548 .758 .975 r
.08312 .91841 m .09374 .91673 L .09753 .91951 L p F P
0 g
s
.556 .76 .973 r
.09374 .91673 m .08312 .91841 L .0793 .91573 L p F P
0 g
s
.461 .535 .847 r
.72832 .70676 m .72772 .70556 L .72889 .70578 L closepath p F P
0 g
s
.455 .523 .839 r
.72832 .70676 m .72889 .70578 L p .73708 .71294 L F P
0 g
s
.91 .745 .665 r
.21137 .7442 m .21522 .74721 L .21267 .7534 L p F P
0 g
s
.912 .742 .659 r
.21522 .74721 m .21137 .7442 L .21379 .73806 L p F P
0 g
s
.23 .122 .517 r
.7844 .84124 m .78116 .84434 L .78206 .84988 L p F P
0 g
s
.266 .175 .562 r
.78116 .84434 m .7844 .84124 L .78356 .83509 L p F P
0 g
s
.798 .768 .826 r
.15771 .90086 m .15296 .90488 L .14932 .90147 L p F P
0 g
s
.845 .742 .75 r
.19575 .85355 m .1966 .85239 L .19316 .85047 L closepath p F P
0 g
s
.847 .74 .746 r
.19223 .84935 m .19695 .84278 L p .1966 .85239 L F P
0 g
s
.847 .74 .746 r
.1966 .85239 m .19316 .85047 L .19223 .84935 L p F P
0 g
s
.842 .737 .747 r
.20208 .83576 m .20416 .83292 L .20065 .82855 L p F P
0 g
s
.883 .741 .701 r
.21205 .77818 m .21467 .77317 L .21116 .76899 L p F P
0 g
s
.397 .327 .661 r
.57999 .75483 m .57958 .75294 L .58089 .75408 L closepath p F P
0 g
s
.345 .33 .699 r
.78311 .7919 m .77988 .79561 L .78474 .80001 L p F P
0 g
s
.363 .356 .718 r
.78235 .78939 m .77868 .78651 L p .77988 .79561 L F P
0 g
s
.363 .356 .718 r
.77988 .79561 m .78311 .7919 L .78235 .78939 L p F P
0 g
s
.752 .78 .876 r
.13801 .90975 m .12685 .91653 L .12314 .91347 L p F P
0 g
s
.556 .551 .803 r
.63373 .88891 m .62313 .88902 L .62082 .88376 L p F P
0 g
s
.798 .768 .826 r
.14932 .90147 m .15297 .89832 L .15771 .90086 L p F P
0 g
s
.79 .764 .829 r
.16075 .89175 m .15297 .89832 L .15771 .90086 L p F P
0 g
s
.79 .764 .829 r
.15771 .90086 m .16437 .89534 L .16075 .89175 L p F P
0 g
s
.88 .739 .703 r
.20861 .78467 m .21292 .78747 L .20941 .79399 L p F P
0 g
s
.878 .737 .702 r
.21292 .78747 m .20861 .78467 L .21205 .77818 L p F P
0 g
s
.829 .742 .768 r
.19067 .85965 m .19575 .85355 L .19316 .85047 L p F P
0 g
s
.803 .754 .807 r
.17568 .88458 m .17589 .88438 L .17231 .88056 L p F P
0 g
s
.811 .762 .807 r
.1707 .88209 m .17568 .88458 L .16724 .89256 L p F P
0 g
s
.803 .754 .807 r
.17231 .88056 m .1707 .88209 L .17568 .88458 L p F P
0 g
s
.769 .956 .933 r
.607 .65735 m .61027 .65517 L .60848 .65785 L closepath p F P
0 g
s
.693 .907 .971 r
.61861 .65054 m .61027 .65517 L .60848 .65785 L p F P
0 g
s
.693 .907 .971 r
.6215 .65313 m .61861 .65054 L p .60848 .65785 L F P
0 g
s
.509 .606 .886 r
.68794 .67403 m .68622 .67113 L .68925 .67123 L closepath p F P
0 g
s
.154 .07 .5 r
.58795 .69428 m .5847 .69831 L .58569 .70352 L p F P
0 g
s
.089 0 .428 r
.5847 .69831 m .58795 .69428 L .58781 .68881 L p F P
0 g
s
.422 .475 .809 r
.75715 .73573 m .75165 .73384 L .74997 .72991 L p F P
0 g
s
.125 0 .383 r
.78207 .85567 m .77725 .86025 L .77719 .86544 L p F P
0 g
s
.185 .055 .459 r
.77725 .86025 m .78207 .85567 L .78206 .84988 L p F P
0 g
s
.161 0 .394 r
.77573 .86671 m .77719 .86544 L .77725 .86025 L p F P
0 g
s
.46 .537 .849 r
.72889 .70578 m .72772 .70556 L .72484 .69982 L p F P
0 g
s
.284 .206 .589 r
.58229 .71405 m .58195 .71441 L .58288 .72076 L p F P
0 g
s
.813 .762 .805 r
.16724 .89256 m .16437 .89534 L .16075 .89175 L p F P
0 g
s
.813 .762 .805 r
.16075 .89175 m .16252 .89001 L .16724 .89256 L p F P
0 g
s
.811 .762 .807 r
.16724 .89256 m .16252 .89001 L .1707 .88209 L p F P
0 g
s
.483 .571 .868 r
.7119 .6877 m .70691 .68715 L .70404 .68187 L p F P
0 g
s
0 0 0 r
.75769 .89269 m .75807 .89228 L .75779 .89251 L closepath p F P
0 g
s
.404 .339 .67 r
.58089 .75408 m .57999 .75483 L .58157 .76189 L p F P
0 g
s
0 .234 .661 r
.04757 .9019 m .05293 .90502 L .057 .90778 L p F P
0 g
s
0 .25 .682 r
.05293 .90502 m .04757 .9019 L .04368 .8992 L p F P
0 g
s
.842 .737 .747 r
.20065 .82855 m .19733 .83315 L .20208 .83576 L p F P
0 g
s
.848 .742 .747 r
.19733 .83315 m .20208 .83576 L .19695 .84278 L p F P
0 g
s
.617 .88 .99 r
.71948 .91525 m .71723 .91673 L p .70564 .91802 L F P
0 g
s
.644 .901 .983 r
.71723 .91673 m .71948 .91525 L .72017 .9156 L closepath p F P
0 g
s
0 0 0 r
.74925 .90037 m .74618 .90278 L .74371 .90392 L p F P
0 g
s
.874 .737 .708 r
.21024 .80329 m .20927 .80503 L .20577 .80072 L p F P
0 g
s
.874 .737 .708 r
.20577 .80072 m .20588 .80052 L .21024 .80329 L p F P
0 g
s
.875 .736 .704 r
.21024 .80329 m .20588 .80052 L .20941 .79399 L p F P
0 g
s
0 0 .302 r
.58781 .68881 m .58879 .68756 L .58975 .68179 L p F P
0 g
s
0 0 .291 r
.59331 .67665 m .58975 .68179 L .58879 .68756 L p F P
0 g
s
0 0 .076 r
.58975 .68179 m .59331 .67665 L .59543 .67054 L p F P
0 g
s
.862 .74 .726 r
.20188 .81675 m .20644 .81944 L .20215 .82621 L p F P
0 g
s
.86 .737 .726 r
.20644 .81944 m .20188 .81675 L .20614 .80999 L p F P
0 g
s
0 0 0 r
.75807 .89228 m .76431 .88713 L p .75558 .89553 L F P
0 g
s
0 0 0 r
.75558 .89553 m .75769 .89269 L .75807 .89228 L p F P
0 g
s
0 0 0 r
.76684 .88412 m .76763 .88181 L p .75807 .89228 L F P
0 g
s
0 0 0 r
.75807 .89228 m .76431 .88713 L .76684 .88412 L p F P
0 g
s
.284 .206 .589 r
.58288 .72076 m .5847 .71887 L .58229 .71405 L p F P
0 g
s
.247 .177 .577 r
.58732 .70856 m .58229 .71405 L .5847 .71887 L p F P
0 g
s
.269 .173 .558 r
.58569 .70352 m .58732 .70856 L .58229 .71405 L p F P
0 g
s
.654 .781 .941 r
.09753 .91951 m .10837 .91587 L .11212 .91877 L p F P
0 g
s
.658 .782 .94 r
.10837 .91587 m .09753 .91951 L .09374 .91673 L p F P
0 g
s
.717 .786 .907 r
.11997 .91498 m .11212 .91877 L .10837 .91587 L p F P
0 g
s
.903 .742 .672 r
.21001 .75963 m .21399 .76258 L .21123 .76885 L p F P
0 g
s
.903 .74 .67 r
.21399 .76258 m .21001 .75963 L .21267 .7534 L p F P
0 g
s
.656 .753 .922 r
.6215 .65313 m .63323 .64931 L .63612 .6528 L p F P
0 g
s
.68 .776 .923 r
.63323 .64931 m .6215 .65313 L .61861 .65054 L p F P
0 g
s
.498 .582 .87 r
.70404 .68187 m .70022 .68158 L .70207 .67829 L closepath p F P
0 g
s
.503 .592 .876 r
.70116 .67668 m .70207 .67829 L .70022 .68158 L p F P
0 g
s
.455 .523 .839 r
.72889 .70578 m .74002 .70816 L p .73708 .71294 L F P
0 g
s
.452 .527 .844 r
.72889 .70578 m .74002 .70816 L .73713 .70226 L p F P
0 g
s
.452 .527 .844 r
.73713 .70226 m .73153 .70108 L .72889 .70578 L p F P
0 g
s
.46 .537 .849 r
.72484 .69982 m .73153 .70108 L .72889 .70578 L p F P
0 g
s
.489 .436 .725 r
.59543 .81368 m .58661 .81107 L .59335 .80668 L closepath p F P
0 g
s
.491 .428 .713 r
.59229 .80309 m .59335 .80668 L .58661 .81107 L p F P
0 g
s
.491 .428 .713 r
.58743 .80138 m .59229 .80309 L p .58661 .81107 L F P
0 g
s
.839 .749 .764 r
.1859 .85708 m .19067 .85965 L .18475 .86692 L p F P
0 g
s
.829 .742 .768 r
.19186 .8498 m .1859 .85708 L .19067 .85965 L p F P
0 g
s
.829 .742 .768 r
.19316 .85047 m .19186 .8498 L p .19067 .85965 L F P
0 g
s
.601 .737 .94 r
.67633 .91751 m .6882 .91525 L .69102 .91852 L p F P
0 g
s
.597 .691 .908 r
.68536 .91161 m .6882 .91525 L .67633 .91751 L p F P
0 g
s
.597 .691 .908 r
.67701 .91296 m .68536 .91161 L p .67633 .91751 L F P
0 g
s
.597 .691 .908 r
.67633 .91751 m .67429 .91468 L .67701 .91296 L p F P
0 g
s
.292 .241 .628 r
.78832 .81421 m .78379 .81911 L .7868 .82405 L p F P
0 g
s
.315 .276 .655 r
.78379 .81911 m .78832 .81421 L .78463 .80947 L p F P
0 g
s
.861 .739 .727 r
.20614 .80999 m .20927 .80503 L .20577 .80072 L p F P
0 g
s
.918 .751 .659 r
.21011 .73498 m .21379 .73806 L .21137 .7442 L p F P
0 g
s
.921 .748 .65 r
.21379 .73806 m .21011 .73498 L .21237 .7289 L p F P
0 g
s
.603 .702 .914 r
.63612 .6528 m .64793 .65047 L .65082 .65444 L p F P
0 g
s
.615 .715 .917 r
.64793 .65047 m .63612 .6528 L .63323 .64931 L p F P
0 g
s
.43 .489 .819 r
.74997 .72991 m .74873 .72713 L .75125 .7279 L closepath p F P
0 g
s
.422 .475 .809 r
.74997 .72991 m .75125 .7279 L p .75715 .73573 L F P
0 g
s
.281 .652 .968 r
.06514 .91213 m .07241 .91289 L .0766 .9156 L p F P
0 g
s
.299 .658 .971 r
.07241 .91289 m .06514 .91213 L .06128 .90948 L p F P
0 g
s
.556 .551 .803 r
.62082 .88376 m .62352 .8822 L p .63373 .88891 L F P
0 g
s
.548 .545 .803 r
.62082 .88376 m .62011 .88215 L .62352 .8822 L closepath p F P
0 g
s
.357 .353 .718 r
.78235 .78939 m .77868 .78651 L .78075 .78406 L closepath p F P
0 g
s
.373 .377 .734 r
.77921 .77926 m .77679 .77759 L p .77868 .78651 L F P
0 g
s
.373 .377 .734 r
.77868 .78651 m .78075 .78406 L .77921 .77926 L p F P
0 g
s
.684 .912 .973 r
.71948 .91525 m .72017 .9156 L .73196 .9103 L p F P
0 g
s
.404 .339 .67 r
.58157 .76189 m .58606 .75819 L .58089 .75408 L p F P
0 g
s
.396 .338 .675 r
.58767 .7482 m .58089 .75408 L .58606 .75819 L p F P
0 g
s
.404 .327 .656 r
.58325 .7439 m .58767 .7482 L .58089 .75408 L p F P
0 g
s
.238 .156 .556 r
.78456 .83405 m .78356 .83509 L .7844 .84124 L p F P
0 g
s
.452 .387 .694 r
.58597 .78 m .58246 .7782 L .58505 .77634 L closepath p F P
0 g
s
.449 .382 .69 r
.58246 .7782 m .58505 .77634 L .58324 .76905 L p F P
0 g
s
.884 .744 .702 r
.20786 .77531 m .21205 .77818 L .20861 .78467 L p F P
0 g
s
.883 .741 .701 r
.21116 .76899 m .20786 .77531 L .21205 .77818 L p F P
0 g
s
.55 .537 .794 r
.62352 .8822 m .62011 .88215 L .61707 .87492 L p F P
0 g
s
0 .432 .837 r
.057 .90778 m .06128 .90948 L .05741 .90677 L p F P
0 g
s
0 .432 .837 r
.05741 .90677 m .05293 .90502 L .057 .90778 L p F P
0 g
s
.426 .357 .677 r
.58157 .76189 m .58606 .75819 L p .58431 .76819 L F P
0 g
s
.426 .357 .677 r
.58431 .76819 m .58279 .76715 L .58157 .76189 L p F P
0 g
s
.532 .641 .903 r
.67535 .66172 m .66849 .66195 L .6656 .65751 L p F P
0 g
s
.56 .583 .834 r
.64985 .89471 m .65281 .90031 L .64095 .90105 L p F P
0 g
s
.56 .583 .834 r
.64708 .89481 m .64985 .89471 L p .64095 .90105 L F P
0 g
s
.56 .583 .834 r
.64095 .90105 m .63994 .89906 L .64708 .89481 L p F P
0 g
s
.576 .604 .843 r
.64095 .90105 m .65281 .90031 L p .6551 .9057 L F P
0 g
s
.548 .519 .776 r
.60959 .86709 m .61401 .86733 L p .61563 .87489 L F P
0 g
s
.541 .515 .776 r
.61401 .86733 m .60959 .86709 L .61316 .86511 L closepath p F P
0 g
s
.541 .507 .767 r
.61095 .85938 m .61316 .86511 L .60959 .86709 L p F P
0 g
s
.541 .507 .767 r
.60508 .85889 m .61095 .85938 L p .60959 .86709 L F P
0 g
s
.849 .742 .745 r
.19695 .84278 m .19223 .84935 L .18868 .84525 L p F P
0 g
s
.849 .742 .745 r
.18868 .84525 m .19231 .84014 L .19695 .84278 L p F P
0 g
s
.848 .742 .747 r
.19695 .84278 m .19231 .84014 L .19733 .83315 L p F P
0 g
s
.08 0 .424 r
.58879 .68756 m .58781 .68881 L .58795 .69428 L p F P
0 g
s
.507 .61 .889 r
.68925 .67123 m .68622 .67113 L .68334 .66635 L p F P
0 g
s
.43 .49 .82 r
.75125 .7279 m .74873 .72713 L .74582 .72062 L p F P
0 g
s
.534 .494 .758 r
.60787 .85106 m .60977 .85622 L .60508 .85889 L p F P
0 g
s
.534 .494 .758 r
.6018 .85035 m .60787 .85106 L p .60508 .85889 L F P
0 g
s
.533 .503 .768 r
.61095 .85938 m .60508 .85889 L .60977 .85622 L closepath p F P
0 g
s
.612 .802 .972 r
.69102 .91852 m .70289 .91555 L .70564 .91802 L p F P
0 g
s
.606 .767 .957 r
.70289 .91555 m .69102 .91852 L .6882 .91525 L p F P
0 g
s
.375 .693 .982 r
.0766 .9156 m .0793 .91573 L .07546 .91301 L p F P
0 g
s
.375 .693 .982 r
.07546 .91301 m .07241 .91289 L .0766 .9156 L p F P
0 g
s
.337 .267 .628 r
.58508 .73334 m .58197 .7292 L .58397 .72728 L closepath p F P
0 g
s
.325 .248 .614 r
.58197 .7292 m .58397 .72728 L .58288 .72076 L p F P
0 g
s
.881 .741 .703 r
.20514 .79117 m .20941 .79399 L .20588 .80052 L p F P
0 g
s
.88 .739 .703 r
.20941 .79399 m .20514 .79117 L .20861 .78467 L p F P
0 g
s
.782 .779 .85 r
.14148 .90718 m .13801 .90975 L .13432 .90654 L p F P
0 g
s
.752 .78 .876 r
.12314 .91347 m .13432 .90654 L .13801 .90975 L p F P
0 g
s
.452 .515 .832 r
.74292 .71437 m .73708 .71294 L p .74462 .72029 L F P
0 g
s
.447 .512 .832 r
.74292 .71437 m .73708 .71294 L .74003 .70817 L closepath p F P
0 g
s
.455 .523 .839 r
.74002 .70816 m .74003 .70817 L .73708 .71294 L p F P
0 g
s
.837 .751 .769 r
.18398 .86787 m .18475 .86692 L .18144 .86507 L closepath p F P
0 g
s
.839 .749 .764 r
.18041 .86392 m .1859 .85708 L p .18475 .86692 L F P
0 g
s
.839 .749 .764 r
.18475 .86692 m .18144 .86507 L .18041 .86392 L p F P
0 g
s
.581 .663 .894 r
.65869 .91059 m .67057 .90918 L .67346 .91353 L p F P
0 g
s
.574 .644 .882 r
.67057 .90918 m .65869 .91059 L .65576 .90564 L p F P
0 g
s
.909 .748 .671 r
.20883 .75039 m .21267 .7534 L .21001 .75963 L p F P
0 g
s
.91 .745 .665 r
.21267 .7534 m .20883 .75039 L .21137 .7442 L p F P
0 g
s
.617 .842 .985 r
.7175 .91413 m .70564 .91802 L .70289 .91555 L p F P
0 g
s
.617 .88 .99 r
.70564 .91802 m .7175 .91413 L .71948 .91525 L p F P
0 g
s
.82 .751 .787 r
.17784 .87447 m .18398 .86787 L .18144 .86507 L p F P
0 g
s
.548 .527 .785 r
.61707 .87492 m .61563 .87489 L .6168 .87426 L closepath p F P
0 g
s
.548 .519 .776 r
.61401 .86733 m .6168 .87426 L .61563 .87489 L p F P
0 g
s
.367 .373 .734 r
.77921 .77926 m .77679 .77759 L .77814 .77593 L closepath p F P
0 g
s
.383 .396 .75 r
.77613 .77002 m .77421 .76886 L p .77679 .77759 L F P
0 g
s
.383 .396 .75 r
.77679 .77759 m .77814 .77593 L .77613 .77002 L p F P
0 g
s
.862 .741 .728 r
.20215 .82621 m .20065 .82855 L .19713 .82435 L p F P
0 g
s
.862 .741 .728 r
.19713 .82435 m .19766 .82351 L .20215 .82621 L p F P
0 g
s
.862 .74 .726 r
.20215 .82621 m .19766 .82351 L .20188 .81675 L p F P
0 g
s
.861 .739 .727 r
.20577 .80072 m .20167 .80726 L .20614 .80999 L p F P
0 g
s
.865 .743 .726 r
.20167 .80726 m .20614 .80999 L .20188 .81675 L p F P
0 g
s
.088 0 .293 r
.77719 .86544 m .77573 .86671 L .77347 .87311 L p F P
0 g
s
.742 .228 0 r
.04285 .89839 m .03892 .89557 L .03544 .89102 L p F P
0 g
s
.831 .74 .764 r
.19316 .85047 m .19223 .84935 L .19186 .8498 L closepath p F P
0 g
s
.301 .231 .609 r
.5847 .71887 m .58288 .72076 L .58397 .72728 L p F P
0 g
s
.782 .779 .85 r
.13432 .90654 m .13691 .90459 L .14148 .90718 L p F P
0 g
s
.775 .774 .852 r
.14566 .89811 m .13691 .90459 L .14148 .90718 L p F P
0 g
s
.775 .774 .852 r
.14148 .90718 m .14932 .90147 L .14566 .89811 L p F P
0 g
s
.559 .582 .833 r
.63994 .89906 m .63797 .89512 L .64708 .89481 L closepath p F P
0 g
s
.652 .891 .983 r
.7175 .91413 m .72516 .9112 L .71948 .91525 L closepath p F P
0 g
s
.684 .912 .973 r
.72934 .90952 m .72516 .9112 L .71948 .91525 L p F P
0 g
s
.684 .912 .973 r
.73196 .9103 m .72934 .90952 L p .71948 .91525 L F P
0 g
s
.459 .538 .85 r
.73153 .70108 m .72484 .69982 L .7222 .69457 L p F P
0 g
s
.562 .684 .921 r
.65583 .65387 m .65082 .65444 L .64793 .65047 L p F P
0 g
s
.525 .49 .76 r
.60787 .85106 m .6018 .85035 L .60661 .84754 L closepath p F P
0 g
s
.526 .482 .75 r
.60478 .84236 m .60661 .84754 L .6018 .85035 L p F P
0 g
s
.526 .482 .75 r
.59948 .84155 m .60478 .84236 L p .6018 .85035 L F P
0 g
s
.42 .358 .682 r
.58324 .76905 m .58279 .76715 L .58431 .76819 L closepath p F P
0 g
s
.269 .202 .594 r
.7868 .82405 m .78917 .82918 L .78456 .83405 L p F P
0 g
s
.238 .156 .556 r
.7844 .84124 m .78618 .83939 L .78456 .83405 L p F P
0 g
s
.236 .156 .558 r
.78917 .82918 m .78456 .83405 L .78618 .83939 L p F P
0 g
s
.827 .754 .783 r
.17784 .87447 m .17231 .88056 L .16871 .87682 L p F P
0 g
s
.827 .754 .783 r
.16871 .87682 m .17312 .8719 L .17784 .87447 L p F P
0 g
s
.82 .751 .787 r
.18003 .86434 m .17312 .8719 L .17784 .87447 L p F P
0 g
s
.82 .751 .787 r
.18144 .86507 m .18003 .86434 L p .17784 .87447 L F P
0 g
s
.814 .977 .895 r
.61027 .65517 m .607 .65735 L .60415 .65727 L p F P
0 g
s
.837 .992 .855 r
.60039 .66359 m .607 .65735 L .60415 .65727 L p F P
0 g
s
.717 .786 .907 r
.10837 .91587 m .11532 .91242 L .11997 .91498 L p F P
0 g
s
.711 .784 .909 r
.11941 .91043 m .11532 .91242 L .11997 .91498 L p F P
0 g
s
.711 .784 .909 r
.11997 .91498 m .12314 .91347 L .11941 .91043 L p F P
0 g
s
.425 .366 .688 r
.58431 .76819 m .58324 .76905 L .58505 .77634 L p F P
0 g
s
.847 .743 .748 r
.19733 .83315 m .20065 .82855 L .19713 .82435 L p F P
0 g
s
.837 .992 .855 r
.60415 .65727 m .60288 .65873 L .60039 .66359 L p F P
0 g
s
0 0 0 r
.59549 .67043 m .59556 .6703 L .60039 .66359 L p F P
0 g
s
0 0 0 r
.60039 .66359 m .60288 .65873 L p .59549 .67043 L F P
0 g
s
.483 .571 .868 r
.70404 .68187 m .71442 .68297 L .7119 .6877 L p F P
0 g
s
.484 .574 .87 r
.71442 .68297 m .70404 .68187 L .70207 .67829 L p F P
0 g
s
.478 .422 .716 r
.59229 .80309 m .58743 .80138 L .5911 .79892 L closepath p F P
0 g
s
.482 .414 .705 r
.58914 .79194 m .5911 .79892 L .58743 .80138 L p F P
0 g
s
.482 .414 .705 r
.58839 .79164 m .58914 .79194 L p .58743 .80138 L F P
0 g
s
.534 .52 .786 r
.6261 .8687 m .62892 .8754 L .61707 .87492 L p F P
0 g
s
.534 .52 .786 r
.61707 .87492 m .6168 .87426 L .6261 .8687 L p F P
0 g
s
.55 .537 .794 r
.61707 .87492 m .62892 .8754 L p .62352 .8822 L F P
0 g
s
.439 .498 .823 r
.74582 .72062 m .74462 .72029 L .74524 .71933 L closepath p F P
0 g
s
.452 .515 .832 r
.74462 .72029 m .74524 .71933 L .74292 .71437 L p F P
0 g
s
.311 .275 .656 r
.78708 .80674 m .78463 .80947 L .78832 .81421 L p F P
0 g
s
.331 .304 .678 r
.7856 .80094 m .78474 .80001 L p .78463 .80947 L F P
0 g
s
.331 .304 .678 r
.78463 .80947 m .78708 .80674 L .7856 .80094 L p F P
0 g
s
.377 .393 .749 r
.77613 .77002 m .77421 .76886 L .77527 .7675 L closepath p F P
0 g
s
.393 .415 .764 r
.77309 .76145 m .77095 .7603 L p .77421 .76886 L F P
0 g
s
.393 .415 .764 r
.77421 .76886 m .77527 .7675 L .77309 .76145 L p F P
0 g
s
.533 .518 .785 r
.62588 .86819 m .6261 .8687 L .6168 .87426 L p F P
0 g
s
.533 .518 .785 r
.6168 .87426 m .61401 .86733 L .62588 .86819 L p F P
0 g
s
.899 .746 .683 r
.21116 .76899 m .21123 .76885 L .21061 .76839 L closepath p F P
0 g
s
.903 .742 .672 r
.20763 .76506 m .21001 .75963 L p .21123 .76885 L F P
0 g
s
.903 .742 .672 r
.21123 .76885 m .21061 .76839 L .20763 .76506 L p F P
0 g
s
.889 .749 .702 r
.20786 .77531 m .21116 .76899 L .21061 .76839 L p F P
0 g
s
.185 .055 .459 r
.78497 .8471 m .78206 .84988 L .78207 .85567 L p F P
0 g
s
.23 .122 .517 r
.78206 .84988 m .78497 .8471 L .7844 .84124 L p F P
0 g
s
.479 .563 .863 r
.7119 .6877 m .71908 .68864 L .7162 .68319 L p F P
0 g
s
.479 .563 .863 r
.7162 .68319 m .71442 .68297 L .7119 .6877 L p F P
0 g
s
.834 .745 .767 r
.19186 .8498 m .19223 .84935 L .18868 .84525 L p F P
0 g
s
.596 .69 .907 r
.67429 .91468 m .67346 .91353 L .67701 .91296 L closepath p F P
0 g
s
.839 .751 .767 r
.1871 .8472 m .19186 .8498 L .1859 .85708 L p F P
0 g
s
.834 .745 .767 r
.18868 .84525 m .1871 .8472 L .19186 .8498 L p F P
0 g
s
.814 .977 .895 r
.60415 .65727 m .61264 .65033 L .61027 .65517 L p F P
0 g
s
.746 .868 .937 r
.61573 .64832 m .61264 .65033 L .61027 .65517 L p F P
0 g
s
.746 .868 .937 r
.61027 .65517 m .61861 .65054 L .61573 .64832 L p F P
0 g
s
.556 .551 .803 r
.62352 .8822 m .63195 .88229 L p .63373 .88891 L F P
0 g
s
.549 .547 .805 r
.63195 .88229 m .62352 .8822 L .63021 .87834 L closepath p F P
0 g
s
.55 .537 .794 r
.62892 .8754 m .63021 .87834 L .62352 .8822 L p F P
0 g
s
.801 .772 .826 r
.15297 .89832 m .14932 .90147 L .14566 .89811 L p F P
0 g
s
.599 .057 0 r
.04285 .89839 m .04368 .8992 L .03979 .8964 L p F P
0 g
s
.599 .057 0 r
.03979 .8964 m .03892 .89557 L .04285 .89839 L p F P
0 g
s
.08 0 .424 r
.58795 .69428 m .58895 .693 L .58879 .68756 L p F P
0 g
s
.033 0 .407 r
.5925 .68238 m .58879 .68756 L .58895 .693 L p F P
0 g
s
0 0 .291 r
.58879 .68756 m .5925 .68238 L .59331 .67665 L p F P
0 g
s
.808 .758 .807 r
.1707 .88209 m .17231 .88056 L .16871 .87682 L p F P
0 g
s
.801 .772 .826 r
.14566 .89811 m .14836 .89574 L .15297 .89832 L p F P
0 g
s
.794 .767 .828 r
.15712 .88822 m .14836 .89574 L .15297 .89832 L p F P
0 g
s
.794 .767 .828 r
.15297 .89832 m .16075 .89175 L .15712 .88822 L p F P
0 g
s
.517 .478 .752 r
.60478 .84236 m .59948 .84155 L .60365 .83906 L closepath p F P
0 g
s
.519 .47 .741 r
.60167 .83325 m .60365 .83906 L .59948 .84155 L p F P
0 g
s
.519 .47 .741 r
.59794 .83253 m .60167 .83325 L p .59948 .84155 L F P
0 g
s
.816 .766 .806 r
.16589 .87955 m .1707 .88209 L .16252 .89001 L p F P
0 g
s
.808 .758 .807 r
.16871 .87682 m .16589 .87955 L .1707 .88209 L p F P
0 g
s
.506 .604 .885 r
.68925 .67123 m .69829 .67167 L .69541 .6667 L p F P
0 g
s
.506 .604 .885 r
.69541 .6667 m .69143 .66654 L .68925 .67123 L p F P
0 g
s
.507 .61 .889 r
.68334 .66635 m .69143 .66654 L .68925 .67123 L p F P
0 g
s
.916 .754 .666 r
.20769 .74113 m .21137 .7442 L .20883 .75039 L p F P
0 g
s
.918 .751 .659 r
.21137 .7442 m .20769 .74113 L .21011 .73498 L p F P
0 g
s
.556 .76 .973 r
.0793 .91573 m .08993 .91393 L .09374 .91673 L p F P
0 g
s
.561 .762 .972 r
.08993 .91393 m .0793 .91573 L .07546 .91301 L p F P
0 g
s
.422 .475 .809 r
.75125 .7279 m .76028 .73097 L .75715 .73573 L p F P
0 g
s
.424 .481 .815 r
.75416 .72319 m .75125 .7279 L .76028 .73097 L p F P
0 g
s
.43 .49 .82 r
.74582 .72062 m .75416 .72319 L .75125 .7279 L p F P
0 g
s
.885 .746 .703 r
.20445 .7818 m .20861 .78467 L .20514 .79117 L p F P
0 g
s
.884 .744 .702 r
.20861 .78467 m .20445 .7818 L .20786 .77531 L p F P
0 g
s
.387 .411 .764 r
.77309 .76145 m .77095 .7603 L .77211 .75875 L closepath p F P
0 g
s
.402 .433 .778 r
.77009 .7534 m .76701 .75192 L p .77095 .7603 L F P
0 g
s
.402 .433 .778 r
.77095 .7603 m .77211 .75875 L .77009 .7534 L p F P
0 g
s
.154 .07 .5 r
.58569 .70352 m .58843 .70013 L .58795 .69428 L p F P
0 g
s
.197 .127 .546 r
.58843 .70013 m .58569 .70352 L .58732 .70856 L p F P
0 g
s
.889 .749 .702 r
.21061 .76839 m .20719 .76592 L p .20786 .77531 L F P
0 g
s
.891 .746 .695 r
.21061 .76839 m .20763 .76506 L .20719 .76592 L closepath p F P
0 g
s
.755 .782 .875 r
.13432 .90654 m .12314 .91347 L .11941 .91043 L p F P
0 g
s
.817 .766 .805 r
.16252 .89001 m .16075 .89175 L .15712 .88822 L p F P
0 g
s
.817 .766 .805 r
.15712 .88822 m .15793 .88742 L .16252 .89001 L p F P
0 g
s
.816 .766 .806 r
.16252 .89001 m .15793 .88742 L .16589 .87955 L p F P
0 g
s
.426 .49 .822 r
.75416 .72319 m .74582 .72062 L .74524 .71933 L p F P
0 g
s
.847 .743 .748 r
.19713 .82435 m .19274 .83047 L .19733 .83315 L p F P
0 g
s
.853 .748 .747 r
.19274 .83047 m .19733 .83315 L .19231 .84014 L p F P
0 g
s
0 0 0 r
.76684 .88412 m .76985 .87987 L .76763 .88181 L closepath p F P
0 g
s
0 0 .155 r
.76763 .88181 m .76985 .87987 L .77347 .87311 L p F P
0 g
s
.561 .573 .823 r
.64708 .89481 m .63797 .89512 L .63497 .88889 L p F P
0 g
s
.199 .1 .51 r
.78618 .83939 m .7844 .84124 L .78497 .8471 L p F P
0 g
s
.444 .382 .693 r
.58505 .77634 m .59042 .77207 L p .5894 .78186 L F P
0 g
s
.444 .382 .693 r
.5894 .78186 m .58597 .78 L .58505 .77634 L p F P
0 g
s
.425 .366 .688 r
.58505 .77634 m .59042 .77207 L .58431 .76819 L p F P
0 g
s
.373 .311 .658 r
.58661 .74083 m .58325 .7439 L .58767 .7482 L p F P
0 g
s
.367 .301 .651 r
.58325 .7439 m .58661 .74083 L .58519 .73395 L p F P
0 g
s
.419 .367 .694 r
.59141 .76226 m .58431 .76819 L .59042 .77207 L p F P
0 g
s
.426 .357 .677 r
.58606 .75819 m .59141 .76226 L .58431 .76819 L p F P
0 g
s
.414 .459 .798 r
.75715 .73573 m .76415 .73838 L p .7624 .74373 L F P
0 g
s
.411 .461 .802 r
.75715 .73573 m .76415 .73838 L .76121 .73132 L p F P
0 g
s
.411 .461 .802 r
.76121 .73132 m .76028 .73097 L .75715 .73573 L p F P
0 g
s
.396 .429 .778 r
.77009 .7534 m .76701 .75192 L .76866 .74964 L closepath p F P
0 g
s
.411 .45 .79 r
.76711 .74574 m .7624 .74373 L p .76701 .75192 L F P
0 g
s
.411 .45 .79 r
.76701 .75192 m .76866 .74964 L .76711 .74574 L p F P
0 g
s
.047 0 .279 r
.78109 .86173 m .77719 .86544 L .77675 .87024 L p F P
0 g
s
.125 0 .383 r
.77719 .86544 m .78109 .86173 L .78207 .85567 L p F P
0 g
s
.088 0 .293 r
.77347 .87311 m .77675 .87024 L .77719 .86544 L p F P
0 g
s
.868 .745 .725 r
.19748 .814 m .20188 .81675 L .19766 .82351 L p F P
0 g
s
.865 .743 .726 r
.20188 .81675 m .19748 .814 L .20167 .80726 L p F P
0 g
s
.878 .744 .71 r
.20577 .80072 m .20588 .80052 L .20522 .80008 L closepath p F P
0 g
s
.881 .741 .703 r
.20224 .79657 m .20514 .79117 L p .20588 .80052 L F P
0 g
s
.881 .741 .703 r
.20588 .80052 m .20522 .80008 L .20224 .79657 L p F P
0 g
s
.405 .446 .79 r
.76711 .74574 m .7624 .74373 L .76489 .74015 L closepath p F P
0 g
s
.414 .459 .798 r
.76415 .73838 m .76489 .74015 L .7624 .74373 L p F P
0 g
s
.866 .746 .728 r
.20167 .80726 m .20577 .80072 L .20522 .80008 L p F P
0 g
s
.426 .49 .822 r
.74524 .71933 m .74741 .71558 L p .75416 .72319 L F P
0 g
s
.434 .504 .832 r
.74524 .71933 m .74292 .71437 L .74741 .71558 L closepath p F P
0 g
s
.599 .671 .89 r
.67701 .91296 m .67346 .91353 L .67057 .90918 L p F P
0 g
s
.56 .934 .895 r
.74313 .90426 m .73196 .9103 L .72934 .90952 L p F P
0 g
s
.525 .507 .778 r
.62282 .86062 m .62588 .86819 L .61401 .86733 L p F P
0 g
s
.525 .507 .778 r
.62079 .86042 m .62282 .86062 L p .61401 .86733 L F P
0 g
s
.525 .507 .778 r
.61401 .86733 m .61316 .86511 L .62079 .86042 L p F P
0 g
s
0 0 0 r
.59543 .67054 m .59549 .67043 L .59556 .6703 L closepath p F P
0 g
s
0 0 0 r
.59549 .67043 m .59543 .67054 L .59331 .67665 L p F P
0 g
s
0 .25 .682 r
.04368 .8992 m .04892 .90222 L .05293 .90502 L p F P
0 g
s
0 .263 .7 r
.04892 .90222 m .04368 .8992 L .03979 .8964 L p F P
0 g
s
.44 .384 .699 r
.58695 .78375 m .58597 .78 L .5894 .78186 L closepath p F P
0 g
s
.84 .75 .764 r
.1859 .85708 m .18041 .86392 L .17683 .86005 L p F P
0 g
s
.84 .75 .764 r
.17683 .86005 m .18127 .85445 L .1859 .85708 L p F P
0 g
s
.839 .751 .767 r
.1859 .85708 m .18127 .85445 L .1871 .8472 L p F P
0 g
s
.301 .231 .609 r
.58397 .72728 m .58755 .72359 L .5847 .71887 L p F P
0 g
s
.339 .268 .629 r
.58397 .72728 m .58755 .72359 L p .58539 .73376 L F P
0 g
s
.339 .268 .629 r
.58539 .73376 m .58508 .73334 L .58397 .72728 L p F P
0 g
s
.342 .343 .716 r
.78075 .78406 m .78256 .78171 L p .78401 .79076 L F P
0 g
s
.342 .343 .716 r
.78401 .79076 m .78235 .78939 L .78075 .78406 L p F P
0 g
s
.353 .364 .732 r
.78075 .78406 m .77921 .77926 L .78256 .78171 L closepath p F P
0 g
s
.352 .364 .732 r
.78256 .78171 m .77921 .77926 L .77814 .77593 L p F P
0 g
s
.352 .364 .732 r
.77814 .77593 m .78045 .77282 L p .78256 .78171 L F P
0 g
s
.363 .383 .748 r
.77814 .77593 m .77613 .77002 L .78045 .77282 L closepath p F P
0 g
s
.576 .604 .843 r
.65281 .90031 m .65563 .90539 L .6551 .9057 L p F P
0 g
s
.575 .615 .855 r
.65576 .90564 m .6551 .9057 L .65563 .90539 L closepath p F P
0 g
s
0 0 .004 r
.59865 .66547 m .59549 .67043 L .5945 .67464 L p F P
0 g
s
0 0 0 r
.59865 .66547 m .59641 .67162 L p .59925 .66456 L F P
0 g
s
0 0 0 r
.60288 .65873 m .59865 .66547 L p .59806 .66636 L F P
0 g
s
.691 .82 .373 r
.60341 .65749 m .60288 .65873 L .59865 .66547 L p F P
0 g
s
.691 .82 .373 r
.60135 .65963 m .60341 .65749 L p .59865 .66547 L F P
0 g
s
.691 .82 .373 r
.60081 .66069 m .60135 .65963 L p .60023 .66204 L F P
0 g
s
.691 .82 .373 r
.59865 .66547 m .60081 .66069 L p .60023 .66204 L F P
0 g
s
0 0 0 r
.60081 .66069 m .59888 .66676 L p .60097 .66032 L F P
0 g
s
.75 .86 .426 r
.60081 .66069 m .60103 .66014 L .60135 .65963 L closepath p F P
0 g
s
0 0 0 r
.60103 .66014 m .60081 .66069 L p .60097 .66032 L F P
0 g
s
0 0 0 r
.60081 .66069 m .59865 .66547 L p .59925 .66456 L F P
0 g
s
0 0 0 r
.59865 .66547 m .59549 .67043 L p .59806 .66636 L F P
0 g
s
0 0 0 r
.59331 .67665 m .5945 .67464 L .59549 .67043 L p F P
0 g
s
.525 .505 .777 r
.61316 .86511 m .61095 .85938 L .62079 .86042 L closepath p F P
0 g
s
.907 .75 .676 r
.21001 .75963 m .20763 .76506 L .20405 .76146 L p F P
0 g
s
.907 .75 .676 r
.20405 .76146 m .20618 .75663 L .21001 .75963 L p F P
0 g
s
.909 .748 .671 r
.21001 .75963 m .20618 .75663 L .20883 .75039 L p F P
0 g
s
.821 .749 .784 r
.18144 .86507 m .18041 .86392 L .18003 .86434 L closepath p F P
0 g
s
.721 .789 .906 r
.11532 .91242 m .10837 .91587 L .1046 .91296 L p F P
0 g
s
.658 .782 .94 r
.09374 .91673 m .1046 .91296 L .10837 .91587 L p F P
0 g
s
.662 .784 .939 r
.1046 .91296 m .09374 .91673 L .08993 .91393 L p F P
0 g
s
.342 .343 .715 r
.78311 .7919 m .78235 .78939 L .78401 .79076 L closepath p F P
0 g
s
0 0 .106 r
.77675 .87024 m .77347 .87311 L .76985 .87987 L p F P
0 g
s
.866 .746 .728 r
.20522 .80008 m .20153 .79773 L p .20167 .80726 L F P
0 g
s
.868 .743 .723 r
.20522 .80008 m .20224 .79657 L .20153 .79773 L closepath p F P
0 g
s
.509 .465 .744 r
.60167 .83325 m .59794 .83253 L .60085 .83074 L closepath p F P
0 g
s
.511 .457 .733 r
.59856 .82371 m .60085 .83074 L .59794 .83253 L p F P
0 g
s
.511 .457 .733 r
.59698 .82334 m .59856 .82371 L p .59794 .83253 L F P
0 g
s
.363 .384 .748 r
.78045 .77282 m .77613 .77002 L .77527 .7675 L p F P
0 g
s
.459 .538 .85 r
.7222 .69457 m .7224 .69418 L p .73153 .70108 L F P
0 g
s
.466 .55 .858 r
.7222 .69457 m .72196 .69411 L .7224 .69418 L closepath p F P
0 g
s
.272 .217 .611 r
.58948 .71347 m .5847 .71887 L .58755 .72359 L p F P
0 g
s
.247 .177 .577 r
.5847 .71887 m .58948 .71347 L .58732 .70856 L p F P
0 g
s
.323 .315 .696 r
.78401 .79076 m .78311 .7919 L .78522 .79946 L p F P
0 g
s
.345 .33 .699 r
.78474 .80001 m .78522 .79946 L .78311 .7919 L p F P
0 g
s
.324 .3 .677 r
.7856 .80094 m .78474 .80001 L .78522 .79946 L closepath p F P
0 g
s
.574 .644 .882 r
.65576 .90564 m .66766 .90451 L .67057 .90918 L p F P
0 g
s
.567 .611 .856 r
.66482 .8997 m .66766 .90451 L .65576 .90564 L p F P
0 g
s
.567 .611 .856 r
.65576 .90564 m .65563 .90539 L .66482 .8997 L p F P
0 g
s
.484 .574 .87 r
.70207 .67829 m .70275 .67682 L p .71442 .68297 L F P
0 g
s
.489 .585 .877 r
.70207 .67829 m .70116 .67668 L .70275 .67682 L closepath p F P
0 g
s
.442 .388 .702 r
.5894 .78186 m .58695 .78375 L .58895 .79125 L p F P
0 g
s
.464 .403 .703 r
.58839 .79164 m .58895 .79125 L .58695 .78375 L p F P
0 g
s
.615 .715 .917 r
.63323 .64931 m .64504 .64661 L .64793 .65047 L p F P
0 g
s
.63 .73 .92 r
.64504 .64661 m .63323 .64931 L .63033 .64601 L p F P
0 g
s
.68 .776 .923 r
.61861 .65054 m .63033 .64601 L .63323 .64931 L p F P
0 g
s
.51 .614 .892 r
.69143 .66654 m .68334 .66635 L .68046 .66162 L p F P
0 g
s
.363 .384 .748 r
.77527 .7675 m .7777 .7641 L p .78045 .77282 L F P
0 g
s
.373 .402 .762 r
.77527 .7675 m .77309 .76145 L .7777 .7641 L closepath p F P
0 g
s
.543 .646 .901 r
.67758 .65695 m .6656 .65751 L .66271 .65315 L p F P
0 g
s
.532 .641 .903 r
.6656 .65751 m .67758 .65695 L p .67535 .66172 L F P
0 g
s
.572 .68 .913 r
.65583 .65387 m .66271 .65315 L .65982 .64887 L p F P
0 g
s
.572 .68 .913 r
.65982 .64887 m .65806 .6491 L .65583 .65387 L p F P
0 g
s
.562 .684 .921 r
.64793 .65047 m .65806 .6491 L .65583 .65387 L p F P
0 g
s
.567 .61 .855 r
.66473 .89956 m .66482 .8997 L .65563 .90539 L p F P
0 g
s
.567 .61 .855 r
.65563 .90539 m .65281 .90031 L .66473 .89956 L p F P
0 g
s
.464 .552 .861 r
.7224 .69418 m .72196 .69411 L .71908 .68864 L p F P
0 g
s
.709 .8 .922 r
.63033 .64601 m .61861 .65054 L .61573 .64832 L p F P
0 g
s
.143 .062 .497 r
.58895 .693 m .58795 .69428 L .58843 .70013 L p F P
0 g
s
.467 .408 .708 r
.58914 .79194 m .58839 .79164 L .58895 .79125 L closepath p F P
0 g
s
.299 .658 .971 r
.06128 .90948 m .06829 .91015 L .07241 .91289 L p F P
0 g
s
.313 .662 .973 r
.06829 .91015 m .06128 .90948 L .05741 .90677 L p F P
0 g
s
.265 .201 .596 r
.7901 .82051 m .7868 .82405 L .78917 .82918 L p F P
0 g
s
.292 .241 .628 r
.78906 .81544 m .78832 .81421 L p .7868 .82405 L F P
0 g
s
.292 .241 .628 r
.7868 .82405 m .7901 .82051 L .78906 .81544 L p F P
0 g
s
.53 .628 .893 r
.68046 .66162 m .67535 .66172 L .67766 .65708 L closepath p F P
0 g
s
.532 .641 .903 r
.67758 .65695 m .67766 .65708 L .67535 .66172 L p F P
0 g
s
.459 .538 .85 r
.7224 .69418 m .73418 .69635 L .73153 .70108 L p F P
0 g
s
.463 .545 .855 r
.72471 .68953 m .7224 .69418 L .73418 .69635 L p F P
0 g
s
.464 .552 .861 r
.71908 .68864 m .72471 .68953 L .7224 .69418 L p F P
0 g
s
.89 .752 .703 r
.20383 .77239 m .20786 .77531 L .20445 .7818 L p F P
0 g
s
.889 .749 .702 r
.20719 .76592 m .20383 .77239 L .20786 .77531 L p F P
0 g
s
.527 .499 .769 r
.62079 .86042 m .61095 .85938 L .60977 .85622 L p F P
0 g
s
.556 .56 .813 r
.63497 .88889 m .63373 .88891 L .63472 .88835 L closepath p F P
0 g
s
.556 .551 .803 r
.63195 .88229 m .63472 .88835 L .63373 .88891 L p F P
0 g
s
.853 .748 .746 r
.19231 .84014 m .18868 .84525 L .18512 .84128 L p F P
0 g
s
.853 .748 .746 r
.18512 .84128 m .18781 .83745 L .19231 .84014 L p F P
0 g
s
.853 .748 .747 r
.19231 .84014 m .18781 .83745 L .19274 .83047 L p F P
0 g
s
.373 .403 .763 r
.7777 .7641 m .77309 .76145 L .77211 .75875 L p F P
0 g
s
0 .439 .845 r
.05293 .90502 m .05741 .90677 L .05353 .904 L p F P
0 g
s
0 .439 .845 r
.05353 .904 m .04892 .90222 L .05293 .90502 L p F P
0 g
s
.307 .289 .675 r
.78522 .79946 m .78862 .79524 L p .78883 .80463 L F P
0 g
s
.307 .289 .675 r
.78883 .80463 m .7856 .80094 L .78522 .79946 L p F P
0 g
s
.323 .315 .696 r
.78522 .79946 m .78862 .79524 L .78401 .79076 L p F P
0 g
s
.823 .754 .786 r
.18003 .86434 m .18041 .86392 L .17683 .86005 L p F P
0 g
s
.527 .499 .769 r
.60977 .85622 m .61613 .85222 L p .62079 .86042 L F P
0 g
s
.517 .492 .768 r
.60977 .85622 m .60787 .85106 L .61613 .85222 L closepath p F P
0 g
s
.829 .76 .786 r
.1753 .86174 m .18003 .86434 L .17312 .8719 L p F P
0 g
s
.823 .754 .786 r
.17683 .86005 m .1753 .86174 L .18003 .86434 L p F P
0 g
s
.46 .403 .707 r
.58895 .79125 m .59641 .78553 L p .59625 .79509 L F P
0 g
s
.46 .403 .707 r
.59625 .79509 m .58914 .79194 L .58895 .79125 L p F P
0 g
s
.442 .388 .702 r
.58895 .79125 m .59641 .78553 L .5894 .78186 L p F P
0 g
s
.606 .767 .957 r
.6882 .91525 m .70011 .91266 L .70289 .91555 L p F P
0 g
s
.597 .737 .942 r
.70011 .91266 m .6882 .91525 L .68536 .91161 L p F P
0 g
s
.373 .403 .763 r
.77211 .75875 m .7743 .75555 L p .7777 .7641 L F P
0 g
s
.383 .421 .776 r
.77211 .75875 m .77009 .7534 L .7743 .75555 L closepath p F P
0 g
s
.597 .691 .908 r
.68536 .91161 m .67701 .91296 L .68343 .90891 L closepath p F P
0 g
s
.599 .671 .89 r
.6825 .90761 m .68343 .90891 L .67701 .91296 L p F P
0 g
s
.599 .671 .89 r
.67057 .90918 m .6825 .90761 L p .67701 .91296 L F P
0 g
s
.488 .587 .88 r
.70275 .67682 m .70116 .67668 L .69829 .67167 L p F P
0 g
s
.456 .406 .714 r
.5911 .79892 m .58914 .79194 L .59625 .79509 L closepath p F P
0 g
s
.884 .747 .705 r
.20514 .79117 m .20224 .79657 L .19868 .79265 L p F P
0 g
s
.884 .747 .705 r
.19868 .79265 m .20101 .7883 L .20514 .79117 L p F P
0 g
s
.885 .746 .703 r
.20514 .79117 m .20101 .7883 L .20445 .7818 L p F P
0 g
s
.308 .289 .675 r
.78708 .80674 m .7856 .80094 L .78883 .80463 L closepath p F P
0 g
s
.786 .782 .849 r
.13691 .90459 m .13432 .90654 L .13062 .90337 L p F P
0 g
s
.755 .782 .875 r
.11941 .91043 m .13062 .90337 L .13432 .90654 L p F P
0 g
s
.384 .695 .982 r
.07241 .91289 m .07546 .91301 L .07162 .91025 L p F P
0 g
s
.384 .695 .982 r
.07162 .91025 m .06829 .91015 L .07241 .91289 L p F P
0 g
s
.561 .573 .823 r
.63497 .88889 m .64686 .88876 L p .64708 .89481 L F P
0 g
s
.544 .554 .814 r
.64392 .88267 m .64686 .88876 L .63497 .88889 L p F P
0 g
s
.544 .554 .814 r
.63497 .88889 m .63472 .88835 L .64392 .88267 L p F P
0 g
s
.434 .504 .832 r
.74741 .71558 m .74292 .71437 L .74003 .70817 L p F P
0 g
s
.865 .747 .73 r
.19713 .82435 m .19766 .82351 L .19476 .82167 L closepath p F P
0 g
s
.868 .745 .725 r
.19358 .82031 m .19748 .814 L p .19766 .82351 L F P
0 g
s
.868 .745 .725 r
.19766 .82351 m .19476 .82167 L .19358 .82031 L p F P
0 g
s
.87 .749 .727 r
.19735 .80447 m .20167 .80726 L .19748 .814 L p F P
0 g
s
.866 .746 .728 r
.20153 .79773 m .19735 .80447 L .20167 .80726 L p F P
0 g
s
.622 .884 .989 r
.72516 .9112 m .7175 .91413 L .71478 .91212 L p F P
0 g
s
.617 .842 .985 r
.70289 .91555 m .71478 .91212 L .7175 .91413 L p F P
0 g
s
.914 .756 .671 r
.20514 .74732 m .20883 .75039 L .20618 .75663 L p F P
0 g
s
.916 .754 .666 r
.20883 .75039 m .20514 .74732 L .20769 .74113 L p F P
0 g
s
.786 .782 .849 r
.13062 .90337 m .13244 .90196 L .13691 .90459 L p F P
0 g
s
.778 .777 .851 r
.14198 .89479 m .13244 .90196 L .13691 .90459 L p F P
0 g
s
.778 .777 .851 r
.13691 .90459 m .14566 .89811 L .14198 .89479 L p F P
0 g
s
.571 .696 .926 r
.65806 .6491 m .64793 .65047 L .64504 .64661 L p F P
0 g
s
.544 .552 .814 r
.64386 .88255 m .64392 .88267 L .63472 .88835 L p F P
0 g
s
.544 .552 .814 r
.63472 .88835 m .63195 .88229 L .64386 .88255 L p F P
0 g
s
.33 .265 .631 r
.58519 .73395 m .58508 .73334 L .58539 .73376 L closepath p F P
0 g
s
.519 .487 .76 r
.61613 .85222 m .60787 .85106 L .60661 .84754 L p F P
0 g
s
.852 .749 .749 r
.19274 .83047 m .19713 .82435 L .19476 .82167 L p F P
0 g
s
.5 .453 .736 r
.59856 .82371 m .59698 .82334 L .5982 .82257 L closepath p F P
0 g
s
.502 .445 .725 r
.5957 .81454 m .5982 .82257 L .59698 .82334 L p F P
0 g
s
.471 .418 .716 r
.5911 .79892 m .59625 .79509 L p .59623 .80459 L F P
0 g
s
.471 .418 .716 r
.59623 .80459 m .59229 .80309 L .5911 .79892 L p F P
0 g
s
.344 .286 .647 r
.58539 .73376 m .58519 .73395 L .58661 .74083 L p F P
0 g
s
.327 .323 .702 r
.78773 .78601 m .78401 .79076 L .78862 .79524 L p F P
0 g
s
.342 .343 .716 r
.78256 .78171 m .78773 .78601 L .78401 .79076 L p F P
0 g
s
.612 .804 .973 r
.71478 .91212 m .70289 .91555 L .70011 .91266 L p F P
0 g
s
.126 0 .383 r
.78524 .85265 m .78207 .85567 L .78109 .86173 L p F P
0 g
s
.185 .055 .459 r
.78207 .85567 m .78524 .85265 L .78497 .8471 L p F P
0 g
s
.519 .487 .76 r
.60661 .84754 m .61252 .84373 L p .61613 .85222 L F P
0 g
s
.508 .479 .76 r
.60661 .84754 m .60478 .84236 L .61252 .84373 L closepath p F P
0 g
s
.831 .759 .783 r
.17312 .8719 m .16871 .87682 L .16509 .87316 L p F P
0 g
s
.831 .759 .783 r
.16509 .87316 m .16854 .86927 L .17312 .8719 L p F P
0 g
s
.829 .76 .786 r
.17312 .8719 m .16854 .86927 L .1753 .86174 L p F P
0 g
s
.199 .1 .51 r
.78497 .8471 m .78705 .84495 L .78618 .83939 L p F P
0 g
s
.197 .099 .51 r
.79084 .83452 m .78618 .83939 L .78705 .84495 L p F P
0 g
s
.236 .156 .558 r
.78618 .83939 m .79084 .83452 L .78917 .82918 L p F P
0 g
s
.4 .344 .68 r
.58977 .75496 m .58606 .75819 L .59141 .76226 L p F P
0 g
s
.396 .338 .675 r
.58833 .74878 m .58767 .7482 L p .58606 .75819 L F P
0 g
s
.396 .338 .675 r
.58606 .75819 m .58977 .75496 L .58833 .74878 L p F P
0 g
s
.382 .421 .777 r
.7743 .75555 m .77009 .7534 L .76866 .74964 L p F P
0 g
s
.721 .789 .906 r
.1046 .91296 m .11082 .90981 L .11532 .91242 L p F P
0 g
s
.715 .786 .908 r
.11566 .90739 m .11082 .90981 L .11532 .91242 L p F P
0 g
s
.715 .786 .908 r
.11532 .91242 m .11941 .91043 L .11566 .90739 L p F P
0 g
s
.838 .751 .767 r
.1871 .8472 m .18868 .84525 L .18512 .84128 L p F P
0 g
s
.32 .274 .649 r
.59075 .72822 m .58539 .73376 L .58928 .7382 L p F P
0 g
s
.339 .268 .629 r
.58755 .72359 m .59075 .72822 L .58539 .73376 L p F P
0 g
s
.344 .286 .647 r
.58661 .74083 m .58928 .7382 L .58539 .73376 L p F P
0 g
s
.56 .934 .895 r
.74357 .90394 m .74313 .90426 L p .72934 .90952 L F P
0 g
s
.581 .943 .834 r
.74313 .90426 m .74357 .90394 L .74371 .90392 L closepath p F P
0 g
s
.467 .421 .723 r
.59335 .80668 m .59229 .80309 L .59623 .80459 L closepath p F P
0 g
s
0 0 0 r
.76985 .87987 m .77564 .8748 L p .76619 .88558 L F P
0 g
s
0 0 0 r
.76619 .88558 m .76684 .88412 L .76985 .87987 L p F P
0 g
s
0 0 .106 r
.77595 .87427 m .77675 .87024 L p .76985 .87987 L F P
0 g
s
0 0 .106 r
.76985 .87987 m .77564 .8748 L .77595 .87427 L p F P
0 g
s
.897 .755 .697 r
.20719 .76592 m .20763 .76506 L .20405 .76146 L p F P
0 g
s
0 0 0 r
.74371 .90392 m .75538 .8957 L .75558 .89553 L p F P
0 g
s
.667 .974 .836 r
.74357 .90394 m .74371 .90392 L .75538 .8957 L p F P
0 g
s
.484 .574 .87 r
.70275 .67682 m .71333 .67791 L p .71442 .68297 L F P
0 g
s
.484 .581 .876 r
.70275 .67682 m .71333 .67791 L .71045 .67273 L p F P
0 g
s
.484 .581 .876 r
.71045 .67273 m .7048 .67219 L .70275 .67682 L p F P
0 g
s
.488 .587 .88 r
.69829 .67167 m .7048 .67219 L .70275 .67682 L p F P
0 g
s
.286 .258 .652 r
.78883 .80463 m .78708 .80674 L .78872 .81377 L p F P
0 g
s
.311 .275 .656 r
.78832 .81421 m .78872 .81377 L .78708 .80674 L p F P
0 g
s
.143 .062 .497 r
.58843 .70013 m .58994 .69823 L .58895 .693 L p F P
0 g
s
.09 .022 .478 r
.59265 .68784 m .58895 .693 L .58994 .69823 L p F P
0 g
s
.033 0 .407 r
.58895 .693 m .59265 .68784 L .5925 .68238 L p F P
0 g
s
.511 .474 .752 r
.61252 .84373 m .60478 .84236 L .60365 .83906 L p F P
0 g
s
.481 .431 .725 r
.59335 .80668 m .59623 .80459 L p .59645 .81401 L F P
0 g
s
.481 .431 .725 r
.59645 .81401 m .59543 .81368 L .59335 .80668 L p F P
0 g
s
.452 .528 .845 r
.73153 .70108 m .73713 .70226 L .73424 .69636 L p F P
0 g
s
.452 .528 .845 r
.73424 .69636 m .73418 .69635 L .73153 .70108 L p F P
0 g
s
.843 .756 .766 r
.18251 .84455 m .1871 .8472 L .18127 .85445 L p F P
0 g
s
.838 .751 .767 r
.18512 .84128 m .18251 .84455 L .1871 .8472 L p F P
0 g
s
0 0 .236 r
.5945 .67464 m .59331 .67665 L .5925 .68238 L p F P
0 g
s
.511 .474 .752 r
.60365 .83906 m .60976 .83501 L p .61252 .84373 L F P
0 g
s
.499 .466 .751 r
.60365 .83906 m .60167 .83325 L .60976 .83501 L closepath p F P
0 g
s
.895 .758 .702 r
.20331 .76294 m .20719 .76592 L .20383 .77239 L p F P
0 g
s
.897 .755 .697 r
.20405 .76146 m .20331 .76294 L .20719 .76592 L p F P
0 g
s
.812 .762 .807 r
.16589 .87955 m .16871 .87682 L .16509 .87316 L p F P
0 g
s
.15 .03 .45 r
.78705 .84495 m .78497 .8471 L .78524 .85265 L p F P
0 g
s
.667 .974 .836 r
.75294 .89699 m .74967 .89905 L .74357 .90394 L p F P
0 g
s
.667 .974 .836 r
.75538 .8957 m .75294 .89699 L p .74357 .90394 L F P
0 g
s
.639 .964 .896 r
.74117 .90391 m .74967 .89905 L .74357 .90394 L closepath p F P
0 g
s
.56 .934 .895 r
.72934 .90952 m .74117 .90391 L .74357 .90394 L p F P
0 g
s
.382 .421 .777 r
.76866 .74964 m .77028 .74718 L p .7743 .75555 L F P
0 g
s
.392 .438 .789 r
.76866 .74964 m .76711 .74574 L .77028 .74718 L closepath p F P
0 g
s
.822 .769 .803 r
.16123 .87695 m .16589 .87955 L .15793 .88742 L p F P
0 g
s
.812 .762 .807 r
.16509 .87316 m .16123 .87695 L .16589 .87955 L p F P
0 g
s
.805 .775 .825 r
.14836 .89574 m .14566 .89811 L .14198 .89479 L p F P
0 g
s
.478 .435 .732 r
.5957 .81454 m .59543 .81368 L .59645 .81401 L closepath p F P
0 g
s
.48 .438 .734 r
.59645 .81401 m .5957 .81454 L .5982 .82257 L p F P
0 g
s
.502 .461 .744 r
.60976 .83501 m .60167 .83325 L .60085 .83074 L p F P
0 g
s
.805 .775 .825 r
.14198 .89479 m .14386 .89311 L .14836 .89574 L p F P
0 g
s
.798 .77 .828 r
.15343 .88478 m .14386 .89311 L .14836 .89574 L p F P
0 g
s
.798 .77 .828 r
.1536 .88487 m .15343 .88478 L p .14836 .89574 L F P
0 g
s
.798 .77 .828 r
.14836 .89574 m .15712 .88822 L .1536 .88487 L p F P
0 g
s
.49 .453 .743 r
.60085 .83074 m .59856 .82371 L .60767 .8261 L closepath p F P
0 g
s
.502 .461 .744 r
.60085 .83074 m .60767 .8261 L p .60976 .83501 L F P
0 g
s
.493 .448 .736 r
.5982 .82257 m .60611 .81704 L p .60767 .8261 L F P
0 g
s
.493 .448 .736 r
.60767 .8261 m .59856 .82371 L .5982 .82257 L p F P
0 g
s
.48 .438 .734 r
.5982 .82257 m .60611 .81704 L .59645 .81401 L p F P
0 g
s
.574 .661 .896 r
.6825 .90761 m .67057 .90918 L .66766 .90451 L p F P
0 g
s
.437 .39 .708 r
.59537 .77708 m .5894 .78186 L .59641 .78553 L p F P
0 g
s
.444 .382 .693 r
.59473 .7747 m .59537 .77708 L .5894 .78186 L p F P
0 g
s
.444 .382 .693 r
.59042 .77207 m .59473 .7747 L p .5894 .78186 L F P
0 g
s
.557 .606 .858 r
.66473 .89956 m .65281 .90031 L .64985 .89471 L p F P
0 g
s
.819 .77 .807 r
.15712 .88822 m .15793 .88742 L .1536 .88487 L closepath p F P
0 g
s
.822 .769 .803 r
.15347 .88475 m .16123 .87695 L p .15793 .88742 L F P
0 g
s
.822 .769 .803 r
.15793 .88742 m .1536 .88487 L .15347 .88475 L p F P
0 g
s
0 0 0 r
.76431 .88713 m .76619 .88558 L .76684 .88412 L closepath p F P
0 g
s
0 0 0 r
.75538 .8957 m .75612 .89508 L .75558 .89553 L closepath p F P
0 g
s
0 0 0 r
.76431 .88713 m .75612 .89508 L .75558 .89553 L p F P
0 g
s
.891 .753 .704 r
.20044 .77887 m .20445 .7818 L .20101 .7883 L p F P
0 g
s
.89 .752 .703 r
.20445 .7818 m .20044 .77887 L .20383 .77239 L p F P
0 g
s
.852 .749 .749 r
.19326 .82076 m .18831 .82775 L .19274 .83047 L p F P
0 g
s
.852 .749 .749 r
.19476 .82167 m .19326 .82076 L p .19274 .83047 L F P
0 g
s
.858 .753 .747 r
.18831 .82775 m .19274 .83047 L .18781 .83745 L p F P
0 g
s
.872 .751 .726 r
.20153 .79773 m .20224 .79657 L .19868 .79265 L p F P
0 g
s
.285 .237 .627 r
.78906 .81544 m .78832 .81421 L .78872 .81377 L closepath p F P
0 g
s
.339 .346 .72 r
.78616 .77695 m .78256 .78171 L .78773 .78601 L p F P
0 g
s
.352 .364 .732 r
.78045 .77282 m .78616 .77695 L .78256 .78171 L p F P
0 g
s
.464 .553 .862 r
.72471 .68953 m .71908 .68864 L .7162 .68319 L p F P
0 g
s
.758 .785 .875 r
.13062 .90337 m .11941 .91043 L .11566 .90739 L p F P
0 g
s
.226 .167 .578 r
.58918 .70628 m .58732 .70856 L .58948 .71347 L p F P
0 g
s
.197 .127 .546 r
.58732 .70856 m .58918 .70628 L .58843 .70013 L p F P
0 g
s
.561 .762 .972 r
.07546 .91301 m .08612 .91111 L .08993 .91393 L p F P
0 g
s
.566 .763 .971 r
.08612 .91111 m .07546 .91301 L .07162 .91025 L p F P
0 g
s
.391 .438 .789 r
.77028 .74718 m .76711 .74574 L .76489 .74015 L p F P
0 g
s
.536 .54 .806 r
.64084 .87597 m .64386 .88255 L .63195 .88229 L p F P
0 g
s
.536 .54 .806 r
.63442 .87567 m .64084 .87597 L p .63195 .88229 L F P
0 g
s
.536 .54 .806 r
.63195 .88229 m .63021 .87834 L .63442 .87567 L p F P
0 g
s
0 0 0 r
.76619 .88558 m .76431 .88713 L .75612 .89508 L p F P
0 g
s
.478 .44 .738 r
.60443 .80827 m .59645 .81401 L .60611 .81704 L p F P
0 g
s
.481 .431 .725 r
.60421 .80755 m .60443 .80827 L .59645 .81401 L p F P
0 g
s
.481 .431 .725 r
.59623 .80459 m .60421 .80755 L p .59645 .81401 L F P
0 g
s
.87 .749 .726 r
.19748 .814 m .19358 .82031 L .19001 .81641 L p F P
0 g
s
.87 .749 .726 r
.19001 .81641 m .19321 .8112 L .19748 .814 L p F P
0 g
s
.87 .749 .727 r
.19748 .814 m .19321 .8112 L .19735 .80447 L p F P
0 g
s
.874 .754 .728 r
.19732 .79489 m .20153 .79773 L .19735 .80447 L p F P
0 g
s
.872 .751 .726 r
.19868 .79265 m .19732 .79489 L .20153 .79773 L p F P
0 g
s
.35 .296 .655 r
.58928 .7382 m .58661 .74083 L .5881 .74781 L p F P
0 g
s
.373 .311 .658 r
.58767 .7482 m .5881 .74781 L .58661 .74083 L p F P
0 g
s
.51 .614 .892 r
.68046 .66162 m .69253 .6618 L p .69143 .66654 L F P
0 g
s
.508 .617 .895 r
.68965 .65709 m .69253 .6618 L .68046 .66162 L p F P
0 g
s
.508 .617 .895 r
.67771 .65695 m .68965 .65709 L p .68046 .66162 L F P
0 g
s
.508 .617 .895 r
.68046 .66162 m .67766 .65708 L .67771 .65695 L p F P
0 g
s
.185 .118 .543 r
.58994 .69823 m .58843 .70013 L .58918 .70628 L p F P
0 g
s
.532 .89 .67 r
.75612 .89508 m .75538 .8957 L .75294 .89699 L p F P
0 g
s
0 0 0 r
.7646 .88787 m .76619 .88558 L p .75612 .89508 L F P
0 g
s
0 0 0 r
.7622 .88997 m .76394 .88852 L .7646 .88787 L closepath p F P
0 g
s
.685 .978 .819 r
.7622 .88997 m .76394 .88852 L p .76388 .88856 L F P
0 g
s
0 0 0 r
.76299 .88928 m .7646 .88787 L p .76183 .89022 L F P
0 g
s
0 0 0 r
.75612 .89508 m .76299 .88928 L .76183 .89022 L F
.685 .978 .819 r
.75205 .89717 m .7622 .88997 L .76388 .88856 L F
0 0 0 r
.7622 .88997 m .76299 .88928 L p .75726 .89412 L F P
0 g
s
0 0 0 r
.75612 .89508 m .7622 .88997 L p .75726 .89412 L F P
0 g
s
0 0 0 r
.7646 .88787 m .77011 .88207 L .76619 .88558 L closepath p F P
0 g
s
.539 .837 .513 r
.76394 .88852 m .7646 .88787 L .77011 .88207 L p F P
0 g
s
.539 .837 .513 r
.77011 .88207 m .77437 .87829 L p .76401 .88845 L F P
0 g
s
.539 .837 .513 r
.76394 .88852 m .76399 .88846 L .76401 .88845 L F
.76399 .88846 m .77011 .88207 L .76401 .88845 L F
.532 .89 .67 r
.75294 .89699 m .7622 .88997 L .75612 .89508 L p F P
0 g
s
.844 .755 .764 r
.18127 .85445 m .17683 .86005 L .17323 .85629 L p F P
0 g
s
.844 .755 .764 r
.17323 .85629 m .17677 .85177 L .18127 .85445 L p F P
0 g
s
.843 .756 .766 r
.18127 .85445 m .17677 .85177 L .18251 .84455 L p F P
0 g
s
.434 .504 .832 r
.74003 .70817 m .74003 .70817 L p .74741 .71558 L F P
0 g
s
.442 .518 .841 r
.74003 .70817 m .74002 .70816 L .74003 .70817 L closepath p F P
0 g
s
.439 .52 .844 r
.74003 .70817 m .74002 .70816 L .73713 .70226 L p F P
0 g
s
.434 .504 .832 r
.74003 .70817 m .75006 .7109 L .74741 .71558 L p F P
0 g
s
.436 .512 .838 r
.74243 .70353 m .74003 .70817 L .75006 .7109 L p F P
0 g
s
.439 .52 .844 r
.73713 .70226 m .74243 .70353 L .74003 .70817 L p F P
0 g
s
.265 .223 .623 r
.78872 .81377 m .79233 .80944 L p .79124 .81919 L F P
0 g
s
.265 .223 .623 r
.79124 .81919 m .78906 .81544 L .78872 .81377 L p F P
0 g
s
.286 .258 .652 r
.78872 .81377 m .79233 .80944 L .78883 .80463 L p F P
0 g
s
.622 .884 .989 r
.72829 .90899 m .72516 .9112 L p .71478 .91212 L F P
0 g
s
.651 .905 .981 r
.72516 .9112 m .72829 .90899 L .72934 .90952 L closepath p F P
0 g
s
.543 .646 .901 r
.66271 .65315 m .67469 .65248 L .67758 .65695 L p F P
0 g
s
.546 .652 .905 r
.67469 .65248 m .66271 .65315 L .65982 .64887 L p F P
0 g
s
0 .263 .7 r
.03979 .8964 m .045 .89939 L .04892 .90222 L p F P
0 g
s
.56 .584 .834 r
.64985 .89471 m .64708 .89481 L .64925 .89352 L closepath p F P
0 g
s
.561 .573 .823 r
.64686 .88876 m .64925 .89352 L .64708 .89481 L p F P
0 g
s
.853 .747 .745 r
.19476 .82167 m .19358 .82031 L .19326 .82076 L closepath p F P
0 g
s
.912 .758 .677 r
.20618 .75663 m .20405 .76146 L .20044 .7582 L p F P
0 g
s
.912 .758 .677 r
.20044 .7582 m .20248 .75356 L .20618 .75663 L p F P
0 g
s
.914 .756 .671 r
.20618 .75663 m .20248 .75356 L .20514 .74732 L p F P
0 g
s
.351 .367 .737 r
.78393 .76807 m .78045 .77282 L .78616 .77695 L p F P
0 g
s
.363 .384 .748 r
.7777 .7641 m .78393 .76807 L .78045 .77282 L p F P
0 g
s
.724 .791 .905 r
.11082 .90981 m .1046 .91296 L .10082 .91005 L p F P
0 g
s
.662 .784 .939 r
.08993 .91393 m .10082 .91005 L .1046 .91296 L p F P
0 g
s
.266 .224 .623 r
.7901 .82051 m .78906 .81544 L .79124 .81919 L closepath p F P
0 g
s
.489 .591 .882 r
.7048 .67219 m .69829 .67167 L .69541 .6667 L p F P
0 g
s
.665 .785 .938 r
.10082 .91005 m .08993 .91393 L .08612 .91111 L p F P
0 g
s
0 0 .143 r
.77595 .87427 m .77901 .86809 L .77675 .87024 L closepath p F P
0 g
s
.047 0 .279 r
.77675 .87024 m .77901 .86809 L .78109 .86173 L p F P
0 g
s
.536 .539 .805 r
.63021 .87834 m .62892 .8754 L .63442 .87567 L closepath p F P
0 g
s
.391 .438 .789 r
.76489 .74015 m .76562 .73898 L p .77028 .74718 L F P
0 g
s
.401 .455 .801 r
.76489 .74015 m .76415 .73838 L .76562 .73898 L closepath p F P
0 g
s
.698 .979 .796 r
.60341 .65749 m .60415 .65727 L .61264 .65033 L p F P
0 g
s
.846 .997 .77 r
.60288 .65873 m .60341 .65749 L .60415 .65727 L closepath p F P
0 g
s
.63 .73 .92 r
.63033 .64601 m .64214 .64289 L .64504 .64661 L p F P
0 g
s
.648 .747 .922 r
.64214 .64289 m .63033 .64601 L .62743 .64294 L p F P
0 g
s
.709 .8 .922 r
.61573 .64832 m .62743 .64294 L .63033 .64601 L p F P
0 g
s
.382 .325 .669 r
.58833 .74878 m .58767 .7482 L .5881 .74781 L closepath p F P
0 g
s
.426 .49 .822 r
.74741 .71558 m .75537 .71798 L p .75416 .72319 L F P
0 g
s
.424 .493 .826 r
.74741 .71558 m .75537 .71798 L .75246 .71162 L p F P
0 g
s
.424 .493 .826 r
.75246 .71162 m .75006 .7109 L .74741 .71558 L p F P
0 g
s
.828 .759 .787 r
.1753 .86174 m .17683 .86005 L .17323 .85629 L p F P
0 g
s
.858 .753 .747 r
.18781 .83745 m .18512 .84128 L .18153 .83745 L p F P
0 g
s
.858 .753 .747 r
.18153 .83745 m .18345 .83471 L .18781 .83745 L p F P
0 g
s
.858 .753 .747 r
.18781 .83745 m .18345 .83471 L .18831 .82775 L p F P
0 g
s
.895 .759 .703 r
.19996 .7694 m .20383 .77239 L .20044 .77887 L p F P
0 g
s
.895 .758 .702 r
.20383 .77239 m .19996 .7694 L .20331 .76294 L p F P
0 g
s
.478 .564 .865 r
.7162 .68319 m .71442 .68297 L .71524 .68138 L closepath p F P
0 g
s
.484 .574 .87 r
.71333 .67791 m .71524 .68138 L .71442 .68297 L p F P
0 g
s
.272 .217 .611 r
.59064 .71559 m .58948 .71347 L p .58755 .72359 L F P
0 g
s
.272 .217 .611 r
.58755 .72359 m .5913 .71927 L .59064 .71559 L p F P
0 g
s
.29 .242 .63 r
.5913 .71927 m .58755 .72359 L .59075 .72822 L p F P
0 g
s
.4 .455 .802 r
.76562 .73898 m .76415 .73838 L .76121 .73132 L p F P
0 g
s
.833 .764 .786 r
.17072 .8591 m .1753 .86174 L .16854 .86927 L p F P
0 g
s
.828 .759 .787 r
.17323 .85629 m .17072 .8591 L .1753 .86174 L p F P
0 g
s
.597 .737 .942 r
.68536 .91161 m .6973 .90939 L .70011 .91266 L p F P
0 g
s
.593 .689 .909 r
.69446 .90576 m .6973 .90939 L .68536 .91161 L p F P
0 g
s
.593 .689 .909 r
.68622 .90704 m .69446 .90576 L p .68536 .91161 L F P
0 g
s
.593 .689 .909 r
.68536 .91161 m .68343 .90891 L .68622 .90704 L p F P
0 g
s
.031 0 .258 r
.78519 .85785 m .78109 .86173 L .77901 .86809 L p F P
0 g
s
.126 0 .383 r
.78109 .86173 m .78519 .85785 L .78524 .85265 L p F P
0 g
s
.313 .662 .973 r
.05741 .90677 m .06424 .90738 L .06829 .91015 L p F P
0 g
s
.324 .664 .974 r
.06424 .90738 m .05741 .90677 L .05353 .904 L p F P
0 g
s
.232 .154 .558 r
.79123 .82698 m .78917 .82918 L .79084 .83452 L p F P
0 g
s
.265 .201 .596 r
.78917 .82918 m .79123 .82698 L .7901 .82051 L p F P
0 g
s
.698 .979 .796 r
.61264 .65033 m .61364 .64703 L p .60341 .65749 L F P
0 g
s
.778 .904 .929 r
.61264 .65033 m .61364 .64703 L .61573 .64832 L closepath p F P
0 g
s
.362 .388 .753 r
.78103 .75937 m .7777 .7641 L .78393 .76807 L p F P
0 g
s
.373 .403 .763 r
.7743 .75555 m .78103 .75937 L .7777 .7641 L p F P
0 g
s
.507 .603 .884 r
.69541 .6667 m .69143 .66654 L .69316 .66286 L closepath p F P
0 g
s
.51 .614 .892 r
.69253 .6618 m .69316 .66286 L .69143 .66654 L p F P
0 g
s
.381 .324 .669 r
.5881 .74781 m .59341 .7426 L p .59245 .75243 L F P
0 g
s
.381 .324 .669 r
.59245 .75243 m .58833 .74878 L .5881 .74781 L p F P
0 g
s
.35 .296 .655 r
.5881 .74781 m .59341 .7426 L .58928 .7382 L p F P
0 g
s
0 0 .245 r
.59641 .67162 m .5945 .67464 L .59417 .67958 L p F P
0 g
s
0 0 .004 r
.5945 .67464 m .59641 .67162 L .59865 .66547 L p F P
0 g
s
0 0 .236 r
.5925 .68238 m .59417 .67958 L .5945 .67464 L p F P
0 g
s
.695 .918 .969 r
.72829 .90899 m .72934 .90952 L .74117 .90391 L p F P
0 g
s
0 .444 .851 r
.04892 .90222 m .05353 .904 L .04964 .90118 L p F P
0 g
s
0 .444 .851 r
.04964 .90118 m .045 .89939 L .04892 .90222 L p F P
0 g
s
.538 .532 .796 r
.63442 .87567 m .62892 .8754 L .6261 .8687 L p F P
0 g
s
.289 .264 .656 r
.79273 .79986 m .78883 .80463 L .79233 .80944 L p F P
0 g
s
.307 .289 .675 r
.78862 .79524 m .79273 .79986 L .78883 .80463 L p F P
0 g
s
.466 .425 .729 r
.60421 .80755 m .59623 .80459 L .602 .8003 L closepath p F P
0 g
s
.471 .418 .716 r
.60106 .79717 m .602 .8003 L .59623 .80459 L p F P
0 g
s
.471 .418 .716 r
.59625 .79509 m .60106 .79717 L p .59623 .80459 L F P
0 g
s
.422 .372 .697 r
.59473 .7747 m .59042 .77207 L .5934 .7696 L closepath p F P
0 g
s
.419 .367 .694 r
.59154 .76236 m .59141 .76226 L p .59042 .77207 L F P
0 g
s
.419 .367 .694 r
.59042 .77207 m .5934 .7696 L .59154 .76236 L p F P
0 g
s
.857 .753 .747 r
.19326 .82076 m .19358 .82031 L .19001 .81641 L p F P
0 g
s
.374 .324 .673 r
.58977 .75496 m .58833 .74878 L .59245 .75243 L closepath p F P
0 g
s
.889 .754 .706 r
.20101 .7883 m .19868 .79265 L .1951 .78898 L p F P
0 g
s
.889 .754 .706 r
.1951 .78898 m .19702 .78538 L .20101 .7883 L p F P
0 g
s
.891 .753 .704 r
.20101 .7883 m .19702 .78538 L .20044 .77887 L p F P
0 g
s
.789 .785 .849 r
.13244 .90196 m .13062 .90337 L .1269 .90022 L p F P
0 g
s
.758 .785 .875 r
.11566 .90739 m .1269 .90022 L .13062 .90337 L p F P
0 g
s
.859 .757 .748 r
.1889 .818 m .19326 .82076 L .18831 .82775 L p F P
0 g
s
.857 .753 .747 r
.19001 .81641 m .1889 .818 L .19326 .82076 L p F P
0 g
s
.424 .481 .815 r
.75828 .72458 m .75416 .72319 L p .76028 .73097 L F P
0 g
s
.426 .49 .822 r
.75537 .71798 m .7562 .71983 L .75416 .72319 L p F P
0 g
s
.417 .478 .815 r
.75828 .72458 m .75416 .72319 L .7562 .71983 L closepath p F P
0 g
s
.875 .756 .727 r
.19318 .80162 m .19735 .80447 L .19321 .8112 L p F P
0 g
s
.874 .754 .728 r
.19735 .80447 m .19318 .80162 L .19732 .79489 L p F P
0 g
s
.39 .696 .982 r
.06829 .91015 m .07162 .91025 L .06776 .90747 L p F P
0 g
s
.39 .696 .982 r
.06776 .90747 m .06424 .90738 L .06829 .91015 L p F P
0 g
s
.571 .696 .926 r
.64504 .64661 m .65693 .64476 L p .65806 .6491 L F P
0 g
s
.593 .699 .916 r
.65693 .64476 m .64504 .64661 L .64214 .64289 L p F P
0 g
s
.697 .89 .968 r
.61364 .64703 m .61573 .64832 L .62743 .64294 L p F P
0 g
s
.557 .606 .858 r
.64985 .89471 m .66178 .89423 L .66473 .89956 L p F P
0 g
s
.55 .579 .836 r
.65882 .88865 m .66178 .89423 L .64985 .89471 L p F P
0 g
s
.55 .579 .836 r
.65672 .88868 m .65882 .88865 L p .64985 .89471 L F P
0 g
s
.55 .579 .836 r
.64985 .89471 m .64925 .89352 L .65672 .88868 L p F P
0 g
s
.789 .785 .849 r
.1269 .90022 m .12808 .8993 L .13244 .90196 L p F P
0 g
s
.782 .78 .851 r
.13829 .89151 m .12808 .8993 L .13244 .90196 L p F P
0 g
s
.782 .78 .851 r
.13244 .90196 m .14198 .89479 L .13829 .89151 L p F P
0 g
s
0 0 .378 r
.59417 .67958 m .5925 .68238 L .59265 .68784 L p F P
0 g
s
.372 .408 .768 r
.77748 .75084 m .7743 .75555 L .78103 .75937 L p F P
0 g
s
.382 .421 .777 r
.77028 .74718 m .77748 .75084 L .7743 .75555 L p F P
0 g
s
.843 .756 .768 r
.18251 .84455 m .18512 .84128 L .18153 .83745 L p F P
0 g
s
.15 .03 .45 r
.78524 .85265 m .7871 .85074 L .78705 .84495 L p F P
0 g
s
.145 .026 .448 r
.79174 .84007 m .78705 .84495 L .7871 .85074 L p F P
0 g
s
.197 .099 .51 r
.78705 .84495 m .79174 .84007 L .79084 .83452 L p F P
0 g
s
0 0 0 r
.77564 .8748 m .77011 .88207 L .76619 .88558 L p F P
0 g
s
.236 .181 .59 r
.79124 .81919 m .7901 .82051 L .79123 .82698 L p F P
0 g
s
.835 .764 .784 r
.16854 .86927 m .16509 .87316 L .16146 .86958 L p F P
0 g
s
.835 .764 .784 r
.16146 .86958 m .16408 .86659 L .16854 .86927 L p F P
0 g
s
.833 .764 .786 r
.16854 .86927 m .16408 .86659 L .17072 .8591 L p F P
0 g
s
.409 .462 .804 r
.76121 .73132 m .76028 .73097 L .76075 .73024 L closepath p F P
0 g
s
.424 .481 .815 r
.76028 .73097 m .76075 .73024 L .75828 .72458 L p F P
0 g
s
.382 .426 .782 r
.77328 .74249 m .77028 .74718 L .77748 .75084 L p F P
0 g
s
.391 .438 .789 r
.76562 .73898 m .77328 .74249 L .77028 .74718 L p F P
0 g
s
.724 .791 .905 r
.10082 .91005 m .10646 .90714 L .11082 .90981 L p F P
0 g
s
.718 .788 .907 r
.11191 .90438 m .10646 .90714 L .11082 .90981 L p F P
0 g
s
.718 .788 .907 r
.11082 .90981 m .11566 .90739 L .11191 .90438 L p F P
0 g
s
.464 .553 .862 r
.7162 .68319 m .727 .68487 L .72471 .68953 L p F P
0 g
s
.463 .556 .865 r
.727 .68487 m .7162 .68319 L .71524 .68138 L p F P
0 g
s
.55 .578 .835 r
.64925 .89352 m .64686 .88876 L .65672 .88868 L closepath p F P
0 g
s
.392 .444 .795 r
.76844 .73432 m .76562 .73898 L .77328 .74249 L p F P
0 g
s
.4 .455 .802 r
.76121 .73132 m .76844 .73432 L .76562 .73898 L p F P
0 g
s
.574 .661 .896 r
.66766 .90451 m .67961 .90326 L .6825 .90761 L p F P
0 g
s
.569 .628 .871 r
.6767 .89861 m .67961 .90326 L .66766 .90451 L p F P
0 g
s
.569 .628 .871 r
.66508 .89953 m .6767 .89861 L p .66766 .90451 L F P
0 g
s
.569 .628 .871 r
.66766 .90451 m .66482 .8997 L .66508 .89953 L p F P
0 g
s
.612 .804 .973 r
.70011 .91266 m .71204 .90967 L .71478 .91212 L p F P
0 g
s
.604 .77 .959 r
.71204 .90967 m .70011 .91266 L .6973 .90939 L p F P
0 g
s
.903 .764 .698 r
.20331 .76294 m .20405 .76146 L .20044 .7582 L p F P
0 g
s
.185 .118 .543 r
.58918 .70628 m .59155 .70328 L .58994 .69823 L p F P
0 g
s
.123 .074 .525 r
.59354 .6931 m .58994 .69823 L .59155 .70328 L p F P
0 g
s
.09 .022 .478 r
.58994 .69823 m .59354 .6931 L .59265 .68784 L p F P
0 g
s
.438 .52 .844 r
.74243 .70353 m .73713 .70226 L .73424 .69636 L p F P
0 g
s
.622 .884 .989 r
.71478 .91212 m .72668 .90809 L .72829 .90899 L p F P
0 g
s
.62 .847 .986 r
.72668 .90809 m .71478 .91212 L .71204 .90967 L p F P
0 g
s
.734 .914 .549 r
.60135 .65963 m .6054 .65383 L .60341 .65749 L closepath p F P
0 g
s
.698 .979 .796 r
.61284 .64666 m .6054 .65383 L .60341 .65749 L p F P
0 g
s
.698 .979 .796 r
.61364 .64703 m .61284 .64666 L p .60341 .65749 L F P
0 g
s
.848 .761 .766 r
.17805 .84184 m .18251 .84455 L .17677 .85177 L p F P
0 g
s
.843 .756 .768 r
.18153 .83745 m .17805 .84184 L .18251 .84455 L p F P
0 g
s
.213 .157 .574 r
.59155 .70328 m .58918 .70628 L .59014 .71266 L p F P
0 g
s
.226 .167 .578 r
.58948 .71347 m .59014 .71266 L .58918 .70628 L p F P
0 g
s
.815 .767 .807 r
.16123 .87695 m .16509 .87316 L .16146 .86958 L p F P
0 g
s
.088 0 .371 r
.7871 .85074 m .78524 .85265 L .78519 .85785 L p F P
0 g
s
.378 .33 .677 r
.59245 .75243 m .58977 .75496 L .5915 .76219 L p F P
0 g
s
.4 .344 .68 r
.59141 .76226 m .5915 .76219 L .58977 .75496 L p F P
0 g
s
.821 .768 .803 r
.16123 .87695 m .15347 .88475 L .14981 .88131 L p F P
0 g
s
.821 .768 .803 r
.14981 .88131 m .15671 .8743 L .16123 .87695 L p F P
0 g
s
.815 .767 .807 r
.16146 .86958 m .15671 .8743 L .16123 .87695 L p F P
0 g
s
.808 .778 .825 r
.14386 .89311 m .14198 .89479 L .13829 .89151 L p F P
0 g
s
.572 .678 .912 r
.65982 .64887 m .65806 .6491 L .65887 .6475 L closepath p F P
0 g
s
.571 .696 .926 r
.65693 .64476 m .65887 .6475 L .65806 .6491 L p F P
0 g
s
.395 .454 .803 r
.76844 .73432 m .76121 .73132 L .76075 .73024 L p F P
0 g
s
.808 .778 .825 r
.13829 .89151 m .13947 .89044 L .14386 .89311 L p F P
0 g
s
.806 .779 .828 r
.14884 .88216 m .15343 .88478 L .14386 .89311 L p F P
0 g
s
.806 .779 .828 r
.14386 .89311 m .13947 .89044 L .14884 .88216 L p F P
0 g
s
.538 .532 .796 r
.6261 .8687 m .62677 .86826 L p .63442 .87567 L F P
0 g
s
.528 .525 .796 r
.6261 .8687 m .62588 .86819 L .62677 .86826 L closepath p F P
0 g
s
.901 .766 .704 r
.1996 .75989 m .20331 .76294 L .19996 .7694 L p F P
0 g
s
.903 .764 .698 r
.20044 .7582 m .1996 .75989 L .20331 .76294 L p F P
0 g
s
.53 .518 .787 r
.62677 .86826 m .62588 .86819 L .62282 .86062 L p F P
0 g
s
.798 .769 .827 r
.1536 .88487 m .15347 .88475 L .15343 .88478 L closepath p F P
0 g
s
.518 .628 .899 r
.67766 .65708 m .67758 .65695 L .67771 .65695 L closepath p F P
0 g
s
.878 .759 .727 r
.19732 .79489 m .19868 .79265 L .1951 .78898 L p F P
0 g
s
.526 .508 .779 r
.62282 .86062 m .62079 .86042 L .62236 .85944 L closepath p F P
0 g
s
.527 .499 .769 r
.61975 .85271 m .62236 .85944 L .62079 .86042 L p F P
0 g
s
.527 .499 .769 r
.61613 .85222 m .61975 .85271 L p .62079 .86042 L F P
0 g
s
.395 .454 .803 r
.76075 .73024 m .76299 .72632 L p .76844 .73432 L F P
0 g
s
.404 .47 .814 r
.76075 .73024 m .75828 .72458 L .76299 .72632 L closepath p F P
0 g
s
.515 .633 .904 r
.67771 .65695 m .67758 .65695 L .67469 .65248 L p F P
0 g
s
.799 .773 .829 r
.14981 .88131 m .14884 .88216 L .15343 .88478 L p F P
0 g
s
.799 .773 .829 r
.15343 .88478 m .15347 .88475 L .14981 .88131 L p F P
0 g
s
.463 .545 .855 r
.73136 .69074 m .72471 .68953 L p .73418 .69635 L F P
0 g
s
.458 .544 .857 r
.72471 .68953 m .73136 .69074 L .72848 .68513 L p F P
0 g
s
.458 .544 .857 r
.72848 .68513 m .727 .68487 L .72471 .68953 L p F P
0 g
s
.463 .556 .865 r
.71524 .68138 m .71654 .67833 L p .727 .68487 L F P
0 g
s
.47 .567 .872 r
.71524 .68138 m .71333 .67791 L .71654 .67833 L closepath p F P
0 g
s
.519 .487 .76 r
.61667 .84445 m .6189 .85045 L .61613 .85222 L p F P
0 g
s
.519 .487 .76 r
.61252 .84373 m .61667 .84445 L p .61613 .85222 L F P
0 g
s
.517 .496 .771 r
.61975 .85271 m .61613 .85222 L .6189 .85045 L closepath p F P
0 g
s
.516 .63 .902 r
.67771 .65695 m .68965 .65709 L .68677 .65242 L p F P
0 g
s
.516 .63 .902 r
.68677 .65242 m .67914 .65242 L .67771 .65695 L p F P
0 g
s
.515 .633 .904 r
.67469 .65248 m .67914 .65242 L .67771 .65695 L p F P
0 g
s
.304 .29 .678 r
.79237 .79054 m .78862 .79524 L .79273 .79986 L p F P
0 g
s
.327 .323 .702 r
.79231 .79034 m .78773 .78601 L p .78862 .79524 L F P
0 g
s
.327 .323 .702 r
.78862 .79524 m .79237 .79054 L .79231 .79034 L p F P
0 g
s
.859 .757 .748 r
.18831 .82775 m .18401 .82497 L .1889 .818 L p F P
0 g
s
.862 .759 .747 r
.18401 .82497 m .18831 .82775 L .18345 .83471 L p F P
0 g
s
.333 .293 .663 r
.59408 .73299 m .58928 .7382 L .59341 .7426 L p F P
0 g
s
.32 .274 .649 r
.59394 .73238 m .59075 .72822 L p .58928 .7382 L F P
0 g
s
.32 .274 .649 r
.58928 .7382 m .59408 .73299 L .59394 .73238 L p F P
0 g
s
.896 .76 .705 r
.19658 .77589 m .20044 .77887 L .19702 .78538 L p F P
0 g
s
.895 .759 .703 r
.20044 .77887 m .19658 .77589 L .19996 .7694 L p F P
0 g
s
.454 .41 .72 r
.60106 .79717 m .59625 .79509 L .59968 .79245 L closepath p F P
0 g
s
.46 .403 .707 r
.5979 .78628 m .59968 .79245 L .59625 .79509 L p F P
0 g
s
.46 .403 .707 r
.59641 .78553 m .5979 .78628 L p .59625 .79509 L F P
0 g
s
.661 .896 .98 r
.72668 .90809 m .73235 .90582 L .72829 .90899 L closepath p F P
0 g
s
.695 .918 .969 r
.73857 .90321 m .73235 .90582 L .72829 .90899 L p F P
0 g
s
.695 .918 .969 r
.74117 .90391 m .73857 .90321 L p .72829 .90899 L F P
0 g
s
.538 .532 .796 r
.62677 .86826 m .63781 .86911 L p .63442 .87567 L F P
0 g
s
.528 .529 .8 r
.63781 .86911 m .62677 .86826 L .63511 .86277 L closepath p F P
0 g
s
.53 .518 .787 r
.63477 .86196 m .63511 .86277 L .62677 .86826 L p F P
0 g
s
.53 .518 .787 r
.62282 .86062 m .63477 .86196 L p .62677 .86826 L F P
0 g
s
.593 .689 .909 r
.68343 .90891 m .6825 .90761 L .68622 .90704 L closepath p F P
0 g
s
.76 .787 .875 r
.1269 .90022 m .11566 .90739 L .11191 .90438 L p F P
0 g
s
.875 .756 .728 r
.19321 .8112 m .19001 .81641 L .18641 .81271 L p F P
0 g
s
.875 .756 .728 r
.18641 .81271 m .18908 .80835 L .19321 .8112 L p F P
0 g
s
.875 .756 .727 r
.19321 .8112 m .18908 .80835 L .19318 .80162 L p F P
0 g
s
.489 .591 .882 r
.69541 .6667 m .70689 .66752 L .7048 .67219 L p F P
0 g
s
.49 .595 .885 r
.70689 .66752 m .69541 .6667 L .69316 .66286 L p F P
0 g
s
.508 .483 .764 r
.61667 .84445 m .61252 .84373 L .61567 .84167 L closepath p F P
0 g
s
.511 .474 .752 r
.61357 .83582 m .61567 .84167 L .61252 .84373 L p F P
0 g
s
.511 .474 .752 r
.60976 .83501 m .61357 .83582 L p .61252 .84373 L F P
0 g
s
.546 .652 .905 r
.65982 .64887 m .67181 .64807 L .67469 .65248 L p F P
0 g
s
.544 .665 .916 r
.66892 .64373 m .67181 .64807 L .65982 .64887 L p F P
0 g
s
.544 .665 .916 r
.6596 .64451 m .66892 .64373 L p .65982 .64887 L F P
0 g
s
.544 .665 .916 r
.65982 .64887 m .65887 .6475 L .6596 .64451 L p F P
0 g
s
.879 .761 .729 r
.19327 .79199 m .19732 .79489 L .19318 .80162 L p F P
0 g
s
.878 .759 .727 r
.1951 .78898 m .19327 .79199 L .19732 .79489 L p F P
0 g
s
0 0 .049 r
.77901 .86809 m .78424 .86313 L p .77587 .87459 L F P
0 g
s
0 0 .049 r
.77587 .87459 m .77595 .87427 L .77901 .86809 L p F P
0 g
s
.031 0 .258 r
.78489 .86129 m .78519 .85785 L p .77901 .86809 L F P
0 g
s
.031 0 .258 r
.77901 .86809 m .78424 .86313 L .78489 .86129 L p F P
0 g
s
.25 .2 .604 r
.59064 .71559 m .58948 .71347 L .59014 .71266 L closepath p F P
0 g
s
.406 .355 .688 r
.59154 .76236 m .59141 .76226 L .5915 .76219 L closepath p F P
0 g
s
.848 .76 .765 r
.17677 .85177 m .17323 .85629 L .16961 .85264 L p F P
0 g
s
.848 .76 .765 r
.16961 .85264 m .17241 .84904 L .17677 .85177 L p F P
0 g
s
.848 .761 .766 r
.17677 .85177 m .17241 .84904 L .17805 .84184 L p F P
0 g
s
.566 .763 .971 r
.07162 .91025 m .08229 .90828 L .08612 .91111 L p F P
0 g
s
.569 .764 .97 r
.08229 .90828 m .07162 .91025 L .06776 .90747 L p F P
0 g
s
.236 .181 .59 r
.79123 .82698 m .7935 .82436 L .79124 .81919 L p F P
0 g
s
.235 .183 .592 r
.79527 .81442 m .79124 .81919 L .7935 .82436 L p F P
0 g
s
.265 .223 .623 r
.79233 .80944 m .79527 .81442 L .79124 .81919 L p F P
0 g
s
.404 .353 .687 r
.5915 .76219 m .59742 .75662 L p .59706 .76628 L F P
0 g
s
.404 .353 .687 r
.59706 .76628 m .59154 .76236 L .5915 .76219 L p F P
0 g
s
.378 .33 .677 r
.5915 .76219 m .59742 .75662 L .59245 .75243 L p F P
0 g
s
.398 .354 .692 r
.5934 .7696 m .59154 .76236 L .59706 .76628 L closepath p F P
0 g
s
.552 .57 .826 r
.65672 .88868 m .64686 .88876 L .64392 .88267 L p F P
0 g
s
.511 .5 .78 r
.63171 .85448 m .63477 .86196 L .62282 .86062 L p F P
0 g
s
.511 .5 .78 r
.63004 .85423 m .63171 .85448 L p .62282 .86062 L F P
0 g
s
.511 .5 .78 r
.62282 .86062 m .62236 .85944 L .63004 .85423 L p F P
0 g
s
.2 .131 .55 r
.7935 .82436 m .79123 .82698 L .7921 .83317 L p F P
0 g
s
.232 .154 .558 r
.79084 .83452 m .7921 .83317 L .79123 .82698 L p F P
0 g
s
.573 .94 .884 r
.74967 .89905 m .74117 .90391 L .73857 .90321 L p F P
0 g
s
.511 .499 .779 r
.62236 .85944 m .61975 .85271 L .63004 .85423 L closepath p F P
0 g
s
.499 .47 .756 r
.61357 .83582 m .60976 .83501 L .61262 .83308 L closepath p F P
0 g
s
.502 .461 .744 r
.61046 .82682 m .61262 .83308 L .60976 .83501 L p F P
0 g
s
.502 .461 .744 r
.60767 .8261 m .61046 .82682 L p .60976 .83501 L F P
0 g
s
.487 .583 .877 r
.7048 .67219 m .71045 .67273 L .70757 .66758 L p F P
0 g
s
.487 .583 .877 r
.70757 .66758 m .70689 .66752 L .7048 .67219 L p F P
0 g
s
.536 .542 .808 r
.64084 .87597 m .63442 .87567 L .63932 .87253 L closepath p F P
0 g
s
.538 .532 .796 r
.63781 .86911 m .63932 .87253 L .63442 .87567 L p F P
0 g
s
.832 .764 .788 r
.17072 .8591 m .17323 .85629 L .16961 .85264 L p F P
0 g
s
.726 .793 .905 r
.10646 .90714 m .10082 .91005 L .09702 .90714 L p F P
0 g
s
.665 .785 .938 r
.08612 .91111 m .09702 .90714 L .10082 .91005 L p F P
0 g
s
.596 .671 .892 r
.68622 .90704 m .6825 .90761 L .67961 .90326 L p F P
0 g
s
.319 .318 .701 r
.79231 .79034 m .78773 .78601 L .79016 .78285 L closepath p F P
0 g
s
.339 .346 .72 r
.78909 .77937 m .78616 .77695 L p .78773 .78601 L F P
0 g
s
.339 .346 .72 r
.78773 .78601 m .79016 .78285 L .78909 .77937 L p F P
0 g
s
.404 .47 .815 r
.76299 .72632 m .75828 .72458 L .7562 .71983 L p F P
0 g
s
.668 .787 .937 r
.09702 .90714 m .08612 .91111 L .08229 .90828 L p F P
0 g
s
.267 .211 .607 r
.59014 .71266 m .59366 .70821 L p .59216 .71824 L F P
0 g
s
.267 .211 .607 r
.59216 .71824 m .59064 .71559 L .59014 .71266 L p F P
0 g
s
.213 .157 .574 r
.59014 .71266 m .59366 .70821 L .59155 .70328 L p F P
0 g
s
.45 .53 .847 r
.73424 .69636 m .73418 .69635 L .73421 .69629 L closepath p F P
0 g
s
.463 .545 .855 r
.73418 .69635 m .73421 .69629 L .73136 .69074 L p F P
0 g
s
.552 .673 .918 r
.65887 .6475 m .65693 .64476 L .6596 .64451 L closepath p F P
0 g
s
.419 .37 .697 r
.5934 .7696 m .59706 .76628 L p .5967 .77593 L F P
0 g
s
.419 .37 .697 r
.5967 .77593 m .59473 .7747 L .5934 .7696 L p F P
0 g
s
.438 .52 .844 r
.73424 .69636 m .7448 .69889 L .74243 .70353 L p F P
0 g
s
.436 .521 .847 r
.7448 .69889 m .73424 .69636 L .73421 .69629 L p F P
0 g
s
.862 .759 .748 r
.18345 .83471 m .18153 .83745 L .17792 .83377 L p F P
0 g
s
.862 .759 .748 r
.17792 .83377 m .17921 .83192 L .18345 .83471 L p F P
0 g
s
.862 .759 .747 r
.18345 .83471 m .17921 .83192 L .18401 .82497 L p F P
0 g
s
.436 .521 .847 r
.73421 .69629 m .73627 .69176 L p .7448 .69889 L F P
0 g
s
.444 .534 .855 r
.73421 .69629 m .73136 .69074 L .73627 .69176 L closepath p F P
0 g
s
.837 .769 .786 r
.16627 .8564 m .17072 .8591 L .16408 .86659 L p F P
0 g
s
.832 .764 .788 r
.16961 .85264 m .16627 .8564 L .17072 .8591 L p F P
0 g
s
.468 .569 .874 r
.71654 .67833 m .71333 .67791 L .71045 .67273 L p F P
0 g
s
.648 .747 .922 r
.62743 .64294 m .63924 .63931 L .64214 .64289 L p F P
0 g
s
.669 .765 .922 r
.63924 .63931 m .62743 .64294 L .62454 .64012 L p F P
0 g
s
.697 .89 .968 r
.62743 .64294 m .62454 .64012 L p .61364 .64703 L F P
0 g
s
.569 .627 .87 r
.66482 .8997 m .66473 .89956 L .66508 .89953 L closepath p F P
0 g
s
.862 .76 .749 r
.1889 .818 m .19001 .81641 L .18641 .81271 L p F P
0 g
s
.901 .767 .705 r
.19624 .76636 m .19996 .7694 L .19658 .77589 L p F P
0 g
s
.901 .766 .704 r
.19996 .7694 m .19624 .76636 L .1996 .75989 L p F P
0 g
s
.191 .096 .509 r
.7921 .83317 m .79084 .83452 L .79174 .84007 L p F P
0 g
s
.572 .614 .856 r
.66508 .89953 m .66473 .89956 L .66178 .89423 L p F P
0 g
s
0 0 .213 r
.59888 .66676 m .59641 .67162 L .59555 .67738 L p F P
0 g
s
0 0 0 r
.59641 .67162 m .59888 .66676 L .60081 .66069 L p F P
0 g
s
0 0 .245 r
.59417 .67958 m .59555 .67738 L .59641 .67162 L p F P
0 g
s
.088 0 .371 r
.78519 .85785 m .78623 .85678 L .7871 .85074 L p F P
0 g
s
.075 0 .363 r
.79178 .84588 m .7871 .85074 L .78623 .85678 L p F P
0 g
s
.145 .026 .448 r
.7871 .85074 m .79178 .84588 L .79174 .84007 L p F P
0 g
s
.032 0 .464 r
.59432 .68506 m .59265 .68784 L .59354 .6931 L p F P
0 g
s
0 0 .378 r
.59265 .68784 m .59432 .68506 L .59417 .67958 L p F P
0 g
s
.572 .614 .856 r
.66178 .89423 m .67371 .89369 L .66508 .89953 L p F P
0 g
s
.559 .609 .859 r
.66508 .89953 m .6767 .89861 L .67378 .89368 L p F P
0 g
s
.559 .609 .859 r
.67378 .89368 m .67371 .89369 L .66508 .89953 L p F P
0 g
s
.441 .395 .712 r
.5979 .78628 m .59641 .78553 L .59746 .7847 L closepath p F P
0 g
s
.437 .39 .708 r
.59641 .78553 m .59746 .7847 L .59537 .77708 L p F P
0 g
s
.324 .664 .974 r
.05353 .904 m .06025 .90458 L .06424 .90738 L p F P
0 g
s
.333 .665 .974 r
.06025 .90458 m .05353 .904 L .04964 .90118 L p F P
0 g
s
.513 .493 .772 r
.63004 .85423 m .61975 .85271 L .6189 .85045 L p F P
0 g
s
.772 .934 .936 r
.61284 .64666 m .61439 .64565 L .61364 .64703 L closepath p F P
0 g
s
.697 .89 .968 r
.62454 .64012 m .61439 .64565 L .61364 .64703 L p F P
0 g
s
0 0 .385 r
.59555 .67738 m .59417 .67958 L .59432 .68506 L p F P
0 g
s
.864 .763 .749 r
.1847 .81517 m .1889 .818 L .18401 .82497 L p F P
0 g
s
.862 .76 .749 r
.18641 .81271 m .1847 .81517 L .1889 .818 L p F P
0 g
s
.414 .371 .702 r
.59537 .77708 m .59473 .7747 L .5967 .77593 L closepath p F P
0 g
s
.847 .762 .769 r
.17805 .84184 m .18153 .83745 L .17792 .83377 L p F P
0 g
s
.489 .456 .748 r
.61046 .82682 m .60767 .8261 L .60974 .82466 L closepath p F P
0 g
s
.493 .448 .736 r
.60734 .81741 m .60974 .82466 L .60767 .8261 L p F P
0 g
s
.493 .448 .736 r
.60611 .81704 m .60734 .81741 L p .60767 .8261 L F P
0 g
s
.894 .761 .708 r
.19702 .78538 m .1951 .78898 L .19148 .78555 L p F P
0 g
s
.894 .761 .708 r
.19148 .78555 m .19316 .7824 L .19702 .78538 L p F P
0 g
s
.896 .76 .705 r
.19702 .78538 m .19316 .7824 L .19658 .77589 L p F P
0 g
s
.593 .699 .916 r
.64214 .64289 m .65403 .64076 L .65693 .64476 L p F P
0 g
s
.604 .71 .919 r
.65403 .64076 m .64214 .64289 L .63924 .63931 L p F P
0 g
s
.791 .787 .849 r
.12808 .8993 m .1269 .90022 L .12316 .8971 L p F P
0 g
s
.76 .787 .875 r
.11191 .90438 m .12316 .8971 L .1269 .90022 L p F P
0 g
s
.879 .761 .729 r
.19318 .80162 m .18916 .79872 L .19327 .79199 L p F P
0 g
s
.88 .762 .728 r
.18916 .79872 m .19318 .80162 L .18908 .80835 L p F P
0 g
s
0 0 .095 r
.77564 .8748 m .77587 .87459 L .77595 .87427 L closepath p F P
0 g
s
.513 .493 .772 r
.6189 .85045 m .62524 .84604 L p .63004 .85423 L F P
0 g
s
.502 .485 .771 r
.6189 .85045 m .61667 .84445 L .62524 .84604 L closepath p F P
0 g
s
.785 .783 .851 r
.13458 .88828 m .12381 .89659 L .12808 .8993 L p F P
0 g
s
.785 .783 .851 r
.12808 .8993 m .13829 .89151 L .13458 .88828 L p F P
0 g
s
.791 .787 .849 r
.12316 .8971 m .12381 .89659 L .12808 .8993 L p F P
0 g
s
.258 .208 .608 r
.5913 .71927 m .59064 .71559 L .59216 .71824 L closepath p F P
0 g
s
.417 .377 .706 r
.5967 .77593 m .59537 .77708 L .59746 .7847 L p F P
0 g
s
.301 .258 .642 r
.59394 .73238 m .59075 .72822 L .59263 .72607 L closepath p F P
0 g
s
.29 .242 .63 r
.59075 .72822 m .59263 .72607 L .5913 .71927 L p F P
0 g
s
.395 .697 .981 r
.06424 .90738 m .06776 .90747 L .0639 .90466 L p F P
0 g
s
.395 .697 .981 r
.0639 .90466 m .06025 .90458 L .06424 .90738 L p F P
0 g
s
0 0 0 r
.77587 .87459 m .77564 .8748 L .77011 .88207 L p F P
0 g
s
.838 .768 .784 r
.16408 .86659 m .16146 .86958 L .15781 .8661 L p F P
0 g
s
.838 .768 .784 r
.15781 .8661 m .15974 .86387 L .16408 .86659 L p F P
0 g
s
.837 .769 .786 r
.16408 .86659 m .15974 .86387 L .16627 .8564 L p F P
0 g
s
.332 .341 .72 r
.78909 .77937 m .78616 .77695 L .7877 .77488 L closepath p F P
0 g
s
.351 .367 .737 r
.78596 .76955 m .78393 .76807 L p .78616 .77695 L F P
0 g
s
.351 .367 .737 r
.78616 .77695 m .7877 .77488 L .78596 .76955 L p F P
0 g
s
.49 .595 .885 r
.69316 .66286 m .69352 .66186 L p .70689 .66752 L F P
0 g
s
.496 .604 .891 r
.69316 .66286 m .69253 .6618 L .69352 .66186 L closepath p F P
0 g
s
.573 .94 .884 r
.75205 .89717 m .74967 .89905 L p .73857 .90321 L F P
0 g
s
.594 .946 .818 r
.74967 .89905 m .75205 .89717 L .75294 .89699 L closepath p F P
0 g
s
.365 .329 .685 r
.59742 .74734 m .59245 .75243 L .59742 .75662 L p F P
0 g
s
.381 .324 .669 r
.59719 .74638 m .59742 .74734 L .59245 .75243 L p F P
0 g
s
.381 .324 .669 r
.59341 .7426 m .59719 .74638 L p .59245 .75243 L F P
0 g
s
.26 .223 .625 r
.796 .80503 m .79233 .80944 L .79527 .81442 L p F P
0 g
s
.289 .264 .656 r
.79572 .80388 m .79273 .79986 L p .79233 .80944 L F P
0 g
s
.289 .264 .656 r
.79233 .80944 m .796 .80503 L .79572 .80388 L p F P
0 g
s
0 0 0 r
.78071 .86989 m .77587 .87459 L .77437 .87829 L p F P
0 g
s
0 0 0 r
.77011 .88207 m .77437 .87829 L .77587 .87459 L p F P
0 g
s
0 0 .049 r
.78424 .86313 m .78071 .86989 L .77587 .87459 L p F P
0 g
s
.413 .485 .825 r
.7562 .71983 m .75537 .71798 L .75692 .71849 L closepath p F P
0 g
s
.404 .47 .815 r
.7562 .71983 m .75692 .71849 L p .76299 .72632 L F P
0 g
s
.436 .512 .838 r
.74956 .70543 m .74243 .70353 L p .75006 .7109 L F P
0 g
s
.429 .509 .839 r
.74243 .70353 m .74956 .70543 L .74666 .69938 L p F P
0 g
s
.429 .509 .839 r
.74666 .69938 m .7448 .69889 L .74243 .70353 L p F P
0 g
s
.726 .793 .905 r
.09702 .90714 m .1022 .90444 L .10646 .90714 L p F P
0 g
s
.721 .79 .906 r
.10813 .90138 m .1022 .90444 L .10646 .90714 L p F P
0 g
s
.721 .79 .906 r
.10646 .90714 m .11191 .90438 L .10813 .90138 L p F P
0 g
s
.552 .57 .826 r
.64392 .88267 m .6441 .88255 L p .65672 .88868 L F P
0 g
s
.542 .564 .826 r
.64392 .88267 m .64386 .88255 L .6441 .88255 L closepath p F P
0 g
s
.604 .77 .959 r
.6973 .90939 m .70926 .9068 L .71204 .90967 L p F P
0 g
s
.595 .74 .945 r
.70926 .9068 m .6973 .90939 L .69446 .90576 L p F P
0 g
s
.545 .554 .815 r
.6441 .88255 m .64386 .88255 L .64084 .87597 L p F P
0 g
s
.819 .771 .808 r
.15671 .8743 m .16146 .86958 L .15781 .8661 L p F P
0 g
s
.592 .692 .912 r
.69446 .90576 m .68622 .90704 L .69232 .90279 L closepath p F P
0 g
s
.596 .671 .892 r
.6916 .90179 m .69232 .90279 L .68622 .90704 L p F P
0 g
s
.596 .671 .892 r
.67961 .90326 m .6916 .90179 L p .68622 .90704 L F P
0 g
s
.852 .766 .767 r
.17375 .83907 m .17805 .84184 L .17241 .84904 L p F P
0 g
s
.847 .762 .769 r
.17792 .83377 m .17375 .83907 L .17805 .84184 L p F P
0 g
s
.504 .48 .764 r
.62524 .84604 m .61667 .84445 L .61567 .84167 L p F P
0 g
s
.552 .57 .826 r
.6441 .88255 m .65583 .88274 L p .65672 .88868 L F P
0 g
s
.542 .567 .83 r
.65583 .88274 m .6441 .88255 L .65285 .87662 L closepath p F P
0 g
s
.545 .554 .815 r
.65283 .87658 m .65285 .87662 L .6441 .88255 L p F P
0 g
s
.545 .554 .815 r
.64084 .87597 m .65283 .87658 L p .6441 .88255 L F P
0 g
s
.628 .891 .987 r
.73235 .90582 m .72668 .90809 L .72398 .90612 L p F P
0 g
s
.62 .847 .986 r
.71204 .90967 m .72398 .90612 L .72668 .90809 L p F P
0 g
s
.157 .125 .569 r
.595 .69821 m .59155 .70328 L .59366 .70821 L p F P
0 g
s
.123 .074 .525 r
.59155 .70328 m .595 .69821 L .59354 .6931 L p F P
0 g
s
.437 .393 .711 r
.59746 .7847 m .60314 .77976 L p .60357 .78919 L F P
0 g
s
.437 .393 .711 r
.60357 .78919 m .5979 .78628 L .59746 .7847 L p F P
0 g
s
.417 .377 .706 r
.59746 .7847 m .60314 .77976 L .5967 .77593 L p F P
0 g
s
.824 .772 .803 r
.15671 .8743 m .14981 .88131 L .14613 .87795 L p F P
0 g
s
.824 .772 .803 r
.14613 .87795 m .15231 .8716 L .15671 .8743 L p F P
0 g
s
.819 .771 .808 r
.15781 .8661 m .15231 .8716 L .15671 .8743 L p F P
0 g
s
.519 .639 .907 r
.67914 .65242 m .67469 .65248 L .67181 .64807 L p F P
0 g
s
.504 .48 .764 r
.61567 .84167 m .62137 .83759 L p .62524 .84604 L F P
0 g
s
.492 .472 .763 r
.61567 .84167 m .61357 .83582 L .62137 .83759 L closepath p F P
0 g
s
.685 .978 .819 r
.75205 .89717 m .75294 .89699 L .7622 .88997 L p F P
0 g
s
.432 .395 .717 r
.59968 .79245 m .5979 .78628 L .60357 .78919 L closepath p F P
0 g
s
.411 .486 .826 r
.75692 .71849 m .75537 .71798 L .75246 .71162 L p F P
0 g
s
.811 .782 .826 r
.13947 .89044 m .13829 .89151 L .13458 .88828 L p F P
0 g
s
.811 .782 .826 r
.13458 .88828 m .13518 .88773 L .13947 .89044 L p F P
0 g
s
.809 .782 .828 r
.14438 .87949 m .14884 .88216 L .13947 .89044 L p F P
0 g
s
.809 .782 .828 r
.13947 .89044 m .13518 .88773 L .14438 .87949 L p F P
0 g
s
.01 0 .271 r
.78489 .86129 m .78623 .85678 L .78519 .85785 L closepath p F P
0 g
s
.494 .608 .894 r
.69352 .66186 m .69253 .6618 L .68965 .65709 L p F P
0 g
s
.883 .767 .729 r
.19327 .79199 m .1951 .78898 L .19148 .78555 L p F P
0 g
s
.275 .232 .627 r
.59216 .71824 m .5913 .71927 L .59263 .72607 L p F P
0 g
s
.479 .443 .74 r
.60734 .81741 m .60611 .81704 L .60701 .81639 L closepath p F P
0 g
s
.478 .44 .738 r
.60611 .81704 m .60701 .81639 L .60443 .80827 L p F P
0 g
s
.613 .81 .975 r
.72398 .90612 m .71204 .90967 L .70926 .9068 L p F P
0 g
s
.802 .777 .829 r
.14613 .87795 m .14438 .87949 L .14884 .88216 L p F P
0 g
s
.802 .777 .829 r
.14884 .88216 m .14981 .88131 L .14613 .87795 L p F P
0 g
s
.343 .363 .737 r
.78596 .76955 m .78393 .76807 L .78498 .76659 L closepath p F P
0 g
s
.362 .388 .753 r
.78288 .76056 m .78103 .75937 L p .78393 .76807 L F P
0 g
s
.362 .388 .753 r
.78393 .76807 m .78498 .76659 L .78288 .76056 L p F P
0 g
s
.813 .96 .907 r
.61439 .64565 m .61284 .64666 L .60998 .64593 L p F P
0 g
s
.861 .965 .866 r
.6054 .65383 m .61284 .64666 L .60998 .64593 L p F P
0 g
s
.495 .467 .756 r
.62137 .83759 m .61357 .83582 L .61262 .83308 L p F P
0 g
s
.45 .408 .72 r
.59968 .79245 m .60357 .78919 L p .60415 .79856 L F P
0 g
s
.45 .408 .72 r
.60415 .79856 m .60106 .79717 L .59968 .79245 L p F P
0 g
s
.156 .07 .499 r
.79509 .82973 m .7921 .83317 L .7927 .83906 L p F P
0 g
s
.2 .131 .55 r
.7921 .83317 m .79509 .82973 L .7935 .82436 L p F P
0 g
s
.191 .096 .509 r
.79174 .84007 m .7927 .83906 L .7921 .83317 L p F P
0 g
s
.463 .556 .865 r
.71654 .67833 m .7256 .6797 L p .727 .68487 L F P
0 g
s
.463 .561 .87 r
.71654 .67833 m .7256 .6797 L .72272 .67437 L p F P
0 g
s
.463 .561 .87 r
.72272 .67437 m .71844 .67374 L .71654 .67833 L p F P
0 g
s
.468 .569 .874 r
.71045 .67273 m .71844 .67374 L .71654 .67833 L p F P
0 g
s
.422 .494 .828 r
.75246 .71162 m .75006 .7109 L .75119 .70886 L closepath p F P
0 g
s
.436 .512 .838 r
.75006 .7109 m .75119 .70886 L .74956 .70543 L p F P
0 g
s
.867 .764 .747 r
.17985 .82213 m .18401 .82497 L .17921 .83192 L p F P
0 g
s
.864 .763 .749 r
.18401 .82497 m .17985 .82213 L .1847 .81517 L p F P
0 g
s
.861 .965 .866 r
.60998 .64593 m .6072 .64913 L .6054 .65383 L p F P
0 g
s
0 0 0 r
.60103 .66014 m .60135 .65963 L .6054 .65383 L p F P
0 g
s
0 0 0 r
.6054 .65383 m .6072 .64913 L p .60103 .66014 L F P
0 g
s
.495 .467 .756 r
.61262 .83308 m .61826 .82893 L p .62137 .83759 L F P
0 g
s
.482 .458 .755 r
.61262 .83308 m .61046 .82682 L .61826 .82893 L closepath p F P
0 g
s
.813 .96 .907 r
.60998 .64593 m .61643 .64087 L .61439 .64565 L p F P
0 g
s
.742 .847 .929 r
.62164 .63759 m .61643 .64087 L .61439 .64565 L p F P
0 g
s
.742 .847 .929 r
.61439 .64565 m .62454 .64012 L .62164 .63759 L p F P
0 g
s
.55 .679 .924 r
.6596 .64451 m .65693 .64476 L .65403 .64076 L p F P
0 g
s
.445 .411 .726 r
.602 .8003 m .60106 .79717 L .60415 .79856 L closepath p F P
0 g
s
.49 .595 .885 r
.69352 .66186 m .70469 .66263 L p .70689 .66752 L F P
0 g
s
.491 .603 .891 r
.69352 .66186 m .70469 .66263 L .70182 .65774 L p F P
0 g
s
.491 .603 .891 r
.70182 .65774 m .69502 .65733 L .69352 .66186 L p F P
0 g
s
.494 .608 .894 r
.68965 .65709 m .69502 .65733 L .69352 .66186 L p F P
0 g
s
.409 .378 .713 r
.60281 .7703 m .5967 .77593 L .60314 .77976 L p F P
0 g
s
.419 .37 .697 r
.59706 .76628 m .60281 .7703 L .5967 .77593 L p F P
0 g
s
.9 .768 .706 r
.19286 .77285 m .19658 .77589 L .19316 .7824 L p F P
0 g
s
.901 .767 .705 r
.19658 .77589 m .19286 .77285 L .19624 .76636 L p F P
0 g
s
.462 .423 .729 r
.602 .8003 m .60415 .79856 L p .60497 .80785 L F P
0 g
s
.462 .423 .729 r
.60497 .80785 m .60421 .80755 L .602 .8003 L p F P
0 g
s
.485 .454 .748 r
.61826 .82893 m .61046 .82682 L .60974 .82466 L p F P
0 g
s
.443 .535 .856 r
.73627 .69176 m .73136 .69074 L .72848 .68513 L p F P
0 g
s
.471 .444 .746 r
.60974 .82466 m .60734 .81741 L .61577 .8201 L closepath p F P
0 g
s
.485 .454 .748 r
.60974 .82466 m .61577 .8201 L p .61826 .82893 L F P
0 g
s
.88 .762 .729 r
.18908 .80835 m .18641 .81271 L .18279 .80919 L p F P
0 g
s
.88 .762 .729 r
.18279 .80919 m .18507 .80545 L .18908 .80835 L p F P
0 g
s
.88 .762 .728 r
.18908 .80835 m .18507 .80545 L .18916 .79872 L p F P
0 g
s
.762 .79 .876 r
.12316 .8971 m .11191 .90438 L .10813 .90138 L p F P
0 g
s
.852 .766 .766 r
.17241 .84904 m .16961 .85264 L .16597 .84911 L p F P
0 g
s
.852 .766 .766 r
.16597 .84911 m .16816 .84627 L .17241 .84904 L p F P
0 g
s
.852 .766 .767 r
.17241 .84904 m .16816 .84627 L .17375 .83907 L p F P
0 g
s
.883 .768 .73 r
.18938 .78903 m .19327 .79199 L .18916 .79872 L p F P
0 g
s
.883 .767 .729 r
.19148 .78555 m .18938 .78903 L .19327 .79199 L p F P
0 g
s
.458 .426 .735 r
.60443 .80827 m .60421 .80755 L .60497 .80785 L closepath p F P
0 g
s
.354 .384 .753 r
.78288 .76056 m .78103 .75937 L .78198 .75798 L closepath p F P
0 g
s
.372 .408 .768 r
.77985 .75219 m .77748 .75084 L p .78103 .75937 L F P
0 g
s
.372 .408 .768 r
.78103 .75937 m .78198 .75798 L .77985 .75219 L p F P
0 g
s
.46 .429 .738 r
.60497 .80785 m .60443 .80827 L .60701 .81639 L p F P
0 g
s
.475 .441 .74 r
.61577 .8201 m .60734 .81741 L .60701 .81639 L p F P
0 g
s
.475 .441 .74 r
.60701 .81639 m .61375 .81112 L p .61577 .8201 L F P
0 g
s
.46 .429 .738 r
.60701 .81639 m .61375 .81112 L .60497 .80785 L p F P
0 g
s
.561 .598 .848 r
.67371 .89369 m .66178 .89423 L .65882 .88865 L p F P
0 g
s
.404 .47 .815 r
.75692 .71849 m .76558 .72168 L .76299 .72632 L p F P
0 g
s
.406 .477 .821 r
.75931 .71389 m .75692 .71849 L .76558 .72168 L p F P
0 g
s
.411 .486 .826 r
.75246 .71162 m .75931 .71389 L .75692 .71849 L p F P
0 g
s
.568 .662 .9 r
.6916 .90179 m .67961 .90326 L .6767 .89861 L p F P
0 g
s
.569 .764 .97 r
.06776 .90747 m .07845 .90544 L .08229 .90828 L p F P
0 g
s
.57 .764 .97 r
.07845 .90544 m .06776 .90747 L .0639 .90466 L p F P
0 g
s
.469 .572 .876 r
.71844 .67374 m .71045 .67273 L .70757 .66758 L p F P
0 g
s
.235 .183 .592 r
.7935 .82436 m .79758 .81958 L .79527 .81442 L p F P
0 g
s
.201 .134 .552 r
.79758 .81958 m .7935 .82436 L .79509 .82973 L p F P
0 g
s
.304 .29 .678 r
.79273 .79986 m .7943 .79792 L .79237 .79054 L p F P
0 g
s
.281 .258 .655 r
.79572 .80388 m .79273 .79986 L .7943 .79792 L closepath p F P
0 g
s
.628 .891 .987 r
.7369 .9024 m .73235 .90582 L p .72398 .90612 L F P
0 g
s
.658 .913 .978 r
.73235 .90582 m .7369 .9024 L .73857 .90321 L closepath p F P
0 g
s
.525 .536 .809 r
.64982 .87007 m .65283 .87658 L .64084 .87597 L p F P
0 g
s
.525 .536 .809 r
.64357 .86958 m .64982 .87007 L p .64084 .87597 L F P
0 g
s
.525 .536 .809 r
.64084 .87597 m .63932 .87253 L .64357 .86958 L p F P
0 g
s
.275 .232 .627 r
.59263 .72607 m .59528 .7229 L .59216 .71824 L p F P
0 g
s
.227 .198 .616 r
.59616 .71304 m .59216 .71824 L .59528 .7229 L p F P
0 g
s
.267 .211 .607 r
.59366 .70821 m .59616 .71304 L .59216 .71824 L p F P
0 g
s
.365 .404 .768 r
.77985 .75219 m .77748 .75084 L .77868 .74902 L closepath p F P
0 g
s
.382 .426 .782 r
.77685 .7443 m .77328 .74249 L p .77748 .75084 L F P
0 g
s
.382 .426 .782 r
.77748 .75084 m .77868 .74902 L .77685 .7443 L p F P
0 g
s
0 0 .212 r
.78623 .85678 m .79086 .85195 L p .78475 .86264 L F P
0 g
s
0 0 .212 r
.78475 .86264 m .78489 .86129 L .78623 .85678 L p F P
0 g
s
.075 0 .363 r
.78623 .85678 m .79086 .85195 L .79178 .84588 L p F P
0 g
s
.455 .432 .743 r
.61211 .80204 m .60497 .80785 L .61375 .81112 L p F P
0 g
s
.462 .423 .729 r
.60415 .79856 m .61211 .80204 L .60497 .80785 L p F P
0 g
s
.392 .456 .807 r
.76299 .72632 m .77091 .72952 L .76797 .72265 L p F P
0 g
s
.392 .456 .807 r
.76797 .72265 m .76558 .72168 L .76299 .72632 L p F P
0 g
s
.395 .454 .803 r
.76299 .72632 m .77091 .72952 L p .76844 .73432 L F P
0 g
s
.34 .302 .67 r
.59719 .74638 m .59341 .7426 L .59571 .74012 L closepath p F P
0 g
s
.333 .293 .663 r
.59341 .7426 m .59571 .74012 L .59408 .73299 L p F P
0 g
s
0 0 .354 r
.59815 .67249 m .59555 .67738 L .59571 .68284 L p F P
0 g
s
0 0 .213 r
.59555 .67738 m .59815 .67249 L .59888 .66676 L p F P
0 g
s
0 0 .385 r
.59432 .68506 m .59571 .68284 L .59555 .67738 L p F P
0 g
s
.836 .769 .788 r
.16627 .8564 m .16961 .85264 L .16597 .84911 L p F P
0 g
s
.375 .423 .782 r
.77685 .7443 m .77328 .74249 L .77505 .73967 L closepath p F P
0 g
s
.392 .444 .795 r
.77387 .73677 m .76844 .73432 L p .77328 .74249 L F P
0 g
s
.392 .444 .795 r
.77328 .74249 m .77505 .73967 L .77387 .73677 L p F P
0 g
s
.385 .44 .795 r
.77387 .73677 m .76844 .73432 L .77108 .72991 L closepath p F P
0 g
s
.395 .454 .803 r
.77091 .72952 m .77108 .72991 L .76844 .73432 L p F P
0 g
s
.313 .266 .644 r
.59263 .72607 m .59528 .7229 L p .59427 .73278 L F P
0 g
s
.313 .266 .644 r
.59427 .73278 m .59394 .73238 L .59263 .72607 L p F P
0 g
s
.558 .678 .919 r
.6596 .64451 m .66892 .64373 L .66602 .63946 L p F P
0 g
s
.558 .678 .919 r
.66602 .63946 m .66079 .64001 L .6596 .64451 L p F P
0 g
s
.55 .679 .924 r
.65403 .64076 m .66079 .64001 L .6596 .64451 L p F P
0 g
s
.729 .795 .905 r
.1022 .90444 m .09702 .90714 L .09321 .90424 L p F P
0 g
s
.668 .787 .937 r
.08229 .90828 m .09321 .90424 L .09702 .90714 L p F P
0 g
s
.315 .33 .717 r
.7877 .77488 m .78948 .77226 L p .79127 .78128 L F P
0 g
s
.315 .33 .717 r
.79127 .78128 m .78909 .77937 L .7877 .77488 L p F P
0 g
s
.328 .353 .735 r
.7877 .77488 m .78596 .76955 L .78948 .77226 L closepath p F P
0 g
s
.573 .94 .884 r
.73857 .90321 m .75043 .8972 L .75205 .89717 L p F P
0 g
s
.654 .97 .883 r
.75043 .8972 m .75578 .89393 L .75205 .89717 L closepath p F P
0 g
s
.685 .978 .819 r
.76221 .88956 m .75578 .89393 L .75205 .89717 L p F P
0 g
s
.685 .978 .819 r
.76394 .88852 m .76221 .88956 L p .75205 .89717 L F P
0 g
s
.841 .773 .786 r
.16197 .85365 m .16627 .8564 L .15974 .86387 L p F P
0 g
s
.836 .769 .788 r
.16597 .84911 m .16197 .85365 L .16627 .8564 L p F P
0 g
s
.866 .765 .749 r
.17921 .83192 m .17792 .83377 L .17429 .83024 L p F P
0 g
s
.866 .765 .749 r
.17429 .83024 m .17509 .82908 L .17921 .83192 L p F P
0 g
s
.867 .764 .747 r
.17921 .83192 m .17509 .82908 L .17985 .82213 L p F P
0 g
s
.14 .022 .446 r
.7927 .83906 m .79174 .84007 L .79178 .84588 L p F P
0 g
s
.867 .767 .75 r
.1847 .81517 m .18641 .81271 L .18279 .80919 L p F P
0 g
s
.408 .485 .828 r
.75931 .71389 m .75246 .71162 L .75119 .70886 L p F P
0 g
s
.327 .353 .735 r
.78948 .77226 m .78596 .76955 L .78498 .76659 L p F P
0 g
s
.316 .331 .717 r
.79016 .78285 m .78909 .77937 L .79127 .78128 L closepath p F P
0 g
s
.046 0 .468 r
.59571 .68284 m .59432 .68506 L .59483 .69096 L p F P
0 g
s
.032 0 .464 r
.59354 .6931 m .59483 .69096 L .59432 .68506 L p F P
0 g
s
.327 .353 .735 r
.78498 .76659 m .78706 .7634 L p .78948 .77226 L F P
0 g
s
.339 .374 .751 r
.78498 .76659 m .78288 .76056 L .78706 .7634 L closepath p F P
0 g
s
.669 .788 .937 r
.09321 .90424 m .08229 .90828 L .07845 .90544 L p F P
0 g
s
.519 .639 .907 r
.67181 .64807 m .68068 .64784 L .67914 .65242 L p F P
0 g
s
.522 .634 .903 r
.67914 .65242 m .68677 .65242 L .68388 .6478 L p F P
0 g
s
.522 .634 .903 r
.68388 .6478 m .68068 .64784 L .67914 .65242 L p F P
0 g
s
.303 .307 .699 r
.79016 .78285 m .79127 .78128 L p .79243 .79046 L F P
0 g
s
.303 .307 .699 r
.79243 .79046 m .79231 .79034 L .79016 .78285 L p F P
0 g
s
.524 .534 .808 r
.63932 .87253 m .63781 .86911 L .64357 .86958 L closepath p F P
0 g
s
.087 .053 .52 r
.59483 .69096 m .59354 .6931 L .595 .69821 L p F P
0 g
s
.456 .546 .859 r
.72848 .68513 m .727 .68487 L .72764 .68351 L closepath p F P
0 g
s
.463 .556 .865 r
.7256 .6797 m .72764 .68351 L .727 .68487 L p F P
0 g
s
.851 .768 .77 r
.17375 .83907 m .17792 .83377 L .17429 .83024 L p F P
0 g
s
.55 .581 .838 r
.65882 .88865 m .65672 .88868 L .6583 .88764 L closepath p F P
0 g
s
.552 .57 .826 r
.65583 .88274 m .6583 .88764 L .65672 .88868 L p F P
0 g
s
.39 .357 .702 r
.60124 .76221 m .59706 .76628 L .60281 .7703 L p F P
0 g
s
.404 .353 .687 r
.6004 .75902 m .60124 .76221 L .59706 .76628 L p F P
0 g
s
.404 .353 .687 r
.59742 .75662 m .6004 .75902 L p .59706 .76628 L F P
0 g
s
.339 .374 .751 r
.78706 .7634 m .78288 .76056 L .78198 .75798 L p F P
0 g
s
.868 .769 .75 r
.18065 .81228 m .1847 .81517 L .17985 .82213 L p F P
0 g
s
.867 .767 .75 r
.18279 .80919 m .18065 .81228 L .1847 .81517 L p F P
0 g
s
.539 .837 .513 r
.76782 .88496 m .76394 .88852 L p .76436 .88812 L F P
0 g
s
.539 .837 .513 r
.77381 .87917 m .76782 .88496 L p .76436 .88812 L F P
0 g
s
0 0 0 r
.76782 .88496 m .77206 .88114 L .77381 .87917 L closepath p F P
0 g
s
.698 .978 .793 r
.76782 .88496 m .77206 .88114 L p .77166 .88144 L F P
0 g
s
.539 .837 .513 r
.77437 .87829 m .77381 .87917 L p .76394 .88852 L F P
0 g
s
.698 .978 .793 r
.76034 .89006 m .76782 .88496 L .77166 .88144 L F
.556 .895 .655 r
.76221 .88956 m .76782 .88496 L .76394 .88852 L closepath p F P
0 g
s
0 0 0 r
.60311 .65585 m .60103 .66014 L p .60274 .65708 L F P
0 g
s
0 0 0 r
.6072 .64913 m .60311 .65585 L p .60274 .65708 L F P
0 g
s
0 0 0 r
.60311 .65585 m .60103 .66014 L .59991 .6642 L p F P
0 g
s
0 0 0 r
.59991 .6642 m .60096 .66199 L .60311 .65585 L p F P
0 g
s
0 0 0 r
.60311 .65585 m .60096 .66199 L p .60352 .6545 L F P
0 g
s
0 0 0 r
.60464 .65122 m .60311 .65585 L p .60352 .6545 L F P
0 g
s
0 0 0 r
.59888 .66676 m .59991 .6642 L .60103 .66014 L p F P
0 g
s
.669 .765 .922 r
.62454 .64012 m .63633 .63588 L .63924 .63931 L p F P
0 g
s
.693 .785 .921 r
.63633 .63588 m .62454 .64012 L .62164 .63759 L p F P
0 g
s
.604 .71 .919 r
.63924 .63931 m .65113 .63686 L .65403 .64076 L p F P
0 g
s
.617 .723 .921 r
.65113 .63686 m .63924 .63931 L .63633 .63588 L p F P
0 g
s
.339 .374 .751 r
.78198 .75798 m .78401 .75472 L p .78706 .7634 L F P
0 g
s
.351 .394 .766 r
.78198 .75798 m .77985 .75219 L .78401 .75472 L closepath p F P
0 g
s
.794 .79 .849 r
.12381 .89659 m .12316 .8971 L .11941 .89402 L p F P
0 g
s
.762 .79 .876 r
.10813 .90138 m .11941 .89402 L .12316 .8971 L p F P
0 g
s
.333 .665 .974 r
.04964 .90118 m .05633 .90174 L .06025 .90458 L p F P
0 g
s
.884 .769 .729 r
.18527 .79576 m .18916 .79872 L .18507 .80545 L p F P
0 g
s
.883 .768 .73 r
.18916 .79872 m .18527 .79576 L .18938 .78903 L p F P
0 g
s
.794 .79 .849 r
.11941 .89402 m .11963 .89385 L .12381 .89659 L p F P
0 g
s
.788 .786 .851 r
.13085 .88511 m .11963 .89385 L .12381 .89659 L p F P
0 g
s
.788 .786 .851 r
.12381 .89659 m .13458 .88828 L .13085 .88511 L p F P
0 g
s
.303 .308 .699 r
.79237 .79054 m .79231 .79034 L .79243 .79046 L closepath p F P
0 g
s
.899 .769 .709 r
.19316 .7824 m .19148 .78555 L .18783 .78237 L p F P
0 g
s
.899 .769 .709 r
.18783 .78237 m .18944 .77937 L .19316 .7824 L p F P
0 g
s
.9 .768 .706 r
.19316 .7824 m .18944 .77937 L .19286 .77285 L p F P
0 g
s
.277 .272 .674 r
.79243 .79046 m .79237 .79054 L .7943 .79792 L p F P
0 g
s
.277 .275 .677 r
.79573 .7858 m .79243 .79046 L .79634 .79515 L p F P
0 g
s
.303 .307 .699 r
.79127 .78128 m .79573 .7858 L .79243 .79046 L p F P
0 g
s
.277 .272 .674 r
.7943 .79792 m .79634 .79515 L .79243 .79046 L p F P
0 g
s
.842 .773 .785 r
.15974 .86387 m .15781 .8661 L .15413 .8627 L p F P
0 g
s
.842 .773 .785 r
.15413 .8627 m .15551 .86111 L .15974 .86387 L p F P
0 g
s
.841 .773 .786 r
.15974 .86387 m .15551 .86111 L .16197 .85365 L p F P
0 g
s
.408 .485 .828 r
.75119 .70886 m .75243 .70628 L p .75931 .71389 L F P
0 g
s
.417 .5 .837 r
.75119 .70886 m .74956 .70543 L .75243 .70628 L closepath p F P
0 g
s
.709 .926 .964 r
.7369 .9024 m .73857 .90321 L .75043 .8972 L p F P
0 g
s
.442 .416 .734 r
.61023 .79338 m .60415 .79856 L .61211 .80204 L p F P
0 g
s
.45 .408 .72 r
.60993 .79241 m .61023 .79338 L .60415 .79856 L p F P
0 g
s
.45 .408 .72 r
.60357 .78919 m .60993 .79241 L p .60415 .79856 L F P
0 g
s
.595 .74 .945 r
.69446 .90576 m .70646 .90355 L .70926 .9068 L p F P
0 g
s
.591 .691 .912 r
.70363 .89997 m .70646 .90355 L .69446 .90576 L p F P
0 g
s
.591 .691 .912 r
.69426 .90139 m .70363 .89997 L p .69446 .90576 L F P
0 g
s
.591 .691 .912 r
.69446 .90576 m .69232 .90279 L .69426 .90139 L p F P
0 g
s
.398 .696 .981 r
.06025 .90458 m .0639 .90466 L .06002 .90182 L p F P
0 g
s
.398 .696 .981 r
.06002 .90182 m .05633 .90174 L .06025 .90458 L p F P
0 g
s
.527 .528 .8 r
.64357 .86958 m .63781 .86911 L .63511 .86277 L p F P
0 g
s
.523 .645 .911 r
.68068 .64784 m .67181 .64807 L .66892 .64373 L p F P
0 g
s
.496 .612 .897 r
.69502 .65733 m .68965 .65709 L .68677 .65242 L p F P
0 g
s
.823 .776 .808 r
.15231 .8716 m .15781 .8661 L .15413 .8627 L p F P
0 g
s
.729 .795 .905 r
.09321 .90424 m .09804 .90169 L .1022 .90444 L p F P
0 g
s
.724 .792 .906 r
.10434 .8984 m .09804 .90169 L .1022 .90444 L p F P
0 g
s
.724 .792 .906 r
.1022 .90444 m .10813 .90138 L .10434 .8984 L p F P
0 g
s
.305 .264 .646 r
.59408 .73299 m .59394 .73238 L .59427 .73278 L closepath p F P
0 g
s
.02 0 .251 r
.78424 .86313 m .78475 .86264 L .78489 .86129 L closepath p F P
0 g
s
.443 .535 .856 r
.72848 .68513 m .73833 .68717 L .73627 .69176 L p F P
0 g
s
.441 .537 .859 r
.73833 .68717 m .72848 .68513 L .72764 .68351 L p F P
0 g
s
.856 .771 .768 r
.16957 .83626 m .17375 .83907 L .16816 .84627 L p F P
0 g
s
.851 .768 .77 r
.17429 .83024 m .16957 .83626 L .17375 .83907 L p F P
0 g
s
.1 0 .434 r
.79596 .8353 m .7927 .83906 L .79298 .84462 L p F P
0 g
s
.156 .07 .499 r
.7927 .83906 m .79596 .8353 L .79509 .82973 L p F P
0 g
s
.14 .022 .446 r
.79178 .84588 m .79298 .84462 L .7927 .83906 L p F P
0 g
s
.318 .282 .66 r
.59427 .73278 m .59408 .73299 L .59571 .74012 L p F P
0 g
s
.35 .394 .767 r
.78401 .75472 m .77985 .75219 L .77868 .74902 L p F P
0 g
s
.827 .777 .804 r
.15231 .8716 m .14613 .87795 L .14243 .87466 L p F P
0 g
s
.827 .777 .804 r
.14243 .87466 m .14804 .86886 L .15231 .8716 L p F P
0 g
s
.823 .776 .808 r
.15413 .8627 m .14804 .86886 L .15231 .8716 L p F P
0 g
s
.561 .598 .848 r
.65882 .88865 m .67083 .8884 L p .67371 .89369 L F P
0 g
s
.542 .577 .839 r
.66787 .88288 m .67083 .8884 L .65882 .88865 L p F P
0 g
s
.542 .577 .839 r
.66508 .88285 m .66787 .88288 L p .65882 .88865 L F P
0 g
s
.542 .577 .839 r
.65882 .88865 m .6583 .88764 L .66508 .88285 L p F P
0 g
s
.23 .181 .593 r
.79742 .81184 m .79527 .81442 L .79758 .81958 L p F P
0 g
s
.26 .223 .625 r
.79527 .81442 m .79742 .81184 L .796 .80503 L p F P
0 g
s
.485 .585 .879 r
.70757 .66758 m .70689 .66752 L .70717 .66687 L closepath p F P
0 g
s
.49 .595 .885 r
.70469 .66263 m .70717 .66687 L .70689 .66752 L p F P
0 g
s
.318 .282 .66 r
.59571 .74012 m .59825 .73723 L .59427 .73278 L p F P
0 g
s
.278 .254 .652 r
.59866 .72751 m .59427 .73278 L .59825 .73723 L p F P
0 g
s
.313 .266 .644 r
.59528 .7229 m .59866 .72751 L .59427 .73278 L p F P
0 g
s
.361 .413 .78 r
.77868 .74902 m .77685 .7443 L .78035 .74619 L closepath p F P
0 g
s
.35 .394 .767 r
.77868 .74902 m .78035 .74619 L p .78401 .75472 L F P
0 g
s
.814 .785 .826 r
.13518 .88773 m .13458 .88828 L .13085 .88511 L p F P
0 g
s
.814 .785 .826 r
.13085 .88511 m .13099 .88498 L .13518 .88773 L p F P
0 g
s
.812 .785 .828 r
.14006 .87676 m .14438 .87949 L .13518 .88773 L p F P
0 g
s
.812 .785 .828 r
.13518 .88773 m .13099 .88498 L .14006 .87676 L p F P
0 g
s
.189 .166 .6 r
.59667 .70365 m .59366 .70821 L .59616 .71304 L p F P
0 g
s
.157 .125 .569 r
.59635 .70166 m .595 .69821 L p .59366 .70821 L F P
0 g
s
.157 .125 .569 r
.59366 .70821 m .59667 .70365 L .59635 .70166 L p F P
0 g
s
.888 .775 .73 r
.18938 .78903 m .19148 .78555 L .18783 .78237 L p F P
0 g
s
.261 .245 .652 r
.7943 .79792 m .79634 .79515 L p .79628 .80466 L F P
0 g
s
.261 .245 .652 r
.79628 .80466 m .79572 .80388 L .7943 .79792 L p F P
0 g
s
.806 .781 .83 r
.14243 .87466 m .14006 .87676 L .14438 .87949 L p F P
0 g
s
.806 .781 .83 r
.14438 .87949 m .14613 .87795 L .14243 .87466 L p F P
0 g
s
.541 .575 .838 r
.6583 .88764 m .65583 .88274 L .66508 .88285 L closepath p F P
0 g
s
.436 .521 .847 r
.73627 .69176 m .74377 .69351 L p .7448 .69889 L F P
0 g
s
.435 .525 .851 r
.73627 .69176 m .74377 .69351 L .74088 .68776 L p F P
0 g
s
.435 .525 .851 r
.74088 .68776 m .73833 .68717 L .73627 .69176 L p F P
0 g
s
0 0 .109 r
.78475 .86264 m .78424 .86313 L .78071 .86989 L p F P
0 g
s
.469 .572 .876 r
.70757 .66758 m .71984 .66908 L p .71844 .67374 L F P
0 g
s
.462 .572 .88 r
.71697 .664 m .71984 .66908 L .70757 .66758 L p F P
0 g
s
.462 .572 .88 r
.70843 .663 m .71697 .664 L p .70757 .66758 L F P
0 g
s
.462 .572 .88 r
.70757 .66758 m .70717 .66687 L .70843 .663 L p F P
0 g
s
.441 .537 .859 r
.72764 .68351 m .7289 .6803 L p .73833 .68717 L F P
0 g
s
.449 .55 .866 r
.72764 .68351 m .7256 .6797 L .7289 .6803 L closepath p F P
0 g
s
.559 .643 .889 r
.68872 .89748 m .6767 .89861 L .67378 .89368 L p F P
0 g
s
.568 .662 .9 r
.6767 .89861 m .68872 .89748 L .6916 .90179 L p F P
0 g
s
.613 .81 .975 r
.70926 .9068 m .72125 .90371 L .72398 .90612 L p F P
0 g
s
.604 .776 .963 r
.72125 .90371 m .70926 .9068 L .70646 .90355 L p F P
0 g
s
.558 .689 .928 r
.66079 .64001 m .65403 .64076 L .65113 .63686 L p F P
0 g
s
.628 .891 .987 r
.72398 .90612 m .73593 .90188 L .7369 .9024 L p F P
0 g
s
.624 .856 .987 r
.73593 .90188 m .72398 .90612 L .72125 .90371 L p F P
0 g
s
.868 .769 .75 r
.17985 .82213 m .17583 .81925 L .18065 .81228 L p F P
0 g
s
.871 .77 .748 r
.17583 .81925 m .17985 .82213 L .17509 .82908 L p F P
0 g
s
.416 .501 .838 r
.75243 .70628 m .74956 .70543 L .74666 .69938 L p F P
0 g
s
.297 .306 .701 r
.79447 .77662 m .79127 .78128 L .79573 .7858 L p F P
0 g
s
.315 .33 .717 r
.78948 .77226 m .79447 .77662 L .79127 .78128 L p F P
0 g
s
.527 .528 .8 r
.63511 .86277 m .63604 .86211 L p .64357 .86958 L F P
0 g
s
.515 .521 .8 r
.63511 .86277 m .63477 .86196 L .63604 .86211 L closepath p F P
0 g
s
.475 .586 .886 r
.70717 .66687 m .70469 .66263 L .70843 .663 L closepath p F P
0 g
s
.37 .337 .691 r
.6004 .75902 m .59742 .75662 L .59928 .75472 L closepath p F P
0 g
s
.365 .329 .685 r
.59742 .75662 m .59928 .75472 L .59742 .74734 L p F P
0 g
s
.36 .413 .781 r
.78035 .74619 m .77685 .7443 L .77505 .73967 L p F P
0 g
s
0 0 .135 r
.59991 .6642 m .59888 .66676 L .59815 .67249 L p F P
0 g
s
.427 .399 .725 r
.60993 .79241 m .60357 .78919 L .60782 .78542 L closepath p F P
0 g
s
.437 .393 .711 r
.60676 .78187 m .60782 .78542 L .60357 .78919 L p F P
0 g
s
.437 .393 .711 r
.60314 .77976 m .60676 .78187 L p .60357 .78919 L F P
0 g
s
.518 .514 .791 r
.63604 .86211 m .63477 .86196 L .63171 .85448 L p F P
0 g
s
0 0 .088 r
.78886 .85831 m .78475 .86264 L .78382 .86692 L p F P
0 g
s
0 0 .212 r
.79086 .85195 m .78886 .85831 L .78475 .86264 L p F P
0 g
s
0 0 .109 r
.78071 .86989 m .78382 .86692 L .78475 .86264 L p F P
0 g
s
.856 .771 .768 r
.16816 .84627 m .16403 .84345 L .16957 .83626 L p F P
0 g
s
.856 .771 .767 r
.16816 .84627 m .16597 .84911 L .1623 .8457 L p F P
0 g
s
.856 .771 .767 r
.1623 .8457 m .16403 .84345 L .16816 .84627 L p F P
0 g
s
.884 .769 .73 r
.18507 .80545 m .18279 .80919 L .17913 .80587 L p F P
0 g
s
.884 .769 .73 r
.17913 .80587 m .1812 .80249 L .18507 .80545 L p F P
0 g
s
.884 .769 .729 r
.18507 .80545 m .1812 .80249 L .18527 .79576 L p F P
0 g
s
.348 .307 .671 r
.59571 .74012 m .59825 .73723 L p .59777 .74695 L F P
0 g
s
.348 .307 .671 r
.59777 .74695 m .59719 .74638 L .59571 .74012 L p F P
0 g
s
.764 .792 .876 r
.11941 .89402 m .10813 .90138 L .10434 .8984 L p F P
0 g
s
.888 .775 .732 r
.18563 .786 m .18938 .78903 L .18527 .79576 L p F P
0 g
s
.888 .775 .73 r
.18783 .78237 m .18563 .786 L .18938 .78903 L p F P
0 g
s
0 0 .439 r
.59831 .67796 m .59571 .68284 L .59662 .6881 L p F P
0 g
s
0 0 .354 r
.59571 .68284 m .59831 .67796 L .59815 .67249 L p F P
0 g
s
.046 0 .468 r
.59483 .69096 m .59662 .6881 L .59571 .68284 L p F P
0 g
s
.097 .059 .522 r
.59662 .6881 m .59483 .69096 L .59563 .69717 L p F P
0 g
s
.087 .053 .52 r
.595 .69821 m .59563 .69717 L .59483 .69096 L p F P
0 g
s
.51 .502 .784 r
.63171 .85448 m .63004 .85423 L .63128 .85338 L closepath p F P
0 g
s
.513 .493 .772 r
.62863 .84666 m .63128 .85338 L .63004 .85423 L p F P
0 g
s
.513 .493 .772 r
.62524 .84604 m .62863 .84666 L p .63004 .85423 L F P
0 g
s
.159 .073 .502 r
.79923 .82495 m .79509 .82973 L .79596 .8353 L p F P
0 g
s
.201 .134 .552 r
.79509 .82973 m .79923 .82495 L .79758 .81958 L p F P
0 g
s
.501 .489 .776 r
.62863 .84666 m .62524 .84604 L .62772 .84426 L closepath p F P
0 g
s
.504 .48 .764 r
.62555 .83852 m .62772 .84426 L .62524 .84604 L p F P
0 g
s
.504 .48 .764 r
.62137 .83759 m .62555 .83852 L p .62524 .84604 L F P
0 g
s
.262 .246 .651 r
.796 .80503 m .79572 .80388 L .79628 .80466 L closepath p F P
0 g
s
.839 .774 .79 r
.16197 .85365 m .16597 .84911 L .1623 .8457 L p F P
0 g
s
.074 0 .362 r
.79298 .84462 m .79178 .84588 L .79086 .85195 L p F P
0 g
s
.57 .764 .97 r
.0639 .90466 m .0746 .90259 L .07845 .90544 L p F P
0 g
s
.571 .764 .97 r
.0746 .90259 m .0639 .90466 L .06002 .90182 L p F P
0 g
s
.231 .203 .619 r
.79628 .80466 m .796 .80503 L .79742 .81184 L p F P
0 g
s
.428 .51 .841 r
.74666 .69938 m .7448 .69889 L .74562 .69722 L closepath p F P
0 g
s
.436 .521 .847 r
.74377 .69351 m .74562 .69722 L .7448 .69889 L p F P
0 g
s
.36 .413 .781 r
.77505 .73967 m .77608 .73784 L p .78035 .74619 L F P
0 g
s
.371 .432 .794 r
.77505 .73967 m .77387 .73677 L .77608 .73784 L closepath p F P
0 g
s
.527 .528 .8 r
.63604 .86211 m .64679 .86331 L p .64357 .86958 L F P
0 g
s
.514 .525 .805 r
.64679 .86331 m .63604 .86211 L .6438 .8564 L closepath p F P
0 g
s
.518 .514 .791 r
.64374 .85627 m .6438 .8564 L .63604 .86211 L p F P
0 g
s
.518 .514 .791 r
.63171 .85448 m .64374 .85627 L p .63604 .86211 L F P
0 g
s
.491 .476 .768 r
.62555 .83852 m .62137 .83759 L .62439 .83536 L closepath p F P
0 g
s
.495 .467 .756 r
.62245 .83005 m .62439 .83536 L .62137 .83759 L p F P
0 g
s
.495 .467 .756 r
.61826 .82893 m .62245 .83005 L p .62137 .83759 L F P
0 g
s
.314 .335 .723 r
.79256 .76761 m .78948 .77226 L .79447 .77662 L p F P
0 g
s
.327 .353 .735 r
.78706 .7634 m .79256 .76761 L .78948 .77226 L p F P
0 g
s
0 0 0 r
.77381 .87917 m .77564 .87707 L .77437 .87829 L closepath p F P
0 g
s
0 0 0 r
.77437 .87829 m .77564 .87707 L .78071 .86989 L p F P
0 g
s
.59 .69 .911 r
.69232 .90279 m .6916 .90179 L .69426 .90139 L closepath p F P
0 g
s
.709 .926 .964 r
.75043 .8972 m .74785 .89663 L p .7369 .9024 L F P
0 g
s
.586 .946 .866 r
.75578 .89393 m .75043 .8972 L .74785 .89663 L p F P
0 g
s
.231 .203 .619 r
.79742 .81184 m .79907 .80969 L .79628 .80466 L p F P
0 g
s
.229 .204 .622 r
.79973 .8 m .79628 .80466 L .79907 .80969 L p F P
0 g
s
.261 .245 .652 r
.79634 .79515 m .79973 .8 L .79628 .80466 L p F P
0 g
s
.871 .774 .752 r
.18065 .81228 m .18279 .80919 L .17913 .80587 L p F P
0 g
s
.844 .777 .787 r
.15779 .85084 m .16197 .85365 L .15551 .86111 L p F P
0 g
s
.839 .774 .79 r
.1623 .8457 m .15779 .85084 L .16197 .85365 L p F P
0 g
s
.543 .568 .83 r
.66508 .88285 m .65583 .88274 L .65285 .87662 L p F P
0 g
s
.341 .306 .674 r
.59742 .74734 m .59719 .74638 L .59777 .74695 L closepath p F P
0 g
s
.763 .994 .873 r
.60798 .64598 m .60998 .64593 L .61643 .64087 L p F P
0 g
s
.885 .986 .811 r
.6072 .64913 m .60798 .64598 L .60998 .64593 L closepath p F P
0 g
s
.87 .77 .75 r
.17509 .82908 m .17429 .83024 L .17063 .82685 L p F P
0 g
s
.87 .77 .75 r
.17063 .82685 m .17108 .8262 L .17509 .82908 L p F P
0 g
s
.871 .77 .748 r
.17509 .82908 m .17108 .8262 L .17583 .81925 L p F P
0 g
s
.252 .235 .645 r
.59898 .7178 m .59528 .7229 L .59866 .72751 L p F P
0 g
s
.227 .198 .616 r
.59528 .7229 m .59898 .7178 L .59616 .71304 L p F P
0 g
s
0 0 0 r
.78382 .86692 m .78071 .86989 L .77564 .87707 L p F P
0 g
s
.371 .432 .794 r
.77608 .73784 m .77387 .73677 L .77108 .72991 L p F P
0 g
s
.73 .796 .905 r
.09804 .90169 m .09321 .90424 L .08939 .90135 L p F P
0 g
s
.669 .788 .937 r
.07845 .90544 m .08939 .90135 L .09321 .90424 L p F P
0 g
s
.349 .319 .683 r
.59777 .74695 m .59742 .74734 L .59928 .75472 L p F P
0 g
s
.497 .495 .784 r
.64068 .8489 m .64374 .85627 L .63171 .85448 L p F P
0 g
s
.497 .495 .784 r
.63793 .84839 m .64068 .8489 L p .63171 .85448 L F P
0 g
s
.497 .495 .784 r
.63171 .85448 m .63128 .85338 L .63793 .84839 L p F P
0 g
s
.447 .551 .869 r
.7289 .6803 m .7256 .6797 L .72272 .67437 L p F P
0 g
s
.48 .462 .761 r
.62245 .83005 m .61826 .82893 L .62125 .82666 L closepath p F P
0 g
s
.485 .454 .748 r
.61934 .82122 m .62125 .82666 L .61826 .82893 L p F P
0 g
s
.485 .454 .748 r
.61577 .8201 m .61934 .82122 L p .61826 .82893 L F P
0 g
s
.463 .562 .87 r
.72272 .67437 m .71844 .67374 L .72013 .6696 L closepath p F P
0 g
s
.469 .572 .876 r
.71984 .66908 m .72013 .6696 L .71844 .67374 L p F P
0 g
s
.127 .103 .559 r
.59635 .70166 m .595 .69821 L .59563 .69717 L closepath p F P
0 g
s
.67 .904 .978 r
.73593 .90188 m .73907 .90055 L .7369 .9024 L closepath p F P
0 g
s
.709 .926 .964 r
.74785 .89663 m .73907 .90055 L .7369 .9024 L p F P
0 g
s
.855 .774 .771 r
.16957 .83626 m .17429 .83024 L .17063 .82685 L p F P
0 g
s
.496 .493 .783 r
.63128 .85338 m .62863 .84666 L .63793 .84839 L closepath p F P
0 g
s
.495 .606 .892 r
.69502 .65733 m .70182 .65774 L .69893 .65289 L p F P
0 g
s
.495 .606 .892 r
.69893 .65289 m .69656 .65277 L .69502 .65733 L p F P
0 g
s
.496 .612 .897 r
.68677 .65242 m .69656 .65277 L .69502 .65733 L p F P
0 g
s
.67 .789 .938 r
.08939 .90135 m .07845 .90544 L .0746 .90259 L p F P
0 g
s
.813 .905 .498 r
.60798 .64598 m .6072 .64913 L .60311 .65585 L p F P
0 g
s
.408 .485 .828 r
.75243 .70628 m .76165 .70927 L .75931 .71389 L p F P
0 g
s
.411 .494 .834 r
.75454 .70171 m .75243 .70628 L .76165 .70927 L p F P
0 g
s
.416 .501 .838 r
.74666 .69938 m .75454 .70171 L .75243 .70628 L p F P
0 g
s
.412 .382 .716 r
.60676 .78187 m .60314 .77976 L .60552 .77756 L closepath p F P
0 g
s
.409 .378 .713 r
.60359 .77082 m .60281 .7703 L p .60314 .77976 L F P
0 g
s
.409 .378 .713 r
.60314 .77976 m .60552 .77756 L .60359 .77082 L p F P
0 g
s
.498 .617 .9 r
.69656 .65277 m .68677 .65242 L .68388 .6478 L p F P
0 g
s
.327 .358 .741 r
.79001 .75876 m .78706 .7634 L .79256 .76761 L p F P
0 g
s
.339 .374 .751 r
.78401 .75472 m .79001 .75876 L .78706 .7634 L p F P
0 g
s
.763 .994 .873 r
.61643 .64087 m .61728 .63642 L p .60798 .64598 L F P
0 g
s
.772 .875 .923 r
.61873 .63536 m .61728 .63642 L .61643 .64087 L p F P
0 g
s
.772 .875 .923 r
.61643 .64087 m .62164 .63759 L .61873 .63536 L p F P
0 g
s
.524 .539 .813 r
.64982 .87007 m .64357 .86958 L .64814 .86633 L closepath p F P
0 g
s
.527 .528 .8 r
.64679 .86331 m .64814 .86633 L .64357 .86958 L p F P
0 g
s
.594 .673 .895 r
.69426 .90139 m .6916 .90179 L .68872 .89748 L p F P
0 g
s
.349 .319 .683 r
.59928 .75472 m .60253 .75122 L .59777 .74695 L p F P
0 g
s
.325 .309 .688 r
.60242 .74165 m .59777 .74695 L .60253 .75122 L p F P
0 g
s
.348 .307 .671 r
.59825 .73723 m .60242 .74165 L .59777 .74695 L p F P
0 g
s
.523 .645 .911 r
.66892 .64373 m .68099 .64327 L p .68068 .64784 L F P
0 g
s
.534 .65 .909 r
.68099 .64327 m .66892 .64373 L .66602 .63946 L p F P
0 g
s
.872 .775 .752 r
.17673 .80935 m .18065 .81228 L .17583 .81925 L p F P
0 g
s
.871 .774 .752 r
.17913 .80587 m .17673 .80935 L .18065 .81228 L p F P
0 g
s
.413 .501 .84 r
.75454 .70171 m .74666 .69938 L .74562 .69722 L p F P
0 g
s
.603 .946 .792 r
.75578 .89393 m .76034 .89006 L .76221 .88956 L closepath p F P
0 g
s
.586 .946 .866 r
.76034 .89006 m .75578 .89393 L p .74785 .89663 L F P
0 g
s
.795 .793 .85 r
.11941 .89402 m .11963 .89385 L .11694 .89202 L closepath p F P
0 g
s
.764 .792 .876 r
.11694 .89202 m .11941 .89402 L p .10434 .8984 L F P
0 g
s
.617 .723 .921 r
.63633 .63588 m .64823 .63306 L .65113 .63686 L p F P
0 g
s
.632 .736 .923 r
.64823 .63306 m .63633 .63588 L .63343 .63261 L p F P
0 g
s
.693 .785 .921 r
.62164 .63759 m .63343 .63261 L .63633 .63588 L p F P
0 g
s
.798 .792 .847 r
.12941 .88391 m .13085 .88511 L .11963 .89385 L p F P
0 g
s
.798 .792 .847 r
.1268 .88221 m .12941 .88391 L p .11963 .89385 L F P
0 g
s
.798 .792 .847 r
.11564 .89097 m .1268 .88221 L p .11963 .89385 L F P
0 g
s
.798 .792 .847 r
.11963 .89385 m .11694 .89202 L .11564 .89097 L p F P
0 g
s
.889 .775 .731 r
.18153 .79274 m .18527 .79576 L .1812 .80249 L p F P
0 g
s
.888 .775 .732 r
.18527 .79576 m .18153 .79274 L .18563 .786 L p F P
0 g
s
.845 .777 .786 r
.15551 .86111 m .15413 .8627 L .15044 .8594 L p F P
0 g
s
.845 .777 .786 r
.15044 .8594 m .15139 .85829 L .15551 .86111 L p F P
0 g
s
.844 .777 .787 r
.15551 .86111 m .15139 .85829 L .15779 .85084 L p F P
0 g
s
.559 .611 .862 r
.67378 .89368 m .67371 .89369 L .67376 .89365 L closepath p F P
0 g
s
.561 .598 .848 r
.67083 .8884 m .67376 .89365 L .67371 .89369 L p F P
0 g
s
.559 .643 .889 r
.67378 .89368 m .68582 .89288 L .68872 .89748 L p F P
0 g
s
.553 .608 .862 r
.6829 .88801 m .68582 .89288 L .67378 .89368 L p F P
0 g
s
.553 .608 .862 r
.6814 .88806 m .6829 .88801 L p .67378 .89368 L F P
0 g
s
.553 .608 .862 r
.67378 .89368 m .67376 .89365 L .6814 .88806 L p F P
0 g
s
.552 .607 .862 r
.67376 .89365 m .67083 .8884 L .6814 .88806 L closepath p F P
0 g
s
.406 .477 .821 r
.76504 .71597 m .75931 .71389 L p .76558 .72168 L F P
0 g
s
.398 .472 .82 r
.75931 .71389 m .76504 .71597 L .76212 .70944 L p F P
0 g
s
.398 .472 .82 r
.76212 .70944 m .76165 .70927 L .75931 .71389 L p F P
0 g
s
.028 0 .347 r
.79603 .84111 m .79298 .84462 L .79291 .8498 L p F P
0 g
s
.074 0 .362 r
.79086 .85195 m .79291 .8498 L .79298 .84462 L p F P
0 g
s
.1 0 .434 r
.79298 .84462 m .79603 .84111 L .79596 .8353 L p F P
0 g
s
.469 .448 .753 r
.61934 .82122 m .61577 .8201 L .61828 .81812 L closepath p F P
0 g
s
.475 .441 .74 r
.61621 .81203 m .61828 .81812 L .61577 .8201 L p F P
0 g
s
.475 .441 .74 r
.61375 .81112 m .61621 .81203 L p .61577 .8201 L F P
0 g
s
.826 .78 .809 r
.14804 .86886 m .15413 .8627 L .15044 .8594 L p F P
0 g
s
.375 .34 .691 r
.59928 .75472 m .60253 .75122 L p .60263 .76077 L F P
0 g
s
.375 .34 .691 r
.60263 .76077 m .6004 .75902 L .59928 .75472 L p F P
0 g
s
.339 .38 .758 r
.78682 .75009 m .78401 .75472 L .79001 .75876 L p F P
0 g
s
.35 .394 .767 r
.78035 .74619 m .78682 .75009 L .78401 .75472 L p F P
0 g
s
.473 .588 .888 r
.70843 .663 m .70469 .66263 L .70182 .65774 L p F P
0 g
s
.197 .158 .585 r
.79907 .80969 m .79742 .81184 L .7986 .81837 L p F P
0 g
s
.23 .181 .593 r
.79758 .81958 m .7986 .81837 L .79742 .81184 L p F P
0 g
s
.73 .796 .905 r
.08939 .90135 m .09398 .8989 L .09804 .90169 L p F P
0 g
s
.726 .795 .906 r
.10054 .89545 m .09398 .8989 L .09804 .90169 L p F P
0 g
s
.726 .795 .906 r
.09804 .90169 m .10434 .8984 L .10054 .89545 L p F P
0 g
s
.499 .489 .776 r
.63793 .84839 m .62863 .84666 L .62772 .84426 L p F P
0 g
s
.859 .776 .768 r
.16552 .83339 m .16957 .83626 L .16403 .84345 L p F P
0 g
s
.855 .774 .771 r
.17063 .82685 m .16552 .83339 L .16957 .83626 L p F P
0 g
s
.721 .805 .917 r
.63343 .63261 m .62164 .63759 L .61873 .63536 L p F P
0 g
s
.549 .826 .477 r
.77206 .88114 m .77381 .87917 L .77564 .87707 L p F P
0 g
s
.549 .826 .477 r
.77564 .87707 m .78064 .87218 L p .77206 .88114 L F P
0 g
s
0 0 0 r
.78299 .86911 m .78382 .86692 L p .77564 .87707 L F P
0 g
s
0 0 0 r
.77564 .87707 m .78064 .87218 L .78299 .86911 L p F P
0 g
s
.83 .781 .805 r
.14804 .86886 m .14243 .87466 L .13871 .87145 L p F P
0 g
s
.83 .781 .805 r
.13871 .87145 m .14388 .86607 L .14804 .86886 L p F P
0 g
s
.826 .78 .809 r
.15044 .8594 m .14388 .86607 L .14804 .86886 L p F P
0 g
s
.413 .501 .84 r
.74562 .69722 m .74684 .69432 L p .75454 .70171 L F P
0 g
s
.422 .516 .849 r
.74562 .69722 m .74377 .69351 L .74684 .69432 L closepath p F P
0 g
s
.371 .432 .794 r
.77108 .72991 m .77121 .72965 L p .77608 .73784 L F P
0 g
s
.381 .449 .806 r
.77108 .72991 m .77091 .72952 L .77121 .72965 L closepath p F P
0 g
s
.569 .684 .918 r
.66079 .64001 m .66602 .63946 L .66312 .63527 L p F P
0 g
s
.569 .684 .918 r
.66312 .63527 m .6624 .63536 L .66079 .64001 L p F P
0 g
s
.558 .689 .928 r
.65113 .63686 m .6624 .63536 L .66079 .64001 L p F P
0 g
s
.698 .978 .793 r
.76034 .89006 m .76221 .88956 L .76782 .88496 L p F P
0 g
s
.168 .132 .57 r
.59563 .69717 m .59811 .69321 L p .59698 .70318 L F P
0 g
s
.168 .132 .57 r
.59698 .70318 m .59635 .70166 L .59563 .69717 L p F P
0 g
s
.097 .059 .522 r
.59563 .69717 m .59811 .69321 L .59662 .6881 L p F P
0 g
s
.35 .401 .773 r
.783 .74159 m .78035 .74619 L .78682 .75009 L p F P
0 g
s
.36 .413 .781 r
.77608 .73784 m .783 .74159 L .78035 .74619 L p F P
0 g
s
.499 .489 .776 r
.62772 .84426 m .63298 .8402 L p .63793 .84839 L F P
0 g
s
.486 .48 .775 r
.62772 .84426 m .62555 .83852 L .63298 .8402 L closepath p F P
0 g
s
.39 .457 .809 r
.76797 .72265 m .76558 .72168 L .76668 .71964 L closepath p F P
0 g
s
.406 .477 .821 r
.76558 .72168 m .76668 .71964 L .76504 .71597 L p F P
0 g
s
.379 .45 .808 r
.77121 .72965 m .77091 .72952 L .76797 .72265 L p F P
0 g
s
.369 .34 .695 r
.60124 .76221 m .6004 .75902 L .60263 .76077 L closepath p F P
0 g
s
.277 .275 .677 r
.79634 .79515 m .79972 .79048 L .79573 .7858 L p F P
0 g
s
.258 .247 .656 r
.79972 .79048 m .79634 .79515 L .79973 .8 L p F P
0 g
s
.589 .696 .916 r
.70363 .89997 m .69426 .90139 L .7009 .89624 L closepath p F P
0 g
s
.594 .673 .895 r
.70078 .89607 m .7009 .89624 L .69426 .90139 L p F P
0 g
s
.594 .673 .895 r
.68872 .89748 m .70078 .89607 L p .69426 .90139 L F P
0 g
s
0 0 .308 r
.59952 .66909 m .59815 .67249 L .59831 .67796 L p F P
0 g
s
0 0 .135 r
.59815 .67249 m .59952 .66909 L .59991 .6642 L p F P
0 g
s
.815 .788 .828 r
.13085 .88511 m .13099 .88498 L .12941 .88391 L closepath p F P
0 g
s
.818 .788 .823 r
.13586 .87399 m .14006 .87676 L .13099 .88498 L p F P
0 g
s
.818 .788 .823 r
.1271 .88198 m .13586 .87399 L p .13099 .88498 L F P
0 g
s
.818 .788 .823 r
.13099 .88498 m .12941 .88391 L .1271 .88198 L p F P
0 g
s
.194 .13 .552 r
.7986 .81837 m .79758 .81958 L .79923 .82495 L p F P
0 g
s
.362 .42 .787 r
.77857 .73325 m .77608 .73784 L .783 .74159 L p F P
0 g
s
.371 .432 .794 r
.77121 .72965 m .77857 .73325 L .77608 .73784 L p F P
0 g
s
.372 .439 .801 r
.77353 .72509 m .77121 .72965 L .77857 .73325 L p F P
0 g
s
.379 .45 .808 r
.76797 .72265 m .77353 .72509 L .77121 .72965 L p F P
0 g
s
.809 .785 .831 r
.13871 .87145 m .13586 .87399 L .14006 .87676 L p F P
0 g
s
.809 .785 .831 r
.14006 .87676 m .14243 .87466 L .13871 .87145 L p F P
0 g
s
0 0 .166 r
.60096 .66199 m .59991 .6642 L .59952 .66909 L p F P
0 g
s
.567 .701 .931 r
.6624 .63536 m .65113 .63686 L .64823 .63306 L p F P
0 g
s
.523 .645 .911 r
.68099 .64327 m .68183 .64458 L .68068 .64784 L p F P
0 g
s
.522 .633 .901 r
.68388 .6478 m .68068 .64784 L .68183 .64458 L closepath p F P
0 g
s
.374 .347 .7 r
.60263 .76077 m .60124 .76221 L .60331 .76981 L p F P
0 g
s
.39 .357 .702 r
.60281 .7703 m .60331 .76981 L .60124 .76221 L p F P
0 g
s
.636 .902 .984 r
.73907 .90055 m .73593 .90188 L .73324 .89999 L p F P
0 g
s
.624 .856 .987 r
.72125 .90371 m .73324 .89999 L .73593 .90188 L p F P
0 g
s
.543 .568 .83 r
.65285 .87662 m .65291 .87658 L p .66508 .88285 L F P
0 g
s
.533 .561 .83 r
.65285 .87662 m .65283 .87658 L .65291 .87658 L closepath p F P
0 g
s
.604 .776 .963 r
.70646 .90355 m .71849 .9009 L .72125 .90371 L p F P
0 g
s
.594 .746 .949 r
.71849 .9009 m .70646 .90355 L .70363 .89997 L p F P
0 g
s
.535 .553 .819 r
.65291 .87658 m .65283 .87658 L .64982 .87007 L p F P
0 g
s
.523 .546 .821 r
.65291 .87658 m .66488 .87705 L .66189 .87098 L p F P
0 g
s
.523 .546 .821 r
.66189 .87098 m .66061 .87088 L .65291 .87658 L p F P
0 g
s
.535 .553 .819 r
.64982 .87007 m .66061 .87088 L .65291 .87658 L p F P
0 g
s
.543 .568 .83 r
.65291 .87658 m .66488 .87705 L p .66508 .88285 L F P
0 g
s
.395 .365 .707 r
.60359 .77082 m .60281 .7703 L .60331 .76981 L closepath p F P
0 g
s
.813 .905 .498 r
.60713 .64645 m .60798 .64598 L p .60311 .65585 L F P
0 g
s
.813 .905 .498 r
.60311 .65585 m .60464 .65122 L p .60447 .65267 L F P
0 g
s
0 0 0 r
.60276 .65729 m .60464 .65122 L p .60239 .65782 L F P
0 g
s
0 0 0 r
.60096 .66199 m .60276 .65729 L p .60239 .65782 L F P
0 g
s
0 0 .051 r
.60276 .65729 m .60205 .66303 L p .60313 .65677 L F P
0 g
s
.709 .719 .196 r
.60464 .65122 m .60276 .65729 L p .60477 .65005 L F P
0 g
s
.709 .719 .196 r
.60437 .65063 m .60527 .64825 L p .60276 .65729 L F P
0 g
s
.709 .719 .196 r
.60382 .6528 m .60437 .65063 L p .6035 .65424 L F P
0 g
s
.709 .719 .196 r
.60276 .65729 m .60382 .6528 L p .6035 .65424 L F P
0 g
s
0 0 0 r
.60382 .6528 m .60321 .65851 L p .60391 .65238 L F P
0 g
s
.771 .761 .248 r
.60382 .6528 m .60394 .65208 L .60437 .65063 L closepath p F P
0 g
s
0 0 0 r
.60394 .65208 m .60382 .6528 L p .60391 .65238 L F P
0 g
s
0 0 .051 r
.60382 .6528 m .60276 .65729 L p .60313 .65677 L F P
0 g
s
.709 .719 .196 r
.60527 .64825 m .60464 .65122 L p .60477 .65005 L F P
0 g
s
.813 .905 .498 r
.60464 .65122 m .60713 .64645 L p .60447 .65267 L F P
0 g
s
.208 .19 .618 r
.59793 .71038 m .59616 .71304 L .59898 .7178 L p F P
0 g
s
.189 .166 .6 r
.59616 .71304 m .59793 .71038 L .59667 .70365 L p F P
0 g
s
.457 .434 .745 r
.61621 .81203 m .61375 .81112 L .61546 .80973 L closepath p F P
0 g
s
.455 .432 .743 r
.61308 .80245 m .61211 .80204 L p .61375 .81112 L F P
0 g
s
.455 .432 .743 r
.61375 .81112 m .61546 .80973 L .61308 .80245 L p F P
0 g
s
.441 .537 .859 r
.7289 .6803 m .73799 .68213 L p .73833 .68717 L F P
0 g
s
.44 .542 .864 r
.7289 .6803 m .73799 .68213 L .73511 .67666 L p F P
0 g
s
.44 .542 .864 r
.73511 .67666 m .73061 .67576 L .7289 .6803 L p F P
0 g
s
.447 .551 .869 r
.72272 .67437 m .73061 .67576 L .7289 .6803 L p F P
0 g
s
.872 .775 .752 r
.17583 .81925 m .17193 .81631 L .17673 .80935 L p F P
0 g
s
.874 .776 .75 r
.17193 .81631 m .17583 .81925 L .17108 .8262 L p F P
0 g
s
0 0 .249 r
.79291 .8498 m .79086 .85195 L .78886 .85831 L p F P
0 g
s
.49 .475 .768 r
.63298 .8402 m .62555 .83852 L .62439 .83536 L p F P
0 g
s
.49 .475 .768 r
.62439 .83536 m .62889 .83178 L p .63298 .8402 L F P
0 g
s
.476 .466 .767 r
.62439 .83536 m .62245 .83005 L .62889 .83178 L closepath p F P
0 g
s
.298 .284 .675 r
.60227 .73207 m .59825 .73723 L .60242 .74165 L p F P
0 g
s
.278 .254 .652 r
.59825 .73723 m .60227 .73207 L .59866 .72751 L p F P
0 g
s
.616 .819 .978 r
.73324 .89999 m .72125 .90371 L .71849 .9009 L p F P
0 g
s
.101 0 .434 r
.80012 .83053 m .79596 .8353 L .79603 .84111 L p F P
0 g
s
.159 .073 .502 r
.80012 .83049 m .79923 .82495 L p .79596 .8353 L F P
0 g
s
.159 .073 .502 r
.79596 .8353 m .80012 .83053 L .80012 .83049 L p F P
0 g
s
0 0 .439 r
.59662 .6881 m .59914 .68325 L .59831 .67796 L p F P
0 g
s
.007 0 .494 r
.59914 .68325 m .59662 .6881 L .59811 .69321 L p F P
0 g
s
.859 .776 .768 r
.16403 .84345 m .1623 .8457 L .15861 .84241 L p F P
0 g
s
.859 .776 .768 r
.15861 .84241 m .16002 .84058 L .16403 .84345 L p F P
0 g
s
.859 .776 .768 r
.16403 .84345 m .16002 .84058 L .16552 .83339 L p F P
0 g
s
.398 .367 .708 r
.60331 .76981 m .6081 .76488 L p .60887 .77425 L F P
0 g
s
.398 .367 .708 r
.60887 .77425 m .60359 .77082 L .60331 .76981 L p F P
0 g
s
.374 .347 .7 r
.60331 .76981 m .6081 .76488 L .60263 .76077 L p F P
0 g
s
.888 .776 .732 r
.1812 .80249 m .17913 .80587 L .17545 .80275 L p F P
0 g
s
.888 .776 .732 r
.17545 .80275 m .17745 .79948 L .1812 .80249 L p F P
0 g
s
.889 .775 .731 r
.1812 .80249 m .17745 .79948 L .18153 .79274 L p F P
0 g
s
.393 .368 .712 r
.60552 .77756 m .60359 .77082 L .60887 .77425 L closepath p F P
0 g
s
.764 .792 .876 r
.10434 .8984 m .11547 .89108 L .11694 .89202 L p F P
0 g
s
.766 .795 .877 r
.11547 .89108 m .10434 .8984 L .10054 .89545 L p F P
0 g
s
.447 .553 .87 r
.73061 .67576 m .72272 .67437 L .72013 .6696 L p F P
0 g
s
.636 .902 .984 r
.74533 .8955 m .73907 .90055 L p .73324 .89999 L F P
0 g
s
.667 .924 .974 r
.73907 .90055 m .74533 .8955 L .74785 .89663 L closepath p F P
0 g
s
.479 .462 .761 r
.62889 .83178 m .62245 .83005 L .62125 .82666 L p F P
0 g
s
.161 .129 .57 r
.59667 .70365 m .59635 .70166 L .59698 .70318 L closepath p F P
0 g
s
.42 .517 .851 r
.74684 .69432 m .74377 .69351 L .74088 .68776 L p F P
0 g
s
.843 .78 .791 r
.15779 .85084 m .1623 .8457 L .15861 .84241 L p F P
0 g
s
.274 .275 .679 r
.79903 .78113 m .79573 .7858 L .79972 .79048 L p F P
0 g
s
.297 .306 .701 r
.79573 .7858 m .79903 .78113 L .79447 .77662 L p F P
0 g
s
.788 .789 .853 r
.12941 .88391 m .1271 .88198 L .1268 .88221 L closepath p F P
0 g
s
.479 .462 .761 r
.62125 .82666 m .62549 .82317 L p .62889 .83178 L F P
0 g
s
.465 .452 .759 r
.62125 .82666 m .61934 .82122 L .62549 .82317 L closepath p F P
0 g
s
.414 .384 .717 r
.60552 .77756 m .60887 .77425 L p .60975 .78358 L F P
0 g
s
.414 .384 .717 r
.60975 .78358 m .60676 .78187 L .60552 .77756 L p F P
0 g
s
.761 .792 .878 r
.11694 .89202 m .11564 .89097 L .11547 .89108 L closepath p F P
0 g
s
.375 .448 .808 r
.77353 .72509 m .76797 .72265 L .76668 .71964 L p F P
0 g
s
.444 .419 .737 r
.61308 .80245 m .61211 .80204 L .61277 .80148 L closepath p F P
0 g
s
.442 .416 .734 r
.61211 .80204 m .61277 .80148 L .61023 .79338 L p F P
0 g
s
.47 .582 .884 r
.70843 .663 m .71697 .664 L .71408 .65896 L p F P
0 g
s
.47 .582 .884 r
.71408 .65896 m .70985 .65849 L .70843 .663 L p F P
0 g
s
.473 .588 .888 r
.70182 .65774 m .70985 .65849 L .70843 .663 L p F P
0 g
s
.571 .764 .97 r
.06002 .90182 m .07073 .89973 L .0746 .90259 L p F P
0 g
s
.157 .104 .542 r
.80127 .81489 m .7986 .81837 L .79951 .82461 L p F P
0 g
s
.194 .13 .552 r
.79923 .82495 m .79951 .82461 L .7986 .81837 L p F P
0 g
s
.197 .158 .585 r
.7986 .81837 m .80127 .81489 L .79907 .80969 L p F P
0 g
s
.409 .385 .721 r
.60782 .78542 m .60676 .78187 L .60975 .78358 L closepath p F P
0 g
s
.498 .617 .9 r
.68388 .6478 m .69605 .64815 L p .69656 .65277 L F P
0 g
s
.494 .619 .904 r
.69316 .64355 m .69605 .64815 L .68388 .6478 L p F P
0 g
s
.494 .619 .904 r
.6821 .64329 m .69316 .64355 L p .68388 .6478 L F P
0 g
s
.494 .619 .904 r
.68388 .6478 m .68183 .64458 L .6821 .64329 L p F P
0 g
s
.468 .448 .753 r
.62549 .82317 m .61934 .82122 L .61828 .81812 L p F P
0 g
s
.555 .599 .852 r
.6814 .88806 m .67083 .8884 L .66787 .88288 L p F P
0 g
s
.19 .167 .6 r
.59698 .70318 m .59667 .70365 L .59793 .71038 L p F P
0 g
s
.563 .664 .905 r
.70078 .89607 m .68872 .89748 L .68582 .89288 L p F P
0 g
s
.428 .4 .725 r
.60782 .78542 m .60975 .78358 L p .6108 .79285 L F P
0 g
s
.428 .4 .725 r
.6108 .79285 m .60993 .79241 L .60782 .78542 L p F P
0 g
s
.876 .781 .754 r
.17673 .80935 m .17913 .80587 L .17545 .80275 L p F P
0 g
s
.847 .782 .788 r
.15373 .84799 m .15779 .85084 L .15139 .85829 L p F P
0 g
s
.843 .78 .791 r
.15861 .84241 m .15373 .84799 L .15779 .85084 L p F P
0 g
s
.468 .448 .753 r
.61828 .81812 m .62266 .8144 L p .62549 .82317 L F P
0 g
s
.453 .437 .751 r
.61828 .81812 m .61621 .81203 L .62266 .8144 L closepath p F P
0 g
s
.434 .526 .853 r
.74088 .68776 m .73833 .68717 L .73937 .68476 L closepath p F P
0 g
s
.441 .537 .859 r
.73799 .68213 m .73937 .68476 L .73833 .68717 L p F P
0 g
s
.357 .344 .708 r
.6074 .75547 m .60263 .76077 L .6081 .76488 L p F P
0 g
s
.375 .34 .691 r
.60253 .75122 m .6074 .75547 L .60263 .76077 L p F P
0 g
s
.873 .776 .751 r
.17108 .8262 m .17063 .82685 L .16695 .82362 L p F P
0 g
s
.873 .776 .751 r
.16695 .82362 m .16719 .82326 L .17108 .8262 L p F P
0 g
s
.874 .776 .75 r
.17108 .8262 m .16719 .82326 L .17193 .81631 L p F P
0 g
s
.525 .539 .813 r
.66061 .87088 m .64982 .87007 L .64814 .86633 L p F P
0 g
s
.457 .434 .745 r
.62266 .8144 m .61621 .81203 L .61546 .80973 L p F P
0 g
s
.424 .402 .731 r
.61023 .79338 m .60993 .79241 L .6108 .79285 L closepath p F P
0 g
s
.534 .65 .909 r
.66602 .63946 m .6781 .6389 L .68099 .64327 L p F P
0 g
s
.537 .656 .912 r
.6781 .6389 m .66602 .63946 L .66312 .63527 L p F P
0 g
s
.426 .406 .734 r
.6108 .79285 m .61023 .79338 L .61277 .80148 L p F P
0 g
s
.457 .434 .745 r
.61546 .80973 m .62029 .80549 L p .62266 .8144 L F P
0 g
s
.44 .422 .743 r
.61546 .80973 m .61308 .80245 L .62029 .80549 L closepath p F P
0 g
s
.859 .78 .773 r
.16552 .83339 m .17063 .82685 L .16695 .82362 L p F P
0 g
s
.731 .798 .905 r
.09398 .8989 m .08939 .90135 L .08555 .89846 L p F P
0 g
s
.67 .789 .938 r
.0746 .90259 m .08555 .89846 L .08939 .90135 L p F P
0 g
s
.198 .161 .588 r
.80259 .80502 m .79907 .80969 L .80127 .81489 L p F P
0 g
s
.229 .204 .622 r
.79907 .80969 m .80259 .80502 L .79973 .8 L p F P
0 g
s
.444 .42 .737 r
.61277 .80148 m .61827 .79648 L p .62029 .80549 L F P
0 g
s
.444 .42 .737 r
.62029 .80549 m .61308 .80245 L .61277 .80148 L p F P
0 g
s
.426 .406 .734 r
.61277 .80148 m .61827 .79648 L .6108 .79285 L p F P
0 g
s
0 0 0 r
.78299 .86911 m .78562 .86501 L .78382 .86692 L closepath p F P
0 g
s
0 0 .088 r
.78382 .86692 m .78562 .86501 L .78886 .85831 L p F P
0 g
s
.375 .448 .808 r
.76668 .71964 m .7679 .71709 L p .77353 .72509 L F P
0 g
s
.385 .465 .819 r
.76668 .71964 m .76504 .71597 L .7679 .71709 L closepath p F P
0 g
s
.474 .592 .891 r
.70985 .65849 m .70182 .65774 L .69893 .65289 L p F P
0 g
s
.842 .981 .691 r
.60713 .64645 m .60856 .64454 L .60798 .64598 L closepath p F P
0 g
s
.763 .994 .873 r
.61728 .63642 m .60856 .64454 L .60798 .64598 L p F P
0 g
s
.19 .167 .6 r
.59793 .71038 m .59952 .70801 L .59698 .70318 L p F P
0 g
s
.135 .127 .583 r
.60005 .6982 m .59698 .70318 L .59952 .70801 L p F P
0 g
s
.168 .132 .57 r
.59811 .69321 m .60005 .6982 L .59698 .70318 L p F P
0 g
s
.671 .79 .938 r
.08555 .89846 m .0746 .90259 L .07073 .89973 L p F P
0 g
s
.292 .305 .703 r
.79682 .77317 m .79447 .77662 L .79903 .78113 L p F P
0 g
s
.314 .335 .723 r
.79599 .77057 m .79256 .76761 L p .79447 .77662 L F P
0 g
s
.314 .335 .723 r
.79447 .77662 m .79682 .77317 L .79599 .77057 L p F P
0 g
s
.876 .782 .753 r
.17296 .80635 m .17673 .80935 L .17193 .81631 L p F P
0 g
s
.876 .781 .754 r
.17545 .80275 m .17296 .80635 L .17673 .80935 L p F P
0 g
s
.264 .25 .656 r
.60093 .72436 m .59866 .72751 L .60227 .73207 L p F P
0 g
s
.252 .235 .645 r
.59968 .71882 m .59898 .7178 L p .59866 .72751 L F P
0 g
s
.252 .235 .645 r
.59866 .72751 m .60093 .72436 L .59968 .71882 L p F P
0 g
s
0 0 .166 r
.59952 .66909 m .60016 .66775 L .60096 .66199 L p F P
0 g
s
0 0 .134 r
.60276 .65729 m .60096 .66199 L .60016 .66775 L p F P
0 g
s
.766 .795 .877 r
.10054 .89545 m .11134 .8883 L .11547 .89108 L p F P
0 g
s
.762 .795 .88 r
.11186 .88796 m .11134 .8883 L .11547 .89108 L p F P
0 g
s
.762 .795 .88 r
.11547 .89108 m .11564 .89097 L .11186 .88796 L p F P
0 g
s
.794 .793 .851 r
.1268 .88221 m .11564 .89097 L .11186 .88796 L p F P
0 g
s
.417 .407 .741 r
.61653 .78738 m .6108 .79285 L .61827 .79648 L p F P
0 g
s
.428 .4 .725 r
.60975 .78358 m .61653 .78738 L .6108 .79285 L p F P
0 g
s
0 0 .048 r
.79245 .85457 m .78886 .85831 L .78562 .86501 L p F P
0 g
s
0 0 .249 r
.78886 .85831 m .79245 .85457 L .79291 .8498 L p F P
0 g
s
.54 .58 .843 r
.66787 .88288 m .66508 .88285 L .6671 .88139 L closepath p F P
0 g
s
.543 .568 .83 r
.66488 .87705 m .6671 .88139 L .66508 .88285 L p F P
0 g
s
.848 .782 .787 r
.15139 .85829 m .15044 .8594 L .14672 .85619 L p F P
0 g
s
.848 .782 .787 r
.14672 .85619 m .14737 .85544 L .15139 .85829 L p F P
0 g
s
.847 .782 .788 r
.15139 .85829 m .14737 .85544 L .15373 .84799 L p F P
0 g
s
.632 .736 .923 r
.63343 .63261 m .64532 .62937 L .64823 .63306 L p F P
0 g
s
.649 .751 .923 r
.64532 .62937 m .63343 .63261 L .63052 .62952 L p F P
0 g
s
.721 .805 .917 r
.61873 .63536 m .63052 .62952 L .63343 .63261 L p F P
0 g
s
.829 .785 .811 r
.14388 .86607 m .15044 .8594 L .14672 .85619 L p F P
0 g
s
.525 .539 .813 r
.64814 .86633 m .65145 .8638 L p .66061 .87088 L F P
0 g
s
.513 .532 .813 r
.64814 .86633 m .64679 .86331 L .65145 .8638 L closepath p F P
0 g
s
0 0 .414 r
.59968 .6746 m .59831 .67796 L .59914 .68325 L p F P
0 g
s
0 0 .308 r
.59831 .67796 m .59968 .6746 L .59952 .66909 L p F P
0 g
s
.586 .946 .866 r
.74785 .89663 m .75973 .8901 L .76034 .89006 L p F P
0 g
s
.725 .938 .956 r
.74533 .8955 m .74785 .89663 L .75973 .8901 L p F P
0 g
s
.41 .506 .846 r
.74684 .69432 m .75631 .69704 L .75341 .69115 L p F P
0 g
s
.41 .506 .846 r
.75341 .69115 m .74866 .68979 L .74684 .69432 L p F P
0 g
s
.42 .517 .851 r
.74088 .68776 m .74866 .68979 L .74684 .69432 L p F P
0 g
s
.413 .501 .84 r
.74684 .69432 m .75631 .69704 L p .75454 .70171 L F P
0 g
s
0 0 .231 r
.79521 .84716 m .79291 .8498 L .79245 .85457 L p F P
0 g
s
.028 0 .347 r
.79291 .8498 m .79521 .84716 L .79603 .84111 L p F P
0 g
s
.731 .798 .905 r
.08555 .89846 m .09 .89607 L .09398 .8989 L p F P
0 g
s
.727 .797 .907 r
.09672 .89252 m .09 .89607 L .09398 .8989 L p F P
0 g
s
.727 .797 .907 r
.09398 .8989 m .10054 .89545 L .09672 .89252 L p F P
0 g
s
.862 .781 .77 r
.16161 .83047 m .16552 .83339 L .16002 .84058 L p F P
0 g
s
.859 .78 .773 r
.16695 .82362 m .16161 .83047 L .16552 .83339 L p F P
0 g
s
.384 .465 .82 r
.7679 .71709 m .76504 .71597 L .76212 .70944 L p F P
0 g
s
.833 .786 .807 r
.14388 .86607 m .13871 .87145 L .13497 .86831 L p F P
0 g
s
.833 .786 .807 r
.13497 .86831 m .13983 .86323 L .14388 .86607 L p F P
0 g
s
.829 .785 .811 r
.14672 .85619 m .13983 .86323 L .14388 .86607 L p F P
0 g
s
.447 .553 .87 r
.72013 .6696 m .72028 .66915 L p .73061 .67576 L F P
0 g
s
.454 .565 .877 r
.72013 .6696 m .71984 .66908 L .72028 .66915 L closepath p F P
0 g
s
.208 .19 .618 r
.59952 .70801 m .59793 .71038 L .59934 .71727 L p F P
0 g
s
.208 .19 .618 r
.59898 .7178 m .59934 .71727 L .59793 .71038 L p F P
0 g
s
.418 .517 .853 r
.74866 .68979 m .74088 .68776 L .73937 .68476 L p F P
0 g
s
.148 .066 .499 r
.80012 .83049 m .79923 .82495 L .79951 .82461 L closepath p F P
0 g
s
.305 .33 .722 r
.79599 .77057 m .79256 .76761 L .79424 .76503 L closepath p F P
0 g
s
.327 .358 .741 r
.79286 .76093 m .79001 .75876 L p .79256 .76761 L F P
0 g
s
.327 .358 .741 r
.79256 .76761 m .79424 .76503 L .79286 .76093 L p F P
0 g
s
.452 .567 .88 r
.72028 .66915 m .71984 .66908 L .71697 .664 L p F P
0 g
s
.794 .793 .851 r
.11186 .88796 m .12268 .87942 L .1268 .88221 L p F P
0 g
s
.79 .793 .855 r
.12334 .87891 m .12268 .87942 L .1268 .88221 L p F P
0 g
s
.79 .793 .855 r
.1268 .88221 m .1271 .88198 L .12334 .87891 L p F P
0 g
s
.567 .701 .931 r
.64823 .63306 m .66022 .63123 L p .6624 .63536 L F P
0 g
s
.589 .703 .922 r
.66022 .63123 m .64823 .63306 L .64532 .62937 L p F P
0 g
s
.594 .746 .949 r
.70363 .89997 m .71569 .89772 L .71849 .9009 L p F P
0 g
s
.59 .696 .916 r
.71287 .89422 m .71569 .89772 L .70363 .89997 L p F P
0 g
s
.59 .696 .916 r
.70121 .89601 m .71287 .89422 L p .70363 .89997 L F P
0 g
s
.59 .696 .916 r
.70363 .89997 m .7009 .89624 L .70121 .89601 L p F P
0 g
s
.333 .321 .696 r
.60644 .74646 m .60253 .75122 L .6074 .75547 L p F P
0 g
s
.325 .309 .688 r
.60617 .74544 m .60242 .74165 L p .60253 .75122 L F P
0 g
s
.325 .309 .688 r
.60253 .75122 m .60644 .74646 L .60617 .74544 L p F P
0 g
s
.815 .789 .828 r
.13586 .87399 m .1271 .88198 L .12334 .87891 L p F P
0 g
s
.815 .789 .828 r
.12334 .87891 m .13177 .87117 L .13586 .87399 L p F P
0 g
s
.811 .789 .832 r
.13497 .86831 m .13177 .87117 L .13586 .87399 L p F P
0 g
s
.811 .789 .832 r
.13586 .87399 m .13871 .87145 L .13497 .86831 L p F P
0 g
s
.516 .526 .805 r
.65145 .8638 m .64679 .86331 L .6438 .8564 L p F P
0 g
s
.024 0 .342 r
.80019 .83634 m .79603 .84111 L .79521 .84716 L p F P
0 g
s
.101 0 .434 r
.80013 .83058 m .80012 .83053 L p .79603 .84111 L F P
0 g
s
.101 0 .434 r
.79603 .84111 m .80019 .83634 L .80013 .83058 L p F P
0 g
s
.868 .99 .827 r
.61747 .63452 m .61728 .63642 L .60856 .64454 L p F P
0 g
s
.803 .899 .91 r
.61728 .63642 m .61747 .63452 L .61873 .63536 L closepath p F P
0 g
s
.447 .553 .87 r
.72028 .66915 m .73223 .6712 L p .73061 .67576 L F P
0 g
s
.445 .559 .877 r
.72028 .66915 m .73223 .6712 L .72935 .66599 L p F P
0 g
s
.445 .559 .877 r
.72935 .66599 m .7216 .66469 L .72028 .66915 L p F P
0 g
s
.452 .567 .88 r
.71697 .664 m .7216 .66469 L .72028 .66915 L p F P
0 g
s
.495 .607 .893 r
.69893 .65289 m .69656 .65277 L .69738 .65031 L closepath p F P
0 g
s
.498 .617 .9 r
.69605 .64815 m .69738 .65031 L .69656 .65277 L p F P
0 g
s
.506 .631 .908 r
.68183 .64458 m .68099 .64327 L .6821 .64329 L closepath p F P
0 g
s
.714 .915 .564 r
.60856 .64454 m .61003 .6399 L p .60527 .64825 L F P
0 g
s
.714 .915 .564 r
.60527 .64825 m .60713 .64645 L .60856 .64454 L p F P
0 g
s
.868 .99 .827 r
.61584 .63368 m .61747 .63452 L p .60856 .64454 L F P
0 g
s
.868 .99 .827 r
.60856 .64454 m .61003 .6399 L .61584 .63368 L p F P
0 g
s
0 0 .333 r
.60016 .66775 m .59952 .66909 L .59968 .6746 L p F P
0 g
s
.118 .045 .491 r
.79951 .82461 m .80284 .82029 L p .80012 .83053 L F P
0 g
s
.118 .045 .491 r
.80012 .83053 m .80012 .83049 L .79951 .82461 L p F P
0 g
s
.157 .104 .542 r
.79951 .82461 m .80284 .82029 L .80127 .81489 L p F P
0 g
s
.716 .888 .959 r
.61747 .63452 m .61873 .63536 L .63052 .62952 L p F P
0 g
s
.226 .203 .623 r
.80291 .7957 m .79973 .8 L .80259 .80502 L p F P
0 g
s
.258 .247 .656 r
.80262 .79453 m .79972 .79048 L p .79973 .8 L F P
0 g
s
.258 .247 .656 r
.79973 .8 m .80291 .7957 L .80262 .79453 L p F P
0 g
s
.698 .978 .793 r
.77149 .88153 m .76161 .88886 L .76034 .89006 L p F P
0 g
s
.698 .978 .793 r
.77206 .88114 m .77149 .88153 L p .76034 .89006 L F P
0 g
s
.668 .975 .865 r
.75973 .8901 m .76161 .88886 L .76034 .89006 L closepath p F P
0 g
s
.411 .494 .834 r
.75921 .70322 m .75454 .70171 L p .76165 .70927 L F P
0 g
s
.404 .49 .834 r
.75921 .70322 m .75454 .70171 L .75649 .69741 L closepath p F P
0 g
s
.413 .501 .84 r
.75631 .69704 m .75649 .69741 L .75454 .70171 L p F P
0 g
s
.4 .39 .732 r
.615 .77821 m .60975 .78358 L .61653 .78738 L p F P
0 g
s
.414 .384 .717 r
.60887 .77425 m .615 .77821 L .60975 .78358 L p F P
0 g
s
.876 .782 .753 r
.17193 .81631 m .16815 .81332 L .17296 .80635 L p F P
0 g
s
.878 .781 .751 r
.16815 .81332 m .17193 .81631 L .16719 .82326 L p F P
0 g
s
.555 .599 .852 r
.66787 .88288 m .67995 .88282 L p .6814 .88806 L F P
0 g
s
.534 .576 .844 r
.67699 .87739 m .67995 .88282 L .66787 .88288 L p F P
0 g
s
.534 .576 .844 r
.67246 .87727 m .67699 .87739 L p .66787 .88288 L F P
0 g
s
.534 .576 .844 r
.66787 .88288 m .6671 .88139 L .67246 .87727 L p F P
0 g
s
.887 .941 .574 r
.60464 .65122 m .60527 .64825 L .60713 .64645 L closepath p F P
0 g
s
.318 .353 .74 r
.79286 .76093 m .79001 .75876 L .79138 .75656 L closepath p F P
0 g
s
.339 .38 .758 r
.78978 .75208 m .78682 .75009 L p .79001 .75876 L F P
0 g
s
.339 .38 .758 r
.79001 .75876 m .79138 .75656 L .78978 .75208 L p F P
0 g
s
.228 .216 .637 r
.59968 .71882 m .59898 .7178 L .59934 .71727 L closepath p F P
0 g
s
.042 .052 .542 r
.6005 .68841 m .59811 .69321 L .60005 .6982 L p F P
0 g
s
.007 0 .494 r
.59811 .69321 m .6005 .68841 L .59914 .68325 L p F P
0 g
s
.862 .781 .77 r
.16002 .84058 m .15861 .84241 L .1549 .83924 L p F P
0 g
s
.862 .781 .77 r
.1549 .83924 m .15611 .83766 L .16002 .84058 L p F P
0 g
s
.862 .781 .77 r
.16002 .84058 m .15611 .83766 L .16161 .83047 L p F P
0 g
s
.636 .902 .984 r
.73324 .89999 m .74523 .89545 L .74533 .8955 L p F P
0 g
s
.629 .869 .987 r
.74523 .89545 m .73324 .89999 L .73052 .89766 L p F P
0 g
s
.616 .819 .978 r
.71849 .9009 m .73052 .89766 L .73324 .89999 L p F P
0 g
s
.606 .785 .967 r
.73052 .89766 m .71849 .9009 L .71569 .89772 L p F P
0 g
s
.563 .664 .905 r
.68582 .89288 m .69791 .89182 L .70078 .89607 L p F P
0 g
s
.554 .645 .895 r
.69791 .89182 m .68582 .89288 L .6829 .88801 L p F P
0 g
s
0 0 0 r
.78562 .86501 m .79018 .8602 L p .78229 .87057 L F P
0 g
s
0 0 0 r
.78229 .87057 m .78299 .86911 L .78562 .86501 L p F P
0 g
s
0 0 .048 r
.79205 .8566 m .79245 .85457 L p .78562 .86501 L F P
0 g
s
0 0 .048 r
.78562 .86501 m .79018 .8602 L .79205 .8566 L p F P
0 g
s
.533 .575 .843 r
.6671 .88139 m .66488 .87705 L .67246 .87727 L closepath p F P
0 g
s
.767 .798 .878 r
.11134 .8883 m .10054 .89545 L .09672 .89252 L p F P
0 g
s
.427 .531 .861 r
.73937 .68476 m .73799 .68213 L .74013 .68262 L closepath p F P
0 g
s
.418 .517 .853 r
.73937 .68476 m .74013 .68262 L p .74866 .68979 L F P
0 g
s
.504 .635 .912 r
.6821 .64329 m .68099 .64327 L .6781 .6389 L p F P
0 g
s
.395 .474 .823 r
.76212 .70944 m .76165 .70927 L .76186 .70886 L closepath p F P
0 g
s
.411 .494 .834 r
.76165 .70927 m .76186 .70886 L .75921 .70322 L p F P
0 g
s
.846 .786 .793 r
.15373 .84799 m .15861 .84241 L .1549 .83924 L p F P
0 g
s
.499 .489 .776 r
.63298 .8402 m .63761 .84124 L p .63793 .84839 L F P
0 g
s
.484 .485 .782 r
.63761 .84124 m .63298 .8402 L .63619 .83761 L closepath p F P
0 g
s
.49 .475 .768 r
.63452 .83329 m .63619 .83761 L .63298 .8402 L p F P
0 g
s
.49 .475 .768 r
.62889 .83178 m .63452 .83329 L p .63298 .8402 L F P
0 g
s
.494 .498 .79 r
.64068 .8489 m .63793 .84839 L .63987 .84688 L closepath p F P
0 g
s
.499 .489 .776 r
.63761 .84124 m .63987 .84688 L .63793 .84839 L p F P
0 g
s
.33 .375 .757 r
.78978 .75208 m .78682 .75009 L .78822 .74773 L closepath p F P
0 g
s
.35 .401 .773 r
.78675 .74383 m .783 .74159 L p .78682 .75009 L F P
0 g
s
.35 .401 .773 r
.78682 .75009 m .78822 .74773 L .78675 .74383 L p F P
0 g
s
.568 .889 .622 r
.77149 .88153 m .77322 .87998 L .77206 .88114 L closepath p F P
0 g
s
.549 .826 .477 r
.78064 .87218 m .77322 .87998 L .77206 .88114 L p F P
0 g
s
.569 .684 .918 r
.66312 .63527 m .6624 .63536 L .66266 .63462 L closepath p F P
0 g
s
.567 .701 .931 r
.66022 .63123 m .66266 .63462 L .6624 .63536 L p F P
0 g
s
.255 .235 .643 r
.59934 .71727 m .60235 .71277 L p .6023 .72243 L F P
0 g
s
.255 .235 .643 r
.6023 .72243 m .59968 .71882 L .59934 .71727 L p F P
0 g
s
.208 .19 .618 r
.59934 .71727 m .60235 .71277 L .59952 .70801 L p F P
0 g
s
.474 .592 .891 r
.69893 .65289 m .7112 .65395 L p .70985 .65849 L F P
0 g
s
.468 .592 .894 r
.70832 .64915 m .7112 .65395 L .69893 .65289 L p F P
0 g
s
.468 .592 .894 r
.69782 .64827 m .70832 .64915 L p .69893 .65289 L F P
0 g
s
.468 .592 .894 r
.69893 .65289 m .69738 .65031 L .69782 .64827 L p F P
0 g
s
.384 .465 .82 r
.76212 .70944 m .76997 .71256 L .7679 .71709 L p F P
0 g
s
.379 .464 .822 r
.76997 .71256 m .76212 .70944 L .76186 .70886 L p F P
0 g
s
.516 .526 .805 r
.6438 .8564 m .64394 .8563 L p .65145 .8638 L F P
0 g
s
.504 .518 .805 r
.6438 .8564 m .64374 .85627 L .64394 .8563 L closepath p F P
0 g
s
.507 .512 .796 r
.64394 .8563 m .64374 .85627 L .64068 .8489 L p F P
0 g
s
.375 .448 .808 r
.7679 .71709 m .7758 .72052 L .77353 .72509 L p F P
0 g
s
.377 .456 .815 r
.76997 .71256 m .7679 .71709 L .7758 .72052 L p F P
0 g
s
.473 .471 .775 r
.63452 .83329 m .62889 .83178 L .63274 .82857 L closepath p F P
0 g
s
.479 .462 .761 r
.63142 .82503 m .63274 .82857 L .62889 .83178 L p F P
0 g
s
.479 .462 .761 r
.62549 .82317 m .63142 .82503 L p .62889 .83178 L F P
0 g
s
.305 .293 .681 r
.60617 .74544 m .60242 .74165 L .60449 .73897 L closepath p F P
0 g
s
.298 .284 .675 r
.60294 .73284 m .60227 .73207 L p .60242 .74165 L F P
0 g
s
.298 .284 .675 r
.60242 .74165 m .60449 .73897 L .60294 .73284 L p F P
0 g
s
.389 .481 .832 r
.76186 .70886 m .75921 .70322 L .76357 .70476 L closepath p F P
0 g
s
.379 .464 .822 r
.76186 .70886 m .76357 .70476 L p .76997 .71256 L F P
0 g
s
.504 .632 .909 r
.6821 .64329 m .69316 .64355 L .69027 .63899 L p F P
0 g
s
.504 .632 .909 r
.69027 .63899 m .68288 .6389 L .6821 .64329 L p F P
0 g
s
.504 .635 .912 r
.6781 .6389 m .68288 .6389 L .6821 .64329 L p F P
0 g
s
.249 .233 .644 r
.60093 .72436 m .59968 .71882 L .6023 .72243 L closepath p F P
0 g
s
.516 .526 .805 r
.64394 .8563 m .65584 .85797 L p .65145 .8638 L F P
0 g
s
.493 .504 .797 r
.64394 .8563 m .65584 .85797 L .6528 .85106 L p F P
0 g
s
.493 .504 .797 r
.6528 .85106 m .65086 .85072 L .64394 .8563 L p F P
0 g
s
.507 .512 .796 r
.64068 .8489 m .65086 .85072 L .64394 .8563 L p F P
0 g
s
.537 .656 .912 r
.66312 .63527 m .6752 .63458 L .6781 .6389 L p F P
0 g
s
.533 .667 .923 r
.6723 .63032 m .6752 .63458 L .66312 .63527 L p F P
0 g
s
.533 .667 .923 r
.66297 .63101 m .6723 .63032 L p .66312 .63527 L F P
0 g
s
.533 .667 .923 r
.66312 .63527 m .66266 .63462 L .66297 .63101 L p F P
0 g
s
.342 .396 .773 r
.78675 .74383 m .783 .74159 L .78474 .73851 L closepath p F P
0 g
s
.362 .42 .787 r
.78374 .73602 m .77857 .73325 L p .783 .74159 L F P
0 g
s
.362 .42 .787 r
.783 .74159 m .78474 .73851 L .78374 .73602 L p F P
0 g
s
.684 .973 .914 r
.76161 .88886 m .75973 .8901 L .75718 .88971 L p F P
0 g
s
.725 .938 .956 r
.75973 .8901 m .75718 .88971 L p .74533 .8955 L F P
0 g
s
0 0 .333 r
.59968 .6746 m .60033 .67323 L .60016 .66775 L p F P
0 g
s
0 0 .299 r
.60205 .66303 m .60016 .66775 L .60033 .67323 L p F P
0 g
s
0 0 .134 r
.60016 .66775 m .60205 .66303 L .60276 .65729 L p F P
0 g
s
.85 .786 .789 r
.1498 .8451 m .15373 .84799 L .14737 .85544 L p F P
0 g
s
.846 .786 .793 r
.1549 .83924 m .1498 .8451 L .15373 .84799 L p F P
0 g
s
.381 .371 .723 r
.61303 .76974 m .60887 .77425 L .615 .77821 L p F P
0 g
s
.398 .367 .708 r
.61256 .76816 m .61303 .76974 L .60887 .77425 L p F P
0 g
s
.398 .367 .708 r
.6081 .76488 m .61256 .76816 L p .60887 .77425 L F P
0 g
s
.372 .439 .801 r
.78076 .72854 m .77353 .72509 L p .77857 .73325 L F P
0 g
s
.361 .432 .8 r
.77353 .72509 m .78076 .72854 L .77781 .72149 L p F P
0 g
s
.361 .432 .8 r
.77781 .72149 m .7758 .72052 L .77353 .72509 L p F P
0 g
s
.353 .416 .787 r
.78374 .73602 m .77857 .73325 L .7809 .72888 L closepath p F P
0 g
s
.372 .439 .801 r
.77857 .73325 m .7809 .72888 L .78076 .72854 L p F P
0 g
s
0 0 0 r
.78064 .87218 m .78229 .87057 L .78299 .86911 L closepath p F P
0 g
s
.684 .973 .914 r
.75718 .88971 m .76684 .88392 L .76161 .88886 L p F P
0 g
s
.599 .937 .747 r
.76905 .88245 m .76684 .88392 L .76161 .88886 L p F P
0 g
s
.599 .937 .747 r
.76161 .88886 m .77149 .88153 L .76905 .88245 L p F P
0 g
s
.877 .782 .753 r
.16719 .82326 m .16695 .82362 L .16324 .82054 L p F P
0 g
s
.877 .782 .753 r
.16324 .82054 m .16342 .82028 L .16719 .82326 L p F P
0 g
s
.878 .781 .751 r
.16719 .82326 m .16342 .82028 L .16815 .81332 L p F P
0 g
s
.44 .543 .865 r
.73511 .67666 m .73061 .67576 L .73227 .67128 L closepath p F P
0 g
s
.447 .553 .87 r
.73223 .6712 m .73227 .67128 L .73061 .67576 L p F P
0 g
s
.274 .275 .679 r
.79921 .78135 m .79903 .78113 L p .79972 .79048 L F P
0 g
s
.274 .275 .679 r
.79972 .79048 m .80114 .78849 L .79921 .78135 L p F P
0 g
s
.248 .241 .654 r
.80262 .79453 m .79972 .79048 L .80114 .78849 L closepath p F P
0 g
s
.863 .787 .775 r
.16161 .83047 m .16695 .82362 L .16324 .82054 L p F P
0 g
s
.46 .456 .767 r
.63142 .82503 m .62549 .82317 L .62948 .81971 L closepath p F P
0 g
s
.468 .448 .753 r
.62831 .81646 m .62948 .81971 L .62549 .82317 L p F P
0 g
s
.468 .448 .753 r
.62266 .8144 m .62831 .81646 L p .62549 .82317 L F P
0 g
s
.543 .676 .925 r
.66266 .63462 m .66022 .63123 L .66297 .63101 L closepath p F P
0 g
s
.198 .161 .588 r
.80127 .81489 m .80485 .81022 L .80259 .80502 L p F P
0 g
s
.161 .108 .545 r
.80485 .81022 m .80127 .81489 L .80284 .82029 L p F P
0 g
s
.732 .8 .906 r
.09 .89607 m .08555 .89846 L .0817 .89558 L p F P
0 g
s
.671 .79 .938 r
.07073 .89973 m .0817 .89558 L .08555 .89846 L p F P
0 g
s
.425 .532 .863 r
.74013 .68262 m .73799 .68213 L .73511 .67666 L p F P
0 g
s
.791 .927 .925 r
.61584 .63368 m .61847 .63185 L .61747 .63452 L closepath p F P
0 g
s
.716 .888 .959 r
.6276 .62662 m .61847 .63185 L .61747 .63452 L p F P
0 g
s
.716 .888 .959 r
.63052 .62952 m .6276 .62662 L p .61747 .63452 L F P
0 g
s
.534 .852 .556 r
.78229 .87057 m .78064 .87218 L .77322 .87998 L p F P
0 g
s
.525 .539 .813 r
.65145 .8638 m .65887 .86459 L p .66061 .87088 L F P
0 g
s
.511 .537 .819 r
.65887 .86459 m .65145 .8638 L .65662 .85968 L closepath p F P
0 g
s
.516 .526 .805 r
.65584 .85797 m .65662 .85968 L .65145 .8638 L p F P
0 g
s
.536 .568 .835 r
.67246 .87727 m .66488 .87705 L .66189 .87098 L p F P
0 g
s
.137 .145 .603 r
.60234 .70311 m .59952 .70801 L .60235 .71277 L p F P
0 g
s
.135 .127 .583 r
.59952 .70801 m .60234 .70311 L .60005 .6982 L p F P
0 g
s
.451 .569 .882 r
.7216 .66469 m .71697 .664 L .71408 .65896 L p F P
0 g
s
.767 .798 .878 r
.09672 .89252 m .10733 .88547 L .11134 .8883 L p F P
0 g
s
.764 .798 .881 r
.10806 .88499 m .10733 .88547 L .11134 .8883 L p F P
0 g
s
.764 .798 .881 r
.11134 .8883 m .11186 .88796 L .10806 .88499 L p F P
0 g
s
.259 .247 .654 r
.6023 .72243 m .60093 .72436 L .60263 .73158 L p F P
0 g
s
.264 .25 .656 r
.60227 .73207 m .60263 .73158 L .60093 .72436 L p F P
0 g
s
.795 .796 .853 r
.12268 .87942 m .11186 .88796 L .10806 .88499 L p F P
0 g
s
.85 .786 .789 r
.14737 .85544 m .14672 .85619 L .14299 .85309 L p F P
0 g
s
.85 .786 .789 r
.14299 .85309 m .14345 .85255 L .14737 .85544 L p F P
0 g
s
.85 .786 .789 r
.14737 .85544 m .14345 .85255 L .1498 .8451 L p F P
0 g
s
.625 .942 .727 r
.77322 .87998 m .77149 .88153 L .76905 .88245 L p F P
0 g
s
0 0 .482 r
.60025 .68056 m .59914 .68325 L .6005 .68841 L p F P
0 g
s
0 0 .414 r
.59914 .68325 m .60025 .68056 L .59968 .6746 L p F P
0 g
s
.534 .852 .556 r
.78076 .87253 m .78229 .87057 L p .77322 .87998 L F P
0 g
s
.625 .942 .727 r
.76905 .88245 m .77805 .87512 L .77322 .87998 L p F P
0 g
s
.534 .852 .556 r
.77322 .87998 m .77805 .87512 L .78076 .87253 L p F P
0 g
s
.448 .442 .759 r
.62831 .81646 m .62266 .8144 L .6264 .81103 L closepath p F P
0 g
s
.457 .434 .745 r
.62518 .80755 m .6264 .81103 L .62266 .8144 L p F P
0 g
s
.457 .434 .745 r
.62029 .80549 m .62518 .80755 L p .62266 .8144 L F P
0 g
s
.832 .79 .812 r
.13983 .86323 m .14672 .85619 L .14299 .85309 L p F P
0 g
s
0 0 .231 r
.79245 .85457 m .79339 .85349 L .79521 .84716 L p F P
0 g
s
0 0 .212 r
.79933 .84242 m .79521 .84716 L .79339 .85349 L p F P
0 g
s
.024 0 .342 r
.79521 .84716 m .79933 .84242 L .80019 .83634 L p F P
0 g
s
.496 .499 .79 r
.65086 .85072 m .64068 .8489 L .63987 .84688 L p F P
0 g
s
.551 .612 .867 r
.6829 .88801 m .6814 .88806 L .68246 .88725 L closepath p F P
0 g
s
.555 .599 .852 r
.67995 .88282 m .68246 .88725 L .6814 .88806 L p F P
0 g
s
.481 .606 .899 r
.69738 .65031 m .69605 .64815 L .69782 .64827 L closepath p F P
0 g
s
.59 .695 .916 r
.7009 .89624 m .70078 .89607 L .70121 .89601 L closepath p F P
0 g
s
.47 .582 .884 r
.71408 .65896 m .70985 .65849 L .71126 .65406 L closepath p F P
0 g
s
.474 .592 .891 r
.7112 .65395 m .71126 .65406 L .70985 .65849 L p F P
0 g
s
.287 .318 .719 r
.79424 .76503 m .79543 .763 L p .79755 .77198 L F P
0 g
s
.287 .318 .719 r
.79755 .77198 m .79599 .77057 L .79424 .76503 L p F P
0 g
s
.301 .342 .737 r
.79424 .76503 m .79286 .76093 L .79543 .763 L closepath p F P
0 g
s
.649 .751 .923 r
.63052 .62952 m .64241 .62579 L .64532 .62937 L p F P
0 g
s
.669 .766 .923 r
.64241 .62579 m .63052 .62952 L .6276 .62662 L p F P
0 g
s
.288 .318 .719 r
.79682 .77317 m .79599 .77057 L .79755 .77198 L closepath p F P
0 g
s
.263 .286 .698 r
.79755 .77198 m .79682 .77317 L .79912 .781 L p F P
0 g
s
.292 .305 .703 r
.79903 .78113 m .79912 .781 L .79682 .77317 L p F P
0 g
s
.593 .678 .9 r
.70121 .89601 m .70078 .89607 L .69791 .89182 L p F P
0 g
s
.121 .047 .491 r
.80012 .83053 m .80012 .83049 L .80012 .83053 L closepath p F P
0 g
s
.063 0 .424 r
.80013 .83058 m .80012 .83053 L .80012 .83053 L closepath p F P
0 g
s
0 0 .4 r
.80012 .83053 m .80371 .82589 L p .80041 .83609 L F P
0 g
s
0 0 .4 r
.80041 .83609 m .80013 .83058 L .80012 .83053 L p F P
0 g
s
.118 .045 .491 r
.80284 .82029 m .80371 .82589 L .80012 .83053 L p F P
0 g
s
.091 0 .43 r
.80019 .83634 m .80041 .83609 L .80013 .83058 L closepath p F P
0 g
s
.301 .342 .738 r
.79543 .763 m .79286 .76093 L .79138 .75656 L p F P
0 g
s
.496 .499 .79 r
.63987 .84688 m .64479 .8428 L p .65086 .85072 L F P
0 g
s
.483 .49 .789 r
.63987 .84688 m .63761 .84124 L .64479 .8428 L closepath p F P
0 g
s
.732 .8 .906 r
.0817 .89558 m .0861 .89321 L .09 .89607 L p F P
0 g
s
.729 .799 .908 r
.09288 .88962 m .0861 .89321 L .09 .89607 L p F P
0 g
s
.729 .799 .908 r
.09 .89607 m .09672 .89252 L .09288 .88962 L p F P
0 g
s
.865 .787 .771 r
.15781 .82751 m .16161 .83047 L .15611 .83766 L p F P
0 g
s
.863 .787 .775 r
.16324 .82054 m .15781 .82751 L .16161 .83047 L p F P
0 g
s
.361 .35 .712 r
.61256 .76816 m .6081 .76488 L .61073 .76187 L closepath p F P
0 g
s
.357 .344 .708 r
.60937 .75711 m .6074 .75547 L p .6081 .76488 L F P
0 g
s
.357 .344 .708 r
.6081 .76488 m .61073 .76187 L .60937 .75711 L p F P
0 g
s
.277 .267 .668 r
.60294 .73284 m .60227 .73207 L .60263 .73158 L closepath p F P
0 g
s
.836 .79 .808 r
.13983 .86323 m .13497 .86831 L .13121 .86525 L p F P
0 g
s
.836 .79 .808 r
.13121 .86525 m .13589 .86035 L .13983 .86323 L p F P
0 g
s
.832 .79 .812 r
.14299 .85309 m .13589 .86035 L .13983 .86323 L p F P
0 g
s
.577 .672 .904 r
.70121 .89601 m .71287 .89422 L .71003 .89041 L p F P
0 g
s
.577 .672 .904 r
.71003 .89041 m .70792 .89066 L .70121 .89601 L p F P
0 g
s
.593 .678 .9 r
.69791 .89182 m .70792 .89066 L .70121 .89601 L p F P
0 g
s
0 0 .434 r
.60033 .67323 m .59968 .6746 L .60025 .68056 L p F P
0 g
s
.301 .342 .738 r
.79138 .75656 m .79271 .75417 L p .79543 .763 L F P
0 g
s
.314 .364 .754 r
.79138 .75656 m .78978 .75208 L .79271 .75417 L closepath p F P
0 g
s
.265 .269 .678 r
.79921 .78135 m .79903 .78113 L .79912 .781 L closepath p F P
0 g
s
.589 .703 .922 r
.64532 .62937 m .65731 .62728 L .66022 .63123 L p F P
0 g
s
.599 .712 .924 r
.65731 .62728 m .64532 .62937 L .64241 .62579 L p F P
0 g
s
.389 .481 .833 r
.76357 .70476 m .75921 .70322 L .75649 .69741 L p F P
0 g
s
.418 .517 .853 r
.74013 .68262 m .75045 .68525 L .74866 .68979 L p F P
0 g
s
.424 .527 .858 r
.74164 .67815 m .74013 .68262 L .75045 .68525 L p F P
0 g
s
.425 .532 .863 r
.73511 .67666 m .74164 .67815 L .74013 .68262 L p F P
0 g
s
.795 .796 .853 r
.10806 .88499 m .11869 .87657 L .12268 .87942 L p F P
0 g
s
.792 .797 .856 r
.11956 .8759 m .11869 .87657 L .12268 .87942 L p F P
0 g
s
.792 .797 .856 r
.12268 .87942 m .12334 .87891 L .11956 .8759 L p F P
0 g
s
.244 .255 .673 r
.79912 .781 m .80186 .77656 L p .80283 .78586 L F P
0 g
s
.244 .255 .673 r
.80283 .78586 m .79921 .78135 L .79912 .781 L p F P
0 g
s
.263 .286 .698 r
.79912 .781 m .80186 .77656 L .79755 .77198 L p F P
0 g
s
.818 .794 .83 r
.13177 .87117 m .12334 .87891 L .11956 .8759 L p F P
0 g
s
.818 .794 .83 r
.11956 .8759 m .12781 .86831 L .13177 .87117 L p F P
0 g
s
.814 .794 .833 r
.13121 .86525 m .12781 .86831 L .13177 .87117 L p F P
0 g
s
.814 .794 .833 r
.13177 .87117 m .13497 .86831 L .13121 .86525 L p F P
0 g
s
.245 .256 .673 r
.80114 .78849 m .79921 .78135 L .80283 .78586 L closepath p F P
0 g
s
.554 .645 .895 r
.6829 .88801 m .69501 .88731 L .69791 .89182 L p F P
0 g
s
.548 .611 .868 r
.69209 .88253 m .69501 .88731 L .6829 .88801 L p F P
0 g
s
.548 .611 .868 r
.68829 .88263 m .69209 .88253 L p .6829 .88801 L F P
0 g
s
.548 .611 .868 r
.6829 .88801 m .68246 .88725 L .68829 .88263 L p F P
0 g
s
.434 .426 .751 r
.62518 .80755 m .62029 .80549 L .62346 .8025 L closepath p F P
0 g
s
.444 .42 .737 r
.62205 .7983 m .62346 .8025 L .62029 .80549 L p F P
0 g
s
.444 .42 .737 r
.61827 .79648 m .62205 .7983 L p .62029 .80549 L F P
0 g
s
.314 .364 .755 r
.79271 .75417 m .78978 .75208 L .78822 .74773 L p F P
0 g
s
.298 .281 .672 r
.60263 .73158 m .60589 .72701 L p .60634 .73652 L F P
0 g
s
.298 .281 .672 r
.60634 .73652 m .60294 .73284 L .60263 .73158 L p F P
0 g
s
.259 .247 .654 r
.60263 .73158 m .60589 .72701 L .6023 .72243 L p F P
0 g
s
0 0 .091 r
.79205 .8566 m .79339 .85349 L .79245 .85457 L closepath p F P
0 g
s
.681 .915 .973 r
.74523 .89545 m .74552 .89532 L .74533 .8955 L closepath p F P
0 g
s
.725 .938 .956 r
.75718 .88971 m .74552 .89532 L .74533 .8955 L p F P
0 g
s
.521 .55 .826 r
.66189 .87098 m .66061 .87088 L .66151 .87019 L closepath p F P
0 g
s
.525 .539 .813 r
.65887 .86459 m .66151 .87019 L .66061 .87088 L p F P
0 g
s
.292 .28 .674 r
.60449 .73897 m .60294 .73284 L .60634 .73652 L closepath p F P
0 g
s
.547 .609 .867 r
.68246 .88725 m .67995 .88282 L .68829 .88263 L closepath p F P
0 g
s
.486 .486 .782 r
.64479 .8428 m .63761 .84124 L .63619 .83761 L p F P
0 g
s
.629 .869 .987 r
.73052 .89766 m .74256 .89368 L .74523 .89545 L p F P
0 g
s
.673 .883 .976 r
.74552 .89532 m .74523 .89545 L .74256 .89368 L p F P
0 g
s
.314 .364 .755 r
.78822 .74773 m .7894 .74551 L p .79271 .75417 L F P
0 g
s
.327 .386 .77 r
.78822 .74773 m .78675 .74383 L .7894 .74551 L closepath p F P
0 g
s
.673 .883 .976 r
.74256 .89368 m .75057 .89043 L .74552 .89532 L p F P
0 g
s
.675 .939 .965 r
.75458 .88872 m .75057 .89043 L .74552 .89532 L p F P
0 g
s
.675 .939 .965 r
.74552 .89532 m .75718 .88971 L .75458 .88872 L p F P
0 g
s
.507 .64 .915 r
.68288 .6389 m .6781 .6389 L .6752 .63458 L p F P
0 g
s
.192 .158 .588 r
.80439 .80259 m .80259 .80502 L .80485 .81022 L p F P
0 g
s
.226 .203 .623 r
.80259 .80502 m .80439 .80259 L .80291 .7957 L p F P
0 g
s
.479 .609 .902 r
.69782 .64827 m .69605 .64815 L .69316 .64355 L p F P
0 g
s
0 0 0 r
.78076 .87253 m .78524 .86737 L .78229 .87057 L closepath p F P
0 g
s
0 0 0 r
.79018 .8602 m .78524 .86737 L .78229 .87057 L p F P
0 g
s
.227 .226 .65 r
.80114 .78849 m .80283 .78586 L p .80316 .79533 L F P
0 g
s
.227 .226 .65 r
.80316 .79533 m .80262 .79453 L .80114 .78849 L p F P
0 g
s
.606 .785 .967 r
.71569 .89772 m .72777 .89494 L .73052 .89766 L p F P
0 g
s
.595 .755 .955 r
.72777 .89494 m .71569 .89772 L .71287 .89422 L p F P
0 g
s
.865 .787 .772 r
.15611 .83766 m .1549 .83924 L .15117 .8362 L p F P
0 g
s
.865 .787 .772 r
.15117 .8362 m .15231 .8347 L .15611 .83766 L p F P
0 g
s
.865 .787 .771 r
.15611 .83766 m .15231 .8347 L .15781 .82751 L p F P
0 g
s
.086 .104 .581 r
.60227 .69347 m .60005 .6982 L .60234 .70311 L p F P
0 g
s
.042 .052 .542 r
.60225 .69339 m .6005 .68841 L p .60005 .6982 L F P
0 g
s
.042 .052 .542 r
.60005 .6982 m .60227 .69347 L .60225 .69339 L p F P
0 g
s
.486 .486 .782 r
.63619 .83761 m .63968 .83463 L p .64479 .8428 L F P
0 g
s
.472 .476 .781 r
.63619 .83761 m .63452 .83329 L .63968 .83463 L closepath p F P
0 g
s
.265 .29 .701 r
.80025 .76742 m .79755 .77198 L .80186 .77656 L p F P
0 g
s
.287 .318 .719 r
.79543 .763 m .80025 .76742 L .79755 .77198 L p F P
0 g
s
.536 .568 .835 r
.66189 .87098 m .67402 .87169 L p .67246 .87727 L F P
0 g
s
.514 .547 .827 r
.67102 .86573 m .67402 .87169 L .66189 .87098 L p F P
0 g
s
.514 .547 .827 r
.66742 .86539 m .67102 .86573 L p .66189 .87098 L F P
0 g
s
.514 .547 .827 r
.66189 .87098 m .66151 .87019 L .66742 .86539 L p F P
0 g
s
.326 .386 .771 r
.7894 .74551 m .78675 .74383 L .78474 .73851 L p F P
0 g
s
.339 .329 .702 r
.60937 .75711 m .6074 .75547 L .60853 .75411 L closepath p F P
0 g
s
.333 .321 .696 r
.6074 .75547 m .60853 .75411 L .60644 .74646 L p F P
0 g
s
.424 .533 .864 r
.74164 .67815 m .73511 .67666 L .73227 .67128 L p F P
0 g
s
.419 .41 .743 r
.62205 .7983 m .61827 .79648 L .62067 .79412 L closepath p F P
0 g
s
.417 .407 .741 r
.6189 .78867 m .61653 .78738 L p .61827 .79648 L F P
0 g
s
.417 .407 .741 r
.61827 .79648 m .62067 .79412 L .6189 .78867 L p F P
0 g
s
.41 .506 .847 r
.74866 .68979 m .75341 .69115 L .75052 .68527 L p F P
0 g
s
.41 .506 .847 r
.75052 .68527 m .75045 .68525 L .74866 .68979 L p F P
0 g
s
.768 .801 .88 r
.10733 .88547 m .09672 .89252 L .09288 .88962 L p F P
0 g
s
.849 .791 .794 r
.1498 .8451 m .1549 .83924 L .15117 .8362 L p F P
0 g
s
.323 .305 .684 r
.60449 .73897 m .60634 .73652 L p .60678 .74603 L F P
0 g
s
.323 .305 .684 r
.60678 .74603 m .60617 .74544 L .60449 .73897 L p F P
0 g
s
.621 .832 .981 r
.74256 .89368 m .73052 .89766 L .72777 .89494 L p F P
0 g
s
.513 .545 .826 r
.66151 .87019 m .65887 .86459 L .66742 .86539 L closepath p F P
0 g
s
0 0 .434 r
.60025 .68056 m .60122 .67851 L .60033 .67323 L p F P
0 g
s
0 0 .398 r
.60221 .66852 m .60033 .67323 L .60122 .67851 L p F P
0 g
s
0 0 .299 r
.60033 .67323 m .60221 .66852 L .60205 .66303 L p F P
0 g
s
.199 .21 .646 r
.60543 .71748 m .6023 .72243 L .60589 .72701 L p F P
0 g
s
.255 .235 .643 r
.60235 .71277 m .60543 .71748 L .6023 .72243 L p F P
0 g
s
.83 .937 .898 r
.61847 .63185 m .61584 .63368 L .61295 .63266 L p F P
0 g
s
.885 .945 .846 r
.61003 .6399 m .61584 .63368 L .61295 .63266 L p F P
0 g
s
.541 .68 .929 r
.66297 .63101 m .66022 .63123 L .65731 .62728 L p F P
0 g
s
.475 .472 .775 r
.63968 .83463 m .63452 .83329 L .63274 .82857 L p F P
0 g
s
0 0 0 r
.79339 .85349 m .79742 .84879 L p .7915 .8588 L F P
0 g
s
0 0 0 r
.7915 .8588 m .79205 .8566 L .79339 .85349 L p F P
0 g
s
0 0 .212 r
.79339 .85349 m .79742 .84879 L .79933 .84242 L p F P
0 g
s
.446 .562 .878 r
.7216 .66469 m .72935 .66599 L .72647 .66081 L p F P
0 g
s
.446 .562 .878 r
.72647 .66081 m .72288 .66022 L .7216 .66469 L p F P
0 g
s
.451 .569 .882 r
.71408 .65896 m .72288 .66022 L .7216 .66469 L p F P
0 g
s
.477 .604 .899 r
.69782 .64827 m .70832 .64915 L .70543 .64438 L p F P
0 g
s
.477 .604 .899 r
.70543 .64438 m .69867 .64388 L .69782 .64827 L p F P
0 g
s
.479 .609 .902 r
.69316 .64355 m .69867 .64388 L .69782 .64827 L p F P
0 g
s
.83 .937 .898 r
.61295 .63266 m .61942 .62734 L .61847 .63185 L p F P
0 g
s
.75 .84 .919 r
.62468 .62391 m .61942 .62734 L .61847 .63185 L p F P
0 g
s
.75 .84 .919 r
.61847 .63185 m .6276 .62662 L .62468 .62391 L p F P
0 g
s
.687 .756 .261 r
.60437 .65063 m .60581 .64668 L .60527 .64825 L closepath p F P
0 g
s
.714 .915 .564 r
.61003 .6399 m .60581 .64668 L .60527 .64825 L p F P
0 g
s
.338 .406 .785 r
.78474 .73851 m .78374 .73602 L .78549 .73701 L closepath p F P
0 g
s
.326 .386 .771 r
.78474 .73851 m .78549 .73701 L p .7894 .74551 L F P
0 g
s
.452 .572 .884 r
.72288 .66022 m .71408 .65896 L .71126 .65406 L p F P
0 g
s
.389 .481 .833 r
.75649 .69741 m .75659 .69713 L p .76357 .70476 L F P
0 g
s
.399 .496 .842 r
.75649 .69741 m .75631 .69704 L .75659 .69713 L closepath p F P
0 g
s
.228 .227 .649 r
.80291 .7957 m .80262 .79453 L .80316 .79533 L closepath p F P
0 g
s
.853 .791 .791 r
.14598 .84215 m .1498 .8451 L .14345 .85255 L p F P
0 g
s
.849 .791 .794 r
.15117 .8362 m .14598 .84215 L .1498 .8451 L p F P
0 g
s
.885 .945 .846 r
.61295 .63266 m .6107 .63549 L .61003 .6399 L p F P
0 g
s
.872 .946 .586 r
.6107 .63549 m .61003 .6399 L .60581 .64668 L p F P
0 g
s
.283 .319 .723 r
.79802 .75844 m .79543 .763 L .80025 .76742 L p F P
0 g
s
.301 .342 .738 r
.79271 .75417 m .79802 .75844 L .79543 .763 L p F P
0 g
s
.317 .304 .687 r
.60644 .74646 m .60617 .74544 L .60678 .74603 L closepath p F P
0 g
s
.396 .497 .845 r
.75659 .69713 m .75631 .69704 L .75341 .69115 L p F P
0 g
s
.475 .472 .775 r
.63274 .82857 m .63537 .82623 L p .63968 .83463 L F P
0 g
s
.46 .462 .773 r
.63274 .82857 m .63142 .82503 L .63537 .82623 L closepath p F P
0 g
s
.325 .316 .695 r
.60678 .74603 m .60644 .74646 L .60853 .75411 L p F P
0 g
s
.192 .18 .615 r
.80316 .79533 m .80291 .7957 L .80439 .80259 L p F P
0 g
s
.112 .041 .489 r
.80646 .81561 m .80284 .82029 L .80371 .82589 L p F P
0 g
s
.161 .108 .545 r
.80284 .82029 m .80646 .81561 L .80485 .81022 L p F P
0 g
s
.393 .49 .839 r
.7582 .69267 m .75659 .69713 L .76539 .70026 L p F P
0 g
s
.396 .497 .845 r
.75341 .69115 m .7582 .69267 L .75659 .69713 L p F P
0 g
s
.389 .481 .833 r
.75659 .69713 m .76539 .70026 L .76357 .70476 L p F P
0 g
s
.338 .406 .785 r
.78549 .73701 m .78374 .73602 L .7809 .72888 L p F P
0 g
s
.403 .394 .735 r
.6189 .78867 m .61653 .78738 L .618 .78587 L closepath p F P
0 g
s
.4 .39 .732 r
.61574 .77866 m .615 .77821 L p .61653 .78738 L F P
0 g
s
.4 .39 .732 r
.61653 .78738 m .618 .78587 L .61574 .77866 L p F P
0 g
s
0 0 .497 r
.60122 .67851 m .60025 .68056 L .60114 .68688 L p F P
0 g
s
0 0 .482 r
.6005 .68841 m .60114 .68688 L .60025 .68056 L p F P
0 g
s
.464 .458 .767 r
.63537 .82623 m .63142 .82503 L .62948 .81971 L p F P
0 g
s
.192 .18 .615 r
.80439 .80259 m .80587 .80039 L .80316 .79533 L p F P
0 g
s
.19 .181 .618 r
.80612 .79076 m .80316 .79533 L .80587 .80039 L p F P
0 g
s
.227 .226 .65 r
.80283 .78586 m .80612 .79076 L .80316 .79533 L p F P
0 g
s
.58 .658 .891 r
.70792 .89066 m .69791 .89182 L .69501 .88731 L p F P
0 g
s
.55 .601 .857 r
.68829 .88263 m .67995 .88282 L .67699 .87739 L p F P
0 g
s
.016 0 .339 r
.80041 .83609 m .80019 .83634 L .79933 .84242 L p F P
0 g
s
.325 .316 .695 r
.60853 .75411 m .61157 .75032 L .60678 .74603 L p F P
0 g
s
.282 .289 .69 r
.6106 .74095 m .60678 .74603 L .61157 .75032 L p F P
0 g
s
.323 .305 .684 r
.60634 .73652 m .6106 .74095 L .60678 .74603 L p F P
0 g
s
0 0 .045 r
.79018 .8602 m .7915 .8588 L .79205 .8566 L closepath p F P
0 g
s
.301 .349 .745 r
.79517 .74963 m .79271 .75417 L .79802 .75844 L p F P
0 g
s
.314 .364 .755 r
.7894 .74551 m .79517 .74963 L .79271 .75417 L p F P
0 g
s
.548 .68 .925 r
.66297 .63101 m .6723 .63032 L .66939 .62612 L p F P
0 g
s
.548 .68 .925 r
.66939 .62612 m .6634 .62668 L .66297 .63101 L p F P
0 g
s
.541 .68 .929 r
.65731 .62728 m .6634 .62668 L .66297 .63101 L p F P
0 g
s
.531 .581 .85 r
.67699 .87739 m .67246 .87727 L .67559 .87472 L closepath p F P
0 g
s
.536 .568 .835 r
.67402 .87169 m .67559 .87472 L .67246 .87727 L p F P
0 g
s
.352 .338 .704 r
.60853 .75411 m .61157 .75032 L p .6126 .75966 L F P
0 g
s
.352 .338 .704 r
.6126 .75966 m .60937 .75711 L .60853 .75411 L p F P
0 g
s
.768 .801 .88 r
.09288 .88962 m .10344 .88259 L .10733 .88547 L p F P
0 g
s
.765 .801 .882 r
.10424 .88207 m .10344 .88259 L .10733 .88547 L p F P
0 g
s
.765 .801 .882 r
.10733 .88547 m .10806 .88499 L .10424 .88207 L p F P
0 g
s
.002 .024 .528 r
.60225 .69339 m .6005 .68841 L .60114 .68688 L closepath p F P
0 g
s
.379 .464 .822 r
.76357 .70476 m .77193 .70799 L p .76997 .71256 L F P
0 g
s
.376 .468 .827 r
.76357 .70476 m .77193 .70799 L .76901 .70166 L p F P
0 g
s
.376 .468 .827 r
.76901 .70166 m .76539 .70026 L .76357 .70476 L p F P
0 g
s
.464 .458 .767 r
.62948 .81971 m .63171 .81766 L p .63537 .82623 L F P
0 g
s
.448 .447 .765 r
.62948 .81971 m .62831 .81646 L .63171 .81766 L closepath p F P
0 g
s
.853 .791 .791 r
.14345 .85255 m .14299 .85309 L .13923 .85008 L p F P
0 g
s
.853 .791 .791 r
.13923 .85008 m .13963 .84961 L .14345 .85255 L p F P
0 g
s
.853 .791 .791 r
.14345 .85255 m .13963 .84961 L .14598 .84215 L p F P
0 g
s
.797 .8 .855 r
.11869 .87657 m .10806 .88499 L .10424 .88207 L p F P
0 g
s
0 0 .4 r
.80371 .82589 m .8038 .83171 L .80041 .83609 L p F P
0 g
s
0 0 .32 r
.8038 .83171 m .80041 .83609 L .80033 .84126 L p F P
0 g
s
.016 0 .339 r
.79933 .84242 m .80033 .84126 L .80041 .83609 L p F P
0 g
s
.834 .795 .814 r
.13589 .86035 m .14299 .85309 L .13923 .85008 L p F P
0 g
s
.516 .54 .819 r
.66742 .86539 m .65887 .86459 L .65662 .85968 L p F P
0 g
s
.347 .338 .707 r
.61073 .76187 m .60937 .75711 L .6126 .75966 L closepath p F P
0 g
s
.51 .636 .91 r
.68288 .6389 m .69027 .63899 L .68737 .63448 L p F P
0 g
s
.51 .636 .91 r
.68737 .63448 m .6837 .63448 L .68288 .6389 L p F P
0 g
s
.507 .64 .915 r
.6752 .63458 m .6837 .63448 L .68288 .6389 L p F P
0 g
s
.168 .186 .635 r
.60493 .70795 m .60235 .71277 L .60543 .71748 L p F P
0 g
s
.137 .145 .603 r
.60235 .71277 m .60493 .70795 L .60234 .70311 L p F P
0 g
s
.452 .444 .759 r
.63171 .81766 m .62831 .81646 L .6264 .81103 L p F P
0 g
s
.622 .956 .909 r
.76684 .88392 m .75718 .88971 L .75458 .88872 L p F P
0 g
s
.315 .372 .762 r
.79171 .74098 m .7894 .74551 L .79517 .74963 L p F P
0 g
s
.326 .386 .771 r
.78549 .73701 m .79171 .74098 L .7894 .74551 L p F P
0 g
s
.372 .357 .713 r
.61073 .76187 m .6126 .75966 L p .61371 .76896 L F P
0 g
s
.372 .357 .713 r
.61371 .76896 m .61256 .76816 L .61073 .76187 L p F P
0 g
s
.377 .456 .815 r
.77486 .71467 m .76997 .71256 L p .7758 .72052 L F P
0 g
s
.369 .451 .815 r
.77486 .71467 m .76997 .71256 L .77197 .70809 L closepath p F P
0 g
s
.379 .464 .822 r
.77193 .70799 m .77197 .70809 L .76997 .71256 L p F P
0 g
s
.838 .795 .81 r
.13589 .86035 m .13121 .86525 L .12742 .86227 L p F P
0 g
s
.838 .795 .81 r
.12742 .86227 m .13205 .85743 L .13589 .86035 L p F P
0 g
s
.834 .795 .814 r
.13923 .85008 m .13205 .85743 L .13589 .86035 L p F P
0 g
s
.385 .376 .727 r
.61574 .77866 m .615 .77821 L .61545 .77773 L closepath p F P
0 g
s
.381 .371 .723 r
.615 .77821 m .61545 .77773 L .61303 .76974 L p F P
0 g
s
.434 .432 .757 r
.6264 .81103 m .62518 .80755 L .62859 .80894 L closepath p F P
0 g
s
.452 .444 .759 r
.6264 .81103 m .62859 .80894 L p .63171 .81766 L F P
0 g
s
.338 .406 .785 r
.7809 .72888 m .781 .72866 L p .78549 .73701 L F P
0 g
s
.349 .425 .798 r
.7809 .72888 m .78076 .72854 L .781 .72866 L closepath p F P
0 g
s
.599 .712 .924 r
.64241 .62579 m .6544 .6234 L .65731 .62728 L p F P
0 g
s
.611 .723 .925 r
.6544 .6234 m .64241 .62579 L .63949 .62231 L p F P
0 g
s
.669 .766 .923 r
.6276 .62662 m .63949 .62231 L .64241 .62579 L p F P
0 g
s
.691 .781 .92 r
.63949 .62231 m .6276 .62662 L .62468 .62391 L p F P
0 g
s
.347 .425 .8 r
.781 .72866 m .78076 .72854 L .77781 .72149 L p F P
0 g
s
0 0 0 r
.60394 .65208 m .60437 .65063 L .60581 .64668 L p F P
0 g
s
0 0 0 r
.60581 .64668 m .607 .64212 L p .60394 .65208 L F P
0 g
s
.872 .946 .586 r
.60581 .64668 m .607 .64212 L .6107 .63549 L p F P
0 g
s
.328 .393 .778 r
.78765 .7325 m .78549 .73701 L .79171 .74098 L p F P
0 g
s
.338 .406 .785 r
.781 .72866 m .78765 .7325 L .78549 .73701 L p F P
0 g
s
0 0 0 r
.7915 .8588 m .79018 .8602 L .78524 .86737 L p F P
0 g
s
.424 .533 .864 r
.73227 .67128 m .73229 .67122 L p .74164 .67815 L F P
0 g
s
.432 .546 .872 r
.73227 .67128 m .73223 .6712 L .73229 .67122 L closepath p F P
0 g
s
.429 .548 .875 r
.73229 .67122 m .73223 .6712 L .72935 .66599 L p F P
0 g
s
.439 .429 .752 r
.62859 .80894 m .62518 .80755 L .62346 .8025 L p F P
0 g
s
0 0 .228 r
.60321 .65851 m .60205 .66303 L .60221 .66852 L p F P
0 g
s
0 0 .051 r
.60205 .66303 m .60321 .65851 L .60382 .6528 L p F P
0 g
s
.358 .433 .802 r
.77781 .72149 m .7758 .72052 L .77665 .71874 L closepath p F P
0 g
s
.377 .456 .815 r
.7758 .72052 m .77665 .71874 L .77486 .71467 L p F P
0 g
s
.367 .358 .717 r
.61303 .76974 m .61256 .76816 L .61371 .76896 L closepath p F P
0 g
s
.797 .8 .855 r
.10424 .88207 m .11482 .87367 L .11869 .87657 L p F P
0 g
s
.793 .801 .858 r
.11576 .87294 m .11482 .87367 L .11869 .87657 L p F P
0 g
s
.793 .801 .858 r
.11869 .87657 m .11956 .8759 L .11576 .87294 L p F P
0 g
s
.424 .533 .864 r
.73229 .67122 m .7431 .67367 L .74164 .67815 L p F P
0 g
s
.43 .543 .87 r
.73345 .6668 m .73229 .67122 L .7431 .67367 L p F P
0 g
s
.429 .548 .875 r
.72935 .66599 m .73345 .6668 L .73229 .67122 L p F P
0 g
s
.82 .798 .831 r
.12781 .86831 m .11956 .8759 L .11576 .87294 L p F P
0 g
s
.82 .798 .831 r
.11576 .87294 m .12395 .8654 L .12781 .86831 L p F P
0 g
s
.816 .798 .835 r
.12742 .86227 m .12395 .8654 L .12781 .86831 L p F P
0 g
s
.816 .798 .835 r
.12781 .86831 m .13121 .86525 L .12742 .86227 L p F P
0 g
s
.155 .132 .578 r
.80587 .80039 m .80439 .80259 L .80561 .80919 L p F P
0 g
s
.192 .158 .588 r
.80485 .81022 m .80561 .80919 L .80439 .80259 L p F P
0 g
s
.371 .364 .721 r
.61371 .76896 m .61303 .76974 L .61545 .77773 L p F P
0 g
s
.333 .407 .789 r
.78301 .72418 m .781 .72866 L .78765 .7325 L p F P
0 g
s
.347 .425 .8 r
.77781 .72149 m .78301 .72418 L .781 .72866 L p F P
0 g
s
.481 .613 .905 r
.69867 .64388 m .69316 .64355 L .69027 .63899 L p F P
0 g
s
.511 .647 .918 r
.6837 .63448 m .6752 .63458 L .6723 .63032 L p F P
0 g
s
.439 .429 .752 r
.62346 .8025 m .62591 .80009 L p .62859 .80894 L F P
0 g
s
.42 .416 .749 r
.62346 .8025 m .62205 .7983 L .62591 .80009 L closepath p F P
0 g
s
.425 .414 .744 r
.62591 .80009 m .62205 .7983 L .62067 .79412 L p F P
0 g
s
.394 .382 .727 r
.61545 .77773 m .61967 .77298 L p .62151 .78209 L F P
0 g
s
.394 .382 .727 r
.62151 .78209 m .61574 .77866 L .61545 .77773 L p F P
0 g
s
.371 .364 .721 r
.61545 .77773 m .61967 .77298 L .61371 .76896 L p F P
0 g
s
.389 .383 .732 r
.618 .78587 m .61574 .77866 L .62151 .78209 L closepath p F P
0 g
s
.425 .414 .744 r
.62067 .79412 m .62357 .79113 L p .62591 .80009 L F P
0 g
s
.405 .4 .74 r
.62067 .79412 m .6189 .78867 L .62357 .79113 L closepath p F P
0 g
s
.41 .398 .736 r
.618 .78587 m .62151 .78209 L p .62357 .79113 L F P
0 g
s
.41 .398 .736 r
.62357 .79113 m .6189 .78867 L .618 .78587 L p F P
0 g
s
.244 .255 .673 r
.80186 .77656 m .80572 .78129 L .80283 .78586 L p F P
0 g
s
.22 .225 .651 r
.80572 .78129 m .80283 .78586 L .80612 .79076 L p F P
0 g
s
.261 .275 .686 r
.60965 .73156 m .60634 .73652 L .6106 .74095 L p F P
0 g
s
.298 .281 .672 r
.60589 .72701 m .60965 .73156 L .60634 .73652 L p F P
0 g
s
.394 .497 .846 r
.7582 .69267 m .75341 .69115 L .75052 .68527 L p F P
0 g
s
.516 .54 .819 r
.65662 .85968 m .65829 .85828 L p .66742 .86539 L F P
0 g
s
.503 .531 .818 r
.65662 .85968 m .65584 .85797 L .65829 .85828 L closepath p F P
0 g
s
.595 .755 .955 r
.71287 .89422 m .72499 .89187 L .72777 .89494 L p F P
0 g
s
.583 .728 .943 r
.72499 .89187 m .71287 .89422 L .71003 .89041 L p F P
0 g
s
.152 .103 .544 r
.80561 .80919 m .80485 .81022 L .80646 .81561 L p F P
0 g
s
.452 .572 .884 r
.71126 .65406 m .71128 .65396 L p .72288 .66022 L F P
0 g
s
.459 .583 .89 r
.71126 .65406 m .7112 .65395 L .71128 .65396 L closepath p F P
0 g
s
.074 .074 .552 r
.60114 .68688 m .60265 .68365 L p .60228 .69345 L F P
0 g
s
.074 .074 .552 r
.60228 .69345 m .60225 .69339 L .60114 .68688 L p F P
0 g
s
0 0 .497 r
.60114 .68688 m .60265 .68365 L .60122 .67851 L p F P
0 g
s
.456 .585 .894 r
.71128 .65396 m .7112 .65395 L .70832 .64915 L p F P
0 g
s
.452 .572 .884 r
.71128 .65396 m .72358 .65568 L p .72288 .66022 L F P
0 g
s
.451 .579 .891 r
.71128 .65396 m .72358 .65568 L .7207 .65074 L p F P
0 g
s
.451 .579 .891 r
.7207 .65074 m .71211 .64959 L .71128 .65396 L p F P
0 g
s
.456 .585 .894 r
.70832 .64915 m .71211 .64959 L .71128 .65396 L p F P
0 g
s
.35 .36 .73 r
.61799 .76382 m .61371 .76896 L .61967 .77298 L p F P
0 g
s
.372 .357 .713 r
.6126 .75966 m .61799 .76382 L .61371 .76896 L p F P
0 g
s
.506 .526 .811 r
.65829 .85828 m .65584 .85797 L .6528 .85106 L p F P
0 g
s
0 0 .462 r
.60301 .67384 m .60122 .67851 L .60265 .68365 L p F P
0 g
s
0 0 .398 r
.60122 .67851 m .60301 .67384 L .60221 .66852 L p F P
0 g
s
.486 .486 .782 r
.63968 .83463 m .64667 .83643 L p .64479 .8428 L F P
0 g
s
.467 .481 .79 r
.64667 .83643 m .63968 .83463 L .64426 .83043 L closepath p F P
0 g
s
.475 .472 .775 r
.64358 .82873 m .64426 .83043 L .63968 .83463 L p F P
0 g
s
.475 .472 .775 r
.63537 .82623 m .64358 .82873 L p .63968 .83463 L F P
0 g
s
.659 .972 .854 r
.76684 .88392 m .76835 .88252 L .76905 .88245 L closepath p F P
0 g
s
.622 .956 .909 r
.76835 .88252 m .76684 .88392 L p .75458 .88872 L F P
0 g
s
.111 .133 .603 r
.60365 .70035 m .60234 .70311 L .60493 .70795 L p F P
0 g
s
.086 .104 .581 r
.60234 .70311 m .60365 .70035 L .60227 .69347 L p F P
0 g
s
.496 .499 .79 r
.64479 .8428 m .64974 .84387 L p .65086 .85072 L F P
0 g
s
.479 .495 .797 r
.64974 .84387 m .64479 .8428 L .64809 .83989 L closepath p F P
0 g
s
.486 .486 .782 r
.64667 .83643 m .64809 .83989 L .64479 .8428 L p F P
0 g
s
.548 .689 .932 r
.6634 .62668 m .65731 .62728 L .6544 .6234 L p F P
0 g
s
.621 .832 .981 r
.72777 .89494 m .73986 .89148 L .74256 .89368 L p F P
0 g
s
.638 .883 .986 r
.75057 .89043 m .74256 .89368 L .73986 .89148 L p F P
0 g
s
.646 .898 .57 r
.77989 .8733 m .78076 .87253 L .78524 .86737 L p F P
0 g
s
.646 .898 .57 r
.78524 .86737 m .78978 .86256 L p .77989 .8733 L F P
0 g
s
0 0 0 r
.79 .86226 m .7915 .8588 L p .78524 .86737 L F P
0 g
s
0 0 0 r
.78524 .86737 m .78978 .86256 L .79 .86226 L p F P
0 g
s
.454 .467 .782 r
.64358 .82873 m .63537 .82623 L .64065 .8212 L closepath p F P
0 g
s
.464 .458 .767 r
.64049 .82076 m .64065 .8212 L .63537 .82623 L p F P
0 g
s
.464 .458 .767 r
.63171 .81766 m .64049 .82076 L p .63537 .82623 L F P
0 g
s
.527 .579 .85 r
.6862 .87216 m .68916 .87748 L .67699 .87739 L p F P
0 g
s
.527 .579 .85 r
.67897 .87188 m .6862 .87216 L p .67699 .87739 L F P
0 g
s
.527 .579 .85 r
.67699 .87739 m .67559 .87472 L .67897 .87188 L p F P
0 g
s
.55 .601 .857 r
.67699 .87739 m .68916 .87748 L p .68829 .88263 L F P
0 g
s
.747 .994 .842 r
.76835 .88252 m .76905 .88245 L .77805 .87512 L p F P
0 g
s
.342 .423 .8 r
.78301 .72418 m .77781 .72149 L .77665 .71874 L p F P
0 g
s
.61 .798 .972 r
.73986 .89148 m .72777 .89494 L .72499 .89187 L p F P
0 g
s
.424 .527 .858 r
.74763 .67966 m .74164 .67815 L p .75045 .68525 L F P
0 g
s
.415 .524 .86 r
.74164 .67815 m .74763 .67966 L .74474 .67408 L p F P
0 g
s
.415 .524 .86 r
.74474 .67408 m .7431 .67367 L .74164 .67815 L p F P
0 g
s
.49 .509 .804 r
.6528 .85106 m .65086 .85072 L .65218 .84961 L closepath p F P
0 g
s
.496 .499 .79 r
.64974 .84387 m .65218 .84961 L .65086 .85072 L p F P
0 g
s
0 0 .215 r
.80033 .84126 m .79933 .84242 L .79742 .84879 L p F P
0 g
s
0 0 0 r
.79 .86226 m .79431 .85548 L .7915 .8588 L closepath p F P
0 g
s
0 0 0 r
.79742 .84879 m .79431 .85548 L .7915 .8588 L p F P
0 g
s
.048 0 .415 r
.80719 .82142 m .80371 .82589 L .8038 .83171 L p F P
0 g
s
.112 .041 .489 r
.8068 .81778 m .80646 .81561 L p .80371 .82589 L F P
0 g
s
.112 .041 .489 r
.80371 .82589 m .80719 .82142 L .8068 .81778 L p F P
0 g
s
.432 .437 .764 r
.63171 .81766 m .64049 .82076 L .63738 .8125 L p F P
0 g
s
.432 .437 .764 r
.63738 .8125 m .63706 .81237 L .63171 .81766 L p F P
0 g
s
.452 .444 .759 r
.62859 .80894 m .63706 .81237 L .63171 .81766 L p F P
0 g
s
.243 .261 .68 r
.80465 .77198 m .80186 .77656 L .80572 .78129 L p F P
0 g
s
.265 .29 .701 r
.80186 .77656 m .80465 .77198 L .80025 .76742 L p F P
0 g
s
.58 .658 .891 r
.69501 .88731 m .70716 .88628 L p .70792 .89066 L F P
0 g
s
.549 .65 .902 r
.70716 .88628 m .69501 .88731 L .69209 .88253 L p F P
0 g
s
.523 .844 .545 r
.77805 .87512 m .77989 .8733 L .78076 .87253 L closepath p F P
0 g
s
.747 .994 .842 r
.77805 .87512 m .77989 .8733 L p .76835 .88252 L F P
0 g
s
.227 .245 .671 r
.60871 .72215 m .60589 .72701 L .60965 .73156 L p F P
0 g
s
.199 .21 .646 r
.60589 .72701 m .60871 .72215 L .60543 .71748 L p F P
0 g
s
.155 .132 .578 r
.80561 .80919 m .80802 .80563 L .80587 .80039 L p F P
0 g
s
.11 .073 .532 r
.80802 .80563 m .80561 .80919 L .80656 .81548 L p F P
0 g
s
.152 .103 .544 r
.80646 .81561 m .80656 .81548 L .80561 .80919 L p F P
0 g
s
.342 .423 .8 r
.77665 .71874 m .77779 .71602 L p .78301 .72418 L F P
0 g
s
.354 .441 .812 r
.77665 .71874 m .77486 .71467 L .77779 .71602 L closepath p F P
0 g
s
.327 .338 .719 r
.61644 .7546 m .6126 .75966 L .61799 .76382 L p F P
0 g
s
.352 .338 .704 r
.61157 .75032 m .61644 .7546 L .6126 .75966 L p F P
0 g
s
.516 .54 .819 r
.65829 .85828 m .66801 .85951 L p .66742 .86539 L F P
0 g
s
.49 .519 .814 r
.65829 .85828 m .66801 .85951 L .66499 .85307 L p F P
0 g
s
.49 .519 .814 r
.66499 .85307 m .66429 .85295 L .65829 .85828 L p F P
0 g
s
.506 .526 .811 r
.6528 .85106 m .66429 .85295 L .65829 .85828 L p F P
0 g
s
.527 .577 .849 r
.67559 .87472 m .67402 .87169 L .67897 .87188 L closepath p F P
0 g
s
.426 .436 .767 r
.63368 .80368 m .62859 .80894 L .63706 .81237 L p F P
0 g
s
.439 .429 .752 r
.62591 .80009 m .63368 .80368 L .62859 .80894 L p F P
0 g
s
.428 .55 .877 r
.73345 .6668 m .72935 .66599 L .72647 .66081 L p F P
0 g
s
.495 .512 .804 r
.66429 .85295 m .6528 .85106 L .65218 .84961 L p F P
0 g
s
.074 .074 .552 r
.60227 .69347 m .60225 .69339 L .60228 .69345 L closepath p F P
0 g
s
.155 .134 .581 r
.80889 .79581 m .80587 .80039 L .80802 .80563 L p F P
0 g
s
.19 .181 .618 r
.80587 .80039 m .80889 .79581 L .80612 .79076 L p F P
0 g
s
.407 .508 .849 r
.75052 .68527 m .75045 .68525 L .75047 .68519 L closepath p F P
0 g
s
.424 .527 .858 r
.75045 .68525 m .75047 .68519 L .74763 .67966 L p F P
0 g
s
.55 .601 .857 r
.68916 .87748 m .69087 .88043 L .68829 .88263 L p F P
0 g
s
.545 .616 .874 r
.69209 .88253 m .68829 .88263 L .69087 .88043 L closepath p F P
0 g
s
.112 .122 .589 r
.60228 .69345 m .60227 .69347 L .60365 .70035 L p F P
0 g
s
.112 .122 .589 r
.60365 .70035 m .60469 .69833 L .60228 .69345 L p F P
0 g
s
.049 .076 .568 r
.60451 .68868 m .60228 .69345 L .60469 .69833 L p F P
0 g
s
.074 .074 .552 r
.60265 .68365 m .60451 .68868 L .60228 .69345 L p F P
0 g
s
.394 .497 .846 r
.75052 .68527 m .75974 .68821 L .7582 .69267 L p F P
0 g
s
.39 .498 .848 r
.75974 .68821 m .75052 .68527 L .75047 .68519 L p F P
0 g
s
.81 .983 .89 r
.61081 .63231 m .61295 .63266 L .61942 .62734 L p F P
0 g
s
.912 .959 .805 r
.6107 .63549 m .61081 .63231 L .61295 .63266 L closepath p F P
0 g
s
.39 .498 .848 r
.75047 .68519 m .75177 .68083 L p .75974 .68821 L F P
0 g
s
.4 .513 .857 r
.75047 .68519 m .74763 .67966 L .75177 .68083 L closepath p F P
0 g
s
.26 .29 .703 r
.80294 .76285 m .80025 .76742 L .80465 .77198 L p F P
0 g
s
.283 .319 .723 r
.80025 .76742 m .80294 .76285 L .79802 .75844 L p F P
0 g
s
.706 .981 .899 r
.76654 .88238 m .77155 .8791 L .76835 .88252 L closepath p F P
0 g
s
.622 .956 .909 r
.75458 .88872 m .76654 .88238 L .76835 .88252 L p F P
0 g
s
.747 .994 .842 r
.77839 .87407 m .77155 .8791 L .76835 .88252 L p F P
0 g
s
.747 .994 .842 r
.77989 .8733 m .77839 .87407 L p .76835 .88252 L F P
0 g
s
.495 .512 .804 r
.65218 .84961 m .65698 .84533 L p .66429 .85295 L F P
0 g
s
.482 .503 .803 r
.65218 .84961 m .64974 .84387 L .65698 .84533 L closepath p F P
0 g
s
.575 .678 .91 r
.71003 .89041 m .70792 .89066 L .70933 .88941 L closepath p F P
0 g
s
.58 .658 .891 r
.70716 .88628 m .70933 .88941 L .70792 .89066 L p F P
0 g
s
.481 .608 .901 r
.69867 .64388 m .70543 .64438 L .70254 .63966 L p F P
0 g
s
.481 .608 .901 r
.70254 .63966 m .69953 .63947 L .69867 .64388 L p F P
0 g
s
.481 .613 .905 r
.69027 .63899 m .69953 .63947 L .69867 .64388 L p F P
0 g
s
0 0 .192 r
.80303 .83777 m .80033 .84126 L .79984 .84598 L p F P
0 g
s
0 0 .32 r
.80033 .84126 m .80303 .83777 L .8038 .83171 L p F P
0 g
s
0 0 .215 r
.79742 .84879 m .79984 .84598 L .80033 .84126 L p F P
0 g
s
0 0 0 r
.60505 .64823 m .60394 .65208 L p .60483 .64918 L F P
0 g
s
0 0 0 r
.607 .64212 m .60505 .64823 L p .60483 .64918 L F P
0 g
s
.805 .797 .302 r
.60751 .63774 m .607 .64212 L .60505 .64823 L p F P
0 g
s
0 0 0 r
.60505 .64823 m .60433 .65398 L p .6053 .64714 L F P
0 g
s
.805 .797 .302 r
.60577 .64379 m .60751 .63774 L p .60587 .64471 L F P
0 g
s
.805 .797 .302 r
.60505 .64823 m .60577 .64379 L p .60587 .64471 L F P
0 g
s
0 0 0 r
.60577 .64379 m .60505 .64823 L p .6053 .64714 L F P
0 g
s
0 0 0 r
.60513 .64953 m .60577 .64379 L p .60491 .64986 L F P
0 g
s
0 0 0 r
.60433 .65398 m .60513 .64953 L p .60491 .64986 L F P
0 g
s
0 0 .091 r
.60513 .64953 m .60528 .65504 L p .60534 .6492 L F P
0 g
s
.744 .658 .102 r
.60577 .64379 m .60513 .64953 L p .60567 .64287 L F P
0 g
s
.744 .658 .102 r
.60538 .64522 m .60595 .6395 L p .60542 .64599 L F P
0 g
s
.744 .658 .102 r
.60513 .64953 m .60538 .64522 L p .60542 .64599 L F P
0 g
s
0 0 .091 r
.60528 .65504 m .60555 .65074 L .60538 .64522 L p F P
0 g
s
0 0 .025 r
.60538 .64522 m .60555 .65074 L p .60535 .64458 L F P
0 g
s
0 0 .025 r
.60528 .64206 m .60538 .64522 L p .60535 .64458 L F P
0 g
s
0 0 .091 r
.60538 .64522 m .60513 .64953 L p .60534 .6492 L F P
0 g
s
.744 .658 .102 r
.60595 .6395 m .60577 .64379 L p .60567 .64287 L F P
0 g
s
0 0 .042 r
.60505 .64823 m .60394 .65208 L .6035 .65691 L p F P
0 g
s
0 0 0 r
.60321 .65851 m .6035 .65691 L .60394 .65208 L p F P
0 g
s
0 0 .34 r
.60338 .664 m .60221 .66852 L .60301 .67384 L p F P
0 g
s
0 0 .228 r
.60221 .66852 m .60338 .664 L .60321 .65851 L p F P
0 g
s
.41 .42 .759 r
.63071 .79489 m .62591 .80009 L .63368 .80368 L p F P
0 g
s
.425 .414 .744 r
.62357 .79113 m .63071 .79489 L .62591 .80009 L p F P
0 g
s
.483 .618 .908 r
.69953 .63947 m .69027 .63899 L .68737 .63448 L p F P
0 g
s
.353 .442 .813 r
.77779 .71602 m .77486 .71467 L .77197 .70809 L p F P
0 g
s
.81 .983 .89 r
.61942 .62734 m .61952 .62306 L p .61081 .63231 L F P
0 g
s
.777 .859 .911 r
.62176 .62141 m .61952 .62306 L .61942 .62734 L p F P
0 g
s
.777 .859 .911 r
.61942 .62734 m .62468 .62391 L .62176 .62141 L p F P
0 g
s
.446 .562 .879 r
.72647 .66081 m .72288 .66022 L .72396 .65634 L closepath p F P
0 g
s
.452 .572 .884 r
.72358 .65568 m .72396 .65634 L .72288 .66022 L p F P
0 g
s
.923 .942 .591 r
.61081 .63231 m .6107 .63549 L .607 .64212 L p F P
0 g
s
.638 .883 .986 r
.75334 .88803 m .75057 .89043 L p .73986 .89148 L F P
0 g
s
.672 .905 .977 r
.75057 .89043 m .75334 .88803 L .75458 .88872 L closepath p F P
0 g
s
.511 .647 .918 r
.6723 .63032 m .68447 .63002 L p .6837 .63448 L F P
0 g
s
.522 .651 .916 r
.68447 .63002 m .6723 .63032 L .66939 .62612 L p F P
0 g
s
.611 .723 .925 r
.63949 .62231 m .65148 .6196 L .6544 .6234 L p F P
0 g
s
.624 .734 .926 r
.65148 .6196 m .63949 .62231 L .63656 .61896 L p F P
0 g
s
.691 .781 .92 r
.62468 .62391 m .63656 .61896 L .63949 .62231 L p F P
0 g
s
.53 .57 .841 r
.67897 .87188 m .67402 .87169 L .67102 .86573 L p F P
0 g
s
.183 .204 .648 r
.60692 .71466 m .60543 .71748 L .60871 .72215 L p F P
0 g
s
.168 .186 .635 r
.60557 .709 m .60493 .70795 L p .60543 .71748 L F P
0 g
s
.168 .186 .635 r
.60543 .71748 m .60692 .71466 L .60557 .709 L p F P
0 g
s
.301 .315 .708 r
.61497 .74536 m .61157 .75032 L .61644 .7546 L p F P
0 g
s
.282 .289 .69 r
.61157 .75032 m .61497 .74536 L .6106 .74095 L p F P
0 g
s
.393 .49 .839 r
.76609 .69541 m .7582 .69267 L p .76539 .70026 L F P
0 g
s
.382 .485 .84 r
.7582 .69267 m .76609 .69541 L .76319 .6894 L p F P
0 g
s
.382 .485 .84 r
.76319 .6894 m .75974 .68821 L .7582 .69267 L p F P
0 g
s
.278 .318 .725 r
.80028 .75441 m .79802 .75844 L .80294 .76285 L p F P
0 g
s
.301 .349 .745 r
.79993 .75338 m .79517 .74963 L p .79802 .75844 L F P
0 g
s
.301 .349 .745 r
.79802 .75844 m .80028 .75441 L .79993 .75338 L p F P
0 g
s
.51 .551 .834 r
.67102 .86573 m .66742 .86539 L .66984 .8633 L closepath p F P
0 g
s
.516 .54 .819 r
.66801 .85951 m .66984 .8633 L .66742 .86539 L p F P
0 g
s
.456 .589 .896 r
.71211 .64959 m .70832 .64915 L .70543 .64438 L p F P
0 g
s
.583 .728 .943 r
.71003 .89041 m .72218 .88848 L .72499 .89187 L p F P
0 g
s
.578 .68 .91 r
.71935 .88479 m .72218 .88848 L .71003 .89041 L p F P
0 g
s
.578 .68 .91 r
.71406 .88543 m .71935 .88479 L p .71003 .89041 L F P
0 g
s
.578 .68 .91 r
.71003 .89041 m .70933 .88941 L .71406 .88543 L p F P
0 g
s
.558 .686 .925 r
.6634 .62668 m .66939 .62612 L .66648 .62198 L p F P
0 g
s
.558 .686 .925 r
.66648 .62198 m .66405 .62226 L .6634 .62668 L p F P
0 g
s
.548 .689 .932 r
.6544 .6234 m .66405 .62226 L .6634 .62668 L p F P
0 g
s
.714 .797 .916 r
.63656 .61896 m .62468 .62391 L .62176 .62141 L p F P
0 g
s
0 0 0 r
.79984 .84598 m .79742 .84879 L .79431 .85548 L p F P
0 g
s
.394 .403 .751 r
.62801 .78604 m .62357 .79113 L .63071 .79489 L p F P
0 g
s
.41 .398 .736 r
.62797 .78595 m .62801 .78604 L .62357 .79113 L p F P
0 g
s
.41 .398 .736 r
.62151 .78209 m .62797 .78595 L p .62357 .79113 L F P
0 g
s
.485 .499 .797 r
.65698 .84533 m .64974 .84387 L .64809 .83989 L p F P
0 g
s
.647 .941 .698 r
.77839 .87407 m .78253 .87034 L .77989 .8733 L closepath p F P
0 g
s
.646 .898 .57 r
.78978 .86256 m .78253 .87034 L .77989 .8733 L p F P
0 g
s
.099 .032 .486 r
.8068 .81778 m .80646 .81561 L .80656 .81548 L closepath p F P
0 g
s
.726 .919 .958 r
.75334 .88803 m .75458 .88872 L .76654 .88238 L p F P
0 g
s
.133 .148 .609 r
.60469 .69833 m .60365 .70035 L .60519 .7074 L p F P
0 g
s
.111 .133 .603 r
.60493 .70795 m .60519 .7074 L .60365 .70035 L p F P
0 g
s
.51 .635 .909 r
.68737 .63448 m .6837 .63448 L .68458 .63018 L closepath p F P
0 g
s
.511 .647 .918 r
.68447 .63002 m .68458 .63018 L .6837 .63448 L p F P
0 g
s
.375 .469 .828 r
.76901 .70166 m .76539 .70026 L .76675 .69678 L closepath p F P
0 g
s
.393 .49 .839 r
.76539 .70026 m .76675 .69678 L .76609 .69541 L p F P
0 g
s
.066 .009 .475 r
.80656 .81548 m .80956 .81105 L p .80733 .82121 L F P
0 g
s
.066 .009 .475 r
.80733 .82121 m .8068 .81778 L .80656 .81548 L p F P
0 g
s
.11 .073 .532 r
.80656 .81548 m .80956 .81105 L .80802 .80563 L p F P
0 g
s
.292 .343 .744 r
.79993 .75338 m .79517 .74963 L .79726 .74571 L closepath p F P
0 g
s
.315 .372 .762 r
.79684 .74457 m .79171 .74098 L p .79517 .74963 L F P
0 g
s
.315 .372 .762 r
.79517 .74963 m .79726 .74571 L .79684 .74457 L p F P
0 g
s
.189 .182 .62 r
.80909 .78617 m .80612 .79076 L .80889 .79581 L p F P
0 g
s
.22 .225 .651 r
.80612 .79076 m .80909 .78617 L .80572 .78129 L p F P
0 g
s
.549 .65 .902 r
.69209 .88253 m .70427 .88187 L .70716 .88628 L p F P
0 g
s
.544 .616 .874 r
.70137 .87722 m .70427 .88187 L .69209 .88253 L p F P
0 g
s
.544 .616 .874 r
.69442 .87736 m .70137 .87722 L p .69209 .88253 L F P
0 g
s
.544 .616 .874 r
.69209 .88253 m .69087 .88043 L .69442 .87736 L p F P
0 g
s
.557 .699 .935 r
.66405 .62226 m .6544 .6234 L .65148 .6196 L p F P
0 g
s
0 0 .506 r
.60433 .67902 m .60265 .68365 L .60451 .68868 L p F P
0 g
s
0 0 .462 r
.60265 .68365 m .60433 .67902 L .60301 .67384 L p F P
0 g
s
.577 .679 .909 r
.70933 .88941 m .70716 .88628 L .71406 .88543 L closepath p F P
0 g
s
.048 0 .415 r
.80744 .82606 m .80719 .82142 L p .8038 .83171 L F P
0 g
s
.048 0 .415 r
.8038 .83171 m .80745 .82704 L .80744 .82606 L p F P
0 g
s
0 0 .317 r
.80745 .82704 m .8038 .83171 L .80303 .83777 L p F P
0 g
s
.485 .499 .797 r
.64809 .83989 m .65077 .83742 L p .65698 .84533 L F P
0 g
s
.47 .489 .796 r
.64809 .83989 m .64667 .83643 L .65077 .83742 L closepath p F P
0 g
s
.353 .442 .813 r
.77197 .70809 m .772 .70802 L p .77779 .71602 L F P
0 g
s
.364 .459 .824 r
.77197 .70809 m .77193 .70799 L .772 .70802 L closepath p F P
0 g
s
.362 .46 .826 r
.772 .70802 m .77193 .70799 L .76901 .70166 L p F P
0 g
s
.305 .366 .761 r
.79684 .74457 m .79171 .74098 L .79391 .73661 L closepath p F P
0 g
s
.328 .393 .778 r
.7938 .73633 m .78765 .7325 L p .79171 .74098 L F P
0 g
s
.328 .393 .778 r
.79171 .74098 m .79391 .73661 L .7938 .73633 L p F P
0 g
s
.353 .442 .813 r
.772 .70802 m .77956 .71155 L .77779 .71602 L p F P
0 g
s
.35 .444 .817 r
.77359 .70358 m .772 .70802 L .77956 .71155 L p F P
0 g
s
.362 .46 .826 r
.76901 .70166 m .77359 .70358 L .772 .70802 L p F P
0 g
s
.271 .287 .694 r
.61289 .73732 m .6106 .74095 L .61497 .74536 L p F P
0 g
s
.261 .275 .686 r
.61206 .73431 m .60965 .73156 L p .6106 .74095 L F P
0 g
s
.261 .275 .686 r
.6106 .74095 m .61289 .73732 L .61206 .73431 L p F P
0 g
s
.374 .385 .742 r
.62797 .78595 m .62151 .78209 L .6252 .77762 L closepath p F P
0 g
s
.394 .382 .727 r
.62482 .77644 m .6252 .77762 L .62151 .78209 L p F P
0 g
s
.394 .382 .727 r
.61967 .77298 m .62482 .77644 L p .62151 .78209 L F P
0 g
s
.923 .942 .591 r
.61008 .6325 m .61081 .63231 L p .607 .64212 L F P
0 g
s
.923 .942 .591 r
.607 .64212 m .60751 .63774 L .61008 .6325 L p F P
0 g
s
.43 .543 .87 r
.74185 .66866 m .73345 .6668 L p .7431 .67367 L F P
0 g
s
.421 .541 .872 r
.73345 .6668 m .74185 .66866 L .73897 .66335 L p F P
0 g
s
.421 .541 .872 r
.73897 .66335 m .73455 .66239 L .73345 .6668 L p F P
0 g
s
.428 .55 .877 r
.72647 .66081 m .73455 .66239 L .73345 .6668 L p F P
0 g
s
.136 .164 .626 r
.60557 .709 m .60493 .70795 L .60519 .7074 L closepath p F P
0 g
s
.598 .767 .961 r
.73712 .8889 m .72499 .89187 L .72218 .88848 L p F P
0 g
s
.61 .798 .972 r
.72499 .89187 m .73712 .8889 L .73986 .89148 L p F P
0 g
s
0 0 .182 r
.6035 .65691 m .60321 .65851 L .60338 .664 L p F P
0 g
s
.399 .514 .858 r
.75177 .68083 m .74763 .67966 L .74474 .67408 L p F P
0 g
s
.314 .384 .775 r
.78765 .7325 m .7938 .73633 L .79079 .72863 L p F P
0 g
s
.314 .384 .775 r
.79079 .72863 m .78977 .72798 L .78765 .7325 L p F P
0 g
s
.333 .407 .789 r
.78765 .7325 m .78977 .72798 L .78301 .72418 L p F P
0 g
s
.427 .552 .879 r
.73455 .66239 m .72647 .66081 L .72396 .65634 L p F P
0 g
s
.342 .423 .8 r
.77779 .71602 m .78496 .71969 L .78301 .72418 L p F P
0 g
s
.345 .432 .807 r
.77956 .71155 m .77779 .71602 L .78496 .71969 L p F P
0 g
s
.638 .883 .986 r
.73986 .89148 m .75193 .88716 L .75334 .88803 L p F P
0 g
s
.628 .849 .984 r
.75193 .88716 m .73986 .89148 L .73712 .8889 L p F P
0 g
s
.333 .412 .793 r
.78496 .71969 m .78301 .72418 L .78977 .72798 L p F P
0 g
s
.473 .485 .79 r
.65077 .83742 m .64667 .83643 L .64426 .83043 L p F P
0 g
s
.069 .011 .476 r
.80719 .82142 m .8068 .81778 L .80733 .82121 L closepath p F P
0 g
s
.544 .614 .873 r
.69087 .88043 m .68916 .87748 L .69442 .87736 L closepath p F P
0 g
s
.53 .57 .841 r
.67102 .86573 m .68323 .86663 L p .67897 .87188 L F P
0 g
s
.506 .549 .834 r
.68024 .86081 m .68323 .86663 L .67102 .86573 L p F P
0 g
s
.506 .549 .834 r
.67345 .86009 m .68024 .86081 L p .67102 .86573 L F P
0 g
s
.506 .549 .834 r
.67102 .86573 m .66984 .8633 L .67345 .86009 L p F P
0 g
s
.186 .197 .639 r
.60519 .7074 m .60737 .70315 L p .60803 .71266 L F P
0 g
s
.186 .197 .639 r
.60803 .71266 m .60557 .709 L .60519 .7074 L p F P
0 g
s
.133 .148 .609 r
.60519 .7074 m .60737 .70315 L .60469 .69833 L p F P
0 g
s
.452 .582 .893 r
.71211 .64959 m .7207 .65074 L .71781 .64584 L p F P
0 g
s
.452 .582 .893 r
.71781 .64584 m .7129 .64521 L .71211 .64959 L p F P
0 g
s
.456 .589 .896 r
.70543 .64438 m .7129 .64521 L .71211 .64959 L p F P
0 g
s
0 0 0 r
.79431 .85548 m .79836 .85076 L p .78993 .86239 L F P
0 g
s
0 0 0 r
.78993 .86239 m .79 .86226 L .79431 .85548 L p F P
0 g
s
0 0 0 r
.7991 .84932 m .79984 .84598 L p .79431 .85548 L F P
0 g
s
0 0 0 r
.79431 .85548 m .79836 .85076 L .7991 .84932 L p F P
0 g
s
.183 .196 .639 r
.60692 .71466 m .60557 .709 L .60803 .71266 L closepath p F P
0 g
s
.243 .261 .68 r
.80633 .77404 m .80465 .77198 L p .80572 .78129 L F P
0 g
s
.243 .261 .68 r
.80572 .78129 m .80753 .77836 L .80633 .77404 L p F P
0 g
s
.214 .223 .652 r
.80753 .77836 m .80572 .78129 L .80909 .78617 L p F P
0 g
s
.524 .585 .858 r
.6862 .87216 m .67897 .87188 L .68372 .86755 L closepath p F P
0 g
s
.53 .57 .841 r
.68323 .86663 m .68372 .86755 L .67897 .87188 L p F P
0 g
s
.354 .365 .733 r
.62482 .77644 m .61967 .77298 L .62252 .76933 L closepath p F P
0 g
s
.35 .36 .73 r
.62165 .76658 m .61799 .76382 L p .61967 .77298 L F P
0 g
s
.35 .36 .73 r
.61967 .77298 m .62252 .76933 L .62165 .76658 L p F P
0 g
s
.477 .618 .911 r
.69676 .63051 m .69965 .63501 L .68737 .63448 L p F P
0 g
s
.477 .618 .911 r
.68459 .63002 m .69676 .63051 L p .68737 .63448 L F P
0 g
s
.477 .618 .911 r
.68737 .63448 m .68458 .63018 L .68459 .63002 L p F P
0 g
s
.483 .618 .908 r
.68737 .63448 m .69965 .63501 L p .69953 .63947 L F P
0 g
s
.458 .475 .788 r
.64426 .83043 m .64358 .82873 L .64548 .82927 L closepath p F P
0 g
s
.473 .485 .79 r
.64426 .83043 m .64548 .82927 L p .65077 .83742 L F P
0 g
s
.237 .257 .679 r
.61206 .73431 m .60965 .73156 L .61078 .72963 L closepath p F P
0 g
s
.227 .245 .671 r
.60883 .72231 m .60871 .72215 L p .60965 .73156 L F P
0 g
s
.227 .245 .671 r
.60965 .73156 m .61078 .72963 L .60883 .72231 L p F P
0 g
s
.686 .898 .973 r
.75193 .88716 m .75568 .88551 L .75334 .88803 L closepath p F P
0 g
s
.726 .919 .958 r
.76397 .88163 m .75568 .88551 L .75334 .88803 L p F P
0 g
s
.726 .919 .958 r
.76654 .88238 m .76397 .88163 L p .75334 .88803 L F P
0 g
s
0 0 .34 r
.60301 .67384 m .60414 .66934 L .60338 .664 L p F P
0 g
s
0 0 .425 r
.60414 .66934 m .60301 .67384 L .60433 .67902 L p F P
0 g
s
.505 .547 .833 r
.66984 .8633 m .66801 .85951 L .67345 .86009 L closepath p F P
0 g
s
.113 .077 .534 r
.81109 .80104 m .80802 .80563 L .80956 .81105 L p F P
0 g
s
.155 .134 .581 r
.80802 .80563 m .81109 .80104 L .80889 .79581 L p F P
0 g
s
.462 .471 .782 r
.64548 .82927 m .64358 .82873 L .64065 .8212 L p F P
0 g
s
.522 .651 .916 r
.66939 .62612 m .68157 .62572 L .68447 .63002 L p F P
0 g
s
.525 .657 .919 r
.68157 .62572 m .66939 .62612 L .66648 .62198 L p F P
0 g
s
.413 .525 .862 r
.74474 .67408 m .7431 .67367 L .74363 .67195 L closepath p F P
0 g
s
.43 .543 .87 r
.7431 .67367 m .74363 .67195 L .74185 .66866 L p F P
0 g
s
.637 .965 .881 r
.77155 .8791 m .76654 .88238 L .76397 .88163 L p F P
0 g
s
.051 .096 .589 r
.60671 .69363 m .60469 .69833 L .60737 .70315 L p F P
0 g
s
.049 .076 .568 r
.60469 .69833 m .60671 .69363 L .60451 .68868 L p F P
0 g
s
.457 .592 .899 r
.7129 .64521 m .70543 .64438 L .70254 .63966 L p F P
0 g
s
.901 .986 .744 r
.61008 .6325 m .61108 .63114 L .61081 .63231 L closepath p F P
0 g
s
.81 .983 .89 r
.61952 .62306 m .61108 .63114 L .61081 .63231 L p F P
0 g
s
.195 .212 .651 r
.60803 .71266 m .60692 .71466 L .60877 .72205 L p F P
0 g
s
.183 .204 .648 r
.60871 .72215 m .60877 .72205 L .60692 .71466 L p F P
0 g
s
.358 .459 .827 r
.77359 .70358 m .76901 .70166 L .76675 .69678 L p F P
0 g
s
0 0 .237 r
.60433 .65398 m .6035 .65691 L .60367 .66243 L p F P
0 g
s
0 0 .182 r
.60338 .664 m .60367 .66243 L .6035 .65691 L p F P
0 g
s
0 0 .042 r
.6035 .65691 m .60433 .65398 L .60505 .64823 L p F P
0 g
s
.581 .666 .897 r
.71406 .88543 m .70716 .88628 L .70427 .88187 L p F P
0 g
s
.547 .605 .863 r
.69442 .87736 m .68916 .87748 L .6862 .87216 L p F P
0 g
s
.332 .345 .724 r
.62165 .76658 m .61799 .76382 L .61995 .76115 L closepath p F P
0 g
s
.327 .338 .719 r
.61847 .75633 m .61644 .7546 L p .61799 .76382 L F P
0 g
s
.327 .338 .719 r
.61799 .76382 m .61995 .76115 L .61847 .75633 L p F P
0 g
s
.624 .734 .926 r
.63656 .61896 m .64855 .61588 L .65148 .6196 L p F P
0 g
s
.638 .745 .926 r
.64855 .61588 m .63656 .61896 L .63363 .61572 L p F P
0 g
s
.714 .797 .916 r
.62176 .62141 m .63363 .61572 L .63656 .61896 L p F P
0 g
s
.232 .254 .678 r
.80633 .77404 m .80465 .77198 L .80541 .77071 L closepath p F P
0 g
s
.26 .29 .703 r
.80307 .76299 m .80294 .76285 L p .80465 .77198 L F P
0 g
s
.26 .29 .703 r
.80465 .77198 m .80541 .77071 L .80307 .76299 L p F P
0 g
s
.003 0 .403 r
.80744 .82606 m .80733 .82121 L .80719 .82142 L closepath p F P
0 g
s
.637 .965 .881 r
.77609 .87453 m .77155 .8791 L p .76397 .88163 L F P
0 g
s
.664 .971 .814 r
.77155 .8791 m .77609 .87453 L .77839 .87407 L closepath p F P
0 g
s
0 0 0 r
.78978 .86256 m .78993 .86239 L .79 .86226 L closepath p F P
0 g
s
.595 .896 .613 r
.78993 .86239 m .78978 .86256 L .78253 .87034 L p F P
0 g
s
0 0 .192 r
.79984 .84598 m .8013 .8441 L .80303 .83777 L p F P
0 g
s
0 0 .176 r
.80665 .83312 m .80303 .83777 L .8013 .8441 L p F P
0 g
s
0 0 .317 r
.80303 .83777 m .80665 .83312 L .80745 .82704 L p F P
0 g
s
0 0 .032 r
.7991 .84932 m .8013 .8441 L .79984 .84598 L closepath p F P
0 g
s
0 0 .374 r
.80733 .82121 m .81042 .81667 L p .80749 .82699 L F P
0 g
s
0 0 .374 r
.80749 .82699 m .80744 .82606 L .80733 .82121 L p F P
0 g
s
.066 .009 .475 r
.80956 .81105 m .81042 .81667 L .80733 .82121 L p F P
0 g
s
.462 .471 .782 r
.64065 .8212 m .64094 .82091 L p .64548 .82927 L F P
0 g
s
.445 .46 .78 r
.64065 .8212 m .64049 .82076 L .64094 .82091 L closepath p F P
0 g
s
.427 .552 .879 r
.72396 .65634 m .72407 .65576 L p .73455 .66239 L F P
0 g
s
.435 .564 .885 r
.72396 .65634 m .72358 .65568 L .72407 .65576 L closepath p F P
0 g
s
0 0 0 r
.79359 .85791 m .78993 .86239 L p .79067 .86136 L F P
0 g
s
0 0 0 r
.79836 .85076 m .79359 .85791 L p .79067 .86136 L F P
0 g
s
0 0 0 r
.79359 .85791 m .79721 .85365 L .79886 .85018 L p F P
0 g
s
.716 .941 .631 r
.79359 .85791 m .79721 .85365 L p .79638 .85461 L F P
0 g
s
0 0 0 r
.79886 .85018 m .79836 .85076 L .79359 .85791 L p F P
0 g
s
.716 .941 .631 r
.78744 .86499 m .79359 .85791 L .79638 .85461 L F
.572 .84 .491 r
.78772 .86479 m .79359 .85791 L .78993 .86239 L closepath p F P
0 g
s
.595 .896 .613 r
.78772 .86479 m .78993 .86239 L p .78253 .87034 L F P
0 g
s
.449 .457 .775 r
.64094 .82091 m .64049 .82076 L .63738 .8125 L p F P
0 g
s
.508 .542 .826 r
.67345 .86009 m .66801 .85951 L .66499 .85307 L p F P
0 g
s
.399 .514 .858 r
.74474 .67408 m .75302 .67642 L .75177 .68083 L p F P
0 g
s
.396 .515 .861 r
.75302 .67642 m .74474 .67408 L .74363 .67195 L p F P
0 g
s
.2 .226 .663 r
.60883 .72231 m .60871 .72215 L .60877 .72205 L closepath p F P
0 g
s
.473 .485 .79 r
.64548 .82927 m .65583 .83222 L p .65077 .83742 L F P
0 g
s
.443 .462 .784 r
.64548 .82927 m .65583 .83222 L .65274 .82477 L p F P
0 g
s
.443 .462 .784 r
.65274 .82477 m .65062 .82407 L .64548 .82927 L p F P
0 g
s
.462 .471 .782 r
.64094 .82091 m .65062 .82407 L .64548 .82927 L p F P
0 g
s
.239 .252 .672 r
.60877 .72205 m .6114 .71732 L p .61254 .72669 L F P
0 g
s
.239 .252 .672 r
.61254 .72669 m .60883 .72231 L .60877 .72205 L p F P
0 g
s
.195 .212 .651 r
.60877 .72205 m .6114 .71732 L .60803 .71266 L p F P
0 g
s
.39 .498 .848 r
.75177 .68083 m .76029 .68347 L p .75974 .68821 L F P
0 g
s
.388 .503 .854 r
.75177 .68083 m .76029 .68347 L .75739 .67776 L p F P
0 g
s
.388 .503 .854 r
.75739 .67776 m .75302 .67642 L .75177 .68083 L p F P
0 g
s
.236 .251 .673 r
.61078 .72963 m .60883 .72231 L .61254 .72669 L closepath p F P
0 g
s
.485 .499 .797 r
.65077 .83742 m .65889 .83939 L p .65698 .84533 L F P
0 g
s
.464 .495 .805 r
.65889 .83939 m .65077 .83742 L .65587 .83231 L closepath p F P
0 g
s
.473 .485 .79 r
.65583 .83222 m .65587 .83231 L .65077 .83742 L p F P
0 g
s
.436 .464 .79 r
.64598 .81571 m .64094 .82091 L .65062 .82407 L p F P
0 g
s
.449 .457 .775 r
.63738 .8125 m .64598 .81571 L .64094 .82091 L p F P
0 g
s
.756 .993 .803 r
.77609 .87453 m .77839 .87407 L .78253 .87034 L p F P
0 g
s
.881 .964 .845 r
.61913 .61934 m .61952 .62306 L .61108 .63114 L p F P
0 g
s
.804 .876 .9 r
.61952 .62306 m .61913 .61934 L .62176 .62141 L closepath p F P
0 g
s
.433 .566 .888 r
.72407 .65576 m .72358 .65568 L .7207 .65074 L p F P
0 g
s
.756 .993 .803 r
.78253 .87034 m .78692 .86556 L p .77609 .87453 L F P
0 g
s
.595 .896 .613 r
.78253 .87034 m .78692 .86556 L .78772 .86479 L p F P
0 g
s
.48 .608 .901 r
.70254 .63966 m .69953 .63947 L .70021 .63589 L closepath p F P
0 g
s
.483 .618 .908 r
.69965 .63501 m .70021 .63589 L .69953 .63947 L p F P
0 g
s
.557 .699 .935 r
.65148 .6196 m .66356 .61794 L p .66405 .62226 L F P
0 g
s
.577 .701 .927 r
.66356 .61794 m .65148 .6196 L .64855 .61588 L p F P
0 g
s
.881 .964 .845 r
.61883 .61914 m .61913 .61934 L p .61108 .63114 L F P
0 g
s
.881 .964 .845 r
.61108 .63114 m .61172 .62669 L .61883 .61914 L p F P
0 g
s
.852 .981 .689 r
.61108 .63114 m .61172 .62669 L p .60751 .6339 L F P
0 g
s
.852 .981 .689 r
.60751 .6339 m .61008 .6325 L .61108 .63114 L p F P
0 g
s
.713 .862 .953 r
.61913 .61934 m .62176 .62141 L .63363 .61572 L p F P
0 g
s
.427 .552 .879 r
.72407 .65576 m .73562 .65797 L .73455 .66239 L p F P
0 g
s
.436 .562 .884 r
.72479 .65142 m .72407 .65576 L .73562 .65797 L p F P
0 g
s
.433 .566 .888 r
.7207 .65074 m .72479 .65142 L .72407 .65576 L p F P
0 g
s
0 0 .312 r
.60367 .66243 m .60338 .664 L .60414 .66934 L p F P
0 g
s
.428 .439 .769 r
.63738 .8125 m .63706 .81237 L .63725 .81217 L closepath p F P
0 g
s
.426 .436 .767 r
.63425 .80394 m .63368 .80368 L p .63706 .81237 L F P
0 g
s
.426 .436 .767 r
.63706 .81237 m .63725 .81217 L .63425 .80394 L p F P
0 g
s
.495 .512 .804 r
.65698 .84533 m .66195 .84634 L p .66429 .85295 L F P
0 g
s
.476 .509 .812 r
.66195 .84634 m .65698 .84533 L .66016 .84228 L closepath p F P
0 g
s
.485 .499 .797 r
.65889 .83939 m .66016 .84228 L .65698 .84533 L p F P
0 g
s
0 .012 .538 r
.60604 .6841 m .60451 .68868 L .60671 .69363 L p F P
0 g
s
0 0 .506 r
.60451 .68868 m .60604 .6841 L .60433 .67902 L p F P
0 g
s
.307 .323 .713 r
.61847 .75633 m .61644 .7546 L .61748 .75308 L closepath p F P
0 g
s
.301 .315 .708 r
.61527 .74565 m .61497 .74536 L p .61644 .7546 L F P
0 g
s
.301 .315 .708 r
.61644 .7546 m .61748 .75308 L .61527 .74565 L p F P
0 g
s
.25 .283 .701 r
.80307 .76299 m .80294 .76285 L .803 .76274 L closepath p F P
0 g
s
.278 .318 .725 r
.80294 .76285 m .803 .76274 L .80028 .75441 L p F P
0 g
s
.15 .132 .581 r
.81094 .79268 m .80889 .79581 L .81109 .80104 L p F P
0 g
s
.189 .182 .62 r
.80977 .78742 m .80909 .78617 L p .80889 .79581 L F P
0 g
s
.189 .182 .62 r
.80889 .79581 m .81094 .79268 L .80977 .78742 L p F P
0 g
s
.955 .944 .635 r
.60751 .63774 m .60751 .6339 L .61008 .6325 L closepath p F P
0 g
s
.228 .269 .697 r
.803 .76274 m .80519 .75837 L p .80712 .76748 L F P
0 g
s
.228 .269 .697 r
.80712 .76748 m .80307 .76299 L .803 .76274 L p F P
0 g
s
.247 .298 .719 r
.80054 .75389 m .80028 .75441 L .803 .76274 L p F P
0 g
s
.247 .298 .719 r
.803 .76274 m .80519 .75837 L .80054 .75389 L p F P
0 g
s
.369 .476 .837 r
.76675 .69678 m .76609 .69541 L .76708 .69578 L closepath p F P
0 g
s
.358 .459 .827 r
.76675 .69678 m .76708 .69578 L p .77359 .70358 L F P
0 g
s
.229 .269 .697 r
.80541 .77071 m .80307 .76299 L .80712 .76748 L closepath p F P
0 g
s
.437 .444 .769 r
.64598 .81571 m .63738 .8125 L .63725 .81217 L p F P
0 g
s
.437 .444 .769 r
.63725 .81217 m .64191 .80719 L p .64598 .81571 L F P
0 g
s
.419 .432 .767 r
.63725 .81217 m .63425 .80394 L .64191 .80719 L closepath p F P
0 g
s
.598 .767 .961 r
.72218 .88848 m .73435 .88596 L .73712 .8889 L p F P
0 g
s
.585 .74 .95 r
.73435 .88596 m .72218 .88848 L .71935 .88479 L p F P
0 g
s
.396 .515 .861 r
.74363 .67195 m .74426 .66926 L p .75302 .67642 L F P
0 g
s
.405 .529 .869 r
.74363 .67195 m .74185 .66866 L .74426 .66926 L closepath p F P
0 g
s
.274 .331 .74 r
.80028 .75441 m .79993 .75338 L .80054 .75389 L closepath p F P
0 g
s
.27 .279 .686 r
.61078 .72963 m .61254 .72669 L p .61371 .73604 L F P
0 g
s
.27 .279 .686 r
.61371 .73604 m .61206 .73431 L .61078 .72963 L p F P
0 g
s
.273 .331 .74 r
.80054 .75389 m .79993 .75338 L .79726 .74571 L p F P
0 g
s
.669 .876 .976 r
.75568 .88551 m .75193 .88716 L .74925 .88512 L p F P
0 g
s
.628 .849 .984 r
.73712 .8889 m .74925 .88512 L .75193 .88716 L p F P
0 g
s
.21 .239 .673 r
.80541 .77071 m .80712 .76748 L p .80843 .77674 L F P
0 g
s
.21 .239 .673 r
.80843 .77674 m .80633 .77404 L .80541 .77071 L p F P
0 g
s
.559 .684 .923 r
.66648 .62198 m .66405 .62226 L .6646 .61936 L closepath p F P
0 g
s
.557 .699 .935 r
.66356 .61794 m .6646 .61936 L .66405 .62226 L p F P
0 g
s
.41 .42 .759 r
.63112 .7951 m .63071 .79489 L p .63368 .80368 L F P
0 g
s
.41 .42 .759 r
.63368 .80368 m .63403 .80331 L .63112 .7951 L p F P
0 g
s
.413 .423 .761 r
.63425 .80394 m .63368 .80368 L .63403 .80331 L closepath p F P
0 g
s
.381 .486 .842 r
.76319 .6894 m .75974 .68821 L .76091 .6847 L closepath p F P
0 g
s
.39 .498 .848 r
.76029 .68347 m .76091 .6847 L .75974 .68821 L p F P
0 g
s
.367 .477 .839 r
.76708 .69578 m .76609 .69541 L .76319 .6894 L p F P
0 g
s
.266 .278 .687 r
.61289 .73732 m .61206 .73431 L .61371 .73604 L closepath p F P
0 g
s
.488 .523 .819 r
.66499 .85307 m .66429 .85295 L .66474 .85253 L closepath p F P
0 g
s
.495 .512 .804 r
.66195 .84634 m .66474 .85253 L .66429 .85295 L p F P
0 g
s
.211 .239 .673 r
.80753 .77836 m .80633 .77404 L .80843 .77674 L closepath p F P
0 g
s
.273 .331 .74 r
.79726 .74571 m .79755 .74509 L p .80054 .75389 L F P
0 g
s
.288 .355 .758 r
.79726 .74571 m .79684 .74457 L .79755 .74509 L closepath p F P
0 g
s
.491 .631 .915 r
.68458 .63018 m .68447 .63002 L .68459 .63002 L closepath p F P
0 g
s
.123 .169 .638 r
.61028 .70792 m .60803 .71266 L .6114 .71732 L p F P
0 g
s
.186 .197 .639 r
.60737 .70315 m .61028 .70792 L .60803 .71266 L p F P
0 g
s
.247 .302 .723 r
.80266 .74943 m .80054 .75389 L .80519 .75837 L p F P
0 g
s
.273 .331 .74 r
.79755 .74509 m .80266 .74943 L .80054 .75389 L p F P
0 g
s
.616 .815 .977 r
.74925 .88512 m .73712 .8889 L .73435 .88596 L p F P
0 g
s
.423 .43 .762 r
.64191 .80719 m .63425 .80394 L .63403 .80331 L p F P
0 g
s
.287 .355 .758 r
.79755 .74509 m .79684 .74457 L .79391 .73661 L p F P
0 g
s
.404 .416 .759 r
.63403 .80331 m .63112 .7951 L .6383 .79854 L closepath p F P
0 g
s
.423 .43 .762 r
.63403 .80331 m .6383 .79854 L p .64191 .80719 L F P
0 g
s
.273 .289 .694 r
.61371 .73604 m .61289 .73732 L .61512 .74512 L p F P
0 g
s
.271 .287 .694 r
.61497 .74536 m .61512 .74512 L .61289 .73732 L p F P
0 g
s
.488 .634 .918 r
.68459 .63002 m .68447 .63002 L .68157 .62572 L p F P
0 g
s
.488 .634 .918 r
.68157 .62572 m .68469 .62578 L .68459 .63002 L p F P
0 g
s
.488 .632 .917 r
.68459 .63002 m .69676 .63051 L .69386 .62606 L p F P
0 g
s
.488 .632 .917 r
.69386 .62606 m .68469 .62578 L .68459 .63002 L p F P
0 g
s
.508 .542 .826 r
.66499 .85307 m .67724 .8548 L p .67345 .86009 L F P
0 g
s
.484 .52 .819 r
.67422 .84853 m .67724 .8548 L .66499 .85307 L p F P
0 g
s
.484 .52 .819 r
.6698 .84774 m .67422 .84853 L p .66499 .85307 L F P
0 g
s
.484 .52 .819 r
.66499 .85307 m .66474 .85253 L .6698 .84774 L p F P
0 g
s
.396 .407 .754 r
.63112 .7951 m .63071 .79489 L .63095 .79461 L closepath p F P
0 g
s
.394 .403 .751 r
.63071 .79489 m .63095 .79461 L .62801 .78604 L p F P
0 g
s
.54 .623 .883 r
.70137 .87722 m .69442 .87736 L .69889 .87308 L closepath p F P
0 g
s
.547 .605 .863 r
.69844 .87233 m .69889 .87308 L .69442 .87736 L p F P
0 g
s
.547 .605 .863 r
.6862 .87216 m .69844 .87233 L p .69442 .87736 L F P
0 g
s
.177 .198 .644 r
.80843 .77674 m .80753 .77836 L .80939 .78569 L p F P
0 g
s
.214 .223 .652 r
.80909 .78617 m .80939 .78569 L .80753 .77836 L p F P
0 g
s
.28 .299 .702 r
.61527 .74565 m .61497 .74536 L .61512 .74512 L closepath p F P
0 g
s
.523 .584 .858 r
.69549 .86716 m .69844 .87233 L .6862 .87216 L p F P
0 g
s
.523 .584 .858 r
.68467 .86669 m .69549 .86716 L p .6862 .87216 L F P
0 g
s
.523 .584 .858 r
.6862 .87216 m .68372 .86755 L .68467 .86669 L p F P
0 g
s
.483 .518 .818 r
.66474 .85253 m .66195 .84634 L .6698 .84774 L closepath p F P
0 g
s
.457 .592 .899 r
.70254 .63966 m .71366 .64083 L .7129 .64521 L p F P
0 g
s
.458 .596 .901 r
.71366 .64083 m .70254 .63966 L .70021 .63589 L p F P
0 g
s
.358 .459 .827 r
.76708 .69578 m .77512 .69915 L .77359 .70358 L p F P
0 g
s
.363 .469 .834 r
.76841 .69138 m .76708 .69578 L .77512 .69915 L p F P
0 g
s
.367 .477 .839 r
.76319 .6894 m .76841 .69138 L .76708 .69578 L p F P
0 g
s
.669 .876 .976 r
.74925 .88512 m .76085 .88055 L .75568 .88551 L p F P
0 g
s
.684 .924 .971 r
.76135 .88034 m .76085 .88055 L .75568 .88551 L p F P
0 g
s
.684 .924 .971 r
.75568 .88551 m .76397 .88163 L .76135 .88034 L p F P
0 g
s
.575 .688 .918 r
.71935 .88479 m .71406 .88543 L .71741 .88208 L closepath p F P
0 g
s
.581 .666 .897 r
.7165 .88081 m .71741 .88208 L .71406 .88543 L p F P
0 g
s
.581 .666 .897 r
.70427 .88187 m .7165 .88081 L p .71406 .88543 L F P
0 g
s
.408 .414 .755 r
.6383 .79854 m .63112 .7951 L .63095 .79461 L p F P
0 g
s
.306 .316 .707 r
.61512 .74512 m .61813 .74045 L p .61984 .74965 L F P
0 g
s
.306 .316 .707 r
.61984 .74965 m .61527 .74565 L .61512 .74512 L p F P
0 g
s
.273 .289 .694 r
.61512 .74512 m .61813 .74045 L .61371 .73604 L p F P
0 g
s
.408 .414 .755 r
.63095 .79461 m .63508 .78978 L p .6383 .79854 L F P
0 g
s
.387 .399 .751 r
.62805 .78599 m .62801 .78604 L .63095 .79461 L p F P
0 g
s
.387 .399 .751 r
.63095 .79461 m .63508 .78978 L .62805 .78599 L p F P
0 g
s
.302 .316 .708 r
.61748 .75308 m .61527 .74565 L .61984 .74965 L closepath p F P
0 g
s
0 0 0 r
.8013 .8441 m .80483 .83949 L p .79886 .85018 L F P
0 g
s
0 0 0 r
.79886 .85018 m .7991 .84932 L .8013 .8441 L p F P
0 g
s
0 0 .176 r
.8013 .8441 m .80483 .83949 L .80665 .83312 L p F P
0 g
s
.264 .329 .743 r
.79954 .74064 m .79755 .74509 L .80266 .74943 L p F P
0 g
s
.287 .355 .758 r
.79398 .73645 m .79954 .74064 L .79755 .74509 L p F P
0 g
s
.287 .355 .758 r
.79391 .73661 m .79398 .73645 L p .79755 .74509 L F P
0 g
s
.546 .658 .909 r
.7165 .88081 m .70427 .88187 L .70137 .87722 L p F P
0 g
s
.525 .657 .919 r
.66648 .62198 m .67867 .62148 L .68157 .62572 L p F P
0 g
s
.517 .663 .928 r
.67576 .61728 m .67867 .62148 L .66648 .62198 L p F P
0 g
s
.517 .663 .928 r
.66451 .61788 m .67576 .61728 L p .66648 .62198 L F P
0 g
s
.517 .663 .928 r
.66648 .62198 m .6646 .61936 L .66451 .61788 L p F P
0 g
s
.059 .005 .475 r
.81267 .80646 m .80956 .81105 L .81042 .81667 L p F P
0 g
s
.113 .077 .534 r
.80956 .81105 m .81267 .80646 L .81109 .80104 L p F P
0 g
s
0 0 .491 r
.60531 .67494 m .60433 .67902 L .60604 .6841 L p F P
0 g
s
0 0 .425 r
.60499 .67286 m .60414 .66934 L p .60433 .67902 L F P
0 g
s
0 0 .425 r
.60433 .67902 m .60531 .67494 L .60499 .67286 L p F P
0 g
s
.879 .823 .348 r
.60751 .6339 m .60751 .63774 L .60577 .64379 L p F P
0 g
s
0 0 .36 r
.60449 .65948 m .60367 .66243 L .60431 .66848 L p F P
0 g
s
0 0 .237 r
.60367 .66243 m .60449 .65948 L .60433 .65398 L p F P
0 g
s
0 0 .312 r
.60414 .66934 m .60431 .66848 L .60367 .66243 L p F P
0 g
s
.035 0 .411 r
.80745 .82704 m .80749 .82699 L .80744 .82606 L closepath p F P
0 g
s
.177 .175 .617 r
.80977 .78742 m .80909 .78617 L .80939 .78569 L closepath p F P
0 g
s
.421 .543 .874 r
.73455 .66239 m .73897 .66335 L .73608 .65807 L p F P
0 g
s
.421 .543 .874 r
.73608 .65807 m .73562 .65797 L .73455 .66239 L p F P
0 g
s
.302 .377 .774 r
.79391 .73661 m .7938 .73633 L .79398 .73645 L closepath p F P
0 g
s
.351 .45 .822 r
.77512 .69915 m .77359 .70358 L .78128 .70709 L p F P
0 g
s
.35 .444 .817 r
.77956 .71155 m .78128 .70709 L .77359 .70358 L p F P
0 g
s
.403 .53 .871 r
.74426 .66926 m .74185 .66866 L .73897 .66335 L p F P
0 g
s
.3 .377 .775 r
.79398 .73645 m .7938 .73633 L .79079 .72863 L p F P
0 g
s
.33 .337 .717 r
.61748 .75308 m .61984 .74965 L p .62164 .75882 L F P
0 g
s
.33 .337 .717 r
.62164 .75882 m .61847 .75633 L .61748 .75308 L p F P
0 g
s
.384 .395 .748 r
.62801 .78604 m .62797 .78595 L .62805 .78599 L closepath p F P
0 g
s
.389 .394 .744 r
.62805 .78599 m .62797 .78595 L .6252 .77762 L p F P
0 g
s
0 0 .172 r
.60513 .64953 m .60433 .65398 L .60449 .65948 L p F P
0 g
s
.325 .337 .719 r
.61995 .76115 m .61847 .75633 L .62164 .75882 L closepath p F P
0 g
s
.367 .397 .76 r
.63217 .78093 m .62805 .78599 L .63508 .78978 L p F P
0 g
s
.389 .394 .744 r
.62571 .777 m .63217 .78093 L .62805 .78599 L p F P
0 g
s
.389 .394 .744 r
.6252 .77762 m .62571 .777 L p .62805 .78599 L F P
0 g
s
.279 .353 .76 r
.79583 .73202 m .79398 .73645 L .79954 .74064 L p F P
0 g
s
.3 .377 .775 r
.79079 .72863 m .79583 .73202 L .79398 .73645 L p F P
0 g
s
.351 .357 .726 r
.61995 .76115 m .62164 .75882 L p .62359 .76794 L F P
0 g
s
.351 .357 .726 r
.62359 .76794 m .62165 .76658 L .61995 .76115 L p F P
0 g
s
.366 .377 .739 r
.6252 .77762 m .62482 .77644 L .62571 .777 L closepath p F P
0 g
s
.371 .376 .735 r
.62571 .777 m .62482 .77644 L .62252 .76933 L p F P
0 g
s
.347 .358 .729 r
.62252 .76933 m .62165 .76658 L .62359 .76794 L closepath p F P
0 g
s
.371 .376 .735 r
.62252 .76933 m .62359 .76794 L p .62571 .777 L F P
0 g
s
.345 .432 .807 r
.78484 .71422 m .77956 .71155 L p .78496 .71969 L F P
0 g
s
.333 .424 .806 r
.77956 .71155 m .78484 .71422 L .78189 .7074 L p F P
0 g
s
.333 .424 .806 r
.78189 .7074 m .78128 .70709 L .77956 .71155 L p F P
0 g
s
.501 .554 .843 r
.68024 .86081 m .67345 .86009 L .67777 .85587 L closepath p F P
0 g
s
.508 .542 .826 r
.67724 .8548 m .67777 .85587 L .67345 .86009 L p F P
0 g
s
0 0 .312 r
.80749 .82699 m .80745 .82704 L .80665 .83312 L p F P
0 g
s
.333 .412 .793 r
.78781 .7213 m .78496 .71969 L p .78977 .72798 L F P
0 g
s
.333 .412 .793 r
.78977 .72798 m .79018 .72707 L .78781 .7213 L p F P
0 g
s
.31 .385 .777 r
.79079 .72863 m .78977 .72798 L .79018 .72707 L closepath p F P
0 g
s
0 0 .289 r
.81054 .8225 m .80749 .82699 L .8074 .83214 L p F P
0 g
s
0 0 .312 r
.80665 .83312 m .8074 .83214 L .80749 .82699 L p F P
0 g
s
0 0 .374 r
.81042 .81667 m .81054 .8225 L .80749 .82699 L p F P
0 g
s
.323 .406 .793 r
.78781 .7213 m .78496 .71969 L .78606 .71705 L closepath p F P
0 g
s
.345 .432 .807 r
.78496 .71969 m .78606 .71705 L .78484 .71422 L p F P
0 g
s
.15 .156 .61 r
.80939 .78569 m .81163 .78168 L p .81177 .79126 L F P
0 g
s
.15 .156 .61 r
.81177 .79126 m .80977 .78742 L .80939 .78569 L p F P
0 g
s
.177 .198 .644 r
.80939 .78569 m .81163 .78168 L .80843 .77674 L p F P
0 g
s
.064 .125 .617 r
.60918 .69852 m .60737 .70315 L .61028 .70792 L p F P
0 g
s
.051 .096 .589 r
.60737 .70315 m .60918 .69852 L .60671 .69363 L p F P
0 g
s
.432 .568 .891 r
.72479 .65142 m .7207 .65074 L .71781 .64584 L p F P
0 g
s
.218 .256 .688 r
.6165 .73121 m .61371 .73604 L .61813 .74045 L p F P
0 g
s
.27 .279 .686 r
.61254 .72669 m .6165 .73121 L .61371 .73604 L p F P
0 g
s
.455 .585 .894 r
.7129 .64521 m .71781 .64584 L .71492 .64098 L p F P
0 g
s
.455 .585 .894 r
.71492 .64098 m .71366 .64083 L .7129 .64521 L p F P
0 g
s
.638 .745 .926 r
.63363 .61572 m .64562 .61223 L .64855 .61588 L p F P
0 g
s
.654 .757 .925 r
.64562 .61223 m .63363 .61572 L .6307 .61259 L p F P
0 g
s
.713 .862 .953 r
.63363 .61572 m .6307 .61259 L p .61913 .61934 L F P
0 g
s
.151 .157 .61 r
.81094 .79268 m .80977 .78742 L .81177 .79126 L closepath p F P
0 g
s
.363 .476 .84 r
.76841 .69138 m .76319 .6894 L .76091 .6847 L p F P
0 g
s
.346 .377 .751 r
.62951 .772 m .62571 .777 L .63217 .78093 L p F P
0 g
s
.371 .376 .735 r
.62359 .76794 m .62951 .772 L .62571 .777 L p F P
0 g
s
.486 .514 .812 r
.6698 .84774 m .66195 .84634 L .66016 .84228 L p F P
0 g
s
.291 .372 .774 r
.79583 .73202 m .79079 .72863 L .79018 .72707 L p F P
0 g
s
0 0 0 r
.79836 .85076 m .79886 .85018 L .7991 .84932 L closepath p F P
0 g
s
.178 .201 .647 r
.81084 .77225 m .80843 .77674 L .81163 .78168 L p F P
0 g
s
.21 .239 .673 r
.80712 .76748 m .81084 .77225 L .80843 .77674 L p F P
0 g
s
.522 .582 .857 r
.68372 .86755 m .68323 .86663 L .68467 .86669 L closepath p F P
0 g
s
.637 .965 .881 r
.76397 .88163 m .77593 .87454 L .77609 .87453 L p F P
0 g
s
.647 .958 .933 r
.77593 .87454 m .76397 .88163 L .76135 .88034 L p F P
0 g
s
0 0 .401 r
.60499 .67286 m .60414 .66934 L .60431 .66848 L closepath p F P
0 g
s
.577 .701 .927 r
.64855 .61588 m .66065 .614 L .66356 .61794 L p F P
0 g
s
.586 .709 .928 r
.66065 .614 m .64855 .61588 L .64562 .61223 L p F P
0 g
s
.291 .372 .774 r
.79018 .72707 m .79155 .72355 L p .79583 .73202 L F P
0 g
s
.306 .395 .79 r
.79018 .72707 m .78781 .7213 L .79155 .72355 L closepath p F P
0 g
s
.396 .515 .861 r
.74426 .66926 m .75421 .67199 L .75302 .67642 L p F P
0 g
s
.403 .525 .867 r
.74519 .66489 m .74426 .66926 L .75421 .67199 L p F P
0 g
s
.403 .53 .871 r
.73897 .66335 m .74519 .66489 L .74426 .66926 L p F P
0 g
s
.585 .74 .95 r
.71935 .88479 m .73156 .8827 L .73435 .88596 L p F P
0 g
s
.581 .691 .917 r
.72874 .87916 m .73156 .8827 L .71935 .88479 L p F P
0 g
s
.581 .691 .917 r
.71925 .88044 m .72874 .87916 L p .71935 .88479 L F P
0 g
s
.581 .691 .917 r
.71935 .88479 m .71741 .88208 L .71925 .88044 L p F P
0 g
s
.525 .574 .847 r
.68467 .86669 m .68323 .86663 L .68024 .86081 L p F P
0 g
s
.458 .596 .901 r
.70021 .63589 m .70028 .63507 L p .71366 .64083 L F P
0 g
s
.464 .605 .906 r
.70021 .63589 m .69965 .63501 L .70028 .63507 L closepath p F P
0 g
s
.529 .673 .93 r
.6646 .61936 m .66356 .61794 L .66451 .61788 L closepath p F P
0 g
s
.104 .072 .533 r
.81221 .79934 m .81109 .80104 L .81267 .80646 L p F P
0 g
s
.15 .132 .581 r
.81109 .80104 m .81221 .79934 L .81094 .79268 L p F P
0 g
s
.781 .895 .925 r
.61883 .61914 m .61923 .61889 L .61913 .61934 L closepath p F P
0 g
s
.713 .862 .953 r
.6307 .61259 m .61923 .61889 L .61913 .61934 L p F P
0 g
s
.186 .236 .682 r
.61493 .72195 m .61254 .72669 L .6165 .73121 L p F P
0 g
s
.239 .252 .672 r
.6114 .71732 m .61493 .72195 L .61254 .72669 L p F P
0 g
s
0 .071 .583 r
.60807 .6891 m .60671 .69363 L .60918 .69852 L p F P
0 g
s
0 .012 .538 r
.60671 .69363 m .60807 .6891 L .60604 .6841 L p F P
0 g
s
.486 .514 .812 r
.66016 .84228 m .66234 .84013 L p .6698 .84774 L F P
0 g
s
.471 .504 .811 r
.66016 .84228 m .65889 .83939 L .66234 .84013 L closepath p F P
0 g
s
.323 .357 .742 r
.62707 .763 m .62359 .76794 L .62951 .772 L p F P
0 g
s
.351 .357 .726 r
.62164 .75882 m .62707 .763 L .62359 .76794 L p F P
0 g
s
.108 .103 .569 r
.81177 .79126 m .81094 .79268 L .81221 .79934 L p F P
0 g
s
.879 .823 .348 r
.60725 .63438 m .60751 .6339 L p .60577 .64379 L F P
0 g
s
.879 .823 .348 r
.60577 .64379 m .60595 .6395 L .60725 .63438 L p F P
0 g
s
.491 .64 .921 r
.68469 .62578 m .68157 .62572 L .67867 .62148 L p F P
0 g
s
.811 .91 .908 r
.61923 .61889 m .61883 .61914 L .61591 .61737 L p F P
0 g
s
.878 .905 .844 r
.61172 .62669 m .61883 .61914 L .61591 .61737 L p F P
0 g
s
0 0 .458 r
.60431 .66848 m .60531 .66481 L p .60544 .67453 L F P
0 g
s
0 0 .458 r
.60544 .67453 m .60499 .67286 L .60431 .66848 L p F P
0 g
s
0 0 .36 r
.60431 .66848 m .60531 .66481 L .60449 .65948 L p F P
0 g
s
.811 .91 .908 r
.61591 .61737 m .61981 .61442 L .61923 .61889 L p F P
0 g
s
.74 .82 .914 r
.62776 .60958 m .61981 .61442 L .61923 .61889 L p F P
0 g
s
.74 .82 .914 r
.61923 .61889 m .6307 .61259 L .62776 .60958 L p F P
0 g
s
0 0 0 r
.80185 .84617 m .79886 .85018 L .79721 .85365 L p F P
0 g
s
0 0 0 r
.80483 .83949 m .80185 .84617 L .79886 .85018 L p F P
0 g
s
.508 .567 .85 r
.68467 .86669 m .69549 .86716 L .69253 .8618 L p F P
0 g
s
.508 .567 .85 r
.69253 .8618 m .68993 .86159 L .68467 .86669 L p F P
0 g
s
.525 .574 .847 r
.68024 .86081 m .68993 .86159 L .68467 .86669 L p F P
0 g
s
.462 .608 .91 r
.70028 .63507 m .69965 .63501 L .69676 .63051 L p F P
0 g
s
.206 .241 .677 r
.80943 .76299 m .80712 .76748 L .81084 .77225 L p F P
0 g
s
.228 .269 .697 r
.80519 .75837 m .80943 .76299 L .80712 .76748 L p F P
0 g
s
.546 .658 .909 r
.70137 .87722 m .71362 .87654 L .7165 .88081 L p F P
0 g
s
.543 .624 .882 r
.71072 .87203 m .71362 .87654 L .70137 .87722 L p F P
0 g
s
.543 .624 .882 r
.69972 .8723 m .71072 .87203 L p .70137 .87722 L F P
0 g
s
.543 .624 .882 r
.70137 .87722 m .69889 .87308 L .69972 .8723 L p F P
0 g
s
.402 .531 .872 r
.74519 .66489 m .73897 .66335 L .73608 .65807 L p F P
0 g
s
.474 .501 .805 r
.66234 .84013 m .65889 .83939 L .65587 .83231 L p F P
0 g
s
.305 .395 .79 r
.79155 .72355 m .78781 .7213 L .78606 .71705 L p F P
0 g
s
.363 .476 .84 r
.76091 .6847 m .76116 .68376 L p .76841 .69138 L F P
0 g
s
.375 .492 .85 r
.76091 .6847 m .76029 .68347 L .76116 .68376 L closepath p F P
0 g
s
.387 .504 .855 r
.75302 .67642 m .75739 .67776 L .7545 .67208 L p F P
0 g
s
.387 .504 .855 r
.7545 .67208 m .75421 .67199 L .75302 .67642 L p F P
0 g
s
.638 .87 .985 r
.76085 .88055 m .74925 .88512 L .74653 .8827 L p F P
0 g
s
.616 .815 .977 r
.73435 .88596 m .74653 .8827 L .74925 .88512 L p F P
0 g
s
.459 .604 .908 r
.70028 .63507 m .71204 .63625 L .70914 .63162 L p F P
0 g
s
.459 .604 .908 r
.70914 .63162 m .70048 .63081 L .70028 .63507 L p F P
0 g
s
.462 .608 .91 r
.69676 .63051 m .70048 .63081 L .70028 .63507 L p F P
0 g
s
.458 .596 .901 r
.70028 .63507 m .71204 .63625 L p .71366 .64083 L F P
0 g
s
.603 .784 .967 r
.74653 .8827 m .73435 .88596 L .73156 .8827 L p F P
0 g
s
.852 .981 .689 r
.61172 .62669 m .60758 .63347 L .60751 .6339 L p F P
0 g
s
.934 .961 .659 r
.61173 .62241 m .61172 .62669 L .60758 .63347 L p F P
0 g
s
.878 .905 .844 r
.61591 .61737 m .61173 .62241 L .61172 .62669 L p F P
0 g
s
.719 .988 .871 r
.77593 .87454 m .77635 .87423 L .77609 .87453 L closepath p F P
0 g
s
.756 .993 .803 r
.78692 .86556 m .77635 .87423 L .77609 .87453 L p F P
0 g
s
.436 .562 .884 r
.7332 .65299 m .72479 .65142 L p .73562 .65797 L F P
0 g
s
.426 .561 .887 r
.72479 .65142 m .7332 .65299 L .73031 .64796 L p F P
0 g
s
.426 .561 .887 r
.73031 .64796 m .72545 .64708 L .72479 .65142 L p F P
0 g
s
.432 .568 .891 r
.71781 .64584 m .72545 .64708 L .72479 .65142 L p F P
0 g
s
0 0 .395 r
.81356 .81208 m .81042 .81667 L .81054 .8225 L p F P
0 g
s
.059 .005 .475 r
.81042 .81667 m .81356 .81208 L .81267 .80646 L p F P
0 g
s
.297 .334 .732 r
.62478 .75395 m .62164 .75882 L .62707 .763 L p F P
0 g
s
.33 .337 .717 r
.61984 .74965 m .62478 .75395 L .62164 .75882 L p F P
0 g
s
.527 .677 .933 r
.66451 .61788 m .66356 .61794 L .66065 .614 L p F P
0 g
s
.716 .941 .631 r
.78744 .86499 m .78772 .86479 L .79359 .85791 L p F P
0 g
s
0 0 .178 r
.8074 .83214 m .80665 .83312 L .80483 .83949 L p F P
0 g
s
0 0 .298 r
.60528 .65504 m .60449 .65948 L .60531 .66481 L p F P
0 g
s
0 0 .172 r
.60449 .65948 m .60528 .65504 L .60513 .64953 L p F P
0 g
s
.372 .493 .852 r
.76116 .68376 m .76029 .68347 L .75739 .67776 L p F P
0 g
s
.143 .199 .662 r
.61339 .71266 m .6114 .71732 L .61493 .72195 L p F P
0 g
s
.123 .169 .638 r
.6114 .71732 m .61339 .71266 L .61028 .70792 L p F P
0 g
s
.729 .98 .914 r
.77635 .87423 m .77593 .87454 L .77339 .87407 L p F P
0 g
s
.647 .958 .933 r
.76135 .88034 m .77339 .87407 L .77593 .87454 L p F P
0 g
s
.729 .98 .914 r
.77339 .87407 m .7802 .86959 L .77635 .87423 L p F P
0 g
s
.725 .989 .865 r
.78744 .86499 m .78692 .86556 L .77635 .87423 L p F P
0 g
s
.725 .989 .865 r
.78532 .8658 m .78744 .86499 L p .77635 .87423 L F P
0 g
s
.725 .989 .865 r
.77635 .87423 m .7802 .86959 L .78532 .8658 L p F P
0 g
s
0 0 .531 r
.60661 .68175 m .60604 .6841 L .60807 .6891 L p F P
0 g
s
0 0 .491 r
.60604 .6841 m .60661 .68175 L .60531 .67494 L p F P
0 g
s
.432 .571 .893 r
.72545 .64708 m .71781 .64584 L .71492 .64098 L p F P
0 g
s
.531 .678 .932 r
.66451 .61788 m .67576 .61728 L .67284 .61314 L p F P
0 g
s
.531 .678 .932 r
.67284 .61314 m .66414 .61374 L .66451 .61788 L p F P
0 g
s
.527 .677 .933 r
.66065 .614 m .66414 .61374 L .66451 .61788 L p F P
0 g
s
.305 .395 .79 r
.78606 .71705 m .78671 .71523 L p .79155 .72355 L F P
0 g
s
.319 .416 .804 r
.78606 .71705 m .78484 .71422 L .78671 .71523 L closepath p F P
0 g
s
.23 .278 .706 r
.80739 .7539 m .80519 .75837 L .80943 .76299 L p F P
0 g
s
.247 .302 .723 r
.80519 .75837 m .80739 .7539 L .80266 .74943 L p F P
0 g
s
.108 .103 .569 r
.81221 .79934 m .81386 .79652 L .81177 .79126 L p F P
0 g
s
.105 .103 .571 r
.81431 .78677 m .81177 .79126 L .81386 .79652 L p F P
0 g
s
.15 .156 .61 r
.81163 .78168 m .81431 .78677 L .81177 .79126 L p F P
0 g
s
0 0 .463 r
.60531 .67494 m .60499 .67286 L .60544 .67453 L closepath p F P
0 g
s
.363 .476 .84 r
.76116 .68376 m .76968 .68698 L .76841 .69138 L p F P
0 g
s
.369 .486 .847 r
.76222 .6794 m .76116 .68376 L .76968 .68698 L p F P
0 g
s
.372 .493 .852 r
.75739 .67776 m .76222 .6794 L .76116 .68376 L p F P
0 g
s
.602 .901 .62 r
.78692 .86556 m .78744 .86499 L .78772 .86479 L closepath p F P
0 g
s
.58 .69 .916 r
.71741 .88208 m .7165 .88081 L .71925 .88044 L closepath p F P
0 g
s
.492 .637 .918 r
.68469 .62578 m .69386 .62606 L .69095 .62165 L p F P
0 g
s
.492 .637 .918 r
.69095 .62165 m .68477 .62153 L .68469 .62578 L p F P
0 g
s
.491 .64 .921 r
.67867 .62148 m .68477 .62153 L .68469 .62578 L p F P
0 g
s
.512 .56 .842 r
.68993 .86159 m .68024 .86081 L .67777 .85587 L p F P
0 g
s
.057 .039 .519 r
.81386 .79652 m .81221 .79934 L .81319 .80568 L p F P
0 g
s
.104 .072 .533 r
.81267 .80646 m .81319 .80568 L .81221 .79934 L p F P
0 g
s
.438 .466 .792 r
.65274 .82477 m .65062 .82407 L .6519 .82268 L closepath p F P
0 g
s
.436 .464 .79 r
.64965 .81709 m .64598 .81571 L p .65062 .82407 L F P
0 g
s
.436 .464 .79 r
.65062 .82407 m .6519 .82268 L .64965 .81709 L p F P
0 g
s
.269 .31 .72 r
.62263 .74486 m .61984 .74965 L .62478 .75395 L p F P
0 g
s
.306 .316 .707 r
.61813 .74045 m .62263 .74486 L .61984 .74965 L p F P
0 g
s
.863 .871 .429 r
.60725 .63438 m .60758 .63347 L .60751 .6339 L closepath p F P
0 g
s
.474 .501 .805 r
.65587 .83231 m .65593 .83225 L p .66234 .84013 L F P
0 g
s
.459 .49 .804 r
.65587 .83231 m .65583 .83222 L .65593 .83225 L closepath p F P
0 g
s
.463 .486 .797 r
.65593 .83225 m .65583 .83222 L .65274 .82477 L p F P
0 g
s
.474 .501 .805 r
.65593 .83225 m .66702 .83509 L .66234 .84013 L p F P
0 g
s
.449 .494 .814 r
.66074 .82714 m .65593 .83225 L .66702 .83509 L p F P
0 g
s
.463 .486 .797 r
.65274 .82477 m .66074 .82714 L .65593 .83225 L p F P
0 g
s
.423 .451 .785 r
.64965 .81709 m .64598 .81571 L .64814 .81325 L closepath p F P
0 g
s
.437 .444 .769 r
.64655 .80917 m .64814 .81325 L .64598 .81571 L p F P
0 g
s
.437 .444 .769 r
.64191 .80719 m .64655 .80917 L p .64598 .81571 L F P
0 g
s
.318 .416 .805 r
.78671 .71523 m .78484 .71422 L .78189 .7074 L p F P
0 g
s
0 0 .151 r
.80983 .82857 m .8074 .83214 L .80688 .83683 L p F P
0 g
s
0 0 .289 r
.8074 .83214 m .80983 .82857 L .81054 .8225 L p F P
0 g
s
0 0 .178 r
.80483 .83949 m .80688 .83683 L .8074 .83214 L p F P
0 g
s
.248 .307 .728 r
.80474 .74496 m .80266 .74943 L .80739 .7539 L p F P
0 g
s
.264 .329 .743 r
.80266 .74943 m .80474 .74496 L .79954 .74064 L p F P
0 g
s
0 0 .521 r
.60544 .67453 m .60531 .67494 L .60661 .68175 L p F P
0 g
s
.407 .436 .778 r
.64655 .80917 m .64191 .80719 L .64456 .804 L closepath p F P
0 g
s
.423 .43 .762 r
.64343 .80102 m .64456 .804 L .64191 .80719 L p F P
0 g
s
.423 .43 .762 r
.6383 .79854 m .64343 .80102 L p .64191 .80719 L F P
0 g
s
.092 .157 .639 r
.61181 .70359 m .61028 .70792 L .61339 .71266 L p F P
0 g
s
.064 .125 .617 r
.61164 .70293 m .60918 .69852 L p .61028 .70792 L F P
0 g
s
.064 .125 .617 r
.61028 .70792 m .61181 .70359 L .61164 .70293 L p F P
0 g
s
.363 .469 .834 r
.77603 .69449 m .76841 .69138 L p .77512 .69915 L F P
0 g
s
.35 .463 .834 r
.76841 .69138 m .77603 .69449 L .77312 .68839 L p F P
0 g
s
.35 .463 .834 r
.77312 .68839 m .76968 .68698 L .76841 .69138 L p F P
0 g
s
.778 .821 .347 r
.60758 .63347 m .60801 .62908 L p .60587 .63738 L F P
0 g
s
.778 .821 .347 r
.60587 .63738 m .60725 .63438 L .60758 .63347 L p F P
0 g
s
.934 .961 .659 r
.60758 .63347 m .60801 .62908 L .61173 .62241 L p F P
0 g
s
.704 .971 .745 r
.78532 .8658 m .79062 .86095 L .78744 .86499 L closepath p F P
0 g
s
.716 .941 .631 r
.79721 .85365 m .797 .85393 L p .78744 .86499 L F P
0 g
s
.716 .941 .631 r
.797 .85393 m .79062 .86095 L .78744 .86499 L p F P
0 g
s
.486 .514 .812 r
.66234 .84013 m .67119 .84206 L p .6698 .84774 L F P
0 g
s
.454 .493 .809 r
.66234 .84013 m .67119 .84206 L .66814 .83538 L p F P
0 g
s
.454 .493 .809 r
.66814 .83538 m .66702 .83509 L .66234 .84013 L p F P
0 g
s
.654 .757 .925 r
.6307 .61259 m .64269 .60866 L .64562 .61223 L p F P
0 g
s
.671 .768 .923 r
.64269 .60866 m .6307 .61259 L .62776 .60958 L p F P
0 g
s
.542 .622 .881 r
.69889 .87308 m .69844 .87233 L .69972 .8723 L closepath p F P
0 g
s
.584 .676 .903 r
.71925 .88044 m .7165 .88081 L .71362 .87654 L p F P
0 g
s
0 0 .521 r
.60661 .68175 m .60731 .67957 L .60544 .67453 L p F P
0 g
s
0 0 .486 r
.60664 .67 m .60544 .67453 L .60731 .67957 L p F P
0 g
s
0 0 .458 r
.60531 .66481 m .60664 .67 L .60544 .67453 L p F P
0 g
s
.926 .845 .4 r
.60595 .6395 m .60587 .63738 L .60725 .63438 L closepath p F P
0 g
s
.419 .545 .877 r
.73608 .65807 m .73562 .65797 L .73573 .65743 L closepath p F P
0 g
s
.436 .562 .884 r
.73562 .65797 m .73573 .65743 L .7332 .65299 L p F P
0 g
s
.389 .419 .771 r
.64343 .80102 m .6383 .79854 L .64115 .79492 L closepath p F P
0 g
s
.408 .414 .755 r
.6403 .79263 m .64115 .79492 L .6383 .79854 L p F P
0 g
s
.408 .414 .755 r
.63508 .78978 m .6403 .79263 L p .6383 .79854 L F P
0 g
s
.265 .334 .748 r
.80148 .73619 m .79954 .74064 L .80474 .74496 L p F P
0 g
s
.279 .353 .76 r
.79954 .74064 m .80148 .73619 L .79583 .73202 L p F P
0 g
s
.586 .709 .928 r
.64562 .61223 m .65772 .61012 L .66065 .614 L p F P
0 g
s
.595 .718 .93 r
.65772 .61012 m .64562 .61223 L .64269 .60866 L p F P
0 g
s
.351 .45 .822 r
.77896 .7009 m .77512 .69915 L p .78128 .70709 L F P
0 g
s
.341 .445 .822 r
.77896 .7009 m .77512 .69915 L .7764 .69528 L closepath p F P
0 g
s
.363 .469 .834 r
.77512 .69915 m .7764 .69528 L .77603 .69449 L p F P
0 g
s
.237 .283 .708 r
.62057 .73573 m .61813 .74045 L .62263 .74486 L p F P
0 g
s
.218 .256 .688 r
.61813 .74045 m .62057 .73573 L .6165 .73121 L p F P
0 g
s
.402 .531 .872 r
.73608 .65807 m .74605 .66053 L .74519 .66489 L p F P
0 g
s
.399 .533 .875 r
.74605 .66053 m .73608 .65807 L .73573 .65743 L p F P
0 g
s
.546 .612 .87 r
.69972 .8723 m .69844 .87233 L .69549 .86716 L p F P
0 g
s
.146 .159 .614 r
.8141 .77718 m .81163 .78168 L .81431 .78677 L p F P
0 g
s
.178 .201 .647 r
.81163 .78168 m .8141 .77718 L .81084 .77225 L p F P
0 g
s
.281 .359 .766 r
.79763 .72758 m .79583 .73202 L .80148 .73619 L p F P
0 g
s
.291 .372 .774 r
.79155 .72355 m .79763 .72758 L .79583 .73202 L p F P
0 g
s
.048 0 .472 r
.81319 .80568 m .81267 .80646 L .81356 .81208 L p F P
0 g
s
.45 .474 .792 r
.66074 .82714 m .65274 .82477 L .6519 .82268 L p F P
0 g
s
0 0 0 r
.80688 .83683 m .80483 .83949 L .80185 .84617 L p F P
0 g
s
.476 .525 .828 r
.67422 .84853 m .6698 .84774 L .67251 .84489 L closepath p F P
0 g
s
.486 .514 .812 r
.67119 .84206 m .67251 .84489 L .6698 .84774 L p F P
0 g
s
.329 .425 .808 r
.78189 .7074 m .78128 .70709 L .7815 .70649 L closepath p F P
0 g
s
.351 .45 .822 r
.78128 .70709 m .7815 .70649 L .77896 .7009 L p F P
0 g
s
.399 .533 .875 r
.73573 .65743 m .73625 .65365 L p .74605 .66053 L F P
0 g
s
.409 .547 .883 r
.73573 .65743 m .7332 .65299 L .73625 .65365 L closepath p F P
0 g
s
.463 .612 .912 r
.70048 .63081 m .69676 .63051 L .69386 .62606 L p F P
0 g
s
.371 .401 .763 r
.6403 .79263 m .63508 .78978 L .63789 .78599 L closepath p F P
0 g
s
.367 .397 .76 r
.63716 .78398 m .63217 .78093 L p .63508 .78978 L F P
0 g
s
.367 .397 .76 r
.63508 .78978 m .63789 .78599 L .63716 .78398 L p F P
0 g
s
.494 .645 .924 r
.68477 .62153 m .67867 .62148 L .67576 .61728 L p F P
0 g
s
.369 .493 .853 r
.76222 .6794 m .75739 .67776 L .7545 .67208 L p F P
0 g
s
.453 .587 .896 r
.71492 .64098 m .71366 .64083 L .7139 .63927 L closepath p F P
0 g
s
.458 .596 .901 r
.71204 .63625 m .7139 .63927 L .71366 .64083 L p F P
0 g
s
.295 .383 .783 r
.79319 .71913 m .79155 .72355 L .79763 .72758 L p F P
0 g
s
.305 .395 .79 r
.78671 .71523 m .79319 .71913 L .79155 .72355 L p F P
0 g
s
.303 .398 .795 r
.78819 .71084 m .78671 .71523 L .79319 .71913 L p F P
0 g
s
.318 .416 .805 r
.78189 .7074 m .78819 .71084 L .78671 .71523 L p F P
0 g
s
.512 .56 .842 r
.67777 .85587 m .6787 .85497 L p .68993 .86159 L F P
0 g
s
.499 .552 .841 r
.67777 .85587 m .67724 .8548 L .6787 .85497 L closepath p F P
0 g
s
.45 .474 .792 r
.6519 .82268 m .65523 .81899 L p .66074 .82714 L F P
0 g
s
.433 .462 .79 r
.6519 .82268 m .64965 .81709 L .65523 .81899 L closepath p F P
0 g
s
.528 .605 .874 r
.69972 .8723 m .71072 .87203 L .7078 .86732 L p F P
0 g
s
.528 .605 .874 r
.7078 .86732 m .70479 .86728 L .69972 .8723 L p F P
0 g
s
.546 .612 .87 r
.69549 .86716 m .70479 .86728 L .69972 .8723 L p F P
0 g
s
.638 .87 .985 r
.76119 .88023 m .76085 .88055 L p .74653 .8827 L F P
0 g
s
.673 .89 .977 r
.76085 .88055 m .76119 .88023 L .76135 .88034 L closepath p F P
0 g
s
.025 .099 .605 r
.61164 .70293 m .60918 .69852 L .6099 .69611 L closepath p F P
0 g
s
0 .071 .583 r
.60836 .6897 m .60807 .6891 L p .60918 .69852 L F P
0 g
s
0 .071 .583 r
.60918 .69852 m .6099 .69611 L .60836 .6897 L p F P
0 g
s
.31 .413 .806 r
.78819 .71084 m .78189 .7074 L .7815 .70649 L p F P
0 g
s
.727 .904 .957 r
.76119 .88023 m .76135 .88034 L .77339 .87407 L p F P
0 g
s
.564 .672 .911 r
.71925 .88044 m .72874 .87916 L .7259 .87535 L p F P
0 g
s
.564 .672 .911 r
.7259 .87535 m .72399 .87553 L .71925 .88044 L p F P
0 g
s
.584 .676 .903 r
.71362 .87654 m .72399 .87553 L .71925 .88044 L p F P
0 g
s
0 0 .395 r
.81054 .8225 m .81367 .81793 L .81356 .81208 L p F P
0 g
s
0 0 .286 r
.81367 .81793 m .81054 .8225 L .80983 .82857 L p F P
0 g
s
.503 .546 .833 r
.6787 .85497 m .67724 .8548 L .67422 .84853 L p F P
0 g
s
0 .039 .556 r
.60731 .67957 m .60661 .68175 L .60815 .68881 L p F P
0 g
s
0 0 .531 r
.60807 .6891 m .60815 .68881 L .60661 .68175 L p F P
0 g
s
.31 .413 .806 r
.7815 .70649 m .78264 .7027 L p .78819 .71084 L F P
0 g
s
.324 .434 .819 r
.7815 .70649 m .77896 .7009 L .78264 .7027 L closepath p F P
0 g
s
.69 .885 .97 r
.75869 .87851 m .7646 .87594 L .76119 .88023 L closepath p F P
0 g
s
.727 .904 .957 r
.77081 .87307 m .7646 .87594 L .76119 .88023 L p F P
0 g
s
.727 .904 .957 r
.77339 .87407 m .77081 .87307 L p .76119 .88023 L F P
0 g
s
.638 .87 .985 r
.74653 .8827 m .75869 .87851 L .76119 .88023 L p F P
0 g
s
.35 .383 .755 r
.63716 .78398 m .63217 .78093 L .63476 .77721 L closepath p F P
0 g
s
.346 .377 .751 r
.63401 .77507 m .62951 .772 L p .63217 .78093 L F P
0 g
s
.346 .377 .751 r
.63217 .78093 m .63476 .77721 L .63401 .77507 L p F P
0 g
s
.432 .571 .893 r
.71492 .64098 m .72606 .64274 L .72545 .64708 L p F P
0 g
s
.431 .574 .896 r
.72606 .64274 m .71492 .64098 L .7139 .63927 L p F P
0 g
s
.2 .252 .693 r
.61842 .72701 m .6165 .73121 L .62057 .73573 L p F P
0 g
s
.186 .236 .682 r
.6181 .72594 m .61493 .72195 L p .6165 .73121 L F P
0 g
s
.186 .236 .682 r
.6165 .73121 m .61842 .72701 L .6181 .72594 L p F P
0 g
s
0 0 .454 r
.81537 .80197 m .81319 .80568 L .81384 .81165 L p F P
0 g
s
.057 .039 .519 r
.81319 .80568 m .81537 .80197 L .81386 .79652 L p F P
0 g
s
.048 0 .472 r
.81356 .81208 m .81384 .81165 L .81319 .80568 L p F P
0 g
s
.603 .784 .967 r
.73156 .8827 m .74378 .87993 L .74653 .8827 L p F P
0 g
s
.59 .755 .957 r
.74378 .87993 m .73156 .8827 L .72874 .87916 L p F P
0 g
s
.393 .522 .868 r
.74519 .66489 m .75161 .66664 L .74872 .66125 L p F P
0 g
s
.393 .522 .868 r
.74872 .66125 m .74605 .66053 L .74519 .66489 L p F P
0 g
s
.403 .525 .867 r
.75161 .66664 m .74519 .66489 L p .75421 .67199 L F P
0 g
s
.533 .685 .936 r
.66414 .61374 m .66065 .614 L .65772 .61012 L p F P
0 g
s
0 0 .38 r
.60605 .66039 m .60531 .66481 L .60664 .67 L p F P
0 g
s
0 0 .298 r
.60531 .66481 m .60605 .66039 L .60528 .65504 L p F P
0 g
s
.436 .459 .786 r
.65523 .81899 m .64965 .81709 L .64814 .81325 L p F P
0 g
s
.174 .201 .649 r
.81323 .76776 m .81084 .77225 L .8141 .77718 L p F P
0 g
s
.206 .241 .677 r
.81084 .77225 m .81323 .76776 L .80943 .76299 L p F P
0 g
s
.626 .836 .981 r
.75869 .87851 m .74653 .8827 L .74378 .87993 L p F P
0 g
s
.512 .56 .842 r
.6787 .85497 m .68955 .85619 L p .68993 .86159 L F P
0 g
s
.484 .537 .836 r
.6787 .85497 m .68955 .85619 L .68655 .85039 L p F P
0 g
s
.484 .537 .836 r
.68655 .85039 m .68355 .84993 L .6787 .85497 L p F P
0 g
s
.503 .546 .833 r
.67422 .84853 m .68355 .84993 L .6787 .85497 L p F P
0 g
s
.839 .905 .883 r
.61981 .61442 m .61591 .61737 L .61299 .6159 L p F P
0 g
s
.903 .915 .819 r
.61173 .62241 m .61591 .61737 L .61299 .6159 L p F P
0 g
s
.328 .363 .746 r
.63401 .77507 m .62951 .772 L .63176 .76855 L closepath p F P
0 g
s
.323 .357 .742 r
.63085 .76589 m .62707 .763 L p .62951 .772 L F P
0 g
s
.323 .357 .742 r
.62951 .772 m .63176 .76855 L .63085 .76589 L p F P
0 g
s
.828 .708 .174 r
.60587 .63738 m .60595 .6395 L .60538 .64522 L p F P
0 g
s
0 .042 .569 r
.60836 .6897 m .60807 .6891 L .60815 .68881 L closepath p F P
0 g
s
.436 .459 .786 r
.64814 .81325 m .65037 .81066 L p .65523 .81899 L F P
0 g
s
.418 .447 .783 r
.64814 .81325 m .64655 .80917 L .65037 .81066 L closepath p F P
0 g
s
.431 .574 .896 r
.7139 .63927 m .71406 .63653 L p .72606 .64274 L F P
0 g
s
.439 .585 .901 r
.7139 .63927 m .71204 .63625 L .71406 .63653 L closepath p F P
0 g
s
.839 .905 .883 r
.61299 .6159 m .61959 .61019 L .61981 .61442 L p F P
0 g
s
.761 .832 .907 r
.62481 .60667 m .61959 .61019 L .61981 .61442 L p F P
0 g
s
.761 .832 .907 r
.61981 .61442 m .62776 .60958 L .62481 .60667 L p F P
0 g
s
.056 .04 .52 r
.81644 .79204 m .81386 .79652 L .81537 .80197 L p F P
0 g
s
.105 .103 .571 r
.81386 .79652 m .81644 .79204 L .81431 .78677 L p F P
0 g
s
0 0 0 r
.80539 .84155 m .80185 .84617 L .79753 .85322 L p F P
0 g
s
0 0 0 r
.80609 .84011 m .80688 .83683 L p .80185 .84617 L F P
0 g
s
0 0 0 r
.80185 .84617 m .80539 .84155 L .80609 .84011 L p F P
0 g
s
0 0 0 r
.79721 .85365 m .79753 .85322 L .80185 .84617 L p F P
0 g
s
.156 .215 .674 r
.6181 .72594 m .61493 .72195 L .61609 .71907 L closepath p F P
0 g
s
.143 .199 .662 r
.61488 .71477 m .61339 .71266 L p .61493 .72195 L F P
0 g
s
.143 .199 .662 r
.61493 .72195 m .61609 .71907 L .61488 .71477 L p F P
0 g
s
.046 .105 .601 r
.60815 .68881 m .6095 .68453 L p .61068 .69395 L F P
0 g
s
.046 .105 .601 r
.61068 .69395 m .60836 .6897 L .60815 .68881 L p F P
0 g
s
0 .039 .556 r
.60815 .68881 m .6095 .68453 L .60731 .67957 L p F P
0 g
s
.461 .608 .91 r
.70048 .63081 m .70914 .63162 L .70625 .62703 L p F P
0 g
s
.461 .608 .91 r
.70625 .62703 m .70064 .62655 L .70048 .63081 L p F P
0 g
s
.463 .612 .912 r
.69386 .62606 m .70064 .62655 L .70048 .63081 L p F P
0 g
s
.052 .108 .602 r
.6099 .69611 m .60836 .6897 L .61068 .69395 L closepath p F P
0 g
s
.959 .945 .66 r
.61125 .61827 m .61173 .62241 L .60801 .62908 L p F P
0 g
s
.903 .915 .819 r
.61299 .6159 m .61125 .61827 L .61173 .62241 L p F P
0 g
s
.422 .445 .779 r
.65037 .81066 m .64655 .80917 L .64456 .804 L p F P
0 g
s
.532 .597 .865 r
.70479 .86728 m .69549 .86716 L .69253 .8618 L p F P
0 g
s
.384 .505 .858 r
.7545 .67208 m .75421 .67199 L .75429 .67168 L closepath p F P
0 g
s
.403 .525 .867 r
.75421 .67199 m .75429 .67168 L .75161 .66664 L p F P
0 g
s
.427 .564 .889 r
.72545 .64708 m .73031 .64796 L .72743 .64298 L p F P
0 g
s
.427 .564 .889 r
.72743 .64298 m .72606 .64274 L .72545 .64708 L p F P
0 g
s
.323 .434 .819 r
.78264 .7027 m .77896 .7009 L .7764 .69528 L p F P
0 g
s
.303 .341 .736 r
.63085 .76589 m .62707 .763 L .62887 .76001 L closepath p F P
0 g
s
.297 .334 .732 r
.62768 .75641 m .62478 .75395 L p .62707 .763 L F P
0 g
s
.297 .334 .732 r
.62707 .763 m .62887 .76001 L .62768 .75641 L p F P
0 g
s
.199 .239 .679 r
.81115 .75959 m .80943 .76299 L .81323 .76776 L p F P
0 g
s
.23 .278 .706 r
.81038 .75712 m .80739 .7539 L p .80943 .76299 L F P
0 g
s
.23 .278 .706 r
.80943 .76299 m .81115 .75959 L .81038 .75712 L p F P
0 g
s
.569 .657 .896 r
.72399 .87553 m .71362 .87654 L .71072 .87203 L p F P
0 g
s
.406 .548 .885 r
.73625 .65365 m .7332 .65299 L .73031 .64796 L p F P
0 g
s
.369 .493 .853 r
.7545 .67208 m .7632 .67504 L .76222 .6794 L p F P
0 g
s
.364 .493 .856 r
.7632 .67504 m .7545 .67208 L .75429 .67168 L p F P
0 g
s
.489 .532 .828 r
.68355 .84993 m .67422 .84853 L .67251 .84489 L p F P
0 g
s
.539 .684 .932 r
.66414 .61374 m .67284 .61314 L .66992 .60905 L p F P
0 g
s
.539 .684 .932 r
.66992 .60905 m .66379 .60957 L .66414 .61374 L p F P
0 g
s
.533 .685 .936 r
.65772 .61012 m .66379 .60957 L .66414 .61374 L p F P
0 g
s
.364 .493 .856 r
.75429 .67168 m .755 .66767 L p .7632 .67504 L F P
0 g
s
.376 .509 .865 r
.75429 .67168 m .75161 .66664 L .755 .66767 L closepath p F P
0 g
s
0 0 .224 r
.60555 .65074 m .60528 .65504 L .60605 .66039 L p F P
0 g
s
.664 .971 .903 r
.7802 .86959 m .77339 .87407 L .77081 .87307 L p F P
0 g
s
.422 .445 .779 r
.64456 .804 m .64606 .80218 L p .65037 .81066 L F P
0 g
s
.403 .431 .776 r
.64456 .804 m .64343 .80102 L .64606 .80218 L closepath p F P
0 g
s
.57 .812 .428 r
.797 .85393 m .79753 .85322 L .79721 .85365 L closepath p F P
0 g
s
0 0 .52 r
.60836 .67509 m .60731 .67957 L .6095 .68453 L p F P
0 g
s
0 0 .486 r
.60731 .67957 m .60836 .67509 L .60664 .67 L p F P
0 g
s
.103 .153 .63 r
.6099 .69611 m .61068 .69395 L p .6119 .70335 L F P
0 g
s
.103 .153 .63 r
.6119 .70335 m .61164 .70293 L .6099 .69611 L p F P
0 g
s
0 0 .391 r
.81384 .81165 m .81356 .81208 L .81367 .81793 L p F P
0 g
s
.109 .177 .653 r
.61488 .71477 m .61339 .71266 L .61389 .71126 L closepath p F P
0 g
s
.092 .157 .639 r
.61339 .71266 m .61389 .71126 L .61181 .70359 L p F P
0 g
s
.595 .718 .93 r
.64269 .60866 m .65479 .60629 L .65772 .61012 L p F P
0 g
s
.605 .726 .93 r
.65479 .60629 m .64269 .60866 L .63975 .60516 L p F P
0 g
s
.671 .768 .923 r
.62776 .60958 m .63975 .60516 L .64269 .60866 L p F P
0 g
s
.465 .617 .915 r
.70064 .62655 m .69386 .62606 L .69095 .62165 L p F P
0 g
s
.497 .641 .92 r
.68477 .62153 m .69095 .62165 L .68805 .61729 L p F P
0 g
s
.497 .641 .92 r
.68805 .61729 m .68484 .61727 L .68477 .62153 L p F P
0 g
s
.494 .645 .924 r
.67576 .61728 m .68484 .61727 L .68477 .62153 L p F P
0 g
s
.688 .779 .92 r
.63975 .60516 m .62776 .60958 L .62481 .60667 L p F P
0 g
s
.407 .43 .772 r
.64606 .80218 m .64343 .80102 L .64115 .79492 L p F P
0 g
s
0 0 .151 r
.80688 .83683 m .80818 .8349 L .80983 .82857 L p F P
0 g
s
0 0 .133 r
.81293 .82402 m .80983 .82857 L .80818 .8349 L p F P
0 g
s
0 0 .286 r
.80983 .82857 m .81293 .82402 L .81367 .81793 L p F P
0 g
s
0 0 0 r
.80609 .84011 m .80818 .8349 L .80688 .83683 L closepath p F P
0 g
s
.369 .486 .847 r
.7702 .68234 m .76222 .6794 L p .76968 .68698 L F P
0 g
s
.357 .481 .848 r
.76222 .6794 m .7702 .68234 L .7673 .67655 L p F P
0 g
s
.357 .481 .848 r
.7673 .67655 m .7632 .67504 L .76222 .6794 L p F P
0 g
s
.276 .318 .726 r
.62768 .75641 m .62478 .75395 L .6261 .75159 L closepath p F P
0 g
s
.269 .31 .72 r
.6245 .74663 m .62263 .74486 L p .62478 .75395 L F P
0 g
s
.269 .31 .72 r
.62478 .75395 m .6261 .75159 L .6245 .74663 L p F P
0 g
s
.498 .651 .927 r
.68484 .61727 m .67576 .61728 L .67284 .61314 L p F P
0 g
s
.218 .27 .703 r
.81038 .75712 m .80739 .7539 L .80858 .7514 L closepath p F P
0 g
s
.248 .307 .728 r
.8072 .74728 m .80474 .74496 L p .80739 .7539 L F P
0 g
s
.248 .307 .728 r
.80739 .7539 m .80858 .7514 L .8072 .74728 L p F P
0 g
s
.504 .573 .859 r
.69253 .8618 m .68993 .86159 L .69152 .8599 L closepath p F P
0 g
s
.512 .56 .842 r
.68955 .85619 m .69152 .8599 L .68993 .86159 L p F P
0 g
s
.641 .885 .542 r
.79753 .85322 m .797 .85393 L .7947 .85607 L p F P
0 g
s
0 0 0 r
.80082 .84867 m .80539 .84155 L p .79828 .8521 L F P
0 g
s
0 0 0 r
.79753 .85322 m .80082 .84867 L p .79828 .8521 L F P
0 g
s
0 0 0 r
.80082 .84867 m .80411 .84431 L .80584 .84095 L p F P
0 g
s
.767 .964 .665 r
.80082 .84867 m .80411 .84431 L p .80324 .84538 L F P
0 g
s
0 0 0 r
.80584 .84095 m .80539 .84155 L .80082 .84867 L p F P
0 g
s
.767 .964 .665 r
.79462 .85612 m .80082 .84867 L .80324 .84538 L F
.641 .885 .542 r
.7947 .85607 m .80082 .84867 L .79753 .85322 L p F P
0 g
s
.489 .532 .828 r
.67251 .84489 m .6746 .84269 L p .68355 .84993 L F P
0 g
s
.475 .523 .827 r
.67251 .84489 m .67119 .84206 L .6746 .84269 L closepath p F P
0 g
s
.592 .869 .542 r
.79062 .86095 m .797 .85393 L .7947 .85607 L p F P
0 g
s
0 0 .369 r
.81622 .80761 m .81384 .81165 L .81414 .81723 L p F P
0 g
s
0 0 .454 r
.81384 .81165 m .81622 .80761 L .81537 .80197 L p F P
0 g
s
0 0 .391 r
.81367 .81793 m .81414 .81723 L .81384 .81165 L p F P
0 g
s
.103 .104 .572 r
.81684 .78227 m .81431 .78677 L .81644 .79204 L p F P
0 g
s
.146 .159 .614 r
.81431 .78677 m .81684 .78227 L .8141 .77718 L p F P
0 g
s
.664 .971 .903 r
.78344 .86597 m .7802 .86959 L p .77081 .87307 L F P
0 g
s
.703 .984 .846 r
.7802 .86959 m .78344 .86597 L .78532 .8658 L closepath p F P
0 g
s
.437 .587 .904 r
.71406 .63653 m .71204 .63625 L .70914 .63162 L p F P
0 g
s
.386 .415 .768 r
.64115 .79492 m .6403 .79263 L .64221 .79357 L closepath p F P
0 g
s
.407 .43 .772 r
.64115 .79492 m .64221 .79357 L p .64606 .80218 L F P
0 g
s
.736 .665 .112 r
.60608 .63521 m .60587 .63738 L .60528 .64206 L p F P
0 g
s
.778 .821 .347 r
.60801 .62908 m .60608 .63521 L .60587 .63738 L p F P
0 g
s
.828 .708 .174 r
.60538 .64522 m .60528 .64206 L .60587 .63738 L p F P
0 g
s
.106 .154 .63 r
.61181 .70359 m .61164 .70293 L .6119 .70335 L closepath p F P
0 g
s
.916 .859 .419 r
.60789 .62483 m .60801 .62908 L .60608 .63521 L p F P
0 g
s
.959 .945 .66 r
.60801 .62908 m .60789 .62483 L .61125 .61827 L p F P
0 g
s
.129 .182 .65 r
.6119 .70335 m .61181 .70359 L .61389 .71126 L p F P
0 g
s
.39 .414 .764 r
.64221 .79357 m .6403 .79263 L .63789 .78599 L p F P
0 g
s
.323 .434 .819 r
.7764 .69528 m .77656 .69472 L p .78264 .7027 L F P
0 g
s
.337 .453 .831 r
.7764 .69528 m .77603 .69449 L .77656 .69472 L closepath p F P
0 g
s
.348 .463 .836 r
.77312 .68839 m .76968 .68698 L .77068 .6833 L closepath p F P
0 g
s
.369 .486 .847 r
.76968 .68698 m .77068 .6833 L .7702 .68234 L p F P
0 g
s
.236 .299 .726 r
.8072 .74728 m .80474 .74496 L .8057 .74282 L closepath p F P
0 g
s
.265 .334 .748 r
.80409 .73836 m .80148 .73619 L p .80474 .74496 L F P
0 g
s
.265 .334 .748 r
.80474 .74496 m .8057 .74282 L .80409 .73836 L p F P
0 g
s
.789 .999 .825 r
.78344 .86597 m .78532 .8658 L .79062 .86095 L p F P
0 g
s
.789 .999 .825 r
.79062 .86095 m .79451 .85626 L p .78344 .86597 L F P
0 g
s
.592 .869 .542 r
.7947 .85607 m .79451 .85626 L .79062 .86095 L p F P
0 g
s
.59 .755 .957 r
.72874 .87916 m .741 .87685 L .74378 .87993 L p F P
0 g
s
.576 .73 .947 r
.741 .87685 m .72874 .87916 L .7259 .87535 L p F P
0 g
s
.245 .293 .714 r
.6245 .74663 m .62263 .74486 L .62343 .74328 L closepath p F P
0 g
s
.237 .283 .708 r
.62131 .7365 m .62057 .73573 L p .62263 .74486 L F P
0 g
s
.237 .283 .708 r
.62263 .74486 m .62343 .74328 L .62131 .7365 L p F P
0 g
s
.399 .533 .875 r
.73625 .65365 m .74583 .65594 L p .74605 .66053 L F P
0 g
s
.398 .539 .881 r
.73625 .65365 m .74583 .65594 L .74294 .65081 L p F P
0 g
s
.398 .539 .881 r
.74294 .65081 m .73677 .64935 L .73625 .65365 L p F P
0 g
s
.406 .548 .885 r
.73031 .64796 m .73677 .64935 L .73625 .65365 L p F P
0 g
s
.129 .182 .65 r
.61389 .71126 m .61519 .70804 L .6119 .70335 L p F P
0 g
s
.059 .137 .631 r
.61355 .69875 m .6119 .70335 L .61519 .70804 L p F P
0 g
s
.103 .153 .63 r
.61068 .69395 m .61355 .69875 L .6119 .70335 L p F P
0 g
s
.334 .453 .833 r
.77656 .69472 m .77603 .69449 L .77312 .68839 L p F P
0 g
s
.478 .519 .821 r
.6746 .84269 m .67119 .84206 L .66814 .83538 L p F P
0 g
s
.539 .692 .938 r
.66379 .60957 m .65772 .61012 L .65479 .60629 L p F P
0 g
s
0 0 .435 r
.60728 .66561 m .60664 .67 L .60836 .67509 L p F P
0 g
s
0 0 .38 r
.60664 .67 m .60728 .66561 L .60605 .66039 L p F P
0 g
s
.39 .414 .764 r
.63789 .78599 m .63873 .78486 L p .64221 .79357 L F P
0 g
s
.368 .397 .76 r
.63789 .78599 m .63716 .78398 L .63873 .78486 L closepath p F P
0 g
s
.253 .327 .746 r
.80409 .73836 m .80148 .73619 L .80246 .73384 L closepath p F P
0 g
s
.281 .359 .766 r
.80103 .73009 m .79763 .72758 L p .80148 .73619 L F P
0 g
s
.281 .359 .766 r
.80148 .73619 m .80246 .73384 L .80103 .73009 L p F P
0 g
s
.507 .575 .858 r
.70191 .85717 m .70487 .86235 L .69253 .8618 L p F P
0 g
s
.507 .575 .858 r
.69472 .85659 m .70191 .85717 L p .69253 .8618 L F P
0 g
s
.507 .575 .858 r
.69253 .8618 m .69152 .8599 L .69472 .85659 L p F P
0 g
s
.532 .597 .865 r
.69253 .8618 m .70487 .86235 L p .70479 .86728 L F P
0 g
s
.323 .434 .819 r
.77656 .69472 m .78389 .69833 L .78264 .7027 L p F P
0 g
s
.321 .437 .823 r
.77762 .69038 m .77656 .69472 L .78389 .69833 L p F P
0 g
s
.334 .453 .833 r
.77312 .68839 m .77762 .69038 L .77656 .69472 L p F P
0 g
s
.171 .219 .67 r
.61389 .71126 m .61519 .70804 L p .61689 .71731 L F P
0 g
s
.171 .219 .67 r
.61689 .71731 m .61488 .71477 L .61389 .71126 L p F P
0 g
s
.372 .397 .757 r
.63873 .78486 m .63716 .78398 L .63476 .77721 L p F P
0 g
s
.654 .892 .982 r
.7646 .87594 m .75869 .87851 L .75599 .87629 L p F P
0 g
s
.626 .836 .981 r
.74378 .87993 m .75599 .87629 L .75869 .87851 L p F P
0 g
s
.45 .474 .792 r
.65523 .81899 m .662 .82134 L p .66074 .82714 L F P
0 g
s
.421 .467 .802 r
.662 .82134 m .65523 .81899 L .659 .81422 L closepath p F P
0 g
s
.436 .459 .786 r
.65892 .81403 m .659 .81422 L .65523 .81899 L p F P
0 g
s
.436 .459 .786 r
.65037 .81066 m .65892 .81403 L p .65523 .81899 L F P
0 g
s
.396 .434 .782 r
.65037 .81066 m .65892 .81403 L .65582 .80649 L p F P
0 g
s
.396 .434 .782 r
.65582 .80649 m .65416 .80576 L .65037 .81066 L p F P
0 g
s
.422 .445 .779 r
.64606 .80218 m .65416 .80576 L .65037 .81066 L p F P
0 g
s
.431 .581 .901 r
.71406 .63653 m .72454 .63813 L .72165 .63338 L p F P
0 g
s
.431 .581 .901 r
.72165 .63338 m .71421 .63228 L .71406 .63653 L p F P
0 g
s
.437 .587 .904 r
.70914 .63162 m .71421 .63228 L .71406 .63653 L p F P
0 g
s
.431 .574 .896 r
.71406 .63653 m .72454 .63813 L p .72606 .64274 L F P
0 g
s
.374 .51 .866 r
.755 .66767 m .75161 .66664 L .74872 .66125 L p F P
0 g
s
.436 .482 .809 r
.66508 .82845 m .66074 .82714 L .66322 .82416 L closepath p F P
0 g
s
.45 .474 .792 r
.662 .82134 m .66322 .82416 L .66074 .82714 L p F P
0 g
s
.449 .494 .814 r
.66508 .82845 m .66074 .82714 L p .66702 .83509 L F P
0 g
s
.172 .219 .67 r
.61609 .71907 m .61488 .71477 L .61689 .71731 L closepath p F P
0 g
s
.269 .352 .765 r
.80103 .73009 m .79763 .72758 L .79886 .72441 L closepath p F P
0 g
s
.295 .383 .783 r
.79801 .72228 m .79319 .71913 L p .79763 .72758 L F P
0 g
s
.295 .383 .783 r
.79763 .72758 m .79886 .72441 L .79801 .72228 L p F P
0 g
s
.31 .413 .806 r
.78264 .7027 m .78961 .70644 L .78819 .71084 L p F P
0 g
s
.316 .425 .814 r
.78389 .69833 m .78264 .7027 L .78961 .70644 L p F P
0 g
s
.612 .804 .973 r
.75599 .87629 m .74378 .87993 L .741 .87685 L p F P
0 g
s
.386 .433 .787 r
.64974 .79728 m .64606 .80218 L .65416 .80576 L p F P
0 g
s
.407 .43 .772 r
.64221 .79357 m .64974 .79728 L .64606 .80218 L p F P
0 g
s
.405 .55 .887 r
.73677 .64935 m .73031 .64796 L .72743 .64298 L p F P
0 g
s
.372 .397 .757 r
.63476 .77721 m .63558 .77604 L p .63873 .78486 L F P
0 g
s
.349 .379 .751 r
.63476 .77721 m .63401 .77507 L .63558 .77604 L closepath p F P
0 g
s
.211 .265 .701 r
.62131 .7365 m .62057 .73573 L .62086 .73508 L closepath p F P
0 g
s
.2 .252 .693 r
.62057 .73573 m .62086 .73508 L .61842 .72701 L p F P
0 g
s
.138 .155 .615 r
.81534 .77486 m .8141 .77718 L .81684 .78227 L p F P
0 g
s
.174 .201 .649 r
.81367 .76843 m .81323 .76776 L p .8141 .77718 L F P
0 g
s
.174 .201 .649 r
.8141 .77718 m .81534 .77486 L .81367 .76843 L p F P
0 g
s
.303 .398 .795 r
.79319 .71913 m .79478 .71471 L .78819 .71084 L p F P
0 g
s
.302 .403 .8 r
.78961 .70644 m .78819 .71084 L .79478 .71471 L p F P
0 g
s
.281 .373 .78 r
.79319 .71913 m .79801 .72228 L .79501 .71486 L p F P
0 g
s
.281 .373 .78 r
.79501 .71486 m .79478 .71471 L .79319 .71913 L p F P
0 g
s
.569 .657 .896 r
.71072 .87203 m .72304 .87126 L p .72399 .87553 L F P
0 g
s
.533 .65 .91 r
.72304 .87126 m .71072 .87203 L .7078 .86732 L p F P
0 g
s
.21 .251 .687 r
.61609 .71907 m .61689 .71731 L p .61864 .72655 L F P
0 g
s
.21 .251 .687 r
.61864 .72655 m .6181 .72594 L .61609 .71907 L p F P
0 g
s
.353 .379 .749 r
.63558 .77604 m .63401 .77507 L .63176 .76855 L p F P
0 g
s
0 0 .455 r
.81798 .79748 m .81537 .80197 L .81622 .80761 L p F P
0 g
s
.056 .04 .52 r
.81537 .80197 m .81798 .79748 L .81644 .79204 L p F P
0 g
s
.45 .496 .815 r
.66814 .83538 m .66702 .83509 L .66768 .83434 L closepath p F P
0 g
s
.449 .494 .814 r
.66702 .83509 m .66768 .83434 L .66508 .82845 L p F P
0 g
s
.367 .416 .78 r
.64573 .78869 m .64221 .79357 L .64974 .79728 L p F P
0 g
s
.39 .414 .764 r
.63873 .78486 m .64573 .78869 L .64221 .79357 L p F P
0 g
s
.506 .573 .857 r
.69152 .8599 m .68955 .85619 L .69472 .85659 L closepath p F P
0 g
s
0 .074 .595 r
.61195 .68944 m .61068 .69395 L .61355 .69875 L p F P
0 g
s
.046 .105 .601 r
.6095 .68453 m .61195 .68944 L .61068 .69395 L p F P
0 g
s
.328 .36 .742 r
.63176 .76855 m .63085 .76589 L .63268 .76715 L closepath p F P
0 g
s
.353 .379 .749 r
.63176 .76855 m .63268 .76715 L p .63558 .77604 L F P
0 g
s
0 0 0 r
.80818 .8349 m .81121 .83038 L p .80584 .84095 L F P
0 g
s
0 0 0 r
.80584 .84095 m .80609 .84011 L .80818 .8349 L p F P
0 g
s
0 0 .133 r
.80818 .8349 m .81121 .83038 L .81293 .82402 L p F P
0 g
s
.209 .251 .687 r
.61842 .72701 m .6181 .72594 L .61864 .72655 L closepath p F P
0 g
s
.22 .265 .697 r
.61864 .72655 m .61842 .72701 L .62086 .73508 L p F P
0 g
s
.332 .36 .74 r
.63268 .76715 m .63085 .76589 L .62887 .76001 L p F P
0 g
s
.391 .523 .87 r
.74872 .66125 m .74605 .66053 L .74663 .65738 L closepath p F P
0 g
s
.399 .533 .875 r
.74583 .65594 m .74663 .65738 L .74605 .66053 L p F P
0 g
s
.332 .36 .74 r
.62887 .76001 m .63 .7582 L p .63268 .76715 L F P
0 g
s
.305 .339 .733 r
.62887 .76001 m .62768 .75641 L .63 .7582 L closepath p F P
0 g
s
.346 .398 .772 r
.64206 .78 m .63873 .78486 L .64573 .78869 L p F P
0 g
s
.372 .397 .757 r
.63558 .77604 m .64206 .78 L .63873 .78486 L p F P
0 g
s
.254 .293 .71 r
.62086 .73508 m .62287 .73102 L p .62513 .74012 L F P
0 g
s
.254 .293 .71 r
.62513 .74012 m .62131 .7365 L .62086 .73508 L p F P
0 g
s
.22 .265 .697 r
.62086 .73508 m .62287 .73102 L .61864 .72655 L p F P
0 g
s
.308 .34 .731 r
.63 .7582 m .62768 .75641 L .6261 .75159 L p F P
0 g
s
.252 .293 .711 r
.62343 .74328 m .62131 .7365 L .62513 .74012 L closepath p F P
0 g
s
0 0 .315 r
.60627 .6561 m .60605 .66039 L .60728 .66561 L p F P
0 g
s
0 0 .224 r
.60605 .66039 m .60627 .6561 L .60555 .65074 L p F P
0 g
s
.308 .34 .731 r
.6261 .75159 m .62749 .74918 L p .63 .7582 L F P
0 g
s
.28 .317 .722 r
.6261 .75159 m .6245 .74663 L .62749 .74918 L closepath p F P
0 g
s
.478 .519 .821 r
.66814 .83538 m .67883 .83777 L .6746 .84269 L p F P
0 g
s
.465 .505 .815 r
.67883 .83777 m .66814 .83538 L .66768 .83434 L p F P
0 g
s
.283 .317 .721 r
.62343 .74328 m .62513 .74012 L p .62749 .74918 L F P
0 g
s
.283 .317 .721 r
.62749 .74918 m .6245 .74663 L .62343 .74328 L p F P
0 g
s
0 0 .282 r
.81414 .81723 m .81367 .81793 L .81293 .82402 L p F P
0 g
s
.654 .892 .982 r
.7686 .87182 m .7646 .87594 L p .75599 .87629 L F P
0 g
s
.689 .913 .972 r
.7646 .87594 m .7686 .87182 L .77081 .87307 L closepath p F P
0 g
s
.16 .23 .687 r
.62071 .72188 m .61864 .72655 L .62287 .73102 L p F P
0 g
s
.21 .251 .687 r
.61689 .71731 m .62071 .72188 L .61864 .72655 L p F P
0 g
s
.465 .617 .915 r
.69095 .62165 m .70075 .62228 L .70064 .62655 L p F P
0 g
s
.467 .621 .918 r
.70075 .62228 m .69095 .62165 L .68805 .61729 L p F P
0 g
s
.489 .532 .828 r
.6746 .84269 m .68354 .84436 L p .68355 .84993 L F P
0 g
s
.457 .51 .825 r
.6746 .84269 m .68354 .84436 L .68052 .83815 L p F P
0 g
s
.457 .51 .825 r
.68052 .83815 m .67883 .83777 L .6746 .84269 L p F P
0 g
s
.84 .948 .89 r
.61056 .61491 m .61299 .6159 L .61959 .61019 L p F P
0 g
s
.925 .919 .79 r
.61125 .61827 m .61056 .61491 L .61299 .6159 L closepath p F P
0 g
s
.194 .255 .698 r
.80858 .7514 m .80939 .74946 L p .81162 .75853 L F P
0 g
s
.194 .255 .698 r
.81162 .75853 m .81038 .75712 L .80858 .7514 L p F P
0 g
s
.215 .285 .72 r
.80858 .7514 m .8072 .74728 L .80939 .74946 L closepath p F P
0 g
s
.465 .505 .815 r
.66768 .83434 m .6714 .8301 L p .67883 .83777 L F P
0 g
s
.449 .494 .814 r
.66768 .83434 m .66508 .82845 L .6714 .8301 L closepath p F P
0 g
s
.736 .665 .112 r
.60537 .64098 m .60608 .63521 L p .60534 .64153 L F P
0 g
s
.794 .697 .155 r
.60612 .63092 m .60608 .63521 L .60537 .64098 L p F P
0 g
s
0 0 .055 r
.60537 .64098 m .60555 .64649 L p .60549 .63917 L F P
0 g
s
.794 .697 .155 r
.60547 .63668 m .60612 .63092 L p .60564 .63741 L F P
0 g
s
.794 .697 .155 r
.60537 .64098 m .60547 .63668 L p .60564 .63741 L F P
0 g
s
0 0 .055 r
.60547 .63668 m .60537 .64098 L p .60549 .63917 L F P
0 g
s
.762 .595 .025 r
.60547 .63668 m .60562 .64221 L p .60529 .63594 L F P
0 g
s
.762 .595 .025 r
.60511 .6325 m .60547 .63668 L p .60529 .63594 L F P
0 g
s
.736 .665 .112 r
.60528 .64206 m .60537 .64098 L p .60534 .64153 L F P
0 g
s
.916 .859 .419 r
.60608 .63521 m .60612 .63092 L .60789 .62483 L p F P
0 g
s
.196 .255 .698 r
.81115 .75959 m .81038 .75712 L .81162 .75853 L closepath p F P
0 g
s
.16 .213 .669 r
.81162 .75853 m .81115 .75959 L .81341 .76741 L p F P
0 g
s
.199 .239 .679 r
.81323 .76776 m .81341 .76741 L .81115 .75959 L p F P
0 g
s
.213 .284 .721 r
.80939 .74946 m .8072 .74728 L .8057 .74282 L p F P
0 g
s
.329 .452 .834 r
.77762 .69038 m .77312 .68839 L .77068 .6833 L p F P
0 g
s
.84 .948 .89 r
.61959 .61019 m .61882 .60611 L p .61056 .61491 L F P
0 g
s
.781 .843 .898 r
.62185 .60386 m .61882 .60611 L .61959 .61019 L p F P
0 g
s
.781 .843 .898 r
.61959 .61019 m .62481 .60667 L .62185 .60386 L p F P
0 g
s
.161 .192 .646 r
.81367 .76843 m .81323 .76776 L .81341 .76741 L closepath p F P
0 g
s
.323 .378 .764 r
.63868 .77122 m .63558 .77604 L .64206 .78 L p F P
0 g
s
.353 .379 .749 r
.63268 .76715 m .63868 .77122 L .63558 .77604 L p F P
0 g
s
.498 .651 .927 r
.67284 .61314 m .68492 .61298 L .68484 .61727 L p F P
0 g
s
.503 .657 .929 r
.68492 .61298 m .67284 .61314 L .66992 .60905 L p F P
0 g
s
.213 .284 .721 r
.8057 .74282 m .80658 .74054 L p .80939 .74946 L F P
0 g
s
.233 .313 .741 r
.8057 .74282 m .80409 .73836 L .80658 .74054 L closepath p F P
0 g
s
.532 .597 .865 r
.70487 .86235 m .70659 .86526 L .70479 .86728 L p F P
0 g
s
.524 .613 .883 r
.7078 .86732 m .70479 .86728 L .70659 .86526 L closepath p F P
0 g
s
.562 .678 .917 r
.7259 .87535 m .72399 .87553 L .72511 .87423 L closepath p F P
0 g
s
.569 .657 .896 r
.72304 .87126 m .72511 .87423 L .72399 .87553 L p F P
0 g
s
.974 .926 .651 r
.61056 .61491 m .61125 .61827 L .60789 .62483 L p F P
0 g
s
.437 .591 .907 r
.71421 .63228 m .70914 .63162 L .70625 .62703 L p F P
0 g
s
.464 .611 .911 r
.70064 .62655 m .70625 .62703 L .70335 .62248 L p F P
0 g
s
.464 .611 .911 r
.70335 .62248 m .70075 .62228 L .70064 .62655 L p F P
0 g
s
.615 .734 .931 r
.65185 .60252 m .63975 .60516 L .6368 .60172 L p F P
0 g
s
.688 .779 .92 r
.62481 .60667 m .6368 .60172 L .63975 .60516 L p F P
0 g
s
.605 .726 .93 r
.63975 .60516 m .65185 .60252 L .65479 .60629 L p F P
0 g
s
0 0 .544 r
.61039 .6801 m .6095 .68453 L .61195 .68944 L p F P
0 g
s
0 0 .52 r
.6095 .68453 m .61039 .6801 L .60836 .67509 L p F P
0 g
s
0 0 .369 r
.81414 .81723 m .81636 .81346 L .81622 .80761 L p F P
0 g
s
0 0 .256 r
.81636 .81346 m .81414 .81723 L .81404 .82237 L p F P
0 g
s
0 0 .282 r
.81293 .82402 m .81404 .82237 L .81414 .81723 L p F P
0 g
s
.133 .173 .638 r
.81341 .76741 m .81522 .76335 L p .81635 .77273 L F P
0 g
s
.133 .173 .638 r
.81635 .77273 m .81367 .76843 L .81341 .76741 L p F P
0 g
s
.16 .213 .669 r
.81341 .76741 m .81522 .76335 L .81162 .75853 L p F P
0 g
s
.509 .567 .85 r
.69472 .85659 m .68955 .85619 L .68655 .85039 L p F P
0 g
s
.231 .313 .742 r
.80658 .74054 m .80409 .73836 L .80246 .73384 L p F P
0 g
s
.134 .174 .638 r
.81534 .77486 m .81367 .76843 L .81635 .77273 L closepath p F P
0 g
s
.364 .493 .856 r
.755 .66767 m .76413 .67068 L .7632 .67504 L p F P
0 g
s
.373 .505 .863 r
.75569 .66336 m .755 .66767 L .76413 .67068 L p F P
0 g
s
.374 .51 .866 r
.74872 .66125 m .75569 .66336 L .755 .66767 L p F P
0 g
s
.548 .689 .932 r
.66379 .60957 m .66992 .60905 L .66699 .605 L p F P
0 g
s
.548 .689 .932 r
.66699 .605 m .66352 .60536 L .66379 .60957 L p F P
0 g
s
.539 .692 .938 r
.65479 .60629 m .66352 .60536 L .66379 .60957 L p F P
0 g
s
.706 .789 .916 r
.6368 .60172 m .62481 .60667 L .62185 .60386 L p F P
0 g
s
.425 .565 .891 r
.72743 .64298 m .72606 .64274 L .72627 .641 L closepath p F P
0 g
s
.431 .574 .896 r
.72454 .63813 m .72627 .641 L .72606 .64274 L p F P
0 g
s
0 0 0 r
.80539 .84155 m .80584 .84095 L .80609 .84011 L closepath p F P
0 g
s
.298 .356 .755 r
.63554 .76238 m .63268 .76715 L .63868 .77122 L p F P
0 g
s
.332 .36 .74 r
.63 .7582 m .63554 .76238 L .63268 .76715 L p F P
0 g
s
.103 .104 .572 r
.81725 .78328 m .81684 .78227 L p .81644 .79204 L F P
0 g
s
.103 .104 .572 r
.81644 .79204 m .81832 .78873 L .81725 .78328 L p F P
0 g
s
.051 .038 .52 r
.81832 .78873 m .81644 .79204 L .81798 .79748 L p F P
0 g
s
.108 .189 .667 r
.61862 .71271 m .61689 .71731 L .62071 .72188 L p F P
0 g
s
.171 .219 .67 r
.61519 .70804 m .61862 .71271 L .61689 .71731 L p F P
0 g
s
.231 .313 .742 r
.80246 .73384 m .80321 .73178 L p .80658 .74054 L F P
0 g
s
.25 .339 .76 r
.80246 .73384 m .80103 .73009 L .80321 .73178 L closepath p F P
0 g
s
.576 .73 .947 r
.7259 .87535 m .7382 .87348 L .741 .87685 L p F P
0 g
s
.572 .683 .915 r
.73538 .86985 m .7382 .87348 L .7259 .87535 L p F P
0 g
s
.572 .683 .915 r
.72878 .8706 m .73538 .86985 L p .7259 .87535 L F P
0 g
s
.572 .683 .915 r
.7259 .87535 m .72511 .87423 L .72878 .8706 L p F P
0 g
s
.371 .511 .868 r
.75569 .66336 m .74872 .66125 L .74663 .65738 L p F P
0 g
s
0 0 .176 r
.60546 .64761 m .60555 .65074 L .60627 .6561 L p F P
0 g
s
0 0 .025 r
.60555 .65074 m .60546 .64761 L .60528 .64206 L p F P
0 g
s
.479 .544 .845 r
.68655 .85039 m .68355 .84993 L .68531 .8479 L closepath p F P
0 g
s
.489 .532 .828 r
.68354 .84436 m .68531 .8479 L .68355 .84993 L p F P
0 g
s
.664 .971 .903 r
.77081 .87307 m .78284 .86592 L .78344 .86597 L p F P
0 g
s
.753 .927 .946 r
.7686 .87182 m .77081 .87307 L .78284 .86592 L p F P
0 g
s
.159 .215 .672 r
.81347 .75413 m .81162 .75853 L .81522 .76335 L p F P
0 g
s
.194 .255 .698 r
.80939 .74946 m .81347 .75413 L .81162 .75853 L p F P
0 g
s
.452 .492 .809 r
.6714 .8301 m .66508 .82845 L .66322 .82416 L p F P
0 g
s
.503 .646 .921 r
.68484 .61727 m .68805 .61729 L .68513 .61298 L p F P
0 g
s
.503 .646 .921 r
.68513 .61298 m .68492 .61298 L .68484 .61727 L p F P
0 g
s
.546 .7 .94 r
.66352 .60536 m .65479 .60629 L .65185 .60252 L p F P
0 g
s
.248 .339 .761 r
.80321 .73178 m .80103 .73009 L .79886 .72441 L p F P
0 g
s
0 0 .111 r
.60537 .64098 m .60528 .64206 L .60546 .64761 L p F P
0 g
s
.405 .55 .887 r
.72743 .64298 m .73721 .64506 L .73677 .64935 L p F P
0 g
s
.403 .552 .89 r
.73721 .64506 m .72743 .64298 L .72627 .641 L p F P
0 g
s
.093 .124 .602 r
.81635 .77273 m .81534 .77486 L .817 .78198 L p F P
0 g
s
.138 .155 .615 r
.81684 .78227 m .817 .78198 L .81534 .77486 L p F P
0 g
s
.533 .65 .91 r
.7078 .86732 m .72015 .86693 L .72304 .87126 L p F P
0 g
s
.531 .616 .883 r
.71725 .86239 m .72015 .86693 L .7078 .86732 L p F P
0 g
s
.531 .616 .883 r
.70935 .86236 m .71725 .86239 L p .7078 .86732 L F P
0 g
s
.531 .616 .883 r
.7078 .86732 m .70659 .86526 L .70935 .86236 L p F P
0 g
s
.27 .333 .745 r
.6326 .75347 m .63 .7582 L .63554 .76238 L p F P
0 g
s
.308 .34 .731 r
.62749 .74918 m .6326 .75347 L .63 .7582 L p F P
0 g
s
0 0 .474 r
.60889 .67074 m .60836 .67509 L .61039 .6801 L p F P
0 g
s
0 0 .435 r
.60836 .67509 m .60889 .67074 L .60728 .66561 L p F P
0 g
s
.354 .481 .849 r
.7632 .67504 m .7673 .67655 L .7644 .67078 L p F P
0 g
s
.354 .481 .849 r
.7644 .67078 m .76413 .67068 L .7632 .67504 L p F P
0 g
s
.329 .452 .834 r
.77068 .6833 m .77083 .68259 L p .77762 .69038 L F P
0 g
s
.343 .47 .844 r
.77068 .6833 m .7702 .68234 L .77083 .68259 L closepath p F P
0 g
s
.789 .999 .825 r
.79451 .85626 m .78426 .86488 L .78344 .86597 L p F P
0 g
s
.747 .99 .886 r
.78284 .86592 m .78426 .86488 L .78344 .86597 L closepath p F P
0 g
s
.571 .682 .915 r
.72511 .87423 m .72304 .87126 L .72878 .8706 L closepath p F P
0 g
s
0 0 0 r
.80838 .83705 m .80584 .84095 L .80411 .84431 L p F P
0 g
s
0 0 0 r
.81121 .83038 m .80838 .83705 L .80584 .84095 L p F P
0 g
s
.046 .141 .641 r
.61659 .70352 m .61519 .70804 L .61862 .71271 L p F P
0 g
s
.059 .137 .631 r
.61519 .70804 m .61659 .70352 L .61355 .69875 L p F P
0 g
s
0 0 .367 r
.81885 .80313 m .81622 .80761 L .81636 .81346 L p F P
0 g
s
0 0 .455 r
.81622 .80761 m .81885 .80313 L .81798 .79748 L p F P
0 g
s
.185 .253 .7 r
.81113 .74507 m .80939 .74946 L .81347 .75413 L p F P
0 g
s
.213 .284 .721 r
.80658 .74054 m .81113 .74507 L .80939 .74946 L p F P
0 g
s
.339 .471 .847 r
.77083 .68259 m .7702 .68234 L .7673 .67655 L p F P
0 g
s
.955 .863 .451 r
.60733 .6207 m .60789 .62483 L .60612 .63092 L p F P
0 g
s
.974 .926 .651 r
.61006 .61486 m .61056 .61491 L p .60789 .62483 L F P
0 g
s
.974 .926 .651 r
.60789 .62483 m .60733 .6207 L .61006 .61486 L p F P
0 g
s
.452 .492 .809 r
.66322 .82416 m .66486 .8222 L p .6714 .8301 L F P
0 g
s
.436 .48 .807 r
.66322 .82416 m .662 .82134 L .66486 .8222 L closepath p F P
0 g
s
.612 .804 .973 r
.741 .87685 m .75327 .87372 L .75599 .87629 L p F P
0 g
s
.598 .775 .965 r
.75327 .87372 m .741 .87685 L .7382 .87348 L p F P
0 g
s
.248 .339 .761 r
.79886 .72441 m .79928 .72316 L p .80321 .73178 L F P
0 g
s
.266 .364 .778 r
.79886 .72441 m .79801 .72228 L .79928 .72316 L closepath p F P
0 g
s
0 0 .138 r
.81404 .82237 m .81293 .82402 L .81121 .83038 L p F P
0 g
s
.654 .892 .982 r
.75599 .87629 m .76818 .87156 L .7686 .87182 L p F P
0 g
s
.64 .861 .983 r
.76818 .87156 m .75599 .87629 L .75327 .87372 L p F P
0 g
s
.238 .308 .733 r
.62982 .7445 m .62749 .74918 L .6326 .75347 L p F P
0 g
s
.283 .317 .721 r
.62513 .74012 m .62982 .7445 L .62749 .74918 L p F P
0 g
s
.329 .452 .834 r
.77083 .68259 m .77861 .68605 L .77762 .69038 L p F P
0 g
s
.328 .456 .838 r
.77164 .67829 m .77083 .68259 L .77861 .68605 L p F P
0 g
s
.339 .471 .847 r
.7673 .67655 m .77164 .67829 L .77083 .68259 L p F P
0 g
s
.397 .541 .883 r
.73677 .64935 m .74294 .65081 L .74005 .64572 L p F P
0 g
s
.397 .541 .883 r
.74005 .64572 m .73721 .64506 L .73677 .64935 L p F P
0 g
s
.088 .094 .568 r
.81725 .78328 m .81684 .78227 L .817 .78198 L closepath p F P
0 g
s
.403 .552 .89 r
.72627 .641 m .72636 .63847 L p .73721 .64506 L F P
0 g
s
.413 .565 .896 r
.72627 .641 m .72454 .63813 L .72636 .63847 L closepath p F P
0 g
s
.264 .364 .778 r
.79928 .72316 m .79801 .72228 L .79501 .71486 L p F P
0 g
s
.767 .964 .665 r
.79462 .85612 m .7947 .85607 L .80082 .84867 L p F P
0 g
s
0 0 .111 r
.60546 .64761 m .60555 .64649 L .60537 .64098 L p F P
0 g
s
.529 .614 .882 r
.70659 .86526 m .70487 .86235 L .70935 .86236 L closepath p F P
0 g
s
.509 .567 .85 r
.68655 .85039 m .6987 .85179 L .69472 .85659 L p F P
0 g
s
.495 .553 .844 r
.6987 .85179 m .68655 .85039 L .68531 .8479 L p F P
0 g
s
.439 .478 .803 r
.66486 .8222 m .662 .82134 L .659 .81422 L p F P
0 g
s
.207 .285 .724 r
.8082 .73616 m .80658 .74054 L .81113 .74507 L p F P
0 g
s
.231 .313 .742 r
.80321 .73178 m .8082 .73616 L .80658 .74054 L p F P
0 g
s
.382 .526 .876 r
.74663 .65738 m .74583 .65594 L .74676 .65619 L closepath p F P
0 g
s
.371 .511 .868 r
.74663 .65738 m .74676 .65619 L p .75569 .66336 L F P
0 g
s
.055 .071 .558 r
.817 .78198 m .81895 .77786 L p .81891 .78756 L F P
0 g
s
.055 .071 .558 r
.81891 .78756 m .81725 .78328 L .817 .78198 L p F P
0 g
s
.093 .124 .602 r
.817 .78198 m .81895 .77786 L .81635 .77273 L p F P
0 g
s
.467 .621 .918 r
.68805 .61729 m .70044 .61799 L p .70075 .62228 L F P
0 g
s
.47 .625 .919 r
.70044 .61799 m .68805 .61729 L .68513 .61298 L p F P
0 g
s
0 0 .398 r
.60744 .66135 m .60728 .66561 L .60889 .67074 L p F P
0 g
s
0 0 .315 r
.60728 .66561 m .60744 .66135 L .60627 .6561 L p F P
0 g
s
.746 .978 .918 r
.78426 .86488 m .78284 .86592 L .78029 .86525 L p F P
0 g
s
.753 .927 .946 r
.78284 .86592 m .78029 .86525 L p .7686 .87182 L F P
0 g
s
.432 .585 .903 r
.71421 .63228 m .72165 .63338 L .71875 .62867 L p F P
0 g
s
.432 .585 .903 r
.71875 .62867 m .7143 .62804 L .71421 .63228 L p F P
0 g
s
.437 .591 .907 r
.70625 .62703 m .7143 .62804 L .71421 .63228 L p F P
0 g
s
0 .084 .608 r
.61461 .6943 m .61355 .69875 L .61659 .70352 L p F P
0 g
s
0 .074 .595 r
.61355 .69875 m .61461 .6943 L .61195 .68944 L p F P
0 g
s
.487 .563 .859 r
.69472 .85659 m .70191 .85717 L .69895 .85182 L p F P
0 g
s
.487 .563 .859 r
.69895 .85182 m .6987 .85179 L .69472 .85659 L p F P
0 g
s
.321 .437 .823 r
.78389 .69833 m .78507 .69396 L .77762 .69038 L p F P
0 g
s
.323 .444 .829 r
.77861 .68605 m .77762 .69038 L .78507 .69396 L p F P
0 g
s
.746 .978 .918 r
.78029 .86525 m .78763 .86032 L .78426 .86488 L p F P
0 g
s
.748 .992 .874 r
.79462 .85612 m .79451 .85626 L .78426 .86488 L p F P
0 g
s
.748 .992 .874 r
.79228 .8568 m .79462 .85612 L p .78426 .86488 L F P
0 g
s
.748 .992 .874 r
.78426 .86488 m .78763 .86032 L .79228 .8568 L p F P
0 g
s
.437 .594 .909 r
.7143 .62804 m .70625 .62703 L .70335 .62248 L p F P
0 g
s
.057 .072 .558 r
.81832 .78873 m .81725 .78328 L .81891 .78756 L closepath p F P
0 g
s
.203 .279 .72 r
.62717 .7355 m .62513 .74012 L .62982 .7445 L p F P
0 g
s
.254 .293 .71 r
.62287 .73102 m .62717 .7355 L .62513 .74012 L p F P
0 g
s
.226 .314 .745 r
.80469 .72741 m .80321 .73178 L .8082 .73616 L p F P
0 g
s
.248 .339 .761 r
.79928 .72316 m .80469 .72741 L .80321 .73178 L p F P
0 g
s
.51 .66 .928 r
.68221 .60879 m .66992 .60905 L .66699 .605 L p F P
0 g
s
.503 .657 .929 r
.66992 .60905 m .68221 .60879 L p .68492 .61298 L F P
0 g
s
.661 .937 .666 r
.79451 .85626 m .79462 .85612 L .7947 .85607 L closepath p F P
0 g
s
.316 .425 .814 r
.78908 .70109 m .78389 .69833 L p .78961 .70644 L F P
0 g
s
.302 .416 .812 r
.78389 .69833 m .78908 .70109 L .78614 .69453 L p F P
0 g
s
.302 .416 .812 r
.78614 .69453 m .78507 .69396 L .78389 .69833 L p F P
0 g
s
.495 .553 .844 r
.68531 .8479 m .68791 .845 L p .6987 .85179 L F P
0 g
s
.481 .544 .844 r
.68531 .8479 m .68354 .84436 L .68791 .845 L closepath p F P
0 g
s
.379 .527 .879 r
.74676 .65619 m .74583 .65594 L .74294 .65081 L p F P
0 g
s
.241 .339 .764 r
.80062 .71881 m .79928 .72316 L .80469 .72741 L p F P
0 g
s
.264 .364 .778 r
.79501 .71486 m .80062 .71881 L .79928 .72316 L p F P
0 g
s
.747 .986 .77 r
.79228 .8568 m .7976 .85176 L .79462 .85612 L closepath p F P
0 g
s
.767 .964 .665 r
.80398 .84446 m .7976 .85176 L .79462 .85612 L p F P
0 g
s
.767 .964 .665 r
.80411 .84431 m .80398 .84446 L p .79462 .85612 L F P
0 g
s
.302 .403 .8 r
.79204 .70788 m .78961 .70644 L p .79478 .71471 L F P
0 g
s
.29 .396 .798 r
.79204 .70788 m .78961 .70644 L .79037 .70397 L closepath p F P
0 g
s
.316 .425 .814 r
.78961 .70644 m .79037 .70397 L .78908 .70109 L p F P
0 g
s
.302 .403 .8 r
.79478 .71471 m .79486 .71448 L .79204 .70788 L p F P
0 g
s
.275 .373 .782 r
.79501 .71486 m .79478 .71471 L .79486 .71448 L closepath p F P
0 g
s
.929 .956 .777 r
.61006 .61486 m .61055 .61418 L .61056 .61491 L closepath p F P
0 g
s
.84 .948 .89 r
.61882 .60611 m .61055 .61418 L .61056 .61491 L p F P
0 g
s
.706 .789 .916 r
.62185 .60386 m .63384 .59834 L .6368 .60172 L p F P
0 g
s
.615 .734 .931 r
.6368 .60172 m .6489 .59879 L .65185 .60252 L p F P
0 g
s
.626 .742 .931 r
.6489 .59879 m .6368 .60172 L .63384 .59834 L p F P
0 g
s
.254 .359 .778 r
.80062 .71881 m .79501 .71486 L .79486 .71448 L p F P
0 g
s
.092 .126 .604 r
.81835 .76833 m .81635 .77273 L .81895 .77786 L p F P
0 g
s
.133 .173 .638 r
.81522 .76335 m .81835 .76833 L .81635 .77273 L p F P
0 g
s
.575 .67 .904 r
.72878 .8706 m .72304 .87126 L .72015 .86693 L p F P
0 g
s
.254 .359 .778 r
.79486 .71448 m .796 .71037 L p .80062 .71881 L F P
0 g
s
.271 .383 .794 r
.79486 .71448 m .79204 .70788 L .796 .71037 L closepath p F P
0 g
s
.421 .465 .8 r
.659 .81422 m .65892 .81403 L .65909 .8141 L closepath p F P
0 g
s
.439 .478 .803 r
.659 .81422 m .65909 .8141 L p .66486 .8222 L F P
0 g
s
.425 .463 .795 r
.65909 .8141 m .65892 .81403 L .65582 .80649 L p F P
0 g
s
.164 .248 .705 r
.62462 .72645 m .62287 .73102 L .62717 .7355 L p F P
0 g
s
.16 .23 .687 r
.62287 .73102 m .62462 .72645 L .62071 .72188 L p F P
0 g
s
.371 .511 .868 r
.74676 .65619 m .7563 .65906 L .75569 .66336 L p F P
0 g
s
.38 .523 .875 r
.74713 .65194 m .74676 .65619 L .7563 .65906 L p F P
0 g
s
.379 .527 .879 r
.74294 .65081 m .74713 .65194 L .74676 .65619 L p F P
0 g
s
.533 .607 .873 r
.70935 .86236 m .70487 .86235 L .70191 .85717 L p F P
0 g
s
0 .033 .576 r
.61268 .68506 m .61195 .68944 L .61461 .6943 L p F P
0 g
s
0 0 .544 r
.61195 .68944 m .61268 .68506 L .61039 .6801 L p F P
0 g
s
0 0 .453 r
.81934 .79512 m .81798 .79748 L .81885 .80313 L p F P
0 g
s
.051 .038 .52 r
.81798 .79748 m .81934 .79512 L .81832 .78873 L p F P
0 g
s
.439 .478 .803 r
.65909 .8141 m .66855 .81736 L .66486 .8222 L p F P
0 g
s
.404 .468 .812 r
.66282 .80922 m .65909 .8141 L .66855 .81736 L p F P
0 g
s
.425 .463 .795 r
.65582 .80649 m .66282 .80922 L .65909 .8141 L p F P
0 g
s
.389 .437 .79 r
.65582 .80649 m .65416 .80576 L .65503 .80454 L closepath p F P
0 g
s
.386 .433 .787 r
.65271 .79875 m .64974 .79728 L p .65416 .80576 L F P
0 g
s
.386 .433 .787 r
.65416 .80576 m .65503 .80454 L .65271 .79875 L p F P
0 g
s
0 0 .284 r
.60622 .65382 m .60627 .6561 L .60744 .66135 L p F P
0 g
s
0 0 .176 r
.60627 .6561 m .60622 .65382 L .60546 .64761 L p F P
0 g
s
0 0 .109 r
.81571 .81953 m .81404 .82237 L .81349 .82701 L p F P
0 g
s
0 0 .256 r
.81404 .82237 m .81571 .81953 L .81636 .81346 L p F P
0 g
s
0 0 .138 r
.81121 .83038 m .81349 .82701 L .81404 .82237 L p F P
0 g
s
.41 .567 .899 r
.72636 .63847 m .72454 .63813 L .72165 .63338 L p F P
0 g
s
.88 .924 .849 r
.61766 .60213 m .61882 .60611 L .61055 .61418 L p F P
0 g
s
.8 .851 .888 r
.61889 .60113 m .61766 .60213 L .61882 .60611 L p F P
0 g
s
.8 .851 .888 r
.61882 .60611 m .62185 .60386 L .61889 .60113 L p F P
0 g
s
.335 .47 .847 r
.77164 .67829 m .7673 .67655 L .7644 .67078 L p F P
0 g
s
.37 .42 .783 r
.65271 .79875 m .64974 .79728 L .65124 .79503 L closepath p F P
0 g
s
.367 .416 .78 r
.64959 .79082 m .64573 .78869 L p .64974 .79728 L F P
0 g
s
.367 .416 .78 r
.64974 .79728 m .65124 .79503 L .64959 .79082 L p F P
0 g
s
0 0 .263 r
.60555 .64649 m .60546 .64761 L .60622 .65382 L p F P
0 g
s
.452 .492 .809 r
.66486 .8222 m .67443 .82515 L p .6714 .8301 L F P
0 g
s
.416 .466 .805 r
.66486 .8222 m .67443 .82515 L .67136 .81835 L p F P
0 g
s
.416 .466 .805 r
.67136 .81835 m .66855 .81736 L .66486 .8222 L p F P
0 g
s
.871 .737 .222 r
.60571 .62675 m .60612 .63092 L .60547 .63668 L p F P
0 g
s
.955 .863 .451 r
.60612 .63092 m .60571 .62675 L .60733 .6207 L p F P
0 g
s
0 0 0 r
.81349 .82701 m .81121 .83038 L .80838 .83705 L p F P
0 g
s
.88 .924 .849 r
.61055 .61418 m .61022 .60995 L .61766 .60213 L p F P
0 g
s
.948 .946 .74 r
.61055 .61418 m .61006 .61486 L .60715 .61484 L p F P
0 g
s
.948 .946 .74 r
.60715 .61484 m .61022 .60995 L .61055 .61418 L p F P
0 g
s
.724 .799 .911 r
.63384 .59834 m .62185 .60386 L .61889 .60113 L p F P
0 g
s
0 .002 .502 r
.81891 .78756 m .81832 .78873 L .81934 .79512 L p F P
0 g
s
.484 .54 .838 r
.68791 .845 m .68354 .84436 L .68052 .83815 L p F P
0 g
s
.977 .906 .672 r
.60733 .6207 m .61006 .61486 L .60715 .61484 L p F P
0 g
s
.346 .398 .772 r
.64646 .7827 m .64206 .78 L p .64573 .78869 L F P
0 g
s
.346 .398 .772 r
.64573 .78869 m .6476 .78568 L .64646 .7827 L p F P
0 g
s
.35 .403 .775 r
.64959 .79082 m .64573 .78869 L .6476 .78568 L closepath p F P
0 g
s
.708 .907 .966 r
.76818 .87156 m .76911 .87111 L .7686 .87182 L closepath p F P
0 g
s
.753 .927 .946 r
.78029 .86525 m .76911 .87111 L .7686 .87182 L p F P
0 g
s
.546 .7 .94 r
.65185 .60252 m .66337 .60109 L .66352 .60536 L p F P
0 g
s
.554 .707 .942 r
.66337 .60109 m .65185 .60252 L .6489 .59879 L p F P
0 g
s
.464 .612 .912 r
.70335 .62248 m .70075 .62228 L .70082 .61856 L closepath p F P
0 g
s
.467 .621 .918 r
.70044 .61799 m .70082 .61856 L .70075 .62228 L p F P
0 g
s
.438 .501 .826 r
.67748 .83172 m .6714 .8301 L .6747 .82573 L closepath p F P
0 g
s
.452 .492 .809 r
.67443 .82515 m .6747 .82573 L .6714 .8301 L p F P
0 g
s
.465 .505 .815 r
.6714 .8301 m .67748 .83172 L p .67883 .83777 L F P
0 g
s
0 0 .367 r
.81636 .81346 m .81899 .80898 L .81885 .80313 L p F P
0 g
s
0 0 .248 r
.81899 .80898 m .81636 .81346 L .81571 .81953 L p F P
0 g
s
.119 .212 .687 r
.62217 .71737 m .62071 .72188 L .62462 .72645 L p F P
0 g
s
.108 .189 .667 r
.62071 .72188 m .62217 .71737 L .61862 .71271 L p F P
0 g
s
.556 .695 .932 r
.66352 .60536 m .66699 .605 L .66405 .60101 L p F P
0 g
s
.556 .695 .932 r
.66405 .60101 m .66337 .60109 L .66352 .60536 L p F P
0 g
s
.328 .384 .768 r
.64646 .7827 m .64206 .78 L .6441 .77646 L closepath p F P
0 g
s
.323 .378 .764 r
.64332 .77439 m .63868 .77122 L p .64206 .78 L F P
0 g
s
.323 .378 .764 r
.64206 .78 m .6441 .77646 L .64332 .77439 L p F P
0 g
s
.159 .215 .672 r
.81522 .76335 m .81713 .75895 L .81347 .75413 L p F P
0 g
s
.129 .176 .643 r
.81713 .75895 m .81522 .76335 L .81835 .76833 L p F P
0 g
s
0 0 .527 r
.61079 .6758 m .61039 .6801 L .61268 .68506 L p F P
0 g
s
0 0 .474 r
.61039 .6801 m .61079 .6758 L .60889 .67074 L p F P
0 g
s
.402 .559 .896 r
.72636 .63847 m .73716 .64069 L .73427 .63584 L p F P
0 g
s
.402 .559 .896 r
.73427 .63584 m .72642 .63425 L .72636 .63847 L p F P
0 g
s
.41 .567 .899 r
.72165 .63338 m .72642 .63425 L .72636 .63847 L p F P
0 g
s
.403 .552 .89 r
.72636 .63847 m .73716 .64069 L p .73721 .64506 L F P
0 g
s
.41 .45 .791 r
.66282 .80922 m .65582 .80649 L .65503 .80454 L p F P
0 g
s
.373 .505 .863 r
.7615 .66527 m .75569 .66336 L p .76413 .67068 L F P
0 g
s
.36 .5 .863 r
.75569 .66336 m .7615 .66527 L .75861 .65981 L p F P
0 g
s
.36 .5 .863 r
.75861 .65981 m .7563 .65906 L .75569 .66336 L p F P
0 g
s
.693 .881 .968 r
.76911 .87111 m .76818 .87156 L .76551 .86957 L p F P
0 g
s
.64 .861 .983 r
.75327 .87372 m .76551 .86957 L .76818 .87156 L p F P
0 g
s
.27 .383 .795 r
.796 .71037 m .79204 .70788 L .79037 .70397 L p F P
0 g
s
.584 .749 .956 r
.75051 .87083 m .7382 .87348 L .73538 .86985 L p F P
0 g
s
.598 .775 .965 r
.7382 .87348 m .75051 .87083 L .75327 .87372 L p F P
0 g
s
0 0 .201 r
.60562 .64221 m .60555 .64649 L .60638 .65183 L p F P
0 g
s
0 0 .122 r
.60562 .64221 m .60639 .64757 L p .60573 .64201 L F P
0 g
s
0 0 .055 r
.60562 .64221 m .60547 .63668 L p .60551 .64241 L F P
0 g
s
.762 .595 .025 r
.60526 .63804 m .60511 .6325 L p .60542 .6384 L F P
0 g
s
.762 .595 .025 r
.60562 .64221 m .60526 .63804 L p .60542 .6384 L F P
0 g
s
0 0 .122 r
.60526 .63804 m .60562 .64221 L p .60573 .64201 L F P
0 g
s
.752 .529 0 r
.60526 .63804 m .60599 .64342 L p .60511 .63768 L F P
0 g
s
.752 .529 0 r
.60453 .63396 m .60526 .63804 L p .60511 .63768 L F P
0 g
s
0 0 .055 r
.60555 .64649 m .60562 .64221 L p .60551 .64241 L F P
0 g
s
0 0 .263 r
.60622 .65382 m .60638 .65183 L .60555 .64649 L p F P
0 g
s
.693 .881 .968 r
.76551 .86957 m .7723 .8666 L .76911 .87111 L p F P
0 g
s
.706 .94 .96 r
.7777 .86408 m .7723 .8666 L .76911 .87111 L p F P
0 g
s
.706 .94 .96 r
.76911 .87111 m .78029 .86525 L .7777 .86408 L p F P
0 g
s
.41 .45 .791 r
.65503 .80454 m .65766 .80092 L p .66282 .80922 L F P
0 g
s
.391 .436 .788 r
.65503 .80454 m .65271 .79875 L .65766 .80092 L closepath p F P
0 g
s
.303 .363 .759 r
.64332 .77439 m .63868 .77122 L .64072 .76737 L closepath p F P
0 g
s
.298 .356 .755 r
.64018 .76587 m .63554 .76238 L p .63868 .77122 L F P
0 g
s
.298 .356 .755 r
.63868 .77122 m .64072 .76737 L .64018 .76587 L p F P
0 g
s
.452 .515 .832 r
.68052 .83815 m .67883 .83777 L .67977 .83658 L closepath p F P
0 g
s
.465 .505 .815 r
.67748 .83172 m .67977 .83658 L .67883 .83777 L p F P
0 g
s
.502 .648 .922 r
.68513 .61298 m .68492 .61298 L .68492 .61266 L closepath p F P
0 g
s
.503 .657 .929 r
.68221 .60879 m .68492 .61266 L .68492 .61298 L p F P
0 g
s
.47 .625 .919 r
.68513 .61298 m .69754 .61365 L .70044 .61799 L p F P
0 g
s
.457 .624 .924 r
.69462 .60934 m .69754 .61365 L .68513 .61298 L p F P
0 g
s
.457 .624 .924 r
.68435 .60887 m .69462 .60934 L p .68513 .61298 L F P
0 g
s
.457 .624 .924 r
.68513 .61298 m .68492 .61266 L .68435 .60887 L p F P
0 g
s
.068 .172 .665 r
.61978 .70827 m .61862 .71271 L .62217 .71737 L p F P
0 g
s
.046 .141 .641 r
.61862 .71271 m .61978 .70827 L .61659 .70352 L p F P
0 g
s
.055 .071 .558 r
.81895 .77786 m .82102 .78316 L .81891 .78756 L p F P
0 g
s
0 .002 .502 r
.81934 .79512 m .82038 .79303 L .81891 .78756 L p F P
0 g
s
0 0 .502 r
.82102 .78316 m .81891 .78756 L .82038 .79303 L p F P
0 g
s
.625 .829 .979 r
.76551 .86957 m .75327 .87372 L .75051 .87083 L p F P
0 g
s
.511 .603 .882 r
.70935 .86236 m .71725 .86239 L .71432 .85766 L p F P
0 g
s
.511 .603 .882 r
.71432 .85766 m .7132 .85761 L .70935 .86236 L p F P
0 g
s
.533 .607 .873 r
.70191 .85717 m .7132 .85761 L .70935 .86236 L p F P
0 g
s
.437 .594 .909 r
.70335 .62248 m .71433 .6238 L .7143 .62804 L p F P
0 g
s
.437 .598 .912 r
.71433 .6238 m .70335 .62248 L .70082 .61856 L p F P
0 g
s
.377 .528 .881 r
.74713 .65194 m .74294 .65081 L .74005 .64572 L p F P
0 g
s
.475 .638 .927 r
.68492 .61266 m .68221 .60879 L .68435 .60887 L closepath p F P
0 g
s
.162 .222 .678 r
.81528 .74973 m .81347 .75413 L .81713 .75895 L p F P
0 g
s
.185 .253 .7 r
.81347 .75413 m .81528 .74973 L .81113 .74507 L p F P
0 g
s
.551 .672 .917 r
.72878 .8706 m .73538 .86985 L .73253 .86598 L p F P
0 g
s
.551 .672 .917 r
.73253 .86598 m .73219 .866 L .72878 .8706 L p F P
0 g
s
.575 .67 .904 r
.72015 .86693 m .73219 .866 L .72878 .8706 L p F P
0 g
s
.276 .341 .75 r
.64018 .76587 m .63554 .76238 L .63746 .75841 L closepath p F P
0 g
s
.27 .333 .745 r
.63702 .75716 m .6326 .75347 L p .63554 .76238 L F P
0 g
s
.27 .333 .745 r
.63554 .76238 m .63746 .75841 L .63702 .75716 L p F P
0 g
s
0 0 .458 r
.60898 .66765 m .60889 .67074 L .61079 .6758 L p F P
0 g
s
0 0 .398 r
.60807 .66344 m .60744 .66135 L p .60889 .67074 L F P
0 g
s
0 0 .398 r
.60889 .67074 m .60898 .66765 L .60807 .66344 L p F P
0 g
s
.35 .483 .852 r
.7644 .67078 m .76413 .67068 L .76419 .67037 L closepath p F P
0 g
s
.373 .505 .863 r
.76413 .67068 m .76419 .67037 L .7615 .66527 L p F P
0 g
s
.27 .383 .795 r
.79037 .70397 m .79084 .70208 L p .796 .71037 L F P
0 g
s
.286 .406 .809 r
.79037 .70397 m .78908 .70109 L .79084 .70208 L closepath p F P
0 g
s
.978 .857 .47 r
.60641 .61667 m .60733 .6207 L .60571 .62675 L p F P
0 g
s
.977 .906 .672 r
.60715 .61484 m .60641 .61667 L .60733 .6207 L p F P
0 g
s
.394 .435 .785 r
.65766 .80092 m .65271 .79875 L .65124 .79503 L p F P
0 g
s
0 0 0 r
.80411 .84431 m .80427 .84406 L .80838 .83705 L p F P
0 g
s
0 0 0 r
.81139 .83253 m .80838 .83705 L .80427 .84406 L p F P
0 g
s
0 0 0 r
.81302 .82895 m .81349 .82701 L p .80838 .83705 L F P
0 g
s
0 0 0 r
.80838 .83705 m .81139 .83253 L .81302 .82895 L p F P
0 g
s
.518 .592 .868 r
.7132 .85761 m .70191 .85717 L .69895 .85182 L p F P
0 g
s
.51 .66 .928 r
.66699 .605 m .67929 .60466 L .68221 .60879 L p F P
0 g
s
.512 .665 .93 r
.67929 .60466 m .66699 .605 L .66405 .60101 L p F P
0 g
s
.329 .47 .85 r
.77236 .67399 m .7644 .67078 L .76419 .67037 L p F P
0 g
s
.335 .47 .847 r
.7644 .67078 m .77236 .67399 L .77164 .67829 L p F P
0 g
s
.484 .54 .838 r
.68052 .83815 m .69164 .84022 L .68791 .845 L p F P
0 g
s
.471 .525 .832 r
.69164 .84022 m .68052 .83815 L .67977 .83658 L p F P
0 g
s
0 0 .364 r
.60638 .65183 m .60622 .65382 L .60742 .66053 L p F P
0 g
s
0 0 .284 r
.60744 .66135 m .60742 .66053 L .60622 .65382 L p F P
0 g
s
.329 .47 .85 r
.76419 .67037 m .76468 .66642 L p .77236 .67399 L F P
0 g
s
.343 .488 .86 r
.76419 .67037 m .7615 .66527 L .76468 .66642 L closepath p F P
0 g
s
.559 .652 .897 r
.73219 .866 m .72015 .86693 L .71725 .86239 L p F P
0 g
s
0 0 .432 r
.82038 .79303 m .81934 .79512 L .82001 .80112 L p F P
0 g
s
0 0 .453 r
.81885 .80313 m .82001 .80112 L .81934 .79512 L p F P
0 g
s
.009 .126 .639 r
.61745 .69914 m .61659 .70352 L .61978 .70827 L p F P
0 g
s
0 .084 .608 r
.61659 .70352 m .61745 .69914 L .61461 .6943 L p F P
0 g
s
.246 .317 .739 r
.63702 .75716 m .6326 .75347 L .63431 .74955 L closepath p F P
0 g
s
.238 .308 .733 r
.63385 .74823 m .62982 .7445 L p .6326 .75347 L F P
0 g
s
.238 .308 .733 r
.6326 .75347 m .63431 .74955 L .63385 .74823 L p F P
0 g
s
.495 .553 .844 r
.68791 .845 m .69596 .84622 L p .6987 .85179 L F P
0 g
s
.462 .532 .844 r
.68791 .845 m .69596 .84622 L .69296 .84047 L p F P
0 g
s
.462 .532 .844 r
.69296 .84047 m .69164 .84022 L .68791 .845 L p F P
0 g
s
.394 .435 .785 r
.65124 .79503 m .65299 .79248 L p .65766 .80092 L F P
0 g
s
.373 .42 .781 r
.65124 .79503 m .64959 .79082 L .65299 .79248 L closepath p F P
0 g
s
.184 .256 .705 r
.81282 .74068 m .81113 .74507 L .81528 .74973 L p F P
0 g
s
.207 .285 .724 r
.81113 .74507 m .81282 .74068 L .8082 .73616 L p F P
0 g
s
.409 .569 .901 r
.72642 .63425 m .72165 .63338 L .71875 .62867 L p F P
0 g
s
.471 .525 .832 r
.67977 .83658 m .6828 .8329 L p .69164 .84022 L F P
0 g
s
.455 .515 .831 r
.67977 .83658 m .67748 .83172 L .6828 .8329 L closepath p F P
0 g
s
.396 .542 .885 r
.74005 .64572 m .73721 .64506 L .73754 .64132 L closepath p F P
0 g
s
.403 .552 .89 r
.73716 .64069 m .73754 .64132 L .73721 .64506 L p F P
0 g
s
.871 .737 .222 r
.60547 .63668 m .60511 .6325 L .60571 .62675 L p F P
0 g
s
.328 .456 .838 r
.77861 .68605 m .77954 .68171 L .77164 .67829 L p F P
0 g
s
.331 .464 .844 r
.77236 .67399 m .77164 .67829 L .77954 .68171 L p F P
0 g
s
.284 .406 .811 r
.79084 .70208 m .78908 .70109 L .78614 .69453 L p F P
0 g
s
0 0 .366 r
.82001 .80112 m .81885 .80313 L .81899 .80898 L p F P
0 g
s
.626 .742 .931 r
.63384 .59834 m .64595 .59511 L .6489 .59879 L p F P
0 g
s
.637 .75 .93 r
.64595 .59511 m .63384 .59834 L .63087 .59502 L p F P
0 g
s
.724 .799 .911 r
.61889 .60113 m .63087 .59502 L .63384 .59834 L p F P
0 g
s
.434 .588 .905 r
.7143 .62804 m .71875 .62867 L .71585 .624 L p F P
0 g
s
.434 .588 .905 r
.71585 .624 m .71433 .6238 L .7143 .62804 L p F P
0 g
s
0 0 .368 r
.60807 .66344 m .60744 .66135 L .60742 .66053 L closepath p F P
0 g
s
.376 .419 .778 r
.65299 .79248 m .64959 .79082 L .6476 .78568 L p F P
0 g
s
0 0 .109 r
.81349 .82701 m .81417 .82586 L .81571 .81953 L p F P
0 g
s
0 0 .085 r
.81831 .81508 m .81571 .81953 L .81417 .82586 L p F P
0 g
s
0 0 .248 r
.81571 .81953 m .81831 .81508 L .81899 .80898 L p F P
0 g
s
.048 .07 .56 r
.821 .77346 m .81895 .77786 L .82102 .78316 L p F P
0 g
s
.092 .126 .604 r
.81895 .77786 m .821 .77346 L .81835 .76833 L p F P
0 g
s
.212 .29 .727 r
.63385 .74823 m .62982 .7445 L .63126 .7408 L closepath p F P
0 g
s
.203 .279 .72 r
.63067 .73908 m .62717 .7355 L p .62982 .7445 L F P
0 g
s
.203 .279 .72 r
.62982 .7445 m .63126 .7408 L .63067 .73908 L p F P
0 g
s
.205 .289 .729 r
.80977 .73178 m .8082 .73616 L .81282 .74068 L p F P
0 g
s
.226 .314 .745 r
.8082 .73616 m .80977 .73178 L .80469 .72741 L p F P
0 g
s
.688 .974 .913 r
.78763 .86032 m .78029 .86525 L .7777 .86408 L p F P
0 g
s
.64 .855 .473 r
.80398 .84446 m .80427 .84406 L .80411 .84431 L closepath p F P
0 g
s
.323 .444 .829 r
.78321 .68825 m .77861 .68605 L p .78507 .69396 L F P
0 g
s
.309 .436 .828 r
.77861 .68605 m .78321 .68825 L .78028 .68207 L p F P
0 g
s
.309 .436 .828 r
.78028 .68207 m .77954 .68171 L .77861 .68605 L p F P
0 g
s
0 .07 .604 r
.61512 .69062 m .61461 .6943 L .61745 .69914 L p F P
0 g
s
0 .033 .576 r
.61464 .6889 m .61268 .68506 L p .61461 .6943 L F P
0 g
s
0 .033 .576 r
.61461 .6943 m .61512 .69062 L .61464 .6889 L p F P
0 g
s
.702 .917 .577 r
.80427 .84406 m .80398 .84446 L .80168 .84641 L p F P
0 g
s
0 0 0 r
.80704 .83962 m .81139 .83253 L p .80485 .84311 L F P
0 g
s
0 0 0 r
.80427 .84406 m .80704 .83962 L p .80485 .84311 L F P
0 g
s
.608 .818 .414 r
.81095 .83366 m .81238 .83103 L p .80704 .83962 L F P
0 g
s
.805 .975 .679 r
.80704 .83962 m .80998 .83511 L p .80926 .83607 L F P
0 g
s
.608 .818 .414 r
.81238 .83103 m .81139 .83253 L .80704 .83962 L p F P
0 g
s
.805 .975 .679 r
.80137 .84658 m .80704 .83962 L .80926 .83607 L F
.702 .917 .577 r
.80168 .84641 m .80704 .83962 L .80427 .84406 L p F P
0 g
s
.225 .318 .751 r
.80612 .72304 m .80469 .72741 L .80977 .73178 L p F P
0 g
s
.241 .339 .764 r
.80469 .72741 m .80612 .72304 L .80062 .71881 L p F P
0 g
s
.647 .901 .576 r
.7976 .85176 m .80398 .84446 L .80168 .84641 L p F P
0 g
s
.355 .403 .773 r
.6476 .78568 m .64646 .7827 L .64873 .78393 L closepath p F P
0 g
s
.376 .419 .778 r
.6476 .78568 m .64873 .78393 L p .65299 .79248 L F P
0 g
s
.554 .707 .942 r
.6489 .59879 m .66111 .59711 L p .66337 .60109 L F P
0 g
s
.571 .708 .935 r
.66111 .59711 m .6489 .59879 L .64595 .59511 L p F P
0 g
s
.297 .417 .815 r
.78614 .69453 m .78507 .69396 L .78536 .69281 L closepath p F P
0 g
s
.323 .444 .829 r
.78507 .69396 m .78536 .69281 L .78321 .68825 L p F P
0 g
s
0 0 .453 r
.60742 .66053 m .60769 .65704 L p .60913 .66646 L F P
0 g
s
0 0 .453 r
.60913 .66646 m .60807 .66344 L .60742 .66053 L p F P
0 g
s
0 0 .364 r
.60742 .66053 m .60769 .65704 L .60638 .65183 L p F P
0 g
s
.175 .261 .713 r
.63067 .73908 m .62717 .7355 L .62831 .73216 L closepath p F P
0 g
s
.164 .248 .705 r
.62749 .72969 m .62462 .72645 L p .62717 .7355 L F P
0 g
s
.164 .248 .705 r
.62717 .7355 m .62831 .73216 L .62749 .72969 L p F P
0 g
s
.243 .346 .77 r
.8019 .71447 m .80062 .71881 L .80612 .72304 L p F P
0 g
s
.254 .359 .778 r
.796 .71037 m .8019 .71447 L .80062 .71881 L p F P
0 g
s
.458 .513 .827 r
.6828 .8329 m .67748 .83172 L .6747 .82573 L p F P
0 g
s
.892 .911 .832 r
.61649 .59898 m .61766 .60213 L .61022 .60995 L p F P
0 g
s
.818 .857 .877 r
.61766 .60213 m .61649 .59898 L .61889 .60113 L closepath p F P
0 g
s
.27 .383 .795 r
.79084 .70208 m .79712 .70604 L .796 .71037 L p F P
0 g
s
.267 .387 .799 r
.7918 .69778 m .79084 .70208 L .79712 .70604 L p F P
0 g
s
.284 .406 .811 r
.78614 .69453 m .7918 .69778 L .79084 .70208 L p F P
0 g
s
.357 .402 .771 r
.64873 .78393 m .64646 .7827 L .6441 .77646 L p F P
0 g
s
.727 .843 .936 r
.61649 .59898 m .61889 .60113 L .63087 .59502 L p F P
0 g
s
.261 .372 .788 r
.79712 .70604 m .796 .71037 L .8019 .71447 L p F P
0 g
s
0 0 0 r
.81302 .82895 m .81417 .82586 L .81349 .82701 L closepath p F P
0 g
s
.688 .974 .913 r
.79043 .85683 m .78763 .86032 L p .7777 .86408 L F P
0 g
s
.732 .991 .86 r
.78763 .86032 m .79043 .85683 L .79228 .8568 L closepath p F P
0 g
s
.38 .523 .875 r
.75571 .65445 m .74713 .65194 L p .7563 .65906 L F P
0 g
s
.366 .519 .877 r
.74713 .65194 m .75571 .65445 L .75283 .64926 L p F P
0 g
s
.366 .519 .877 r
.75283 .64926 m .74742 .64769 L .74713 .65194 L p F P
0 g
s
.377 .528 .881 r
.74005 .64572 m .74742 .64769 L .74713 .65194 L p F P
0 g
s
.437 .598 .912 r
.70082 .61856 m .70077 .61803 L p .71433 .6238 L F P
0 g
s
.444 .607 .916 r
.70082 .61856 m .70044 .61799 L .70077 .61803 L closepath p F P
0 g
s
.584 .749 .956 r
.73538 .86985 m .74773 .86767 L .75051 .87083 L p F P
0 g
s
.57 .725 .947 r
.74773 .86767 m .73538 .86985 L .73253 .86598 L p F P
0 g
s
0 0 .201 r
.60638 .65183 m .60639 .64757 L .60562 .64221 L p F P
0 g
s
0 0 .298 r
.60639 .64757 m .60638 .65183 L .60769 .65704 L p F P
0 g
s
.374 .53 .883 r
.74742 .64769 m .74005 .64572 L .73754 .64132 L p F P
0 g
s
.485 .565 .862 r
.69895 .85182 m .6987 .85179 L .69884 .85162 L closepath p F P
0 g
s
.495 .553 .844 r
.69596 .84622 m .69884 .85162 L .6987 .85179 L p F P
0 g
s
.813 1 .833 r
.7976 .85176 m .80094 .84718 L p .79043 .85683 L F P
0 g
s
.813 1 .833 r
.79043 .85683 m .79228 .8568 L .7976 .85176 L p F P
0 g
s
.647 .901 .576 r
.80168 .84641 m .80094 .84718 L .7976 .85176 L p F P
0 g
s
.921 .757 .272 r
.60492 .62268 m .60571 .62675 L .60511 .6325 L p F P
0 g
s
.978 .857 .47 r
.60571 .62675 m .60492 .62268 L .60641 .61667 L p F P
0 g
s
0 .002 .559 r
.61464 .6889 m .61268 .68506 L .61288 .68274 L closepath p F P
0 g
s
0 0 .527 r
.61138 .67713 m .61079 .6758 L p .61268 .68506 L F P
0 g
s
0 0 .527 r
.61268 .68506 m .61288 .68274 L .61138 .67713 L p F P
0 g
s
0 0 .465 r
.60898 .66765 m .60807 .66344 L .60913 .66646 L closepath p F P
0 g
s
.518 .592 .868 r
.69895 .85182 m .71138 .85269 L p .7132 .85761 L F P
0 g
s
.493 .57 .862 r
.70843 .84755 m .71138 .85269 L .69895 .85182 L p F P
0 g
s
.493 .57 .862 r
.7028 .84694 m .70843 .84755 L p .69895 .85182 L F P
0 g
s
.493 .57 .862 r
.69895 .85182 m .69884 .85162 L .7028 .84694 L p F P
0 g
s
.09 .128 .607 r
.82033 .76391 m .81835 .76833 L .821 .77346 L p F P
0 g
s
.129 .176 .643 r
.81835 .76833 m .82033 .76391 L .81713 .75895 L p F P
0 g
s
.341 .488 .861 r
.76468 .66642 m .7615 .66527 L .75861 .65981 L p F P
0 g
s
.491 .567 .86 r
.69884 .85162 m .69596 .84622 L .7028 .84694 L closepath p F P
0 g
s
.944 .959 .729 r
.61022 .60995 m .60942 .60585 L p .60592 .61498 L F P
0 g
s
.944 .959 .729 r
.60592 .61498 m .60715 .61484 L .61022 .60995 L p F P
0 g
s
.892 .911 .832 r
.61592 .5985 m .61649 .59898 L p .61022 .60995 L F P
0 g
s
.892 .911 .832 r
.61022 .60995 m .60942 .60585 L .61592 .5985 L p F P
0 g
s
.276 .403 .811 r
.7918 .69778 m .78614 .69453 L .78536 .69281 L p F P
0 g
s
.473 .641 .93 r
.68435 .60887 m .68221 .60879 L .67929 .60466 L p F P
0 g
s
.441 .61 .919 r
.70077 .61803 m .70044 .61799 L .69754 .61365 L p F P
0 g
s
.357 .402 .771 r
.6441 .77646 m .64481 .77529 L p .64873 .78393 L F P
0 g
s
.334 .385 .765 r
.6441 .77646 m .64332 .77439 L .64481 .77529 L closepath p F P
0 g
s
.132 .228 .697 r
.62749 .72969 m .62462 .72645 L .62546 .72361 L closepath p F P
0 g
s
.119 .212 .687 r
.62429 .72004 m .62217 .71737 L p .62462 .72645 L F P
0 g
s
.119 .212 .687 r
.62462 .72645 m .62546 .72361 L .62429 .72004 L p F P
0 g
s
.437 .598 .912 r
.70077 .61803 m .71295 .61944 L p .71433 .6238 L F P
0 g
s
.437 .605 .918 r
.70077 .61803 m .71295 .61944 L .71005 .61498 L p F P
0 g
s
.437 .605 .918 r
.71005 .61498 m .70027 .61391 L .70077 .61803 L p F P
0 g
s
.441 .61 .919 r
.69754 .61365 m .70027 .61391 L .70077 .61803 L p F P
0 g
s
0 0 .432 r
.82001 .80112 m .82123 .79869 L .82038 .79303 L p F P
0 g
s
0 0 .43 r
.82251 .78864 m .82038 .79303 L .82123 .79869 L p F P
0 g
s
0 0 .502 r
.82038 .79303 m .82251 .78864 L .82102 .78316 L p F P
0 g
s
.337 .385 .764 r
.64481 .77529 m .64332 .77439 L .64072 .76737 L p F P
0 g
s
.659 .887 .981 r
.7723 .8666 m .76551 .86957 L .76281 .86724 L p F P
0 g
s
.625 .829 .979 r
.75051 .87083 m .76281 .86724 L .76551 .86957 L p F P
0 g
s
.276 .403 .811 r
.78536 .69281 m .78596 .68966 L p .7918 .69778 L F P
0 g
s
.293 .425 .825 r
.78536 .69281 m .78321 .68825 L .78596 .68966 L closepath p F P
0 g
s
.556 .695 .933 r
.66405 .60101 m .66337 .60109 L .66333 .60004 L closepath p F P
0 g
s
.554 .707 .942 r
.66111 .59711 m .66333 .60004 L .66337 .60109 L p F P
0 g
s
0 0 .34 r
.82123 .79869 m .82001 .80112 L .82031 .80671 L p F P
0 g
s
0 0 .366 r
.81899 .80898 m .82031 .80671 L .82001 .80112 L p F P
0 g
s
.522 .646 .912 r
.72966 .86184 m .71725 .86239 L .71432 .85766 L p F P
0 g
s
.559 .652 .897 r
.71725 .86239 m .72966 .86184 L p .73219 .866 L F P
0 g
s
.61 .799 .972 r
.76281 .86724 m .75051 .87083 L .74773 .86767 L p F P
0 g
s
0 0 .515 r
.60913 .66646 m .60898 .66765 L .61082 .67507 L p F P
0 g
s
0 0 .458 r
.61079 .6758 m .61082 .67507 L .60898 .66765 L p F P
0 g
s
.402 .562 .898 r
.72642 .63425 m .73427 .63584 L .73138 .63103 L p F P
0 g
s
.402 .562 .898 r
.73138 .63103 m .72639 .63004 L .72642 .63425 L p F P
0 g
s
.409 .569 .901 r
.71875 .62867 m .72639 .63004 L .72642 .63425 L p F P
0 g
s
.41 .45 .791 r
.65766 .80092 m .6652 .80428 L p .66282 .80922 L F P
0 g
s
.362 .422 .789 r
.65766 .80092 m .6652 .80428 L .6621 .79698 L p F P
0 g
s
.362 .422 .789 r
.6621 .79698 m .66055 .79622 L .65766 .80092 L p F P
0 g
s
.394 .435 .785 r
.65299 .79248 m .66055 .79622 L .65766 .80092 L p F P
0 g
s
.512 .665 .93 r
.66405 .60101 m .67636 .60057 L .67929 .60466 L p F P
0 g
s
.501 .668 .938 r
.67343 .59653 m .67636 .60057 L .66405 .60101 L p F P
0 g
s
.501 .668 .938 r
.66248 .59703 m .67343 .59653 L p .66405 .60101 L F P
0 g
s
.501 .668 .938 r
.66405 .60101 m .66333 .60004 L .66248 .59703 L p F P
0 g
s
.404 .468 .812 r
.66829 .81139 m .66282 .80922 L p .66855 .81736 L F P
0 g
s
.39 .456 .808 r
.66829 .81139 m .66282 .80922 L .6655 .80498 L closepath p F P
0 g
s
.41 .45 .791 r
.6652 .80428 m .6655 .80498 L .66282 .80922 L p F P
0 g
s
0 0 .505 r
.61138 .67713 m .61079 .6758 L .61082 .67507 L closepath p F P
0 g
s
0 0 0 r
.81417 .82586 m .81669 .82143 L p .81238 .83103 L F P
0 g
s
0 0 0 r
.81238 .83103 m .81302 .82895 L .81417 .82586 L p F P
0 g
s
0 0 .085 r
.81417 .82586 m .81669 .82143 L .81831 .81508 L p F P
0 g
s
.408 .572 .903 r
.72639 .63004 m .71875 .62867 L .71585 .624 L p F P
0 g
s
.349 .42 .793 r
.65581 .78778 m .65299 .79248 L .66055 .79622 L p F P
0 g
s
.376 .419 .778 r
.64873 .78393 m .65581 .78778 L .65299 .79248 L p F P
0 g
s
.358 .501 .865 r
.75861 .65981 m .7563 .65906 L .75666 .65616 L closepath p F P
0 g
s
.38 .523 .875 r
.7563 .65906 m .75666 .65616 L .75571 .65445 L p F P
0 g
s
.084 .19 .678 r
.62429 .72004 m .62217 .71737 L .6227 .71518 L closepath p F P
0 g
s
.068 .172 .665 r
.62109 .71009 m .61978 .70827 L p .62217 .71737 L F P
0 g
s
.068 .172 .665 r
.62217 .71737 m .6227 .71518 L .62109 .71009 L p F P
0 g
s
.337 .385 .764 r
.64072 .76737 m .64119 .76655 L p .64481 .77529 L F P
0 g
s
.312 .366 .757 r
.64072 .76737 m .64018 .76587 L .64119 .76655 L closepath p F P
0 g
s
.458 .513 .827 r
.6747 .82573 m .67503 .8253 L p .6828 .8329 L F P
0 g
s
.442 .501 .825 r
.6747 .82573 m .67443 .82515 L .67503 .8253 L closepath p F P
0 g
s
.407 .471 .814 r
.67136 .81835 m .66855 .81736 L .66998 .81524 L closepath p F P
0 g
s
.404 .468 .812 r
.66855 .81736 m .66998 .81524 L .66829 .81139 L p F P
0 g
s
.985 .894 .638 r
.60641 .61667 m .60592 .61498 L .60715 .61484 L closepath p F P
0 g
s
0 0 .25 r
.82031 .80671 m .81899 .80898 L .81831 .81508 L p F P
0 g
s
.472 .638 .928 r
.68435 .60887 m .69462 .60934 L .69171 .60508 L p F P
0 g
s
.472 .638 .928 r
.69171 .60508 m .68365 .60478 L .68435 .60887 L p F P
0 g
s
.473 .641 .93 r
.67929 .60466 m .68365 .60478 L .68435 .60887 L p F P
0 g
s
.162 .222 .678 r
.81794 .75319 m .81528 .74973 L p .81713 .75895 L F P
0 g
s
.162 .222 .678 r
.81713 .75895 m .81861 .75545 L .81794 .75319 L p F P
0 g
s
.121 .173 .644 r
.81861 .75545 m .81713 .75895 L .82033 .76391 L p F P
0 g
s
.314 .366 .756 r
.64119 .76655 m .64018 .76587 L .63746 .75841 L p F P
0 g
s
.327 .401 .786 r
.65143 .77924 m .64873 .78393 L .65581 .78778 L p F P
0 g
s
.357 .402 .771 r
.64481 .77529 m .65143 .77924 L .64873 .78393 L p F P
0 g
s
.446 .498 .819 r
.67503 .8253 m .67443 .82515 L .67136 .81835 L p F P
0 g
s
.302 .381 .778 r
.64736 .77061 m .64481 .77529 L .65143 .77924 L p F P
0 g
s
.337 .385 .764 r
.64119 .76655 m .64736 .77061 L .64481 .77529 L p F P
0 g
s
.458 .513 .827 r
.67503 .8253 m .68608 .8282 L .6828 .8329 L p F P
0 g
s
.425 .504 .836 r
.67857 .8205 m .67503 .8253 L .68608 .8282 L p F P
0 g
s
.446 .498 .819 r
.67136 .81835 m .67857 .8205 L .67503 .8253 L p F P
0 g
s
.516 .679 .939 r
.66333 .60004 m .66111 .59711 L .66248 .59703 L closepath p F P
0 g
s
0 0 .515 r
.61082 .67507 m .61126 .67146 L .60913 .66646 L p F P
0 g
s
0 .021 .567 r
.61082 .67507 m .61126 .67146 L p .61323 .68072 L F P
0 g
s
0 .021 .567 r
.61323 .68072 m .61138 .67713 L .61082 .67507 L p F P
0 g
s
.989 .842 .47 r
.60592 .61498 m .60641 .61667 L .60492 .62268 L p F P
0 g
s
.314 .366 .756 r
.63746 .75841 m .63781 .75774 L p .64119 .76655 L F P
0 g
s
.288 .345 .748 r
.63746 .75841 m .63702 .75716 L .63781 .75774 L closepath p F P
0 g
s
.289 .345 .747 r
.63781 .75774 m .63702 .75716 L .63431 .74955 L p F P
0 g
s
.03 .148 .655 r
.62109 .71009 m .61978 .70827 L .62005 .70686 L closepath p F P
0 g
s
.009 .126 .639 r
.61787 .69979 m .61745 .69914 L p .61978 .70827 L F P
0 g
s
.009 .126 .639 r
.61978 .70827 m .62005 .70686 L .61787 .69979 L p F P
0 g
s
0 .031 .571 r
.61288 .68274 m .61138 .67713 L .61323 .68072 L closepath p F P
0 g
s
0 0 0 r
.81139 .83253 m .81238 .83103 L .81302 .82895 L closepath p F P
0 g
s
0 0 .467 r
.60939 .66216 m .60913 .66646 L .61126 .67146 L p F P
0 g
s
0 0 .453 r
.60769 .65704 m .60939 .66216 L .60913 .66646 L p F P
0 g
s
.264 .346 .76 r
.64357 .76189 m .64119 .76655 L .64736 .77061 L p F P
0 g
s
.314 .366 .756 r
.63781 .75774 m .64357 .76189 L .64119 .76655 L p F P
0 g
s
.291 .426 .826 r
.78596 .68966 m .78321 .68825 L .78028 .68207 L p F P
0 g
s
.329 .47 .85 r
.76468 .66642 m .77301 .66969 L .77236 .67399 L p F P
0 g
s
.339 .483 .858 r
.76512 .66216 m .76468 .66642 L .77301 .66969 L p F P
0 g
s
.341 .488 .861 r
.75861 .65981 m .76512 .66216 L .76468 .66642 L p F P
0 g
s
.659 .887 .981 r
.77562 .86282 m .7723 .8666 L p .76281 .86724 L F P
0 g
s
.695 .908 .97 r
.7723 .8666 m .77562 .86282 L .7777 .86408 L closepath p F P
0 g
s
0 .001 .504 r
.82312 .77875 m .82102 .78316 L .82251 .78864 L p F P
0 g
s
.048 .07 .56 r
.82102 .78316 m .82312 .77875 L .821 .77346 L p F P
0 g
s
.374 .53 .883 r
.73754 .64132 m .73755 .64078 L p .74742 .64769 L F P
0 g
s
.385 .544 .89 r
.73754 .64132 m .73716 .64069 L .73755 .64078 L closepath p F P
0 g
s
.727 .843 .936 r
.63087 .59502 m .6279 .59173 L p .61649 .59898 L F P
0 g
s
.637 .75 .93 r
.63087 .59502 m .64298 .59148 L .64595 .59511 L p F P
0 g
s
.648 .758 .929 r
.64298 .59148 m .63087 .59502 L .6279 .59173 L p F P
0 g
s
.147 .212 .675 r
.81794 .75319 m .81528 .74973 L .8162 .74741 L closepath p F P
0 g
s
.184 .256 .705 r
.8147 .74278 m .81282 .74068 L p .81528 .74973 L F P
0 g
s
.184 .256 .705 r
.81528 .74973 m .8162 .74741 L .8147 .74278 L p F P
0 g
s
.494 .563 .855 r
.7028 .84694 m .69596 .84622 L .69296 .84047 L p F P
0 g
s
.289 .345 .747 r
.63431 .74955 m .63464 .74887 L p .63781 .75774 L F P
0 g
s
.261 .322 .738 r
.63431 .74955 m .63385 .74823 L .63464 .74887 L closepath p F P
0 g
s
.262 .323 .737 r
.63464 .74887 m .63385 .74823 L .63126 .7408 L p F P
0 g
s
0 .084 .608 r
.61288 .68274 m .61323 .68072 L p .61527 .68996 L F P
0 g
s
0 .084 .608 r
.61527 .68996 m .61464 .6889 L .61288 .68274 L p F P
0 g
s
.337 .488 .863 r
.76512 .66216 m .75861 .65981 L .75666 .65616 L p F P
0 g
s
.432 .504 .833 r
.6828 .8329 m .68995 .83451 L .68692 .82842 L p F P
0 g
s
.432 .504 .833 r
.68692 .82842 m .68608 .8282 L .6828 .8329 L p F P
0 g
s
.471 .525 .832 r
.6828 .8329 m .68995 .83451 L p .69164 .84022 L F P
0 g
s
.382 .546 .893 r
.73755 .64078 m .73716 .64069 L .73427 .63584 L p F P
0 g
s
.239 .324 .75 r
.63999 .75312 m .63781 .75774 L .64357 .76189 L p F P
0 g
s
.289 .345 .747 r
.63464 .74887 m .63999 .75312 L .63781 .75774 L p F P
0 g
s
.837 .639 .093 r
.60438 .62842 m .60511 .6325 L .60526 .63804 L p F P
0 g
s
.921 .757 .272 r
.60511 .6325 m .60438 .62842 L .60492 .62268 L p F P
0 g
s
.571 .708 .935 r
.64595 .59511 m .65816 .59326 L .66111 .59711 L p F P
0 g
s
.577 .714 .936 r
.65816 .59326 m .64595 .59511 L .64298 .59148 L p F P
0 g
s
.374 .53 .883 r
.73755 .64078 m .74763 .64345 L .74742 .64769 L p F P
0 g
s
.385 .543 .889 r
.73749 .63659 m .73755 .64078 L .74763 .64345 L p F P
0 g
s
.382 .546 .893 r
.73427 .63584 m .73749 .63659 L .73755 .64078 L p F P
0 g
s
0 .099 .626 r
.61787 .69979 m .61745 .69914 L .61752 .69866 L closepath p F P
0 g
s
0 .07 .604 r
.61745 .69914 m .61752 .69866 L .61512 .69062 L p F P
0 g
s
.551 .673 .918 r
.73253 .86598 m .73219 .866 L .73237 .86576 L closepath p F P
0 g
s
.559 .652 .897 r
.72966 .86184 m .73237 .86576 L .73219 .866 L p F P
0 g
s
.784 .867 .91 r
.61592 .5985 m .61643 .59815 L .61649 .59898 L closepath p F P
0 g
s
.727 .843 .936 r
.6279 .59173 m .61643 .59815 L .61649 .59898 L p F P
0 g
s
.262 .323 .737 r
.63126 .7408 m .63164 .73995 L p .63464 .74887 L F P
0 g
s
.231 .298 .726 r
.63126 .7408 m .63067 .73908 L .63164 .73995 L closepath p F P
0 g
s
0 .09 .61 r
.61512 .69062 m .61464 .6889 L .61527 .68996 L closepath p F P
0 g
s
.508 .607 .886 r
.71432 .85766 m .7132 .85761 L .71381 .8568 L closepath p F P
0 g
s
.518 .592 .868 r
.71138 .85269 m .71381 .8568 L .7132 .85761 L p F P
0 g
s
.43 .485 .815 r
.67857 .8205 m .67136 .81835 L .66998 .81524 L p F P
0 g
s
.317 .457 .843 r
.77236 .67399 m .77737 .67615 L .77446 .67032 L p F P
0 g
s
.317 .457 .843 r
.77446 .67032 m .77301 .66969 L .77236 .67399 L p F P
0 g
s
.331 .464 .844 r
.77737 .67615 m .77236 .67399 L p .77954 .68171 L F P
0 g
s
.231 .298 .726 r
.63164 .73995 m .63067 .73908 L .62831 .73216 L p F P
0 g
s
.57 .725 .947 r
.73253 .86598 m .74492 .86424 L .74773 .86767 L p F P
0 g
s
.565 .68 .916 r
.74209 .86058 m .74492 .86424 L .73253 .86598 L p F P
0 g
s
.565 .68 .916 r
.73656 .86114 m .74209 .86058 L p .73253 .86598 L F P
0 g
s
.565 .68 .916 r
.73253 .86598 m .73237 .86576 L .73656 .86114 L p F P
0 g
s
.014 .121 .633 r
.61527 .68996 m .61512 .69062 L .61752 .69866 L p F P
0 g
s
.169 .247 .702 r
.8147 .74278 m .81282 .74068 L .81345 .73897 L closepath p F P
0 g
s
.205 .289 .729 r
.81155 .73353 m .80977 .73178 L p .81282 .74068 L F P
0 g
s
.205 .289 .729 r
.81282 .74068 m .81345 .73897 L .81155 .73353 L p F P
0 g
s
.432 .589 .907 r
.71585 .624 m .71433 .6238 L .71429 .62152 L closepath p F P
0 g
s
.437 .598 .912 r
.71295 .61944 m .71429 .62152 L .71433 .6238 L p F P
0 g
s
.564 .678 .916 r
.73237 .86576 m .72966 .86184 L .73656 .86114 L closepath p F P
0 g
s
.21 .3 .739 r
.63661 .74428 m .63464 .74887 L .63999 .75312 L p F P
0 g
s
.262 .323 .737 r
.63164 .73995 m .63661 .74428 L .63464 .74887 L p F P
0 g
s
.231 .298 .726 r
.62831 .73216 m .62878 .73098 L p .63164 .73995 L F P
0 g
s
.198 .271 .713 r
.62831 .73216 m .62749 .72969 L .62878 .73098 L closepath p F P
0 g
s
0 0 .364 r
.60762 .65281 m .60769 .65704 L .60939 .66216 L p F P
0 g
s
0 0 .298 r
.60769 .65704 m .60762 .65281 L .60639 .64757 L p F P
0 g
s
.442 .613 .922 r
.70027 .61391 m .69754 .61365 L .69462 .60934 L p F P
0 g
s
.197 .27 .714 r
.62878 .73098 m .62749 .72969 L .62546 .72361 L p F P
0 g
s
.688 .974 .913 r
.7777 .86408 m .78979 .85674 L .79043 .85683 L p F P
0 g
s
.76 .922 .943 r
.77562 .86282 m .7777 .86408 L .78979 .85674 L p F P
0 g
s
.062 .165 .66 r
.61752 .69866 m .61837 .69472 L p .62085 .70383 L F P
0 g
s
.062 .165 .66 r
.62085 .70383 m .61787 .69979 L .61752 .69866 L p F P
0 g
s
.014 .121 .633 r
.61752 .69866 m .61837 .69472 L .61527 .68996 L p F P
0 g
s
.071 .169 .66 r
.62005 .70686 m .61787 .69979 L .62085 .70383 L closepath p F P
0 g
s
.475 .646 .932 r
.68365 .60478 m .67929 .60466 L .67636 .60057 L p F P
0 g
s
.522 .646 .912 r
.71432 .85766 m .72677 .85751 L .72966 .86184 L p F P
0 g
s
.52 .613 .885 r
.72386 .85298 m .72677 .85751 L .71432 .85766 L p F P
0 g
s
.52 .613 .885 r
.71716 .85282 m .72386 .85298 L p .71432 .85766 L F P
0 g
s
.52 .613 .885 r
.71432 .85766 m .71381 .8568 L .71716 .85282 L p F P
0 g
s
.197 .27 .714 r
.62546 .72361 m .62604 .72196 L p .62878 .73098 L F P
0 g
s
.161 .241 .699 r
.62546 .72361 m .62429 .72004 L .62604 .72196 L closepath p F P
0 g
s
.158 .24 .699 r
.62604 .72196 m .62429 .72004 L .6227 .71518 L p F P
0 g
s
0 0 .34 r
.82031 .80671 m .82139 .80455 L .82123 .79869 L p F P
0 g
s
0 0 .334 r
.82337 .7943 m .82123 .79869 L .82139 .80455 L p F P
0 g
s
0 0 .43 r
.82123 .79869 m .82337 .7943 L .82251 .78864 L p F P
0 g
s
.119 .207 .681 r
.6227 .71518 m .62109 .71009 L .6234 .71291 L closepath p F P
0 g
s
.113 .205 .682 r
.6234 .71291 m .62109 .71009 L .62005 .70686 L p F P
0 g
s
.113 .205 .682 r
.62005 .70686 m .62085 .70383 L p .6234 .71291 L F P
0 g
s
.158 .24 .699 r
.6227 .71518 m .6234 .71291 L p .62604 .72196 L F P
0 g
s
.977 .892 .536 r
.60428 .61653 m .60558 .61258 L .60592 .61498 L closepath p F P
0 g
s
.944 .959 .729 r
.60942 .60585 m .60558 .61258 L .60592 .61498 L p F P
0 g
s
.989 .842 .47 r
.60428 .61653 m .60592 .61498 L p .60492 .62268 L F P
0 g
s
.305 .437 .83 r
.78028 .68207 m .77954 .68171 L .7797 .68085 L closepath p F P
0 g
s
.331 .464 .844 r
.77954 .68171 m .7797 .68085 L .77737 .67615 L p F P
0 g
s
.191 .28 .726 r
.81155 .73353 m .80977 .73178 L .81034 .73009 L closepath p F P
0 g
s
.225 .318 .751 r
.80846 .72507 m .80612 .72304 L p .80977 .73178 L F P
0 g
s
.225 .318 .751 r
.80977 .73178 m .81034 .73009 L .80846 .72507 L p F P
0 g
s
.803 .87 .897 r
.61643 .59815 m .61592 .5985 L .61294 .59607 L p F P
0 g
s
.879 .868 .823 r
.60942 .60585 m .61592 .5985 L .61294 .59607 L p F P
0 g
s
.43 .485 .815 r
.66998 .81524 m .67186 .8126 L p .67857 .8205 L F P
0 g
s
.413 .473 .813 r
.66998 .81524 m .66829 .81139 L .67186 .8126 L closepath p F P
0 g
s
.039 .066 .56 r
.82242 .77033 m .821 .77346 L .82312 .77875 L p F P
0 g
s
.09 .128 .607 r
.82137 .76591 m .82033 .76391 L p .821 .77346 L F P
0 g
s
.09 .128 .607 r
.821 .77346 m .82242 .77033 L .82137 .76591 L p F P
0 g
s
.803 .87 .897 r
.61294 .59607 m .61575 .59399 L .61643 .59815 L p F P
0 g
s
.741 .809 .906 r
.62491 .58848 m .61575 .59399 L .61643 .59815 L p F P
0 g
s
.741 .809 .906 r
.61643 .59815 m .6279 .59173 L .62491 .58848 L p F P
0 g
s
.458 .536 .85 r
.69296 .84047 m .69164 .84022 L .69234 .83925 L closepath p F P
0 g
s
.471 .525 .832 r
.68995 .83451 m .69234 .83925 L .69164 .84022 L p F P
0 g
s
0 .068 .606 r
.61597 .68557 m .61527 .68996 L .61837 .69472 L p F P
0 g
s
0 .084 .608 r
.61323 .68072 m .61597 .68557 L .61527 .68996 L p F P
0 g
s
.77 .99 .89 r
.78979 .85674 m .79115 .85571 L .79043 .85683 L closepath p F P
0 g
s
.813 1 .833 r
.80094 .84718 m .79115 .85571 L .79043 .85683 L p F P
0 g
s
.177 .274 .726 r
.63338 .73539 m .63164 .73995 L .63661 .74428 L p F P
0 g
s
.231 .298 .726 r
.62878 .73098 m .63338 .73539 L .63164 .73995 L p F P
0 g
s
0 0 .066 r
.8202 .81183 m .81831 .81508 L .81669 .82143 L p F P
0 g
s
0 0 .25 r
.81831 .81508 m .8202 .81183 L .82031 .80671 L p F P
0 g
s
.518 .611 .884 r
.71381 .8568 m .71138 .85269 L .71716 .85282 L closepath p F P
0 g
s
0 0 .221 r
.82139 .80455 m .82031 .80671 L .8202 .81183 L p F P
0 g
s
.408 .572 .903 r
.71585 .624 m .72629 .62584 L .72639 .63004 L p F P
0 g
s
.407 .575 .906 r
.72629 .62584 m .71585 .624 L .71429 .62152 L p F P
0 g
s
.276 .403 .811 r
.78596 .68966 m .7927 .69347 L .7918 .69778 L p F P
0 g
s
.284 .417 .821 r
.78668 .68538 m .78596 .68966 L .7927 .69347 L p F P
0 g
s
.291 .426 .826 r
.78028 .68207 m .78668 .68538 L .78596 .68966 L p F P
0 g
s
.211 .31 .748 r
.80846 .72507 m .80612 .72304 L .80684 .72073 L closepath p F P
0 g
s
.243 .346 .77 r
.80542 .71716 m .8019 .71447 L p .80612 .72304 L F P
0 g
s
.243 .346 .77 r
.80612 .72304 m .80684 .72073 L .80542 .71716 L p F P
0 g
s
.283 .423 .827 r
.78668 .68538 m .78028 .68207 L .7797 .68085 L p F P
0 g
s
.337 .488 .863 r
.75666 .65616 m .75674 .65478 L p .76512 .66216 L F P
0 g
s
.35 .505 .872 r
.75666 .65616 m .75571 .65445 L .75674 .65478 L closepath p F P
0 g
s
.515 .682 .942 r
.66248 .59703 m .66111 .59711 L .65816 .59326 L p F P
0 g
s
.953 .765 .309 r
.60381 .61869 m .60492 .62268 L .60438 .62842 L p F P
0 g
s
.989 .842 .47 r
.60492 .62268 m .60381 .61869 L .60428 .61653 L p F P
0 g
s
.61 .799 .972 r
.74773 .86767 m .76007 .86458 L .76281 .86724 L p F P
0 g
s
.595 .772 .964 r
.76007 .86458 m .74773 .86767 L .74492 .86424 L p F P
0 g
s
.365 .52 .879 r
.74742 .64769 m .75283 .64926 L .74993 .64411 L p F P
0 g
s
.365 .52 .879 r
.74993 .64411 m .74763 .64345 L .74742 .64769 L p F P
0 g
s
.267 .387 .799 r
.79712 .70604 m .79819 .70171 L .7918 .69778 L p F P
0 g
s
.269 .394 .806 r
.7927 .69347 m .7918 .69778 L .79819 .70171 L p F P
0 g
s
.229 .338 .768 r
.80542 .71716 m .8019 .71447 L .80291 .71086 L closepath p F P
0 g
s
.261 .372 .788 r
.8024 .70965 m .79712 .70604 L p .8019 .71447 L F P
0 g
s
.261 .372 .788 r
.8019 .71447 m .80291 .71086 L .8024 .70965 L p F P
0 g
s
.965 .918 .708 r
.60825 .60185 m .60942 .60585 L .60558 .61258 L p F P
0 g
s
.879 .868 .823 r
.61294 .59607 m .60825 .60185 L .60942 .60585 L p F P
0 g
s
.243 .361 .785 r
.79712 .70604 m .8024 .70965 L .79942 .70256 L p F P
0 g
s
.243 .361 .785 r
.79942 .70256 m .79819 .70171 L .79712 .70604 L p F P
0 g
s
0 0 .225 r
.60599 .64342 m .60639 .64757 L .60762 .65281 L p F P
0 g
s
0 0 .154 r
.60599 .64342 m .60716 .64869 L p .60609 .64353 L F P
0 g
s
0 0 .122 r
.60599 .64342 m .60526 .63804 L p .60589 .64331 L F P
0 g
s
.752 .529 0 r
.60523 .63936 m .60453 .63396 L p .60537 .63939 L F P
0 g
s
.752 .529 0 r
.60599 .64342 m .60523 .63936 L p .60537 .63939 L F P
0 g
s
0 0 .154 r
.60523 .63936 m .60599 .64342 L p .60609 .64353 L F P
0 g
s
.749 .482 0 r
.60523 .63936 m .60635 .64464 L p .60509 .63932 L F P
0 g
s
.749 .482 0 r
.60416 .63537 m .60523 .63936 L p .60509 .63932 L F P
0 g
s
0 0 .122 r
.60639 .64757 m .60599 .64342 L p .60589 .64331 L F P
0 g
s
.494 .563 .855 r
.69296 .84047 m .70546 .84225 L p .7028 .84694 L F P
0 g
s
.467 .542 .85 r
.70247 .83674 m .70546 .84225 L .69296 .84047 L p F P
0 g
s
.467 .542 .85 r
.69528 .83545 m .70247 .83674 L p .69296 .84047 L F P
0 g
s
.467 .542 .85 r
.69296 .84047 m .69234 .83925 L .69528 .83545 L p F P
0 g
s
.805 .975 .679 r
.80137 .84658 m .80168 .84641 L .80704 .83962 L p F P
0 g
s
.608 .818 .414 r
.80704 .83962 m .80998 .83511 L .81095 .83366 L p F P
0 g
s
.659 .887 .981 r
.76281 .86724 m .77506 .86245 L .77562 .86282 L p F P
0 g
s
.643 .857 .981 r
.77506 .86245 m .76281 .86724 L .76007 .86458 L p F P
0 g
s
.416 .471 .81 r
.67186 .8126 m .66829 .81139 L .6655 .80498 L p F P
0 g
s
.139 .244 .711 r
.63028 .72646 m .62878 .73098 L .63338 .73539 L p F P
0 g
s
.197 .27 .714 r
.62604 .72196 m .63028 .72646 L .62878 .73098 L p F P
0 g
s
.283 .423 .827 r
.7797 .68085 m .78015 .67745 L p .78668 .68538 L F P
0 g
s
.3 .445 .839 r
.7797 .68085 m .77737 .67615 L .78015 .67745 L closepath p F P
0 g
s
.438 .609 .92 r
.70027 .61391 m .71005 .61498 L .70714 .61057 L p F P
0 g
s
.438 .609 .92 r
.70714 .61057 m .69969 .6098 L .70027 .61391 L p F P
0 g
s
.442 .613 .922 r
.69462 .60934 m .69969 .6098 L .70027 .61391 L p F P
0 g
s
0 0 .559 r
.61364 .6764 m .61323 .68072 L .61597 .68557 L p F P
0 g
s
0 .021 .567 r
.61126 .67146 m .61364 .6764 L .61323 .68072 L p F P
0 g
s
0 0 0 r
.81095 .83366 m .81402 .82808 L .81238 .83103 L closepath p F P
0 g
s
0 0 0 r
.8165 .82366 m .8193 .81697 L p .81421 .82769 L F P
0 g
s
0 0 0 r
.81402 .82808 m .8165 .82366 L p .81421 .82769 L F P
0 g
s
0 0 0 r
.81669 .82143 m .81402 .82808 L p .81238 .83101 L F P
0 g
s
0 0 0 r
.8193 .81697 m .81669 .82143 L .81402 .82808 L p F P
0 g
s
0 0 0 r
.81961 .81642 m .8193 .81697 L .8165 .82366 L p F P
0 g
s
0 0 0 r
.8165 .82366 m .8184 .82032 L .81961 .81642 L p F P
0 g
s
.678 .851 .441 r
.8165 .82366 m .8124 .83071 L p .81824 .8206 L F P
0 g
s
.678 .851 .441 r
.8184 .82032 m .8165 .82366 L p .81824 .8206 L F P
0 g
s
.736 .867 .447 r
.81402 .82808 m .8165 .82366 L p .81648 .82368 L F P
0 g
s
.736 .867 .447 r
.81053 .83425 m .81402 .82808 L .81648 .82368 L F
0 0 0 r
.81402 .82808 m .81238 .83103 L p .81238 .83101 L F P
0 g
s
.119 .194 .667 r
.8162 .74741 m .81689 .74537 L p .81894 .75456 L F P
0 g
s
.119 .194 .667 r
.81894 .75456 m .81794 .75319 L .8162 .74741 L p F P
0 g
s
.144 .23 .694 r
.8162 .74741 m .8147 .74278 L .81689 .74537 L closepath p F P
0 g
s
.518 .682 .94 r
.66248 .59703 m .67343 .59653 L .67049 .59252 L p F P
0 g
s
.518 .682 .94 r
.67049 .59252 m .66127 .59306 L .66248 .59703 L p F P
0 g
s
.515 .682 .942 r
.65816 .59326 m .66127 .59306 L .66248 .59703 L p F P
0 g
s
.465 .539 .848 r
.69234 .83925 m .68995 .83451 L .69528 .83545 L closepath p F P
0 g
s
.143 .229 .695 r
.81689 .74537 m .8147 .74278 L .81345 .73897 L p F P
0 g
s
.143 .229 .695 r
.81345 .73897 m .81426 .73633 L p .81689 .74537 L F P
0 g
s
.167 .263 .719 r
.81345 .73897 m .81155 .73353 L .81426 .73633 L closepath p F P
0 g
s
.346 .506 .874 r
.75674 .65478 m .75571 .65445 L .75283 .64926 L p F P
0 g
s
.074 .117 .603 r
.82137 .76591 m .82033 .76391 L .82069 .76308 L closepath p F P
0 g
s
.121 .173 .644 r
.82033 .76391 m .82069 .76308 L .81861 .75545 L p F P
0 g
s
.764 .977 .917 r
.79115 .85571 m .78979 .85674 L .78724 .85595 L p F P
0 g
s
.76 .922 .943 r
.78979 .85674 m .78724 .85595 L p .77562 .86282 L F P
0 g
s
.121 .194 .667 r
.81861 .75545 m .81794 .75319 L .81894 .75456 L closepath p F P
0 g
s
.773 .994 .877 r
.80137 .84658 m .80094 .84718 L .79115 .85571 L p F P
0 g
s
.773 .994 .877 r
.79927 .84707 m .80137 .84658 L p .79115 .85571 L F P
0 g
s
.773 .994 .877 r
.79115 .85571 m .79398 .85125 L .79927 .84707 L p F P
0 g
s
.764 .977 .917 r
.78724 .85595 m .79398 .85125 L .79115 .85571 L p F P
0 g
s
.075 .142 .63 r
.81894 .75456 m .81861 .75545 L .82069 .76308 L p F P
0 g
s
.095 .21 .694 r
.6273 .7175 m .62604 .72196 L .63028 .72646 L p F P
0 g
s
.158 .24 .699 r
.6234 .71291 m .6273 .7175 L .62604 .72196 L p F P
0 g
s
.165 .263 .72 r
.81426 .73633 m .81155 .73353 L .81034 .73009 L p F P
0 g
s
.402 .564 .9 r
.72639 .63004 m .73138 .63103 L .72849 .62626 L p F P
0 g
s
.402 .564 .9 r
.72849 .62626 m .72629 .62584 L .72639 .63004 L p F P
0 g
s
.379 .547 .895 r
.73749 .63659 m .73427 .63584 L .73138 .63103 L p F P
0 g
s
.708 .957 .689 r
.80094 .84718 m .80137 .84658 L .80168 .84641 L closepath p F P
0 g
s
0 0 .432 r
.82465 .78422 m .82251 .78864 L .82337 .7943 L p F P
0 g
s
0 .001 .504 r
.82251 .78864 m .82465 .78422 L .82312 .77875 L p F P
0 g
s
.407 .575 .906 r
.71429 .62152 m .7141 .61962 L p .72629 .62584 L F P
0 g
s
.416 .586 .911 r
.71429 .62152 m .71295 .61944 L .7141 .61962 L closepath p F P
0 g
s
.476 .643 .93 r
.68365 .60478 m .69171 .60508 L .68878 .60086 L p F P
0 g
s
.476 .643 .93 r
.68878 .60086 m .68288 .6007 L .68365 .60478 L p F P
0 g
s
.475 .646 .932 r
.67636 .60057 m .68288 .6007 L .68365 .60478 L p F P
0 g
s
.165 .263 .72 r
.81034 .73009 m .81108 .72745 L p .81426 .73633 L F P
0 g
s
.188 .294 .742 r
.81034 .73009 m .80846 .72507 L .81108 .72745 L closepath p F P
0 g
s
.337 .488 .863 r
.75674 .65478 m .76548 .65791 L .76512 .66216 L p F P
0 g
s
.347 .502 .87 r
.75689 .65057 m .75674 .65478 L .76548 .65791 L p F P
0 g
s
.346 .506 .874 r
.75283 .64926 m .75689 .65057 L .75674 .65478 L p F P
0 g
s
.482 .577 .874 r
.70843 .84755 m .7028 .84694 L .7057 .84269 L closepath p F P
0 g
s
.494 .563 .855 r
.70546 .84225 m .7057 .84269 L .7028 .84694 L p F P
0 g
s
.837 .639 .093 r
.60526 .63804 m .60453 .63396 L .60438 .62842 L p F P
0 g
s
0 0 .495 r
.61138 .6672 m .61126 .67146 L .61364 .6764 L p F P
0 g
s
0 0 .467 r
.61126 .67146 m .61138 .6672 L .60939 .66216 L p F P
0 g
s
.648 .758 .929 r
.6279 .59173 m .64002 .58788 L .64298 .59148 L p F P
0 g
s
.659 .764 .928 r
.64002 .58788 m .6279 .59173 L .62491 .58848 L p F P
0 g
s
.416 .471 .81 r
.6655 .80498 m .66581 .80452 L p .67186 .8126 L F P
0 g
s
.397 .458 .806 r
.6655 .80498 m .6652 .80428 L .66581 .80452 L closepath p F P
0 g
s
.567 .668 .906 r
.73656 .86114 m .72966 .86184 L .72677 .85751 L p F P
0 g
s
.521 .605 .877 r
.71716 .85282 m .71138 .85269 L .70843 .84755 L p F P
0 g
s
.04 .094 .592 r
.82069 .76308 m .82196 .75957 L p .82292 .76906 L F P
0 g
s
.04 .094 .592 r
.82292 .76906 m .82137 .76591 L .82069 .76308 L p F P
0 g
s
.075 .142 .63 r
.82069 .76308 m .82196 .75957 L .81894 .75456 L p F P
0 g
s
.401 .456 .803 r
.66581 .80452 m .6652 .80428 L .6621 .79698 L p F P
0 g
s
.044 .171 .673 r
.62441 .70849 m .6234 .71291 L .6273 .7175 L p F P
0 g
s
.113 .205 .682 r
.62085 .70383 m .62441 .70849 L .6234 .71291 L p F P
0 g
s
.969 .893 .522 r
.60558 .61258 m .60466 .60851 L p .6034 .61748 L F P
0 g
s
.969 .893 .522 r
.6034 .61748 m .60428 .61653 L .60558 .61258 L p F P
0 g
s
.965 .918 .708 r
.60558 .61258 m .60466 .60851 L .60825 .60185 L p F P
0 g
s
.781 .994 .778 r
.79927 .84707 m .80361 .84275 L .80137 .84658 L closepath p F P
0 g
s
.805 .975 .679 r
.80998 .83511 m .80361 .84275 L .80137 .84658 L p F P
0 g
s
.186 .294 .742 r
.81108 .72745 m .80846 .72507 L .80684 .72073 L p F P
0 g
s
0 0 .066 r
.8198 .81513 m .8202 .81183 L p .81669 .82143 L F P
0 g
s
0 0 .066 r
.81669 .82143 m .8193 .81697 L .8198 .81513 L p F P
0 g
s
.577 .714 .936 r
.64298 .59148 m .65521 .58945 L .65816 .59326 L p F P
0 g
s
.583 .72 .937 r
.65521 .58945 m .64298 .59148 L .64002 .58788 L p F P
0 g
s
.119 .194 .667 r
.81689 .74537 m .8204 .75024 L .81894 .75456 L p F P
0 g
s
.071 .142 .632 r
.8204 .75024 m .81894 .75456 L .82196 .75957 L p F P
0 g
s
.297 .445 .84 r
.78015 .67745 m .77737 .67615 L .77446 .67032 L p F P
0 g
s
.353 .424 .796 r
.6621 .79698 m .66055 .79622 L .66125 .79495 L closepath p F P
0 g
s
.349 .42 .793 r
.65899 .78952 m .65581 .78778 L p .66055 .79622 L F P
0 g
s
.349 .42 .793 r
.66055 .79622 m .66125 .79495 L .65899 .78952 L p F P
0 g
s
.443 .617 .924 r
.69969 .6098 m .69462 .60934 L .69171 .60508 L p F P
0 g
s
0 0 .334 r
.82139 .80455 m .82353 .80017 L .82337 .7943 L p F P
0 g
s
0 0 .221 r
.8202 .81183 m .82081 .81063 L .82139 .80455 L p F P
0 g
s
0 0 .204 r
.82353 .80017 m .82139 .80455 L .82081 .81063 L p F P
0 g
s
.416 .471 .81 r
.66581 .80452 m .67473 .80794 L .67186 .8126 L p F P
0 g
s
.374 .459 .819 r
.66875 .79981 m .66581 .80452 L .67473 .80794 L p F P
0 g
s
.401 .456 .803 r
.6621 .79698 m .66875 .79981 L .66581 .80452 L p F P
0 g
s
.331 .407 .789 r
.65899 .78952 m .65581 .78778 L .65717 .7851 L closepath p F P
0 g
s
.327 .401 .786 r
.65588 .78192 m .65143 .77924 L p .65581 .78778 L F P
0 g
s
.327 .401 .786 r
.65581 .78778 m .65717 .7851 L .65588 .78192 L p F P
0 g
s
.043 .095 .592 r
.82242 .77033 m .82137 .76591 L .82292 .76906 L closepath p F P
0 g
s
.468 .536 .844 r
.69528 .83545 m .68995 .83451 L .68692 .82842 L p F P
0 g
s
.478 .65 .935 r
.68288 .6007 m .67636 .60057 L .67343 .59653 L p F P
0 g
s
.186 .294 .742 r
.80684 .72073 m .80734 .71872 L p .81108 .72745 L F P
0 g
s
.208 .323 .763 r
.80684 .72073 m .80542 .71716 L .80734 .71872 L closepath p F P
0 g
s
.307 .387 .782 r
.65588 .78192 m .65143 .77924 L .65322 .77537 L closepath p F P
0 g
s
.302 .381 .778 r
.65275 .7742 m .64736 .77061 L p .65143 .77924 L F P
0 g
s
.302 .381 .778 r
.65143 .77924 m .65322 .77537 L .65275 .7742 L p F P
0 g
s
.716 .903 .962 r
.77506 .86245 m .77619 .86189 L .77562 .86282 L closepath p F P
0 g
s
.76 .922 .943 r
.78724 .85595 m .77619 .86189 L .77562 .86282 L p F P
0 g
s
.339 .483 .858 r
.77155 .66466 m .76512 .66216 L p .77301 .66969 L F P
0 g
s
.324 .476 .858 r
.76512 .66216 m .77155 .66466 L .76865 .65914 L p F P
0 g
s
.324 .476 .858 r
.76865 .65914 m .76548 .65791 L .76512 .66216 L p F P
0 g
s
0 0 .41 r
.60922 .65796 m .60939 .66216 L .61138 .6672 L p F P
0 g
s
0 0 .364 r
.60939 .66216 m .60922 .65796 L .60762 .65281 L p F P
0 g
s
.43 .485 .815 r
.67186 .8126 m .68083 .81572 L p .67857 .8205 L F P
0 g
s
.388 .459 .812 r
.67186 .8126 m .68083 .81572 L .67776 .80912 L p F P
0 g
s
.388 .459 .812 r
.67776 .80912 m .67473 .80794 L .67186 .8126 L p F P
0 g
s
0 .126 .647 r
.62161 .69946 m .62085 .70383 L .62441 .70849 L p F P
0 g
s
.062 .165 .66 r
.61837 .69472 m .62161 .69946 L .62085 .70383 L p F P
0 g
s
.413 .588 .914 r
.7141 .61962 m .71295 .61944 L .71005 .61498 L p F P
0 g
s
.269 .351 .763 r
.64736 .77061 m .65275 .7742 L .64961 .76632 L p F P
0 g
s
.269 .351 .763 r
.64961 .76632 m .64928 .76608 L .64736 .77061 L p F P
0 g
s
.264 .346 .76 r
.64736 .77061 m .64928 .76608 L .64357 .76189 L p F P
0 g
s
.888 .666 .148 r
.60331 .62442 m .60438 .62842 L .60453 .63396 L p F P
0 g
s
.953 .765 .309 r
.60438 .62842 m .60331 .62442 L .60381 .61869 L p F P
0 g
s
.105 .189 .668 r
.81825 .74106 m .81689 .74537 L .8204 .75024 L p F P
0 g
s
.143 .229 .695 r
.81426 .73633 m .81825 .74106 L .81689 .74537 L p F P
0 g
s
.039 .066 .56 r
.82312 .77875 m .82383 .77719 L .82242 .77033 L p F P
0 g
s
0 0 .502 r
.82383 .77719 m .82312 .77875 L .82465 .78422 L p F P
0 g
s
.385 .543 .889 r
.74704 .63904 m .73749 .63659 L p .74763 .64345 L F P
0 g
s
.37 .538 .891 r
.73749 .63659 m .74704 .63904 L .74415 .63414 L p F P
0 g
s
.37 .538 .891 r
.74415 .63414 m .73734 .63242 L .73749 .63659 L p F P
0 g
s
.379 .547 .895 r
.73138 .63103 m .73734 .63242 L .73749 .63659 L p F P
0 g
s
.206 .323 .763 r
.80734 .71872 m .80542 .71716 L .80291 .71086 L p F P
0 g
s
0 .028 .541 r
.82292 .76906 m .82242 .77033 L .82383 .77719 L p F P
0 g
s
.425 .504 .836 r
.68388 .82212 m .67857 .8205 L p .68608 .8282 L F P
0 g
s
.412 .493 .833 r
.68388 .82212 m .67857 .8205 L .68111 .81631 L closepath p F P
0 g
s
.43 .485 .815 r
.68083 .81572 m .68111 .81631 L .67857 .8205 L p F P
0 g
s
.252 .343 .763 r
.64533 .75739 m .64357 .76189 L .64928 .76608 L p F P
0 g
s
.239 .324 .75 r
.64357 .76189 m .64533 .75739 L .63999 .75312 L p F P
0 g
s
.383 .443 .799 r
.66875 .79981 m .6621 .79698 L .66125 .79495 L p F P
0 g
s
.407 .575 .906 r
.7141 .61962 m .72559 .62156 L p .72629 .62584 L F P
0 g
s
.406 .582 .912 r
.7141 .61962 m .72559 .62156 L .72269 .61701 L p F P
0 g
s
.406 .582 .912 r
.72269 .61701 m .71356 .61551 L .7141 .61962 L p F P
0 g
s
.413 .588 .914 r
.71005 .61498 m .71356 .61551 L .7141 .61962 L p F P
0 g
s
.996 .838 .49 r
.60381 .61869 m .6034 .61748 L .60428 .61653 L closepath p F P
0 g
s
.699 .879 .965 r
.77619 .86189 m .77506 .86245 L .77239 .86038 L p F P
0 g
s
.643 .857 .981 r
.76007 .86458 m .77239 .86038 L .77506 .86245 L p F P
0 g
s
.313 .457 .845 r
.77446 .67032 m .77301 .66969 L .77324 .6679 L closepath p F P
0 g
s
.339 .483 .858 r
.77301 .66969 m .77324 .6679 L .77155 .66466 L p F P
0 g
s
.343 .507 .876 r
.75689 .65057 m .75283 .64926 L .74993 .64411 L p F P
0 g
s
.519 .687 .944 r
.66127 .59306 m .65816 .59326 L .65521 .58945 L p F P
0 g
s
.595 .772 .964 r
.74492 .86424 m .75731 .86165 L .76007 .86458 L p F P
0 g
s
.58 .748 .957 r
.75731 .86165 m .74492 .86424 L .74209 .86058 L p F P
0 g
s
0 0 .074 r
.8198 .81513 m .82081 .81063 L .8202 .81183 L closepath p F P
0 g
s
0 .072 .614 r
.61887 .6904 m .61837 .69472 L .62161 .69946 L p F P
0 g
s
0 .068 .606 r
.61837 .69472 m .61887 .6904 L .61597 .68557 L p F P
0 g
s
0 0 .298 r
.60716 .64869 m .60762 .65281 L .60922 .65796 L p F P
0 g
s
0 0 .225 r
.60762 .65281 m .60716 .64869 L .60599 .64342 L p F P
0 g
s
.819 .865 .881 r
.61575 .59399 m .61294 .59607 L .60995 .59368 L p F P
0 g
s
.893 .868 .807 r
.60825 .60185 m .61294 .59607 L .60995 .59368 L p F P
0 g
s
.699 .879 .965 r
.77239 .86038 m .77883 .85749 L .77619 .86189 L p F P
0 g
s
.716 .939 .958 r
.78464 .8547 m .77883 .85749 L .77619 .86189 L p F P
0 g
s
.716 .939 .958 r
.77619 .86189 m .78724 .85595 L .78464 .8547 L p F P
0 g
s
.383 .443 .799 r
.66125 .79495 m .66328 .79155 L p .66875 .79981 L F P
0 g
s
.363 .428 .795 r
.66125 .79495 m .65899 .78952 L .66328 .79155 L closepath p F P
0 g
s
.22 .319 .753 r
.64158 .74864 m .63999 .75312 L .64533 .75739 L p F P
0 g
s
.21 .3 .739 r
.63999 .75312 m .64158 .74864 L .63661 .74428 L p F P
0 g
s
.134 .229 .698 r
.81551 .73203 m .81426 .73633 L .81825 .74106 L p F P
0 g
s
.165 .263 .72 r
.81108 .72745 m .81551 .73203 L .81426 .73633 L p F P
0 g
s
.819 .865 .881 r
.60995 .59368 m .61457 .58996 L .61575 .59399 L p F P
0 g
s
.754 .814 .9 r
.62192 .58525 m .61457 .58996 L .61575 .59399 L p F P
0 g
s
.754 .814 .9 r
.61575 .59399 m .62491 .58848 L .62192 .58525 L p F P
0 g
s
.428 .507 .838 r
.68692 .82842 m .68608 .8282 L .6865 .82755 L closepath p F P
0 g
s
.425 .504 .836 r
.68608 .8282 m .6865 .82755 L .68388 .82212 L p F P
0 g
s
.377 .549 .897 r
.73734 .63242 m .73138 .63103 L .72849 .62626 L p F P
0 g
s
.736 .867 .447 r
.81053 .83425 m .81095 .83366 L .81402 .82808 L p F P
0 g
s
.627 .827 .977 r
.77239 .86038 m .76007 .86458 L .75731 .86165 L p F P
0 g
s
.293 .438 .836 r
.78062 .6732 m .78015 .67745 L .78733 .68111 L p F P
0 g
s
.297 .445 .84 r
.77446 .67032 m .78062 .6732 L .78015 .67745 L p F P
0 g
s
.283 .423 .827 r
.78015 .67745 m .78733 .68111 L .78668 .68538 L p F P
0 g
s
.206 .323 .763 r
.80291 .71086 m .80307 .71013 L p .80734 .71872 L F P
0 g
s
.227 .35 .781 r
.80291 .71086 m .8024 .70965 L .80307 .71013 L closepath p F P
0 g
s
.184 .292 .741 r
.638 .73983 m .63661 .74428 L .64158 .74864 L p F P
0 g
s
.177 .274 .726 r
.63661 .74428 m .638 .73983 L .63338 .73539 L p F P
0 g
s
.973 .771 .343 r
.6034 .61748 m .60381 .61869 L .60331 .62442 L p F P
0 g
s
.158 .263 .723 r
.8122 .72316 m .81108 .72745 L .81551 .73203 L p F P
0 g
s
.186 .294 .742 r
.80734 .71872 m .8122 .72316 L .81108 .72745 L p F P
0 g
s
.521 .605 .877 r
.70843 .84755 m .72019 .84825 L .71716 .85282 L p F P
0 g
s
.506 .59 .873 r
.72019 .84825 m .70843 .84755 L .7057 .84269 L p F P
0 g
s
0 .009 .571 r
.61621 .68131 m .61597 .68557 L .61887 .6904 L p F P
0 g
s
0 0 .559 r
.61597 .68557 m .61621 .68131 L .61364 .6764 L p F P
0 g
s
.468 .536 .844 r
.68692 .82842 m .69822 .83084 L .69528 .83545 L p F P
0 g
s
.453 .522 .839 r
.69822 .83084 m .68692 .82842 L .6865 .82755 L p F P
0 g
s
0 0 .334 r
.82553 .78989 m .82337 .7943 L .82353 .80017 L p F P
0 g
s
0 0 .432 r
.82337 .7943 m .82553 .78989 L .82465 .78422 L p F P
0 g
s
.968 .9 .701 r
.60676 .59793 m .60825 .60185 L .60466 .60851 L p F P
0 g
s
.893 .868 .807 r
.60995 .59368 m .60676 .59793 L .60825 .60185 L p F P
0 g
s
.291 .444 .842 r
.78062 .6732 m .77446 .67032 L .77324 .6679 L p F P
0 g
s
.223 .35 .782 r
.80307 .71013 m .8024 .70965 L .79942 .70256 L p F P
0 g
s
.496 .601 .888 r
.71716 .85282 m .72386 .85298 L .72093 .8483 L p F P
0 g
s
.496 .601 .888 r
.72093 .8483 m .72019 .84825 L .71716 .85282 L p F P
0 g
s
.542 .671 .922 r
.73656 .86114 m .74209 .86058 L .73924 .8567 L p F P
0 g
s
.542 .671 .922 r
.73924 .8567 m .73919 .85671 L .73656 .86114 L p F P
0 g
s
.567 .668 .906 r
.72677 .85751 m .73919 .85671 L .73656 .86114 L p F P
0 g
s
0 .028 .541 r
.82383 .77719 m .82493 .7744 L .82292 .76906 L p F P
0 g
s
0 .026 .541 r
.82452 .76474 m .82292 .76906 L .82493 .7744 L p F P
0 g
s
.04 .094 .592 r
.82196 .75957 m .82452 .76474 L .82292 .76906 L p F P
0 g
s
.284 .417 .821 r
.79349 .68915 m .78668 .68538 L p .7927 .69347 L F P
0 g
s
.267 .408 .819 r
.78668 .68538 m .79349 .68915 L .79055 .68291 L p F P
0 g
s
.267 .408 .819 r
.79055 .68291 m .78733 .68111 L .78668 .68538 L p F P
0 g
s
.365 .428 .793 r
.66328 .79155 m .65899 .78952 L .65717 .7851 L p F P
0 g
s
.362 .521 .881 r
.74993 .64411 m .74763 .64345 L .74772 .64021 L closepath p F P
0 g
s
.385 .543 .889 r
.74763 .64345 m .74772 .64021 L .74704 .63904 L p F P
0 g
s
.453 .522 .839 r
.6865 .82755 m .68934 .82348 L p .69822 .83084 L F P
0 g
s
.437 .511 .837 r
.6865 .82755 m .68388 .82212 L .68934 .82348 L closepath p F P
0 g
s
.179 .294 .746 r
.80833 .71443 m .80734 .71872 L .8122 .72316 L p F P
0 g
s
.206 .323 .763 r
.80307 .71013 m .80833 .71443 L .80734 .71872 L p F P
0 g
s
.552 .651 .901 r
.73919 .85671 m .72677 .85751 L .72386 .85298 L p F P
0 g
s
.144 .261 .727 r
.63457 .73098 m .63338 .73539 L .638 .73983 L p F P
0 g
s
.139 .244 .711 r
.63338 .73539 m .63457 .73098 L .63028 .72646 L p F P
0 g
s
0 0 .479 r
.82493 .7744 m .82383 .77719 L .82491 .78366 L p F P
0 g
s
0 0 .502 r
.82465 .78422 m .82491 .78366 L .82383 .77719 L p F P
0 g
s
.44 .613 .922 r
.69969 .6098 m .70714 .61057 L .70423 .6062 L p F P
0 g
s
.44 .613 .922 r
.70423 .6062 m .69902 .6057 L .69969 .6098 L p F P
0 g
s
.443 .617 .924 r
.69171 .60508 m .69902 .6057 L .69969 .6098 L p F P
0 g
s
.523 .687 .941 r
.66127 .59306 m .67049 .59252 L .66754 .58856 L p F P
0 g
s
.523 .687 .941 r
.66754 .58856 m .65998 .58909 L .66127 .59306 L p F P
0 g
s
.519 .687 .944 r
.65521 .58945 m .65998 .58909 L .66127 .59306 L p F P
0 g
s
.269 .394 .806 r
.79645 .69579 m .7927 .69347 L p .79819 .70171 L F P
0 g
s
.254 .386 .804 r
.79645 .69579 m .7927 .69347 L .79352 .68921 L closepath p F P
0 g
s
.284 .417 .821 r
.7927 .69347 m .79352 .68921 L .79349 .68915 L p F P
0 g
s
0 0 0 r
.82081 .81063 m .82291 .80627 L p .81961 .81642 L F P
0 g
s
0 0 0 r
.81961 .81642 m .8198 .81513 L .82081 .81063 L p F P
0 g
s
0 0 .204 r
.82081 .81063 m .82291 .80627 L .82353 .80017 L p F P
0 g
s
.196 .321 .765 r
.80392 .70586 m .80307 .71013 L .80833 .71443 L p F P
0 g
s
.223 .35 .782 r
.79942 .70256 m .80392 .70586 L .80307 .71013 L p F P
0 g
s
.269 .394 .806 r
.79819 .70171 m .79849 .70037 L .79645 .69579 L p F P
0 g
s
.237 .36 .787 r
.79942 .70256 m .79819 .70171 L .79849 .70037 L closepath p F P
0 g
s
0 0 .516 r
.61362 .67219 m .61364 .6764 L .61621 .68131 L p F P
0 g
s
0 0 .495 r
.61364 .6764 m .61362 .67219 L .61138 .6672 L p F P
0 g
s
.441 .528 .851 r
.69528 .83545 m .70247 .83674 L .69947 .83111 L p F P
0 g
s
.441 .528 .851 r
.69947 .83111 m .69822 .83084 L .69528 .83545 L p F P
0 g
s
.443 .621 .927 r
.69902 .6057 m .69171 .60508 L .68878 .60086 L p F P
0 g
s
.618 .825 .423 r
.80998 .83511 m .81053 .83425 L .81095 .83366 L closepath p F P
0 g
s
.291 .444 .842 r
.77324 .6679 m .77342 .66545 L p .78062 .6732 L F P
0 g
s
.307 .464 .853 r
.77324 .6679 m .77155 .66466 L .77342 .66545 L closepath p F P
0 g
s
.365 .428 .793 r
.65717 .7851 m .65824 .78316 L p .66328 .79155 L F P
0 g
s
.344 .412 .788 r
.65717 .7851 m .65588 .78192 L .65824 .78316 L closepath p F P
0 g
s
.099 .227 .71 r
.63127 .72208 m .63028 .72646 L .63457 .73098 L p F P
0 g
s
.095 .21 .694 r
.63028 .72646 m .63127 .72208 L .6273 .7175 L p F P
0 g
s
.659 .764 .928 r
.62491 .58848 m .63704 .5843 L .64002 .58788 L p F P
0 g
s
.67 .771 .926 r
.63704 .5843 m .62491 .58848 L .62192 .58525 L p F P
0 g
s
.583 .72 .937 r
.64002 .58788 m .65224 .58567 L .65521 .58945 L p F P
0 g
s
.589 .726 .938 r
.65224 .58567 m .64002 .58788 L .63704 .5843 L p F P
0 g
s
.947 .78 .321 r
.6028 .61465 m .6034 .61748 L .60241 .62174 L p F P
0 g
s
.969 .893 .522 r
.60466 .60851 m .6028 .61465 L .6034 .61748 L p F P
0 g
s
.973 .771 .343 r
.60331 .62442 m .60241 .62174 L .6034 .61748 L p F P
0 g
s
.4 .566 .902 r
.72849 .62626 m .72629 .62584 L .72614 .62244 L closepath p F P
0 g
s
.407 .575 .906 r
.72559 .62156 m .72614 .62244 L .72629 .62584 L p F P
0 g
s
.479 .647 .932 r
.68288 .6007 m .68878 .60086 L .68585 .59669 L p F P
0 g
s
.479 .647 .932 r
.68585 .59669 m .68203 .59662 L .68288 .6007 L p F P
0 g
s
.478 .65 .935 r
.67343 .59653 m .68203 .59662 L .68288 .6007 L p F P
0 g
s
.751 .971 .7 r
.81053 .83425 m .80998 .83511 L .80361 .84275 L p F P
0 g
s
.711 .978 .914 r
.79398 .85125 m .78724 .85595 L .78464 .8547 L p F P
0 g
s
.48 .655 .937 r
.68203 .59662 m .67343 .59653 L .67049 .59252 L p F P
0 g
s
.412 .591 .916 r
.71356 .61551 m .71005 .61498 L .70714 .61057 L p F P
0 g
s
.029 .091 .593 r
.82348 .75525 m .82196 .75957 L .82452 .76474 L p F P
0 g
s
.071 .142 .632 r
.82196 .75957 m .82348 .75525 L .8204 .75024 L p F P
0 g
s
.818 .57 .014 r
.60348 .62997 m .60453 .63396 L .60523 .63936 L p F P
0 g
s
.888 .666 .148 r
.60453 .63396 m .60348 .62997 L .60331 .62442 L p F P
0 g
s
.346 .411 .787 r
.65824 .78316 m .65588 .78192 L .65322 .77537 L p F P
0 g
s
.213 .345 .781 r
.80392 .70586 m .79942 .70256 L .79849 .70037 L p F P
0 g
s
.347 .502 .87 r
.76575 .65366 m .75689 .65057 L p .76548 .65791 L F P
0 g
s
.33 .496 .871 r
.75689 .65057 m .76575 .65366 L .76286 .64843 L p F P
0 g
s
.33 .496 .871 r
.76286 .64843 m .75694 .64638 L .75689 .65057 L p F P
0 g
s
.343 .507 .876 r
.74993 .64411 m .75694 .64638 L .75689 .65057 L p F P
0 g
s
.048 .189 .69 r
.62807 .71316 m .6273 .7175 L .63127 .72208 L p F P
0 g
s
.044 .171 .673 r
.6273 .7175 m .62807 .71316 L .62441 .70849 L p F P
0 g
s
.339 .508 .878 r
.75694 .64638 m .74993 .64411 L .74772 .64021 L p F P
0 g
s
0 0 .443 r
.6111 .66304 m .61138 .6672 L .61362 .67219 L p F P
0 g
s
0 0 .41 r
.61138 .6672 m .6111 .66304 L .60922 .65796 L p F P
0 g
s
.994 .867 .543 r
.6034 .60453 m .60466 .60851 L .6028 .61465 L p F P
0 g
s
.968 .9 .701 r
.60466 .60851 m .6034 .60453 L .60676 .59793 L p F P
0 g
s
.44 .509 .834 r
.68934 .82348 m .68388 .82212 L .68111 .81631 L p F P
0 g
s
.756 .994 .863 r
.79398 .85125 m .79697 .84702 L .79927 .84707 L closepath p F P
0 g
s
.711 .978 .914 r
.79697 .84702 m .79398 .85125 L p .78464 .8547 L F P
0 g
s
0 0 .426 r
.82491 .78366 m .82465 .78422 L .82553 .78989 L p F P
0 g
s
.213 .345 .781 r
.79849 .70037 m .79898 .69744 L p .80392 .70586 L F P
0 g
s
.234 .372 .799 r
.79849 .70037 m .79645 .69579 L .79898 .69744 L closepath p F P
0 g
s
.834 .998 .83 r
.80361 .84275 m .80636 .83828 L p .79697 .84702 L F P
0 g
s
.834 .998 .83 r
.79697 .84702 m .79927 .84707 L .80361 .84275 L p F P
0 g
s
.751 .971 .7 r
.80867 .83576 m .81053 .83425 L p .80361 .84275 L F P
0 g
s
.751 .971 .7 r
.80361 .84275 m .80636 .83828 L .80867 .83576 L p F P
0 g
s
.506 .59 .873 r
.7057 .84269 m .706 .8423 L p .72019 .84825 L F P
0 g
s
.493 .582 .872 r
.7057 .84269 m .70546 .84225 L .706 .8423 L closepath p F P
0 g
s
0 0 .054 r
.8193 .81697 m .81961 .81642 L .8198 .81513 L closepath p F P
0 g
s
.75 .935 .592 r
.80867 .83576 m .8124 .83071 L .81053 .83425 L closepath p F P
0 g
s
.736 .867 .447 r
.8165 .82366 m .8124 .83071 L .81053 .83425 L p F P
0 g
s
.58 .748 .957 r
.74209 .86058 m .75452 .85845 L .75731 .86165 L p F P
0 g
s
.565 .725 .949 r
.75452 .85845 m .74209 .86058 L .73924 .8567 L p F P
0 g
s
0 .145 .665 r
.62495 .70419 m .62441 .70849 L .62807 .71316 L p F P
0 g
s
0 .126 .647 r
.62441 .70849 m .62495 .70419 L .62161 .69946 L p F P
0 g
s
.304 .464 .855 r
.77342 .66545 m .77155 .66466 L .76865 .65914 L p F P
0 g
s
.497 .576 .865 r
.706 .8423 m .70546 .84225 L .70247 .83674 L p F P
0 g
s
.377 .549 .897 r
.72849 .62626 m .73711 .62825 L .73734 .63242 L p F P
0 g
s
.375 .551 .9 r
.73711 .62825 m .72849 .62626 L .72614 .62244 L p F P
0 g
s
.524 .693 .945 r
.65998 .58909 m .65521 .58945 L .65224 .58567 L p F P
0 g
s
.323 .394 .781 r
.65322 .77537 m .65275 .7742 L .65358 .77468 L closepath p F P
0 g
s
.346 .411 .787 r
.65322 .77537 m .65358 .77468 L p .65824 .78316 L F P
0 g
s
.105 .189 .668 r
.8204 .75024 m .82182 .74591 L .81825 .74106 L p F P
0 g
s
.07 .145 .636 r
.82182 .74591 m .8204 .75024 L .82348 .75525 L p F P
0 g
s
0 0 .399 r
.82638 .7799 m .82491 .78366 L .82561 .78972 L p F P
0 g
s
0 0 .479 r
.82491 .78366 m .82638 .7799 L .82493 .7744 L p F P
0 g
s
0 0 .426 r
.82553 .78989 m .82561 .78972 L .82491 .78366 L p F P
0 g
s
.506 .59 .873 r
.706 .8423 m .71799 .84339 L p .72019 .84825 L F P
0 g
s
.476 .564 .866 r
.706 .8423 m .71799 .84339 L .71503 .83833 L p F P
0 g
s
.476 .564 .866 r
.71503 .83833 m .70937 .8376 L .706 .8423 L p F P
0 g
s
.497 .576 .865 r
.70247 .83674 m .70937 .8376 L .706 .8423 L p F P
0 g
s
0 0 .349 r
.60867 .65386 m .60922 .65796 L .6111 .66304 L p F P
0 g
s
0 0 .298 r
.60922 .65796 m .60867 .65386 L .60716 .64869 L p F P
0 g
s
.921 .681 .189 r
.60241 .62174 m .60331 .62442 L .60348 .62997 L p F P
0 g
s
.324 .394 .78 r
.65358 .77468 m .65275 .7742 L .64961 .76632 L p F P
0 g
s
.321 .477 .859 r
.76865 .65914 m .76548 .65791 L .76576 .65368 L closepath p F P
0 g
s
.347 .502 .87 r
.76548 .65791 m .76576 .65368 L .76575 .65366 L p F P
0 g
s
0 0 .334 r
.82353 .80017 m .82569 .79577 L .82553 .78989 L p F P
0 g
s
0 0 .202 r
.82569 .79577 m .82353 .80017 L .82291 .80627 L p F P
0 g
s
.667 .887 .978 r
.77883 .85749 m .77239 .86038 L .76968 .85799 L p F P
0 g
s
.627 .827 .977 r
.75731 .86165 m .76968 .85799 L .77239 .86038 L p F P
0 g
s
0 .094 .634 r
.62192 .6952 m .62161 .69946 L .62495 .70419 L p F P
0 g
s
0 .072 .614 r
.62161 .69946 m .62192 .6952 L .61887 .6904 L p F P
0 g
s
.369 .541 .894 r
.73734 .63242 m .74415 .63414 L .74125 .62929 L p F P
0 g
s
.369 .541 .894 r
.74125 .62929 m .73711 .62825 L .73734 .63242 L p F P
0 g
s
.552 .651 .901 r
.72386 .85298 m .73636 .85259 L p .73919 .85671 L F P
0 g
s
.512 .646 .916 r
.73636 .85259 m .72386 .85298 L .72093 .8483 L p F P
0 g
s
.383 .443 .799 r
.66328 .79155 m .671 .79528 L .66875 .79981 L p F P
0 g
s
.334 .427 .808 r
.66552 .78699 m .66328 .79155 L .671 .79528 L p F P
0 g
s
.365 .428 .793 r
.65824 .78316 m .66552 .78699 L .66328 .79155 L p F P
0 g
s
.311 .408 .801 r
.66044 .77859 m .65824 .78316 L .66552 .78699 L p F P
0 g
s
.346 .411 .787 r
.65358 .77468 m .66044 .77859 L .65824 .78316 L p F P
0 g
s
.406 .585 .914 r
.71356 .61551 m .72269 .61701 L .71978 .61251 L p F P
0 g
s
.406 .585 .914 r
.71978 .61251 m .71293 .61141 L .71356 .61551 L p F P
0 g
s
.412 .591 .916 r
.70714 .61057 m .71293 .61141 L .71356 .61551 L p F P
0 g
s
.611 .8 .972 r
.76968 .85799 m .75731 .86165 L .75452 .85845 L p F P
0 g
s
.274 .375 .785 r
.65569 .7701 m .65358 .77468 L .66044 .77859 L p F P
0 g
s
.324 .394 .78 r
.64961 .76632 m .65569 .7701 L .65358 .77468 L p F P
0 g
s
.232 .372 .799 r
.79898 .69744 m .79645 .69579 L .79352 .68921 L p F P
0 g
s
.374 .459 .819 r
.67468 .8024 m .66875 .79981 L p .67473 .80794 L F P
0 g
s
.346 .43 .805 r
.66875 .79981 m .67468 .8024 L .6716 .79557 L p F P
0 g
s
.346 .43 .805 r
.6716 .79557 m .671 .79528 L .66875 .79981 L p F P
0 g
s
.831 .859 .867 r
.61457 .58996 m .60995 .59368 L .60695 .5913 L p F P
0 g
s
.904 .865 .791 r
.60676 .59793 m .60995 .59368 L .60695 .5913 L p F P
0 g
s
.108 .197 .675 r
.81956 .73674 m .81825 .74106 L .82182 .74591 L p F P
0 g
s
.134 .229 .698 r
.81825 .74106 m .81956 .73674 L .81551 .73203 L p F P
0 g
s
0 0 0 r
.82141 .81262 m .81961 .81642 L .8184 .82032 L p F P
0 g
s
0 0 0 r
.82291 .80627 m .82141 .81262 L .81961 .81642 L p F P
0 g
s
.258 .351 .768 r
.64961 .76632 m .64928 .76608 L .6494 .76578 L closepath p F P
0 g
s
.252 .343 .763 r
.64647 .75828 m .64533 .75739 L p .64928 .76608 L F P
0 g
s
.252 .343 .763 r
.64928 .76608 m .6494 .76578 L .64647 .75828 L p F P
0 g
s
0 0 .231 r
.60635 .64464 m .60716 .64869 L .60867 .65386 L p F P
0 g
s
0 0 .197 r
.60635 .64464 m .6078 .64984 L p .60642 .64488 L F P
0 g
s
.749 .482 0 r
.60635 .64464 m .60542 .64129 L .6049 .63896 L p F P
0 g
s
0 0 .197 r
.60542 .64129 m .60635 .64464 L p .60642 .64488 L F P
0 g
s
0 0 .154 r
.60635 .64464 m .60523 .63936 L p .60627 .64438 L F P
0 g
s
0 0 .154 r
.60716 .64869 m .60635 .64464 L p .60627 .64438 L F P
0 g
s
.304 .464 .855 r
.76865 .65914 m .77362 .66124 L .77342 .66545 L p F P
0 g
s
.291 .444 .842 r
.77342 .66545 m .78101 .66897 L .78062 .6732 L p F P
0 g
s
.291 .449 .846 r
.77362 .66124 m .77342 .66545 L .78101 .66897 L p F P
0 g
s
.377 .463 .822 r
.67776 .80912 m .67473 .80794 L .67606 .80542 L closepath p F P
0 g
s
.374 .459 .819 r
.67473 .80794 m .67606 .80542 L .67468 .8024 L p F P
0 g
s
.44 .509 .834 r
.68111 .81631 m .6814 .81588 L p .68934 .82348 L F P
0 g
s
.423 .498 .831 r
.68111 .81631 m .68083 .81572 L .6814 .81588 L closepath p F P
0 g
s
0 .026 .541 r
.82493 .7744 m .82656 .77007 L .82452 .76474 L p F P
0 g
s
0 0 .479 r
.82656 .77007 m .82493 .7744 L .82638 .7799 L p F P
0 g
s
.831 .859 .867 r
.60695 .5913 m .613 .58603 L .61457 .58996 L p F P
0 g
s
.766 .818 .894 r
.61892 .58202 m .613 .58603 L .61457 .58996 L p F P
0 g
s
.766 .818 .894 r
.61457 .58996 m .62192 .58525 L .61892 .58202 L p F P
0 g
s
.353 .523 .886 r
.74772 .64021 m .74704 .63904 L .74769 .63923 L closepath p F P
0 g
s
.339 .508 .878 r
.74772 .64021 m .74769 .63923 L p .75694 .64638 L F P
0 g
s
.427 .495 .827 r
.6814 .81588 m .68083 .81572 L .67776 .80912 L p F P
0 g
s
0 .036 .595 r
.61895 .68619 m .61887 .6904 L .62192 .6952 L p F P
0 g
s
0 .009 .571 r
.61887 .6904 m .61895 .68619 L .61621 .68131 L p F P
0 g
s
.304 .38 .776 r
.65569 .7701 m .64961 .76632 L .6494 .76578 L p F P
0 g
s
.304 .38 .776 r
.6494 .76578 m .65123 .76153 L p .65569 .7701 L F P
0 g
s
.279 .361 .768 r
.6494 .76578 m .64647 .75828 L .65123 .76153 L closepath p F P
0 g
s
.228 .328 .758 r
.64647 .75828 m .64533 .75739 L .64569 .7563 L closepath p F P
0 g
s
.22 .319 .753 r
.64332 .75013 m .64158 .74864 L p .64533 .75739 L F P
0 g
s
.22 .319 .753 r
.64533 .75739 m .64569 .7563 L .64332 .75013 L p F P
0 g
s
.968 .883 .693 r
.60502 .59407 m .60676 .59793 L .6034 .60453 L p F P
0 g
s
.904 .865 .791 r
.60695 .5913 m .60502 .59407 L .60676 .59793 L p F P
0 g
s
.443 .621 .927 r
.68878 .60086 m .69827 .6016 L .69902 .6057 L p F P
0 g
s
.444 .625 .93 r
.69827 .6016 m .68878 .60086 L .68585 .59669 L p F P
0 g
s
.44 .509 .834 r
.6814 .81588 m .69193 .81892 L .68934 .82348 L p F P
0 g
s
.401 .499 .844 r
.68425 .81122 m .6814 .81588 L .69193 .81892 L p F P
0 g
s
.427 .495 .827 r
.67776 .80912 m .68425 .81122 L .6814 .81588 L p F P
0 g
s
.947 .78 .321 r
.60241 .62174 m .60213 .62044 L .6028 .61465 L p F P
0 g
s
.968 .785 .352 r
.60163 .61064 m .6028 .61465 L .60213 .62044 L p F P
0 g
s
.994 .867 .543 r
.6028 .61465 m .60163 .61064 L .6034 .60453 L p F P
0 g
s
.135 .235 .704 r
.8167 .72772 m .81551 .73203 L .81956 .73674 L p F P
0 g
s
.158 .263 .723 r
.81551 .73203 m .8167 .72772 L .8122 .72316 L p F P
0 g
s
.293 .438 .836 r
.78762 .6767 m .78062 .6732 L p .78733 .68111 L F P
0 g
s
.275 .429 .835 r
.78062 .6732 m .78762 .6767 L .7847 .67082 L p F P
0 g
s
.275 .429 .835 r
.7847 .67082 m .78101 .66897 L .78062 .6732 L p F P
0 g
s
.194 .302 .748 r
.64332 .75013 m .64158 .74864 L .64207 .74691 L closepath p F P
0 g
s
.184 .292 .741 r
.64016 .74185 m .638 .73983 L p .64158 .74864 L F P
0 g
s
.184 .292 .741 r
.64158 .74864 m .64207 .74691 L .64016 .74185 L p F P
0 g
s
.349 .525 .888 r
.74769 .63923 m .74704 .63904 L .74415 .63414 L p F P
0 g
s
.411 .594 .919 r
.71293 .61141 m .70714 .61057 L .70423 .6062 L p F P
0 g
s
.667 .887 .978 r
.78222 .85317 m .77883 .85749 L p .76968 .85799 L F P
0 g
s
.703 .908 .967 r
.77883 .85749 m .78222 .85317 L .78464 .8547 L closepath p F P
0 g
s
.529 .692 .942 r
.65998 .58909 m .66754 .58856 L .66458 .58464 L p F P
0 g
s
.529 .692 .942 r
.66458 .58464 m .65863 .58512 L .65998 .58909 L p F P
0 g
s
.524 .693 .945 r
.65224 .58567 m .65863 .58512 L .65998 .58909 L p F P
0 g
s
0 0 .546 r
.61605 .67715 m .61621 .68131 L .61895 .68619 L p F P
0 g
s
0 0 .516 r
.61621 .68131 m .61605 .67715 L .61362 .67219 L p F P
0 g
s
.48 .655 .937 r
.67049 .59252 m .68111 .59254 L .68203 .59662 L p F P
0 g
s
.483 .66 .939 r
.68111 .59254 m .67049 .59252 L .66754 .58856 L p F P
0 g
s
.818 .57 .014 r
.60523 .63936 m .60416 .63537 L .60348 .62997 L p F P
0 g
s
.589 .726 .938 r
.63704 .5843 m .64927 .58192 L .65224 .58567 L p F P
0 g
s
.595 .731 .939 r
.64927 .58192 m .63704 .5843 L .63405 .58076 L p F P
0 g
s
.67 .771 .926 r
.62192 .58525 m .63405 .58076 L .63704 .5843 L p F P
0 g
s
.159 .27 .73 r
.81326 .71886 m .8122 .72316 L .8167 .72772 L p F P
0 g
s
.179 .294 .746 r
.8122 .72316 m .81326 .71886 L .80833 .71443 L p F P
0 g
s
.48 .563 .862 r
.70937 .8376 m .70247 .83674 L .69947 .83111 L p F P
0 g
s
.442 .616 .924 r
.69902 .6057 m .70423 .6062 L .70131 .60188 L p F P
0 g
s
.442 .616 .924 r
.70131 .60188 m .69827 .6016 L .69902 .6057 L p F P
0 g
s
.68 .776 .923 r
.63405 .58076 m .62192 .58525 L .61892 .58202 L p F P
0 g
s
.339 .508 .878 r
.74769 .63923 m .75691 .64219 L .75694 .64638 L p F P
0 g
s
.341 .513 .882 r
.74743 .63509 m .74769 .63923 L .75691 .64219 L p F P
0 g
s
.349 .525 .888 r
.74415 .63414 m .74743 .63509 L .74769 .63923 L p F P
0 g
s
.375 .551 .9 r
.72614 .62244 m .72605 .62166 L p .73711 .62825 L F P
0 g
s
.386 .564 .905 r
.72614 .62244 m .72559 .62156 L .72605 .62166 L closepath p F P
0 g
s
.299 .463 .856 r
.77362 .66124 m .76865 .65914 L .76576 .65368 L p F P
0 g
s
.156 .274 .735 r
.64016 .74185 m .638 .73983 L .63854 .73759 L closepath p F P
0 g
s
.144 .261 .727 r
.63699 .73346 m .63457 .73098 L p .638 .73983 L F P
0 g
s
.144 .261 .727 r
.638 .73983 m .63854 .73759 L .63699 .73346 L p F P
0 g
s
.262 .408 .821 r
.79055 .68291 m .78733 .68111 L .78786 .6772 L closepath p F P
0 g
s
.293 .438 .836 r
.78733 .68111 m .78786 .6772 L .78762 .6767 L p F P
0 g
s
.279 .361 .768 r
.65123 .76153 m .64647 .75828 L .64569 .7563 L p F P
0 g
s
.453 .522 .839 r
.68934 .82348 m .69645 .82529 L p .69822 .83084 L F P
0 g
s
.41 .499 .84 r
.68934 .82348 m .69645 .82529 L .69342 .81936 L p F P
0 g
s
.41 .499 .84 r
.69342 .81936 m .69193 .81892 L .68934 .82348 L p F P
0 g
s
.182 .303 .753 r
.80925 .71016 m .80833 .71443 L .81326 .71886 L p F P
0 g
s
.196 .321 .765 r
.80833 .71443 m .80925 .71016 L .80392 .70586 L p F P
0 g
s
0 .028 .544 r
.82608 .76041 m .82452 .76474 L .82656 .77007 L p F P
0 g
s
.029 .091 .593 r
.82452 .76474 m .82608 .76041 L .82348 .75525 L p F P
0 g
s
0 0 .327 r
.82561 .78972 m .82553 .78989 L .82569 .79577 L p F P
0 g
s
.232 .372 .799 r
.79352 .68921 m .79352 .68917 L p .79898 .69744 L F P
0 g
s
.251 .396 .814 r
.79352 .68921 m .79349 .68915 L .79352 .68917 L closepath p F P
0 g
s
.246 .396 .816 r
.79352 .68917 m .79349 .68915 L .79055 .68291 L p F P
0 g
s
.279 .361 .768 r
.64569 .7563 m .64702 .75289 L p .65123 .76153 L F P
0 g
s
.253 .34 .76 r
.64569 .7563 m .64332 .75013 L .64702 .75289 L closepath p F P
0 g
s
.232 .372 .799 r
.79352 .68917 m .79961 .6932 L .79898 .69744 L p F P
0 g
s
.223 .371 .802 r
.794 .68495 m .79352 .68917 L .79961 .6932 L p F P
0 g
s
.246 .396 .816 r
.79055 .68291 m .794 .68495 L .79352 .68917 L p F P
0 g
s
.203 .333 .774 r
.8047 .7016 m .80392 .70586 L .80925 .71016 L p F P
0 g
s
.213 .345 .781 r
.79898 .69744 m .8047 .7016 L .80392 .70586 L p F P
0 g
s
.21 .349 .786 r
.79961 .6932 m .79898 .69744 L .8047 .7016 L p F P
0 g
s
0 0 .294 r
.82723 .78558 m .82561 .78972 L .82591 .7953 L p F P
0 g
s
0 0 .399 r
.82561 .78972 m .82723 .78558 L .82638 .7799 L p F P
0 g
s
0 0 .327 r
.82569 .79577 m .82591 .7953 L .82561 .78972 L p F P
0 g
s
.113 .242 .72 r
.63699 .73346 m .63457 .73098 L .63507 .72836 L closepath p F P
0 g
s
.099 .227 .71 r
.63382 .72496 m .63127 .72208 L p .63457 .73098 L F P
0 g
s
.099 .227 .71 r
.63457 .73098 m .63507 .72836 L .63382 .72496 L p F P
0 g
s
.383 .566 .908 r
.72605 .62166 m .72559 .62156 L .72269 .61701 L p F P
0 g
s
0 0 .484 r
.61323 .66807 m .61362 .67219 L .61605 .67715 L p F P
0 g
s
0 0 .443 r
.61362 .67219 m .61323 .66807 L .6111 .66304 L p F P
0 g
s
.542 .672 .922 r
.73924 .8567 m .73919 .85671 L .73921 .85667 L closepath p F P
0 g
s
.552 .651 .901 r
.73636 .85259 m .73921 .85667 L .73919 .85671 L p F P
0 g
s
.483 .651 .933 r
.68203 .59662 m .68585 .59669 L .68292 .59256 L p F P
0 g
s
.483 .651 .933 r
.68292 .59256 m .68111 .59254 L .68203 .59662 L p F P
0 g
s
.565 .725 .949 r
.73924 .8567 m .75171 .85502 L .75452 .85845 L p F P
0 g
s
.561 .681 .919 r
.74888 .85137 m .75171 .85502 L .73924 .8567 L p F P
0 g
s
.561 .681 .919 r
.74305 .85193 m .74888 .85137 L p .73924 .8567 L F P
0 g
s
.561 .681 .919 r
.73924 .8567 m .73921 .85667 L .74305 .85193 L p F P
0 g
s
.56 .679 .919 r
.73921 .85667 m .73636 .85259 L .74305 .85193 L closepath p F P
0 g
s
.863 .651 .118 r
.60213 .62044 m .60241 .62174 L .60261 .62734 L p F P
0 g
s
.921 .681 .189 r
.60348 .62997 m .60261 .62734 L .60241 .62174 L p F P
0 g
s
.494 .604 .892 r
.72093 .8483 m .72019 .84825 L .72055 .84766 L closepath p F P
0 g
s
.506 .59 .873 r
.71799 .84339 m .72055 .84766 L .72019 .84825 L p F P
0 g
s
0 0 .023 r
.82504 .80188 m .82291 .80627 L .82141 .81262 L p F P
0 g
s
0 0 .202 r
.82291 .80627 m .82504 .80188 L .82569 .79577 L p F P
0 g
s
.409 .482 .824 r
.68425 .81122 m .67776 .80912 L .67606 .80542 L p F P
0 g
s
.389 .565 .905 r
.72544 .61757 m .72605 .62166 L .73679 .62409 L p F P
0 g
s
.383 .566 .908 r
.72269 .61701 m .72544 .61757 L .72605 .62166 L p F P
0 g
s
.375 .551 .9 r
.72605 .62166 m .73679 .62409 L .73711 .62825 L p F P
0 g
s
.855 .59 .053 r
.60261 .62734 m .60348 .62997 L .60416 .63537 L p F P
0 g
s
.711 .978 .914 r
.78464 .8547 m .79678 .84699 L .79697 .84702 L p F P
0 g
s
.772 .922 .936 r
.78222 .85317 m .78464 .8547 L .79678 .84699 L p F P
0 g
s
.065 .207 .702 r
.63382 .72496 m .63127 .72208 L .63168 .71919 L closepath p F P
0 g
s
.048 .189 .69 r
.63064 .71634 m .62807 .71316 L p .63127 .72208 L F P
0 g
s
.048 .189 .69 r
.63127 .72208 m .63168 .71919 L .63064 .71634 L p F P
0 g
s
.512 .646 .916 r
.72093 .8483 m .73347 .84829 L .73636 .85259 L p F P
0 g
s
.511 .613 .89 r
.73056 .84383 m .73347 .84829 L .72093 .8483 L p F P
0 g
s
.511 .613 .89 r
.72355 .84357 m .73056 .84383 L p .72093 .8483 L F P
0 g
s
.511 .613 .89 r
.72093 .8483 m .72055 .84766 L .72355 .84357 L p F P
0 g
s
.252 .34 .76 r
.64702 .75289 m .64332 .75013 L .64207 .74691 L p F P
0 g
s
.529 .698 .947 r
.65863 .58512 m .65224 .58567 L .64927 .58192 L p F P
0 g
s
.998 .853 .552 r
.60183 .60062 m .6034 .60453 L .60163 .61064 L p F P
0 g
s
.968 .883 .693 r
.6034 .60453 m .60183 .60062 L .60502 .59407 L p F P
0 g
s
.327 .497 .873 r
.75694 .64638 m .76286 .64843 L .75996 .64324 L p F P
0 g
s
.327 .497 .873 r
.75996 .64324 m .75691 .64219 L .75694 .64638 L p F P
0 g
s
0 0 .407 r
.61047 .65898 m .6111 .66304 L .61323 .66807 L p F P
0 g
s
0 0 .349 r
.6111 .66304 m .61047 .65898 L .60867 .65386 L p F P
0 g
s
.51 .611 .889 r
.72055 .84766 m .71799 .84339 L .72355 .84357 L closepath p F P
0 g
s
.437 .532 .857 r
.69947 .83111 m .69822 .83084 L .6988 .82984 L closepath p F P
0 g
s
.453 .522 .839 r
.69645 .82529 m .6988 .82984 L .69822 .83084 L p F P
0 g
s
.252 .34 .76 r
.64207 .74691 m .64302 .74418 L p .64702 .75289 L F P
0 g
s
.223 .317 .75 r
.64207 .74691 m .64016 .74185 L .64302 .74418 L closepath p F P
0 g
s
.025 .092 .596 r
.82496 .75092 m .82348 .75525 L .82608 .76041 L p F P
0 g
s
.07 .145 .636 r
.82348 .75525 m .82496 .75092 L .82182 .74591 L p F P
0 g
s
.835 .977 .678 r
.8124 .83071 m .81477 .82631 L p .80762 .83628 L F P
0 g
s
.835 .977 .678 r
.80762 .83628 m .80867 .83576 L .8124 .83071 L p F P
0 g
s
.678 .851 .441 r
.81787 .82129 m .8184 .82032 L p .8124 .83071 L F P
0 g
s
.678 .851 .441 r
.8124 .83071 m .81477 .82631 L .81787 .82129 L p F P
0 g
s
.01 .166 .68 r
.63064 .71634 m .62807 .71316 L .62835 .71009 L closepath p F P
0 g
s
0 .145 .665 r
.62746 .7076 m .62495 .70419 L p .62807 .71316 L F P
0 g
s
0 .145 .665 r
.62807 .71316 m .62835 .71009 L .62746 .7076 L p F P
0 g
s
.409 .482 .824 r
.67606 .80542 m .67728 .80334 L p .68425 .81122 L F P
0 g
s
.391 .469 .821 r
.67606 .80542 m .67468 .8024 L .67728 .80334 L closepath p F P
0 g
s
.595 .774 .965 r
.76695 .85531 m .75452 .85845 L .75171 .85502 L p F P
0 g
s
.611 .8 .972 r
.75452 .85845 m .76695 .85531 L .76968 .85799 L p F P
0 g
s
.221 .317 .751 r
.64302 .74418 m .64016 .74185 L .63854 .73759 L p F P
0 g
s
.863 .651 .118 r
.60261 .62734 m .60231 .62599 L .60213 .62044 L p F P
0 g
s
.904 .675 .167 r
.60099 .61643 m .60213 .62044 L .60231 .62599 L p F P
0 g
s
.968 .785 .352 r
.60213 .62044 m .60099 .61643 L .60163 .61064 L p F P
0 g
s
0 0 .398 r
.82803 .77558 m .82638 .7799 L .82723 .78558 L p F P
0 g
s
0 0 .479 r
.82638 .7799 m .82803 .77558 L .82656 .77007 L p F P
0 g
s
.48 .563 .862 r
.69947 .83111 m .71185 .83312 L .70937 .8376 L p F P
0 g
s
.465 .548 .857 r
.71185 .83312 m .69947 .83111 L .6988 .82984 L p F P
0 g
s
.667 .887 .978 r
.76968 .85799 m .78201 .85303 L .78222 .85317 L p F P
0 g
s
.65 .86 .98 r
.78201 .85303 m .76968 .85799 L .76695 .85531 L p F P
0 g
s
.834 .998 .83 r
.80636 .83828 m .79715 .84669 L .79697 .84702 L p F P
0 g
s
.79 .99 .886 r
.79678 .84699 m .79715 .84669 L .79697 .84702 L closepath p F P
0 g
s
0 0 .313 r
.6078 .64984 m .60867 .65386 L .61047 .65898 L p F P
0 g
s
0 0 .231 r
.60867 .65386 m .6078 .64984 L .60635 .64464 L p F P
0 g
s
0 .12 .652 r
.62746 .7076 m .62495 .70419 L .62508 .70106 L closepath p F P
0 g
s
0 .094 .634 r
.62427 .69873 m .62192 .6952 L p .62495 .70419 L F P
0 g
s
0 .094 .634 r
.62495 .70419 m .62508 .70106 L .62427 .69873 L p F P
0 g
s
.345 .526 .89 r
.74743 .63509 m .74415 .63414 L .74125 .62929 L p F P
0 g
s
.24 .393 .816 r
.794 .68495 m .79055 .68291 L .78786 .6772 L p F P
0 g
s
.745 .968 .695 r
.80636 .83828 m .80762 .83628 L .80867 .83576 L closepath p F P
0 g
s
.299 .463 .856 r
.76576 .65368 m .76576 .65367 L p .77362 .66124 L F P
0 g
s
.315 .482 .866 r
.76576 .65368 m .76575 .65366 L .76576 .65367 L closepath p F P
0 g
s
.31 .483 .869 r
.76576 .65367 m .76575 .65366 L .76286 .64843 L p F P
0 g
s
.299 .463 .856 r
.76576 .65367 m .77374 .65705 L .77362 .66124 L p F P
0 g
s
.296 .466 .86 r
.76568 .64951 m .76576 .65367 L .77374 .65705 L p F P
0 g
s
.31 .483 .869 r
.76286 .64843 m .76568 .64951 L .76576 .65367 L p F P
0 g
s
.221 .317 .751 r
.63854 .73759 m .6392 .73542 L p .64302 .74418 L F P
0 g
s
.191 .292 .739 r
.63854 .73759 m .63699 .73346 L .6392 .73542 L closepath p F P
0 g
s
.393 .468 .818 r
.67728 .80334 m .67468 .8024 L .6716 .79557 L p F P
0 g
s
.444 .625 .93 r
.68585 .59669 m .69743 .59752 L .69827 .6016 L p F P
0 g
s
.445 .629 .932 r
.69743 .59752 m .68585 .59669 L .68292 .59256 L p F P
0 g
s
.784 .975 .912 r
.79715 .84669 m .79678 .84699 L .79423 .84615 L p F P
0 g
s
.772 .922 .936 r
.79678 .84699 m .79423 .84615 L p .78222 .85317 L F P
0 g
s
.784 .975 .912 r
.79423 .84615 m .7994 .84236 L .79715 .84669 L p F P
0 g
s
.799 .994 .872 r
.80762 .83628 m .80636 .83828 L .79715 .84669 L p F P
0 g
s
.799 .994 .872 r
.80627 .83656 m .80762 .83628 L p .79715 .84669 L F P
0 g
s
.799 .994 .872 r
.79715 .84669 m .7994 .84236 L .80627 .83656 L p F P
0 g
s
.06 .141 .636 r
.82298 .74224 m .82182 .74591 L .82496 .75092 L p F P
0 g
s
.108 .197 .675 r
.8225 .74068 m .81956 .73674 L p .82182 .74591 L F P
0 g
s
.108 .197 .675 r
.82182 .74591 m .82298 .74224 L .8225 .74068 L p F P
0 g
s
.465 .548 .857 r
.6988 .82984 m .70118 .8262 L p .71185 .83312 L F P
0 g
s
.451 .538 .855 r
.6988 .82984 m .69645 .82529 L .70118 .8262 L closepath p F P
0 g
s
.411 .594 .919 r
.70423 .6062 m .7122 .60732 L .71293 .61141 L p F P
0 g
s
.41 .597 .922 r
.7122 .60732 m .70423 .6062 L .70131 .60188 L p F P
0 g
s
.367 .543 .896 r
.73711 .62825 m .74125 .62929 L .73835 .62448 L p F P
0 g
s
.367 .543 .896 r
.73835 .62448 m .73679 .62409 L .73711 .62825 L p F P
0 g
s
.406 .588 .916 r
.71293 .61141 m .71978 .61251 L .71688 .60805 L p F P
0 g
s
.406 .588 .916 r
.71688 .60805 m .7122 .60732 L .71293 .61141 L p F P
0 g
s
.841 .854 .853 r
.613 .58603 m .60695 .5913 L .60394 .58889 L p F P
0 g
s
.912 .86 .776 r
.60502 .59407 m .60695 .5913 L .60394 .58889 L p F P
0 g
s
.187 .291 .74 r
.6392 .73542 m .63699 .73346 L .63507 .72836 L p F P
0 g
s
.841 .854 .853 r
.60394 .58889 m .61114 .58218 L .613 .58603 L p F P
0 g
s
.777 .82 .887 r
.6159 .57879 m .61114 .58218 L .613 .58603 L p F P
0 g
s
.777 .82 .887 r
.613 .58603 m .61892 .58202 L .6159 .57879 L p F P
0 g
s
0 .068 .619 r
.62427 .69873 m .62192 .6952 L .62189 .6921 L closepath p F P
0 g
s
0 .036 .595 r
.62107 .68972 m .61895 .68619 L p .62192 .6952 L F P
0 g
s
0 .036 .595 r
.62192 .6952 m .62189 .6921 L .62107 .68972 L p F P
0 g
s
.483 .66 .939 r
.66754 .58856 m .67997 .58848 L p .68111 .59254 L F P
0 g
s
.49 .664 .939 r
.67997 .58848 m .66754 .58856 L .66458 .58464 L p F P
0 g
s
.749 .482 0 r
.6049 .63896 m .60416 .63537 L p .60635 .64464 L F P
0 g
s
0 0 0 r
.8184 .82032 m .81891 .81924 L .82141 .81262 L p F P
0 g
s
0 0 0 r
.82348 .80826 m .82141 .81262 L .81891 .81924 L p F P
0 g
s
0 0 .023 r
.82141 .81262 m .82348 .80826 L .82504 .80188 L p F P
0 g
s
0 0 .195 r
.82591 .7953 m .82569 .79577 L .82504 .80188 L p F P
0 g
s
.967 .867 .687 r
.60304 .59026 m .60502 .59407 L .60183 .60062 L p F P
0 g
s
.912 .86 .776 r
.60394 .58889 m .60304 .59026 L .60502 .59407 L p F P
0 g
s
.291 .449 .846 r
.78101 .66897 m .78132 .66474 L .77362 .66124 L p F P
0 g
s
.295 .459 .853 r
.77374 .65705 m .77362 .66124 L .78132 .66474 L p F P
0 g
s
.452 .557 .872 r
.70937 .8376 m .71503 .83833 L .71206 .83315 L p F P
0 g
s
.452 .557 .872 r
.71206 .83315 m .71185 .83312 L .70937 .8376 L p F P
0 g
s
.187 .291 .74 r
.63507 .72836 m .63552 .72661 L p .6392 .73542 L F P
0 g
s
.154 .264 .726 r
.63507 .72836 m .63382 .72496 L .63552 .72661 L closepath p F P
0 g
s
.595 .731 .939 r
.63405 .58076 m .64629 .5782 L .64927 .58192 L p F P
0 g
s
.601 .736 .939 r
.64629 .5782 m .63405 .58076 L .63105 .57722 L p F P
0 g
s
.68 .776 .923 r
.61892 .58202 m .63105 .57722 L .63405 .58076 L p F P
0 g
s
.09 .185 .67 r
.8225 .74068 m .81956 .73674 L .82037 .73392 L closepath p F P
0 g
s
.135 .235 .704 r
.81927 .7307 m .8167 .72772 L p .81956 .73674 L F P
0 g
s
.135 .235 .704 r
.81956 .73674 m .82037 .73392 L .81927 .7307 L p F P
0 g
s
.38 .568 .911 r
.72544 .61757 m .72269 .61701 L .71978 .61251 L p F P
0 g
s
.985 .784 .384 r
.60015 .60672 m .60163 .61064 L .60099 .61643 L p F P
0 g
s
.998 .853 .552 r
.60163 .61064 m .60015 .60672 L .60183 .60062 L p F P
0 g
s
0 .007 .576 r
.62107 .68972 m .61895 .68619 L .61877 .68322 L closepath p F P
0 g
s
0 0 .546 r
.61787 .68053 m .61605 .67715 L p .61895 .68619 L F P
0 g
s
0 0 .546 r
.61895 .68619 m .61877 .68322 L .61787 .68053 L p F P
0 g
s
.311 .408 .801 r
.6654 .78149 m .66044 .77859 L p .66552 .78699 L F P
0 g
s
.278 .379 .787 r
.66044 .77859 m .6654 .78149 L .66229 .77432 L p F P
0 g
s
.278 .379 .787 r
.66229 .77432 m .66205 .77417 L .66044 .77859 L p F P
0 g
s
.274 .375 .785 r
.66044 .77859 m .66205 .77417 L .65569 .7701 L p F P
0 g
s
.334 .427 .808 r
.6685 .78857 m .66552 .78699 L p .671 .79528 L F P
0 g
s
.316 .414 .804 r
.6685 .78857 m .66552 .78699 L .66661 .78428 L closepath p F P
0 g
s
.311 .408 .801 r
.66552 .78699 m .66661 .78428 L .6654 .78149 L p F P
0 g
s
.767 .526 0 r
.60231 .62599 m .60261 .62734 L .60369 .63394 L p F P
0 g
s
.855 .59 .053 r
.60416 .63537 m .60369 .63394 L .60261 .62734 L p F P
0 g
s
.689 .78 .921 r
.63105 .57722 m .61892 .58202 L .6159 .57879 L p F P
0 g
s
.563 .671 .911 r
.74305 .85193 m .73636 .85259 L .73347 .84829 L p F P
0 g
s
.512 .606 .883 r
.72355 .84357 m .71799 .84339 L .71503 .83833 L p F P
0 g
s
.262 .372 .787 r
.65722 .76567 m .65569 .7701 L .66205 .77417 L p F P
0 g
s
.304 .38 .776 r
.65123 .76153 m .65722 .76567 L .65569 .7701 L p F P
0 g
s
0 0 .294 r
.82591 .7953 m .82741 .79146 L .82723 .78558 L p F P
0 g
s
0 0 .16 r
.82741 .79146 m .82591 .7953 L .82576 .80038 L p F P
0 g
s
0 0 .195 r
.82504 .80188 m .82576 .80038 L .82591 .7953 L p F P
0 g
s
.148 .263 .727 r
.63552 .72661 m .63382 .72496 L .63168 .71919 L p F P
0 g
s
0 0 .481 r
.82816 .76574 m .82656 .77007 L .82803 .77558 L p F P
0 g
s
0 .028 .544 r
.82656 .77007 m .82816 .76574 L .82608 .76041 L p F P
0 g
s
.338 .432 .81 r
.6716 .79557 m .671 .79528 L .67123 .79475 L closepath p F P
0 g
s
.334 .427 .808 r
.671 .79528 m .67123 .79475 L .6685 .78857 L p F P
0 g
s
.534 .696 .943 r
.65863 .58512 m .66458 .58464 L .66162 .58075 L p F P
0 g
s
.534 .696 .943 r
.66162 .58075 m .65721 .58116 L .65863 .58512 L p F P
0 g
s
.529 .698 .947 r
.64927 .58192 m .65721 .58116 L .65863 .58512 L p F P
0 g
s
.232 .35 .779 r
.65266 .75711 m .65123 .76153 L .65722 .76567 L p F P
0 g
s
.279 .361 .768 r
.64702 .75289 m .65266 .75711 L .65123 .76153 L p F P
0 g
s
.665 .8 .348 r
.81787 .82129 m .81891 .81924 L .8184 .82032 L closepath p F P
0 g
s
.789 .505 0 r
.6049 .63896 m .60416 .63537 L .60369 .63394 L closepath p F P
0 g
s
.269 .428 .836 r
.78101 .66897 m .7847 .67082 L .78178 .66497 L p F P
0 g
s
.269 .428 .836 r
.78178 .66497 m .78132 .66474 L .78101 .66897 L p F P
0 g
s
.117 .224 .699 r
.81927 .7307 m .8167 .72772 L .81737 .72513 L closepath p F P
0 g
s
.159 .27 .73 r
.81613 .72176 m .81326 .71886 L p .8167 .72772 L F P
0 g
s
.159 .27 .73 r
.8167 .72772 m .81737 .72513 L .81613 .72176 L p F P
0 g
s
.409 .482 .824 r
.67728 .80334 m .68641 .80674 L .68425 .81122 L p F P
0 g
s
.364 .469 .834 r
.67958 .7988 m .67728 .80334 L .68641 .80674 L p F P
0 g
s
.393 .468 .818 r
.6716 .79557 m .67958 .7988 L .67728 .80334 L p F P
0 g
s
.376 .455 .814 r
.67958 .7988 m .6716 .79557 L .67123 .79475 L p F P
0 g
s
.198 .325 .768 r
.64833 .74847 m .64702 .75289 L .65266 .75711 L p F P
0 g
s
.252 .34 .76 r
.64302 .74418 m .64833 .74847 L .64702 .75289 L p F P
0 g
s
.444 .62 .926 r
.69827 .6016 m .70131 .60188 L .69839 .5976 L p F P
0 g
s
.444 .62 .926 r
.69839 .5976 m .69743 .59752 L .69827 .6016 L p F P
0 g
s
.24 .393 .816 r
.78786 .6772 m .78789 .67685 L p .794 .68495 L F P
0 g
s
.259 .417 .83 r
.78786 .6772 m .78762 .6767 L .78789 .67685 L closepath p F P
0 g
s
.148 .263 .727 r
.63168 .71919 m .63198 .71776 L p .63552 .72661 L F P
0 g
s
.113 .233 .711 r
.63168 .71919 m .63064 .71634 L .63198 .71776 L closepath p F P
0 g
s
0 0 .523 r
.61787 .68053 m .61605 .67715 L .61575 .67445 L closepath p F P
0 g
s
0 0 .484 r
.61465 .67109 m .61323 .66807 L p .61605 .67715 L F P
0 g
s
0 0 .484 r
.61605 .67715 m .61575 .67445 L .61465 .67109 L p F P
0 g
s
.453 .536 .852 r
.70118 .8262 m .69645 .82529 L .69342 .81936 L p F P
0 g
s
.341 .513 .882 r
.75691 .64219 m .75679 .638 L .74743 .63509 L p F P
0 g
s
.348 .524 .888 r
.74707 .63096 m .74743 .63509 L .75679 .638 L p F P
0 g
s
.345 .526 .89 r
.74125 .62929 m .74707 .63096 L .74743 .63509 L p F P
0 g
s
.376 .455 .814 r
.67123 .79475 m .67328 .79071 L p .67958 .7988 L F P
0 g
s
.356 .44 .81 r
.67123 .79475 m .6685 .78857 L .67328 .79071 L closepath p F P
0 g
s
.254 .417 .832 r
.78789 .67685 m .78762 .6767 L .7847 .67082 L p F P
0 g
s
.104 .231 .711 r
.63198 .71776 m .63064 .71634 L .62835 .71009 L p F P
0 g
s
.153 .286 .748 r
.64418 .73978 m .64302 .74418 L .64833 .74847 L p F P
0 g
s
.221 .317 .751 r
.6392 .73542 m .64418 .73978 L .64302 .74418 L p F P
0 g
s
.534 .703 .948 r
.65721 .58116 m .64927 .58192 L .64629 .5782 L p F P
0 g
s
.24 .393 .816 r
.78789 .67685 m .79439 .68074 L .794 .68495 L p F P
0 g
s
.233 .394 .819 r
.78811 .67266 m .78789 .67685 L .79439 .68074 L p F P
0 g
s
.254 .417 .832 r
.7847 .67082 m .78811 .67266 L .78789 .67685 L p F P
0 g
s
.142 .259 .726 r
.81613 .72176 m .81326 .71886 L .81395 .71584 L closepath p F P
0 g
s
.182 .303 .753 r
.81305 .71354 m .80925 .71016 L p .81326 .71886 L F P
0 g
s
.182 .303 .753 r
.81326 .71886 m .81395 .71584 L .81305 .71354 L p F P
0 g
s
.401 .499 .844 r
.69038 .81327 m .68425 .81122 L p .69193 .81892 L F P
0 g
s
.375 .471 .83 r
.68425 .81122 m .69038 .81327 L .68733 .80709 L p F P
0 g
s
.375 .471 .83 r
.68733 .80709 m .68641 .80674 L .68425 .81122 L p F P
0 g
s
.726 .903 .958 r
.78201 .85303 m .7824 .85282 L .78222 .85317 L closepath p F P
0 g
s
.772 .922 .936 r
.79423 .84615 m .7824 .85282 L .78222 .85317 L p F P
0 g
s
.482 .653 .934 r
.68292 .59256 m .68111 .59254 L .68018 .58876 L closepath p F P
0 g
s
.483 .66 .939 r
.67997 .58848 m .68018 .58876 L .68111 .59254 L p F P
0 g
s
.121 .261 .735 r
.6402 .73104 m .6392 .73542 L .64418 .73978 L p F P
0 g
s
.187 .291 .74 r
.63552 .72661 m .6402 .73104 L .6392 .73542 L p F P
0 g
s
.81 .997 .775 r
.80627 .83656 m .8088 .83388 L .80762 .83628 L closepath p F P
0 g
s
.835 .977 .678 r
.81477 .82631 m .8088 .83388 L .80762 .83628 L p F P
0 g
s
.223 .371 .802 r
.79961 .6932 m .80015 .68897 L .794 .68495 L p F P
0 g
s
.222 .375 .806 r
.79439 .68074 m .794 .68495 L .80015 .68897 L p F P
0 g
s
.165 .293 .75 r
.81305 .71354 m .80925 .71016 L .81009 .70599 L closepath p F P
0 g
s
.203 .333 .774 r
.81 .7058 m .8047 .7016 L p .80925 .71016 L F P
0 g
s
.203 .333 .774 r
.80925 .71016 m .81009 .70599 L .81 .7058 L p F P
0 g
s
0 0 .457 r
.61465 .67109 m .61323 .66807 L .61285 .6658 L closepath p F P
0 g
s
0 0 .407 r
.61143 .66131 m .61047 .65898 L p .61323 .66807 L F P
0 g
s
0 0 .407 r
.61323 .66807 m .61285 .6658 L .61143 .66131 L p F P
0 g
s
.104 .231 .711 r
.62835 .71009 m .62855 .70888 L p .63198 .71776 L F P
0 g
s
.066 .198 .692 r
.62835 .71009 m .62746 .7076 L .62855 .70888 L closepath p F P
0 g
s
.305 .483 .87 r
.76568 .64951 m .76286 .64843 L .75996 .64324 L p F P
0 g
s
.767 .526 0 r
.60369 .63394 m .6031 .63136 L .60231 .62599 L p F P
0 g
s
.828 .566 .016 r
.60114 .62199 m .60231 .62599 L .6031 .63136 L p F P
0 g
s
.904 .675 .167 r
.60231 .62599 m .60114 .62199 L .60099 .61643 L p F P
0 g
s
.389 .565 .905 r
.73545 .61977 m .72544 .61757 L p .73679 .62409 L F P
0 g
s
.372 .561 .908 r
.72544 .61757 m .73545 .61977 L .73256 .61518 L p F P
0 g
s
.372 .561 .908 r
.73256 .61518 m .72473 .61349 L .72544 .61757 L p F P
0 g
s
.38 .568 .911 r
.71978 .61251 m .72473 .61349 L .72544 .61757 L p F P
0 g
s
.21 .349 .786 r
.8047 .7016 m .8054 .69734 L .79961 .6932 L p F P
0 g
s
.213 .357 .793 r
.80015 .68897 m .79961 .6932 L .8054 .69734 L p F P
0 g
s
.181 .319 .769 r
.8047 .7016 m .81 .7058 L .807 .69862 L p F P
0 g
s
.181 .319 .769 r
.807 .69862 m .8054 .69734 L .8047 .7016 L p F P
0 g
s
.342 .527 .893 r
.74707 .63096 m .74125 .62929 L .73835 .62448 L p F P
0 g
s
0 .022 .542 r
.82708 .75752 m .82608 .76041 L .82816 .76574 L p F P
0 g
s
.025 .092 .596 r
.82589 .75279 m .82496 .75092 L p .82608 .76041 L F P
0 g
s
.025 .092 .596 r
.82608 .76041 m .82708 .75752 L .82589 .75279 L p F P
0 g
s
.71 .879 .96 r
.7824 .85282 m .78201 .85303 L .77933 .85094 L p F P
0 g
s
.65 .86 .98 r
.76695 .85531 m .77933 .85094 L .78201 .85303 L p F P
0 g
s
0 0 0 r
.82086 .81492 m .82348 .80826 L p .81911 .81876 L F P
0 g
s
0 0 0 r
.81891 .81924 m .82086 .81492 L p .81911 .81876 L F P
0 g
s
0 0 0 r
.82509 .80488 m .82348 .80826 L .82086 .81492 L p F P
0 g
s
0 0 0 r
.82466 .80631 m .82509 .80488 L p .82086 .81492 L F P
0 g
s
0 0 0 r
.82086 .81492 m .82288 .81057 L .82466 .80631 L p F P
0 g
s
.749 .883 .473 r
.82086 .81492 m .81703 .82193 L p .82262 .81107 L F P
0 g
s
.749 .883 .473 r
.82288 .81057 m .82086 .81492 L p .82262 .81107 L F P
0 g
s
.775 .875 .448 r
.81891 .81924 m .82086 .81492 L p .81641 .82335 L F P
0 g
s
.775 .875 .448 r
.81641 .82335 m .81787 .82129 L .81891 .81924 L p F P
0 g
s
.054 .194 .692 r
.62855 .70888 m .62746 .7076 L .62508 .70106 L p F P
0 g
s
.997 .839 .558 r
.60001 .59677 m .60183 .60062 L .60015 .60672 L p F P
0 g
s
.967 .867 .687 r
.60183 .60062 m .60001 .59677 L .60304 .59026 L p F P
0 g
s
0 0 .29 r
.8289 .78127 m .82723 .78558 L .82741 .79146 L p F P
0 g
s
0 0 .398 r
.82723 .78558 m .8289 .78127 L .82803 .77558 L p F P
0 g
s
.71 .879 .96 r
.77933 .85094 m .78439 .84856 L .7824 .85282 L p F P
0 g
s
.729 .942 .953 r
.79164 .84489 m .78439 .84856 L .7824 .85282 L p F P
0 g
s
.729 .942 .953 r
.7824 .85282 m .79423 .84615 L .79164 .84489 L p F P
0 g
s
.595 .774 .965 r
.75171 .85502 m .76419 .85237 L .76695 .85531 L p F P
0 g
s
.58 .751 .959 r
.76419 .85237 m .75171 .85502 L .74888 .85137 L p F P
0 g
s
.085 .233 .721 r
.63636 .72226 m .63552 .72661 L .6402 .73104 L p F P
0 g
s
.148 .263 .727 r
.63198 .71776 m .63636 .72226 L .63552 .72661 L p F P
0 g
s
0 0 .174 r
.60369 .63394 m .6031 .63136 L p .60531 .64065 L F P
0 g
s
0 0 .174 r
.60531 .64065 m .6049 .63896 L .60369 .63394 L p F P
0 g
s
.404 .503 .846 r
.69342 .81936 m .69193 .81892 L .69257 .81766 L closepath p F P
0 g
s
.401 .499 .844 r
.69193 .81892 m .69257 .81766 L .69038 .81327 L p F P
0 g
s
.054 .194 .692 r
.62508 .70106 m .62522 .69996 L p .62855 .70888 L F P
0 g
s
.013 .157 .67 r
.62508 .70106 m .62427 .69873 L .62522 .69996 L closepath p F P
0 g
s
.324 .498 .875 r
.75691 .64219 m .75996 .64324 L .75706 .6381 L p F P
0 g
s
.324 .498 .875 r
.75706 .6381 m .75679 .638 L .75691 .64219 L p F P
0 g
s
.667 .843 .431 r
.81477 .82631 m .81641 .82335 L .81787 .82129 L closepath p F P
0 g
s
.445 .629 .932 r
.68292 .59256 m .69546 .59341 L p .69743 .59752 L F P
0 g
s
.429 .624 .934 r
.69253 .58929 m .69546 .59341 L .68292 .59256 L p F P
0 g
s
.429 .624 .934 r
.68008 .58849 m .69253 .58929 L p .68292 .59256 L F P
0 g
s
.429 .624 .934 r
.68292 .59256 m .68018 .58876 L .68008 .58849 L p F P
0 g
s
0 0 .376 r
.61143 .66131 m .61047 .65898 L .61011 .65734 L closepath p F P
0 g
s
0 0 .313 r
.60819 .65095 m .6078 .64984 L p .61047 .65898 L F P
0 g
s
0 0 .313 r
.61047 .65898 m .61011 .65734 L .60819 .65095 L p F P
0 g
s
.357 .44 .809 r
.67328 .79071 m .6685 .78857 L .66661 .78428 L p F P
0 g
s
.41 .597 .922 r
.70131 .60188 m .71138 .60325 L .7122 .60732 L p F P
0 g
s
.41 .6 .924 r
.71138 .60325 m .70131 .60188 L .69839 .5976 L p F P
0 g
s
0 0 .026 r
.82576 .80038 m .82504 .80188 L .82348 .80826 L p F P
0 g
s
.044 .202 .704 r
.63264 .71344 m .63198 .71776 L .63636 .72226 L p F P
0 g
s
.104 .231 .711 r
.62855 .70888 m .63264 .71344 L .63198 .71776 L p F P
0 g
s
0 .151 .669 r
.62522 .69996 m .62427 .69873 L .62189 .6921 L p F P
0 g
s
.633 .832 .977 r
.77933 .85094 m .76695 .85531 L .76419 .85237 L p F P
0 g
s
.486 .601 .893 r
.72355 .84357 m .73056 .84383 L .72764 .83923 L p F P
0 g
s
.486 .601 .893 r
.72764 .83923 m .72604 .8391 L .72355 .84357 L p F P
0 g
s
.512 .606 .883 r
.71503 .83833 m .72604 .8391 L .72355 .84357 L p F P
0 g
s
.938 .692 .218 r
.59953 .6125 m .60099 .61643 L .60114 .62199 L p F P
0 g
s
.985 .784 .384 r
.60099 .61643 m .59953 .6125 L .60015 .60672 L p F P
0 g
s
.496 .592 .88 r
.72604 .8391 m .71503 .83833 L .71206 .83315 L p F P
0 g
s
0 0 .215 r
.60542 .64129 m .6049 .63896 L .60531 .64065 L closepath p F P
0 g
s
0 .151 .669 r
.62189 .6921 m .62197 .69101 L p .62522 .69996 L F P
0 g
s
0 .11 .641 r
.62189 .6921 m .62107 .68972 L .62197 .69101 L closepath p F P
0 g
s
.537 .673 .925 r
.74305 .85193 m .74888 .85137 L .74603 .84754 L p F P
0 g
s
.537 .673 .925 r
.74603 .84754 m .74523 .84758 L .74305 .85193 L p F P
0 g
s
.563 .671 .911 r
.73347 .84829 m .74523 .84758 L .74305 .85193 L p F P
0 g
s
0 .167 .684 r
.62902 .70459 m .62855 .70888 L .63264 .71344 L p F P
0 g
s
.054 .194 .692 r
.62522 .69996 m .62902 .70459 L .62855 .70888 L p F P
0 g
s
.005 .078 .589 r
.82589 .75279 m .82496 .75092 L .82522 .7501 L closepath p F P
0 g
s
.06 .141 .636 r
.82496 .75092 m .82522 .7501 L .82298 .74224 L p F P
0 g
s
0 .101 .639 r
.62197 .69101 m .62107 .68972 L .61877 .68322 L p F P
0 g
s
.453 .536 .852 r
.69342 .81936 m .70357 .8217 L .70118 .8262 L p F P
0 g
s
.437 .522 .847 r
.70357 .8217 m .69342 .81936 L .69257 .81766 L p F P
0 g
s
.49 .664 .939 r
.66458 .58464 m .67703 .5845 L .67997 .58848 L p F P
0 g
s
.491 .668 .941 r
.67703 .5845 m .66458 .58464 L .66162 .58075 L p F P
0 g
s
.378 .57 .913 r
.72473 .61349 m .71978 .61251 L .71688 .60805 L p F P
0 g
s
0 0 .278 r
.60819 .65095 m .6078 .64984 L .60761 .64913 L closepath p F P
0 g
s
0 0 .197 r
.6078 .64984 m .60761 .64913 L .60542 .64129 L p F P
0 g
s
.059 .164 .66 r
.82037 .73392 m .82071 .73245 L p .82315 .7416 L F P
0 g
s
.059 .164 .66 r
.82315 .7416 m .8225 .74068 L .82037 .73392 L p F P
0 g
s
.09 .204 .69 r
.82037 .73392 m .81927 .7307 L .82071 .73245 L closepath p F P
0 g
s
.547 .655 .906 r
.74523 .84758 m .73347 .84829 L .73056 .84383 L p F P
0 g
s
.248 .415 .832 r
.78811 .67266 m .7847 .67082 L .78178 .66497 L p F P
0 g
s
.062 .165 .66 r
.82298 .74224 m .8225 .74068 L .82315 .7416 L closepath p F P
0 g
s
0 0 .316 r
.60531 .64065 m .60542 .64129 L .60761 .64913 L p F P
0 g
s
.007 .105 .618 r
.82315 .7416 m .82298 .74224 L .82522 .7501 L p F P
0 g
s
.357 .44 .809 r
.66661 .78428 m .66745 .7825 L p .67328 .79071 L F P
0 g
s
.337 .424 .804 r
.66661 .78428 m .6654 .78149 L .66745 .7825 L closepath p F P
0 g
s
.087 .204 .69 r
.82071 .73245 m .81927 .7307 L .81737 .72513 L p F P
0 g
s
.797 .98 .704 r
.81641 .82335 m .81477 .82631 L .8088 .83388 L p F P
0 g
s
0 .101 .639 r
.61877 .68322 m .61881 .68202 L p .62197 .69101 L F P
0 g
s
0 .055 .606 r
.61877 .68322 m .61787 .68053 L .61881 .68202 L closepath p F P
0 g
s
.304 .479 .867 r
.76551 .64536 m .76568 .64951 L .77376 .65286 L p F P
0 g
s
.305 .483 .87 r
.75996 .64324 m .76551 .64536 L .76568 .64951 L p F P
0 g
s
.296 .466 .86 r
.77374 .65705 m .77376 .65286 L .76568 .64951 L p F P
0 g
s
.849 .848 .841 r
.61114 .58218 m .60394 .58889 L .60092 .5864 L p F P
0 g
s
.849 .848 .841 r
.60092 .5864 m .60903 .57839 L .61114 .58218 L p F P
0 g
s
.785 .821 .88 r
.61288 .57553 m .60903 .57839 L .61114 .58218 L p F P
0 g
s
.785 .821 .88 r
.61114 .58218 m .6159 .57879 L .61288 .57553 L p F P
0 g
s
0 .043 .6 r
.61881 .68202 m .61787 .68053 L .61575 .67445 L p F P
0 g
s
.465 .548 .857 r
.70118 .8262 m .70907 .82777 L p .71185 .83312 L F P
0 g
s
.425 .526 .857 r
.70118 .8262 m .70907 .82777 L .70608 .8223 L p F P
0 g
s
.425 .526 .857 r
.70608 .8223 m .70357 .8217 L .70118 .8262 L p F P
0 g
s
0 .126 .659 r
.62548 .6957 m .62522 .69996 L .62902 .70459 L p F P
0 g
s
0 .151 .669 r
.62197 .69101 m .62548 .6957 L .62522 .69996 L p F P
0 g
s
.918 .853 .763 r
.60304 .59026 m .60394 .58889 L .60092 .5864 L p F P
0 g
s
.406 .591 .919 r
.7122 .60732 m .71688 .60805 L .71396 .60363 L p F P
0 g
s
.406 .591 .919 r
.71396 .60363 m .71138 .60325 L .7122 .60732 L p F P
0 g
s
.087 .204 .69 r
.81737 .72513 m .81771 .72344 L p .82071 .73245 L F P
0 g
s
.116 .241 .718 r
.81737 .72513 m .81613 .72176 L .81771 .72344 L closepath p F P
0 g
s
.601 .736 .939 r
.63105 .57722 m .64331 .57451 L .64629 .5782 L p F P
0 g
s
.607 .74 .94 r
.64331 .57451 m .63105 .57722 L .62805 .5737 L p F P
0 g
s
.689 .78 .921 r
.6159 .57879 m .62805 .5737 L .63105 .57722 L p F P
0 g
s
.437 .522 .847 r
.69257 .81766 m .69449 .81435 L p .70357 .8217 L F P
0 g
s
.421 .511 .845 r
.69257 .81766 m .69038 .81327 L .69449 .81435 L closepath p F P
0 g
s
0 0 .399 r
.82967 .77124 m .82803 .77558 L .8289 .78127 L p F P
0 g
s
0 0 .481 r
.82803 .77558 m .82967 .77124 L .82816 .76574 L p F P
0 g
s
.364 .544 .898 r
.73835 .62448 m .73679 .62409 L .73651 .62147 L closepath p F P
0 g
s
.389 .565 .905 r
.73679 .62409 m .73651 .62147 L .73545 .61977 L p F P
0 g
s
0 .043 .6 r
.61575 .67445 m .61572 .67301 L p .61881 .68202 L F P
0 g
s
0 0 .56 r
.61575 .67445 m .61465 .67109 L .61572 .67301 L closepath p F P
0 g
s
.965 .853 .681 r
.60085 .58651 m .60304 .59026 L .60001 .59677 L p F P
0 g
s
.918 .853 .763 r
.60092 .5864 m .60085 .58651 L .60304 .59026 L p F P
0 g
s
.766 .966 .928 r
.7994 .84236 m .79423 .84615 L .79164 .84489 L p F P
0 g
s
0 0 .549 r
.61572 .67301 m .61465 .67109 L .61285 .6658 L p F P
0 g
s
0 0 .397 r
.60761 .64913 m .60702 .64578 L p .60981 .6549 L F P
0 g
s
0 0 .397 r
.60981 .6549 m .60819 .65095 L .60761 .64913 L p F P
0 g
s
0 0 .316 r
.60761 .64913 m .60702 .64578 L .60531 .64065 L p F P
0 g
s
0 0 .422 r
.61011 .65734 m .60819 .65095 L .60981 .6549 L closepath p F P
0 g
s
0 .053 .576 r
.82522 .7501 m .82611 .74665 L p .82749 .7561 L F P
0 g
s
0 .053 .576 r
.82749 .7561 m .82589 .75279 L .82522 .7501 L p F P
0 g
s
.007 .105 .618 r
.82522 .7501 m .82611 .74665 L .82315 .7416 L p F P
0 g
s
.338 .424 .803 r
.66745 .7825 m .6654 .78149 L .66229 .77432 L p F P
0 g
s
.114 .241 .718 r
.81771 .72344 m .81613 .72176 L .81395 .71584 L p F P
0 g
s
0 0 .249 r
.60437 .63661 m .60531 .64065 L .60702 .64578 L p F P
0 g
s
0 0 .249 r
.60599 .64177 m .60437 .63661 L p .60566 .64109 L F P
0 g
s
0 0 .249 r
.60702 .64578 m .60599 .64177 L p .60566 .64109 L F P
0 g
s
0 0 .241 r
.60599 .64177 m .6079 .64686 L p .60632 .64245 L F P
0 g
s
0 0 .241 r
.60466 .63784 m .60599 .64177 L p .60632 .64245 L F P
0 g
s
.705 .402 0 r
.60437 .63661 m .60599 .64177 L p .60444 .63688 L F P
0 g
s
.705 .402 0 r
.6031 .63265 m .60437 .63661 L p .60444 .63688 L F P
0 g
s
0 0 .174 r
.60437 .63661 m .60531 .64065 L p .60429 .63635 L F P
0 g
s
0 0 .174 r
.6031 .63136 m .60437 .63661 L p .60429 .63635 L F P
0 g
s
.697 .784 .918 r
.62805 .5737 m .6159 .57879 L .61288 .57553 L p F P
0 g
s
.001 .105 .619 r
.82414 .73736 m .82315 .7416 L .82611 .74665 L p F P
0 g
s
.059 .164 .66 r
.82071 .73245 m .82414 .73736 L .82315 .7416 L p F P
0 g
s
0 0 .5 r
.61285 .6658 m .61143 .66131 L .61272 .66397 L closepath p F P
0 g
s
0 0 .483 r
.61272 .66397 m .61143 .66131 L .61011 .65734 L p F P
0 g
s
0 0 .549 r
.61285 .6658 m .61272 .66397 L p .61572 .67301 L F P
0 g
s
0 0 .483 r
.61011 .65734 m .60981 .6549 L p .61272 .66397 L F P
0 g
s
0 .08 .629 r
.62204 .68678 m .62197 .69101 L .62548 .6957 L p F P
0 g
s
0 .101 .639 r
.61881 .68202 m .62204 .68678 L .62197 .69101 L p F P
0 g
s
0 0 0 r
.82686 .79756 m .82576 .80038 L .82509 .80488 L p F P
0 g
s
0 0 .16 r
.82576 .80038 m .82686 .79756 L .82741 .79146 L p F P
0 g
s
0 0 .026 r
.82348 .80826 m .82509 .80488 L .82576 .80038 L p F P
0 g
s
.993 .78 .407 r
.5984 .60285 m .60015 .60672 L .59953 .6125 L p F P
0 g
s
.997 .839 .558 r
.60015 .60672 m .5984 .60285 L .60001 .59677 L p F P
0 g
s
.3 .483 .872 r
.76551 .64536 m .75996 .64324 L .75706 .6381 L p F P
0 g
s
.766 .966 .928 r
.79164 .84489 m .80197 .83791 L .7994 .84236 L p F P
0 g
s
.776 .997 .852 r
.8038 .83651 m .80197 .83791 L .7994 .84236 L p F P
0 g
s
.776 .997 .852 r
.7994 .84236 m .80627 .83656 L .8038 .83651 L p F P
0 g
s
0 .054 .576 r
.82708 .75752 m .82589 .75279 L .82749 .7561 L closepath p F P
0 g
s
.811 1 .816 r
.8088 .83388 m .80627 .83656 L .8038 .83651 L p F P
0 g
s
.811 1 .816 r
.8038 .83651 m .81096 .82953 L .8088 .83388 L p F P
0 g
s
.797 .98 .704 r
.81565 .82396 m .81641 .82335 L p .8088 .83388 L F P
0 g
s
.797 .98 .704 r
.8088 .83388 m .81096 .82953 L .81565 .82396 L p F P
0 g
s
.295 .459 .853 r
.77887 .65937 m .77374 .65705 L p .78132 .66474 L F P
0 g
s
.277 .45 .852 r
.77374 .65705 m .77887 .65937 L .77596 .65386 L p F P
0 g
s
.277 .45 .852 r
.77596 .65386 m .77376 .65286 L .77374 .65705 L p F P
0 g
s
.539 .7 .944 r
.65721 .58116 m .66162 .58075 L .65865 .5769 L p F P
0 g
s
.539 .7 .944 r
.65865 .5769 m .65571 .5772 L .65721 .58116 L p F P
0 g
s
.534 .703 .948 r
.64629 .5782 m .65571 .5772 L .65721 .58116 L p F P
0 g
s
.114 .241 .718 r
.81395 .71584 m .81417 .71459 L p .81771 .72344 L F P
0 g
s
.141 .276 .742 r
.81395 .71584 m .81305 .71354 L .81417 .71459 L closepath p F P
0 g
s
.342 .527 .893 r
.73835 .62448 m .74661 .62684 L .74707 .63096 L p F P
0 g
s
.338 .529 .895 r
.74661 .62684 m .73835 .62448 L .73651 .62147 L p F P
0 g
s
.538 .708 .949 r
.65571 .5772 m .64629 .5782 L .64331 .57451 L p F P
0 g
s
0 .026 .592 r
.61866 .67784 m .61881 .68202 L .62204 .68678 L p F P
0 g
s
0 .043 .6 r
.61572 .67301 m .61866 .67784 L .61881 .68202 L p F P
0 g
s
0 0 .147 r
.82907 .78716 m .82741 .79146 L .82686 .79756 L p F P
0 g
s
0 0 .29 r
.82741 .79146 m .82907 .78716 L .8289 .78127 L p F P
0 g
s
.039 .155 .658 r
.82159 .72821 m .82071 .73245 L .82414 .73736 L p F P
0 g
s
.087 .204 .69 r
.81771 .72344 m .82159 .72821 L .82071 .73245 L p F P
0 g
s
.76 .475 0 r
.6019 .62738 m .6031 .63136 L .60437 .63661 L p F P
0 g
s
.828 .566 .016 r
.6031 .63136 m .6019 .62738 L .60114 .62199 L p F P
0 g
s
.139 .275 .742 r
.81417 .71459 m .81305 .71354 L .81009 .70599 L p F P
0 g
s
.442 .622 .928 r
.69839 .5976 m .69743 .59752 L .69695 .59553 L closepath p F P
0 g
s
.445 .629 .932 r
.69546 .59341 m .69695 .59553 L .69743 .59752 L p F P
0 g
s
0 0 .518 r
.82749 .7561 m .82708 .75752 L .82859 .76452 L p F P
0 g
s
0 .022 .542 r
.82816 .76574 m .82859 .76452 L .82708 .75752 L p F P
0 g
s
.423 .51 .843 r
.69449 .81435 m .69038 .81327 L .68733 .80709 L p F P
0 g
s
.263 .428 .838 r
.78178 .66497 m .78132 .66474 L .78135 .66412 L closepath p F P
0 g
s
.295 .459 .853 r
.78132 .66474 m .78135 .66412 L .77887 .65937 L p F P
0 g
s
.58 .751 .959 r
.74888 .85137 m .7614 .84919 L .76419 .85237 L p F P
0 g
s
.564 .73 .952 r
.7614 .84919 m .74888 .85137 L .74603 .84754 L p F P
0 g
s
.268 .379 .791 r
.66229 .77432 m .66205 .77417 L .66212 .77393 L closepath p F P
0 g
s
.262 .372 .787 r
.65916 .767 m .65722 .76567 L p .66205 .77417 L F P
0 g
s
.262 .372 .787 r
.66205 .77417 m .66212 .77393 L .65916 .767 L p F P
0 g
s
0 0 .477 r
.82859 .76452 m .82816 .76574 L .82967 .77124 L p F P
0 g
s
.449 .559 .875 r
.71206 .83315 m .71185 .83312 L .71194 .83293 L closepath p F P
0 g
s
.465 .548 .857 r
.70907 .82777 m .71194 .83293 L .71185 .83312 L p F P
0 g
s
.348 .524 .888 r
.75417 .63315 m .74707 .63096 L p .75679 .638 L F P
0 g
s
.331 .517 .889 r
.74707 .63096 m .75417 .63315 L .75127 .62827 L p F P
0 g
s
.331 .517 .889 r
.75127 .62827 m .74661 .62684 L .74707 .63096 L p F P
0 g
s
.239 .358 .783 r
.65916 .767 m .65722 .76567 L .65776 .76372 L closepath p F P
0 g
s
.232 .35 .779 r
.65603 .75963 m .65266 .75711 L p .65722 .76567 L F P
0 g
s
.232 .35 .779 r
.65722 .76567 m .65776 .76372 L .65603 .75963 L p F P
0 g
s
0 0 .544 r
.61536 .66887 m .61572 .67301 L .61866 .67784 L p F P
0 g
s
0 0 .549 r
.61272 .66397 m .61536 .66887 L .61572 .67301 L p F P
0 g
s
.357 .44 .809 r
.66745 .7825 m .67504 .78627 L .67328 .79071 L p F P
0 g
s
.299 .419 .816 r
.66922 .77803 m .66745 .7825 L .67504 .78627 L p F P
0 g
s
.338 .424 .803 r
.66229 .77432 m .66922 .77803 L .66745 .7825 L p F P
0 g
s
.496 .592 .88 r
.71206 .83315 m .7247 .83444 L p .72604 .8391 L F P
0 g
s
.47 .571 .875 r
.72174 .82951 m .7247 .83444 L .71206 .83315 L p F P
0 g
s
.47 .571 .875 r
.71467 .82852 m .72174 .82951 L p .71206 .83315 L F P
0 g
s
.47 .571 .875 r
.71206 .83315 m .71194 .83293 L .71467 .82852 L p F P
0 g
s
.451 .64 .937 r
.68018 .58876 m .67997 .58848 L .68008 .58849 L closepath p F P
0 g
s
.317 .41 .799 r
.66922 .77803 m .66229 .77432 L .66212 .77393 L p F P
0 g
s
.072 .198 .691 r
.81848 .71922 m .81771 .72344 L .82159 .72821 L p F P
0 g
s
.114 .241 .718 r
.81417 .71459 m .81848 .71922 L .81771 .72344 L p F P
0 g
s
.468 .568 .873 r
.71194 .83293 m .70907 .82777 L .71467 .82852 L closepath p F P
0 g
s
.207 .335 .774 r
.65603 .75963 m .65266 .75711 L .65348 .75358 L closepath p F P
0 g
s
.198 .325 .768 r
.6529 .7522 m .64833 .74847 L p .65266 .75711 L F P
0 g
s
.198 .325 .768 r
.65266 .75711 m .65348 .75358 L .6529 .7522 L p F P
0 g
s
.248 .415 .832 r
.78178 .66497 m .78825 .66848 L .78811 .67266 L p F P
0 g
s
.239 .412 .833 r
.78825 .66848 m .78178 .66497 L .78135 .66412 L p F P
0 g
s
.317 .41 .799 r
.66212 .77393 m .66376 .76969 L p .66922 .77803 L F P
0 g
s
.295 .393 .793 r
.66212 .77393 m .65916 .767 L .66376 .76969 L closepath p F P
0 g
s
.41 .6 .924 r
.69839 .5976 m .71046 .59918 L .71138 .60325 L p F P
0 g
s
.409 .604 .927 r
.71046 .59918 m .69839 .5976 L .69695 .59553 L p F P
0 g
s
.376 .455 .814 r
.67328 .79071 m .6812 .79436 L p .67958 .7988 L F P
0 g
s
.321 .423 .81 r
.67328 .79071 m .6812 .79436 L .67812 .78782 L p F P
0 g
s
.321 .423 .81 r
.67812 .78782 m .67504 .78627 L .67328 .79071 L p F P
0 g
s
.448 .642 .94 r
.68008 .58849 m .67997 .58848 L .67703 .5845 L p F P
0 g
s
.445 .639 .939 r
.68008 .58849 m .69253 .58929 L .68959 .58522 L p F P
0 g
s
.445 .639 .939 r
.68959 .58522 m .67854 .58457 L .68008 .58849 L p F P
0 g
s
.448 .642 .94 r
.67703 .5845 m .67854 .58457 L .68008 .58849 L p F P
0 g
s
.233 .394 .819 r
.79439 .68074 m .79469 .67653 L .78811 .67266 L p F P
0 g
s
.232 .398 .823 r
.78825 .66848 m .78811 .67266 L .79469 .67653 L p F P
0 g
s
.16 .294 .753 r
.64833 .74847 m .6529 .7522 L .64976 .74469 L p F P
0 g
s
.16 .294 .753 r
.64976 .74469 m .64916 .74418 L .64833 .74847 L p F P
0 g
s
.153 .286 .748 r
.64833 .74847 m .64916 .74418 L .64418 .73978 L p F P
0 g
s
.995 .825 .562 r
.59794 .59298 m .60001 .59677 L .5984 .60285 L p F P
0 g
s
.965 .853 .681 r
.60001 .59677 m .59794 .59298 L .60085 .58651 L p F P
0 g
s
.689 .868 .966 r
.78439 .84856 m .77933 .85094 L .77663 .84854 L p F P
0 g
s
.633 .832 .977 r
.76419 .85237 m .77663 .84854 L .77933 .85094 L p F P
0 g
s
.239 .412 .833 r
.78135 .66412 m .78133 .66057 L p .78825 .66848 L F P
0 g
s
.259 .436 .846 r
.78135 .66412 m .77887 .65937 L .78133 .66057 L closepath p F P
0 g
s
.878 .597 .077 r
.59968 .61807 m .60114 .62199 L .6019 .62738 L p F P
0 g
s
.938 .692 .218 r
.60114 .62199 m .59968 .61807 L .59953 .6125 L p F P
0 g
s
.37 .563 .91 r
.72473 .61349 m .73256 .61518 L .72965 .61065 L p F P
0 g
s
.37 .563 .91 r
.72965 .61065 m .72392 .60943 L .72473 .61349 L p F P
0 g
s
.378 .57 .913 r
.71688 .60805 m .72392 .60943 L .72473 .61349 L p F P
0 g
s
.099 .236 .718 r
.81481 .71037 m .81417 .71459 L .81848 .71922 L p F P
0 g
s
.139 .275 .742 r
.8101 .70588 m .81481 .71037 L .81417 .71459 L p F P
0 g
s
.139 .275 .742 r
.81009 .70599 m .8101 .70588 L p .81417 .71459 L F P
0 g
s
.364 .469 .834 r
.68427 .80075 m .67958 .7988 L p .68641 .80674 L F P
0 g
s
.348 .458 .831 r
.68427 .80075 m .67958 .7988 L .68125 .79447 L closepath p F P
0 g
s
.376 .455 .814 r
.6812 .79436 m .68125 .79447 L .67958 .7988 L p F P
0 g
s
0 0 .483 r
.61214 .65987 m .61272 .66397 L .61536 .66887 L p F P
0 g
s
0 0 .483 r
.60981 .6549 m .61214 .65987 L .61272 .66397 L p F P
0 g
s
.13 .278 .749 r
.64488 .7355 m .64418 .73978 L .64916 .74418 L p F P
0 g
s
.121 .261 .735 r
.64418 .73978 m .64488 .7355 L .6402 .73104 L p F P
0 g
s
.547 .655 .906 r
.73056 .84383 m .74316 .84349 L p .74523 .84758 L F P
0 g
s
.506 .649 .922 r
.74316 .84349 m .73056 .84383 L .72764 .83923 L p F P
0 g
s
.222 .375 .806 r
.80015 .68897 m .80063 .68473 L .79439 .68074 L p F P
0 g
s
.223 .382 .812 r
.79469 .67653 m .79439 .68074 L .80063 .68473 L p F P
0 g
s
.164 .307 .764 r
.81009 .70599 m .81 .7058 L .8101 .70588 L closepath p F P
0 g
s
.616 .805 .973 r
.77663 .84854 m .76419 .85237 L .7614 .84919 L p F P
0 g
s
.376 .573 .916 r
.72392 .60943 m .71688 .60805 L .71396 .60363 L p F P
0 g
s
.159 .306 .765 r
.8101 .70588 m .81 .7058 L .807 .69862 L p F P
0 g
s
.122 .269 .742 r
.81061 .70168 m .8101 .70588 L .81481 .71037 L p F P
0 g
s
.159 .306 .765 r
.807 .69862 m .81061 .70168 L .8101 .70588 L p F P
0 g
s
.213 .357 .793 r
.80401 .69172 m .80015 .68897 L p .8054 .69734 L F P
0 g
s
.192 .344 .789 r
.80015 .68897 m .80401 .69172 L .80104 .68503 L p F P
0 g
s
.192 .344 .789 r
.80104 .68503 m .80063 .68473 L .80015 .68897 L p F P
0 g
s
.174 .318 .77 r
.807 .69862 m .8054 .69734 L .80567 .69547 L closepath p F P
0 g
s
.213 .357 .793 r
.8054 .69734 m .80567 .69547 L .80401 .69172 L p F P
0 g
s
.086 .246 .733 r
.64076 .72678 m .6402 .73104 L .64488 .7355 L p F P
0 g
s
.085 .233 .721 r
.6402 .73104 m .64076 .72678 L .63636 .72226 L p F P
0 g
s
.338 .529 .895 r
.73651 .62147 m .73627 .61998 L p .74661 .62684 L F P
0 g
s
.352 .543 .902 r
.73651 .62147 m .73545 .61977 L .73627 .61998 L closepath p F P
0 g
s
.491 .668 .941 r
.66162 .58075 m .67407 .58055 L .67703 .5845 L p F P
0 g
s
.491 .671 .944 r
.67407 .58055 m .66162 .58075 L .65865 .5769 L p F P
0 g
s
.368 .473 .836 r
.68733 .80709 m .68641 .80674 L .68676 .80592 L closepath p F P
0 g
s
.364 .469 .834 r
.68641 .80674 m .68676 .80592 L .68427 .80075 L p F P
0 g
s
0 0 .518 r
.82859 .76452 m .82946 .76147 L .82749 .7561 L p F P
0 g
s
0 0 .518 r
.82861 .75186 m .82749 .7561 L .82946 .76147 L p F P
0 g
s
0 .053 .576 r
.82611 .74665 m .82861 .75186 L .82749 .7561 L p F P
0 g
s
0 0 .448 r
.82946 .76147 m .82859 .76452 L .82973 .77108 L p F P
0 g
s
0 0 .477 r
.82967 .77124 m .82973 .77108 L .82859 .76452 L p F P
0 g
s
0 0 .404 r
.60901 .65084 m .60981 .6549 L .61214 .65987 L p F P
0 g
s
0 0 .397 r
.60702 .64578 m .60901 .65084 L .60981 .6549 L p F P
0 g
s
.319 .499 .878 r
.75706 .6381 m .75679 .638 L .75677 .63759 L closepath p F P
0 g
s
.348 .524 .888 r
.75679 .638 m .75677 .63759 L .75417 .63315 L p F P
0 g
s
0 0 .288 r
.83046 .77718 m .8289 .78127 L .82907 .78716 L p F P
0 g
s
0 0 .399 r
.83001 .77345 m .82967 .77124 L p .8289 .78127 L F P
0 g
s
0 0 .399 r
.8289 .78127 m .83046 .77718 L .83001 .77345 L p F P
0 g
s
.035 .21 .714 r
.63676 .71802 m .63636 .72226 L .64076 .72678 L p F P
0 g
s
.044 .202 .704 r
.63636 .72226 m .63676 .71802 L .63264 .71344 L p F P
0 g
s
.775 .875 .448 r
.82086 .81492 m .81703 .82193 L .81641 .82335 L p F P
0 g
s
.787 .941 .59 r
.81565 .82396 m .81703 .82193 L .81641 .82335 L closepath p F P
0 g
s
.294 .393 .793 r
.66376 .76969 m .65916 .767 L .65776 .76372 L p F P
0 g
s
.3 .483 .872 r
.75706 .6381 m .76524 .64122 L .76551 .64536 L p F P
0 g
s
.294 .483 .874 r
.76524 .64122 m .75706 .6381 L .75677 .63759 L p F P
0 g
s
.689 .868 .966 r
.77663 .84854 m .78719 .84405 L .78439 .84856 L p F P
0 g
s
.715 .913 .963 r
.78901 .84323 m .78719 .84405 L .78439 .84856 L p F P
0 g
s
.715 .913 .963 r
.78439 .84856 m .79164 .84489 L .78901 .84323 L p F P
0 g
s
.96 .701 .258 r
.5978 .60864 m .59953 .6125 L .59968 .61807 L p F P
0 g
s
.993 .78 .407 r
.59953 .6125 m .5978 .60864 L .5984 .60285 L p F P
0 g
s
.409 .604 .927 r
.69695 .59553 m .6963 .5935 L p .71046 .59918 L F P
0 g
s
.417 .613 .93 r
.69695 .59553 m .69546 .59341 L .6963 .5935 L closepath p F P
0 g
s
.423 .51 .843 r
.68733 .80709 m .6966 .80989 L .69449 .81435 L p F P
0 g
s
.406 .496 .839 r
.6966 .80989 m .68733 .80709 L .68676 .80592 L p F P
0 g
s
.294 .483 .874 r
.75677 .63759 m .75635 .6339 L p .76524 .64122 L F P
0 g
s
.311 .502 .883 r
.75677 .63759 m .75417 .63315 L .75635 .6339 L closepath p F P
0 g
s
.607 .74 .94 r
.62805 .5737 m .64031 .57084 L .64331 .57451 L p F P
0 g
s
.611 .744 .94 r
.64031 .57084 m .62805 .5737 L .62503 .57019 L p F P
0 g
s
.697 .784 .918 r
.61288 .57553 m .62503 .57019 L .62805 .5737 L p F P
0 g
s
0 .16 .684 r
.63287 .70922 m .63264 .71344 L .63676 .71802 L p F P
0 g
s
0 .167 .684 r
.63264 .71344 m .63287 .70922 L .62902 .70459 L p F P
0 g
s
.854 .863 .846 r
.60903 .57839 m .60671 .57465 L p .60062 .58614 L F P
0 g
s
.854 .863 .846 r
.60062 .58614 m .60092 .5864 L .60903 .57839 L p F P
0 g
s
.793 .821 .874 r
.60984 .57223 m .60671 .57465 L .60903 .57839 L p F P
0 g
s
.793 .821 .874 r
.60903 .57839 m .61288 .57553 L .60984 .57223 L p F P
0 g
s
0 0 0 r
.82509 .80488 m .82547 .8039 L .82686 .79756 L p F P
0 g
s
0 0 0 r
.82849 .79327 m .82686 .79756 L .82547 .8039 L p F P
0 g
s
0 0 .147 r
.82686 .79756 m .82849 .79327 L .82907 .78716 L p F P
0 g
s
0 0 .305 r
.60599 .64177 m .60702 .64578 L .60901 .65084 L p F P
0 g
s
.348 .545 .904 r
.73627 .61998 m .73545 .61977 L .73256 .61518 L p F P
0 g
s
.437 .522 .847 r
.69449 .81435 m .70306 .81669 L p .70357 .8217 L F P
0 g
s
.394 .497 .846 r
.69449 .81435 m .70306 .81669 L .70004 .81096 L p F P
0 g
s
.394 .497 .846 r
.70004 .81096 m .6966 .80989 L .69449 .81435 L p F P
0 g
s
.406 .496 .839 r
.68676 .80592 m .68863 .80222 L p .6966 .80989 L F P
0 g
s
.389 .484 .836 r
.68676 .80592 m .68427 .80075 L .68863 .80222 L closepath p F P
0 g
s
.294 .393 .793 r
.65776 .76372 m .65861 .76127 L p .66376 .76969 L F P
0 g
s
.27 .374 .786 r
.65776 .76372 m .65603 .75963 L .65861 .76127 L closepath p F P
0 g
s
0 .121 .66 r
.62907 .70039 m .62902 .70459 L .63287 .70922 L p F P
0 g
s
0 .126 .659 r
.62902 .70459 m .62907 .70039 L .62548 .6957 L p F P
0 g
s
.922 .845 .751 r
.60085 .58651 m .60062 .58614 L .60092 .5864 L closepath p F P
0 g
s
.963 .839 .672 r
.60062 .58614 m .60085 .58651 L .59794 .59298 L p F P
0 g
s
.147 .3 .763 r
.81061 .70168 m .807 .69862 L .80567 .69547 L p F P
0 g
s
.704 .787 .916 r
.62503 .57019 m .61288 .57553 L .60984 .57223 L p F P
0 g
s
0 .047 .575 r
.82714 .74241 m .82611 .74665 L .82861 .75186 L p F P
0 g
s
.001 .105 .619 r
.82611 .74665 m .82714 .74241 L .82414 .73736 L p F P
0 g
s
.47 .565 .87 r
.71467 .82852 m .70907 .82777 L .70608 .8223 L p F P
0 g
s
.406 .594 .921 r
.71138 .60325 m .71396 .60363 L .71104 .59927 L p F P
0 g
s
.406 .594 .921 r
.71104 .59927 m .71046 .59918 L .71138 .60325 L p F P
0 g
s
.304 .479 .867 r
.77305 .64844 m .76551 .64536 L p .77376 .65286 L F P
0 g
s
.285 .471 .866 r
.76551 .64536 m .77305 .64844 L .77015 .64322 L p F P
0 g
s
.285 .471 .866 r
.77015 .64322 m .76524 .64122 L .76551 .64536 L p F P
0 g
s
.255 .436 .848 r
.78133 .66057 m .77887 .65937 L .77596 .65386 L p F P
0 g
s
.338 .529 .895 r
.73627 .61998 m .74606 .62273 L .74661 .62684 L p F P
0 g
s
.341 .534 .898 r
.73548 .61592 m .73627 .61998 L .74606 .62273 L p F P
0 g
s
.348 .545 .904 r
.73256 .61518 m .73548 .61592 L .73627 .61998 L p F P
0 g
s
.536 .675 .927 r
.74603 .84754 m .74523 .84758 L .74555 .84687 L closepath p F P
0 g
s
.547 .655 .906 r
.74316 .84349 m .74555 .84687 L .74523 .84758 L p F P
0 g
s
.854 .863 .846 r
.60671 .57465 m .59881 .58268 L .60062 .58614 L p F P
0 g
s
.918 .864 .77 r
.59788 .58405 m .59881 .58268 L .60062 .58614 L closepath p F P
0 g
s
.963 .839 .672 r
.59788 .58405 m .60062 .58614 L p .59794 .59298 L F P
0 g
s
.538 .708 .949 r
.64331 .57451 m .65412 .57325 L .65571 .5772 L p F P
0 g
s
.543 .712 .95 r
.65412 .57325 m .64331 .57451 L .64031 .57084 L p F P
0 g
s
.496 .592 .88 r
.7247 .83444 m .72671 .83772 L .72604 .8391 L p F P
0 g
s
.482 .606 .899 r
.72764 .83923 m .72604 .8391 L .72671 .83772 L closepath p F P
0 g
s
0 .078 .631 r
.62536 .69154 m .62548 .6957 L .62907 .70039 L p F P
0 g
s
0 .08 .629 r
.62548 .6957 m .62536 .69154 L .62204 .68678 L p F P
0 g
s
.76 .475 0 r
.60437 .63661 m .6031 .63265 L .6019 .62738 L p F P
0 g
s
.996 .773 .426 r
.59639 .59905 m .5984 .60285 L .5978 .60864 L p F P
0 g
s
.995 .825 .562 r
.5984 .60285 m .59639 .59905 L .59794 .59298 L p F P
0 g
s
.269 .374 .787 r
.65861 .76127 m .65603 .75963 L .65348 .75358 L p F P
0 g
s
.725 .967 .937 r
.80197 .83791 m .79164 .84489 L .78901 .84323 L p F P
0 g
s
.564 .73 .952 r
.74603 .84754 m .75859 .8458 L .7614 .84919 L p F P
0 g
s
.561 .687 .924 r
.75576 .84222 m .75859 .8458 L .74603 .84754 L p F P
0 g
s
.561 .687 .924 r
.74839 .84295 m .75576 .84222 L p .74603 .84754 L F P
0 g
s
.561 .687 .924 r
.74603 .84754 m .74555 .84687 L .74839 .84295 L p F P
0 g
s
.147 .3 .763 r
.80567 .69547 m .80589 .69313 L p .81061 .70168 L F P
0 g
s
.173 .331 .783 r
.80567 .69547 m .80401 .69172 L .80589 .69313 L closepath p F P
0 g
s
.859 .974 .663 r
.81703 .82193 m .81886 .81763 L p .8133 .82514 L F P
0 g
s
.859 .974 .663 r
.8133 .82514 m .81565 .82396 L .81703 .82193 L p F P
0 g
s
.749 .883 .473 r
.81703 .82193 m .81886 .81763 L .82288 .81057 L p F P
0 g
s
0 0 .389 r
.83001 .77345 m .82967 .77124 L .82973 .77108 L closepath p F P
0 g
s
.544 .705 .945 r
.65571 .5772 m .65865 .5769 L .65567 .57308 L p F P
0 g
s
.544 .705 .945 r
.65567 .57308 m .65412 .57325 L .65571 .5772 L p F P
0 g
s
0 .028 .596 r
.62172 .68266 m .62204 .68678 L .62536 .69154 L p F P
0 g
s
0 .026 .592 r
.62204 .68678 m .62172 .68266 L .61866 .67784 L p F P
0 g
s
0 0 0 r
.82466 .80631 m .82547 .8039 L .82509 .80488 L closepath p F P
0 g
s
0 .106 .622 r
.82507 .73311 m .82414 .73736 L .82714 .74241 L p F P
0 g
s
.039 .155 .658 r
.82414 .73736 m .82507 .73311 L .82159 .72821 L p F P
0 g
s
.414 .615 .933 r
.6963 .5935 m .69546 .59341 L .69253 .58929 L p F P
0 g
s
0 0 .367 r
.82973 .77108 m .83089 .767 L p .83053 .77694 L F P
0 g
s
0 0 .367 r
.83053 .77694 m .83001 .77345 L .82973 .77108 L p F P
0 g
s
0 0 .448 r
.82973 .77108 m .83089 .767 L .82946 .76147 L p F P
0 g
s
.417 .531 .865 r
.70608 .8223 m .70357 .8217 L .70456 .81949 L closepath p F P
0 g
s
.437 .522 .847 r
.70306 .81669 m .70456 .81949 L .70357 .8217 L p F P
0 g
s
.778 .972 .685 r
.81096 .82953 m .8133 .82514 L .81565 .82396 L closepath p F P
0 g
s
.273 .45 .854 r
.77596 .65386 m .77376 .65286 L .77371 .64963 L closepath p F P
0 g
s
.304 .479 .867 r
.77376 .65286 m .77371 .64963 L .77305 .64844 L p F P
0 g
s
.506 .619 .897 r
.73736 .83492 m .74027 .83928 L .72764 .83923 L p F P
0 g
s
.506 .619 .897 r
.72869 .83458 m .73736 .83492 L p .72764 .83923 L F P
0 g
s
.506 .619 .897 r
.72764 .83923 m .72671 .83772 L .72869 .83458 L p F P
0 g
s
.506 .649 .922 r
.72764 .83923 m .74027 .83928 L .74316 .84349 L p F P
0 g
s
.56 .685 .923 r
.74555 .84687 m .74316 .84349 L .74839 .84295 L closepath p F P
0 g
s
.449 .646 .942 r
.67854 .58457 m .67703 .5845 L .67407 .58055 L p F P
0 g
s
.818 .513 0 r
.6004 .62347 m .6019 .62738 L .6031 .63265 L p F P
0 g
s
.878 .597 .077 r
.6019 .62738 m .6004 .62347 L .59968 .61807 L p F P
0 g
s
.39 .483 .835 r
.68863 .80222 m .68427 .80075 L .68125 .79447 L p F P
0 g
s
.409 .604 .927 r
.6963 .5935 m .70812 .59501 L p .71046 .59918 L F P
0 g
s
.408 .61 .931 r
.6963 .5935 m .70812 .59501 L .7052 .59082 L p F P
0 g
s
.408 .61 .931 r
.7052 .59082 m .6949 .58955 L .6963 .5935 L p F P
0 g
s
.414 .615 .933 r
.69253 .58929 m .6949 .58955 L .6963 .5935 L p F P
0 g
s
0 0 .552 r
.61816 .67375 m .61866 .67784 L .62172 .68266 L p F P
0 g
s
0 0 .544 r
.61866 .67784 m .61816 .67375 L .61536 .66887 L p F P
0 g
s
.376 .573 .916 r
.71396 .60363 m .723 .60538 L .72392 .60943 L p F P
0 g
s
.374 .575 .918 r
.723 .60538 m .71396 .60363 L .71104 .59927 L p F P
0 g
s
.17 .331 .784 r
.80589 .69313 m .80401 .69172 L .80104 .68503 L p F P
0 g
s
.269 .374 .787 r
.65348 .75358 m .65372 .75277 L p .65861 .76127 L F P
0 g
s
.243 .354 .778 r
.65348 .75358 m .6529 .7522 L .65372 .75277 L closepath p F P
0 g
s
.85 .988 .853 r
.81096 .82953 m .8133 .82514 L p .80291 .83633 L F P
0 g
s
.85 .988 .853 r
.80291 .83633 m .8038 .83651 L .81096 .82953 L p F P
0 g
s
.037 .157 .661 r
.82241 .72398 m .82159 .72821 L .82507 .73311 L p F P
0 g
s
.072 .198 .691 r
.82159 .72821 m .82241 .72398 L .81848 .71922 L p F P
0 g
s
.725 .967 .937 r
.80291 .83633 m .80197 .83791 L p .78901 .84323 L F P
0 g
s
.778 .988 .895 r
.80197 .83791 m .80291 .83633 L .8038 .83651 L closepath p F P
0 g
s
.328 .519 .891 r
.74661 .62684 m .75127 .62827 L .74837 .62343 L p F P
0 g
s
.328 .519 .891 r
.74837 .62343 m .74606 .62273 L .74661 .62684 L p F P
0 g
s
.239 .412 .833 r
.78133 .66057 m .7883 .66431 L .78825 .66848 L p F P
0 g
s
.239 .418 .838 r
.78121 .65643 m .78133 .66057 L .7883 .66431 L p F P
0 g
s
.255 .436 .848 r
.77596 .65386 m .78121 .65643 L .78133 .66057 L p F P
0 g
s
0 0 .144 r
.83074 .78283 m .82907 .78716 L .82849 .79327 L p F P
0 g
s
0 0 .288 r
.83071 .78184 m .83046 .77718 L p .82907 .78716 L F P
0 g
s
0 0 .288 r
.82907 .78716 m .83074 .78283 L .83071 .78184 L p F P
0 g
s
.616 .805 .973 r
.7614 .84919 m .77389 .84588 L .77663 .84854 L p F P
0 g
s
.6 .781 .967 r
.77389 .84588 m .7614 .84919 L .75859 .8458 L p F P
0 g
s
.307 .503 .885 r
.75635 .6339 m .75417 .63315 L .75127 .62827 L p F P
0 g
s
.446 .643 .941 r
.67854 .58457 m .68959 .58522 L .68664 .58119 L p F P
0 g
s
.446 .643 .941 r
.68664 .58119 m .67687 .58067 L .67854 .58457 L p F P
0 g
s
.449 .646 .942 r
.67407 .58055 m .67687 .58067 L .67854 .58457 L p F P
0 g
s
.242 .354 .779 r
.65372 .75277 m .6529 .7522 L .64976 .74469 L p F P
0 g
s
.991 .813 .565 r
.59566 .58925 m .59794 .59298 L .59639 .59905 L p F P
0 g
s
.963 .839 .672 r
.59794 .59298 m .59566 .58925 L .59788 .58405 L p F P
0 g
s
.504 .616 .896 r
.72671 .83772 m .7247 .83444 L .72869 .83458 L closepath p F P
0 g
s
.661 .867 .977 r
.78719 .84405 m .77663 .84854 L .77389 .84588 L p F P
0 g
s
0 0 .369 r
.83046 .77718 m .83001 .77345 L .83053 .77694 L closepath p F P
0 g
s
0 0 .497 r
.61466 .66482 m .61536 .66887 L .61816 .67375 L p F P
0 g
s
0 0 .483 r
.61536 .66887 m .61466 .66482 L .61214 .65987 L p F P
0 g
s
.725 .77 .273 r
.82547 .8039 m .82704 .79963 L p .82377 .80863 L F P
0 g
s
.725 .77 .273 r
.82377 .80863 m .82466 .80631 L .82547 .8039 L p F P
0 g
s
0 0 0 r
.82547 .8039 m .82704 .79963 L .82849 .79327 L p F P
0 g
s
.491 .671 .944 r
.65865 .5769 m .67111 .57664 L .67407 .58055 L p F P
0 g
s
.492 .675 .946 r
.67111 .57664 m .65865 .5769 L .65567 .57308 L p F P
0 g
s
.912 .617 .127 r
.59794 .61421 m .59968 .61807 L .6004 .62347 L p F P
0 g
s
.96 .701 .258 r
.59968 .61807 m .59794 .61421 L .5978 .60864 L p F P
0 g
s
0 0 .518 r
.82946 .76147 m .8306 .75722 L .82861 .75186 L p F P
0 g
s
0 0 .447 r
.8306 .75722 m .82946 .76147 L .83089 .767 L p F P
0 g
s
.069 .2 .694 r
.81917 .71499 m .81848 .71922 L .82241 .72398 L p F P
0 g
s
.099 .236 .718 r
.81848 .71922 m .81917 .71499 L .81481 .71037 L p F P
0 g
s
.47 .565 .87 r
.70608 .8223 m .71673 .82411 L .71467 .82852 L p F P
0 g
s
.453 .552 .866 r
.71673 .82411 m .70608 .8223 L .70456 .81949 L p F P
0 g
s
.369 .566 .913 r
.72392 .60943 m .72965 .61065 L .72674 .60616 L p F P
0 g
s
.369 .566 .913 r
.72674 .60616 m .723 .60538 L .72392 .60943 L p F P
0 g
s
.232 .398 .823 r
.79469 .67653 m .79492 .67233 L .78825 .66848 L p F P
0 g
s
.233 .406 .829 r
.7883 .66431 m .78825 .66848 L .79492 .67233 L p F P
0 g
s
.269 .374 .787 r
.65372 .75277 m .65978 .7569 L .65861 .76127 L p F P
0 g
s
.294 .393 .793 r
.65861 .76127 m .66498 .76533 L .66376 .76969 L p F P
0 g
s
.217 .361 .795 r
.65978 .7569 m .65861 .76127 L .66498 .76533 L p F P
0 g
s
.317 .41 .799 r
.66376 .76969 m .67047 .77369 L .66922 .77803 L p F P
0 g
s
.248 .383 .804 r
.66498 .76533 m .66376 .76969 L .67047 .77369 L p F P
0 g
s
.186 .331 .778 r
.65481 .7484 m .65372 .75277 L .65978 .7569 L p F P
0 g
s
.242 .354 .779 r
.64976 .74469 m .65481 .7484 L .65372 .75277 L p F P
0 g
s
.248 .434 .849 r
.78121 .65643 m .77596 .65386 L .77371 .64963 L p F P
0 g
s
0 0 .429 r
.61124 .65586 m .61214 .65987 L .61466 .66482 L p F P
0 g
s
0 0 .404 r
.61214 .65987 m .61124 .65586 L .60901 .65084 L p F P
0 g
s
.299 .419 .816 r
.67503 .78123 m .66922 .77803 L p .67504 .78627 L F P
0 g
s
.27 .391 .802 r
.66922 .77803 m .67503 .78123 L .67193 .77456 L p F P
0 g
s
.27 .391 .802 r
.67193 .77456 m .67047 .77369 L .66922 .77803 L p F P
0 g
s
.345 .547 .906 r
.73548 .61592 m .73256 .61518 L .72965 .61065 L p F P
0 g
s
.142 .29 .756 r
.64976 .74469 m .64916 .74418 L .64925 .7435 L closepath p F P
0 g
s
.13 .278 .749 r
.64661 .73711 m .64488 .7355 L p .64916 .74418 L F P
0 g
s
.13 .278 .749 r
.64916 .74418 m .64925 .7435 L .64661 .73711 L p F P
0 g
s
.096 .238 .722 r
.81538 .70616 m .81481 .71037 L .81917 .71499 L p F P
0 g
s
.122 .269 .742 r
.81481 .71037 m .81538 .70616 L .81061 .70168 L p F P
0 g
s
0 0 0 r
.82288 .81057 m .82377 .80863 L .82466 .80631 L closepath p F P
0 g
s
.223 .382 .812 r
.79809 .67872 m .79469 .67653 L p .80063 .68473 L F P
0 g
s
.202 .369 .808 r
.79469 .67653 m .79809 .67872 L .79514 .67248 L p F P
0 g
s
.202 .369 .808 r
.79514 .67248 m .79492 .67233 L .79469 .67653 L p F P
0 g
s
.441 .557 .877 r
.71467 .82852 m .72174 .82951 L .71877 .82447 L p F P
0 g
s
.441 .557 .877 r
.71877 .82447 m .71673 .82411 L .71467 .82852 L p F P
0 g
s
.299 .419 .816 r
.67504 .78627 m .67597 .78325 L .67503 .78123 L p F P
0 g
s
.305 .426 .82 r
.67812 .78782 m .67504 .78627 L .67597 .78325 L closepath p F P
0 g
s
.611 .744 .94 r
.62503 .57019 m .6373 .56718 L .64031 .57084 L p F P
0 g
s
.615 .748 .94 r
.6373 .56718 m .62503 .57019 L .622 .56666 L p F P
0 g
s
.704 .787 .916 r
.60984 .57223 m .622 .56666 L .62503 .57019 L p F P
0 g
s
.1 .261 .742 r
.64661 .73711 m .64488 .7355 L .64508 .73345 L closepath p F P
0 g
s
.086 .246 .733 r
.64346 .72951 m .64076 .72678 L p .64488 .7355 L F P
0 g
s
.086 .246 .733 r
.64488 .7355 m .64508 .73345 L .64346 .72951 L p F P
0 g
s
.119 .271 .746 r
.81104 .69748 m .81061 .70168 L .81538 .70616 L p F P
0 g
s
.147 .3 .763 r
.80589 .69313 m .81104 .69748 L .81061 .70168 L p F P
0 g
s
.184 .343 .79 r
.80104 .68503 m .80063 .68473 L .80067 .68421 L closepath p F P
0 g
s
.223 .382 .812 r
.80063 .68473 m .80067 .68421 L .79809 .67872 L p F P
0 g
s
.139 .301 .767 r
.80617 .68895 m .80589 .69313 L .81104 .69748 L p F P
0 g
s
.17 .331 .784 r
.80104 .68503 m .80617 .68895 L .80589 .69313 L p F P
0 g
s
.39 .483 .835 r
.68125 .79447 m .68129 .7944 L p .68863 .80222 L F P
0 g
s
.372 .47 .831 r
.68125 .79447 m .6812 .79436 L .68129 .7944 L closepath p F P
0 g
s
.375 .469 .828 r
.68129 .7944 m .6812 .79436 L .67812 .78782 L p F P
0 g
s
.973 .704 .29 r
.59581 .60484 m .5978 .60864 L .59794 .61421 L p F P
0 g
s
.996 .773 .426 r
.5978 .60864 m .59581 .60484 L .59639 .59905 L p F P
0 g
s
0 0 .345 r
.6079 .64686 m .60901 .65084 L .61124 .65586 L p F P
0 g
s
0 0 .305 r
.60901 .65084 m .6079 .64686 L .60599 .64177 L p F P
0 g
s
.39 .483 .835 r
.68129 .7944 m .69037 .79782 L .68863 .80222 L p F P
0 g
s
.338 .467 .844 r
.68319 .78992 m .68129 .7944 L .69037 .79782 L p F P
0 g
s
.375 .469 .828 r
.67812 .78782 m .68319 .78992 L .68129 .7944 L p F P
0 g
s
.215 .339 .775 r
.65481 .7484 m .64976 .74469 L .64925 .7435 L p F P
0 g
s
.294 .483 .874 r
.75635 .6339 m .76488 .63709 L .76524 .64122 L p F P
0 g
s
.308 .5 .882 r
.75579 .62981 m .75635 .6339 L .76488 .63709 L p F P
0 g
s
.307 .503 .885 r
.75127 .62827 m .75579 .62981 L .75635 .6339 L p F P
0 g
s
.052 .228 .725 r
.64346 .72951 m .64076 .72678 L .64091 .72341 L closepath p F P
0 g
s
.035 .21 .714 r
.6403 .72191 m .63676 .71802 L p .64076 .72678 L F P
0 g
s
.035 .21 .714 r
.64076 .72678 m .64091 .72341 L .6403 .72191 L p F P
0 g
s
.857 .845 .831 r
.60419 .57095 m .60671 .57465 L .59881 .58268 L p F P
0 g
s
.798 .82 .868 r
.60679 .56889 m .60419 .57095 L .60671 .57465 L p F P
0 g
s
.798 .82 .868 r
.60671 .57465 m .60984 .57223 L .60679 .56889 L p F P
0 g
s
.156 .325 .783 r
.80617 .68895 m .80104 .68503 L .80067 .68421 L p F P
0 g
s
.215 .339 .775 r
.64925 .7435 m .65005 .73984 L p .65481 .7484 L F P
0 g
s
.188 .316 .764 r
.64925 .7435 m .64661 .73711 L .65005 .73984 L closepath p F P
0 g
s
.453 .552 .866 r
.70456 .81949 m .70579 .81723 L p .71673 .82411 L F P
0 g
s
.439 .542 .864 r
.70456 .81949 m .70306 .81669 L .70579 .81723 L closepath p F P
0 g
s
.804 .977 .901 r
.80126 .83579 m .80407 .83358 L .80291 .83633 L closepath p F P
0 g
s
.725 .967 .937 r
.78901 .84323 m .80126 .83579 L .80291 .83633 L p F P
0 g
s
.85 .988 .853 r
.81329 .82514 m .80407 .83358 L .80291 .83633 L p F P
0 g
s
.85 .988 .853 r
.8133 .82514 m .81329 .82514 L p .80291 .83633 L F P
0 g
s
0 0 .519 r
.82967 .74761 m .82861 .75186 L .8306 .75722 L p F P
0 g
s
0 .047 .575 r
.82861 .75186 m .82967 .74761 L .82714 .74241 L p F P
0 g
s
0 0 .259 r
.83071 .78184 m .83053 .77694 L .83046 .77718 L closepath p F P
0 g
s
.709 .789 .914 r
.622 .56666 m .60984 .57223 L .60679 .56889 L p F P
0 g
s
0 .176 .695 r
.63676 .71802 m .6403 .72191 L .63714 .71429 L p F P
0 g
s
0 .176 .695 r
.63714 .71429 m .63677 .71387 L .63676 .71802 L p F P
0 g
s
0 .16 .684 r
.63676 .71802 m .63677 .71387 L .63287 .70922 L p F P
0 g
s
.182 .355 .802 r
.80067 .68421 m .79809 .67872 L .8008 .68057 L closepath p F P
0 g
s
.156 .325 .783 r
.80067 .68421 m .8008 .68057 L p .80617 .68895 L F P
0 g
s
.563 .677 .916 r
.74839 .84295 m .74316 .84349 L .74027 .83928 L p F P
0 g
s
.543 .712 .95 r
.64031 .57084 m .65243 .56932 L .65412 .57325 L p F P
0 g
s
.546 .716 .951 r
.65243 .56932 m .64031 .57084 L .6373 .56718 L p F P
0 g
s
.507 .611 .891 r
.72869 .83458 m .7247 .83444 L .72174 .82951 L p F P
0 g
s
.918 .85 .76 r
.59881 .58268 m .59788 .58405 L .59483 .58154 L p F P
0 g
s
.918 .85 .76 r
.59483 .58154 m .59654 .57892 L .59881 .58268 L p F P
0 g
s
.857 .845 .831 r
.59881 .58268 m .59654 .57892 L .60419 .57095 L p F P
0 g
s
.705 .402 0 r
.60599 .64177 m .60466 .63784 L p .60458 .63731 L F P
0 g
s
0 0 .241 r
.6065 .64295 m .60466 .63784 L p .60618 .64207 L F P
0 g
s
0 0 .241 r
.6079 .64686 m .6065 .64295 L p .60618 .64207 L F P
0 g
s
0 0 .285 r
.60857 .64802 m .6065 .64295 L p .60803 .64682 L F P
0 g
s
0 0 .285 r
.61004 .65191 m .60857 .64802 L p .60803 .64682 L F P
0 g
s
.666 .309 0 r
.60857 .64802 m .61083 .65305 L p .60912 .64923 L F P
0 g
s
.694 .346 0 r
.60857 .64802 m .60686 .64419 L .60486 .6391 L p F P
0 g
s
.666 .309 0 r
.60686 .64419 m .60857 .64802 L p .60912 .64923 L F P
0 g
s
.694 .346 0 r
.6065 .64295 m .60857 .64802 L p .60683 .64384 L F P
0 g
s
.694 .346 0 r
.60486 .6391 m .6065 .64295 L p .60683 .64384 L F P
0 g
s
.726 .389 0 r
.60466 .63784 m .6065 .64295 L p .60475 .63836 L F P
0 g
s
.726 .389 0 r
.60307 .63396 m .60466 .63784 L p .60475 .63836 L F P
0 g
s
.705 .402 0 r
.60466 .63784 m .6031 .63265 L p .60458 .63731 L F P
0 g
s
0 0 .212 r
.83053 .77694 m .83174 .77271 L p .83076 .78278 L F P
0 g
s
0 0 .212 r
.83076 .78278 m .83071 .78184 L .83053 .77694 L p F P
0 g
s
0 0 .367 r
.83089 .767 m .83174 .77271 L .83053 .77694 L p F P
0 g
s
.406 .496 .839 r
.68863 .80222 m .697 .80515 L p .6966 .80989 L F P
0 g
s
.358 .468 .836 r
.68863 .80222 m .697 .80515 L .69396 .79921 L p F P
0 g
s
.358 .468 .836 r
.69396 .79921 m .69037 .79782 L .68863 .80222 L p F P
0 g
s
0 .145 .678 r
.63273 .70509 m .63287 .70922 L .63677 .71387 L p F P
0 g
s
0 .121 .66 r
.63287 .70922 m .63273 .70509 L .62907 .70039 L p F P
0 g
s
.759 .904 .515 r
.82377 .80863 m .82288 .81057 L .81886 .81763 L p F P
0 g
s
.955 .823 .674 r
.59566 .58925 m .59788 .58405 L .59483 .58154 L p F P
0 g
s
.413 .618 .935 r
.6949 .58955 m .69253 .58929 L .68959 .58522 L p F P
0 g
s
.404 .596 .923 r
.71104 .59927 m .71046 .59918 L .71012 .59791 L closepath p F P
0 g
s
.409 .604 .927 r
.70812 .59501 m .71012 .59791 L .71046 .59918 L p F P
0 g
s
.996 .765 .441 r
.59416 .59531 m .59639 .59905 L .59581 .60484 L p F P
0 g
s
.991 .813 .565 r
.59639 .59905 m .59416 .59531 L .59566 .58925 L p F P
0 g
s
.341 .534 .898 r
.74606 .62273 m .74541 .61863 L .73548 .61592 L p F P
0 g
s
.35 .547 .905 r
.73458 .61188 m .73548 .61592 L .74541 .61863 L p F P
0 g
s
.345 .547 .906 r
.72965 .61065 m .73458 .61188 L .73548 .61592 L p F P
0 g
s
0 .097 .647 r
.62877 .69629 m .62907 .70039 L .63273 .70509 L p F P
0 g
s
0 .078 .631 r
.62907 .70039 m .62877 .69629 L .62536 .69154 L p F P
0 g
s
.661 .867 .977 r
.78819 .84263 m .78719 .84405 L p .77389 .84588 L F P
0 g
s
.697 .886 .967 r
.78719 .84405 m .78819 .84263 L .78901 .84323 L closepath p F P
0 g
s
.28 .471 .868 r
.76524 .64122 m .77015 .64322 L .76725 .63806 L p F P
0 g
s
.28 .471 .868 r
.76725 .63806 m .76488 .63709 L .76524 .64122 L p F P
0 g
s
.45 .649 .944 r
.67687 .58067 m .67407 .58055 L .67111 .57664 L p F P
0 g
s
.268 .456 .86 r
.77371 .64963 m .77305 .64844 L .77365 .6487 L closepath p F P
0 g
s
.248 .434 .849 r
.77371 .64963 m .77365 .6487 L p .78121 .65643 L F P
0 g
s
0 0 0 r
.83013 .78896 m .82849 .79327 L .82704 .79963 L p F P
0 g
s
0 0 .144 r
.82849 .79327 m .83013 .78896 L .83074 .78283 L p F P
0 g
s
.374 .575 .918 r
.71104 .59927 m .72198 .60134 L .723 .60538 L p F P
0 g
s
.372 .578 .921 r
.72198 .60134 m .71104 .59927 L .71012 .59791 L p F P
0 g
s
.767 .444 0 r
.60156 .62876 m .6031 .63265 L .60466 .63784 L p F P
0 g
s
.818 .513 0 r
.6031 .63265 m .60156 .62876 L .6004 .62347 L p F P
0 g
s
.182 .315 .765 r
.65005 .73984 m .64661 .73711 L .64508 .73345 L p F P
0 g
s
.442 .54 .861 r
.70579 .81723 m .70306 .81669 L .70004 .81096 L p F P
0 g
s
.302 .503 .887 r
.75579 .62981 m .75127 .62827 L .74837 .62343 L p F P
0 g
s
0 .048 .578 r
.82811 .73816 m .82714 .74241 L .82967 .74761 L p F P
0 g
s
0 .106 .622 r
.82714 .74241 m .82811 .73816 L .82507 .73311 L p F P
0 g
s
.548 .708 .946 r
.65412 .57325 m .65567 .57308 L .65268 .56929 L p F P
0 g
s
.548 .708 .946 r
.65268 .56929 m .65243 .56932 L .65412 .57325 L p F P
0 g
s
.764 .901 .937 r
.78819 .84263 m .78901 .84323 L .80126 .83579 L p F P
0 g
s
.382 .503 .856 r
.70004 .81096 m .6966 .80989 L .69779 .80667 L closepath p F P
0 g
s
.406 .496 .839 r
.697 .80515 m .69779 .80667 L .6966 .80989 L p F P
0 g
s
0 .041 .608 r
.62489 .68746 m .62536 .69154 L .62877 .69629 L p F P
0 g
s
0 .028 .596 r
.62536 .69154 m .62489 .68746 L .62172 .68266 L p F P
0 g
s
.354 .456 .826 r
.68319 .78992 m .67812 .78782 L .67597 .78325 L p F P
0 g
s
.263 .457 .863 r
.77365 .6487 m .77305 .64844 L .77015 .64322 L p F P
0 g
s
.152 .291 .753 r
.64508 .73345 m .64346 .72951 L .64546 .73123 L closepath p F P
0 g
s
.182 .315 .765 r
.64508 .73345 m .64546 .73123 L p .65005 .73984 L F P
0 g
s
.6 .781 .967 r
.75859 .8458 m .77113 .84298 L .77389 .84588 L p F P
0 g
s
.584 .759 .962 r
.77113 .84298 m .75859 .8458 L .75576 .84222 L p F P
0 g
s
0 0 .557 r
.62108 .67861 m .62172 .68266 L .62489 .68746 L p F P
0 g
s
0 0 .552 r
.62172 .68266 m .62108 .67861 L .61816 .67375 L p F P
0 g
s
.861 .541 .02 r
.59864 .61963 m .6004 .62347 L .60156 .62876 L p F P
0 g
s
.912 .617 .127 r
.6004 .62347 m .59864 .61963 L .59794 .61421 L p F P
0 g
s
.408 .613 .934 r
.6949 .58955 m .7052 .59082 L .70226 .58668 L p F P
0 g
s
.408 .613 .934 r
.70226 .58668 m .69338 .58562 L .6949 .58955 L p F P
0 g
s
.413 .618 .935 r
.68959 .58522 m .69338 .58562 L .6949 .58955 L p F P
0 g
s
.179 .355 .802 r
.8008 .68057 m .79809 .67872 L .79514 .67248 L p F P
0 g
s
.492 .675 .946 r
.65567 .57308 m .66814 .57277 L .67111 .57664 L p F P
0 g
s
.492 .678 .948 r
.66814 .57277 m .65567 .57308 L .65268 .56929 L p F P
0 g
s
.248 .434 .849 r
.77365 .6487 m .78099 .6523 L .78121 .65643 L p F P
0 g
s
.244 .437 .852 r
.77326 .6446 m .77365 .6487 L .78099 .6523 L p F P
0 g
s
.263 .457 .863 r
.77015 .64322 m .77326 .6446 L .77365 .6487 L p F P
0 g
s
.372 .578 .921 r
.71012 .59791 m .70923 .59519 L p .72198 .60134 L F P
0 g
s
.383 .589 .925 r
.71012 .59791 m .70812 .59501 L .70923 .59519 L closepath p F P
0 g
s
0 0 .355 r
.83206 .76275 m .83089 .767 L .83174 .77271 L p F P
0 g
s
0 0 .447 r
.83089 .767 m .83206 .76275 L .8306 .75722 L p F P
0 g
s
0 .109 .626 r
.82594 .72887 m .82507 .73311 L .82811 .73816 L p F P
0 g
s
.037 .157 .661 r
.82507 .73311 m .82594 .72887 L .82241 .72398 L p F P
0 g
s
.481 .604 .897 r
.72869 .83458 m .73736 .83492 L .73444 .83043 L p F P
0 g
s
.481 .604 .897 r
.73444 .83043 m .73086 .83016 L .72869 .83458 L p F P
0 g
s
.507 .611 .891 r
.72174 .82951 m .73086 .83016 L .72869 .83458 L p F P
0 g
s
.341 .548 .909 r
.73458 .61188 m .72965 .61065 L .72674 .60616 L p F P
0 g
s
.859 .974 .663 r
.81886 .81763 m .81331 .82511 L .8133 .82514 L p F P
0 g
s
.841 .985 .707 r
.82078 .8133 m .81886 .81763 L .81331 .82511 L p F P
0 g
s
.759 .904 .515 r
.82256 .8104 m .82377 .80863 L p .81886 .81763 L F P
0 g
s
.759 .904 .515 r
.81886 .81763 m .82078 .8133 L .82256 .8104 L p F P
0 g
s
.537 .676 .928 r
.74839 .84295 m .75576 .84222 L .75291 .83846 L p F P
0 g
s
.537 .676 .928 r
.75291 .83846 m .75039 .83862 L .74839 .84295 L p F P
0 g
s
.563 .677 .916 r
.74027 .83928 m .75039 .83862 L .74839 .84295 L p F P
0 g
s
.661 .867 .977 r
.77389 .84588 m .78634 .84119 L .78819 .84263 L p F P
0 g
s
.643 .841 .976 r
.78634 .84119 m .77389 .84588 L .77113 .84298 L p F P
0 g
s
.987 .8 .568 r
.59318 .58555 m .59566 .58925 L .59416 .59531 L p F P
0 g
s
.955 .823 .674 r
.59483 .58154 m .59318 .58555 L .59566 .58925 L p F P
0 g
s
0 0 .507 r
.61733 .66973 m .61816 .67375 L .62108 .67861 L p F P
0 g
s
0 0 .497 r
.61816 .67375 m .61733 .66973 L .61466 .66482 L p F P
0 g
s
.447 .646 .943 r
.67687 .58067 m .68664 .58119 L .68369 .57721 L p F P
0 g
s
.447 .646 .943 r
.68369 .57721 m .67509 .57679 L .67687 .58067 L p F P
0 g
s
.45 .649 .944 r
.67111 .57664 m .67509 .57679 L .67687 .58067 L p F P
0 g
s
.145 .29 .754 r
.64546 .73123 m .64346 .72951 L .64091 .72341 L p F P
0 g
s
.325 .521 .893 r
.74606 .62273 m .74837 .62343 L .74547 .61865 L p F P
0 g
s
.325 .521 .893 r
.74547 .61865 m .74541 .61863 L .74606 .62273 L p F P
0 g
s
.724 .885 .955 r
.78634 .84119 m .78923 .83973 L .78819 .84263 L closepath p F P
0 g
s
.764 .901 .937 r
.79868 .83457 m .78923 .83973 L .78819 .84263 L p F P
0 g
s
.764 .901 .937 r
.80126 .83579 m .79868 .83457 L p .78819 .84263 L F P
0 g
s
.453 .552 .866 r
.70579 .81723 m .71579 .8193 L p .71673 .82411 L F P
0 g
s
.415 .527 .862 r
.70579 .81723 m .71579 .8193 L .71279 .81401 L p F P
0 g
s
.415 .527 .862 r
.71279 .81401 m .7078 .81279 L .70579 .81723 L p F P
0 g
s
.442 .54 .861 r
.70004 .81096 m .7078 .81279 L .70579 .81723 L p F P
0 g
s
.935 .63 .169 r
.59595 .61041 m .59794 .61421 L .59864 .61963 L p F P
0 g
s
.973 .704 .29 r
.59794 .61421 m .59595 .61041 L .59581 .60484 L p F P
0 g
s
.239 .418 .838 r
.7883 .66431 m .78827 .66014 L .78121 .65643 L p F P
0 g
s
.244 .429 .846 r
.78099 .6523 m .78121 .65643 L .78827 .66014 L p F P
0 g
s
.765 .866 .434 r
.82256 .8104 m .82462 .80627 L .82377 .80863 L closepath p F P
0 g
s
.725 .77 .273 r
.82704 .79963 m .82462 .80627 L .82377 .80863 L p F P
0 g
s
0 0 .277 r
.83074 .78283 m .83076 .78278 L .83071 .78184 L closepath p F P
0 g
s
.334 .441 .821 r
.67597 .78325 m .67503 .78123 L .67649 .7819 L closepath p F P
0 g
s
.354 .456 .826 r
.67597 .78325 m .67649 .7819 L p .68319 .78992 L F P
0 g
s
0 0 .446 r
.61365 .66083 m .61466 .66482 L .61733 .66973 L p F P
0 g
s
0 0 .429 r
.61466 .66482 m .61365 .66083 L .61124 .65586 L p F P
0 g
s
.03 .157 .664 r
.82316 .71974 m .82241 .72398 L .82594 .72887 L p F P
0 g
s
.069 .2 .694 r
.82241 .72398 m .82316 .71974 L .81917 .71499 L p F P
0 g
s
.49 .598 .888 r
.73086 .83016 m .72174 .82951 L .71877 .82447 L p F P
0 g
s
.368 .568 .915 r
.723 .60538 m .72674 .60616 L .72383 .60172 L p F P
0 g
s
.368 .568 .915 r
.72383 .60172 m .72198 .60134 L .723 .60538 L p F P
0 g
s
.615 .748 .94 r
.622 .56666 m .63429 .56354 L .6373 .56718 L p F P
0 g
s
.619 .751 .94 r
.63429 .56354 m .622 .56666 L .61897 .56313 L p F P
0 g
s
.709 .789 .914 r
.60679 .56889 m .61897 .56313 L .622 .56666 L p F P
0 g
s
.79 .965 .918 r
.80407 .83358 m .80126 .83579 L .79868 .83457 L p F P
0 g
s
.546 .662 .912 r
.75039 .83862 m .74027 .83928 L .73736 .83492 L p F P
0 g
s
.836 .996 .76 r
.81329 .82514 m .81331 .82511 L .8133 .82514 L closepath p F P
0 g
s
0 0 .133 r
.83076 .78278 m .83074 .78283 L .83013 .78896 L p F P
0 g
s
.79 .965 .918 r
.79868 .83457 m .80595 .82928 L .80407 .83358 L p F P
0 g
s
.794 .999 .831 r
.81083 .8252 m .80595 .82928 L .80407 .83358 L p F P
0 g
s
.794 .999 .831 r
.80407 .83358 m .81329 .82514 L .81083 .8252 L p F P
0 g
s
.844 .999 .807 r
.81331 .82511 m .81329 .82514 L .81083 .8252 L p F P
0 g
s
.844 .999 .807 r
.81083 .8252 m .8149 .82088 L .81331 .82511 L p F P
0 g
s
.841 .985 .707 r
.81331 .82511 m .8149 .82088 L .82078 .8133 L p F P
0 g
s
0 0 .094 r
.83194 .77861 m .83076 .78278 L .83056 .7878 L p F P
0 g
s
0 0 .133 r
.83013 .78896 m .83056 .7878 L .83076 .78278 L p F P
0 g
s
0 0 .212 r
.83174 .77271 m .83194 .77861 L .83076 .78278 L p F P
0 g
s
.335 .441 .821 r
.67649 .7819 m .67503 .78123 L .67193 .77456 L p F P
0 g
s
0 0 .373 r
.61004 .65191 m .61124 .65586 L .61365 .66083 L p F P
0 g
s
0 0 .345 r
.61124 .65586 m .61004 .65191 L .6079 .64686 L p F P
0 g
s
.233 .406 .829 r
.79221 .66658 m .7883 .66431 L p .79492 .67233 L F P
0 g
s
.213 .394 .826 r
.7883 .66431 m .79221 .66658 L .78928 .66074 L p F P
0 g
s
.213 .394 .826 r
.78928 .66074 m .78827 .66014 L .7883 .66431 L p F P
0 g
s
.424 .527 .858 r
.7078 .81279 m .70004 .81096 L .69779 .80667 L p F P
0 g
s
.692 .767 .277 r
.82863 .79535 m .82704 .79963 L .82462 .80627 L p F P
0 g
s
0 0 0 r
.82704 .79963 m .82863 .79535 L .83013 .78896 L p F P
0 g
s
.063 .202 .697 r
.8198 .71077 m .81917 .71499 L .82316 .71974 L p F P
0 g
s
.096 .238 .722 r
.81917 .71499 m .8198 .71077 L .81538 .70616 L p F P
0 g
s
.145 .29 .754 r
.64091 .72341 m .64102 .72258 L p .64546 .73123 L F P
0 g
s
.113 .263 .74 r
.64091 .72341 m .6403 .72191 L .64102 .72258 L closepath p F P
0 g
s
0 0 .448 r
.83171 .75297 m .8306 .75722 L .83206 .76275 L p F P
0 g
s
0 0 .519 r
.8306 .75722 m .83171 .75297 L .82967 .74761 L p F P
0 g
s
.98 .703 .317 r
.59359 .60109 m .59581 .60484 L .59595 .61041 L p F P
0 g
s
.996 .765 .441 r
.59581 .60484 m .59359 .60109 L .59416 .59531 L p F P
0 g
s
.856 .835 .824 r
.6015 .5673 m .60419 .57095 L .59654 .57892 L p F P
0 g
s
.802 .818 .863 r
.60373 .56549 m .6015 .5673 L .60419 .57095 L p F P
0 g
s
.802 .818 .863 r
.60419 .57095 m .60679 .56889 L .60373 .56549 L p F P
0 g
s
.103 .261 .741 r
.64102 .72258 m .6403 .72191 L .63714 .71429 L p F P
0 g
s
.546 .716 .951 r
.6373 .56718 m .64969 .56555 L p .65243 .56932 L F P
0 g
s
.553 .717 .949 r
.64969 .56555 m .6373 .56718 L .63429 .56354 L p F P
0 g
s
.713 .79 .912 r
.61897 .56313 m .60679 .56889 L .60373 .56549 L p F P
0 g
s
.195 .368 .81 r
.79514 .67248 m .79492 .67233 L .79493 .67203 L closepath p F P
0 g
s
.233 .406 .829 r
.79492 .67233 m .79493 .67203 L .79221 .66658 L p F P
0 g
s
.094 .243 .727 r
.81587 .70196 m .81538 .70616 L .8198 .71077 L p F P
0 g
s
.119 .271 .746 r
.81538 .70616 m .81587 .70196 L .81104 .69748 L p F P
0 g
s
.186 .331 .778 r
.65978 .7569 m .66049 .75265 L .65481 .7484 L p F P
0 g
s
.217 .361 .795 r
.66571 .76106 m .65978 .7569 L p .66498 .76533 L F P
0 g
s
.188 .333 .779 r
.65978 .7569 m .66571 .76106 L .66259 .75421 L p F P
0 g
s
.188 .333 .779 r
.66259 .75421 m .66049 .75265 L .65978 .7569 L p F P
0 g
s
0 0 .285 r
.6065 .64295 m .6079 .64686 L .61004 .65191 L p F P
0 g
s
.226 .37 .8 r
.66882 .76781 m .66498 .76533 L .66574 .76113 L closepath p F P
0 g
s
.217 .361 .795 r
.66498 .76533 m .66574 .76113 L .66571 .76106 L p F P
0 g
s
.248 .383 .804 r
.66882 .76781 m .66498 .76533 L p .67047 .77369 L F P
0 g
s
.154 .318 .778 r
.65545 .74414 m .65481 .7484 L .66049 .75265 L p F P
0 g
s
.215 .339 .775 r
.65005 .73984 m .65545 .74414 L .65481 .7484 L p F P
0 g
s
.413 .621 .938 r
.69338 .58562 m .68959 .58522 L .68664 .58119 L p F P
0 g
s
.179 .355 .802 r
.79514 .67248 m .80086 .67642 L .8008 .68057 L p F P
0 g
s
.167 .35 .802 r
.80086 .67642 m .79514 .67248 L .79493 .67203 L p F P
0 g
s
.302 .503 .887 r
.74837 .62343 m .75512 .62574 L .75579 .62981 L p F P
0 g
s
.297 .504 .889 r
.75512 .62574 m .74837 .62343 L .74547 .61865 L p F P
0 g
s
.107 .281 .759 r
.65059 .73559 m .65005 .73984 L .65545 .74414 L p F P
0 g
s
.182 .315 .765 r
.64546 .73123 m .65059 .73559 L .65005 .73984 L p F P
0 g
s
.308 .5 .882 r
.76435 .63295 m .75579 .62981 L p .76488 .63709 L F P
0 g
s
.288 .492 .882 r
.75579 .62981 m .76435 .63295 L .76145 .62805 L p F P
0 g
s
.288 .492 .882 r
.76145 .62805 m .75512 .62574 L .75579 .62981 L p F P
0 g
s
.255 .391 .808 r
.67193 .77456 m .67047 .77369 L .67082 .77215 L closepath p F P
0 g
s
.248 .383 .804 r
.67047 .77369 m .67082 .77215 L .66882 .76781 L p F P
0 g
s
.156 .325 .783 r
.8008 .68057 m .80638 .68478 L .80617 .68895 L p F P
0 g
s
.153 .33 .788 r
.80086 .67642 m .8008 .68057 L .80638 .68478 L p F P
0 g
s
.122 .28 .753 r
.81139 .69329 m .81104 .69748 L .81587 .70196 L p F P
0 g
s
.139 .301 .767 r
.81104 .69748 m .81139 .69329 L .80617 .68895 L p F P
0 g
s
.167 .35 .802 r
.79493 .67203 m .79484 .6682 L p .80086 .67642 L F P
0 g
s
.193 .379 .819 r
.79493 .67203 m .79221 .66658 L .79484 .6682 L closepath p F P
0 g
s
.916 .837 .752 r
.59654 .57892 m .59483 .58154 L .59176 .57877 L p F P
0 g
s
.916 .837 .752 r
.59176 .57877 m .59401 .57522 L .59654 .57892 L p F P
0 g
s
.856 .835 .824 r
.59654 .57892 m .59401 .57522 L .6015 .5673 L p F P
0 g
s
.137 .304 .77 r
.80638 .68478 m .80617 .68895 L .81139 .69329 L p F P
0 g
s
.256 .456 .864 r
.77326 .6446 m .77015 .64322 L .76725 .63806 L p F P
0 g
s
.079 .259 .747 r
.64589 .72699 m .64546 .73123 L .65059 .73559 L p F P
0 g
s
.145 .29 .754 r
.64102 .72258 m .64589 .72699 L .64546 .73123 L p F P
0 g
s
.38 .591 .927 r
.70923 .59519 m .70812 .59501 L .7052 .59082 L p F P
0 g
s
.354 .456 .826 r
.67649 .7819 m .68453 .78558 L .68319 .78992 L p F P
0 g
s
.293 .435 .833 r
.67792 .77751 m .67649 .7819 L .68453 .78558 L p F P
0 g
s
.335 .441 .821 r
.67193 .77456 m .67792 .77751 L .67649 .7819 L p F P
0 g
s
.45 .653 .946 r
.67509 .57679 m .67111 .57664 L .66814 .57277 L p F P
0 g
s
.047 .235 .733 r
.64133 .71835 m .64102 .72258 L .64589 .72699 L p F P
0 g
s
.103 .261 .741 r
.63714 .71429 m .64133 .71835 L .64102 .72258 L p F P
0 g
s
.435 .562 .884 r
.71877 .82447 m .71673 .82411 L .71746 .82222 L closepath p F P
0 g
s
.453 .552 .866 r
.71579 .8193 m .71746 .82222 L .71673 .82411 L p F P
0 g
s
.767 .444 0 r
.60466 .63784 m .60307 .63396 L .60156 .62876 L p F P
0 g
s
0 .167 .693 r
.63714 .71429 m .63677 .71387 L .63675 .71335 L closepath p F P
0 g
s
0 .145 .678 r
.63397 .70663 m .63273 .70509 L p .63677 .71387 L F P
0 g
s
0 .145 .678 r
.63677 .71387 m .63675 .71335 L .63397 .70663 L p F P
0 g
s
.953 .813 .667 r
.59318 .58555 m .59483 .58154 L .59176 .57877 L p F P
0 g
s
.994 .756 .453 r
.59171 .59161 m .59416 .59531 L .59359 .60109 L p F P
0 g
s
.987 .8 .568 r
.59416 .59531 m .59171 .59161 L .59318 .58555 L p F P
0 g
s
0 0 .518 r
.8307 .74335 m .82967 .74761 L .83171 .75297 L p F P
0 g
s
0 .048 .578 r
.82967 .74761 m .8307 .74335 L .82811 .73816 L p F P
0 g
s
.372 .578 .921 r
.70923 .59519 m .72084 .59732 L .72198 .60134 L p F P
0 g
s
.39 .594 .926 r
.7078 .59125 m .70923 .59519 L .72084 .59732 L p F P
0 g
s
.38 .591 .927 r
.7052 .59082 m .7078 .59125 L .70923 .59519 L p F P
0 g
s
.338 .467 .844 r
.6909 .79322 m .68319 .78992 L p .69037 .79782 L F P
0 g
s
.316 .439 .827 r
.68319 .78992 m .6909 .79322 L .68783 .78712 L p F P
0 g
s
.316 .439 .827 r
.68783 .78712 m .68453 .78558 L .68319 .78992 L p F P
0 g
s
0 .123 .666 r
.63397 .70663 m .63273 .70509 L .63255 .70326 L closepath p F P
0 g
s
0 .097 .647 r
.63081 .69902 m .62877 .69629 L p .63273 .70509 L F P
0 g
s
0 .097 .647 r
.63273 .70509 m .63255 .70326 L .63081 .69902 L p F P
0 g
s
.424 .527 .858 r
.69779 .80667 m .69834 .8055 L p .7078 .81279 L F P
0 g
s
.408 .516 .856 r
.69779 .80667 m .697 .80515 L .69834 .8055 L closepath p F P
0 g
s
.068 .242 .734 r
.64133 .71835 m .63714 .71429 L .63675 .71335 L p F P
0 g
s
.35 .547 .905 r
.74257 .61404 m .73458 .61188 L p .74541 .61863 L F P
0 g
s
.331 .539 .906 r
.73458 .61188 m .74257 .61404 L .73966 .60949 L p F P
0 g
s
.331 .539 .906 r
.73966 .60949 m .73357 .60786 L .73458 .61188 L p F P
0 g
s
.341 .548 .909 r
.72674 .60616 m .73357 .60786 L .73458 .61188 L p F P
0 g
s
.584 .759 .962 r
.75576 .84222 m .76835 .83987 L .77113 .84298 L p F P
0 g
s
.568 .739 .957 r
.76835 .83987 m .75576 .84222 L .75291 .83846 L p F P
0 g
s
.313 .427 .817 r
.67792 .77751 m .67193 .77456 L .67082 .77215 L p F P
0 g
s
.815 .476 0 r
.59977 .62493 m .60156 .62876 L .60307 .63396 L p F P
0 g
s
.861 .541 .02 r
.60156 .62876 m .59977 .62493 L .59864 .61963 L p F P
0 g
s
0 0 .235 r
.83292 .76847 m .83174 .77271 L .83194 .77861 L p F P
0 g
s
0 0 .355 r
.83174 .77271 m .83292 .76847 L .83206 .76275 L p F P
0 g
s
.338 .55 .911 r
.73357 .60786 m .72674 .60616 L .72383 .60172 L p F P
0 g
s
.068 .242 .734 r
.63675 .71335 m .63688 .70967 L p .64133 .71835 L F P
0 g
s
.035 .212 .716 r
.63675 .71335 m .63397 .70663 L .63688 .70967 L closepath p F P
0 g
s
.276 .472 .87 r
.76725 .63806 m .76488 .63709 L .76444 .63311 L closepath p F P
0 g
s
.308 .5 .882 r
.76488 .63709 m .76444 .63311 L .76435 .63295 L p F P
0 g
s
.547 .71 .947 r
.65268 .56929 m .65243 .56932 L .652 .56844 L closepath p F P
0 g
s
.546 .716 .951 r
.64969 .56555 m .652 .56844 L .65243 .56932 L p F P
0 g
s
0 .073 .632 r
.63081 .69902 m .62877 .69629 L .6283 .6931 L closepath p F P
0 g
s
0 .041 .608 r
.62764 .69148 m .62489 .68746 L p .62877 .69629 L F P
0 g
s
0 .041 .608 r
.62877 .69629 m .6283 .6931 L .62764 .69148 L p F P
0 g
s
.492 .678 .948 r
.65268 .56929 m .66517 .56893 L .66814 .57277 L p F P
0 g
s
.474 .674 .952 r
.66218 .56512 m .66517 .56893 L .65268 .56929 L p F P
0 g
s
.474 .674 .952 r
.65023 .56553 m .66218 .56512 L p .65268 .56929 L F P
0 g
s
.474 .674 .952 r
.65268 .56929 m .652 .56844 L .65023 .56553 L p F P
0 g
s
.705 .871 .96 r
.78923 .83973 m .78634 .84119 L .78364 .83885 L p F P
0 g
s
.643 .841 .976 r
.77113 .84298 m .78364 .83885 L .78634 .84119 L p F P
0 g
s
.343 .473 .847 r
.69396 .79921 m .69037 .79782 L .69142 .79425 L closepath p F P
0 g
s
.338 .467 .844 r
.69037 .79782 m .69142 .79425 L .6909 .79322 L p F P
0 g
s
.847 .915 .515 r
.82462 .80627 m .8261 .80202 L p .8216 .81143 L F P
0 g
s
.847 .915 .515 r
.8216 .81143 m .82256 .8104 L .82462 .80627 L p F P
0 g
s
.692 .767 .277 r
.82462 .80627 m .8261 .80202 L .82863 .79535 L p F P
0 g
s
.49 .598 .888 r
.71877 .82447 m .7315 .82582 L p .73086 .83016 L F P
0 g
s
.464 .579 .884 r
.72855 .82105 m .7315 .82582 L .71877 .82447 L p F P
0 g
s
.464 .579 .884 r
.71876 .81969 m .72855 .82105 L p .71877 .82447 L F P
0 g
s
.464 .579 .884 r
.71877 .82447 m .71746 .82222 L .71876 .81969 L p F P
0 g
s
.411 .514 .853 r
.69834 .8055 m .697 .80515 L .69396 .79921 L p F P
0 g
s
0 .006 .582 r
.62489 .68746 m .62764 .69148 L .62446 .68399 L p F P
0 g
s
0 .006 .582 r
.62446 .68399 m .62411 .68346 L .62489 .68746 L p F P
0 g
s
0 0 .557 r
.62489 .68746 m .62411 .68346 L .62108 .67861 L p F P
0 g
s
.313 .427 .817 r
.67082 .77215 m .67167 .76934 L p .67792 .77751 L F P
0 g
s
.292 .411 .811 r
.67082 .77215 m .66882 .76781 L .67167 .76934 L closepath p F P
0 g
s
.892 .561 .068 r
.59663 .61584 m .59864 .61963 L .59977 .62493 L p F P
0 g
s
.935 .63 .169 r
.59864 .61963 m .59663 .61584 L .59595 .61041 L p F P
0 g
s
0 .041 .575 r
.82867 .73553 m .82811 .73816 L .8307 .74335 L p F P
0 g
s
0 .109 .626 r
.8274 .73129 m .82594 .72887 L p .82811 .73816 L F P
0 g
s
0 .109 .626 r
.82811 .73816 m .82867 .73553 L .8274 .73129 L p F P
0 g
s
.626 .816 .973 r
.78364 .83885 m .77113 .84298 L .76835 .83987 L p F P
0 g
s
0 0 0 r
.83056 .7878 m .83013 .78896 L .82863 .79535 L p F P
0 g
s
.407 .616 .936 r
.69338 .58562 m .70226 .58668 L .69933 .58258 L p F P
0 g
s
.407 .616 .936 r
.69933 .58258 m .69174 .58171 L .69338 .58562 L p F P
0 g
s
.413 .621 .938 r
.68664 .58119 m .69174 .58171 L .69338 .58562 L p F P
0 g
s
.705 .871 .96 r
.78364 .83885 m .79102 .83546 L .78923 .83973 L p F P
0 g
s
.731 .924 .956 r
.79606 .83299 m .79102 .83546 L .78923 .83973 L p F P
0 g
s
.731 .924 .956 r
.78923 .83973 m .79868 .83457 L .79606 .83299 L p F P
0 g
s
.981 .789 .571 r
.59051 .5819 m .59318 .58555 L .59171 .59161 L p F P
0 g
s
.953 .813 .667 r
.59176 .57877 m .59051 .5819 L .59318 .58555 L p F P
0 g
s
.546 .662 .912 r
.73736 .83492 m .75004 .83453 L p .75039 .83862 L F P
0 g
s
.502 .657 .929 r
.75004 .83453 m .73736 .83492 L .73444 .83043 L p F P
0 g
s
0 0 .535 r
.62014 .67463 m .62108 .67861 L .62411 .68346 L p F P
0 g
s
0 0 .507 r
.62108 .67861 m .62014 .67463 L .61733 .66973 L p F P
0 g
s
.495 .686 .952 r
.652 .56844 m .64969 .56555 L .65023 .56553 L closepath p F P
0 g
s
.189 .379 .82 r
.79484 .6682 m .79221 .66658 L .78928 .66074 L p F P
0 g
s
.244 .437 .852 r
.78099 .6523 m .78069 .64818 L .77326 .6446 L p F P
0 g
s
.243 .441 .856 r
.77277 .64051 m .77326 .6446 L .78069 .64818 L p F P
0 g
s
.256 .456 .864 r
.76725 .63806 m .77277 .64051 L .77326 .6446 L p F P
0 g
s
.45 .653 .946 r
.66814 .57277 m .67318 .57294 L .67509 .57679 L p F P
0 g
s
.447 .65 .945 r
.67509 .57679 m .68369 .57721 L .68073 .57326 L p F P
0 g
s
.447 .65 .945 r
.68073 .57326 m .67318 .57294 L .67509 .57679 L p F P
0 g
s
.018 .207 .716 r
.63688 .70967 m .63397 .70663 L .63255 .70326 L p F P
0 g
s
.424 .527 .858 r
.69834 .8055 m .70921 .8085 L .7078 .81279 L p F P
0 g
s
.378 .515 .869 r
.70013 .80108 m .69834 .8055 L .70921 .8085 L p F P
0 g
s
.411 .514 .853 r
.69396 .79921 m .70013 .80108 L .69834 .8055 L p F P
0 g
s
.761 .905 .517 r
.82078 .8133 m .8216 .81143 L .82256 .8104 L closepath p F P
0 g
s
0 0 .471 r
.61622 .66578 m .61733 .66973 L .62014 .67463 L p F P
0 g
s
0 0 .446 r
.61733 .66973 m .61622 .66578 L .61365 .66083 L p F P
0 g
s
.949 .637 .204 r
.59373 .60667 m .59595 .61041 L .59663 .61584 L p F P
0 g
s
.98 .703 .317 r
.59595 .61041 m .59373 .60667 L .59359 .60109 L p F P
0 g
s
.461 .575 .883 r
.71746 .82222 m .71579 .8193 L .71876 .81969 L closepath p F P
0 g
s
.619 .751 .94 r
.61897 .56313 m .63126 .55991 L .63429 .56354 L p F P
0 g
s
.621 .753 .941 r
.63126 .55991 m .61897 .56313 L .61592 .55959 L p F P
0 g
s
.713 .79 .912 r
.60373 .56549 m .61592 .55959 L .61897 .56313 L p F P
0 g
s
0 .093 .618 r
.8274 .73129 m .82594 .72887 L .82621 .72737 L closepath p F P
0 g
s
.03 .157 .664 r
.82414 .72112 m .82316 .71974 L p .82594 .72887 L F P
0 g
s
.03 .157 .664 r
.82594 .72887 m .82621 .72737 L .82414 .72112 L p F P
0 g
s
0 0 .355 r
.83319 .7585 m .83206 .76275 L .83292 .76847 L p F P
0 g
s
0 0 .448 r
.83206 .76275 m .83319 .7585 L .83171 .75297 L p F P
0 g
s
.25 .455 .865 r
.77277 .64051 m .76725 .63806 L .76444 .63311 L p F P
0 g
s
.32 .522 .896 r
.74547 .61865 m .74541 .61863 L .74539 .61853 L closepath p F P
0 g
s
.35 .547 .905 r
.74541 .61863 m .74539 .61853 L .74257 .61404 L p F P
0 g
s
.29 .411 .812 r
.67167 .76934 m .66882 .76781 L .66574 .76113 L p F P
0 g
s
.297 .504 .889 r
.74547 .61865 m .75434 .62168 L .75512 .62574 L p F P
0 g
s
.291 .504 .891 r
.75434 .62168 m .74547 .61865 L .74539 .61853 L p F P
0 g
s
.309 .522 .899 r
.74539 .61853 m .74257 .61404 L .74444 .61462 L closepath p F P
0 g
s
.291 .504 .891 r
.74539 .61853 m .74444 .61462 L p .75434 .62168 L F P
0 g
s
.018 .207 .716 r
.63255 .70326 m .63252 .70096 L p .63688 .70967 L F P
0 g
s
0 .175 .695 r
.63255 .70326 m .63081 .69902 L .63252 .70096 L closepath p F P
0 g
s
0 0 .394 r
.61236 .65691 m .61365 .66083 L .61622 .66578 L p F P
0 g
s
0 0 .373 r
.61365 .66083 m .61236 .65691 L .61004 .65191 L p F P
0 g
s
.244 .429 .846 r
.78636 .65511 m .78099 .6523 L p .78827 .66014 L F P
0 g
s
.222 .418 .843 r
.78099 .6523 m .78636 .65511 L .78345 .64963 L p F P
0 g
s
.222 .418 .843 r
.78345 .64963 m .78069 .64818 L .78099 .6523 L p F P
0 g
s
.837 .992 .739 r
.8216 .81143 m .82078 .8133 L .8149 .82088 L p F P
0 g
s
.366 .571 .918 r
.72198 .60134 m .72383 .60172 L .72091 .59734 L p F P
0 g
s
.366 .571 .918 r
.72091 .59734 m .72084 .59732 L .72198 .60134 L p F P
0 g
s
0 0 0 r
.83143 .78473 m .83056 .7878 L .8298 .79218 L p F P
0 g
s
0 0 .094 r
.83056 .7878 m .83143 .78473 L .83194 .77861 L p F P
0 g
s
0 0 0 r
.82863 .79535 m .8298 .79218 L .83056 .7878 L p F P
0 g
s
.412 .624 .94 r
.69174 .58171 m .68664 .58119 L .68369 .57721 L p F P
0 g
s
.474 .612 .908 r
.73444 .83043 m .73086 .83016 L .73208 .82673 L closepath p F P
0 g
s
.49 .598 .888 r
.7315 .82582 m .73208 .82673 L .73086 .83016 L p F P
0 g
s
.534 .683 .934 r
.75291 .83846 m .75039 .83862 L .7512 .83611 L closepath p F P
0 g
s
.546 .662 .912 r
.75004 .83453 m .7512 .83611 L .75039 .83862 L p F P
0 g
s
.553 .717 .949 r
.63429 .56354 m .64668 .56184 L .64969 .56555 L p F P
0 g
s
.555 .72 .95 r
.64668 .56184 m .63429 .56354 L .63126 .55991 L p F P
0 g
s
.854 .826 .82 r
.59864 .56367 m .6015 .5673 L .59401 .57522 L p F P
0 g
s
.805 .815 .859 r
.60066 .56203 m .59864 .56367 L .6015 .5673 L p F P
0 g
s
.805 .815 .859 r
.6015 .5673 m .60373 .56549 L .60066 .56203 L p F P
0 g
s
.378 .594 .93 r
.7078 .59125 m .7052 .59082 L .70226 .58668 L p F P
0 g
s
.983 .7 .339 r
.59116 .59739 m .59359 .60109 L .59373 .60667 L p F P
0 g
s
.994 .756 .453 r
.59359 .60109 m .59116 .59739 L .59171 .59161 L p F P
0 g
s
.715 .79 .911 r
.61592 .55959 m .60373 .56549 L .60066 .56203 L p F P
0 g
s
.007 .142 .656 r
.82414 .72112 m .82316 .71974 L .82333 .71867 L closepath p F P
0 g
s
.063 .202 .697 r
.82099 .7122 m .8198 .71077 L p .82316 .71974 L F P
0 g
s
.063 .202 .697 r
.82316 .71974 m .82333 .71867 L .82099 .7122 L p F P
0 g
s
0 0 .318 r
.60857 .64802 m .61004 .65191 L .61236 .65691 L p F P
0 g
s
.772 .956 .931 r
.80595 .82928 m .79868 .83457 L .79606 .83299 L p F P
0 g
s
0 .167 .694 r
.63252 .70096 m .63081 .69902 L .6283 .6931 L p F P
0 g
s
.45 .656 .948 r
.67318 .57294 m .66814 .57277 L .66517 .56893 L p F P
0 g
s
.387 .517 .867 r
.7078 .81279 m .71279 .81401 L .70978 .80866 L p F P
0 g
s
.387 .517 .867 r
.70978 .80866 m .70921 .8085 L .7078 .81279 L p F P
0 g
s
.391 .501 .851 r
.70013 .80108 m .69396 .79921 L .69142 .79425 L p F P
0 g
s
.206 .393 .828 r
.78928 .66074 m .78827 .66014 L .78822 .65864 L closepath p F P
0 g
s
.244 .429 .846 r
.78827 .66014 m .78822 .65864 L .78636 .65511 L p F P
0 g
s
.913 .825 .746 r
.59401 .57522 m .59176 .57877 L .58867 .57571 L p F P
0 g
s
.913 .825 .746 r
.58867 .57571 m .59125 .57158 L .59401 .57522 L p F P
0 g
s
.854 .826 .82 r
.59401 .57522 m .59125 .57158 L .59864 .56367 L p F P
0 g
s
.726 .389 0 r
.6065 .64295 m .60486 .6391 L .60307 .63396 L p F P
0 g
s
.041 .187 .691 r
.82099 .7122 m .8198 .71077 L .81997 .7094 L closepath p F P
0 g
s
.094 .243 .727 r
.81789 .70408 m .81587 .70196 L p .8198 .71077 L F P
0 g
s
.094 .243 .727 r
.8198 .71077 m .81997 .7094 L .81789 .70408 L p F P
0 g
s
0 0 .235 r
.83194 .77861 m .83311 .77438 L .83292 .76847 L p F P
0 g
s
0 0 .08 r
.83311 .77438 m .83194 .77861 L .83143 .78473 L p F P
0 g
s
.464 .572 .879 r
.71876 .81969 m .71579 .8193 L .71279 .81401 L p F P
0 g
s
.834 .998 .834 r
.8149 .82088 m .81083 .8252 L .80832 .82474 L p F P
0 g
s
.834 .998 .834 r
.80832 .82474 m .81661 .8166 L .8149 .82088 L p F P
0 g
s
.837 .992 .739 r
.82027 .8122 m .8216 .81143 L p .8149 .82088 L F P
0 g
s
.837 .992 .739 r
.8149 .82088 m .81661 .8166 L .82027 .8122 L p F P
0 g
s
.167 .35 .802 r
.79484 .6682 m .80082 .67228 L .80086 .67642 L p F P
0 g
s
.165 .355 .808 r
.79465 .66408 m .79484 .6682 L .80082 .67228 L p F P
0 g
s
.189 .379 .82 r
.78928 .66074 m .79465 .66408 L .79484 .6682 L p F P
0 g
s
.338 .55 .911 r
.72383 .60172 m .73246 .60385 L .73357 .60786 L p F P
0 g
s
.334 .552 .913 r
.73246 .60385 m .72383 .60172 L .72091 .59734 L p F P
0 g
s
0 0 .443 r
.83234 .75037 m .83171 .75297 L .83319 .7585 L p F P
0 g
s
0 0 .518 r
.83085 .74376 m .8307 .74335 L p .83171 .75297 L F P
0 g
s
0 0 .518 r
.83171 .75297 m .83234 .75037 L .83085 .74376 L p F P
0 g
s
.283 .492 .884 r
.75512 .62574 m .76145 .62805 L .75855 .62321 L p F P
0 g
s
.283 .492 .884 r
.75855 .62321 m .75434 .62168 L .75512 .62574 L p F P
0 g
s
.772 .956 .931 r
.79606 .83299 m .80813 .82488 L .80595 .82928 L p F P
0 g
s
.801 .992 .878 r
.80832 .82474 m .80813 .82488 L .80595 .82928 L p F P
0 g
s
.801 .992 .878 r
.80595 .82928 m .81083 .8252 L .80832 .82474 L p F P
0 g
s
.703 .784 .304 r
.8298 .79218 m .82863 .79535 L .8261 .80202 L p F P
0 g
s
.566 .698 .93 r
.76272 .83306 m .76555 .83655 L .75291 .83846 L p F P
0 g
s
.566 .698 .93 r
.75242 .83425 m .76272 .83306 L p .75291 .83846 L F P
0 g
s
.566 .698 .93 r
.75291 .83846 m .7512 .83611 L .75242 .83425 L p F P
0 g
s
.568 .739 .957 r
.75291 .83846 m .76555 .83655 L .76835 .83987 L p F P
0 g
s
.072 .229 .721 r
.81789 .70408 m .81587 .70196 L .8161 .69951 L closepath p F P
0 g
s
.122 .28 .753 r
.81484 .69648 m .81139 .69329 L p .81587 .70196 L F P
0 g
s
.122 .28 .753 r
.81587 .70196 m .8161 .69951 L .81484 .69648 L p F P
0 g
s
0 .067 .603 r
.82621 .72737 m .82656 .72468 L p .82892 .73394 L F P
0 g
s
0 .067 .603 r
.82892 .73394 m .8274 .73129 L .82621 .72737 L p F P
0 g
s
0 .119 .643 r
.82621 .72737 m .82414 .72112 L .82656 .72468 L closepath p F P
0 g
s
.99 .747 .464 r
.58906 .58795 m .59171 .59161 L .59116 .59739 L p F P
0 g
s
.981 .789 .571 r
.59171 .59161 m .58906 .58795 L .59051 .5819 L p F P
0 g
s
.153 .33 .788 r
.80638 .68478 m .8065 .68062 L .80086 .67642 L p F P
0 g
s
.16 .342 .797 r
.80082 .67228 m .80086 .67642 L .8065 .68062 L p F P
0 g
s
.178 .375 .821 r
.79465 .66408 m .78928 .66074 L .78822 .65864 L p F P
0 g
s
.776 .423 0 r
.60123 .63015 m .60307 .63396 L .60486 .6391 L p F P
0 g
s
.815 .476 0 r
.60307 .63396 m .60123 .63015 L .59977 .62493 L p F P
0 g
s
.095 .262 .745 r
.81139 .69329 m .81484 .69648 L .81182 .68925 L p F P
0 g
s
.095 .262 .745 r
.81182 .68925 m .81166 .68911 L .81139 .69329 L p F P
0 g
s
.137 .304 .77 r
.81139 .69329 m .81166 .68911 L .80638 .68478 L p F P
0 g
s
0 .068 .603 r
.82867 .73553 m .8274 .73129 L .82892 .73394 L closepath p F P
0 g
s
0 .117 .643 r
.82656 .72468 m .82414 .72112 L .82333 .71867 L p F P
0 g
s
.29 .411 .812 r
.66574 .76113 m .66576 .76108 L p .67167 .76934 L F P
0 g
s
.268 .393 .805 r
.66574 .76113 m .66571 .76106 L .66576 .76108 L closepath p F P
0 g
s
.165 .329 .785 r
.66259 .75421 m .66049 .75265 L .66073 .75015 L closepath p F P
0 g
s
.154 .318 .778 r
.65947 .74737 m .65545 .74414 L p .66049 .75265 L F P
0 g
s
.154 .318 .778 r
.66049 .75265 m .66073 .75015 L .65947 .74737 L p F P
0 g
s
.134 .309 .776 r
.8065 .68062 m .80638 .68478 L .81166 .68911 L p F P
0 g
s
.267 .393 .805 r
.66576 .76108 m .66571 .76106 L .66259 .75421 L p F P
0 g
s
.114 .288 .763 r
.65545 .74414 m .65947 .74737 L .65634 .74053 L p F P
0 g
s
.114 .288 .763 r
.65634 .74053 m .65569 .73998 L .65545 .74414 L p F P
0 g
s
.107 .281 .759 r
.65545 .74414 m .65569 .73998 L .65059 .73559 L p F P
0 g
s
0 .117 .643 r
.82333 .71867 m .82364 .71556 L p .82656 .72468 L F P
0 g
s
.01 .165 .678 r
.82333 .71867 m .82099 .7122 L .82364 .71556 L closepath p F P
0 g
s
.29 .411 .812 r
.66576 .76108 m .67264 .76504 L .67167 .76934 L p F P
0 g
s
.215 .373 .807 r
.66671 .75676 m .66576 .76108 L .67264 .76504 L p F P
0 g
s
.267 .393 .805 r
.66259 .75421 m .66671 .75676 L .66576 .76108 L p F P
0 g
s
.951 .803 .662 r
.59051 .5819 m .59176 .57877 L .58867 .57571 L p F P
0 g
s
.08 .27 .757 r
.65074 .73143 m .65059 .73559 L .65569 .73998 L p F P
0 g
s
.079 .259 .747 r
.65059 .73559 m .65074 .73143 L .64589 .72699 L p F P
0 g
s
0 .041 .575 r
.8307 .74335 m .83073 .74322 L .82867 .73553 L p F P
0 g
s
0 0 .548 r
.82892 .73394 m .82867 .73553 L .83073 .74322 L p F P
0 g
s
0 .167 .694 r
.6283 .6931 m .62825 .69223 L p .63252 .70096 L F P
0 g
s
0 .131 .669 r
.6283 .6931 m .62764 .69148 L .62825 .69223 L closepath p F P
0 g
s
.032 .237 .74 r
.64594 .72283 m .64589 .72699 L .65074 .73143 L p F P
0 g
s
.047 .235 .733 r
.64589 .72699 m .64594 .72283 L .64133 .71835 L p F P
0 g
s
.39 .594 .926 r
.71799 .59308 m .7078 .59125 L p .72084 .59732 L F P
0 g
s
.369 .587 .928 r
.7078 .59125 m .71799 .59308 L .71507 .58888 L p F P
0 g
s
.369 .587 .928 r
.71507 .58888 m .70626 .58732 L .7078 .59125 L p F P
0 g
s
.378 .594 .93 r
.70226 .58668 m .70626 .58732 L .7078 .59125 L p F P
0 g
s
.493 .688 .954 r
.65023 .56553 m .64969 .56555 L .64668 .56184 L p F P
0 g
s
.313 .427 .817 r
.67167 .76934 m .67885 .77324 L .67792 .77751 L p F P
0 g
s
.242 .4 .821 r
.67264 .76504 m .67167 .76934 L .67885 .77324 L p F P
0 g
s
.502 .657 .929 r
.73444 .83043 m .74716 .83043 L .75004 .83453 L p F P
0 g
s
.505 .629 .906 r
.74425 .8262 m .74716 .83043 L .73444 .83043 L p F P
0 g
s
.505 .629 .906 r
.73256 .82584 m .74425 .8262 L p .73444 .83043 L F P
0 g
s
.505 .629 .906 r
.73444 .83043 m .73208 .82673 L .73256 .82584 L p F P
0 g
s
0 .198 .716 r
.64126 .7142 m .64133 .71835 L .64594 .72283 L p F P
0 g
s
.068 .242 .734 r
.63688 .70967 m .64126 .7142 L .64133 .71835 L p F P
0 g
s
0 .122 .665 r
.62825 .69223 m .62764 .69148 L .62446 .68399 L p F P
0 g
s
.851 .501 0 r
.59773 .62115 m .59977 .62493 L .60123 .63015 L p F P
0 g
s
.892 .561 .068 r
.59977 .62493 m .59773 .62115 L .59663 .61584 L p F P
0 g
s
.492 .687 .954 r
.65023 .56553 m .66218 .56512 L .65919 .56135 L p F P
0 g
s
.492 .687 .954 r
.65919 .56135 m .6478 .56179 L .65023 .56553 L p F P
0 g
s
.493 .688 .954 r
.64668 .56184 m .6478 .56179 L .65023 .56553 L p F P
0 g
s
.327 .541 .908 r
.73357 .60786 m .73966 .60949 L .73676 .60499 L p F P
0 g
s
.327 .541 .908 r
.73676 .60499 m .73246 .60385 L .73357 .60786 L p F P
0 g
s
0 .169 .698 r
.63668 .70554 m .63688 .70967 L .64126 .7142 L p F P
0 g
s
.018 .207 .716 r
.63252 .70096 m .63668 .70554 L .63688 .70967 L p F P
0 g
s
.006 .164 .678 r
.82364 .71556 m .82099 .7122 L .81997 .7094 L p F P
0 g
s
.293 .435 .833 r
.68476 .781 m .67792 .77751 L p .68453 .78558 L F P
0 g
s
.268 .407 .818 r
.67792 .77751 m .68476 .781 L .68168 .7748 L p F P
0 g
s
.268 .407 .818 r
.68168 .7748 m .67885 .77324 L .67792 .77751 L p F P
0 g
s
.847 .966 .642 r
.82027 .8122 m .82238 .80903 L .8216 .81143 L closepath p F P
0 g
s
.847 .915 .515 r
.8261 .80202 m .82238 .80903 L .8216 .81143 L p F P
0 g
s
.178 .375 .821 r
.78822 .65864 m .78801 .65603 L p .79465 .66408 L F P
0 g
s
.203 .403 .836 r
.78822 .65864 m .78636 .65511 L .78801 .65603 L closepath p F P
0 g
s
.678 .879 .973 r
.79102 .83546 m .78364 .83885 L .78091 .83625 L p F P
0 g
s
.626 .816 .973 r
.76835 .83987 m .78091 .83625 L .78364 .83885 L p F P
0 g
s
.25 .455 .865 r
.76444 .63311 m .76442 .63298 L p .77277 .64051 L F P
0 g
s
.27 .476 .875 r
.76444 .63311 m .76435 .63295 L .76442 .63298 L closepath p F P
0 g
s
.609 .794 .97 r
.78091 .83625 m .76835 .83987 L .76555 .83655 L p F P
0 g
s
0 .137 .678 r
.63218 .69686 m .63252 .70096 L .63668 .70554 L p F P
0 g
s
0 .167 .694 r
.62825 .69223 m .63218 .69686 L .63252 .70096 L p F P
0 g
s
0 0 .508 r
.83085 .74376 m .8307 .74335 L .83073 .74322 L closepath p F P
0 g
s
.006 .164 .678 r
.81997 .7094 m .82018 .7066 L p .82364 .71556 L F P
0 g
s
.043 .208 .71 r
.81997 .7094 m .81789 .70408 L .82018 .7066 L closepath p F P
0 g
s
.264 .477 .878 r
.76442 .63298 m .76435 .63295 L .76145 .62805 L p F P
0 g
s
.391 .501 .851 r
.69142 .79425 m .69172 .7935 L p .70013 .80108 L F P
0 g
s
.374 .489 .847 r
.69142 .79425 m .6909 .79322 L .69172 .7935 L closepath p F P
0 g
s
.437 .561 .882 r
.71876 .81969 m .72855 .82105 L .72558 .81619 L p F P
0 g
s
.437 .561 .882 r
.72558 .81619 m .72057 .81531 L .71876 .81969 L p F P
0 g
s
.464 .572 .879 r
.71279 .81401 m .72057 .81531 L .71876 .81969 L p F P
0 g
s
.25 .455 .865 r
.76442 .63298 m .77218 .63643 L .77277 .64051 L p F P
0 g
s
.245 .457 .868 r
.76365 .62893 m .76442 .63298 L .77218 .63643 L p F P
0 g
s
.264 .477 .878 r
.76145 .62805 m .76365 .62893 L .76442 .63298 L p F P
0 g
s
0 0 .487 r
.83073 .74322 m .83136 .73918 L p .83264 .74875 L F P
0 g
s
0 0 .487 r
.83264 .74875 m .83085 .74376 L .83073 .74322 L p F P
0 g
s
0 0 .548 r
.83073 .74322 m .83136 .73918 L .82892 .73394 L p F P
0 g
s
.976 .779 .575 r
.58766 .57829 m .59051 .5819 L .58906 .58795 L p F P
0 g
s
.951 .803 .662 r
.58867 .57571 m .58766 .57829 L .59051 .5819 L p F P
0 g
s
0 .102 .654 r
.62776 .68814 m .62825 .69223 L .63218 .69686 L p F P
0 g
s
0 .122 .665 r
.62446 .68399 m .62776 .68814 L .62825 .69223 L p F P
0 g
s
.914 .574 .108 r
.5944 .6121 m .59663 .61584 L .59773 .62115 L p F P
0 g
s
.949 .637 .204 r
.59663 .61584 m .5944 .6121 L .59373 .60667 L p F P
0 g
s
.299 .441 .837 r
.68783 .78712 m .68453 .78558 L .68529 .78207 L closepath p F P
0 g
s
.293 .435 .833 r
.68453 .78558 m .68529 .78207 L .68476 .781 L p F P
0 g
s
0 0 .489 r
.83234 .75037 m .83085 .74376 L .83264 .74875 L closepath p F P
0 g
s
.305 .523 .901 r
.74444 .61462 m .74257 .61404 L .73966 .60949 L p F P
0 g
s
.376 .488 .846 r
.69172 .7935 m .6909 .79322 L .68783 .78712 L p F P
0 g
s
0 0 .232 r
.83407 .76422 m .83292 .76847 L .83311 .77438 L p F P
0 g
s
0 0 .355 r
.83292 .76847 m .83407 .76422 L .83319 .7585 L p F P
0 g
s
.407 .62 .938 r
.69174 .58171 m .69933 .58258 L .69638 .57853 L p F P
0 g
s
.407 .62 .938 r
.69638 .57853 m .68997 .57783 L .69174 .58171 L p F P
0 g
s
.412 .624 .94 r
.68369 .57721 m .68997 .57783 L .69174 .58171 L p F P
0 g
s
0 0 .568 r
.62446 .68399 m .62411 .68346 L .62395 .68282 L closepath p F P
0 g
s
0 0 .535 r
.62129 .67652 m .62014 .67463 L p .62411 .68346 L F P
0 g
s
0 0 .535 r
.62411 .68346 m .62395 .68282 L .62129 .67652 L p F P
0 g
s
.564 .696 .929 r
.7512 .83611 m .75004 .83453 L .75242 .83425 L closepath p F P
0 g
s
.448 .653 .947 r
.67318 .57294 m .68073 .57326 L .67776 .56936 L p F P
0 g
s
.448 .653 .947 r
.67776 .56936 m .67114 .56911 L .67318 .57294 L p F P
0 g
s
.45 .656 .948 r
.66517 .56893 m .67114 .56911 L .67318 .57294 L p F P
0 g
s
.621 .753 .941 r
.61592 .55959 m .62823 .55629 L .63126 .55991 L p F P
0 g
s
.622 .755 .941 r
.62823 .55629 m .61592 .55959 L .61286 .55603 L p F P
0 g
s
.715 .79 .911 r
.60066 .56203 m .61286 .55603 L .61592 .55959 L p F P
0 g
s
.04 .207 .71 r
.82018 .7066 m .81789 .70408 L .8161 .69951 L p F P
0 g
s
.24 .379 .802 r
.66671 .75676 m .66259 .75421 L .66073 .75015 L p F P
0 g
s
.819 .919 .527 r
.82762 .79775 m .8261 .80202 L .82238 .80903 L p F P
0 g
s
.703 .784 .304 r
.82928 .79362 m .8298 .79218 L p .8261 .80202 L F P
0 g
s
.703 .784 .304 r
.8261 .80202 m .82762 .79775 L .82928 .79362 L p F P
0 g
s
.391 .501 .851 r
.69172 .7935 m .70136 .7968 L .70013 .80108 L p F P
0 g
s
.338 .486 .86 r
.69319 .78912 m .69172 .7935 L .70136 .7968 L p F P
0 g
s
.376 .488 .846 r
.68783 .78712 m .69319 .78912 L .69172 .7935 L p F P
0 g
s
0 0 .512 r
.62129 .67652 m .62014 .67463 L .61945 .67236 L closepath p F P
0 g
s
0 0 .471 r
.61811 .6692 m .61622 .66578 L p .62014 .67463 L F P
0 g
s
0 0 .471 r
.62014 .67463 m .61945 .67236 L .61811 .6692 L p F P
0 g
s
.959 .64 .233 r
.5913 .60298 m .59373 .60667 L .5944 .6121 L p F P
0 g
s
.983 .7 .339 r
.59373 .60667 m .5913 .60298 L .59116 .59739 L p F P
0 g
s
0 .097 .65 r
.62776 .68814 m .62446 .68399 L .62395 .68282 L p F P
0 g
s
0 0 .548 r
.82947 .72977 m .82892 .73394 L .83136 .73918 L p F P
0 g
s
0 .067 .603 r
.82656 .72468 m .82947 .72977 L .82892 .73394 L p F P
0 g
s
.446 .56 .877 r
.72057 .81531 m .71279 .81401 L .70978 .80866 L p F P
0 g
s
.243 .441 .856 r
.78069 .64818 m .78028 .64406 L .77277 .64051 L p F P
0 g
s
.248 .452 .863 r
.77218 .63643 m .77277 .64051 L .78028 .64406 L p F P
0 g
s
.411 .627 .942 r
.68997 .57783 m .68369 .57721 L .68073 .57326 L p F P
0 g
s
.375 .596 .932 r
.70626 .58732 m .70226 .58668 L .69933 .58258 L p F P
0 g
s
0 0 0 r
.8298 .79218 m .83011 .79107 L .83143 .78473 L p F P
0 g
s
0 0 0 r
.83257 .78051 m .83143 .78473 L .83011 .79107 L p F P
0 g
s
0 0 .08 r
.83143 .78473 m .83257 .78051 L .83311 .77438 L p F P
0 g
s
0 .097 .65 r
.62395 .68282 m .6234 .67941 L p .62776 .68814 L F P
0 g
s
0 .057 .62 r
.62395 .68282 m .62129 .67652 L .6234 .67941 L closepath p F P
0 g
s
0 0 .439 r
.61622 .66578 m .61811 .6692 L .61494 .66206 L p F P
0 g
s
0 0 .439 r
.61494 .66206 m .61485 .66189 L .61622 .66578 L p F P
0 g
s
0 0 .394 r
.61622 .66578 m .61485 .66189 L .61236 .65691 L p F P
0 g
s
.555 .72 .95 r
.63126 .55991 m .64367 .55816 L .64668 .56184 L p F P
0 g
s
.555 .723 .952 r
.64367 .55816 m .63126 .55991 L .62823 .55629 L p F P
0 g
s
.198 .403 .838 r
.78801 .65603 m .78636 .65511 L .78345 .64963 L p F P
0 g
s
.678 .879 .973 r
.79354 .83118 m .79102 .83546 L p .78091 .83625 L F P
0 g
s
.714 .897 .962 r
.79102 .83546 m .79354 .83118 L .79606 .83299 L closepath p F P
0 g
s
.851 .818 .816 r
.59563 .56008 m .59864 .56367 L .59125 .57158 L p F P
0 g
s
.806 .812 .856 r
.59757 .55849 m .59563 .56008 L .59864 .56367 L p F P
0 g
s
.806 .812 .856 r
.59864 .56367 m .60066 .56203 L .59757 .55849 L p F P
0 g
s
.305 .523 .901 r
.73966 .60949 m .74335 .61062 L .74444 .61462 L p F P
0 g
s
.291 .504 .891 r
.74444 .61462 m .75347 .61763 L .75434 .62168 L p F P
0 g
s
.294 .511 .895 r
.74335 .61062 m .74444 .61462 L .75347 .61763 L p F P
0 g
s
.04 .207 .71 r
.8161 .69951 m .81618 .69778 L p .82018 .7066 L F P
0 g
s
.074 .248 .738 r
.8161 .69951 m .81484 .69648 L .81618 .69778 L closepath p F P
0 g
s
.716 .79 .91 r
.61286 .55603 m .60066 .56203 L .59757 .55849 L p F P
0 g
s
0 0 .443 r
.83319 .7585 m .83355 .75705 L .83234 .75037 L p F P
0 g
s
0 0 .409 r
.83264 .74875 m .83234 .75037 L .83355 .75705 L p F P
0 g
s
.451 .659 .95 r
.67114 .56911 m .66517 .56893 L .66218 .56512 L p F P
0 g
s
0 0 .36 r
.61083 .65305 m .61236 .65691 L .61485 .66189 L p F P
0 g
s
0 0 .318 r
.61236 .65691 m .61083 .65305 L .60857 .64802 L p F P
0 g
s
.503 .626 .905 r
.73208 .82673 m .7315 .82582 L .73256 .82584 L closepath p F P
0 g
s
.983 .696 .357 r
.58852 .59374 m .59116 .59739 L .5913 .60298 L p F P
0 g
s
.99 .747 .464 r
.59116 .59739 m .58852 .59374 L .58906 .58795 L p F P
0 g
s
.362 .573 .92 r
.72091 .59734 m .72084 .59732 L .72079 .59716 L closepath p F P
0 g
s
.39 .594 .926 r
.72084 .59732 m .72079 .59716 L .71799 .59308 L p F P
0 g
s
.334 .552 .913 r
.72091 .59734 m .73123 .59986 L .73246 .60385 L p F P
0 g
s
.33 .554 .916 r
.73123 .59986 m .72091 .59734 L .72079 .59716 L p F P
0 g
s
0 .058 .6 r
.82701 .72051 m .82656 .72468 L .82947 .72977 L p F P
0 g
s
0 .117 .643 r
.82364 .71556 m .82701 .72051 L .82656 .72468 L p F P
0 g
s
.216 .359 .794 r
.66073 .75015 m .65947 .74737 L .66104 .74842 L closepath p F P
0 g
s
.24 .379 .802 r
.66073 .75015 m .66104 .74842 L p .66671 .75676 L F P
0 g
s
.378 .515 .869 r
.70676 .80317 m .70013 .80108 L p .70921 .8085 L F P
0 g
s
.354 .488 .855 r
.70013 .80108 m .70676 .80317 L .70374 .79763 L p F P
0 g
s
.354 .488 .855 r
.70374 .79763 m .70136 .7968 L .70013 .80108 L p F P
0 g
s
.215 .416 .844 r
.78069 .64818 m .78345 .64963 L .78053 .64419 L p F P
0 g
s
.215 .416 .844 r
.78053 .64419 m .78028 .64406 L .78069 .64818 L p F P
0 g
s
.567 .689 .922 r
.75242 .83425 m .75004 .83453 L .74716 .83043 L p F P
0 g
s
.33 .554 .916 r
.72079 .59716 m .71939 .59338 L p .73123 .59986 L F P
0 g
s
.345 .567 .921 r
.72079 .59716 m .71799 .59308 L .71939 .59338 L closepath p F P
0 g
s
0 0 .347 r
.83355 .75705 m .83319 .7585 L .83407 .76422 L p F P
0 g
s
.907 .814 .743 r
.59125 .57158 m .58867 .57571 L .58557 .57232 L p F P
0 g
s
.907 .814 .743 r
.58557 .57232 m .58825 .56799 L .59125 .57158 L p F P
0 g
s
.851 .818 .816 r
.59125 .57158 m .58825 .56799 L .59563 .56008 L p F P
0 g
s
.07 .247 .738 r
.81618 .69778 m .81484 .69648 L .81182 .68925 L p F P
0 g
s
.506 .621 .9 r
.73256 .82584 m .7315 .82582 L .72855 .82105 L p F P
0 g
s
.717 .759 .256 r
.82928 .79362 m .83011 .79107 L .8298 .79218 L closepath p F P
0 g
s
0 .041 .61 r
.6234 .67941 m .62129 .67652 L .61945 .67236 L p F P
0 g
s
.786 .911 .926 r
.79354 .83118 m .79606 .83299 L .80813 .82488 L p F P
0 g
s
.355 .475 .844 r
.69319 .78912 m .68783 .78712 L .68529 .78207 L p F P
0 g
s
.776 .423 0 r
.60486 .6391 m .60297 .6353 L .60123 .63015 L p F P
0 g
s
.745 .38 0 r
.60297 .6353 m .60486 .6391 L .60686 .64419 L p F P
0 g
s
.895 .98 .695 r
.82238 .80903 m .82373 .80481 L p .81819 .81284 L F P
0 g
s
.895 .98 .695 r
.81819 .81284 m .82027 .8122 L .82238 .80903 L p F P
0 g
s
.819 .919 .527 r
.82238 .80903 m .82373 .80481 L .82762 .79775 L p F P
0 g
s
0 .113 .643 r
.82398 .71141 m .82364 .71556 L .82701 .72051 L p F P
0 g
s
.006 .164 .678 r
.82018 .7066 m .82398 .71141 L .82364 .71556 L p F P
0 g
s
.212 .359 .795 r
.66104 .74842 m .65947 .74737 L .65634 .74053 L p F P
0 g
s
.178 .375 .821 r
.78801 .65603 m .79437 .65997 L .79465 .66408 L p F P
0 g
s
.174 .379 .825 r
.78757 .65194 m .78801 .65603 L .79437 .65997 L p F P
0 g
s
.198 .403 .838 r
.78345 .64963 m .78757 .65194 L .78801 .65603 L p F P
0 g
s
.986 .738 .473 r
.58622 .58435 m .58906 .58795 L .58852 .59374 L p F P
0 g
s
.976 .779 .575 r
.58906 .58795 m .58622 .58435 L .58766 .57829 L p F P
0 g
s
.506 .621 .9 r
.72855 .82105 m .73462 .82141 L .73256 .82584 L p F P
0 g
s
.483 .609 .901 r
.73256 .82584 m .74425 .8262 L .74134 .82186 L p F P
0 g
s
.483 .609 .901 r
.74134 .82186 m .73462 .82141 L .73256 .82584 L p F P
0 g
s
.258 .476 .879 r
.76365 .62893 m .76145 .62805 L .75855 .62321 L p F P
0 g
s
.544 .682 .929 r
.75242 .83425 m .76272 .83306 L .75988 .82941 L p F P
0 g
s
.544 .682 .929 r
.75988 .82941 m .75459 .82982 L .75242 .83425 L p F P
0 g
s
.567 .689 .922 r
.74716 .83043 m .75459 .82982 L .75242 .83425 L p F P
0 g
s
.494 .691 .955 r
.6478 .56179 m .64668 .56184 L .64367 .55816 L p F P
0 g
s
.279 .493 .886 r
.75434 .62168 m .75855 .62321 L .75565 .61842 L p F P
0 g
s
.279 .493 .886 r
.75565 .61842 m .75347 .61763 L .75434 .62168 L p F P
0 g
s
.815 .45 0 r
.59917 .62639 m .60123 .63015 L .60297 .6353 L p F P
0 g
s
.851 .501 0 r
.60123 .63015 m .59917 .62639 L .59773 .62115 L p F P
0 g
s
.946 .794 .66 r
.58766 .57829 m .58867 .57571 L .58557 .57232 L p F P
0 g
s
0 .161 .679 r
.82039 .70245 m .82018 .7066 L .82398 .71141 L p F P
0 g
s
.04 .207 .71 r
.81618 .69778 m .82039 .70245 L .82018 .7066 L p F P
0 g
s
.172 .368 .816 r
.79437 .65997 m .79465 .66408 L .8007 .66814 L p F P
0 g
s
.165 .355 .808 r
.80082 .67228 m .8007 .66814 L .79465 .66408 L p F P
0 g
s
.828 .99 .73 r
.81661 .8166 m .81819 .81284 L .82027 .8122 L closepath p F P
0 g
s
.382 .52 .871 r
.70978 .80866 m .70921 .8085 L .70938 .80792 L closepath p F P
0 g
s
.378 .515 .869 r
.70921 .8085 m .70938 .80792 L .70676 .80317 L p F P
0 g
s
0 0 .072 r
.83427 .77014 m .83311 .77438 L .83257 .78051 L p F P
0 g
s
0 0 .232 r
.83311 .77438 m .83427 .77014 L .83407 .76422 L p F P
0 g
s
0 .041 .61 r
.61945 .67236 m .61909 .67067 L p .6234 .67941 L F P
0 g
s
0 0 .574 r
.61945 .67236 m .61811 .6692 L .61909 .67067 L closepath p F P
0 g
s
.367 .59 .93 r
.70626 .58732 m .71507 .58888 L .71214 .58472 L p F P
0 g
s
.367 .59 .93 r
.71214 .58472 m .70459 .58342 L .70626 .58732 L p F P
0 g
s
.375 .596 .932 r
.69933 .58258 m .70459 .58342 L .70626 .58732 L p F P
0 g
s
.3 .524 .903 r
.74335 .61062 m .73966 .60949 L .73676 .60499 L p F P
0 g
s
.493 .69 .955 r
.6478 .56179 m .65919 .56135 L .65619 .55761 L p F P
0 g
s
.493 .69 .955 r
.65619 .55761 m .64525 .55808 L .6478 .56179 L p F P
0 g
s
.494 .691 .955 r
.64367 .55816 m .64525 .55808 L .6478 .56179 L p F P
0 g
s
.023 .202 .71 r
.81627 .69365 m .81618 .69778 L .82039 .70245 L p F P
0 g
s
.07 .247 .738 r
.81182 .68925 m .81627 .69365 L .81618 .69778 L p F P
0 g
s
.16 .342 .797 r
.80585 .67598 m .80082 .67228 L p .8065 .68062 L F P
0 g
s
.133 .326 .791 r
.80082 .67228 m .80585 .67598 L .80289 .66977 L p F P
0 g
s
.133 .326 .791 r
.80289 .66977 m .8007 .66814 L .80082 .67228 L p F P
0 g
s
.609 .794 .97 r
.76555 .83655 m .77815 .83343 L .78091 .83625 L p F P
0 g
s
.593 .772 .966 r
.77815 .83343 m .76555 .83655 L .76272 .83306 L p F P
0 g
s
0 0 .487 r
.83136 .73918 m .83331 .74458 L .83264 .74875 L p F P
0 g
s
0 0 .409 r
.83355 .75705 m .83405 .75431 L .83264 .74875 L p F P
0 g
s
0 0 .404 r
.83331 .74458 m .83264 .74875 L .83405 .75431 L p F P
0 g
s
.446 .56 .877 r
.70978 .80866 m .72177 .81108 L .72057 .81531 L p F P
0 g
s
.428 .546 .874 r
.72177 .81108 m .70978 .80866 L .70938 .80792 L p F P
0 g
s
.878 .518 .029 r
.59548 .61743 m .59773 .62115 L .59917 .62639 L p F P
0 g
s
.914 .574 .108 r
.59773 .62115 m .59548 .61743 L .5944 .6121 L p F P
0 g
s
.134 .309 .776 r
.80883 .68254 m .8065 .68062 L p .81166 .68911 L F P
0 g
s
.112 .296 .77 r
.80883 .68254 m .8065 .68062 L .80653 .67741 L closepath p F P
0 g
s
.16 .342 .797 r
.8065 .68062 m .80653 .67741 L .80585 .67598 L p F P
0 g
s
.084 .259 .745 r
.81182 .68925 m .81166 .68911 L .81167 .6889 L closepath p F P
0 g
s
.134 .309 .776 r
.81166 .68911 m .81167 .6889 L .80883 .68254 L p F P
0 g
s
.861 .975 .859 r
.81661 .8166 m .81819 .81284 L p .80822 .8247 L F P
0 g
s
.861 .975 .859 r
.80822 .8247 m .80832 .82474 L .81661 .8166 L p F P
0 g
s
0 0 0 r
.83011 .79107 m .83119 .78688 L .83257 .78051 L p F P
0 g
s
.806 .817 .335 r
.83011 .79107 m .83119 .78688 L p .82832 .79574 L F P
0 g
s
.806 .817 .335 r
.82832 .79574 m .82928 .79362 L .83011 .79107 L p F P
0 g
s
0 0 .308 r
.83405 .75431 m .83355 .75705 L .83432 .76321 L p F P
0 g
s
0 0 .347 r
.83407 .76422 m .83432 .76321 L .83355 .75705 L p F P
0 g
s
.678 .879 .973 r
.78091 .83625 m .7934 .83107 L .79354 .83118 L p F P
0 g
s
.66 .856 .975 r
.7934 .83107 m .78091 .83625 L .77815 .83343 L p F P
0 g
s
.051 .237 .734 r
.81627 .69365 m .81182 .68925 L .81167 .6889 L p F P
0 g
s
.094 .284 .765 r
.65634 .74053 m .65569 .73998 L .6557 .73914 L closepath p F P
0 g
s
.08 .27 .757 r
.6532 .73366 m .65074 .73143 L p .65569 .73998 L F P
0 g
s
.08 .27 .757 r
.65569 .73998 m .6557 .73914 L .6532 .73366 L p F P
0 g
s
.049 .254 .75 r
.6532 .73366 m .65074 .73143 L .65061 .72805 L closepath p F P
0 g
s
.032 .237 .74 r
.65006 .72685 m .64594 .72283 L p .65074 .73143 L F P
0 g
s
.032 .237 .74 r
.65074 .73143 m .65061 .72805 L .65006 .72685 L p F P
0 g
s
.24 .379 .802 r
.66104 .74842 m .66724 .75255 L .66671 .75676 L p F P
0 g
s
.15 .333 .792 r
.66153 .74419 m .66104 .74842 L .66724 .75255 L p F P
0 g
s
.212 .359 .795 r
.65634 .74053 m .66153 .74419 L .66104 .74842 L p F P
0 g
s
.051 .237 .734 r
.81167 .6889 m .81163 .68499 L p .81627 .69365 L F P
0 g
s
.086 .276 .76 r
.81167 .6889 m .80883 .68254 L .81163 .68499 L closepath p F P
0 g
s
.428 .546 .874 r
.70938 .80792 m .71089 .80411 L p .72177 .81108 L F P
0 g
s
.415 .536 .871 r
.70938 .80792 m .70676 .80317 L .71089 .80411 L closepath p F P
0 g
s
.324 .543 .91 r
.73246 .60385 m .73676 .60499 L .73384 .60055 L p F P
0 g
s
.324 .543 .91 r
.73384 .60055 m .73123 .59986 L .73246 .60385 L p F P
0 g
s
.786 .911 .926 r
.80813 .82488 m .80822 .8247 L p .79354 .83118 L F P
0 g
s
.792 .978 .906 r
.80813 .82488 m .80822 .8247 L .80832 .82474 L closepath p F P
0 g
s
.969 .769 .578 r
.58463 .57472 m .58766 .57829 L .58622 .58435 L p F P
0 g
s
.946 .794 .66 r
.58557 .57232 m .58463 .57472 L .58766 .57829 L p F P
0 g
s
0 .207 .722 r
.64594 .72283 m .65006 .72685 L .64692 .72005 L p F P
0 g
s
0 .207 .722 r
.64692 .72005 m .64565 .71876 L .64594 .72283 L p F P
0 g
s
0 .198 .716 r
.64594 .72283 m .64565 .71876 L .64126 .7142 L p F P
0 g
s
.189 .4 .838 r
.78757 .65194 m .78345 .64963 L .78053 .64419 L p F P
0 g
s
0 0 .558 r
.61909 .67067 m .61811 .6692 L .61494 .66206 L p F P
0 g
s
.215 .373 .807 r
.67264 .76504 m .67317 .76084 L .66671 .75676 L p F P
0 g
s
.183 .361 .807 r
.66724 .75255 m .66671 .75676 L .67317 .76084 L p F P
0 g
s
0 .176 .706 r
.64086 .71014 m .64126 .7142 L .64565 .71876 L p F P
0 g
s
0 .169 .698 r
.64126 .7142 m .64086 .71014 L .63668 .70554 L p F P
0 g
s
.816 .965 .903 r
.80575 .82363 m .80942 .82071 L .80822 .8247 L closepath p F P
0 g
s
.861 .975 .859 r
.81786 .81286 m .80942 .82071 L .80822 .8247 L p F P
0 g
s
.861 .975 .859 r
.81819 .81284 m .81786 .81286 L p .80822 .8247 L F P
0 g
s
.786 .911 .926 r
.80822 .8247 m .80575 .82363 L p .79354 .83118 L F P
0 g
s
.928 .583 .143 r
.59195 .60842 m .5944 .6121 L .59548 .61743 L p F P
0 g
s
.959 .64 .233 r
.5944 .6121 m .59195 .60842 L .5913 .60298 L p F P
0 g
s
0 .128 .674 r
.63615 .70149 m .63668 .70554 L .64086 .71014 L p F P
0 g
s
0 .137 .678 r
.63668 .70554 m .63615 .70149 L .63218 .69686 L p F P
0 g
s
.355 .475 .844 r
.68529 .78207 m .68553 .78132 L p .69319 .78912 L F P
0 g
s
.337 .462 .839 r
.68529 .78207 m .68476 .781 L .68553 .78132 L closepath p F P
0 g
s
.242 .4 .821 r
.67859 .76858 m .67264 .76504 L p .67885 .77324 L F P
0 g
s
.214 .373 .807 r
.67264 .76504 m .67859 .76858 L .67549 .76232 L p F P
0 g
s
.214 .373 .807 r
.67549 .76232 m .67317 .76084 L .67264 .76504 L p F P
0 g
s
.245 .457 .868 r
.77218 .63643 m .77149 .63236 L .76365 .62893 L p F P
0 g
s
.243 .461 .871 r
.76278 .6249 m .76365 .62893 L .77149 .63236 L p F P
0 g
s
.258 .476 .879 r
.75855 .62321 m .76278 .6249 L .76365 .62893 L p F P
0 g
s
.183 .343 .791 r
.66153 .74419 m .65634 .74053 L .6557 .73914 L p F P
0 g
s
.622 .755 .941 r
.61286 .55603 m .62519 .55268 L .62823 .55629 L p F P
0 g
s
.623 .756 .942 r
.62519 .55268 m .61286 .55603 L .60979 .55245 L p F P
0 g
s
.716 .79 .91 r
.59757 .55849 m .60979 .55245 L .61286 .55603 L p F P
0 g
s
.406 .623 .941 r
.68997 .57783 m .69638 .57853 L .69343 .57453 L p F P
0 g
s
.406 .623 .941 r
.69343 .57453 m .68808 .57396 L .68997 .57783 L p F P
0 g
s
.411 .627 .942 r
.68073 .57326 m .68808 .57396 L .68997 .57783 L p F P
0 g
s
0 .094 .65 r
.63153 .69282 m .63218 .69686 L .63615 .70149 L p F P
0 g
s
0 .102 .654 r
.63218 .69686 m .63153 .69282 L .62776 .68814 L p F P
0 g
s
.373 .599 .935 r
.70459 .58342 m .69933 .58258 L .69638 .57853 L p F P
0 g
s
.41 .63 .945 r
.68808 .57396 m .68073 .57326 L .67776 .56936 L p F P
0 g
s
.71 .79 .31 r
.82762 .79775 m .82832 .79574 L .82928 .79362 L closepath p F P
0 g
s
.338 .462 .839 r
.68553 .78132 m .68476 .781 L .68168 .7748 L p F P
0 g
s
.25 .408 .825 r
.68168 .7748 m .67885 .77324 L .67929 .77001 L closepath p F P
0 g
s
.242 .4 .821 r
.67885 .77324 m .67929 .77001 L .67859 .76858 L p F P
0 g
s
.448 .656 .949 r
.67114 .56911 m .67776 .56936 L .67479 .5655 L p F P
0 g
s
.448 .656 .949 r
.67479 .5655 m .66897 .5653 L .67114 .56911 L p F P
0 g
s
.451 .659 .95 r
.66218 .56512 m .66897 .5653 L .67114 .56911 L p F P
0 g
s
0 0 .483 r
.83194 .73501 m .83136 .73918 L .83331 .74458 L p F P
0 g
s
0 0 .548 r
.83136 .73918 m .83194 .73501 L .82947 .72977 L p F P
0 g
s
0 .057 .622 r
.62696 .68413 m .62776 .68814 L .63153 .69282 L p F P
0 g
s
0 .097 .65 r
.6234 .67941 m .62696 .68413 L .62776 .68814 L p F P
0 g
s
.183 .343 .791 r
.6557 .73914 m .656 .73578 L p .66153 .74419 L F P
0 g
s
.157 .322 .78 r
.6557 .73914 m .6532 .73366 L .656 .73578 L closepath p F P
0 g
s
.963 .641 .259 r
.58865 .59933 m .5913 .60298 L .59195 .60842 L p F P
0 g
s
.983 .696 .357 r
.5913 .60298 m .58865 .59933 L .58852 .59374 L p F P
0 g
s
0 .015 .59 r
.62245 .67542 m .6234 .67941 L .62696 .68413 L p F P
0 g
s
0 .041 .61 r
.61909 .67067 m .62245 .67542 L .6234 .67941 L p F P
0 g
s
.555 .723 .952 r
.62823 .55629 m .64065 .55449 L .64367 .55816 L p F P
0 g
s
.556 .725 .953 r
.64065 .55449 m .62823 .55629 L .62519 .55268 L p F P
0 g
s
.489 .608 .897 r
.73462 .82141 m .72855 .82105 L .72558 .81619 L p F P
0 g
s
.55 .674 .92 r
.75459 .82982 m .74716 .83043 L .74425 .8262 L p F P
0 g
s
.341 .569 .923 r
.71939 .59338 m .71799 .59308 L .71507 .58888 L p F P
0 g
s
.355 .475 .844 r
.68553 .78132 m .69416 .78487 L .69319 .78912 L p F P
0 g
s
.293 .455 .851 r
.68664 .777 m .68553 .78132 L .69416 .78487 L p F P
0 g
s
.338 .462 .839 r
.68168 .7748 m .68664 .777 L .68553 .78132 L p F P
0 g
s
.411 .552 .886 r
.72057 .81531 m .72558 .81619 L .72261 .81125 L p F P
0 g
s
.411 .552 .886 r
.72261 .81125 m .72177 .81108 L .72057 .81531 L p F P
0 g
s
.45 .662 .952 r
.66897 .5653 m .66218 .56512 L .65919 .56135 L p F P
0 g
s
0 0 .551 r
.61798 .6667 m .61909 .67067 L .62245 .67542 L p F P
0 g
s
0 0 .558 r
.61494 .66206 m .61798 .6667 L .61909 .67067 L p F P
0 g
s
0 0 .222 r
.83432 .76321 m .83407 .76422 L .83427 .77014 L p F P
0 g
s
.248 .452 .863 r
.77763 .63901 m .77218 .63643 L p .78028 .64406 L F P
0 g
s
.225 .44 .86 r
.77218 .63643 m .77763 .63901 L .77472 .63389 L p F P
0 g
s
.225 .44 .86 r
.77472 .63389 m .77149 .63236 L .77218 .63643 L p F P
0 g
s
0 0 .414 r
.61494 .66206 m .61485 .66189 L .61476 .66167 L closepath p F P
0 g
s
0 0 .36 r
.61176 .65495 m .61083 .65305 L p .61485 .66189 L F P
0 g
s
0 0 .36 r
.61485 .66189 m .61476 .66167 L .61176 .65495 L p F P
0 g
s
.981 .69 .373 r
.58568 .59013 m .58852 .59374 L .58865 .59933 L p F P
0 g
s
.986 .738 .473 r
.58852 .59374 m .58568 .59013 L .58622 .58435 L p F P
0 g
s
0 0 .532 r
.61798 .6667 m .61494 .66206 L .61476 .66167 L p F P
0 g
s
.082 .275 .761 r
.81163 .68499 m .80883 .68254 L .80653 .67741 L p F P
0 g
s
0 0 .548 r
.82996 .7256 m .82947 .72977 L .83194 .73501 L p F P
0 g
s
0 .058 .6 r
.82947 .72977 m .82996 .7256 L .82701 .72051 L p F P
0 g
s
.294 .511 .895 r
.75347 .61763 m .75248 .6136 L .74335 .61062 L p F P
0 g
s
.304 .524 .902 r
.74215 .60663 m .74335 .61062 L .75248 .6136 L p F P
0 g
s
.3 .524 .903 r
.73676 .60499 m .74215 .60663 L .74335 .61062 L p F P
0 g
s
0 0 .532 r
.61476 .66167 m .61355 .65796 L p .61798 .6667 L F P
0 g
s
0 0 .487 r
.61476 .66167 m .61176 .65495 L .61355 .65796 L closepath p F P
0 g
s
.252 .476 .881 r
.76278 .6249 m .75855 .62321 L .75565 .61842 L p F P
0 g
s
.826 .935 .564 r
.82832 .79574 m .82762 .79775 L .82373 .80481 L p F P
0 g
s
0 0 .332 r
.61176 .65495 m .61083 .65305 L .60967 .65053 L closepath p F P
0 g
s
.666 .309 0 r
.60859 .64813 m .60686 .64419 L p .61083 .65305 L F P
0 g
s
.666 .309 0 r
.61083 .65305 m .60967 .65053 L .60859 .64813 L p F P
0 g
s
.33 .554 .916 r
.71939 .59338 m .72988 .59589 L .73123 .59986 L p F P
0 g
s
.349 .571 .923 r
.7178 .58947 m .71939 .59338 L .72988 .59589 L p F P
0 g
s
.341 .569 .923 r
.71507 .58888 m .7178 .58947 L .71939 .59338 L p F P
0 g
s
.338 .486 .86 r
.7007 .79203 m .69319 .78912 L p .70136 .7968 L F P
0 g
s
.317 .459 .845 r
.69319 .78912 m .7007 .79203 L .69765 .78635 L p F P
0 g
s
.317 .459 .845 r
.69765 .78635 m .69416 .78487 L .69319 .78912 L p F P
0 g
s
.416 .536 .87 r
.71089 .80411 m .70676 .80317 L .70374 .79763 L p F P
0 g
s
0 0 0 r
.8337 .77628 m .83257 .78051 L .83119 .78688 L p F P
0 g
s
0 0 .072 r
.83257 .78051 m .8337 .77628 L .83427 .77014 L p F P
0 g
s
.148 .32 .782 r
.656 .73578 m .6532 .73366 L .65061 .72805 L p F P
0 g
s
.698 .326 0 r
.60686 .64419 m .60859 .64813 L .60541 .64152 L p F P
0 g
s
.698 .326 0 r
.60541 .64152 m .60493 .64041 L .60686 .64419 L p F P
0 g
s
.745 .38 0 r
.60686 .64419 m .60493 .64041 L .60297 .6353 L p F P
0 g
s
.208 .416 .846 r
.78053 .64419 m .78028 .64406 L .78023 .64364 L closepath p F P
0 g
s
.248 .452 .863 r
.78028 .64406 m .78023 .64364 L .77763 .63901 L p F P
0 g
s
0 0 .222 r
.83427 .77014 m .83461 .7688 L .83432 .76321 L p F P
0 g
s
0 0 .181 r
.8349 .76004 m .83432 .76321 L .83461 .7688 L p F P
0 g
s
0 0 .308 r
.83432 .76321 m .8349 .76004 L .83405 .75431 L p F P
0 g
s
.98 .73 .482 r
.58319 .58078 m .58622 .58435 L .58568 .59013 L p F P
0 g
s
.969 .769 .578 r
.58622 .58435 m .58319 .58078 L .58463 .57472 L p F P
0 g
s
.495 .694 .957 r
.64525 .55808 m .64367 .55816 L .64065 .55449 L p F P
0 g
s
.295 .525 .905 r
.74215 .60663 m .73676 .60499 L .73384 .60055 L p F P
0 g
s
0 .058 .602 r
.82739 .71635 m .82701 .72051 L .82996 .7256 L p F P
0 g
s
0 .113 .643 r
.82701 .72051 m .82739 .71635 L .82398 .71141 L p F P
0 g
s
.189 .4 .838 r
.78053 .64419 m .78703 .64787 L .78757 .65194 L p F P
0 g
s
.179 .397 .838 r
.78703 .64787 m .78053 .64419 L .78023 .64364 L p F P
0 g
s
.742 .895 .948 r
.7934 .83107 m .7936 .83096 L .79354 .83118 L closepath p F P
0 g
s
.786 .911 .926 r
.80575 .82363 m .7936 .83096 L .79354 .83118 L p F P
0 g
s
.785 .409 0 r
.60087 .63156 m .60297 .6353 L .60493 .64041 L p F P
0 g
s
.815 .45 0 r
.60297 .6353 m .60087 .63156 L .59917 .62639 L p F P
0 g
s
.315 .448 .837 r
.68664 .777 m .68168 .7748 L .67929 .77001 L p F P
0 g
s
.725 .876 .951 r
.7936 .83096 m .7934 .83107 L .7907 .82881 L p F P
0 g
s
.66 .856 .975 r
.77815 .83343 m .7907 .82881 L .7934 .83107 L p F P
0 g
s
.725 .876 .951 r
.7907 .82881 m .79455 .82687 L .7936 .83096 L p F P
0 g
s
.751 .938 .946 r
.80314 .82217 m .79455 .82687 L .7936 .83096 L p F P
0 g
s
.751 .938 .946 r
.7936 .83096 m .80575 .82363 L .80314 .82217 L p F P
0 g
s
.179 .397 .838 r
.78023 .64364 m .77961 .64001 L p .78703 .64787 L F P
0 g
s
.205 .424 .853 r
.78023 .64364 m .77763 .63901 L .77961 .64001 L closepath p F P
0 g
s
0 0 .3 r
.83473 .75014 m .83405 .75431 L .8349 .76004 L p F P
0 g
s
0 0 .404 r
.83405 .75431 m .83473 .75014 L .83331 .74458 L p F P
0 g
s
.593 .772 .966 r
.76272 .83306 m .77538 .8304 L .77815 .83343 L p F P
0 g
s
.577 .753 .961 r
.77538 .8304 m .76272 .83306 L .75988 .82941 L p F P
0 g
s
.343 .491 .863 r
.70374 .79763 m .70136 .7968 L .7019 .79425 L closepath p F P
0 g
s
.338 .486 .86 r
.70136 .7968 m .7019 .79425 L .7007 .79203 L p F P
0 g
s
.174 .379 .825 r
.79437 .65997 m .794 .65587 L .78757 .65194 L p F P
0 g
s
.171 .382 .828 r
.78703 .64787 m .78757 .65194 L .794 .65587 L p F P
0 g
s
.845 .47 0 r
.59689 .62267 m .59917 .62639 L .60087 .63156 L p F P
0 g
s
.878 .518 .029 r
.59917 .62639 m .59689 .62267 L .59548 .61743 L p F P
0 g
s
.082 .275 .761 r
.80653 .67741 m .80649 .67647 L p .81163 .68499 L F P
0 g
s
.114 .311 .783 r
.80653 .67741 m .80585 .67598 L .80649 .67647 L closepath p F P
0 g
s
0 .114 .645 r
.82424 .70726 m .82398 .71141 L .82739 .71635 L p F P
0 g
s
0 .161 .679 r
.82398 .71141 m .82424 .70726 L .82039 .70245 L p F P
0 g
s
.493 .692 .957 r
.64525 .55808 m .65619 .55761 L .65318 .55391 L p F P
0 g
s
.493 .692 .957 r
.65318 .55391 m .64255 .55439 L .64525 .55808 L p F P
0 g
s
.495 .694 .957 r
.64065 .55449 m .64255 .55439 L .64525 .55808 L p F P
0 g
s
0 0 .461 r
.61355 .65796 m .61176 .65495 L .60967 .65053 L p F P
0 g
s
.274 .494 .888 r
.75347 .61763 m .75565 .61842 L .75274 .6137 L p F P
0 g
s
.274 .494 .888 r
.75274 .6137 m .75248 .6136 L .75347 .61763 L p F P
0 g
s
.365 .593 .933 r
.70459 .58342 m .71214 .58472 L .7092 .58062 L p F P
0 g
s
.365 .593 .933 r
.7092 .58062 m .7028 .57953 L .70459 .58342 L p F P
0 g
s
.373 .599 .935 r
.69638 .57853 m .7028 .57953 L .70459 .58342 L p F P
0 g
s
.895 .98 .695 r
.82373 .80481 m .81835 .81228 L .81819 .81284 L p F P
0 g
s
.876 .989 .729 r
.82513 .80056 m .82373 .80481 L .81835 .81228 L p F P
0 g
s
.826 .935 .564 r
.82714 .79716 m .82832 .79574 L p .82373 .80481 L F P
0 g
s
.826 .935 .564 r
.82373 .80481 m .82513 .80056 L .82714 .79716 L p F P
0 g
s
.897 .531 .067 r
.59302 .61375 m .59548 .61743 L .59689 .62267 L p F P
0 g
s
.928 .583 .143 r
.59548 .61743 m .59302 .61375 L .59195 .60842 L p F P
0 g
s
.642 .832 .974 r
.7907 .82881 m .77815 .83343 L .77538 .8304 L p F P
0 g
s
.172 .368 .816 r
.79994 .66366 m .79437 .65997 L p .8007 .66814 L F P
0 g
s
.146 .353 .811 r
.79437 .65997 m .79994 .66366 L .79701 .65788 L p F P
0 g
s
.146 .353 .811 r
.79701 .65788 m .794 .65587 L .79437 .65997 L p F P
0 g
s
.107 .31 .784 r
.80649 .67647 m .80585 .67598 L .80289 .66977 L p F P
0 g
s
.148 .32 .782 r
.65061 .72805 m .65064 .72732 L p .656 .73578 L F P
0 g
s
.12 .297 .769 r
.65061 .72805 m .65006 .72685 L .65064 .72732 L closepath p F P
0 g
s
0 .162 .682 r
.82053 .69832 m .82039 .70245 L .82424 .70726 L p F P
0 g
s
.023 .202 .71 r
.82039 .70245 m .82053 .69832 L .81627 .69365 L p F P
0 g
s
.489 .608 .897 r
.72558 .81619 m .73592 .81717 L .73462 .82141 L p F P
0 g
s
.471 .595 .895 r
.73592 .81717 m .72558 .81619 L .72261 .81125 L p F P
0 g
s
.371 .601 .937 r
.7028 .57953 m .69638 .57853 L .69343 .57453 L p F P
0 g
s
.111 .295 .77 r
.65064 .72732 m .65006 .72685 L .64692 .72005 L p F P
0 g
s
.125 .324 .792 r
.80289 .66977 m .8007 .66814 L .80053 .66485 L closepath p F P
0 g
s
.172 .368 .816 r
.8007 .66814 m .80053 .66485 L .79994 .66366 L p F P
0 g
s
.41 .63 .945 r
.67776 .56936 m .68605 .57012 L .68808 .57396 L p F P
0 g
s
.408 .633 .947 r
.68605 .57012 m .67776 .56936 L .67479 .5655 L p F P
0 g
s
.018 .203 .712 r
.81628 .68953 m .81627 .69365 L .82053 .69832 L p F P
0 g
s
.051 .237 .734 r
.81163 .68499 m .81628 .68953 L .81627 .69365 L p F P
0 g
s
.459 .602 .906 r
.73462 .82141 m .74134 .82186 L .7384 .81743 L p F P
0 g
s
.459 .602 .906 r
.7384 .81743 m .73592 .81717 L .73462 .82141 L p F P
0 g
s
.938 .588 .172 r
.5893 .60478 m .59195 .60842 L .59302 .61375 L p F P
0 g
s
.963 .641 .259 r
.59195 .60842 m .5893 .60478 L .58865 .59933 L p F P
0 g
s
.623 .756 .942 r
.60979 .55245 m .62213 .54908 L .62519 .55268 L p F P
0 g
s
.321 .545 .913 r
.73123 .59986 m .73384 .60055 L .73093 .59616 L p F P
0 g
s
.321 .545 .913 r
.73093 .59616 m .72988 .59589 L .73123 .59986 L p F P
0 g
s
.867 .996 .781 r
.81786 .81286 m .81835 .81228 L .81819 .81284 L closepath p F P
0 g
s
.082 .275 .761 r
.80649 .67647 m .8115 .68088 L .81163 .68499 L p F P
0 g
s
.067 .272 .761 r
.80622 .67238 m .80649 .67647 L .8115 .68088 L p F P
0 g
s
.107 .31 .784 r
.80289 .66977 m .80622 .67238 L .80649 .67647 L p F P
0 g
s
.522 .675 .934 r
.75459 .82982 m .75988 .82941 L .75701 .82562 L p F P
0 g
s
.522 .675 .934 r
.75701 .82562 m .75565 .82568 L .75459 .82982 L p F P
0 g
s
.55 .674 .92 r
.74425 .8262 m .75565 .82568 L .75459 .82982 L p F P
0 g
s
.044 .24 .739 r
.8115 .68088 m .81163 .68499 L .81628 .68953 L p F P
0 g
s
.835 .9 .485 r
.82714 .79716 m .82887 .79352 L .82832 .79574 L closepath p F P
0 g
s
.806 .817 .335 r
.83119 .78688 m .82887 .79352 L .82832 .79574 L p F P
0 g
s
0 0 .065 r
.83461 .7688 m .83427 .77014 L .8337 .77628 L p F P
0 g
s
0 0 .483 r
.83331 .74458 m .83392 .74041 L .83194 .73501 L p F P
0 g
s
0 0 .401 r
.83392 .74041 m .83331 .74458 L .83473 .75014 L p F P
0 g
s
.533 .659 .917 r
.75565 .82568 m .74425 .8262 L .74134 .82186 L p F P
0 g
s
.428 .546 .874 r
.71089 .80411 m .71962 .8062 L p .72177 .81108 L F P
0 g
s
.384 .522 .872 r
.71089 .80411 m .71962 .8062 L .71661 .80107 L p F P
0 g
s
.384 .522 .872 r
.71661 .80107 m .71211 .79983 L .71089 .80411 L p F P
0 g
s
.416 .536 .87 r
.70374 .79763 m .71211 .79983 L .71089 .80411 L p F P
0 g
s
.295 .434 .831 r
.67929 .77001 m .67859 .76858 L .67951 .76903 L closepath p F P
0 g
s
.315 .448 .837 r
.67929 .77001 m .67951 .76903 L p .68664 .777 L F P
0 g
s
.397 .523 .868 r
.71211 .79983 m .70374 .79763 L .7019 .79425 L p F P
0 g
s
.337 .571 .926 r
.7178 .58947 m .71507 .58888 L .71214 .58472 L p F P
0 g
s
.405 .626 .943 r
.68808 .57396 m .69343 .57453 L .69047 .57057 L p F P
0 g
s
.405 .626 .943 r
.69047 .57057 m .68605 .57012 L .68808 .57396 L p F P
0 g
s
.056 .27 .763 r
.65061 .72318 m .65064 .72732 L .65605 .73163 L p F P
0 g
s
.111 .295 .77 r
.64692 .72005 m .65061 .72318 L .65064 .72732 L p F P
0 g
s
.148 .32 .782 r
.65064 .72732 m .65605 .73163 L .656 .73578 L p F P
0 g
s
0 .197 .72 r
.64692 .72005 m .64565 .71876 L .64539 .7168 L closepath p F P
0 g
s
0 .176 .706 r
.64378 .71331 m .64086 .71014 L p .64565 .71876 L F P
0 g
s
0 .176 .706 r
.64565 .71876 m .64539 .7168 L .64378 .71331 L p F P
0 g
s
.183 .343 .791 r
.656 .73578 m .66163 .74005 L .66153 .74419 L p F P
0 g
s
.078 .288 .773 r
.65605 .73163 m .656 .73578 L .66163 .74005 L p F P
0 g
s
0 0 0 r
.83119 .78688 m .83228 .78268 L .8337 .77628 L p F P
0 g
s
.785 .821 .345 r
.83228 .78268 m .83119 .78688 L .82887 .79352 L p F P
0 g
s
0 0 .461 r
.60967 .65053 m .60916 .64921 L p .61355 .65796 L F P
0 g
s
0 0 .406 r
.60967 .65053 m .60859 .64813 L .60916 .64921 L closepath p F P
0 g
s
.448 .659 .951 r
.66897 .5653 m .67479 .5655 L .67181 .56168 L p F P
0 g
s
.448 .659 .951 r
.67181 .56168 m .66665 .56152 L .66897 .5653 L p F P
0 g
s
.45 .662 .952 r
.65919 .56135 m .66665 .56152 L .66897 .5653 L p F P
0 g
s
0 .144 .685 r
.64086 .71014 m .64378 .71331 L .64063 .70668 L p F P
0 g
s
0 .144 .685 r
.64063 .70668 m .64015 .70615 L .64086 .71014 L p F P
0 g
s
0 .128 .674 r
.64086 .71014 m .64015 .70615 L .63615 .70149 L p F P
0 g
s
.243 .461 .871 r
.77149 .63236 m .7707 .62831 L .76278 .6249 L p F P
0 g
s
.252 .474 .879 r
.7618 .62089 m .76278 .6249 L .7707 .62831 L p F P
0 g
s
.252 .476 .881 r
.75565 .61842 m .7618 .62089 L .76278 .6249 L p F P
0 g
s
.965 .64 .28 r
.58581 .59573 m .58865 .59933 L .5893 .60478 L p F P
0 g
s
.981 .69 .373 r
.58865 .59933 m .58581 .59573 L .58568 .59013 L p F P
0 g
s
.8 .956 .917 r
.80942 .82071 m .80575 .82363 L .80314 .82217 L p F P
0 g
s
.15 .333 .792 r
.66724 .75255 m .66738 .74842 L .66153 .74419 L p F P
0 g
s
.116 .318 .789 r
.66163 .74005 m .66153 .74419 L .66738 .74842 L p F P
0 g
s
.556 .725 .953 r
.62519 .55268 m .63762 .55085 L .64065 .55449 L p F P
0 g
s
.555 .727 .954 r
.63762 .55085 m .62519 .55268 L .62213 .54908 L p F P
0 g
s
.245 .476 .882 r
.7618 .62089 m .75565 .61842 L .75274 .6137 L p F P
0 g
s
.866 .993 .815 r
.81835 .81228 m .81786 .81286 L .81538 .81259 L p F P
0 g
s
.866 .993 .815 r
.81538 .81259 m .81946 .80812 L .81835 .81228 L p F P
0 g
s
.876 .989 .729 r
.81835 .81228 m .81946 .80812 L .82513 .80056 L p F P
0 g
s
0 .106 .66 r
.63533 .69751 m .63615 .70149 L .64015 .70615 L p F P
0 g
s
0 .094 .65 r
.63615 .70149 m .63533 .69751 L .63153 .69282 L p F P
0 g
s
.45 .665 .954 r
.66665 .56152 m .65919 .56135 L .65619 .55761 L p F P
0 g
s
.821 .997 .848 r
.80942 .82071 m .81786 .81286 L .81538 .81259 L p F P
0 g
s
.295 .434 .831 r
.67951 .76903 m .67859 .76858 L .67549 .76232 L p F P
0 g
s
.183 .361 .807 r
.67239 .75606 m .66724 .75255 L p .67317 .76084 L F P
0 g
s
.152 .334 .793 r
.66724 .75255 m .67239 .75606 L .66928 .74979 L p F P
0 g
s
.152 .334 .793 r
.66928 .74979 m .66738 .74842 L .66724 .75255 L p F P
0 g
s
.8 .956 .917 r
.80314 .82217 m .81081 .81648 L .80942 .82071 L p F P
0 g
s
.821 .997 .848 r
.81538 .81259 m .81081 .81648 L .80942 .82071 L p F P
0 g
s
0 .051 .618 r
.63058 .68886 m .63153 .69282 L .63533 .69751 L p F P
0 g
s
0 .057 .622 r
.63153 .69282 m .63058 .68886 L .62696 .68413 L p F P
0 g
s
.193 .371 .812 r
.67549 .76232 m .67317 .76084 L .67332 .75796 L closepath p F P
0 g
s
.183 .361 .807 r
.67317 .76084 m .67332 .75796 L .67239 .75606 L p F P
0 g
s
0 .012 .587 r
.62588 .68019 m .62696 .68413 L .63058 .68886 L p F P
0 g
s
0 .015 .59 r
.62696 .68413 m .62588 .68019 L .62245 .67542 L p F P
0 g
s
0 0 .374 r
.60916 .64921 m .60859 .64813 L .60541 .64152 L p F P
0 g
s
.199 .424 .854 r
.77961 .64001 m .77763 .63901 L .77472 .63389 L p F P
0 g
s
0 0 .55 r
.62122 .6715 m .62245 .67542 L .62588 .68019 L p F P
0 g
s
0 0 .551 r
.62245 .67542 m .62122 .6715 L .61798 .6667 L p F P
0 g
s
.977 .684 .387 r
.58265 .58657 m .58568 .59013 L .58581 .59573 L p F P
0 g
s
.98 .73 .482 r
.58568 .59013 m .58265 .58657 L .58319 .58078 L p F P
0 g
s
0 0 .484 r
.83246 .73084 m .83194 .73501 L .83392 .74041 L p F P
0 g
s
0 0 .548 r
.83194 .73501 m .83246 .73084 L .82996 .7256 L p F P
0 g
s
.315 .448 .837 r
.67951 .76903 m .68731 .77279 L .68664 .777 L p F P
0 g
s
.238 .414 .835 r
.68026 .76478 m .67951 .76903 L .68731 .77279 L p F P
0 g
s
.295 .434 .831 r
.67549 .76232 m .68026 .76478 L .67951 .76903 L p F P
0 g
s
0 0 .507 r
.61659 .6628 m .61798 .6667 L .62122 .6715 L p F P
0 g
s
0 0 .532 r
.61355 .65796 m .61659 .6628 L .61798 .6667 L p F P
0 g
s
.295 .525 .905 r
.73384 .60055 m .74084 .60266 L .74215 .60663 L p F P
0 g
s
.29 .526 .907 r
.74084 .60266 m .73384 .60055 L .73093 .59616 L p F P
0 g
s
0 0 .456 r
.612 .65409 m .61355 .65796 L .61659 .6628 L p F P
0 g
s
0 0 .461 r
.60916 .64921 m .612 .65409 L .61355 .65796 L p F P
0 g
s
0 0 .065 r
.8337 .77628 m .83435 .77376 L .83461 .7688 L p F P
0 g
s
0 0 .181 r
.83461 .7688 m .83512 .76596 L .8349 .76004 L p F P
0 g
s
0 0 .026 r
.83512 .76596 m .83461 .7688 L .83435 .77376 L p F P
0 g
s
.075 .277 .764 r
.65061 .72318 m .64692 .72005 L .64539 .7168 L p F P
0 g
s
.218 .44 .862 r
.77149 .63236 m .77472 .63389 L .77182 .62884 L p F P
0 g
s
.218 .44 .862 r
.77182 .62884 m .7707 .62831 L .77149 .63236 L p F P
0 g
s
.095 .304 .782 r
.80622 .67238 m .80289 .66977 L .80053 .66485 L p F P
0 g
s
.397 .523 .868 r
.7019 .79425 m .70244 .79254 L p .71211 .79983 L F P
0 g
s
.382 .512 .865 r
.7019 .79425 m .7007 .79203 L .70244 .79254 L closepath p F P
0 g
s
.304 .524 .902 r
.74984 .60913 m .74215 .60663 L p .75248 .6136 L F P
0 g
s
.281 .515 .901 r
.74215 .60663 m .74984 .60913 L .74693 .60463 L p F P
0 g
s
.281 .515 .901 r
.74693 .60463 m .74084 .60266 L .74215 .60663 L p F P
0 g
s
0 0 .395 r
.60744 .64537 m .60916 .64921 L .612 .65409 L p F P
0 g
s
0 0 .374 r
.60541 .64152 m .60744 .64537 L .60916 .64921 L p F P
0 g
s
0 0 .168 r
.83558 .75588 m .8349 .76004 L .83512 .76596 L p F P
0 g
s
0 0 .3 r
.8349 .76004 m .83558 .75588 L .83473 .75014 L p F P
0 g
s
.349 .571 .923 r
.72801 .59185 m .7178 .58947 L p .72988 .59589 L F P
0 g
s
.326 .563 .923 r
.7178 .58947 m .72801 .59185 L .72508 .58765 L p F P
0 g
s
.326 .563 .923 r
.72508 .58765 m .71609 .58557 L .7178 .58947 L p F P
0 g
s
.337 .571 .926 r
.71214 .58472 m .71609 .58557 L .7178 .58947 L p F P
0 g
s
.274 .429 .835 r
.68664 .777 m .69459 .78067 L .69152 .77489 L p F P
0 g
s
.274 .429 .835 r
.69152 .77489 m .68731 .77279 L .68664 .777 L p F P
0 g
s
.293 .455 .851 r
.69459 .78067 m .68664 .777 L p .69416 .78487 L F P
0 g
s
.495 .696 .958 r
.64255 .55439 m .64065 .55449 L .63762 .55085 L p F P
0 g
s
.406 .555 .891 r
.72261 .81125 m .72177 .81108 L .72197 .81019 L closepath p F P
0 g
s
.428 .546 .874 r
.71962 .8062 m .72197 .81019 L .72177 .81108 L p F P
0 g
s
.732 .346 0 r
.60541 .64152 m .60493 .64041 L .60393 .63866 L closepath p F P
0 g
s
.785 .409 0 r
.60224 .63518 m .60087 .63156 L p .60493 .64041 L F P
0 g
s
.785 .409 0 r
.60493 .64041 m .60393 .63866 L .60224 .63518 L p F P
0 g
s
.577 .753 .961 r
.75988 .82941 m .77258 .8272 L .77538 .8304 L p F P
0 g
s
.561 .735 .957 r
.77258 .8272 m .75988 .82941 L .75701 .82562 L p F P
0 g
s
0 0 .556 r
.83038 .72144 m .82996 .7256 L .83246 .73084 L p F P
0 g
s
0 .058 .602 r
.82996 .7256 m .83038 .72144 L .82739 .71635 L p F P
0 g
s
.804 .417 0 r
.60087 .63156 m .60224 .63518 L .59908 .62922 L p F P
0 g
s
.804 .417 0 r
.59908 .62922 m .59856 .62785 L .60087 .63156 L p F P
0 g
s
.845 .47 0 r
.60087 .63156 m .59856 .62785 L .59689 .62267 L p F P
0 g
s
.446 .578 .892 r
.7325 .80822 m .73546 .81288 L .72261 .81125 L p F P
0 g
s
.446 .578 .892 r
.72326 .80674 m .7325 .80822 L p .72261 .81125 L F P
0 g
s
.446 .578 .892 r
.72261 .81125 m .72197 .81019 L .72326 .80674 L p F P
0 g
s
.471 .595 .895 r
.72261 .81125 m .73546 .81288 L p .73592 .81717 L F P
0 g
s
.046 .251 .749 r
.64539 .7168 m .64378 .71331 L .64529 .71469 L closepath p F P
0 g
s
.075 .277 .764 r
.64539 .7168 m .64529 .71469 L p .65061 .72318 L F P
0 g
s
.179 .397 .838 r
.77961 .64001 m .7864 .64381 L .78703 .64787 L p F P
0 g
s
.176 .402 .843 r
.77881 .63598 m .77961 .64001 L .7864 .64381 L p F P
0 g
s
.199 .424 .854 r
.77472 .63389 m .77881 .63598 L .77961 .64001 L p F P
0 g
s
.894 .929 .549 r
.82887 .79352 m .82986 .78935 L p .8259 .79823 L F P
0 g
s
.894 .929 .549 r
.8259 .79823 m .82714 .79716 L .82887 .79352 L p F P
0 g
s
.785 .821 .345 r
.82887 .79352 m .82986 .78935 L .83228 .78268 L p F P
0 g
s
.383 .511 .863 r
.70244 .79254 m .7007 .79203 L .69765 .78635 L p F P
0 g
s
.3 .462 .854 r
.69765 .78635 m .69416 .78487 L .69469 .78085 L closepath p F P
0 g
s
.293 .455 .851 r
.69416 .78487 m .69469 .78085 L .69459 .78067 L p F P
0 g
s
.707 .865 .957 r
.79455 .82687 m .7907 .82881 L .78798 .82632 L p F P
0 g
s
.642 .832 .974 r
.77538 .8304 m .78798 .82632 L .7907 .82881 L p F P
0 g
s
.269 .42 .829 r
.68026 .76478 m .67549 .76232 L .67332 .75796 L p F P
0 g
s
0 0 0 r
.83435 .77376 m .8337 .77628 L .83228 .78268 L p F P
0 g
s
.872 .493 .014 r
.5944 .619 m .59689 .62267 L .59856 .62785 L p F P
0 g
s
.897 .531 .067 r
.59689 .62267 m .5944 .619 L .59302 .61375 L p F P
0 g
s
.492 .694 .958 r
.64255 .55439 m .65318 .55391 L .65016 .55024 L p F P
0 g
s
.492 .694 .958 r
.65016 .55024 m .63972 .55073 L .64255 .55439 L p F P
0 g
s
.495 .696 .958 r
.63762 .55085 m .63972 .55073 L .64255 .55439 L p F P
0 g
s
0 0 .335 r
.60744 .64537 m .60541 .64152 L .60393 .63866 L p F P
0 g
s
0 .061 .606 r
.82769 .71219 m .82739 .71635 L .83038 .72144 L p F P
0 g
s
0 .114 .645 r
.82739 .71635 m .82769 .71219 L .82424 .70726 L p F P
0 g
s
.443 .574 .89 r
.72197 .81019 m .71962 .8062 L .72326 .80674 L closepath p F P
0 g
s
.533 .659 .917 r
.74134 .82186 m .75413 .82168 L p .75565 .82568 L F P
0 g
s
.489 .655 .933 r
.75413 .82168 m .74134 .82186 L .7384 .81743 L p F P
0 g
s
.625 .81 .971 r
.78798 .82632 m .77538 .8304 L .77258 .8272 L p F P
0 g
s
.371 .601 .937 r
.69343 .57453 m .70088 .57567 L .7028 .57953 L p F P
0 g
s
.368 .604 .939 r
.70088 .57567 m .69343 .57453 L .69047 .57057 L p F P
0 g
s
.911 .54 .099 r
.59035 .61012 m .59302 .61375 L .5944 .619 L p F P
0 g
s
.938 .588 .172 r
.59302 .61375 m .59035 .61012 L .5893 .60478 L p F P
0 g
s
.171 .382 .828 r
.794 .65587 m .79353 .65178 L .78703 .64787 L p F P
0 g
s
.175 .393 .836 r
.7864 .64381 m .78703 .64787 L .79353 .65178 L p F P
0 g
s
.363 .595 .935 r
.7028 .57953 m .7092 .58062 L .70626 .57657 L p F P
0 g
s
.363 .595 .935 r
.70626 .57657 m .70088 .57567 L .7028 .57953 L p F P
0 g
s
.408 .633 .947 r
.67479 .5655 m .68388 .5663 L .68605 .57012 L p F P
0 g
s
.407 .636 .949 r
.68388 .5663 m .67479 .5655 L .67181 .56168 L p F P
0 g
s
.095 .304 .782 r
.80053 .66485 m .80046 .66403 L p .80622 .67238 L F P
0 g
s
.127 .338 .803 r
.80053 .66485 m .79994 .66366 L .80046 .66403 L closepath p F P
0 g
s
0 0 .296 r
.83536 .74597 m .83473 .75014 L .83558 .75588 L p F P
0 g
s
0 0 .401 r
.83473 .75014 m .83536 .74597 L .83392 .74041 L p F P
0 g
s
.268 .495 .891 r
.75274 .6137 m .75248 .6136 L .75232 .61302 L closepath p F P
0 g
s
.304 .524 .902 r
.75248 .6136 m .75232 .61302 L .74984 .60913 L p F P
0 g
s
.029 .247 .749 r
.64529 .71469 m .64378 .71331 L .64063 .70668 L p F P
0 g
s
.707 .865 .957 r
.78798 .82632 m .79591 .82266 L .79455 .82687 L p F P
0 g
s
.735 .914 .954 r
.8005 .82039 m .79591 .82266 L .79455 .82687 L p F P
0 g
s
.735 .914 .954 r
.79455 .82687 m .80314 .82217 L .8005 .82039 L p F P
0 g
s
.827 .936 .565 r
.82513 .80056 m .8259 .79823 L .82714 .79716 L closepath p F P
0 g
s
.245 .476 .882 r
.75274 .6137 m .76071 .61689 L .7618 .62089 L p F P
0 g
s
.237 .476 .884 r
.76071 .61689 m .75274 .6137 L .75232 .61302 L p F P
0 g
s
.334 .573 .928 r
.71609 .58557 m .71214 .58472 L .7092 .58062 L p F P
0 g
s
0 .117 .65 r
.82442 .70311 m .82424 .70726 L .82769 .71219 L p F P
0 g
s
0 .162 .682 r
.82424 .70726 m .82442 .70311 L .82053 .69832 L p F P
0 g
s
.944 .591 .198 r
.58646 .60118 m .5893 .60478 L .59035 .61012 L p F P
0 g
s
.965 .64 .28 r
.5893 .60478 m .58646 .60118 L .58581 .59573 L p F P
0 g
s
.397 .523 .868 r
.70244 .79254 m .71284 .79567 L .71211 .79983 L p F P
0 g
s
.344 .508 .877 r
.70352 .78826 m .70244 .79254 L .71284 .79567 L p F P
0 g
s
.383 .511 .863 r
.69765 .78635 m .70352 .78826 L .70244 .79254 L p F P
0 g
s
.119 .337 .804 r
.80046 .66403 m .79994 .66366 L .79701 .65788 L p F P
0 g
s
.135 .35 .811 r
.794 .65587 m .79701 .65788 L .79407 .65214 L p F P
0 g
s
.135 .35 .811 r
.79407 .65214 m .79353 .65178 L .794 .65587 L p F P
0 g
s
.191 .422 .855 r
.77881 .63598 m .77472 .63389 L .77182 .62884 L p F P
0 g
s
0 0 .335 r
.60393 .63866 m .60291 .63664 L p .60744 .64537 L F P
0 g
s
.674 .301 0 r
.60393 .63866 m .60224 .63518 L .60291 .63664 L closepath p F P
0 g
s
.237 .476 .884 r
.75232 .61302 m .75123 .60963 L p .76071 .61689 L F P
0 g
s
.26 .497 .893 r
.75232 .61302 m .74984 .60913 L .75123 .60963 L closepath p F P
0 g
s
.316 .547 .915 r
.73093 .59616 m .72988 .59589 L .72882 .59303 L closepath p F P
0 g
s
.349 .571 .923 r
.72988 .59589 m .72882 .59303 L .72801 .59185 L p F P
0 g
s
0 .168 .688 r
.82058 .69418 m .82053 .69832 L .82442 .70311 L p F P
0 g
s
.018 .203 .712 r
.82053 .69832 m .82058 .69418 L .81628 .68953 L p F P
0 g
s
.555 .727 .954 r
.62213 .54908 m .63458 .54722 L .63762 .55085 L p F P
0 g
s
.45 .665 .954 r
.65619 .55761 m .66418 .55777 L .66665 .56152 L p F P
0 g
s
.449 .668 .956 r
.66418 .55777 m .65619 .55761 L .65318 .55391 L p F P
0 g
s
.269 .42 .829 r
.67332 .75796 m .67351 .75668 L p .68026 .76478 L F P
0 g
s
.249 .403 .822 r
.67332 .75796 m .67239 .75606 L .67351 .75668 L closepath p F P
0 g
s
.095 .304 .782 r
.80046 .66403 m .80586 .6683 L .80622 .67238 L p F P
0 g
s
.082 .301 .783 r
.79995 .65997 m .80046 .66403 L .80586 .6683 L p F P
0 g
s
.119 .337 .804 r
.79701 .65788 m .79995 .65997 L .80046 .66403 L p F P
0 g
s
.403 .629 .945 r
.68605 .57012 m .69047 .57057 L .68751 .56666 L p F P
0 g
s
.403 .629 .945 r
.68751 .56666 m .68388 .5663 L .68605 .57012 L p F P
0 g
s
.965 .637 .299 r
.58278 .59217 m .58581 .59573 L .58646 .60118 L p F P
0 g
s
.977 .684 .387 r
.58581 .59573 m .58278 .59217 L .58265 .58657 L p F P
0 g
s
.447 .662 .953 r
.66665 .56152 m .67181 .56168 L .66882 .5579 L p F P
0 g
s
.447 .662 .953 r
.66882 .5579 m .66418 .55777 L .66665 .56152 L p F P
0 g
s
.872 .993 .754 r
.8259 .79823 m .82513 .80056 L .81946 .80812 L p F P
0 g
s
.022 .214 .722 r
.81619 .68541 m .81628 .68953 L .82058 .69418 L p F P
0 g
s
.044 .24 .739 r
.81628 .68953 m .81619 .68541 L .8115 .68088 L p F P
0 g
s
.067 .272 .761 r
.8115 .68088 m .81128 .67678 L .80622 .67238 L p F P
0 g
s
.062 .273 .764 r
.80586 .6683 m .80622 .67238 L .81128 .67678 L p F P
0 g
s
.039 .241 .741 r
.81128 .67678 m .8115 .68088 L .81619 .68541 L p F P
0 g
s
.29 .526 .907 r
.73093 .59616 m .73941 .59871 L .74084 .60266 L p F P
0 g
s
.284 .527 .909 r
.73941 .59871 m .73093 .59616 L .72882 .59303 L p F P
0 g
s
.252 .474 .879 r
.76891 .62392 m .7618 .62089 L p .7707 .62831 L F P
0 g
s
.228 .463 .877 r
.7618 .62089 m .76891 .62392 L .76601 .61914 L p F P
0 g
s
.228 .463 .877 r
.76601 .61914 m .76071 .61689 L .7618 .62089 L p F P
0 g
s
0 0 .484 r
.83392 .74041 m .83447 .73623 L .83246 .73084 L p F P
0 g
s
0 0 .401 r
.83447 .73623 m .83392 .74041 L .83536 .74597 L p F P
0 g
s
0 0 .026 r
.83435 .77376 m .83465 .77209 L .83512 .76596 L p F P
0 g
s
0 0 .004 r
.8358 .76181 m .83512 .76596 L .83465 .77209 L p F P
0 g
s
0 0 .168 r
.83512 .76596 m .8358 .76181 L .83558 .75588 L p F P
0 g
s
.246 .404 .823 r
.67351 .75668 m .67239 .75606 L .66928 .74979 L p F P
0 g
s
.471 .595 .895 r
.73546 .81288 m .73649 .81447 L .73592 .81717 L p F P
0 g
s
.453 .608 .913 r
.7384 .81743 m .73592 .81717 L .73649 .81447 L closepath p F P
0 g
s
.075 .277 .764 r
.64529 .71469 m .65025 .71911 L .65061 .72318 L p F P
0 g
s
0 .218 .735 r
.64484 .71062 m .64529 .71469 L .65025 .71911 L p F P
0 g
s
.029 .247 .749 r
.64063 .70668 m .64484 .71062 L .64529 .71469 L p F P
0 g
s
0 .132 .679 r
.64063 .70668 m .64015 .70615 L .63996 .70531 L closepath p F P
0 g
s
0 .106 .66 r
.63748 .70009 m .63533 .69751 L p .64015 .70615 L F P
0 g
s
0 .106 .66 r
.64015 .70615 m .63996 .70531 L .63748 .70009 L p F P
0 g
s
.52 .678 .937 r
.75701 .82562 m .75565 .82568 L .75593 .82414 L closepath p F P
0 g
s
.533 .659 .917 r
.75413 .82168 m .75593 .82414 L .75565 .82568 L p F P
0 g
s
.056 .27 .763 r
.65605 .73163 m .65576 .72756 L .65061 .72318 L p F P
0 g
s
0 .238 .748 r
.65025 .71911 m .65061 .72318 L .65576 .72756 L p F P
0 g
s
0 .074 .636 r
.63533 .69751 m .63748 .70009 L .63433 .6937 L p F P
0 g
s
0 .074 .636 r
.63433 .6937 m .63424 .69359 L .63533 .69751 L p F P
0 g
s
0 .051 .618 r
.63533 .69751 m .63424 .69359 L .63058 .68886 L p F P
0 g
s
.783 .948 .929 r
.81081 .81648 m .80314 .82217 L .8005 .82039 L p F P
0 g
s
.078 .288 .773 r
.66163 .74005 m .6614 .73599 L .65605 .73163 L p F P
0 g
s
.039 .27 .766 r
.65576 .72756 m .65605 .73163 L .6614 .73599 L p F P
0 g
s
.715 .325 0 r
.60291 .63664 m .60224 .63518 L .59908 .62922 L p F P
0 g
s
.362 .499 .862 r
.70352 .78826 m .69765 .78635 L .69469 .78085 L p F P
0 g
s
0 .027 .599 r
.62937 .68495 m .63058 .68886 L .63424 .69359 L p F P
0 g
s
0 .012 .587 r
.63058 .68886 m .62937 .68495 L .62588 .68019 L p F P
0 g
s
.444 .572 .888 r
.72326 .80674 m .71962 .8062 L .71661 .80107 L p F P
0 g
s
.356 .512 .875 r
.71211 .79983 m .71661 .80107 L .7136 .79591 L p F P
0 g
s
.356 .512 .875 r
.7136 .79591 m .71284 .79567 L .71211 .79983 L p F P
0 g
s
.116 .318 .789 r
.66617 .74354 m .66163 .74005 L p .66738 .74842 L F P
0 g
s
.081 .291 .775 r
.66163 .74005 m .66617 .74354 L .66305 .73732 L p F P
0 g
s
.081 .291 .775 r
.66305 .73732 m .6614 .73599 L .66163 .74005 L p F P
0 g
s
0 0 .548 r
.62453 .6763 m .62588 .68019 L .62937 .68495 L p F P
0 g
s
0 0 .55 r
.62588 .68019 m .62453 .6763 L .62122 .6715 L p F P
0 g
s
0 0 0 r
.83367 .77719 m .83435 .77376 L p .83228 .78268 L F P
0 g
s
0 0 0 r
.83228 .78268 m .83336 .77845 L .83367 .77719 L p F P
0 g
s
.792 .831 .361 r
.83336 .77845 m .83228 .78268 L .82986 .78935 L p F P
0 g
s
.129 .331 .796 r
.66928 .74979 m .66738 .74842 L .6673 .74582 L closepath p F P
0 g
s
.116 .318 .789 r
.66738 .74842 m .6673 .74582 L .66617 .74354 L p F P
0 g
s
0 .226 .739 r
.64484 .71062 m .64063 .70668 L .63996 .70531 L p F P
0 g
s
0 0 .508 r
.61973 .66763 m .62122 .6715 L .62453 .6763 L p F P
0 g
s
0 0 .507 r
.62122 .6715 m .61973 .66763 L .61659 .6628 L p F P
0 g
s
.856 .991 .839 r
.81946 .80812 m .81538 .81259 L .81284 .81187 L p F P
0 g
s
.856 .991 .839 r
.81284 .81187 m .82065 .80392 L .81946 .80812 L p F P
0 g
s
.872 .993 .754 r
.82482 .79868 m .8259 .79823 L p .81946 .80812 L F P
0 g
s
.872 .993 .754 r
.81946 .80812 m .82065 .80392 L .82482 .79868 L p F P
0 g
s
.561 .735 .957 r
.75701 .82562 m .76976 .82383 L .77258 .8272 L p F P
0 g
s
.559 .698 .933 r
.76692 .82032 m .76976 .82383 L .75701 .82562 L p F P
0 g
s
.559 .698 .933 r
.75743 .82132 m .76692 .82032 L p .75701 .82562 L F P
0 g
s
.559 .698 .933 r
.75701 .82562 m .75593 .82414 L .75743 .82132 L p F P
0 g
s
0 0 .462 r
.61496 .65896 m .61659 .6628 L .61973 .66763 L p F P
0 g
s
0 0 .456 r
.61659 .6628 m .61496 .65896 L .612 .65409 L p F P
0 g
s
.495 .698 .96 r
.63972 .55073 m .63762 .55085 L .63458 .54722 L p F P
0 g
s
.269 .42 .829 r
.67351 .75668 m .6806 .76062 L .68026 .76478 L p F P
0 g
s
.187 .381 .823 r
.67388 .75249 m .67351 .75668 L .6806 .76062 L p F P
0 g
s
.246 .404 .823 r
.66928 .74979 m .67388 .75249 L .67351 .75668 L p F P
0 g
s
.783 .948 .929 r
.8005 .82039 m .81245 .81218 L .81081 .81648 L p F P
0 g
s
.819 .985 .883 r
.81284 .81187 m .81245 .81218 L .81081 .81648 L p F P
0 g
s
.819 .985 .883 r
.81081 .81648 m .81538 .81259 L .81284 .81187 L p F P
0 g
s
.709 .686 .145 r
.83367 .77719 m .83465 .77209 L .83435 .77376 L closepath p F P
0 g
s
0 0 .408 r
.6102 .65028 m .612 .65409 L .61496 .65896 L p F P
0 g
s
0 0 .395 r
.612 .65409 m .6102 .65028 L .60744 .64537 L p F P
0 g
s
0 .226 .739 r
.63996 .70531 m .6395 .70212 L p .64484 .71062 L F P
0 g
s
0 .199 .721 r
.63996 .70531 m .63748 .70009 L .6395 .70212 L closepath p F P
0 g
s
0 0 .479 r
.8329 .72682 m .83246 .73084 L .83447 .73623 L p F P
0 g
s
0 0 .556 r
.83278 .72638 m .83038 .72144 L p .83246 .73084 L F P
0 g
s
0 0 .556 r
.83246 .73084 m .8329 .72682 L .83278 .72638 L p F P
0 g
s
.211 .44 .863 r
.77182 .62884 m .7707 .62831 L .7702 .62607 L closepath p F P
0 g
s
.252 .474 .879 r
.7707 .62831 m .7702 .62607 L .76891 .62392 L p F P
0 g
s
.276 .516 .903 r
.74084 .60266 m .74693 .60463 L .74402 .6002 L p F P
0 g
s
.276 .516 .903 r
.74402 .6002 m .73941 .59871 L .74084 .60266 L p F P
0 g
s
.323 .565 .925 r
.71609 .58557 m .72508 .58765 L .72215 .5835 L p F P
0 g
s
.323 .565 .925 r
.72215 .5835 m .71426 .58169 L .71609 .58557 L p F P
0 g
s
.334 .573 .928 r
.7092 .58062 m .71426 .58169 L .71609 .58557 L p F P
0 g
s
0 0 .344 r
.60547 .64159 m .60744 .64537 L .6102 .65028 L p F P
0 g
s
0 0 .335 r
.60547 .64159 m .60744 .64537 L p .6046 .63991 L F P
0 g
s
.665 .26 0 r
.60547 .64159 m .60817 .64652 L p .60634 .64328 L F P
0 g
s
.665 .26 0 r
.60327 .63786 m .60547 .64159 L p .60634 .64328 L F P
0 g
s
0 0 .335 r
.60291 .63664 m .60547 .64159 L p .6046 .63991 L F P
0 g
s
.489 .655 .933 r
.7384 .81743 m .75124 .81761 L .75413 .82168 L p F P
0 g
s
.494 .63 .912 r
.74833 .81344 m .75124 .81761 L .7384 .81743 L p F P
0 g
s
.494 .63 .912 r
.7371 .81294 m .74833 .81344 L p .7384 .81743 L F P
0 g
s
.494 .63 .912 r
.7384 .81743 m .73649 .81447 L .7371 .81294 L p F P
0 g
s
.684 .285 0 r
.60076 .63289 m .60291 .63664 L .60547 .64159 L p F P
0 g
s
.715 .325 0 r
.59908 .62922 m .60076 .63289 L .60291 .63664 L p F P
0 g
s
.238 .414 .835 r
.68731 .77279 m .68758 .76867 L .68026 .76478 L p F P
0 g
s
.217 .405 .834 r
.6806 .76062 m .68026 .76478 L .68758 .76867 L p F P
0 g
s
.108 .332 .803 r
.79995 .65997 m .79701 .65788 L .79407 .65214 L p F P
0 g
s
.827 .43 0 r
.59908 .62922 m .59856 .62785 L .59659 .62497 L closepath p F P
0 g
s
.872 .493 .014 r
.59591 .62374 m .5944 .619 L p .59856 .62785 L F P
0 g
s
.872 .493 .014 r
.59856 .62785 m .59659 .62497 L .59591 .62374 L p F P
0 g
s
0 0 .16 r
.83622 .75171 m .83558 .75588 L .8358 .76181 L p F P
0 g
s
0 0 .296 r
.83558 .75588 m .83622 .75171 L .83536 .74597 L p F P
0 g
s
.491 .696 .96 r
.63972 .55073 m .65016 .55024 L .64713 .54659 L p F P
0 g
s
.491 .696 .96 r
.64713 .54659 m .63675 .5471 L .63972 .55073 L p F P
0 g
s
.495 .698 .96 r
.63458 .54722 m .63675 .5471 L .63972 .55073 L p F P
0 g
s
.368 .604 .939 r
.69047 .57057 m .69883 .57183 L .70088 .57567 L p F P
0 g
s
.365 .606 .941 r
.69883 .57183 m .69047 .57057 L .68751 .56666 L p F P
0 g
s
.254 .497 .895 r
.75123 .60963 m .74984 .60913 L .74693 .60463 L p F P
0 g
s
.191 .422 .855 r
.77182 .62884 m .77791 .63196 L .77881 .63598 L p F P
0 g
s
.181 .42 .856 r
.77791 .63196 m .77182 .62884 L .7702 .62607 L p F P
0 g
s
.557 .696 .932 r
.75593 .82414 m .75413 .82168 L .75743 .82132 L closepath p F P
0 g
s
.88 .492 .029 r
.5944 .619 m .59591 .62374 L .59275 .61859 L p F P
0 g
s
.88 .492 .029 r
.59275 .61859 m .59173 .61538 L .5944 .619 L p F P
0 g
s
.911 .54 .099 r
.5944 .619 m .59173 .61538 L .59035 .61012 L p F P
0 g
s
.683 .873 .97 r
.79591 .82266 m .78798 .82632 L .78524 .82361 L p F P
0 g
s
.625 .81 .971 r
.77258 .8272 m .78524 .82361 L .78798 .82632 L p F P
0 g
s
.608 .79 .969 r
.78524 .82361 m .77258 .8272 L .76976 .82383 L p F P
0 g
s
.238 .414 .835 r
.68731 .77279 m .69152 .77489 L .68845 .76914 L p F P
0 g
s
.238 .414 .835 r
.68845 .76914 m .68758 .76867 L .68731 .77279 L p F P
0 g
s
.176 .402 .843 r
.7864 .64381 m .78566 .63976 L .77881 .63598 L p F P
0 g
s
.173 .405 .846 r
.77791 .63196 m .77881 .63598 L .78566 .63976 L p F P
0 g
s
0 0 .544 r
.83278 .72638 m .83038 .72144 L .83059 .71879 L closepath p F P
0 g
s
0 .061 .606 r
.8294 .71509 m .82769 .71219 L p .83038 .72144 L F P
0 g
s
0 .061 .606 r
.83038 .72144 m .83059 .71879 L .8294 .71509 L p F P
0 g
s
.407 .636 .949 r
.67181 .56168 m .68157 .56251 L .68388 .5663 L p F P
0 g
s
.405 .639 .951 r
.68157 .56251 m .67181 .56168 L .66882 .5579 L p F P
0 g
s
.218 .389 .82 r
.67388 .75249 m .66928 .74979 L .6673 .74582 L p F P
0 g
s
.33 .575 .93 r
.71426 .58169 m .7092 .58062 L .70626 .57657 L p F P
0 g
s
.888 .973 .664 r
.82482 .79868 m .82631 .79635 L .8259 .79823 L closepath p F P
0 g
s
.894 .929 .549 r
.82986 .78935 m .82631 .79635 L .8259 .79823 L p F P
0 g
s
.284 .527 .909 r
.72882 .59303 m .72837 .59195 L p .73941 .59871 L F P
0 g
s
.303 .543 .916 r
.72882 .59303 m .72801 .59185 L .72837 .59195 L closepath p F P
0 g
s
.415 .56 .891 r
.72326 .80674 m .7325 .80822 L .72953 .8035 L p F P
0 g
s
.415 .56 .891 r
.72953 .8035 m .72437 .8025 L .72326 .80674 L p F P
0 g
s
.444 .572 .888 r
.71661 .80107 m .72437 .8025 L .72326 .80674 L p F P
0 g
s
.92 .545 .127 r
.5875 .60653 m .59035 .61012 L .59173 .61538 L p F P
0 g
s
.944 .591 .198 r
.59035 .61012 m .5875 .60653 L .58646 .60118 L p F P
0 g
s
0 .191 .718 r
.6395 .70212 m .63748 .70009 L .63433 .6937 L p F P
0 g
s
.36 .598 .937 r
.70088 .57567 m .70626 .57657 L .70331 .57257 L p F P
0 g
s
.36 .598 .937 r
.70331 .57257 m .69883 .57183 L .70088 .57567 L p F P
0 g
s
.362 .499 .862 r
.69469 .78085 m .69472 .78071 L p .70352 .78826 L F P
0 g
s
.346 .487 .858 r
.69469 .78085 m .69459 .78067 L .69472 .78071 L closepath p F P
0 g
s
.751 .346 0 r
.60076 .63289 m .59908 .62922 L .59659 .62497 L p F P
0 g
s
.878 .939 .569 r
.83085 .78517 m .82986 .78935 L .82631 .79635 L p F P
0 g
s
.792 .831 .361 r
.82986 .78935 m .83085 .78517 L .83336 .77845 L p F P
0 g
s
.347 .487 .857 r
.69472 .78071 m .69459 .78067 L .69152 .77489 L p F P
0 g
s
.947 .591 .22 r
.58341 .59763 m .58646 .60118 L .5875 .60653 L p F P
0 g
s
.965 .637 .299 r
.58646 .60118 m .58341 .59763 L .58278 .59217 L p F P
0 g
s
.293 .472 .865 r
.69556 .77646 m .69472 .78071 L .70413 .78409 L p F P
0 g
s
.347 .487 .857 r
.69152 .77489 m .69556 .77646 L .69472 .78071 L p F P
0 g
s
.362 .499 .862 r
.69472 .78071 m .70413 .78409 L .70352 .78826 L p F P
0 g
s
.237 .476 .884 r
.75123 .60963 m .75951 .6129 L .76071 .61689 L p F P
0 g
s
.237 .481 .888 r
.74985 .60568 m .75123 .60963 L .75951 .6129 L p F P
0 g
s
.254 .497 .895 r
.74693 .60463 m .74985 .60568 L .75123 .60963 L p F P
0 g
s
0 0 .004 r
.83465 .77209 m .8353 .76795 L .8358 .76181 L p F P
0 g
s
.789 .738 .214 r
.83465 .77209 m .8353 .76795 L p .83347 .77799 L F P
0 g
s
.789 .738 .214 r
.83347 .77799 m .83367 .77719 L .83465 .77209 L p F P
0 g
s
.175 .393 .836 r
.79115 .64667 m .7864 .64381 L p .79353 .65178 L F P
0 g
s
.148 .378 .83 r
.7864 .64381 m .79115 .64667 L .78823 .64131 L p F P
0 g
s
.148 .378 .83 r
.78823 .64131 m .78566 .63976 L .7864 .64381 L p F P
0 g
s
0 .042 .594 r
.8294 .71509 m .82769 .71219 L .8278 .71016 L closepath p F P
0 g
s
0 .117 .65 r
.82618 .70563 m .82442 .70311 L p .82769 .71219 L F P
0 g
s
0 .117 .65 r
.82769 .71219 m .8278 .71016 L .82618 .70563 L p F P
0 g
s
.449 .668 .956 r
.65318 .55391 m .66155 .55405 L .66418 .55777 L p F P
0 g
s
.448 .671 .958 r
.66155 .55405 m .65318 .55391 L .65016 .55024 L p F P
0 g
s
.425 .56 .887 r
.72437 .8025 m .71661 .80107 L .7136 .79591 L p F P
0 g
s
.298 .545 .918 r
.72837 .59195 m .72801 .59185 L .72508 .58765 L p F P
0 g
s
.491 .626 .911 r
.73649 .81447 m .73546 .81288 L .7371 .81294 L closepath p F P
0 g
s
0 0 .293 r
.83594 .7418 m .83536 .74597 L .83622 .75171 L p F P
0 g
s
0 0 .401 r
.83536 .74597 m .83594 .7418 L .83447 .73623 L p F P
0 g
s
.445 .665 .955 r
.66418 .55777 m .66882 .5579 L .66582 .55416 L p F P
0 g
s
.445 .665 .955 r
.66582 .55416 m .66155 .55405 L .66418 .55777 L p F P
0 g
s
.402 .631 .948 r
.68388 .5663 m .68751 .56666 L .68454 .5628 L p F P
0 g
s
.402 .631 .948 r
.68454 .5628 m .68157 .56251 L .68388 .5663 L p F P
0 g
s
.284 .527 .909 r
.72837 .59195 m .73786 .59478 L .73941 .59871 L p F P
0 g
s
.283 .531 .912 r
.72662 .58806 m .72837 .59195 L .73786 .59478 L p F P
0 g
s
.298 .545 .918 r
.72508 .58765 m .72662 .58806 L .72837 .59195 L p F P
0 g
s
0 .098 .639 r
.82618 .70563 m .82442 .70311 L .82447 .70088 L closepath p F P
0 g
s
0 .168 .688 r
.82305 .69722 m .82058 .69418 L p .82442 .70311 L F P
0 g
s
0 .168 .688 r
.82442 .70311 m .82447 .70088 L .82305 .69722 L p F P
0 g
s
.126 .348 .812 r
.79407 .65214 m .79353 .65178 L .7934 .65085 L closepath p F P
0 g
s
.175 .393 .836 r
.79353 .65178 m .7934 .65085 L .79115 .64667 L p F P
0 g
s
.218 .389 .82 r
.6673 .74582 m .66739 .74431 L p .67388 .75249 L F P
0 g
s
.196 .371 .811 r
.6673 .74582 m .66617 .74354 L .66739 .74431 L closepath p F P
0 g
s
.208 .446 .869 r
.7702 .62607 m .76891 .62392 L .76973 .62429 L closepath p F P
0 g
s
.181 .42 .856 r
.7702 .62607 m .76973 .62429 L p .77791 .63196 L F P
0 g
s
.683 .873 .97 r
.79794 .81842 m .79591 .82266 L p .78524 .82361 L F P
0 g
s
.718 .89 .959 r
.79591 .82266 m .79794 .81842 L .8005 .82039 L closepath p F P
0 g
s
.082 .301 .783 r
.80586 .6683 m .80541 .66423 L .79995 .65997 L p F P
0 g
s
.076 .303 .786 r
.79935 .65592 m .79995 .65997 L .80541 .66423 L p F P
0 g
s
.108 .332 .803 r
.79407 .65214 m .79935 .65592 L .79995 .65997 L p F P
0 g
s
0 .15 .678 r
.82305 .69722 m .82058 .69418 L .82056 .69086 L closepath p F P
0 g
s
.022 .214 .722 r
.81996 .68945 m .81619 .68541 L p .82058 .69418 L F P
0 g
s
.022 .214 .722 r
.82058 .69418 m .82056 .69086 L .81996 .68945 L p F P
0 g
s
.094 .327 .801 r
.79935 .65592 m .79407 .65214 L .7934 .65085 L p F P
0 g
s
.344 .508 .877 r
.71058 .79065 m .70352 .78826 L p .71284 .79567 L F P
0 g
s
.323 .483 .864 r
.70352 .78826 m .71058 .79065 L .70755 .78536 L p F P
0 g
s
.323 .483 .864 r
.70755 .78536 m .70413 .78409 L .70352 .78826 L p F P
0 g
s
.56 .69 .927 r
.75743 .82132 m .75413 .82168 L .75124 .81761 L p F P
0 g
s
.062 .273 .764 r
.81128 .67678 m .81097 .67269 L .80586 .6683 L p F P
0 g
s
.057 .275 .766 r
.80541 .66423 m .80586 .6683 L .81097 .67269 L p F P
0 g
s
0 .191 .709 r
.81619 .68541 m .81996 .68945 L .81692 .68227 L p F P
0 g
s
0 .191 .709 r
.81692 .68227 m .81603 .6813 L .81619 .68541 L p F P
0 g
s
.039 .241 .741 r
.81619 .68541 m .81603 .6813 L .81128 .67678 L p F P
0 g
s
.221 .463 .878 r
.76071 .61689 m .76601 .61914 L .7631 .61443 L p F P
0 g
s
.221 .463 .878 r
.7631 .61443 m .75951 .6129 L .76071 .61689 L p F P
0 g
s
.039 .249 .748 r
.81097 .67269 m .81128 .67678 L .81603 .6813 L p F P
0 g
s
.19 .371 .813 r
.66739 .74431 m .66617 .74354 L .66305 .73732 L p F P
0 g
s
.493 .623 .907 r
.7371 .81294 m .73546 .81288 L .7325 .80822 L p F P
0 g
s
.895 .982 .706 r
.82631 .79635 m .82482 .79868 L .8224 .79913 L p F P
0 g
s
.895 .982 .706 r
.8224 .79913 m .82715 .79221 L .82631 .79635 L p F P
0 g
s
.878 .939 .569 r
.82631 .79635 m .82715 .79221 L .83085 .78517 L p F P
0 g
s
.094 .327 .801 r
.7934 .65085 m .79283 .64774 L p .79935 .65592 L F P
0 g
s
.128 .361 .821 r
.7934 .65085 m .79115 .64667 L .79283 .64774 L closepath p F P
0 g
s
0 .06 .625 r
.63433 .6937 m .63424 .69359 L .63419 .69342 L closepath p F P
0 g
s
0 .027 .599 r
.63118 .68734 m .62937 .68495 L p .63424 .69359 L F P
0 g
s
0 .027 .599 r
.63424 .69359 m .63419 .69342 L .63118 .68734 L p F P
0 g
s
0 .226 .739 r
.6395 .70212 m .64408 .70663 L .64484 .71062 L p F P
0 g
s
0 .16 .7 r
.63865 .69813 m .6395 .70212 L .64408 .70663 L p F P
0 g
s
0 .191 .718 r
.63433 .6937 m .63865 .69813 L .6395 .70212 L p F P
0 g
s
0 0 .572 r
.62937 .68495 m .63118 .68734 L .62802 .68125 L p F P
0 g
s
0 0 .572 r
.62802 .68125 m .62791 .6811 L .62937 .68495 L p F P
0 g
s
0 0 .548 r
.62937 .68495 m .62791 .6811 L .62453 .6763 L p F P
0 g
s
0 .218 .735 r
.65025 .71911 m .64958 .71511 L .64484 .71062 L p F P
0 g
s
0 .183 .715 r
.64408 .70663 m .64484 .71062 L .64958 .71511 L p F P
0 g
s
0 .168 .705 r
.63865 .69813 m .63433 .6937 L .63419 .69342 L p F P
0 g
s
.791 .904 .92 r
.79794 .81842 m .8005 .82039 L .81245 .81218 L p F P
0 g
s
0 0 .479 r
.83447 .73623 m .8347 .73423 L .8329 .72682 L p F P
0 g
s
0 0 .392 r
.8347 .73423 m .83447 .73623 L .83594 .7418 L p F P
0 g
s
.803 .412 0 r
.59659 .62497 m .59591 .62374 L .59609 .62419 L closepath p F P
0 g
s
.751 .346 0 r
.59659 .62497 m .59609 .62419 L p .60076 .63289 L F P
0 g
s
0 .238 .748 r
.65576 .72756 m .65517 .72357 L .65025 .71911 L p F P
0 g
s
0 .214 .735 r
.64958 .71511 m .65025 .71911 L .65517 .72357 L p F P
0 g
s
0 .168 .705 r
.63419 .69342 m .63326 .68962 L p .63865 .69813 L F P
0 g
s
0 .138 .683 r
.63419 .69342 m .63118 .68734 L .63326 .68962 L closepath p F P
0 g
s
0 0 .52 r
.62295 .67246 m .62453 .6763 L .62791 .6811 L p F P
0 g
s
0 0 .508 r
.62453 .6763 m .62295 .67246 L .61973 .66763 L p F P
0 g
s
0 0 0 r
.83644 .75765 m .8358 .76181 L .8353 .76795 L p F P
0 g
s
0 0 .16 r
.8358 .76181 m .83644 .75765 L .83622 .75171 L p F P
0 g
s
.039 .27 .766 r
.65993 .73115 m .65576 .72756 L p .6614 .73599 L F P
0 g
s
.002 .243 .751 r
.65576 .72756 m .65993 .73115 L .6568 .72502 L p F P
0 g
s
.002 .243 .751 r
.6568 .72502 m .65517 .72357 L .65576 .72756 L p F P
0 g
s
0 0 .465 r
.61801 .66382 m .61973 .66763 L .62295 .67246 L p F P
0 g
s
0 0 .462 r
.61973 .66763 m .61801 .66382 L .61496 .65896 L p F P
0 g
s
.201 .446 .87 r
.76973 .62429 m .76891 .62392 L .76601 .61914 L p F P
0 g
s
.695 .702 .173 r
.83336 .77845 m .83347 .77799 L .83367 .77719 L closepath p F P
0 g
s
.863 .993 .745 r
.82065 .80392 m .82482 .79868 L .8224 .79913 L p F P
0 g
s
0 0 .416 r
.61308 .65517 m .61496 .65896 L .61801 .66382 L p F P
0 g
s
0 0 .408 r
.61496 .65896 m .61308 .65517 L .6102 .65028 L p F P
0 g
s
.039 .27 .766 r
.6614 .73599 m .6611 .73348 L .65993 .73115 L p F P
0 g
s
.055 .285 .776 r
.66305 .73732 m .6614 .73599 L .6611 .73348 L closepath p F P
0 g
s
.324 .474 .856 r
.69556 .77646 m .69152 .77489 L .68845 .76914 L p F P
0 g
s
0 0 .522 r
.83059 .71879 m .83064 .7173 L p .83291 .72667 L F P
0 g
s
0 0 .522 r
.83291 .72667 m .83278 .72638 L .83059 .71879 L p F P
0 g
s
0 .015 .576 r
.83059 .71879 m .8294 .71509 L .83064 .7173 L closepath p F P
0 g
s
.248 .497 .897 r
.74985 .60568 m .74693 .60463 L .74402 .6002 L p F P
0 g
s
.493 .623 .907 r
.7325 .80822 m .73847 .80864 L .7371 .81294 L p F P
0 g
s
.469 .611 .909 r
.7371 .81294 m .74833 .81344 L .7454 .80919 L p F P
0 g
s
.469 .611 .909 r
.7454 .80919 m .73847 .80864 L .7371 .81294 L p F P
0 g
s
0 .012 .575 r
.83064 .7173 m .8294 .71509 L .8278 .71016 L p F P
0 g
s
0 0 .36 r
.60817 .64652 m .6102 .65028 L .61308 .65517 L p F P
0 g
s
0 0 .36 r
.61099 .65143 m .60817 .64652 L p .60973 .64926 L F P
0 g
s
0 0 .36 r
.61308 .65517 m .61099 .65143 L p .60973 .64926 L F P
0 g
s
0 0 .372 r
.61392 .65634 m .61099 .65143 L p .61302 .65487 L F P
0 g
s
0 0 .372 r
.61607 .66006 m .61392 .65634 L p .61302 .65487 L F P
0 g
s
0 0 .401 r
.61541 .65872 m .61392 .65634 L .61607 .66006 L p F P
0 g
s
.609 .19 0 r
.61392 .65634 m .61541 .65872 L .61455 .65735 L p F P
0 g
s
.609 .19 0 r
.61455 .65735 m .61226 .65376 L p .61392 .65634 L F P
0 g
s
.64 .224 0 r
.61099 .65143 m .61392 .65634 L p .61227 .65362 L F P
0 g
s
.64 .224 0 r
.6087 .64774 m .61099 .65143 L p .61227 .65362 L F P
0 g
s
.651 .24 0 r
.60817 .64652 m .61099 .65143 L p .60926 .64848 L F P
0 g
s
0 0 .344 r
.6102 .65028 m .60817 .64652 L p .60709 .64456 L F P
0 g
s
.651 .24 0 r
.60592 .64281 m .60817 .64652 L p .60926 .64848 L F P
0 g
s
0 0 .344 r
.60817 .64652 m .60547 .64159 L p .60709 .64456 L F P
0 g
s
0 .012 .575 r
.8278 .71016 m .8278 .70807 L p .83064 .7173 L F P
0 g
s
0 .073 .622 r
.8278 .71016 m .82618 .70563 L .8278 .70807 L closepath p F P
0 g
s
.319 .567 .927 r
.71426 .58169 m .72215 .5835 L .71922 .57941 L p F P
0 g
s
.319 .567 .927 r
.71922 .57941 m .71231 .57784 L .71426 .58169 L p F P
0 g
s
.33 .575 .93 r
.70626 .57657 m .71231 .57784 L .71426 .58169 L p F P
0 g
s
.83 .428 0 r
.59609 .62419 m .59591 .62374 L .59275 .61859 L p F P
0 g
s
.684 .285 0 r
.60547 .64159 m .60327 .63786 L .60076 .63289 L p F P
0 g
s
.218 .389 .82 r
.66739 .74431 m .67388 .74839 L .67388 .75249 L p F P
0 g
s
.131 .346 .809 r
.66739 .74019 m .66739 .74431 L .67388 .74839 L p F P
0 g
s
.19 .371 .813 r
.66305 .73732 m .66739 .74019 L .66739 .74431 L p F P
0 g
s
.35 .514 .879 r
.7136 .79591 m .71284 .79567 L .71295 .79478 L closepath p F P
0 g
s
.344 .508 .877 r
.71284 .79567 m .71295 .79478 L .71058 .79065 L p F P
0 g
s
.536 .685 .934 r
.75743 .82132 m .76692 .82032 L .76407 .81667 L p F P
0 g
s
.536 .685 .934 r
.76407 .81667 m .75885 .81704 L .75743 .82132 L p F P
0 g
s
.56 .69 .927 r
.75124 .81761 m .75885 .81704 L .75743 .82132 L p F P
0 g
s
.271 .517 .905 r
.73941 .59871 m .74402 .6002 L .7411 .59582 L p F P
0 g
s
.271 .517 .905 r
.7411 .59582 m .73786 .59478 L .73941 .59871 L p F P
0 g
s
.791 .83 .36 r
.83347 .77799 m .83336 .77845 L .83085 .78517 L p F P
0 g
s
.365 .606 .941 r
.68751 .56666 m .69664 .56802 L .69883 .57183 L p F P
0 g
s
.363 .609 .943 r
.69664 .56802 m .68751 .56666 L .68454 .5628 L p F P
0 g
s
.727 .314 0 r
.59838 .6292 m .60076 .63289 L .60327 .63786 L p F P
0 g
s
.751 .346 0 r
.59609 .62419 m .59838 .6292 L .60076 .63289 L p F P
0 g
s
.181 .42 .856 r
.76973 .62429 m .7769 .62795 L .77791 .63196 L p F P
0 g
s
.176 .423 .859 r
.76856 .62032 m .76973 .62429 L .7769 .62795 L p F P
0 g
s
.201 .446 .87 r
.76601 .61914 m .76856 .62032 L .76973 .62429 L p F P
0 g
s
0 .07 .621 r
.8278 .70807 m .82618 .70563 L .82447 .70088 L p F P
0 g
s
.787 .371 0 r
.5935 .62053 m .59609 .62419 L .59838 .6292 L p F P
0 g
s
.83 .428 0 r
.59275 .61859 m .5935 .62053 L .59609 .62419 L p F P
0 g
s
.608 .79 .969 r
.76976 .82383 m .78247 .82071 L .78524 .82361 L p F P
0 g
s
.592 .772 .966 r
.78247 .82071 m .76976 .82383 L .76692 .82032 L p F P
0 g
s
.872 .965 .854 r
.82065 .80392 m .82194 .79967 L p .8126 .81177 L F P
0 g
s
.872 .965 .854 r
.8126 .81177 m .81284 .81187 L .82065 .80392 L p F P
0 g
s
.863 .993 .745 r
.8224 .79913 m .82194 .79967 L .82065 .80392 L p F P
0 g
s
0 0 .524 r
.8329 .72682 m .83278 .72638 L .83291 .72667 L closepath p F P
0 g
s
.326 .577 .932 r
.71231 .57784 m .70626 .57657 L .70331 .57257 L p F P
0 g
s
0 0 .441 r
.83291 .72667 m .8329 .72682 L .8347 .73423 L p F P
0 g
s
.187 .381 .823 r
.6806 .76062 m .68058 .75654 L .67388 .75249 L p F P
0 g
s
.156 .368 .82 r
.67388 .74839 m .67388 .75249 L .68058 .75654 L p F P
0 g
s
.425 .56 .887 r
.7136 .79591 m .72498 .79837 L .72437 .8025 L p F P
0 g
s
.407 .548 .884 r
.72498 .79837 m .7136 .79591 L .71295 .79478 L p F P
0 g
s
.405 .639 .951 r
.66882 .5579 m .67911 .55876 L .68157 .56251 L p F P
0 g
s
.403 .641 .953 r
.67911 .55876 m .66882 .5579 L .66582 .55416 L p F P
0 g
s
.892 .498 .058 r
.59173 .61538 m .59275 .61859 L .5896 .6141 L p F P
0 g
s
.892 .498 .058 r
.5896 .6141 m .58886 .61179 L .59173 .61538 L p F P
0 g
s
.92 .545 .127 r
.59173 .61538 m .58886 .61179 L .5875 .60653 L p F P
0 g
s
0 0 .441 r
.8347 .73423 m .83481 .7321 L .83291 .72667 L p F P
0 g
s
0 0 .435 r
.83303 .72258 m .83291 .72667 L .83481 .7321 L p F P
0 g
s
0 0 .522 r
.83064 .7173 m .83303 .72258 L .83291 .72667 L p F P
0 g
s
.683 .873 .97 r
.78524 .82361 m .79782 .81832 L .79794 .81842 L p F P
0 g
s
.665 .853 .972 r
.79782 .81832 m .78524 .82361 L .78247 .82071 L p F P
0 g
s
.838 .838 .37 r
.83401 .77433 m .83347 .77799 L .83178 .78129 L p F P
0 g
s
.789 .738 .214 r
.8353 .76795 m .83401 .77433 L .83347 .77799 L p F P
0 g
s
.791 .83 .36 r
.83085 .78517 m .83178 .78129 L .83347 .77799 L p F P
0 g
s
0 .07 .621 r
.82447 .70088 m .82442 .699 L p .8278 .70807 L F P
0 g
s
0 .126 .663 r
.82447 .70088 m .82305 .69722 L .82442 .699 L closepath p F P
0 g
s
.807 .97 .905 r
.81245 .81218 m .8126 .81177 L .81284 .81187 L closepath p F P
0 g
s
.791 .904 .92 r
.81245 .81218 m .8126 .81177 L p .79794 .81842 L F P
0 g
s
.926 .548 .152 r
.58445 .60298 m .5875 .60653 L .58886 .61179 L p F P
0 g
s
.947 .591 .22 r
.5875 .60653 m .58445 .60298 L .58341 .59763 L p F P
0 g
s
.217 .405 .834 r
.68537 .76335 m .6806 .76062 L p .68758 .76867 L F P
0 g
s
.187 .38 .822 r
.6806 .76062 m .68537 .76335 L .68229 .75758 L p F P
0 g
s
.187 .38 .822 r
.68229 .75758 m .68058 .75654 L .6806 .76062 L p F P
0 g
s
.407 .548 .884 r
.71295 .79478 m .71381 .79142 L p .72498 .79837 L F P
0 g
s
.395 .538 .882 r
.71295 .79478 m .71058 .79065 L .71381 .79142 L closepath p F P
0 g
s
.173 .405 .846 r
.78566 .63976 m .78482 .63572 L .77791 .63196 L p F P
0 g
s
.18 .417 .854 r
.7769 .62795 m .77791 .63196 L .78482 .63572 L p F P
0 g
s
.159 .355 .809 r
.66739 .74019 m .66305 .73732 L .6611 .73348 L p F P
0 g
s
.829 .956 .897 r
.81025 .81059 m .81329 .80806 L .8126 .81177 L closepath p F P
0 g
s
.791 .904 .92 r
.8126 .81177 m .81025 .81059 L p .79794 .81842 L F P
0 g
s
.872 .965 .854 r
.82194 .79967 m .81329 .80806 L .8126 .81177 L p F P
0 g
s
.12 .36 .822 r
.79283 .64774 m .79115 .64667 L .78823 .64131 L p F P
0 g
s
0 .124 .662 r
.82442 .699 m .82305 .69722 L .82056 .69086 L p F P
0 g
s
.293 .546 .92 r
.72662 .58806 m .72508 .58765 L .72215 .5835 L p F P
0 g
s
.357 .6 .939 r
.69883 .57183 m .70331 .57257 L .70036 .56862 L p F P
0 g
s
.357 .6 .939 r
.70036 .56862 m .69664 .56802 L .69883 .57183 L p F P
0 g
s
0 0 .155 r
.83682 .74754 m .83622 .75171 L .83644 .75765 L p F P
0 g
s
0 0 .293 r
.83622 .75171 m .83682 .74754 L .83594 .7418 L p F P
0 g
s
.448 .671 .958 r
.65016 .55024 m .65877 .55037 L .66155 .55405 L p F P
0 g
s
.447 .673 .96 r
.65877 .55037 m .65016 .55024 L .64713 .54659 L p F P
0 g
s
0 .125 .675 r
.63326 .68962 m .63118 .68734 L .62802 .68125 L p F P
0 g
s
0 0 .507 r
.83065 .71321 m .83064 .7173 L .83303 .72258 L p F P
0 g
s
0 .012 .575 r
.8278 .70807 m .83065 .71321 L .83064 .7173 L p F P
0 g
s
.226 .414 .839 r
.68845 .76914 m .68758 .76867 L .68759 .76754 L closepath p F P
0 g
s
.217 .405 .834 r
.68758 .76867 m .68759 .76754 L .68537 .76335 L p F P
0 g
s
0 0 .349 r
.83481 .7321 m .8347 .73423 L .83603 .74108 L p F P
0 g
s
0 0 .392 r
.83594 .7418 m .83603 .74108 L .8347 .73423 L p F P
0 g
s
.237 .481 .888 r
.75951 .6129 m .7582 .60893 L .74985 .60568 L p F P
0 g
s
.233 .484 .89 r
.74836 .60175 m .74985 .60568 L .7582 .60893 L p F P
0 g
s
.248 .497 .897 r
.74402 .6002 m .74836 .60175 L .74985 .60568 L p F P
0 g
s
.138 .375 .83 r
.78566 .63976 m .78823 .64131 L .78531 .63602 L p F P
0 g
s
.138 .375 .83 r
.78531 .63602 m .78482 .63572 L .78566 .63976 L p F P
0 g
s
.543 .677 .925 r
.75885 .81704 m .75124 .81761 L .74833 .81344 L p F P
0 g
s
.476 .611 .906 r
.73847 .80864 m .7325 .80822 L .72953 .8035 L p F P
0 g
s
.444 .667 .957 r
.66155 .55405 m .66582 .55416 L .66281 .55046 L p F P
0 g
s
.444 .667 .957 r
.66281 .55046 m .65877 .55037 L .66155 .55405 L p F P
0 g
s
.389 .551 .894 r
.72437 .8025 m .72953 .8035 L .72655 .79872 L p F P
0 g
s
.389 .551 .894 r
.72655 .79872 m .72498 .79837 L .72437 .8025 L p F P
0 g
s
.399 .634 .95 r
.68157 .56251 m .68454 .5628 L .68156 .55899 L p F P
0 g
s
.399 .634 .95 r
.68156 .55899 m .67911 .55876 L .68157 .56251 L p F P
0 g
s
.324 .474 .856 r
.68845 .76914 m .69598 .7723 L .69556 .77646 L p F P
0 g
s
.301 .461 .853 r
.69598 .7723 m .68845 .76914 L .68759 .76754 L p F P
0 g
s
0 0 .566 r
.82771 .70399 m .8278 .70807 L .83065 .71321 L p F P
0 g
s
0 .07 .621 r
.82442 .699 m .82771 .70399 L .8278 .70807 L p F P
0 g
s
.283 .531 .912 r
.73786 .59478 m .73619 .59087 L .72662 .58806 L p F P
0 g
s
.28 .534 .915 r
.72475 .58419 m .72662 .58806 L .73619 .59087 L p F P
0 g
s
.293 .546 .92 r
.72215 .5835 m .72475 .58419 L .72662 .58806 L p F P
0 g
s
.881 .947 .588 r
.83178 .78129 m .83085 .78517 L .82715 .79221 L p F P
0 g
s
0 .124 .662 r
.82056 .69086 m .82051 .69007 L p .82442 .699 L F P
0 g
s
0 .175 .699 r
.82056 .69086 m .81996 .68945 L .82051 .69007 L closepath p F P
0 g
s
0 0 0 r
.8353 .76795 m .83592 .76381 L .83644 .75765 L p F P
0 g
s
.762 .73 .203 r
.83592 .76381 m .8353 .76795 L .83401 .77433 L p F P
0 g
s
.293 .472 .865 r
.70413 .78409 m .70435 .78001 L .69556 .77646 L p F P
0 g
s
.277 .465 .864 r
.69598 .7723 m .69556 .77646 L .70435 .78001 L p F P
0 g
s
.159 .355 .809 r
.6611 .73348 m .66105 .73194 L p .66739 .74019 L F P
0 g
s
.136 .335 .799 r
.6611 .73348 m .65993 .73115 L .66105 .73194 L closepath p F P
0 g
s
.094 .327 .801 r
.79283 .64774 m .79866 .65188 L .79935 .65592 L p F P
0 g
s
.087 .329 .805 r
.79198 .64373 m .79283 .64774 L .79866 .65188 L p F P
0 g
s
.12 .36 .822 r
.78823 .64131 m .79198 .64373 L .79283 .64774 L p F P
0 g
s
.193 .445 .871 r
.76856 .62032 m .76601 .61914 L .7631 .61443 L p F P
0 g
s
0 .172 .698 r
.82051 .69007 m .81996 .68945 L .81692 .68227 L p F P
0 g
s
.85 .44 0 r
.5935 .62053 m .59275 .61859 L .5896 .6141 L p F P
0 g
s
0 .059 .615 r
.82422 .69492 m .82442 .699 L .82771 .70399 L p F P
0 g
s
0 .124 .662 r
.82051 .69007 m .82422 .69492 L .82442 .699 L p F P
0 g
s
.301 .461 .853 r
.68759 .76754 m .68795 .76451 L p .69598 .7723 L F P
0 g
s
.284 .448 .848 r
.68759 .76754 m .68537 .76335 L .68795 .76451 L closepath p F P
0 g
s
0 0 .281 r
.83603 .74108 m .83594 .7418 L .83682 .74754 L p F P
0 g
s
.076 .303 .786 r
.80541 .66423 m .80486 .66017 L .79935 .65592 L p F P
0 g
s
.071 .304 .788 r
.79866 .65188 m .79935 .65592 L .80486 .66017 L p F P
0 g
s
.241 .498 .898 r
.74836 .60175 m .74402 .6002 L .7411 .59582 L p F P
0 g
s
.395 .538 .881 r
.71381 .79142 m .71058 .79065 L .70755 .78536 L p F P
0 g
s
0 .111 .656 r
.82019 .68601 m .82051 .69007 L .82422 .69492 L p F P
0 g
s
0 .172 .698 r
.81692 .68227 m .82019 .68601 L .82051 .69007 L p F P
0 g
s
.214 .463 .88 r
.75951 .6129 m .7631 .61443 L .76019 .60978 L p F P
0 g
s
.214 .463 .88 r
.76019 .60978 m .7582 .60893 L .75951 .6129 L p F P
0 g
s
.057 .275 .766 r
.81097 .67269 m .81057 .66861 L .80541 .66423 L p F P
0 g
s
.057 .283 .773 r
.80486 .66017 m .80541 .66423 L .81057 .66861 L p F P
0 g
s
.126 .334 .8 r
.66105 .73194 m .65993 .73115 L .6568 .72502 L p F P
0 g
s
0 .186 .708 r
.81692 .68227 m .81603 .6813 L .81594 .67997 L closepath p F P
0 g
s
.039 .249 .748 r
.81392 .6755 m .81097 .67269 L p .81603 .6813 L F P
0 g
s
.039 .249 .748 r
.81603 .6813 m .81594 .67997 L .81392 .6755 L p F P
0 g
s
.006 .227 .736 r
.81097 .67269 m .81392 .6755 L .81092 .66894 L p F P
0 g
s
.006 .227 .736 r
.81092 .66894 m .81057 .66861 L .81097 .67269 L p F P
0 g
s
.749 .89 .943 r
.79782 .81832 m .79797 .81824 L .79794 .81842 L closepath p F P
0 g
s
.791 .904 .92 r
.81025 .81059 m .79797 .81824 L .79794 .81842 L p F P
0 g
s
.292 .471 .865 r
.70413 .78409 m .70755 .78536 L .70451 .78007 L p F P
0 g
s
.292 .471 .865 r
.70451 .78007 m .70435 .78001 L .70413 .78409 L p F P
0 g
s
0 0 .555 r
.62802 .68125 m .62791 .6811 L .62779 .68082 L closepath p F P
0 g
s
0 0 .52 r
.62487 .67524 m .62295 .67246 L p .62791 .6811 L F P
0 g
s
0 0 .52 r
.62791 .6811 m .62779 .68082 L .62487 .67524 L p F P
0 g
s
.733 .873 .946 r
.79797 .81824 m .79782 .81832 L .79511 .81596 L p F P
0 g
s
.665 .853 .972 r
.78247 .82071 m .79511 .81596 L .79782 .81832 L p F P
0 g
s
0 .168 .705 r
.63326 .68962 m .63752 .69421 L .63865 .69813 L p F P
0 g
s
0 .099 .655 r
.63201 .68571 m .63326 .68962 L .63752 .69421 L p F P
0 g
s
0 .125 .675 r
.62802 .68125 m .63201 .68571 L .63326 .68962 L p F P
0 g
s
0 0 .234 r
.83621 .73769 m .83603 .74108 L .83685 .74732 L p F P
0 g
s
0 0 .349 r
.83603 .74108 m .83621 .73769 L .83481 .7321 L p F P
0 g
s
0 0 .281 r
.83682 .74754 m .83685 .74732 L .83603 .74108 L p F P
0 g
s
0 0 .494 r
.62295 .67246 m .62487 .67524 L .62172 .66952 L p F P
0 g
s
0 0 .494 r
.62172 .66952 m .62115 .66868 L .62295 .67246 L p F P
0 g
s
0 0 .465 r
.62295 .67246 m .62115 .66868 L .61801 .66382 L p F P
0 g
s
.363 .609 .943 r
.68454 .5628 m .69431 .56423 L .69664 .56802 L p F P
0 g
s
.359 .611 .946 r
.69431 .56423 m .68454 .5628 L .68156 .55899 L p F P
0 g
s
.733 .873 .946 r
.79511 .81596 m .79841 .81423 L .79797 .81824 L p F P
0 g
s
.762 .933 .941 r
.80763 .80898 m .79841 .81423 L .79797 .81824 L p F P
0 g
s
.762 .933 .941 r
.79797 .81824 m .81025 .81059 L .80763 .80898 L p F P
0 g
s
0 .16 .7 r
.64408 .70663 m .64305 .7027 L .63865 .69813 L p F P
0 g
s
0 .124 .674 r
.63752 .69421 m .63865 .69813 L .64305 .7027 L p F P
0 g
s
0 .1 .656 r
.63201 .68571 m .62802 .68125 L .62779 .68082 L p F P
0 g
s
0 0 .423 r
.61607 .66006 m .61801 .66382 L .62115 .66868 L p F P
0 g
s
0 0 .416 r
.61801 .66382 m .61607 .66006 L .61308 .65517 L p F P
0 g
s
.592 .772 .966 r
.76692 .82032 m .77968 .81764 L .78247 .82071 L p F P
0 g
s
.576 .755 .963 r
.77968 .81764 m .76692 .82032 L .76407 .81667 L p F P
0 g
s
0 .183 .715 r
.64958 .71511 m .64865 .71117 L .64408 .70663 L p F P
0 g
s
0 .152 .694 r
.64305 .7027 m .64408 .70663 L .64865 .71117 L p F P
0 g
s
0 0 .372 r
.61099 .65143 m .61308 .65517 L .61607 .66006 L p F P
0 g
s
.326 .577 .932 r
.70331 .57257 m .71022 .57401 L .71231 .57784 L p F P
0 g
s
.322 .579 .934 r
.71022 .57401 m .70331 .57257 L .70036 .56862 L p F P
0 g
s
.665 .26 0 r
.60817 .64652 m .60592 .64281 L .60327 .63786 L p F P
0 g
s
0 .1 .656 r
.62779 .68082 m .62652 .67721 L p .63201 .68571 L F P
0 g
s
0 .067 .63 r
.62779 .68082 m .62487 .67524 L .62652 .67721 L closepath p F P
0 g
s
0 .214 .735 r
.65368 .719 m .64958 .71511 L p .65517 .72357 L F P
0 g
s
0 .189 .719 r
.64958 .71511 m .65368 .719 L .65054 .71304 L p F P
0 g
s
0 .189 .719 r
.65054 .71304 m .64865 .71117 L .64958 .71511 L p F P
0 g
s
.109 .356 .821 r
.79198 .64373 m .78823 .64131 L .78531 .63602 L p F P
0 g
s
.315 .569 .929 r
.71231 .57784 m .71922 .57941 L .71628 .57537 L p F P
0 g
s
.315 .569 .929 r
.71628 .57537 m .71022 .57401 L .71231 .57784 L p F P
0 g
s
.707 .288 0 r
.60084 .63418 m .60327 .63786 L .60592 .64281 L p F P
0 g
s
.727 .314 0 r
.60327 .63786 m .60084 .63418 L .59838 .6292 L p F P
0 g
s
.921 .977 .74 r
.82715 .79221 m .828 .78805 L p .82209 .79914 L F P
0 g
s
.921 .977 .74 r
.82209 .79914 m .8224 .79913 L .82715 .79221 L p F P
0 g
s
.881 .947 .588 r
.8316 .78148 m .83178 .78129 L p .82715 .79221 L F P
0 g
s
.881 .947 .588 r
.82715 .79221 m .828 .78805 L .8316 .78148 L p F P
0 g
s
0 .234 .748 r
.6568 .72502 m .65517 .72357 L .65458 .72076 L closepath p F P
0 g
s
0 .214 .735 r
.65517 .72357 m .65458 .72076 L .65368 .719 L p F P
0 g
s
.762 .338 0 r
.59577 .62556 m .59838 .6292 L .60084 .63418 L p F P
0 g
s
.787 .371 0 r
.59838 .6292 m .59577 .62556 L .5935 .62053 L p F P
0 g
s
0 0 .435 r
.83481 .7321 m .83495 .72801 L .83303 .72258 L p F P
0 g
s
0 0 .342 r
.83495 .72801 m .83481 .7321 L .83621 .73769 L p F P
0 g
s
.403 .641 .953 r
.66582 .55416 m .6765 .55503 L .67911 .55876 L p F P
0 g
s
.401 .644 .955 r
.6765 .55503 m .66582 .55416 L .66281 .55046 L p F P
0 g
s
.814 .389 0 r
.59069 .61694 m .5935 .62053 L .59577 .62556 L p F P
0 g
s
.85 .44 0 r
.5896 .6141 m .59069 .61694 L .5935 .62053 L p F P
0 g
s
.266 .518 .907 r
.73786 .59478 m .7411 .59582 L .73818 .5915 L p F P
0 g
s
.266 .518 .907 r
.73818 .5915 m .73619 .59087 L .73786 .59478 L p F P
0 g
s
0 .16 .692 r
.82019 .68601 m .81692 .68227 L .81594 .67997 L p F P
0 g
s
.126 .334 .8 r
.6568 .72502 m .66069 .72788 L .66105 .73194 L p F P
0 g
s
.159 .355 .809 r
.66105 .73194 m .66706 .73614 L .66739 .74019 L p F P
0 g
s
.068 .308 .792 r
.66069 .72788 m .66105 .73194 L .66706 .73614 L p F P
0 g
s
0 0 0 r
.83704 .75349 m .83644 .75765 L .83592 .76381 L p F P
0 g
s
0 0 .155 r
.83644 .75765 m .83704 .75349 L .83682 .74754 L p F P
0 g
s
.901 .504 .084 r
.58886 .61179 m .5896 .6141 L .58645 .61026 L p F P
0 g
s
.901 .504 .084 r
.58645 .61026 m .58581 .60825 L .58886 .61179 L p F P
0 g
s
.926 .548 .152 r
.58886 .61179 m .58581 .60825 L .58445 .60298 L p F P
0 g
s
.176 .423 .859 r
.7769 .62795 m .77578 .62396 L .76856 .62032 L p F P
0 g
s
.171 .425 .861 r
.76727 .61636 m .76856 .62032 L .77578 .62396 L p F P
0 g
s
.193 .445 .871 r
.7631 .61443 m .76727 .61636 L .76856 .62032 L p F P
0 g
s
.648 .832 .971 r
.79511 .81596 m .78247 .82071 L .77968 .81764 L p F P
0 g
s
.281 .448 .849 r
.68795 .76451 m .68537 .76335 L .68229 .75758 L p F P
0 g
s
.131 .346 .809 r
.67388 .74839 m .67356 .74436 L .66739 .74019 L p F P
0 g
s
.081 .32 .798 r
.66706 .73614 m .66739 .74019 L .67356 .74436 L p F P
0 g
s
.288 .547 .921 r
.72475 .58419 m .72215 .5835 L .71922 .57941 L p F P
0 g
s
0 .16 .692 r
.81594 .67997 m .81564 .67723 L p .82019 .68601 L F P
0 g
s
0 .209 .726 r
.81594 .67997 m .81392 .6755 L .81564 .67723 L closepath p F P
0 g
s
.838 .838 .37 r
.83178 .78129 m .83182 .78096 L .83401 .77433 L p F P
0 g
s
.862 .857 .403 r
.83458 .77021 m .83401 .77433 L .83182 .78096 L p F P
0 g
s
.762 .73 .203 r
.83401 .77433 m .83458 .77021 L .83592 .76381 L p F P
0 g
s
.476 .611 .906 r
.72953 .8035 m .73921 .80449 L .73847 .80864 L p F P
0 g
s
.458 .599 .905 r
.73921 .80449 m .72953 .8035 L .72655 .79872 L p F P
0 g
s
.445 .604 .913 r
.73847 .80864 m .7454 .80919 L .74246 .80486 L p F P
0 g
s
.445 .604 .913 r
.74246 .80486 m .73921 .80449 L .73847 .80864 L p F P
0 g
s
.407 .548 .884 r
.71381 .79142 m .72355 .79387 L p .72498 .79837 L F P
0 g
s
.364 .523 .881 r
.71381 .79142 m .72355 .79387 L .72055 .78896 L p F P
0 g
s
.364 .523 .881 r
.72055 .78896 m .71448 .78724 L .71381 .79142 L p F P
0 g
s
.395 .538 .881 r
.70755 .78536 m .71448 .78724 L .71381 .79142 L p F P
0 g
s
.156 .368 .82 r
.6792 .75183 m .67388 .74839 L p .68058 .75654 L F P
0 g
s
.129 .344 .808 r
.67388 .74839 m .6792 .75183 L .6761 .74608 L p F P
0 g
s
.129 .344 .808 r
.6761 .74608 m .67356 .74436 L .67388 .74839 L p F P
0 g
s
.514 .677 .939 r
.75885 .81704 m .76407 .81667 L .7612 .81291 L p F P
0 g
s
.514 .677 .939 r
.7612 .81291 m .75938 .81298 L .75885 .81704 L p F P
0 g
s
.543 .677 .925 r
.74833 .81344 m .75938 .81298 L .75885 .81704 L p F P
0 g
s
.526 .664 .924 r
.75938 .81298 m .74833 .81344 L .7454 .80919 L p F P
0 g
s
.447 .673 .96 r
.64713 .54659 m .65583 .54672 L .65877 .55037 L p F P
0 g
s
0 0 .431 r
.83307 .71849 m .83303 .72258 L .83495 .72801 L p F P
0 g
s
0 0 .507 r
.83303 .72258 m .83307 .71849 L .83065 .71321 L p F P
0 g
s
.354 .603 .942 r
.69664 .56802 m .70036 .56862 L .69739 .56472 L p F P
0 g
s
.354 .603 .942 r
.69739 .56472 m .69431 .56423 L .69664 .56802 L p F P
0 g
s
.867 .996 .79 r
.82194 .79967 m .82209 .79914 L .8224 .79913 L closepath p F P
0 g
s
.843 .969 .88 r
.82209 .79914 m .82194 .79967 L .81329 .80806 L p F P
0 g
s
.18 .417 .854 r
.7824 .63094 m .7769 .62795 L p .78482 .63572 L F P
0 g
s
.151 .402 .848 r
.7769 .62795 m .7824 .63094 L .77949 .62598 L p F P
0 g
s
.151 .402 .848 r
.77949 .62598 m .77578 .62396 L .7769 .62795 L p F P
0 g
s
.814 .948 .909 r
.81329 .80806 m .81025 .81059 L .80763 .80898 L p F P
0 g
s
.814 .948 .909 r
.80763 .80898 m .81412 .80394 L .81329 .80806 L p F P
0 g
s
.843 .969 .88 r
.8199 .79873 m .82209 .79914 L p .81329 .80806 L F P
0 g
s
.843 .969 .88 r
.81329 .80806 m .81412 .80394 L .8199 .79873 L p F P
0 g
s
.091 .317 .794 r
.66069 .72788 m .6568 .72502 L .65458 .72076 L p F P
0 g
s
.168 .379 .826 r
.68229 .75758 m .68058 .75654 L .68041 .7541 L closepath p F P
0 g
s
.156 .368 .82 r
.68058 .75654 m .68041 .7541 L .6792 .75183 L p F P
0 g
s
.184 .443 .872 r
.76727 .61636 m .7631 .61443 L .76019 .60978 L p F P
0 g
s
.374 .527 .88 r
.71448 .78724 m .70755 .78536 L .70451 .78007 L p F P
0 g
s
.441 .67 .959 r
.65877 .55037 m .66281 .55046 L .6598 .5468 L p F P
0 g
s
.441 .67 .959 r
.6598 .5468 m .65583 .54672 L .65877 .55037 L p F P
0 g
s
.233 .484 .89 r
.7582 .60893 m .75677 .60498 L .74836 .60175 L p F P
0 g
s
.245 .499 .898 r
.74674 .59784 m .74836 .60175 L .75677 .60498 L p F P
0 g
s
.241 .498 .898 r
.7411 .59582 m .74674 .59784 L .74836 .60175 L p F P
0 g
s
.866 .45 .005 r
.59069 .61694 m .5896 .6141 L .58645 .61026 L p F P
0 g
s
.397 .637 .952 r
.67911 .55876 m .68156 .55899 L .67857 .55522 L p F P
0 g
s
.397 .637 .952 r
.67857 .55522 m .6765 .55503 L .67911 .55876 L p F P
0 g
s
.888 .984 .811 r
.8199 .79873 m .82263 .79557 L .82209 .79914 L closepath p F P
0 g
s
.921 .977 .74 r
.828 .78805 m .82263 .79557 L .82209 .79914 L p F P
0 g
s
0 .051 .615 r
.62652 .67721 m .62487 .67524 L .62172 .66952 L p F P
0 g
s
0 0 .505 r
.83059 .70912 m .83065 .71321 L .83307 .71849 L p F P
0 g
s
0 0 .566 r
.83065 .71321 m .83059 .70912 L .82771 .70399 L p F P
0 g
s
0 0 .14 r
.83685 .74732 m .83682 .74754 L .83704 .75349 L p F P
0 g
s
0 .207 .725 r
.81564 .67723 m .81392 .6755 L .81092 .66894 L p F P
0 g
s
.234 .498 .9 r
.74674 .59784 m .7411 .59582 L .73818 .5915 L p F P
0 g
s
.129 .374 .831 r
.78531 .63602 m .78482 .63572 L .78459 .63474 L closepath p F P
0 g
s
.18 .417 .854 r
.78482 .63572 m .78459 .63474 L .7824 .63094 L p F P
0 g
s
.301 .461 .853 r
.68795 .76451 m .69602 .76823 L .69598 .7723 L p F P
0 g
s
.227 .433 .854 r
.68811 .76039 m .68795 .76451 L .69602 .76823 L p F P
0 g
s
.281 .448 .849 r
.68229 .75758 m .68811 .76039 L .68795 .76451 L p F P
0 g
s
.28 .534 .915 r
.73619 .59087 m .7344 .58698 L .72475 .58419 L p F P
0 g
s
.296 .55 .922 r
.72276 .58035 m .72475 .58419 L .7344 .58698 L p F P
0 g
s
.288 .547 .921 r
.71922 .57941 m .72276 .58035 L .72475 .58419 L p F P
0 g
s
0 0 .095 r
.83705 .74345 m .83685 .74732 L .83711 .75289 L p F P
0 g
s
0 0 .234 r
.83685 .74732 m .83705 .74345 L .83621 .73769 L p F P
0 g
s
0 0 .14 r
.83704 .75349 m .83711 .75289 L .83685 .74732 L p F P
0 g
s
.109 .356 .821 r
.78531 .63602 m .79104 .63972 L .79198 .64373 L p F P
0 g
s
.096 .352 .82 r
.79104 .63972 m .78531 .63602 L .78459 .63474 L p F P
0 g
s
.885 .912 .508 r
.8316 .78148 m .83182 .78096 L .83178 .78129 L closepath p F P
0 g
s
0 0 .565 r
.82754 .69991 m .82771 .70399 L .83059 .70912 L p F P
0 g
s
0 .059 .615 r
.82771 .70399 m .82754 .69991 L .82422 .69492 L p F P
0 g
s
.382 .554 .9 r
.72655 .79872 m .72498 .79837 L .72514 .79645 L closepath p F P
0 g
s
.407 .548 .884 r
.72355 .79387 m .72514 .79645 L .72498 .79837 L p F P
0 g
s
.256 .435 .847 r
.68811 .76039 m .68229 .75758 L .68041 .7541 L p F P
0 g
s
.087 .329 .805 r
.79866 .65188 m .79786 .64785 L .79198 .64373 L p F P
0 g
s
.081 .331 .807 r
.79104 .63972 m .79198 .64373 L .79786 .64785 L p F P
0 g
s
0 0 0 r
.83592 .76381 m .8365 .75966 L .83704 .75349 L p F P
0 g
s
.773 .74 .217 r
.8365 .75966 m .83592 .76381 L .83458 .77021 L p F P
0 g
s
.906 .934 .562 r
.83182 .78096 m .8316 .78148 L .8293 .78319 L p F P
0 g
s
.906 .934 .562 r
.8293 .78319 m .83231 .77688 L .83182 .78096 L p F P
0 g
s
.862 .857 .403 r
.83182 .78096 m .83231 .77688 L .83458 .77021 L p F P
0 g
s
.277 .465 .864 r
.70146 .7747 m .69598 .7723 L p .70435 .78001 L F P
0 g
s
.253 .442 .853 r
.69598 .7723 m .70146 .7747 L .69841 .76935 L p F P
0 g
s
.253 .442 .853 r
.69841 .76935 m .69602 .76823 L .69598 .7723 L p F P
0 g
s
.091 .317 .794 r
.65458 .72076 m .65444 .71959 L p .66069 .72788 L F P
0 g
s
.067 .296 .782 r
.65458 .72076 m .65368 .719 L .65444 .71959 L closepath p F P
0 g
s
.576 .755 .963 r
.76407 .81667 m .77687 .81441 L .77968 .81764 L p F P
0 g
s
.561 .739 .96 r
.77687 .81441 m .76407 .81667 L .7612 .81291 L p F P
0 g
s
.873 .944 .58 r
.828 .78805 m .8316 .78148 L .8293 .78319 L p F P
0 g
s
.359 .611 .946 r
.68156 .55899 m .69183 .56047 L .69431 .56423 L p F P
0 g
s
.356 .613 .948 r
.69183 .56047 m .68156 .55899 L .67857 .55522 L p F P
0 g
s
0 .056 .615 r
.82392 .69086 m .82422 .69492 L .82754 .69991 L p F P
0 g
s
0 .111 .656 r
.82422 .69492 m .82392 .69086 L .82019 .68601 L p F P
0 g
s
.096 .352 .82 r
.78459 .63474 m .78377 .63173 L p .79104 .63972 L F P
0 g
s
.131 .384 .839 r
.78459 .63474 m .7824 .63094 L .78377 .63173 L closepath p F P
0 g
s
.207 .463 .881 r
.7582 .60893 m .76019 .60978 L .75728 .6052 L p F P
0 g
s
.207 .463 .881 r
.75728 .6052 m .75677 .60498 L .7582 .60893 L p F P
0 g
s
.322 .579 .934 r
.70036 .56862 m .708 .5702 L .71022 .57401 L p F P
0 g
s
.317 .58 .936 r
.708 .5702 m .70036 .56862 L .69739 .56472 L p F P
0 g
s
.071 .304 .788 r
.80486 .66017 m .80421 .65612 L .79866 .65188 L p F P
0 g
s
.075 .316 .796 r
.79786 .64785 m .79866 .65188 L .80421 .65612 L p F P
0 g
s
0 0 .224 r
.83635 .7336 m .83621 .73769 L .83705 .74345 L p F P
0 g
s
0 0 .342 r
.83621 .73769 m .83635 .7336 L .83495 .72801 L p F P
0 g
s
0 .11 .656 r
.81977 .68195 m .82019 .68601 L .82392 .69086 L p F P
0 g
s
0 .16 .692 r
.81564 .67723 m .81977 .68195 L .82019 .68601 L p F P
0 g
s
.057 .283 .773 r
.80795 .66281 m .80486 .66017 L p .81057 .66861 L F P
0 g
s
.024 .262 .762 r
.80486 .66017 m .80795 .66281 L .80499 .65678 L p F P
0 g
s
.024 .262 .762 r
.80499 .65678 m .80421 .65612 L .80486 .66017 L p F P
0 g
s
.458 .599 .905 r
.72655 .79872 m .73948 .80046 L .73921 .80449 L p F P
0 g
s
.44 .588 .903 r
.73948 .80046 m .72655 .79872 L .72514 .79645 L p F P
0 g
s
.717 .864 .951 r
.79841 .81423 m .79511 .81596 L .79238 .81339 L p F P
0 g
s
.648 .832 .971 r
.77968 .81764 m .79238 .81339 L .79511 .81596 L p F P
0 g
s
.401 .644 .955 r
.66281 .55046 m .67373 .55133 L .6765 .55503 L p F P
0 g
s
.398 .646 .957 r
.67373 .55133 m .66281 .55046 L .6598 .5468 L p F P
0 g
s
0 0 .469 r
.62172 .66952 m .62115 .66868 L .62016 .66682 L closepath p F P
0 g
s
0 0 .423 r
.61857 .664 m .61607 .66006 L p .62115 .66868 L F P
0 g
s
0 0 .423 r
.62115 .66868 m .62016 .66682 L .61857 .664 L p F P
0 g
s
0 0 .401 r
.61607 .66006 m .61857 .664 L .61541 .65872 L p F P
0 g
s
0 .156 .691 r
.8151 .67319 m .81564 .67723 L .81977 .68195 L p F P
0 g
s
0 .207 .725 r
.81092 .66894 m .8151 .67319 L .81564 .67723 L p F P
0 g
s
.053 .293 .782 r
.65444 .71959 m .65368 .719 L .65054 .71304 L p F P
0 g
s
0 .1 .656 r
.62652 .67721 m .63051 .68186 L .63201 .68571 L p F P
0 g
s
0 .035 .6 r
.62489 .67338 m .62652 .67721 L .63051 .68186 L p F P
0 g
s
0 .051 .615 r
.62172 .66952 m .62489 .67338 L .62652 .67721 L p F P
0 g
s
.651 .24 0 r
.61099 .65143 m .6087 .64774 L .60592 .64281 L p F P
0 g
s
0 .223 .735 r
.81092 .66894 m .81057 .66861 L .8105 .66804 L closepath p F P
0 g
s
.057 .283 .773 r
.81057 .66861 m .8105 .66804 L .80795 .66281 L p F P
0 g
s
.691 .266 0 r
.60346 .63914 m .60592 .64281 L .6087 .64774 L p F P
0 g
s
.707 .288 0 r
.60592 .64281 m .60346 .63914 L .60084 .63418 L p F P
0 g
s
.741 .311 0 r
.59821 .63055 m .60084 .63418 L .60346 .63914 L p F P
0 g
s
.762 .338 0 r
.60084 .63418 m .59821 .63055 L .59577 .62556 L p F P
0 g
s
.311 .571 .932 r
.71022 .57401 m .71628 .57537 L .71334 .57139 L p F P
0 g
s
.311 .571 .932 r
.71334 .57139 m .708 .5702 L .71022 .57401 L p F P
0 g
s
.789 .356 0 r
.59294 .62197 m .59577 .62556 L .59821 .63055 L p F P
0 g
s
.814 .389 0 r
.59577 .62556 m .59294 .62197 L .59069 .61694 L p F P
0 g
s
0 .099 .655 r
.63752 .69421 m .63614 .69034 L .63201 .68571 L p F P
0 g
s
0 .062 .624 r
.63051 .68186 m .63201 .68571 L .63614 .69034 L p F P
0 g
s
.833 .403 0 r
.58766 .61339 m .59069 .61694 L .59294 .62197 L p F P
0 g
s
.866 .45 .005 r
.58645 .61026 m .58766 .61339 L .59069 .61694 L p F P
0 g
s
0 .124 .674 r
.64305 .7027 m .64178 .69882 L .63752 .69421 L p F P
0 g
s
0 .088 .646 r
.63614 .69034 m .63752 .69421 L .64178 .69882 L p F P
0 g
s
.283 .548 .923 r
.72276 .58035 m .71922 .57941 L .71628 .57537 L p F P
0 g
s
0 .152 .694 r
.64741 .70724 m .64305 .7027 L p .64865 .71117 L F P
0 g
s
0 .13 .679 r
.64305 .7027 m .64741 .70724 L .64428 .70149 L p F P
0 g
s
0 .13 .679 r
.64428 .70149 m .64178 .69882 L .64305 .7027 L p F P
0 g
s
0 .196 .72 r
.8151 .67319 m .81092 .66894 L .8105 .66804 L p F P
0 g
s
.631 .813 .97 r
.79238 .81339 m .77968 .81764 L .77687 .81441 L p F P
0 g
s
.285 .472 .868 r
.70451 .78007 m .70435 .78001 L .70436 .7798 L closepath p F P
0 g
s
.277 .465 .864 r
.70435 .78001 m .70436 .7798 L .70146 .7747 L p F P
0 g
s
.526 .664 .924 r
.7454 .80919 m .75831 .80904 L p .75938 .81298 L F P
0 g
s
.482 .659 .939 r
.75831 .80904 m .7454 .80919 L .74246 .80486 L p F P
0 g
s
.26 .52 .909 r
.73619 .59087 m .73818 .5915 L .73526 .58725 L p F P
0 g
s
.26 .52 .909 r
.73526 .58725 m .7344 .58698 L .73619 .59087 L p F P
0 g
s
0 .177 .712 r
.65054 .71304 m .64865 .71117 L .64749 .70739 L closepath p F P
0 g
s
0 .152 .694 r
.64865 .71117 m .64749 .70739 L .64741 .70724 L p F P
0 g
s
.374 .527 .88 r
.70451 .78007 m .71473 .78315 L .71448 .78724 L p F P
0 g
s
.355 .514 .878 r
.71473 .78315 m .70451 .78007 L .70436 .7798 L p F P
0 g
s
.256 .435 .847 r
.68041 .7541 m .68046 .75248 L p .68811 .76039 L F P
0 g
s
.238 .421 .841 r
.68041 .7541 m .6792 .75183 L .68046 .75248 L closepath p F P
0 g
s
.717 .864 .951 r
.79238 .81339 m .79913 .81013 L .79841 .81423 L p F P
0 g
s
.746 .912 .949 r
.80497 .8071 m .79913 .81013 L .79841 .81423 L p F P
0 g
s
.746 .912 .949 r
.79841 .81423 m .80763 .80898 L .80497 .8071 L p F P
0 g
s
.355 .514 .878 r
.70436 .7798 m .70489 .77582 L p .71473 .78315 L F P
0 g
s
.341 .504 .874 r
.70436 .7798 m .70146 .7747 L .70489 .77582 L closepath p F P
0 g
s
0 .196 .72 r
.8105 .66804 m .80993 .66458 L p .8151 .67319 L F P
0 g
s
.001 .244 .751 r
.8105 .66804 m .80795 .66281 L .80993 .66458 L closepath p F P
0 g
s
0 .024 .59 r
.62489 .67338 m .62172 .66952 L .62016 .66682 L p F P
0 g
s
.091 .317 .794 r
.65444 .71959 m .66003 .72388 L .66069 .72788 L p F P
0 g
s
0 .268 .771 r
.65372 .71559 m .65444 .71959 L .66003 .72388 L p F P
0 g
s
.053 .293 .782 r
.65054 .71304 m .65372 .71559 L .65444 .71959 L p F P
0 g
s
.171 .425 .861 r
.77578 .62396 m .77456 .61999 L .76727 .61636 L p F P
0 g
s
.167 .427 .864 r
.76588 .61241 m .76727 .61636 L .77456 .61999 L p F P
0 g
s
.184 .443 .872 r
.76019 .60978 m .76588 .61241 L .76727 .61636 L p F P
0 g
s
0 0 .431 r
.83495 .72801 m .83501 .72392 L .83307 .71849 L p F P
0 g
s
0 0 .336 r
.83501 .72392 m .83495 .72801 L .83635 .7336 L p F P
0 g
s
.176 .442 .873 r
.76588 .61241 m .76019 .60978 L .75728 .6052 L p F P
0 g
s
.068 .308 .792 r
.66706 .73614 m .66643 .73215 L .66069 .72788 L p F P
0 g
s
.016 .28 .778 r
.66003 .72388 m .66069 .72788 L .66643 .73215 L p F P
0 g
s
.903 .986 .754 r
.82889 .78386 m .828 .78805 L .82263 .79557 L p F P
0 g
s
.873 .944 .58 r
.8293 .78319 m .82889 .78386 L .828 .78805 L p F P
0 g
s
0 0 0 r
.83711 .75289 m .83704 .75349 L .8365 .75966 L p F P
0 g
s
.44 .588 .903 r
.72514 .79645 m .72567 .7942 L p .73948 .80046 L F P
0 g
s
.43 .58 .901 r
.72514 .79645 m .72355 .79387 L .72567 .7942 L closepath p F P
0 g
s
.351 .605 .944 r
.69431 .56423 m .69739 .56472 L .69443 .56088 L p F P
0 g
s
.351 .605 .944 r
.69443 .56088 m .69183 .56047 L .69431 .56423 L p F P
0 g
s
.081 .32 .798 r
.67356 .74436 m .67296 .74039 L .66706 .73614 L p F P
0 g
s
.055 .307 .793 r
.66643 .73215 m .66706 .73614 L .67296 .74039 L p F P
0 g
s
.233 .421 .842 r
.68046 .75248 m .6792 .75183 L .6761 .74608 L p F P
0 g
s
.123 .383 .84 r
.78377 .63173 m .7824 .63094 L .77949 .62598 L p F P
0 g
s
.234 .498 .9 r
.73818 .5915 m .74501 .59395 L .74674 .59784 L p F P
0 g
s
.227 .498 .901 r
.74501 .59395 m .73818 .5915 L .73526 .58725 L p F P
0 g
s
.871 .867 .421 r
.83512 .76608 m .83458 .77021 L .83231 .77688 L p F P
0 g
s
.773 .74 .217 r
.83458 .77021 m .83512 .76608 L .8365 .75966 L p F P
0 g
s
.142 .401 .849 r
.77578 .62396 m .77949 .62598 L .77657 .62108 L p F P
0 g
s
.142 .401 .849 r
.77657 .62108 m .77456 .61999 L .77578 .62396 L p F P
0 g
s
.087 .325 .801 r
.67356 .74436 m .6761 .74608 L .673 .74042 L p F P
0 g
s
.087 .325 .801 r
.673 .74042 m .67296 .74039 L .67356 .74436 L p F P
0 g
s
0 0 .095 r
.83711 .75289 m .83729 .7494 L .83705 .74345 L p F P
0 g
s
.727 .631 .067 r
.83729 .7494 m .83711 .75289 L .83674 .75773 L p F P
0 g
s
0 0 0 r
.8365 .75966 m .83674 .75773 L .83711 .75289 L p F P
0 g
s
.421 .595 .916 r
.73921 .80449 m .74246 .80486 L .73951 .80046 L p F P
0 g
s
.421 .595 .916 r
.73951 .80046 m .73948 .80046 L .73921 .80449 L p F P
0 g
s
0 0 .428 r
.83303 .7144 m .83307 .71849 L .83501 .72392 L p F P
0 g
s
0 0 .505 r
.83307 .71849 m .83303 .7144 L .83059 .70912 L p F P
0 g
s
.394 .639 .954 r
.6765 .55503 m .67857 .55522 L .67558 .5515 L p F P
0 g
s
.394 .639 .954 r
.67558 .5515 m .67373 .55133 L .6765 .55503 L p F P
0 g
s
.335 .512 .883 r
.71448 .78724 m .72055 .78896 L .71754 .78404 L p F P
0 g
s
.335 .512 .883 r
.71754 .78404 m .71473 .78315 L .71448 .78724 L p F P
0 g
s
0 .024 .59 r
.62016 .66682 m .61926 .6649 L p .62489 .67338 L F P
0 g
s
0 0 .558 r
.62016 .66682 m .61857 .664 L .61926 .6649 L closepath p F P
0 g
s
.512 .681 .943 r
.7612 .81291 m .75938 .81298 L .75948 .81062 L closepath p F P
0 g
s
.526 .664 .924 r
.75831 .80904 m .75948 .81062 L .75938 .81298 L p F P
0 g
s
.799 .94 .92 r
.81412 .80394 m .80763 .80898 L .80497 .8071 L p F P
0 g
s
.245 .499 .898 r
.75437 .60075 m .74674 .59784 L p .75677 .60498 L F P
0 g
s
.217 .486 .895 r
.74674 .59784 m .75437 .60075 L .75145 .5964 L p F P
0 g
s
.217 .486 .895 r
.75145 .5964 m .74501 .59395 L .74674 .59784 L p F P
0 g
s
.879 .981 .832 r
.82263 .79557 m .8199 .79873 L .81735 .79788 L p F P
0 g
s
.879 .981 .832 r
.81735 .79788 m .82326 .79146 L .82263 .79557 L p F P
0 g
s
.903 .986 .754 r
.82263 .79557 m .82326 .79146 L .82889 .78386 L p F P
0 g
s
.013 .273 .773 r
.65372 .71559 m .65054 .71304 L .64749 .70739 L p F P
0 g
s
.256 .435 .847 r
.68046 .75248 m .68794 .75634 L .68811 .76039 L p F P
0 g
s
.175 .398 .84 r
.68035 .74839 m .68046 .75248 L .68794 .75634 L p F P
0 g
s
.233 .421 .842 r
.6761 .74608 m .68035 .74839 L .68046 .75248 L p F P
0 g
s
.296 .55 .922 r
.73233 .58307 m .72276 .58035 L p .7344 .58698 L F P
0 g
s
.268 .538 .92 r
.72276 .58035 m .73233 .58307 L .7294 .579 L p F P
0 g
s
.268 .538 .92 r
.7294 .579 m .72064 .57652 L .72276 .58035 L p F P
0 g
s
.283 .548 .923 r
.71628 .57537 m .72064 .57652 L .72276 .58035 L p F P
0 g
s
.799 .94 .92 r
.80497 .8071 m .8151 .79975 L .81412 .80394 L p F P
0 g
s
.837 .98 .875 r
.81735 .79788 m .8151 .79975 L .81412 .80394 L p F P
0 g
s
.837 .98 .875 r
.81412 .80394 m .8199 .79873 L .81735 .79788 L p F P
0 g
s
0 .241 .751 r
.80993 .66458 m .80795 .66281 L .80499 .65678 L p F P
0 g
s
.096 .352 .82 r
.78377 .63173 m .78998 .63574 L .79104 .63972 L p F P
0 g
s
.089 .354 .823 r
.78256 .62777 m .78377 .63173 L .78998 .63574 L p F P
0 g
s
.123 .383 .84 r
.77949 .62598 m .78256 .62777 L .78377 .63173 L p F P
0 g
s
0 0 .503 r
.83045 .70504 m .83059 .70912 L .83303 .7144 L p F P
0 g
s
0 0 .565 r
.83059 .70912 m .83045 .70504 L .82754 .69991 L p F P
0 g
s
.432 .579 .9 r
.72567 .7942 m .72355 .79387 L .72055 .78896 L p F P
0 g
s
.56 .705 .938 r
.7712 .80757 m .77404 .81105 L .7612 .81291 L p F P
0 g
s
.56 .705 .938 r
.76024 .80881 m .7712 .80757 L p .7612 .81291 L F P
0 g
s
.56 .705 .938 r
.7612 .81291 m .75948 .81062 L .76024 .80881 L p F P
0 g
s
.561 .739 .96 r
.7612 .81291 m .77404 .81105 L .77687 .81441 L p F P
0 g
s
0 0 .08 r
.8372 .73937 m .83705 .74345 L .83729 .7494 L p F P
0 g
s
0 0 .224 r
.83705 .74345 m .8372 .73937 L .83635 .7336 L p F P
0 g
s
.356 .613 .948 r
.67857 .55522 m .68921 .55674 L .69183 .56047 L p F P
0 g
s
.352 .615 .949 r
.68921 .55674 m .67857 .55522 L .67558 .5515 L p F P
0 g
s
.317 .58 .936 r
.69739 .56472 m .70565 .56642 L .708 .5702 L p F P
0 g
s
.313 .582 .938 r
.70565 .56642 m .69739 .56472 L .69443 .56088 L p F P
0 g
s
.34 .504 .875 r
.70489 .77582 m .70146 .7747 L .69841 .76935 L p F P
0 g
s
.227 .433 .854 r
.69535 .76402 m .68811 .76039 L p .69602 .76823 L F P
0 g
s
.209 .412 .842 r
.68811 .76039 m .69535 .76402 L .69228 .75866 L p F P
0 g
s
.209 .412 .842 r
.69228 .75866 m .68794 .75634 L .68811 .76039 L p F P
0 g
s
0 0 .536 r
.61926 .6649 m .61857 .664 L .61541 .65872 L p F P
0 g
s
.081 .331 .807 r
.79786 .64785 m .79696 .64384 L .79104 .63972 L p F P
0 g
s
.075 .332 .809 r
.78998 .63574 m .79104 .63972 L .79696 .64384 L p F P
0 g
s
0 0 .565 r
.82728 .69584 m .82754 .69991 L .83045 .70504 L p F P
0 g
s
0 .056 .615 r
.82754 .69991 m .82728 .69584 L .82392 .69086 L p F P
0 g
s
.482 .659 .939 r
.74246 .80486 m .75541 .80506 L .75831 .80904 L p F P
0 g
s
.468 .648 .937 r
.75541 .80506 m .74246 .80486 L .73951 .80046 L p F P
0 g
s
.398 .646 .957 r
.6598 .5468 m .6708 .54767 L .67373 .55133 L p F P
0 g
s
.199 .463 .883 r
.75728 .6052 m .75677 .60498 L .75619 .60352 L closepath p F P
0 g
s
.245 .499 .898 r
.75677 .60498 m .75619 .60352 L .75437 .60075 L p F P
0 g
s
.277 .55 .925 r
.72064 .57652 m .71628 .57537 L .71334 .57139 L p F P
0 g
s
.075 .316 .796 r
.80204 .65104 m .79786 .64785 L p .80421 .65612 L F P
0 g
s
.041 .295 .786 r
.79786 .64785 m .80204 .65104 L .7991 .64548 L p F P
0 g
s
.041 .295 .786 r
.7991 .64548 m .79696 .64384 L .79786 .64785 L p F P
0 g
s
.204 .407 .839 r
.68035 .74839 m .6761 .74608 L .673 .74042 L p F P
0 g
s
.44 .588 .903 r
.72567 .7942 m .73655 .79596 L p .73948 .80046 L F P
0 g
s
.404 .565 .899 r
.72567 .7942 m .73655 .79596 L .73358 .79142 L p F P
0 g
s
.404 .565 .899 r
.73358 .79142 m .72632 .79002 L .72567 .7942 L p F P
0 g
s
.432 .579 .9 r
.72055 .78896 m .72632 .79002 L .72567 .7942 L p F P
0 g
s
.833 .403 0 r
.59294 .62197 m .5899 .61843 L .58766 .61339 L p F P
0 g
s
0 .055 .615 r
.82354 .6868 m .82392 .69086 L .82728 .69584 L p F P
0 g
s
0 .11 .656 r
.82392 .69086 m .82354 .6868 L .81977 .68195 L p F P
0 g
s
.789 .356 0 r
.59821 .63055 m .59536 .62697 L .59294 .62197 L p F P
0 g
s
.81 .37 0 r
.5899 .61843 m .59294 .62197 L .59536 .62697 L p F P
0 g
s
.741 .311 0 r
.60346 .63914 m .6008 .63552 L .59821 .63055 L p F P
0 g
s
.768 .329 0 r
.59536 .62697 m .59821 .63055 L .6008 .63552 L p F P
0 g
s
.7 .855 .957 r
.79913 .81013 m .79238 .81339 L .78962 .81064 L p F P
0 g
s
.631 .813 .97 r
.77687 .81441 m .78962 .81064 L .79238 .81339 L p F P
0 g
s
.691 .266 0 r
.6087 .64774 m .6062 .64409 L .60346 .63914 L p F P
0 g
s
.724 .288 0 r
.6008 .63552 m .60346 .63914 L .6062 .64409 L p F P
0 g
s
.794 .764 .252 r
.83674 .75773 m .8365 .75966 L .83512 .76608 L p F P
0 g
s
.64 .224 0 r
.61392 .65634 m .61157 .65266 L .6087 .64774 L p F P
0 g
s
.678 .249 0 r
.6062 .64409 m .6087 .64774 L .61157 .65266 L p F P
0 g
s
.94 .942 .605 r
.83231 .77688 m .83277 .77278 L p .829 .78334 L F P
0 g
s
.94 .942 .605 r
.829 .78334 m .8293 .78319 L .83231 .77688 L p F P
0 g
s
.871 .867 .421 r
.83231 .77688 m .83277 .77278 L .83512 .76608 L p F P
0 g
s
.609 .19 0 r
.61226 .65376 m .61157 .65266 L .61392 .65634 L p F P
0 g
s
.237 .443 .859 r
.69841 .76935 m .69602 .76823 L .69581 .76483 L closepath p F P
0 g
s
.227 .433 .854 r
.69602 .76823 m .69581 .76483 L .69535 .76402 L p F P
0 g
s
.176 .442 .873 r
.75728 .6052 m .76437 .60849 L .76588 .61241 L p F P
0 g
s
.166 .441 .873 r
.76437 .60849 m .75728 .6052 L .75619 .60352 L p F P
0 g
s
.615 .795 .968 r
.78962 .81064 m .77687 .81441 L .77404 .81105 L p F P
0 g
s
.306 .572 .933 r
.708 .5702 m .71334 .57139 L .71039 .56746 L p F P
0 g
s
.306 .572 .933 r
.71039 .56746 m .70565 .56642 L .708 .5702 L p F P
0 g
s
0 .024 .59 r
.61926 .6649 m .62304 .66959 L .62489 .67338 L p F P
0 g
s
0 0 .535 r
.61725 .66114 m .61926 .6649 L .62304 .66959 L p F P
0 g
s
0 0 .536 r
.61541 .65872 m .61725 .66114 L .61926 .6649 L p F P
0 g
s
0 .035 .6 r
.63051 .68186 m .62879 .67806 L .62489 .67338 L p F P
0 g
s
0 0 .565 r
.62304 .66959 m .62489 .67338 L .62879 .67806 L p F P
0 g
s
0 .108 .657 r
.81926 .67791 m .81977 .68195 L .82354 .6868 L p F P
0 g
s
0 .156 .691 r
.81977 .68195 m .81926 .67791 L .8151 .67319 L p F P
0 g
s
.011 .258 .762 r
.80499 .65678 m .80421 .65612 L .80395 .65471 L closepath p F P
0 g
s
.075 .316 .796 r
.80421 .65612 m .80395 .65471 L .80204 .65104 L p F P
0 g
s
0 0 .216 r
.83643 .72951 m .83635 .7336 L .8372 .73937 L p F P
0 g
s
0 0 .336 r
.83635 .7336 m .83643 .72951 L .83501 .72392 L p F P
0 g
s
0 .062 .624 r
.63614 .69034 m .63453 .68653 L .63051 .68186 L p F P
0 g
s
0 .027 .592 r
.62879 .67806 m .63051 .68186 L .63453 .68653 L p F P
0 g
s
0 .155 .692 r
.81446 .66917 m .8151 .67319 L .81926 .67791 L p F P
0 g
s
0 .196 .72 r
.80993 .66458 m .81446 .66917 L .8151 .67319 L p F P
0 g
s
0 .196 .721 r
.80915 .66057 m .80993 .66458 L .81446 .66917 L p F P
0 g
s
0 .241 .751 r
.80499 .65678 m .80915 .66057 L .80993 .66458 L p F P
0 g
s
0 .088 .646 r
.64178 .69882 m .64027 .69499 L .63614 .69034 L p F P
0 g
s
0 .055 .617 r
.63453 .68653 m .63614 .69034 L .64027 .69499 L p F P
0 g
s
.254 .52 .911 r
.73526 .58725 m .7344 .58698 L .73276 .58368 L closepath p F P
0 g
s
.296 .55 .922 r
.7344 .58698 m .73276 .58368 L .73233 .58307 L p F P
0 g
s
.112 .38 .839 r
.78256 .62777 m .77949 .62598 L .77657 .62108 L p F P
0 g
s
0 .102 .657 r
.64178 .69882 m .64428 .70149 L .64114 .69594 L p F P
0 g
s
0 .102 .657 r
.64114 .69594 m .64027 .69499 L .64178 .69882 L p F P
0 g
s
.013 .273 .773 r
.64749 .70739 m .64747 .70729 L p .65372 .71559 L F P
0 g
s
0 .251 .759 r
.64749 .70739 m .64741 .70724 L .64747 .70729 L closepath p F P
0 g
s
0 .245 .757 r
.64747 .70729 m .64741 .70724 L .64428 .70149 L p F P
0 g
s
.013 .273 .773 r
.64747 .70729 m .65273 .71166 L .65372 .71559 L p F P
0 g
s
0 .226 .747 r
.6464 .70335 m .64747 .70729 L .65273 .71166 L p F P
0 g
s
0 .245 .757 r
.64428 .70149 m .6464 .70335 L .64747 .70729 L p F P
0 g
s
.558 .703 .937 r
.75948 .81062 m .75831 .80904 L .76024 .80881 L closepath p F P
0 g
s
.167 .427 .864 r
.77456 .61999 m .77322 .61603 L .76588 .61241 L p F P
0 g
s
.176 .442 .872 r
.76437 .60849 m .76588 .61241 L .77322 .61603 L p F P
0 g
s
0 .233 .747 r
.80915 .66057 m .80499 .65678 L .80395 .65471 L p F P
0 g
s
.227 .498 .901 r
.73526 .58725 m .74316 .59007 L .74501 .59395 L p F P
0 g
s
.22 .499 .903 r
.74316 .59007 m .73526 .58725 L .73276 .58368 L p F P
0 g
s
0 .268 .771 r
.66003 .72388 m .6591 .71995 L .65372 .71559 L p F P
0 g
s
0 .239 .755 r
.65273 .71166 m .65372 .71559 L .6591 .71995 L p F P
0 g
s
.347 .607 .946 r
.69183 .56047 m .69443 .56088 L .69145 .55709 L p F P
0 g
s
.347 .607 .946 r
.69145 .55709 m .68921 .55674 L .69183 .56047 L p F P
0 g
s
.355 .514 .878 r
.70489 .77582 m .71452 .7791 L p .71473 .78315 L F P
0 g
s
.305 .486 .872 r
.70489 .77582 m .71452 .7791 L .71149 .77411 L p F P
0 g
s
.305 .486 .872 r
.71149 .77411 m .70506 .77172 L .70489 .77582 L p F P
0 g
s
.34 .504 .875 r
.69841 .76935 m .70506 .77172 L .70489 .77582 L p F P
0 g
s
.166 .441 .873 r
.75619 .60352 m .75515 .60107 L p .76437 .60849 L F P
0 g
s
.196 .466 .886 r
.75619 .60352 m .75437 .60075 L .75515 .60107 L closepath p F P
0 g
s
.7 .855 .957 r
.78962 .81064 m .80034 .80589 L .79913 .81013 L p F P
0 g
s
.729 .891 .954 r
.80228 .80497 m .80034 .80589 L .79913 .81013 L p F P
0 g
s
.729 .891 .954 r
.79913 .81013 m .80497 .8071 L .80228 .80497 L p F P
0 g
s
0 0 .428 r
.83501 .72392 m .835 .71983 L .83303 .7144 L p F P
0 g
s
0 0 .331 r
.835 .71983 m .83501 .72392 L .83643 .72951 L p F P
0 g
s
.016 .28 .778 r
.66643 .73215 m .66554 .72823 L .66003 .72388 L p F P
0 g
s
0 .259 .767 r
.6591 .71995 m .66003 .72388 L .66554 .72823 L p F P
0 g
s
.412 .568 .899 r
.72632 .79002 m .72055 .78896 L .71754 .78404 L p F P
0 g
s
.317 .493 .874 r
.70506 .77172 m .69841 .76935 L .69581 .76483 L p F P
0 g
s
.893 .965 .641 r
.82889 .78386 m .829 .78334 L .8293 .78319 L closepath p F P
0 g
s
.39 .641 .956 r
.67373 .55133 m .67558 .5515 L .67258 .54783 L p F P
0 g
s
.39 .641 .956 r
.67258 .54783 m .6708 .54767 L .67373 .55133 L p F P
0 g
s
0 .233 .747 r
.80395 .65471 m .80337 .65211 L p .80915 .66057 L F P
0 g
s
.02 .277 .775 r
.80395 .65471 m .80204 .65104 L .80337 .65211 L closepath p F P
0 g
s
0 0 .08 r
.83729 .7494 m .83743 .74533 L .8372 .73937 L p F P
0 g
s
.749 .647 .088 r
.83743 .74533 m .83729 .7494 L .83685 .75556 L p F P
0 g
s
.727 .631 .067 r
.83674 .75773 m .83685 .75556 L .83729 .7494 L p F P
0 g
s
.895 .987 .781 r
.829 .78334 m .82889 .78386 L .82326 .79146 L p F P
0 g
s
.055 .307 .793 r
.66989 .73476 m .66643 .73215 L p .67296 .74039 L F P
0 g
s
.02 .284 .781 r
.66643 .73215 m .66989 .73476 L .66678 .7292 L p F P
0 g
s
.02 .284 .781 r
.66678 .7292 m .66554 .72823 L .66643 .73215 L p F P
0 g
s
0 0 .503 r
.61725 .66114 m .61541 .65872 L .61226 .65376 L p F P
0 g
s
.132 .399 .849 r
.77456 .61999 m .77657 .62108 L .77366 .61626 L p F P
0 g
s
.132 .399 .849 r
.77366 .61626 m .77322 .61603 L .77456 .61999 L p F P
0 g
s
.56 .698 .933 r
.76024 .80881 m .75831 .80904 L .75541 .80506 L p F P
0 g
s
.821 .754 .237 r
.83576 .76144 m .83685 .75556 L .83674 .75773 L closepath p F P
0 g
s
.794 .764 .252 r
.83576 .76144 m .83674 .75773 L p .83512 .76608 L F P
0 g
s
.21 .486 .896 r
.74501 .59395 m .75145 .5964 L .74854 .59211 L p F P
0 g
s
.21 .486 .896 r
.74854 .59211 m .74316 .59007 L .74501 .59395 L p F P
0 g
s
.071 .322 .802 r
.673 .74042 m .67296 .74039 L .67294 .74032 L closepath p F P
0 g
s
.055 .307 .793 r
.67296 .74039 m .67294 .74032 L .66989 .73476 L p F P
0 g
s
.204 .407 .839 r
.673 .74042 m .67992 .74437 L .68035 .74839 L p F P
0 g
s
.177 .393 .835 r
.67992 .74437 m .673 .74042 L .67294 .74032 L p F P
0 g
s
.177 .393 .835 r
.67294 .74032 m .67254 .73635 L p .67992 .74437 L F P
0 g
s
.158 .377 .827 r
.67294 .74032 m .66989 .73476 L .67254 .73635 L closepath p F P
0 g
s
.263 .54 .921 r
.72064 .57652 m .7294 .579 L .72646 .57499 L p F P
0 g
s
.263 .54 .921 r
.72646 .57499 m .7184 .57272 L .72064 .57652 L p F P
0 g
s
.277 .55 .925 r
.71334 .57139 m .7184 .57272 L .72064 .57652 L p F P
0 g
s
0 0 .425 r
.83292 .71031 m .83303 .7144 L .835 .71983 L p F P
0 g
s
0 0 .503 r
.83303 .7144 m .83292 .71031 L .83045 .70504 L p F P
0 g
s
.895 .987 .781 r
.82688 .78363 m .829 .78334 L p .82326 .79146 L F P
0 g
s
.924 .973 .703 r
.82688 .78363 m .82929 .77979 L .829 .78334 L closepath p F P
0 g
s
.94 .942 .605 r
.83277 .77278 m .82929 .77979 L .829 .78334 L p F P
0 g
s
.878 .875 .437 r
.83564 .76194 m .83512 .76608 L .83277 .77278 L p F P
0 g
s
.794 .764 .252 r
.83512 .76608 m .83564 .76194 L .83576 .76144 L p F P
0 g
s
.776 .948 .932 r
.8151 .79975 m .80497 .8071 L .80228 .80497 L p F P
0 g
s
.419 .596 .918 r
.73951 .80046 m .73948 .80046 L .73948 .80041 L closepath p F P
0 g
s
.44 .588 .903 r
.73655 .79596 m .73948 .80041 L .73948 .80046 L p F P
0 g
s
.468 .648 .937 r
.73951 .80046 m .75249 .801 L .75541 .80506 L p F P
0 g
s
.473 .626 .919 r
.74956 .79687 m .75249 .801 L .73951 .80046 L p F P
0 g
s
.473 .626 .919 r
.74044 .79621 m .74956 .79687 L p .73951 .80046 L F P
0 g
s
.473 .626 .919 r
.73951 .80046 m .73948 .80041 L .74044 .79621 L p F P
0 g
s
.313 .582 .938 r
.69443 .56088 m .70316 .56266 L .70565 .56642 L p F P
0 g
s
.308 .584 .94 r
.70316 .56266 m .69443 .56088 L .69145 .55709 L p F P
0 g
s
.47 .622 .917 r
.73948 .80041 m .73655 .79596 L .74044 .79621 L closepath p F P
0 g
s
.323 .516 .89 r
.71754 .78404 m .71473 .78315 L .71464 .7793 L closepath p F P
0 g
s
.355 .514 .878 r
.71452 .7791 m .71464 .7793 L .71473 .78315 L p F P
0 g
s
.352 .615 .949 r
.67558 .5515 m .68645 .55304 L .68921 .55674 L p F P
0 g
s
.348 .617 .951 r
.68645 .55304 m .67558 .5515 L .67258 .54783 L p F P
0 g
s
.089 .354 .823 r
.78998 .63574 m .78882 .63176 L .78256 .62777 L p F P
0 g
s
.082 .355 .825 r
.78125 .62382 m .78256 .62777 L .78882 .63176 L p F P
0 g
s
.112 .38 .839 r
.77657 .62108 m .78125 .62382 L .78256 .62777 L p F P
0 g
s
.538 .691 .938 r
.76024 .80881 m .7712 .80757 L .76833 .80399 L p F P
0 g
s
.538 .691 .938 r
.76833 .80399 m .76142 .80455 L .76024 .80881 L p F P
0 g
s
.56 .698 .933 r
.75541 .80506 m .76142 .80455 L .76024 .80881 L p F P
0 g
s
.175 .398 .84 r
.68794 .75634 m .68745 .75236 L .68035 .74839 L p F P
0 g
s
.141 .383 .836 r
.67992 .74437 m .68035 .74839 L .68745 .75236 L p F P
0 g
s
.887 .958 .841 r
.82326 .79146 m .82393 .78733 L p .81576 .79714 L F P
0 g
s
.887 .958 .841 r
.81576 .79714 m .81735 .79788 L .82326 .79146 L p F P
0 g
s
.895 .987 .781 r
.82326 .79146 m .82393 .78733 L .82688 .78363 L p F P
0 g
s
0 .224 .745 r
.6464 .70335 m .64428 .70149 L .64114 .69594 L p F P
0 g
s
.272 .551 .927 r
.7184 .57272 m .71334 .57139 L .71039 .56746 L p F P
0 g
s
.188 .466 .887 r
.75515 .60107 m .75437 .60075 L .75145 .5964 L p F P
0 g
s
0 0 .507 r
.83023 .70096 m .83045 .70504 L .83292 .71031 L p F P
0 g
s
0 0 .565 r
.83045 .70504 m .83023 .70096 L .82728 .69584 L p F P
0 g
s
.01 .275 .775 r
.80337 .65211 m .80204 .65104 L .7991 .64548 L p F P
0 g
s
.776 .948 .932 r
.81576 .79714 m .8151 .79975 L p .80228 .80497 L F P
0 g
s
.826 .965 .896 r
.8151 .79975 m .81576 .79714 L .81735 .79788 L closepath p F P
0 g
s
0 0 .069 r
.83729 .73529 m .8372 .73937 L .83743 .74533 L p F P
0 g
s
0 0 .216 r
.8372 .73937 m .83729 .73529 L .83643 .72951 L p F P
0 g
s
.1 .377 .839 r
.78125 .62382 m .77657 .62108 L .77366 .61626 L p F P
0 g
s
.075 .332 .809 r
.79696 .64384 m .79596 .63983 L .78998 .63574 L p F P
0 g
s
.08 .344 .817 r
.78882 .63176 m .78998 .63574 L .79596 .63983 L p F P
0 g
s
.615 .795 .968 r
.77404 .81105 m .78684 .80772 L .78962 .81064 L p F P
0 g
s
.599 .779 .966 r
.78684 .80772 m .77404 .81105 L .7712 .80757 L p F P
0 g
s
.81 .37 0 r
.59536 .62697 m .59232 .62343 L .5899 .61843 L p F P
0 g
s
.768 .329 0 r
.6008 .63552 m .59794 .63195 L .59536 .62697 L p F P
0 g
s
.789 .343 0 r
.59232 .62343 m .59536 .62697 L .59794 .63195 L p F P
0 g
s
.173 .396 .839 r
.68794 .75634 m .69228 .75866 L .6892 .75334 L p F P
0 g
s
.173 .396 .839 r
.6892 .75334 m .68745 .75236 L .68794 .75634 L p F P
0 g
s
.166 .441 .873 r
.75515 .60107 m .76275 .60458 L .76437 .60849 L p F P
0 g
s
.16 .444 .876 r
.75337 .59719 m .75515 .60107 L .76275 .60458 L p F P
0 g
s
.188 .466 .887 r
.75145 .5964 m .75337 .59719 L .75515 .60107 L p F P
0 g
s
.724 .288 0 r
.6062 .64409 m .60351 .64048 L .6008 .63552 L p F P
0 g
s
.75 .306 0 r
.59794 .63195 m .6008 .63552 L .60351 .64048 L p F P
0 g
s
.679 .857 .967 r
.80034 .80589 m .78962 .81064 L .78684 .80772 L p F P
0 g
s
0 0 .568 r
.82694 .69178 m .82728 .69584 L .83023 .70096 L p F P
0 g
s
0 .055 .615 r
.82728 .69584 m .82694 .69178 L .82354 .6868 L p F P
0 g
s
.678 .249 0 r
.61157 .65266 m .60904 .64902 L .6062 .64409 L p F P
0 g
s
.719 .281 0 r
.60351 .64048 m .6062 .64409 L .60904 .64902 L p F P
0 g
s
.317 .493 .874 r
.69581 .76483 m .69584 .76421 L p .70506 .77172 L F P
0 g
s
.303 .481 .869 r
.69581 .76483 m .69535 .76402 L .69584 .76421 L closepath p F P
0 g
s
.245 .518 .911 r
.73276 .58368 m .73233 .58307 L .73246 .58311 L closepath p F P
0 g
s
.22 .499 .903 r
.73276 .58368 m .73246 .58311 L p .74316 .59007 L F P
0 g
s
.301 .574 .935 r
.70565 .56642 m .71039 .56746 L .70743 .56359 L p F P
0 g
s
.301 .574 .935 r
.70743 .56359 m .70316 .56266 L .70565 .56642 L p F P
0 g
s
.645 .212 0 r
.61157 .65266 m .61226 .65376 L .60911 .64913 L p F P
0 g
s
.645 .212 0 r
.60911 .64913 m .60904 .64902 L .61157 .65266 L p F P
0 g
s
0 0 .535 r
.62304 .66959 m .62096 .66586 L .61725 .66114 L p F P
0 g
s
0 0 .498 r
.61503 .65743 m .61725 .66114 L .62096 .66586 L p F P
0 g
s
0 0 .503 r
.61226 .65376 m .61503 .65743 L .61725 .66114 L p F P
0 g
s
.027 .29 .784 r
.79696 .64384 m .7991 .64548 L .79616 .63999 L p F P
0 g
s
.027 .29 .784 r
.79616 .63999 m .79596 .63983 L .79696 .64384 L p F P
0 g
s
0 0 .565 r
.62879 .67806 m .62684 .6743 L .62304 .66959 L p F P
0 g
s
0 0 .53 r
.62096 .66586 m .62304 .66959 L .62684 .6743 L p F P
0 g
s
.301 .482 .87 r
.69584 .76421 m .69535 .76402 L .69228 .75866 L p F P
0 g
s
0 .061 .622 r
.82307 .68275 m .82354 .6868 L .82694 .69178 L p F P
0 g
s
0 .108 .657 r
.82354 .6868 m .82307 .68275 L .81926 .67791 L p F P
0 g
s
.412 .568 .899 r
.71754 .78404 m .72653 .78594 L .72632 .79002 L p F P
0 g
s
.393 .557 .898 r
.72653 .78594 m .71754 .78404 L .71464 .7793 L p F P
0 g
s
.239 .519 .913 r
.73246 .58311 m .73233 .58307 L .7294 .579 L p F P
0 g
s
0 .027 .592 r
.63453 .68653 m .6327 .68275 L .62879 .67806 L p F P
0 g
s
0 0 .558 r
.62684 .6743 m .62879 .67806 L .6327 .68275 L p F P
0 g
s
.22 .499 .903 r
.73246 .58311 m .74118 .58622 L .74316 .59007 L p F P
0 g
s
.214 .5 .905 r
.73032 .5793 m .73246 .58311 L .74118 .58622 L p F P
0 g
s
.239 .519 .913 r
.7294 .579 m .73032 .5793 L .73246 .58311 L p F P
0 g
s
0 .233 .747 r
.80337 .65211 m .80829 .65657 L .80915 .66057 L p F P
0 g
s
0 .231 .747 r
.80236 .64813 m .80337 .65211 L .80829 .65657 L p F P
0 g
s
.01 .275 .775 r
.7991 .64548 m .80236 .64813 L .80337 .65211 L p F P
0 g
s
.247 .465 .873 r
.69585 .76011 m .69584 .76421 L .70488 .76769 L p F P
0 g
s
.301 .482 .87 r
.69228 .75866 m .69585 .76011 L .69584 .76421 L p F P
0 g
s
.317 .493 .874 r
.69584 .76421 m .70488 .76769 L .70506 .77172 L p F P
0 g
s
0 .122 .668 r
.81866 .67387 m .81926 .67791 L .82307 .68275 L p F P
0 g
s
0 .155 .692 r
.81926 .67791 m .81866 .67387 L .81446 .66917 L p F P
0 g
s
.876 .786 .292 r
.83685 .75556 m .83697 .7515 L p .83566 .76173 L F P
0 g
s
.876 .786 .292 r
.83566 .76173 m .83576 .76144 L .83685 .75556 L p F P
0 g
s
.749 .647 .088 r
.83685 .75556 m .83697 .7515 L .83743 .74533 L p F P
0 g
s
0 .055 .617 r
.638 .69054 m .63453 .68653 L p .64027 .69499 L F P
0 g
s
0 .038 .601 r
.63453 .68653 m .638 .69054 L .63486 .68529 L p F P
0 g
s
0 .038 .601 r
.63486 .68529 m .6327 .68275 L .63453 .68653 L p F P
0 g
s
.926 .95 .613 r
.83321 .76867 m .83277 .77278 L .82929 .77979 L p F P
0 g
s
.878 .875 .437 r
.83277 .77278 m .83321 .76867 L .83564 .76194 L p F P
0 g
s
.379 .556 .902 r
.72632 .79002 m .73358 .79142 L .7306 .78685 L p F P
0 g
s
.379 .556 .902 r
.7306 .78685 m .72653 .78594 L .72632 .79002 L p F P
0 g
s
0 .196 .721 r
.81446 .66917 m .81372 .66515 L .80915 .66057 L p F P
0 g
s
0 .195 .722 r
.80829 .65657 m .80915 .66057 L .81372 .66515 L p F P
0 g
s
0 .154 .692 r
.81372 .66515 m .81446 .66917 L .81866 .67387 L p F P
0 g
s
.148 .376 .829 r
.67254 .73635 m .66989 .73476 L .66678 .7292 L p F P
0 g
s
0 0 .209 r
.83644 .72543 m .83643 .72951 L .83729 .73529 L p F P
0 g
s
0 0 .331 r
.83643 .72951 m .83644 .72543 L .835 .71983 L p F P
0 g
s
0 .088 .644 r
.64114 .69594 m .64027 .69499 L .63925 .69271 L closepath p F P
0 g
s
0 .055 .617 r
.64027 .69499 m .63925 .69271 L .638 .69054 L p F P
0 g
s
0 0 .469 r
.61503 .65743 m .61226 .65376 L .60911 .64913 L p F P
0 g
s
.342 .609 .948 r
.68921 .55674 m .69145 .55709 L .68847 .55335 L p F P
0 g
s
.342 .609 .948 r
.68847 .55335 m .68645 .55304 L .68921 .55674 L p F P
0 g
s
.176 .442 .872 r
.77075 .61161 m .76437 .60849 L p .77322 .61603 L F P
0 g
s
.146 .426 .866 r
.76437 .60849 m .77075 .61161 L .76784 .60707 L p F P
0 g
s
.146 .426 .866 r
.76784 .60707 m .76275 .60458 L .76437 .60849 L p F P
0 g
s
0 .226 .747 r
.65273 .71166 m .65148 .70778 L .6464 .70335 L p F P
0 g
s
0 .197 .727 r
.64508 .69947 m .6464 .70335 L .65148 .70778 L p F P
0 g
s
0 .224 .745 r
.64114 .69594 m .64508 .69947 L .6464 .70335 L p F P
0 g
s
.543 .686 .932 r
.76142 .80455 m .75541 .80506 L .75249 .801 L p F P
0 g
s
0 .239 .755 r
.6591 .71995 m .65792 .71607 L .65273 .71166 L p F P
0 g
s
0 .21 .736 r
.65148 .70778 m .65273 .71166 L .65792 .71607 L p F P
0 g
s
.47 .621 .916 r
.74044 .79621 m .73655 .79596 L .73358 .79142 L p F P
0 g
s
0 .203 .731 r
.64508 .69947 m .64114 .69594 L .63925 .69271 L p F P
0 g
s
0 .259 .767 r
.66367 .72372 m .6591 .71995 L p .66554 .72823 L F P
0 g
s
0 .239 .755 r
.6591 .71995 m .66367 .72372 L .66055 .71831 L p F P
0 g
s
0 .239 .755 r
.66055 .71831 m .65792 .71607 L .6591 .71995 L p F P
0 g
s
.274 .474 .873 r
.70506 .77172 m .71149 .77411 L .70845 .76912 L p F P
0 g
s
.274 .474 .873 r
.70845 .76912 m .70488 .76769 L .70506 .77172 L p F P
0 g
s
0 .268 .772 r
.80236 .64813 m .7991 .64548 L .79616 .63999 L p F P
0 g
s
0 0 .425 r
.835 .71983 m .83491 .71574 L .83292 .71031 L p F P
0 g
s
0 0 .327 r
.83491 .71574 m .835 .71983 L .83644 .72543 L p F P
0 g
s
.122 .398 .85 r
.77366 .61626 m .77322 .61603 L .77279 .61485 L closepath p F P
0 g
s
.176 .442 .872 r
.77322 .61603 m .77279 .61485 L .77075 .61161 L p F P
0 g
s
.203 .486 .897 r
.74316 .59007 m .74854 .59211 L .74562 .58789 L p F P
0 g
s
.203 .486 .897 r
.74562 .58789 m .74118 .58622 L .74316 .59007 L p F P
0 g
s
0 .278 .779 r
.66678 .7292 m .66554 .72823 L .66486 .72583 L closepath p F P
0 g
s
0 .259 .767 r
.66554 .72823 m .66486 .72583 L .66367 .72372 L p F P
0 g
s
.308 .584 .94 r
.69145 .55709 m .70053 .55893 L .70316 .56266 L p F P
0 g
s
.303 .585 .941 r
.70053 .55893 m .69145 .55709 L .68847 .55335 L p F P
0 g
s
.679 .857 .967 r
.80105 .80391 m .80034 .80589 L p .78684 .80772 L F P
0 g
s
.711 .872 .957 r
.80034 .80589 m .80105 .80391 L .80228 .80497 L closepath p F P
0 g
s
.257 .541 .923 r
.7184 .57272 m .72646 .57499 L .72352 .57104 L p F P
0 g
s
.257 .541 .923 r
.72352 .57104 m .71602 .56894 L .7184 .57272 L p F P
0 g
s
.272 .551 .927 r
.71039 .56746 m .71602 .56894 L .7184 .57272 L p F P
0 g
s
.348 .617 .951 r
.67258 .54783 m .68353 .54937 L .68645 .55304 L p F P
0 g
s
0 0 .069 r
.83743 .74533 m .83751 .74126 L .83729 .73529 L p F P
0 g
s
.765 .659 .103 r
.83751 .74126 m .83743 .74533 L .83697 .7515 L p F P
0 g
s
.887 .958 .841 r
.82393 .78733 m .81588 .7956 L .81576 .79714 L p F P
0 g
s
.846 .951 .884 r
.81476 .7966 m .81588 .7956 L .81576 .79714 L closepath p F P
0 g
s
.776 .948 .932 r
.80228 .80497 m .81476 .7966 L .81576 .79714 L p F P
0 g
s
.18 .466 .888 r
.75337 .59719 m .75145 .5964 L .74854 .59211 L p F P
0 g
s
.1 .377 .839 r
.77366 .61626 m .77983 .61989 L .78125 .62382 L p F P
0 g
s
.088 .374 .838 r
.77983 .61989 m .77366 .61626 L .77279 .61485 L p F P
0 g
s
.939 .965 .726 r
.82929 .77979 m .8296 .77573 L p .82459 .78349 L F P
0 g
s
.939 .965 .726 r
.82459 .78349 m .82688 .78363 L .82929 .77979 L p F P
0 g
s
.926 .95 .613 r
.82929 .77979 m .8296 .77573 L .83321 .76867 L p F P
0 g
s
.786 .888 .919 r
.80105 .80391 m .80228 .80497 L .81476 .7966 L p F P
0 g
s
.266 .552 .928 r
.71602 .56894 m .71039 .56746 L .70743 .56359 L p F P
0 g
s
.084 .348 .82 r
.67184 .73238 m .67254 .73635 L .67921 .74042 L p F P
0 g
s
.148 .376 .829 r
.66678 .7292 m .67184 .73238 L .67254 .73635 L p F P
0 g
s
.177 .393 .835 r
.67254 .73635 m .67921 .74042 L .67992 .74437 L p F P
0 g
s
.277 .47 .869 r
.69585 .76011 m .69228 .75866 L .6892 .75334 L p F P
0 g
s
0 0 .416 r
.83277 .70723 m .83292 .71031 L .83491 .71574 L p F P
0 g
s
0 0 .507 r
.83196 .70465 m .83023 .70096 L p .83292 .71031 L F P
0 g
s
0 0 .507 r
.83292 .71031 m .83277 .70723 L .83196 .70465 L p F P
0 g
s
.814 .777 .271 r
.83564 .76194 m .83566 .76173 L .83576 .76144 L closepath p F P
0 g
s
.082 .355 .825 r
.78882 .63176 m .78756 .6278 L .78125 .62382 L p F P
0 g
s
.075 .356 .827 r
.77983 .61989 m .78125 .62382 L .78756 .6278 L p F P
0 g
s
.393 .557 .898 r
.71464 .7793 m .71465 .77914 L p .72653 .78594 L F P
0 g
s
.383 .549 .895 r
.71464 .7793 m .71452 .7791 L .71465 .77914 L closepath p F P
0 g
s
.599 .779 .966 r
.7712 .80757 m .78405 .80466 L .78684 .80772 L p F P
0 g
s
.583 .764 .964 r
.78405 .80466 m .7712 .80757 L .76833 .80399 L p F P
0 g
s
.88 .876 .439 r
.83566 .76173 m .83564 .76194 L .83321 .76867 L p F P
0 g
s
.383 .549 .895 r
.71465 .77914 m .71452 .7791 L .71149 .77411 L p F P
0 g
s
.393 .557 .898 r
.71465 .77914 m .72637 .78195 L .72653 .78594 L p F P
0 g
s
.338 .542 .905 r
.71495 .775 m .71465 .77914 L .72637 .78195 L p F P
0 g
s
.383 .549 .895 r
.71149 .77411 m .71495 .775 L .71465 .77914 L p F P
0 g
s
.116 .361 .824 r
.67184 .73238 m .66678 .7292 L .66486 .72583 L p F P
0 g
s
.894 .988 .779 r
.82393 .78733 m .82459 .78349 L .82688 .78363 L closepath p F P
0 g
s
0 .179 .714 r
.63925 .69271 m .638 .69054 L .63867 .69118 L closepath p F P
0 g
s
0 .203 .731 r
.63925 .69271 m .63867 .69118 L p .64508 .69947 L F P
0 g
s
.088 .374 .838 r
.77279 .61485 m .77169 .61211 L p .77983 .61989 L F P
0 g
s
.124 .407 .856 r
.77279 .61485 m .77075 .61161 L .77169 .61211 L closepath p F P
0 g
s
.911 .871 .437 r
.83574 .75789 m .83566 .76173 L .83363 .76461 L p F P
0 g
s
.876 .786 .292 r
.83697 .7515 m .83574 .75789 L .83566 .76173 L p F P
0 g
s
.88 .876 .439 r
.83321 .76867 m .83363 .76461 L .83566 .76173 L p F P
0 g
s
.789 .343 0 r
.59794 .63195 m .59488 .62842 L .59232 .62343 L p F P
0 g
s
.141 .383 .836 r
.68612 .74807 m .67992 .74437 L p .68745 .75236 L F P
0 g
s
.122 .364 .825 r
.67992 .74437 m .68612 .74807 L .68304 .74281 L p F P
0 g
s
.122 .364 .825 r
.68304 .74281 m .67921 .74042 L .67992 .74437 L p F P
0 g
s
.443 .611 .92 r
.74044 .79621 m .74956 .79687 L .74662 .79269 L p F P
0 g
s
.443 .611 .92 r
.74662 .79269 m .74085 .7921 L .74044 .79621 L p F P
0 g
s
.47 .621 .916 r
.73358 .79142 m .74085 .7921 L .74044 .79621 L p F P
0 g
s
.75 .306 0 r
.60351 .64048 m .60063 .63691 L .59794 .63195 L p F P
0 g
s
.772 .32 0 r
.59488 .62842 m .59794 .63195 L .60063 .63691 L p F P
0 g
s
.679 .857 .967 r
.78684 .80772 m .79956 .80259 L .80105 .80391 L p F P
0 g
s
.662 .839 .968 r
.79956 .80259 m .78684 .80772 L .78405 .80466 L p F P
0 g
s
.719 .281 0 r
.60596 .64475 m .60351 .64048 L p .60904 .64902 L F P
0 g
s
.73 .282 0 r
.60351 .64048 m .60596 .64475 L .60281 .64071 L p F P
0 g
s
.73 .282 0 r
.60281 .64071 m .60063 .63691 L .60351 .64048 L p F P
0 g
s
0 0 .488 r
.83196 .70465 m .83023 .70096 L .83004 .69863 L closepath p F P
0 g
s
0 0 .568 r
.82868 .69482 m .82694 .69178 L p .83023 .70096 L F P
0 g
s
0 0 .568 r
.83023 .70096 m .83004 .69863 L .82868 .69482 L p F P
0 g
s
.296 .576 .937 r
.70316 .56266 m .70743 .56359 L .70447 .55978 L p F P
0 g
s
.296 .576 .937 r
.70447 .55978 m .70053 .55893 L .70316 .56266 L p F P
0 g
s
.866 .96 .863 r
.82459 .78349 m .82393 .78733 L .81588 .7956 L p F P
0 g
s
.08 .344 .817 r
.79324 .6348 m .78882 .63176 L p .79596 .63983 L F P
0 g
s
.045 .324 .807 r
.78882 .63176 m .79324 .6348 L .79032 .6297 L p F P
0 g
s
.045 .324 .807 r
.79032 .6297 m .78756 .6278 L .78882 .63176 L p F P
0 g
s
.16 .444 .876 r
.76275 .60458 m .76102 .60068 L .75337 .59719 L p F P
0 g
s
.154 .445 .877 r
.75147 .59333 m .75337 .59719 L .76102 .60068 L p F P
0 g
s
.18 .466 .888 r
.74854 .59211 m .75147 .59333 L .75337 .59719 L p F P
0 g
s
.672 .228 0 r
.60911 .64913 m .60904 .64902 L .60862 .64846 L closepath p F P
0 g
s
.719 .281 0 r
.60904 .64902 m .60862 .64846 L .60596 .64475 L p F P
0 g
s
.232 .52 .914 r
.73032 .5793 m .7294 .579 L .72646 .57499 L p F P
0 g
s
.518 .684 .942 r
.76142 .80455 m .76833 .80399 L .76546 .80031 L p F P
0 g
s
.518 .684 .942 r
.76546 .80031 m .76172 .80049 L .76142 .80455 L p F P
0 g
s
.543 .686 .932 r
.75249 .801 m .76172 .80049 L .76142 .80455 L p F P
0 g
s
0 0 .469 r
.60911 .64913 m .61258 .65377 L .61503 .65743 L p F P
0 g
s
0 0 .434 r
.61258 .65377 m .60911 .64913 L .60862 .64846 L p F P
0 g
s
0 0 .058 r
.83731 .73121 m .83729 .73529 L .83751 .74126 L p F P
0 g
s
0 0 .209 r
.83729 .73529 m .83731 .73121 L .83644 .72543 L p F P
0 g
s
0 0 .498 r
.62096 .66586 m .61867 .66217 L .61503 .65743 L p F P
0 g
s
0 0 .461 r
.61258 .65377 m .61503 .65743 L .61867 .66217 L p F P
0 g
s
.833 .941 .895 r
.81588 .7956 m .81476 .7966 L .81212 .79493 L p F P
0 g
s
.786 .888 .919 r
.81476 .7966 m .81212 .79493 L p .80105 .80391 L F P
0 g
s
.833 .941 .895 r
.81212 .79493 m .81612 .79158 L .81588 .7956 L p F P
0 g
s
.866 .96 .863 r
.82439 .78345 m .82459 .78349 L p .81588 .7956 L F P
0 g
s
.866 .96 .863 r
.81588 .7956 m .81612 .79158 L .82439 .78345 L p F P
0 g
s
.155 .395 .842 r
.6892 .75334 m .68745 .75236 L .68692 .74944 L closepath p F P
0 g
s
.141 .383 .836 r
.68745 .75236 m .68692 .74944 L .68612 .74807 L p F P
0 g
s
0 0 .53 r
.62684 .6743 m .62469 .67059 L .62096 .66586 L p F P
0 g
s
0 0 .494 r
.61867 .66217 m .62096 .66586 L .62469 .67059 L p F P
0 g
s
0 0 .551 r
.82868 .69482 m .82694 .69178 L .82666 .68921 L closepath p F P
0 g
s
0 .061 .622 r
.82551 .68633 m .82307 .68275 L p .82694 .69178 L F P
0 g
s
0 .061 .622 r
.82694 .69178 m .82666 .68921 L .82551 .68633 L p F P
0 g
s
0 .169 .706 r
.63867 .69118 m .638 .69054 L .63486 .68529 L p F P
0 g
s
.014 .287 .784 r
.79616 .63999 m .79596 .63983 L .79583 .63938 L closepath p F P
0 g
s
.08 .344 .817 r
.79596 .63983 m .79583 .63938 L .79324 .6348 L p F P
0 g
s
.592 .149 0 r
.60641 .6454 m .60862 .64846 L .60626 .64517 L p F P
0 g
s
.592 .149 0 r
.60626 .64517 m .60596 .64475 L .60641 .6454 L p F P
0 g
s
0 0 .434 r
.60862 .64846 m .60641 .6454 L p .61258 .65377 L F P
0 g
s
.601 .141 0 r
.60641 .6454 m .60993 .65015 L p .6071 .64644 L F P
0 g
s
.601 .141 0 r
.60358 .64182 m .60641 .6454 L p .6071 .64644 L F P
0 g
s
.232 .52 .914 r
.72646 .57499 m .72805 .5755 L .73032 .5793 L p F P
0 g
s
.214 .5 .905 r
.74118 .58622 m .73908 .58238 L .73032 .5793 L p F P
0 g
s
.209 .502 .906 r
.72805 .5755 m .73032 .5793 L .73908 .58238 L p F P
0 g
s
0 0 .558 r
.6327 .68275 m .63068 .67902 L .62684 .6743 L p F P
0 g
s
0 0 .524 r
.62469 .67059 m .62684 .6743 L .63068 .67902 L p F P
0 g
s
0 .268 .772 r
.79616 .63999 m .80125 .64416 L .80236 .64813 L p F P
0 g
s
0 .261 .768 r
.80125 .64416 m .79616 .63999 L .79583 .63938 L p F P
0 g
s
.748 .876 .938 r
.79956 .80259 m .80106 .80175 L .80105 .80391 L closepath p F P
0 g
s
.786 .888 .919 r
.81212 .79493 m .80106 .80175 L .80105 .80391 L p F P
0 g
s
.453 .611 .916 r
.74085 .7921 m .73358 .79142 L .7306 .78685 L p F P
0 g
s
.527 .675 .932 r
.76172 .80049 m .75249 .801 L .74956 .79687 L p F P
0 g
s
0 .011 .574 r
.6327 .68275 m .63486 .68529 L .63172 .68027 L p F P
0 g
s
0 .011 .574 r
.63172 .68027 m .63068 .67902 L .6327 .68275 L p F P
0 g
s
0 .038 .605 r
.82551 .68633 m .82307 .68275 L .82254 .67887 L closepath p F P
0 g
s
0 .122 .668 r
.82241 .67858 m .81866 .67387 L p .82307 .68275 L F P
0 g
s
0 .122 .668 r
.82307 .68275 m .82254 .67887 L .82241 .67858 L p F P
0 g
s
.338 .611 .95 r
.68645 .55304 m .68847 .55335 L .68548 .54967 L p F P
0 g
s
.338 .611 .95 r
.68548 .54967 m .68353 .54937 L .68645 .55304 L p F P
0 g
s
0 .231 .747 r
.80829 .65657 m .80732 .65258 L .80236 .64813 L p F P
0 g
s
0 .23 .747 r
.80125 .64416 m .80236 .64813 L .80732 .65258 L p F P
0 g
s
.023 .304 .795 r
.79583 .63938 m .79324 .6348 L .79473 .63588 L closepath p F P
0 g
s
0 .261 .768 r
.79583 .63938 m .79473 .63588 L p .80125 .64416 L F P
0 g
s
.116 .361 .824 r
.66486 .72583 m .66456 .72431 L p .67184 .73238 L F P
0 g
s
.097 .344 .815 r
.66486 .72583 m .66367 .72372 L .66456 .72431 L closepath p F P
0 g
s
0 .203 .731 r
.63867 .69118 m .64352 .69565 L .64508 .69947 L p F P
0 g
s
0 .154 .694 r
.63701 .68736 m .63867 .69118 L .64352 .69565 L p F P
0 g
s
0 .169 .706 r
.63486 .68529 m .63701 .68736 L .63867 .69118 L p F P
0 g
s
0 .091 .647 r
.81866 .67387 m .82241 .67858 L .81937 .67163 L p F P
0 g
s
0 .091 .647 r
.81937 .67163 m .81797 .66985 L .81866 .67387 L p F P
0 g
s
0 .154 .692 r
.81866 .67387 m .81797 .66985 L .81372 .66515 L p F P
0 g
s
0 .195 .722 r
.81372 .66515 m .81289 .66114 L .80829 .65657 L p F P
0 g
s
0 .194 .722 r
.80732 .65258 m .80829 .65657 L .81289 .66114 L p F P
0 g
s
0 .165 .701 r
.81289 .66114 m .81372 .66515 L .81797 .66985 L p F P
0 g
s
.136 .425 .866 r
.76275 .60458 m .76784 .60707 L .76493 .6026 L p F P
0 g
s
.136 .425 .866 r
.76493 .6026 m .76102 .60068 L .76275 .60458 L p F P
0 g
s
.862 .785 .288 r
.83703 .74744 m .83697 .7515 L .83574 .75789 L p F P
0 g
s
.765 .659 .103 r
.83697 .7515 m .83703 .74744 L .83751 .74126 L p F P
0 g
s
.247 .465 .873 r
.70488 .76769 m .7044 .76373 L .69585 .76011 L p F P
0 g
s
.221 .453 .871 r
.69552 .75609 m .69585 .76011 L .7044 .76373 L p F P
0 g
s
.277 .47 .869 r
.6892 .75334 m .69552 .75609 L .69585 .76011 L p F P
0 g
s
0 0 .198 r
.83639 .72217 m .83644 .72543 L .83731 .73121 L p F P
0 g
s
0 0 .327 r
.83556 .71824 m .83491 .71574 L p .83644 .72543 L F P
0 g
s
0 0 .327 r
.83644 .72543 m .83639 .72217 L .83556 .71824 L p F P
0 g
s
.928 .954 .628 r
.83363 .76461 m .83321 .76867 L .8296 .77573 L p F P
0 g
s
0 .197 .727 r
.65148 .70778 m .65001 .70394 L .64508 .69947 L p F P
0 g
s
0 .167 .704 r
.64352 .69565 m .64508 .69947 L .65001 .70394 L p F P
0 g
s
.352 .546 .904 r
.72653 .78594 m .7306 .78685 L .7276 .78226 L p F P
0 g
s
.352 .546 .904 r
.7276 .78226 m .72637 .78195 L .72653 .78594 L p F P
0 g
s
.252 .458 .867 r
.69552 .75609 m .6892 .75334 L .68692 .74944 L p F P
0 g
s
.115 .406 .856 r
.77169 .61211 m .77075 .61161 L .76784 .60707 L p F P
0 g
s
0 .21 .736 r
.65792 .71607 m .65651 .71224 L .65148 .70778 L p F P
0 g
s
0 .183 .717 r
.65001 .70394 m .65148 .70778 L .65651 .71224 L p F P
0 g
s
.171 .465 .888 r
.75147 .59333 m .74854 .59211 L .74562 .58789 L p F P
0 g
s
.084 .342 .815 r
.66456 .72431 m .66367 .72372 L .66055 .71831 L p F P
0 g
s
.303 .585 .941 r
.68847 .55335 m .69776 .55522 L .70053 .55893 L p F P
0 g
s
.298 .587 .943 r
.69776 .55522 m .68847 .55335 L .68548 .54967 L p F P
0 g
s
.362 .538 .894 r
.71495 .775 m .71149 .77411 L .70845 .76912 L p F P
0 g
s
0 .217 .741 r
.65792 .71607 m .66055 .71831 L .65743 .71305 L p F P
0 g
s
0 .217 .741 r
.65743 .71305 m .65651 .71224 L .65792 .71607 L p F P
0 g
s
.251 .542 .924 r
.71602 .56894 m .72352 .57104 L .72058 .56715 L p F P
0 g
s
.251 .542 .924 r
.72058 .56715 m .71352 .56518 L .71602 .56894 L p F P
0 g
s
.266 .552 .928 r
.70743 .56359 m .71352 .56518 L .71602 .56894 L p F P
0 g
s
.195 .486 .898 r
.74118 .58622 m .74562 .58789 L .74269 .58375 L p F P
0 g
s
.195 .486 .898 r
.74269 .58375 m .73908 .58238 L .74118 .58622 L p F P
0 g
s
0 0 .461 r
.83004 .69863 m .82983 .69692 L p .83268 .70625 L F P
0 g
s
0 0 .461 r
.83268 .70625 m .83196 .70465 L .83004 .69863 L p F P
0 g
s
0 0 .528 r
.83004 .69863 m .82868 .69482 L .82983 .69692 L closepath p F P
0 g
s
.088 .374 .838 r
.77169 .61211 m .7783 .61597 L .77983 .61989 L p F P
0 g
s
.079 .375 .84 r
.77001 .60821 m .77169 .61211 L .7783 .61597 L p F P
0 g
s
.115 .406 .856 r
.76784 .60707 m .77001 .60821 L .77169 .61211 L p F P
0 g
s
.26 .553 .929 r
.71352 .56518 m .70743 .56359 L .70447 .55978 L p F P
0 g
s
0 0 .464 r
.83277 .70723 m .83196 .70465 L .83268 .70625 L closepath p F P
0 g
s
0 0 .368 r
.83268 .70625 m .83277 .70723 L .83488 .71507 L p F P
0 g
s
0 0 .416 r
.83491 .71574 m .83488 .71507 L .83277 .70723 L p F P
0 g
s
.243 .462 .872 r
.70488 .76769 m .70845 .76912 L .70541 .76416 L p F P
0 g
s
.243 .462 .872 r
.70541 .76416 m .7044 .76373 L .70488 .76769 L p F P
0 g
s
0 0 .305 r
.83556 .71824 m .83491 .71574 L .83488 .71507 L closepath p F P
0 g
s
.116 .361 .824 r
.66456 .72431 m .67087 .72846 L .67184 .73238 L p F P
0 g
s
.034 .319 .805 r
.66358 .72038 m .66456 .72431 L .67087 .72846 L p F P
0 g
s
.084 .342 .815 r
.66055 .71831 m .66358 .72038 L .66456 .72431 L p F P
0 g
s
0 0 .525 r
.82983 .69692 m .82868 .69482 L .82666 .68921 L p F P
0 g
s
.583 .764 .964 r
.76833 .80399 m .78123 .80147 L .78405 .80466 L p F P
0 g
s
.569 .75 .963 r
.78123 .80147 m .76833 .80399 L .76546 .80031 L p F P
0 g
s
.733 .865 .943 r
.80106 .80175 m .79956 .80259 L .79682 .80001 L p F P
0 g
s
.662 .839 .968 r
.78405 .80466 m .79682 .80001 L .79956 .80259 L p F P
0 g
s
0 0 .058 r
.83751 .74126 m .83753 .73718 L .83731 .73121 L p F P
0 g
s
.779 .669 .117 r
.83753 .73718 m .83751 .74126 L .83703 .74744 L p F P
0 g
s
0 .146 .687 r
.63701 .68736 m .63486 .68529 L .63172 .68027 L p F P
0 g
s
.733 .865 .943 r
.79682 .80001 m .80106 .79779 L .80106 .80175 L p F P
0 g
s
.764 .916 .94 r
.80945 .79301 m .80106 .79779 L .80106 .80175 L p F P
0 g
s
.764 .916 .94 r
.80106 .80175 m .81212 .79493 L .80945 .79301 L p F P
0 g
s
0 0 .525 r
.82666 .68921 m .82643 .68774 L p .82983 .69692 L F P
0 g
s
0 .011 .585 r
.82666 .68921 m .82551 .68633 L .82643 .68774 L closepath p F P
0 g
s
.626 .169 0 r
.60641 .6454 m .60596 .64475 L .60281 .64071 L p F P
0 g
s
.926 .972 .753 r
.82989 .77165 m .8296 .77573 L .8246 .78318 L p F P
0 g
s
.928 .954 .628 r
.83359 .76464 m .83363 .76461 L p .8296 .77573 L F P
0 g
s
.928 .954 .628 r
.8296 .77573 m .82989 .77165 L .83359 .76464 L p F P
0 g
s
.939 .965 .726 r
.8296 .77573 m .8246 .78318 L .82459 .78349 L p F P
0 g
s
.075 .356 .827 r
.78756 .6278 m .78618 .62385 L .77983 .61989 L p F P
0 g
s
.086 .372 .837 r
.7783 .61597 m .77983 .61989 L .78618 .62385 L p F P
0 g
s
0 0 .368 r
.83488 .71507 m .83455 .71172 L .83268 .70625 L p F P
0 g
s
0 0 .274 r
.83488 .71507 m .83455 .71172 L p .83633 .72136 L F P
0 g
s
0 0 .274 r
.83633 .72136 m .83556 .71824 L .83488 .71507 L p F P
0 g
s
.084 .348 .82 r
.67921 .74042 m .67824 .73652 L .67184 .73238 L p F P
0 g
s
.043 .327 .81 r
.67087 .72846 m .67184 .73238 L .67824 .73652 L p F P
0 g
s
.225 .52 .915 r
.72805 .5755 m .72646 .57499 L .72352 .57104 L p F P
0 g
s
.772 .32 0 r
.60063 .63691 m .59757 .63338 L .59488 .62842 L p F P
0 g
s
.013 .302 .795 r
.79473 .63588 m .79324 .6348 L .79032 .6297 L p F P
0 g
s
0 0 .359 r
.83218 .70224 m .83268 .70625 L .83455 .71172 L p F P
0 g
s
0 0 .461 r
.82983 .69692 m .83218 .70224 L .83268 .70625 L p F P
0 g
s
.646 .822 .968 r
.79682 .80001 m .78405 .80466 L .78123 .80147 L p F P
0 g
s
.752 .296 0 r
.60063 .63691 m .60281 .64071 L .59966 .63703 L p F P
0 g
s
.752 .296 0 r
.59966 .63703 m .59757 .63338 L .60063 .63691 L p F P
0 g
s
.252 .458 .867 r
.68692 .74944 m .68684 .7484 L p .69552 .75609 L F P
0 g
s
.237 .446 .861 r
.68692 .74944 m .68612 .74807 L .68684 .7484 L closepath p F P
0 g
s
.29 .577 .939 r
.70053 .55893 m .70447 .55978 L .7015 .55603 L p F P
0 g
s
.29 .577 .939 r
.7015 .55603 m .69776 .55522 L .70053 .55893 L p F P
0 g
s
0 .007 .582 r
.82643 .68774 m .82551 .68633 L .82254 .67887 L p F P
0 g
s
.453 .611 .916 r
.7306 .78685 m .74082 .78809 L .74085 .7921 L p F P
0 g
s
.435 .601 .915 r
.74082 .78809 m .7306 .78685 L .7276 .78226 L p F P
0 g
s
0 0 .434 r
.60641 .6454 m .60993 .65015 L .61258 .65377 L p F P
0 g
s
.626 .169 0 r
.60281 .64071 m .60358 .64182 L .60641 .6454 L p F P
0 g
s
.911 .871 .437 r
.83363 .76461 m .83363 .76454 L .83574 .75789 L p F P
0 g
s
.927 .882 .463 r
.83576 .75385 m .83574 .75789 L .83363 .76454 L p F P
0 g
s
.862 .785 .288 r
.83574 .75789 m .83576 .75385 L .83703 .74744 L p F P
0 g
s
.154 .445 .877 r
.76102 .60068 m .75916 .59681 L .75147 .59333 L p F P
0 g
s
.148 .446 .879 r
.74945 .58949 m .75147 .59333 L .75916 .59681 L p F P
0 g
s
.171 .465 .888 r
.74562 .58789 m .74945 .58949 L .75147 .59333 L p F P
0 g
s
.527 .675 .932 r
.74956 .79687 m .76149 .79657 L .76172 .80049 L p F P
0 g
s
.511 .665 .931 r
.76149 .79657 m .74956 .79687 L .74662 .79269 L p F P
0 g
s
.083 .347 .819 r
.67921 .74042 m .68304 .74281 L .67995 .73763 L p F P
0 g
s
.083 .347 .819 r
.67995 .73763 m .67824 .73652 L .67921 .74042 L p F P
0 g
s
.032 .319 .805 r
.78756 .6278 m .79032 .6297 L .7874 .62469 L p F P
0 g
s
.032 .319 .805 r
.7874 .62469 m .78618 .62385 L .78756 .6278 L p F P
0 g
s
0 0 .461 r
.61867 .66217 m .61618 .65852 L .61258 .65377 L p F P
0 g
s
0 0 .426 r
.60993 .65015 m .61258 .65377 L .61618 .65852 L p F P
0 g
s
.338 .542 .905 r
.7246 .77763 m .71495 .775 L p .72637 .78195 L F P
0 g
s
.33 .522 .892 r
.71495 .775 m .7246 .77763 L .72159 .77297 L p F P
0 g
s
.33 .522 .892 r
.72159 .77297 m .71486 .77095 L .71495 .775 L p F P
0 g
s
.362 .538 .894 r
.70845 .76912 m .71486 .77095 L .71495 .775 L p F P
0 g
s
0 0 .279 r
.83639 .72217 m .83556 .71824 L .83633 .72136 L closepath p F P
0 g
s
0 0 .441 r
.82923 .69292 m .82983 .69692 L .83218 .70224 L p F P
0 g
s
0 0 .525 r
.82643 .68774 m .82923 .69292 L .82983 .69692 L p F P
0 g
s
.908 .975 .795 r
.82439 .78345 m .8246 .78318 L .82459 .78349 L closepath p F P
0 g
s
.232 .446 .863 r
.68684 .7484 m .68612 .74807 L .68304 .74281 L p F P
0 g
s
.42 .603 .923 r
.74085 .7921 m .74662 .79269 L .74367 .78846 L p F P
0 g
s
.42 .603 .923 r
.74367 .78846 m .74082 .78809 L .74085 .7921 L p F P
0 g
s
0 0 .494 r
.62469 .67059 m .62235 .66692 L .61867 .66217 L p F P
0 g
s
0 0 .46 r
.61618 .65852 m .61867 .66217 L .62235 .66692 L p F P
0 g
s
.209 .502 .906 r
.73908 .58238 m .73685 .57857 L .72805 .5755 L p F P
0 g
s
.203 .503 .908 r
.72566 .57172 m .72805 .5755 L .73685 .57857 L p F P
0 g
s
.225 .52 .915 r
.72352 .57104 m .72566 .57172 L .72805 .5755 L p F P
0 g
s
.049 .326 .808 r
.66358 .72038 m .66055 .71831 L .65743 .71305 L p F P
0 g
s
0 0 .524 r
.63068 .67902 m .62846 .67533 L .62469 .67059 L p F P
0 g
s
0 0 .485 r
.62235 .66692 m .62469 .67059 L .62846 .67533 L p F P
0 g
s
.901 .968 .815 r
.8246 .78318 m .82439 .78345 L .82183 .78255 L p F P
0 g
s
.901 .968 .815 r
.82183 .78255 m .82468 .77917 L .8246 .78318 L p F P
0 g
s
.926 .972 .753 r
.8246 .78318 m .82468 .77917 L .82989 .77165 L p F P
0 g
s
0 0 .047 r
.83727 .72851 m .83731 .73121 L .83753 .73718 L p F P
0 g
s
0 0 .198 r
.83731 .73121 m .83727 .72851 L .83639 .72217 L p F P
0 g
s
.497 .677 .945 r
.76172 .80049 m .76546 .80031 L .76257 .79655 L p F P
0 g
s
.497 .677 .945 r
.76257 .79655 m .76149 .79657 L .76172 .80049 L p F P
0 g
s
.86 .978 .858 r
.81612 .79158 m .82439 .78345 L .82183 .78255 L p F P
0 g
s
0 .261 .768 r
.79473 .63588 m .80004 .6402 L .80125 .64416 L p F P
0 g
s
0 .26 .769 r
.79338 .63195 m .79473 .63588 L .80004 .6402 L p F P
0 g
s
.013 .302 .795 r
.79032 .6297 m .79338 .63195 L .79473 .63588 L p F P
0 g
s
.252 .458 .867 r
.68684 .7484 m .6949 .75213 L .69552 .75609 L p F P
0 g
s
.179 .426 .861 r
.68631 .7444 m .68684 .7484 L .6949 .75213 L p F P
0 g
s
.232 .446 .863 r
.68304 .74281 m .68631 .7444 L .68684 .7484 L p F P
0 g
s
.82 .934 .905 r
.81612 .79158 m .81212 .79493 L .80945 .79301 L p F P
0 g
s
0 0 .509 r
.82572 .68375 m .82643 .68774 L .82923 .69292 L p F P
0 g
s
0 .007 .582 r
.82251 .67871 m .82572 .68375 L .82643 .68774 L p F P
0 g
s
0 .007 .582 r
.82254 .67887 m .82251 .67871 L p .82643 .68774 L F P
0 g
s
.105 .403 .856 r
.77001 .60821 m .76784 .60707 L .76493 .6026 L p F P
0 g
s
0 0 .546 r
.63068 .67902 m .63172 .68027 L .62858 .67548 L p F P
0 g
s
0 0 .546 r
.62858 .67548 m .62846 .67533 L .63068 .67902 L p F P
0 g
s
.341 .528 .893 r
.71486 .77095 m .70845 .76912 L .70541 .76416 L p F P
0 g
s
.82 .934 .905 r
.80945 .79301 m .81642 .78752 L .81612 .79158 L p F P
0 g
s
.86 .978 .858 r
.82183 .78255 m .81642 .78752 L .81612 .79158 L p F P
0 g
s
0 .074 .634 r
.82254 .67887 m .82241 .67858 L .82251 .67871 L closepath p F P
0 g
s
0 0 .151 r
.83633 .72136 m .83639 .72217 L .83727 .72851 L p F P
0 g
s
0 .23 .747 r
.80732 .65258 m .80624 .6486 L .80125 .64416 L p F P
0 g
s
0 .229 .747 r
.80004 .6402 m .80125 .64416 L .80624 .6486 L p F P
0 g
s
0 .068 .63 r
.82251 .67871 m .82241 .67858 L .81937 .67163 L p F P
0 g
s
0 0 .566 r
.82168 .67472 m .82251 .67871 L .82572 .68375 L p F P
0 g
s
0 .068 .63 r
.81937 .67163 m .82168 .67472 L .82251 .67871 L p F P
0 g
s
0 .154 .694 r
.64352 .69565 m .64173 .69187 L .63701 .68736 L p F P
0 g
s
0 .125 .669 r
.63512 .68359 m .63701 .68736 L .64173 .69187 L p F P
0 g
s
0 .146 .687 r
.63172 .68027 m .63512 .68359 L .63701 .68736 L p F P
0 g
s
.162 .464 .889 r
.74945 .58949 m .74562 .58789 L .74269 .58375 L p F P
0 g
s
.126 .423 .867 r
.76102 .60068 m .76493 .6026 L .76201 .59821 L p F P
0 g
s
.126 .423 .867 r
.76201 .59821 m .75916 .59681 L .76102 .60068 L p F P
0 g
s
0 .194 .722 r
.81289 .66114 m .81196 .65714 L .80732 .65258 L p F P
0 g
s
0 .207 .732 r
.80624 .6486 m .80732 .65258 L .81196 .65714 L p F P
0 g
s
0 .084 .642 r
.81937 .67163 m .81797 .66985 L .81747 .66735 L closepath p F P
0 g
s
0 .165 .701 r
.81634 .66495 m .81289 .66114 L p .81797 .66985 L F P
0 g
s
0 .165 .701 r
.81797 .66985 m .81747 .66735 L .81634 .66495 L p F P
0 g
s
0 .136 .682 r
.81289 .66114 m .81634 .66495 L .81335 .65869 L p F P
0 g
s
0 .136 .682 r
.81335 .65869 m .81196 .65714 L .81289 .66114 L p F P
0 g
s
0 .167 .704 r
.65001 .70394 m .64832 .70016 L .64352 .69565 L p F P
0 g
s
0 .138 .681 r
.64173 .69187 m .64352 .69565 L .64832 .70016 L p F P
0 g
s
.298 .587 .943 r
.68548 .54967 m .69485 .55154 L .69776 .55522 L p F P
0 g
s
.874 .795 .304 r
.83704 .74337 m .83703 .74744 L .83576 .75385 L p F P
0 g
s
.779 .669 .117 r
.83703 .74744 m .83704 .74337 L .83753 .73718 L p F P
0 g
s
.206 .435 .861 r
.69552 .75609 m .70235 .7592 L .6993 .75425 L p F P
0 g
s
.206 .435 .861 r
.6993 .75425 m .6949 .75213 L .69552 .75609 L p F P
0 g
s
.221 .453 .871 r
.70235 .7592 m .69552 .75609 L p .7044 .76373 L F P
0 g
s
0 0 .151 r
.83727 .72851 m .83717 .72715 L .83633 .72136 L p F P
0 g
s
0 0 .134 r
.83594 .71735 m .83633 .72136 L .83717 .72715 L p F P
0 g
s
0 0 .274 r
.83455 .71172 m .83594 .71735 L .83633 .72136 L p F P
0 g
s
.26 .553 .929 r
.70447 .55978 m .71088 .56145 L .71352 .56518 L p F P
0 g
s
.253 .554 .931 r
.71088 .56145 m .70447 .55978 L .7015 .55603 L p F P
0 g
s
0 .123 .666 r
.63512 .68359 m .63172 .68027 L .62858 .67548 L p F P
0 g
s
0 .183 .717 r
.65431 .70789 m .65001 .70394 L p .65651 .71224 L F P
0 g
s
0 .168 .705 r
.65001 .70394 m .65431 .70789 L .65119 .70285 L p F P
0 g
s
0 .168 .705 r
.65119 .70285 m .64832 .70016 L .65001 .70394 L p F P
0 g
s
.346 .549 .908 r
.7276 .78226 m .72637 .78195 L .72619 .78009 L closepath p F P
0 g
s
.338 .542 .905 r
.72637 .78195 m .72619 .78009 L .7246 .77763 L p F P
0 g
s
.936 .924 .554 r
.83359 .76464 m .83363 .76454 L .83363 .76461 L closepath p F P
0 g
s
.244 .543 .926 r
.71352 .56518 m .72058 .56715 L .71762 .56332 L p F P
0 g
s
.244 .543 .926 r
.71762 .56332 m .71088 .56145 L .71352 .56518 L p F P
0 g
s
.947 .935 .595 r
.83363 .76454 m .83359 .76464 L .83122 .76572 L p F P
0 g
s
.947 .935 .595 r
.83122 .76572 m .83358 .76053 L .83363 .76454 L p F P
0 g
s
.927 .882 .463 r
.83363 .76454 m .83358 .76053 L .83576 .75385 L p F P
0 g
s
.922 .953 .621 r
.82989 .77165 m .83359 .76464 L .83122 .76572 L p F P
0 g
s
.569 .75 .963 r
.76546 .80031 m .77839 .79817 L .78123 .80147 L p F P
0 g
s
.554 .737 .961 r
.77839 .79817 m .76546 .80031 L .76257 .79655 L p F P
0 g
s
.187 .486 .899 r
.73908 .58238 m .74269 .58375 L .73976 .57967 L p F P
0 g
s
.187 .486 .899 r
.73976 .57967 m .73685 .57857 L .73908 .58238 L p F P
0 g
s
0 .296 .792 r
.79338 .63195 m .79032 .6297 L .7874 .62469 L p F P
0 g
s
.079 .375 .84 r
.7783 .61597 m .77666 .61206 L .77001 .60821 L p F P
0 g
s
.071 .376 .841 r
.76822 .60434 m .77001 .60821 L .77666 .61206 L p F P
0 g
s
.105 .403 .856 r
.76493 .6026 m .76822 .60434 L .77001 .60821 L p F P
0 g
s
0 .208 .734 r
.65743 .71305 m .65651 .71224 L .65554 .70994 L closepath p F P
0 g
s
0 .183 .717 r
.65651 .71224 m .65554 .70994 L .65431 .70789 L p F P
0 g
s
.658 .189 0 r
.60358 .64182 m .60281 .64071 L .59966 .63703 L p F P
0 g
s
.435 .601 .915 r
.7276 .78226 m .74043 .78416 L .74082 .78809 L p F P
0 g
s
.417 .59 .914 r
.74043 .78416 m .7276 .78226 L .72619 .78009 L p F P
0 g
s
0 .054 .62 r
.82168 .67472 m .81937 .67163 L .81747 .66735 L p F P
0 g
s
.218 .52 .916 r
.72566 .57172 m .72352 .57104 L .72058 .56715 L p F P
0 g
s
.719 .857 .947 r
.80106 .79779 m .79682 .80001 L .79405 .79727 L p F P
0 g
s
.646 .822 .968 r
.78123 .80147 m .79405 .79727 L .79682 .80001 L p F P
0 g
s
.205 .433 .86 r
.68631 .7444 m .68304 .74281 L .67995 .73763 L p F P
0 g
s
0 0 .359 r
.83455 .71172 m .83407 .70771 L .83218 .70224 L p F P
0 g
s
0 0 .25 r
.83407 .70771 m .83455 .71172 L .83594 .71735 L p F P
0 g
s
.034 .319 .805 r
.67087 .72846 m .66966 .72459 L .66358 .72038 L p F P
0 g
s
0 .295 .792 r
.66234 .7165 m .66358 .72038 L .66966 .72459 L p F P
0 g
s
.049 .326 .808 r
.65743 .71305 m .66234 .7165 L .66358 .72038 L p F P
0 g
s
.232 .462 .875 r
.70541 .76416 m .7044 .76373 L .70412 .76208 L closepath p F P
0 g
s
.221 .453 .871 r
.7044 .76373 m .70412 .76208 L .70235 .7592 L p F P
0 g
s
.511 .665 .931 r
.74662 .79269 m .75966 .7927 L p .76149 .79657 L F P
0 g
s
.469 .661 .945 r
.75966 .7927 m .74662 .79269 L .74367 .78846 L p F P
0 g
s
.63 .807 .967 r
.79405 .79727 m .78123 .80147 L .77839 .79817 L p F P
0 g
s
.014 .309 .8 r
.66234 .7165 m .65743 .71305 L .65554 .70994 L p F P
0 g
s
.086 .372 .837 r
.78447 .61979 m .7783 .61597 L p .78618 .62385 L F P
0 g
s
.051 .352 .826 r
.7783 .61597 m .78447 .61979 L .78156 .61511 L p F P
0 g
s
.051 .352 .826 r
.78156 .61511 m .77666 .61206 L .7783 .61597 L p F P
0 g
s
.284 .578 .94 r
.69776 .55522 m .7015 .55603 L .69852 .55234 L p F P
0 g
s
.284 .578 .94 r
.69852 .55234 m .69485 .55154 L .69776 .55522 L p F P
0 g
s
.601 .141 0 r
.60993 .65015 m .60708 .64658 L .60358 .64182 L p F P
0 g
s
.632 .16 0 r
.60053 .63829 m .60358 .64182 L .60708 .64658 L p F P
0 g
s
.658 .189 0 r
.59966 .63703 m .60053 .63829 L .60358 .64182 L p F P
0 g
s
.736 .571 0 r
.83717 .72715 m .83727 .72851 L .83749 .73407 L p F P
0 g
s
0 0 .047 r
.83753 .73718 m .83749 .73407 L .83727 .72851 L p F P
0 g
s
.796 .684 .138 r
.83749 .73407 m .83753 .73718 L .83704 .74337 L p F P
0 g
s
.043 .327 .81 r
.67685 .73254 m .67087 .72846 L p .67824 .73652 L F P
0 g
s
.025 .312 .801 r
.67087 .72846 m .67685 .73254 L .67375 .72748 L p F P
0 g
s
.025 .312 .801 r
.67375 .72748 m .66966 .72459 L .67087 .72846 L p F P
0 g
s
.341 .528 .893 r
.70541 .76416 m .71445 .76697 L .71486 .77095 L p F P
0 g
s
.32 .517 .892 r
.71445 .76697 m .70541 .76416 L .70412 .76208 L p F P
0 g
s
.719 .857 .947 r
.79405 .79727 m .80127 .79376 L .80106 .79779 L p F P
0 g
s
.749 .898 .945 r
.80676 .79088 m .80127 .79376 L .80106 .79779 L p F P
0 g
s
.749 .898 .945 r
.80106 .79779 m .80945 .79301 L .80676 .79088 L p F P
0 g
s
.148 .446 .879 r
.75916 .59681 m .75718 .59295 L .74945 .58949 L p F P
0 g
s
.14 .447 .88 r
.74731 .58566 m .74945 .58949 L .75718 .59295 L p F P
0 g
s
.162 .464 .889 r
.74269 .58375 m .74731 .58566 L .74945 .58949 L p F P
0 g
s
.923 .972 .765 r
.83018 .76755 m .82989 .77165 L .82468 .77917 L p F P
0 g
s
.922 .953 .621 r
.83122 .76572 m .83018 .76755 L .82989 .77165 L p F P
0 g
s
0 0 .35 r
.8316 .69824 m .83218 .70224 L .83407 .70771 L p F P
0 g
s
0 0 .441 r
.83218 .70224 m .8316 .69824 L .82923 .69292 L p F P
0 g
s
0 0 .426 r
.61618 .65852 m .6135 .65492 L .60993 .65015 L p F P
0 g
s
.598 .136 0 r
.60708 .64658 m .60993 .65015 L .6135 .65492 L p F P
0 g
s
.093 .401 .855 r
.76822 .60434 m .76493 .6026 L .76201 .59821 L p F P
0 g
s
0 .054 .62 r
.81747 .66735 m .81712 .66585 L p .82168 .67472 L F P
0 g
s
0 .117 .668 r
.81747 .66735 m .81634 .66495 L .81712 .66585 L closepath p F P
0 g
s
.417 .59 .914 r
.72619 .78009 m .72633 .77791 L p .74043 .78416 L F P
0 g
s
.41 .584 .912 r
.72619 .78009 m .7246 .77763 L .72633 .77791 L closepath p F P
0 g
s
.02 .317 .805 r
.7874 .62469 m .78618 .62385 L .78493 .62053 L closepath p F P
0 g
s
.086 .372 .837 r
.78618 .62385 m .78493 .62053 L .78447 .61979 L p F P
0 g
s
0 0 .46 r
.62235 .66692 m .61982 .66329 L .61618 .65852 L p F P
0 g
s
0 0 .427 r
.6135 .65492 m .61618 .65852 L .61982 .66329 L p F P
0 g
s
.203 .503 .908 r
.73685 .57857 m .7345 .57478 L .72566 .57172 L p F P
0 g
s
.196 .504 .909 r
.72314 .56797 m .72566 .57172 L .7345 .57478 L p F P
0 g
s
.218 .52 .916 r
.72058 .56715 m .72314 .56797 L .72566 .57172 L p F P
0 g
s
.061 .343 .819 r
.67995 .73763 m .67824 .73652 L .67717 .73306 L closepath p F P
0 g
s
.043 .327 .81 r
.67824 .73652 m .67717 .73306 L .67685 .73254 L p F P
0 g
s
.934 .888 .48 r
.83572 .74981 m .83576 .75385 L .83358 .76053 L p F P
0 g
s
.874 .795 .304 r
.83576 .75385 m .83572 .74981 L .83704 .74337 L p F P
0 g
s
0 0 .485 r
.62544 .67085 m .62235 .66692 L p .62846 .67533 L F P
0 g
s
0 0 .472 r
.62235 .66692 m .62544 .67085 L .62229 .66646 L p F P
0 g
s
0 0 .472 r
.62229 .66646 m .61982 .66329 L .62235 .66692 L p F P
0 g
s
0 0 .434 r
.82854 .68892 m .82923 .69292 L .8316 .69824 L p F P
0 g
s
0 0 .509 r
.82923 .69292 m .82854 .68892 L .82572 .68375 L p F P
0 g
s
.153 .464 .889 r
.74731 .58566 m .74269 .58375 L .73976 .57967 L p F P
0 g
s
.302 .511 .893 r
.71486 .77095 m .72159 .77297 L .71857 .76832 L p F P
0 g
s
.302 .511 .893 r
.71857 .76832 m .71445 .76697 L .71486 .77095 L p F P
0 g
s
0 .26 .769 r
.80004 .6402 m .79873 .63626 L .79338 .63195 L p F P
0 g
s
0 .259 .769 r
.79192 .62803 m .79338 .63195 L .79873 .63626 L p F P
0 g
s
0 .296 .792 r
.7874 .62469 m .79192 .62803 L .79338 .63195 L p F P
0 g
s
0 0 .525 r
.62858 .67548 m .62846 .67533 L .62809 .67477 L closepath p F P
0 g
s
0 0 .485 r
.62846 .67533 m .62809 .67477 L .62544 .67085 L p F P
0 g
s
.32 .517 .892 r
.70412 .76208 m .704 .75974 L p .71445 .76697 L F P
0 g
s
.31 .508 .888 r
.70412 .76208 m .70235 .7592 L .704 .75974 L closepath p F P
0 g
s
0 .112 .665 r
.81712 .66585 m .81634 .66495 L .81335 .65869 L p F P
0 g
s
.397 .595 .924 r
.74082 .78809 m .74367 .78846 L .74071 .7842 L p F P
0 g
s
.397 .595 .924 r
.74071 .7842 m .74043 .78416 L .74082 .78809 L p F P
0 g
s
0 .292 .789 r
.65554 .70994 m .65431 .70789 L .65502 .70842 L closepath p F P
0 g
s
.014 .309 .8 r
.65554 .70994 m .65502 .70842 L p .66234 .7165 L F P
0 g
s
0 .123 .666 r
.62858 .67548 m .63301 .67987 L .63512 .68359 L p F P
0 g
s
0 .101 .644 r
.63301 .67987 m .62858 .67548 L .62809 .67477 L p F P
0 g
s
0 0 .504 r
.82492 .67976 m .82572 .68375 L .82854 .68892 L p F P
0 g
s
0 0 .566 r
.82572 .68375 m .82492 .67976 L .82168 .67472 L p F P
0 g
s
.736 .571 0 r
.83749 .73407 m .83742 .73312 L .83717 .72715 L p F P
0 g
s
0 0 .134 r
.83717 .72715 m .83678 .72314 L .83594 .71735 L p F P
0 g
s
.76 .586 .015 r
.83678 .72314 m .83717 .72715 L .83742 .73312 L p F P
0 g
s
.807 .927 .914 r
.81642 .78752 m .80945 .79301 L .80676 .79088 L p F P
0 g
s
.495 .679 .947 r
.76257 .79655 m .76149 .79657 L .76129 .79486 L closepath p F P
0 g
s
.511 .665 .931 r
.75966 .7927 m .76129 .79486 L .76149 .79657 L p F P
0 g
s
0 .29 .789 r
.79192 .62803 m .7874 .62469 L .78493 .62053 L p F P
0 g
s
.892 .965 .831 r
.82468 .77917 m .82183 .78255 L .81924 .78133 L p F P
0 g
s
.892 .965 .831 r
.81924 .78133 m .82474 .77514 L .82468 .77917 L p F P
0 g
s
.923 .972 .765 r
.82468 .77917 m .82474 .77514 L .83018 .76755 L p F P
0 g
s
.179 .426 .861 r
.6949 .75213 m .69402 .74823 L .68631 .7444 L p F P
0 g
s
.141 .407 .854 r
.68551 .74045 m .68631 .7444 L .69402 .74823 L p F P
0 g
s
.205 .433 .86 r
.67995 .73763 m .68551 .74045 L .68631 .7444 L p F P
0 g
s
.116 .422 .867 r
.75916 .59681 m .76201 .59821 L .75909 .59389 L p F P
0 g
s
.116 .422 .867 r
.75909 .59389 m .75718 .59295 L .75916 .59681 L p F P
0 g
s
0 .229 .747 r
.80624 .6486 m .80507 .64464 L .80004 .6402 L p F P
0 g
s
0 .228 .747 r
.79873 .63626 m .80004 .6402 L .80507 .64464 L p F P
0 g
s
0 .125 .669 r
.64173 .69187 m .63975 .68813 L .63512 .68359 L p F P
0 g
s
0 .098 .643 r
.63301 .67987 m .63512 .68359 L .63975 .68813 L p F P
0 g
s
0 .101 .644 r
.62809 .67477 m .6262 .67164 L p .63301 .67987 L F P
0 g
s
0 .076 .623 r
.62809 .67477 m .62544 .67085 L .6262 .67164 L closepath p F P
0 g
s
0 0 .562 r
.82075 .67075 m .82168 .67472 L .82492 .67976 L p F P
0 g
s
0 .054 .62 r
.81712 .66585 m .82075 .67075 L .82168 .67472 L p F P
0 g
s
0 .207 .732 r
.81036 .65262 m .80624 .6486 L p .81196 .65714 L F P
0 g
s
0 .18 .714 r
.80624 .6486 m .81036 .65262 L .8074 .64693 L p F P
0 g
s
0 .18 .714 r
.8074 .64693 m .80507 .64464 L .80624 .6486 L p F P
0 g
s
.85 .964 .877 r
.81642 .78752 m .82183 .78255 L .81924 .78133 L p F P
0 g
s
.807 .927 .914 r
.80676 .79088 m .8168 .78342 L .81642 .78752 L p F P
0 g
s
.85 .964 .877 r
.81924 .78133 m .8168 .78342 L .81642 .78752 L p F P
0 g
s
.253 .554 .931 r
.7015 .55603 m .70811 .55774 L .71088 .56145 L p F P
0 g
s
.247 .555 .932 r
.70811 .55774 m .7015 .55603 L .69852 .55234 L p F P
0 g
s
.554 .737 .961 r
.76257 .79655 m .77554 .79476 L .77839 .79817 L p F P
0 g
s
.554 .708 .943 r
.77268 .79127 m .77554 .79476 L .76257 .79655 L p F P
0 g
s
.554 .708 .943 r
.76192 .79244 m .77268 .79127 L p .76257 .79655 L F P
0 g
s
.554 .708 .943 r
.76257 .79655 m .76129 .79486 L .76192 .79244 L p F P
0 g
s
.177 .421 .857 r
.68551 .74045 m .67995 .73763 L .67717 .73306 L p F P
0 g
s
0 .041 .61 r
.81607 .66189 m .81712 .66585 L .82075 .67075 L p F P
0 g
s
0 .112 .665 r
.81335 .65869 m .81607 .66189 L .81712 .66585 L p F P
0 g
s
.41 .584 .912 r
.72633 .77791 m .7246 .77763 L .72159 .77297 L p F P
0 g
s
0 .13 .678 r
.81335 .65869 m .81196 .65714 L .81123 .65433 L closepath p F P
0 g
s
0 .207 .732 r
.81196 .65714 m .81123 .65433 L .81036 .65262 L p F P
0 g
s
0 .138 .681 r
.64832 .70016 m .64643 .69641 L .64173 .69187 L p F P
0 g
s
0 .111 .656 r
.63975 .68813 m .64173 .69187 L .64643 .69641 L p F P
0 g
s
.237 .543 .927 r
.71088 .56145 m .71762 .56332 L .71467 .55956 L p F P
0 g
s
.237 .543 .927 r
.71467 .55956 m .70811 .55774 L .71088 .56145 L p F P
0 g
s
0 .287 .787 r
.65502 .70842 m .65431 .70789 L .65119 .70285 L p F P
0 g
s
.179 .486 .9 r
.73685 .57857 m .73976 .57967 L .73683 .57566 L p F P
0 g
s
.179 .486 .9 r
.73683 .57566 m .7345 .57478 L .73685 .57857 L p F P
0 g
s
0 .145 .686 r
.64832 .70016 m .65119 .70285 L .64806 .69798 L p F P
0 g
s
0 .145 .686 r
.64806 .69798 m .64643 .69641 L .64832 .70016 L p F P
0 g
s
.173 .422 .858 r
.6949 .75213 m .6993 .75425 L .69623 .74935 L p F P
0 g
s
.173 .422 .858 r
.69623 .74935 m .69402 .74823 L .6949 .75213 L p F P
0 g
s
0 0 .12 r
.83546 .71334 m .83594 .71735 L .83678 .72314 L p F P
0 g
s
0 0 .25 r
.83594 .71735 m .83546 .71334 L .83407 .70771 L p F P
0 g
s
.469 .661 .945 r
.74367 .78846 m .75674 .78878 L .75966 .7927 L p F P
0 g
s
.455 .651 .943 r
.75674 .78878 m .74367 .78846 L .74071 .7842 L p F P
0 g
s
.884 .803 .319 r
.83699 .73931 m .83704 .74337 L .83572 .74981 L p F P
0 g
s
.796 .684 .138 r
.83718 .7371 m .83749 .73407 L p .83704 .74337 L F P
0 g
s
.796 .684 .138 r
.83704 .74337 m .83699 .73931 L .83718 .7371 L p F P
0 g
s
.071 .376 .841 r
.77666 .61206 m .7749 .60818 L .76822 .60434 L p F P
0 g
s
.063 .376 .841 r
.76631 .60048 m .76822 .60434 L .7749 .60818 L p F P
0 g
s
.093 .401 .855 r
.76201 .59821 m .76631 .60048 L .76822 .60434 L p F P
0 g
s
.21 .521 .917 r
.72314 .56797 m .72058 .56715 L .71762 .56332 L p F P
0 g
s
.307 .509 .89 r
.704 .75974 m .70235 .7592 L .6993 .75425 L p F P
0 g
s
.014 .309 .8 r
.65502 .70842 m .66086 .71267 L .66234 .7165 L p F P
0 g
s
0 .268 .775 r
.65349 .70459 m .65502 .70842 L .66086 .71267 L p F P
0 g
s
0 .287 .787 r
.65119 .70285 m .65349 .70459 L .65502 .70842 L p F P
0 g
s
.417 .59 .914 r
.72633 .77791 m .73773 .77988 L p .74043 .78416 L F P
0 g
s
.383 .569 .911 r
.72633 .77791 m .73773 .77988 L .73475 .77553 L p F P
0 g
s
.383 .569 .911 r
.73475 .77553 m .72629 .77385 L .72633 .77791 L p F P
0 g
s
.41 .584 .912 r
.72159 .77297 m .72629 .77385 L .72633 .77791 L p F P
0 g
s
.964 .933 .622 r
.83358 .76053 m .83348 .75651 L p .83027 .76594 L F P
0 g
s
.964 .933 .622 r
.83027 .76594 m .83122 .76572 L .83358 .76053 L p F P
0 g
s
.934 .888 .48 r
.83358 .76053 m .83348 .75651 L .83572 .74981 L p F P
0 g
s
.704 .85 .952 r
.80127 .79376 m .79405 .79727 L .79127 .79438 L p F P
0 g
s
.63 .807 .967 r
.77839 .79817 m .79127 .79438 L .79405 .79727 L p F P
0 g
s
.616 .793 .967 r
.79127 .79438 m .77839 .79817 L .77554 .79476 L p F P
0 g
s
.826 .687 .146 r
.83718 .7371 m .83742 .73312 L .83749 .73407 L closepath p F P
0 g
s
0 .1 .656 r
.81607 .66189 m .81335 .65869 L .81123 .65433 L p F P
0 g
s
.552 .706 .942 r
.76129 .79486 m .75966 .7927 L .76192 .79244 L closepath p F P
0 g
s
0 .295 .792 r
.66966 .72459 m .66823 .72077 L .66234 .7165 L p F P
0 g
s
0 .272 .778 r
.66086 .71267 m .66234 .7165 L .66823 .72077 L p F P
0 g
s
.632 .16 0 r
.60708 .64658 m .60403 .64305 L .60053 .63829 L p F P
0 g
s
.082 .398 .854 r
.76631 .60048 m .76201 .59821 L .75909 .59389 L p F P
0 g
s
0 0 .35 r
.83407 .70771 m .8335 .70371 L .8316 .69824 L p F P
0 g
s
0 0 .24 r
.8335 .70371 m .83407 .70771 L .83546 .71334 L p F P
0 g
s
.038 .349 .825 r
.77666 .61206 m .78156 .61511 L .77865 .61051 L p F P
0 g
s
.038 .349 .825 r
.77865 .61051 m .7749 .60818 L .77666 .61206 L p F P
0 g
s
.32 .517 .892 r
.704 .75974 m .71375 .76306 L .71445 .76697 L p F P
0 g
s
.252 .493 .893 r
.70353 .75574 m .704 .75974 L .71375 .76306 L p F P
0 g
s
.307 .509 .89 r
.6993 .75425 m .70353 .75574 L .704 .75974 L p F P
0 g
s
0 .29 .789 r
.78493 .62053 m .78468 .61993 L p .79192 .62803 L F P
0 g
s
.03 .332 .815 r
.78493 .62053 m .78447 .61979 L .78468 .61993 L closepath p F P
0 g
s
.598 .136 0 r
.6135 .65492 m .61063 .65135 L .60708 .64658 L p F P
0 g
s
.627 .154 0 r
.60403 .64305 m .60708 .64658 L .61063 .65135 L p F P
0 g
s
.14 .447 .88 r
.75718 .59295 m .75508 .58912 L .74731 .58566 L p F P
0 g
s
.133 .448 .881 r
.74505 .58186 m .74731 .58566 L .75508 .58912 L p F P
0 g
s
.153 .464 .889 r
.73976 .57967 m .74505 .58186 L .74731 .58566 L p F P
0 g
s
0 .294 .791 r
.66966 .72459 m .67375 .72748 L .67065 .72253 L p F P
0 g
s
0 .294 .791 r
.67065 .72253 m .66823 .72077 L .66966 .72459 L p F P
0 g
s
0 .06 .604 r
.6262 .67164 m .62544 .67085 L .62229 .66646 L p F P
0 g
s
.143 .463 .889 r
.74505 .58186 m .73976 .57967 L .73683 .57566 L p F P
0 g
s
0 0 .427 r
.61982 .66329 m .61711 .65969 L .6135 .65492 L p F P
0 g
s
.595 .132 0 r
.61063 .65135 m .6135 .65492 L .61711 .65969 L p F P
0 g
s
.932 .963 .668 r
.83018 .76755 m .83027 .76594 L .83122 .76572 L closepath p F P
0 g
s
.196 .504 .909 r
.7345 .57478 m .73201 .57102 L .72314 .56797 L p F P
0 g
s
.188 .505 .91 r
.7205 .56423 m .72314 .56797 L .73201 .57102 L p F P
0 g
s
.21 .521 .917 r
.71762 .56332 m .7205 .56423 L .72314 .56797 L p F P
0 g
s
.871 .713 .192 r
.83742 .73312 m .83702 .72913 L p .83697 .73872 L F P
0 g
s
.871 .713 .192 r
.83697 .73872 m .83718 .7371 L .83742 .73312 L p F P
0 g
s
.76 .586 .015 r
.83742 .73312 m .83702 .72913 L .83678 .72314 L p F P
0 g
s
.019 .33 .814 r
.78468 .61993 m .78447 .61979 L .78156 .61511 L p F P
0 g
s
.163 .408 .851 r
.67717 .73306 m .67685 .73254 L .67708 .73266 L closepath p F P
0 g
s
.177 .421 .857 r
.67717 .73306 m .67708 .73266 L p .68551 .74045 L F P
0 g
s
0 0 .342 r
.83093 .69424 m .8316 .69824 L .8335 .70371 L p F P
0 g
s
0 0 .434 r
.8316 .69824 m .83093 .69424 L .82854 .68892 L p F P
0 g
s
0 .29 .789 r
.78468 .61993 m .79036 .62412 L .79192 .62803 L p F P
0 g
s
0 .286 .787 r
.78298 .61604 m .78468 .61993 L .79036 .62412 L p F P
0 g
s
.019 .33 .814 r
.78156 .61511 m .78298 .61604 L .78468 .61993 L p F P
0 g
s
.704 .85 .952 r
.79127 .79438 m .80183 .78961 L .80127 .79376 L p F P
0 g
s
.732 .881 .949 r
.80404 .78854 m .80183 .78961 L .80127 .79376 L p F P
0 g
s
.732 .881 .949 r
.80127 .79376 m .80676 .79088 L .80404 .78854 L p F P
0 g
s
0 0 .442 r
.61982 .66329 m .62229 .66646 L .61914 .66232 L p F P
0 g
s
0 0 .442 r
.61914 .66232 m .61711 .65969 L .61982 .66329 L p F P
0 g
s
.154 .408 .852 r
.67708 .73266 m .67685 .73254 L .67375 .72748 L p F P
0 g
s
.917 .971 .782 r
.83027 .76594 m .83018 .76755 L .82474 .77514 L p F P
0 g
s
.177 .421 .857 r
.67708 .73266 m .68445 .73657 L .68551 .74045 L p F P
0 g
s
.107 .389 .846 r
.67605 .72875 m .67708 .73266 L .68445 .73657 L p F P
0 g
s
.154 .408 .852 r
.67375 .72748 m .67605 .72875 L .67708 .73266 L p F P
0 g
s
.391 .575 .912 r
.72629 .77385 m .72159 .77297 L .71857 .76832 L p F P
0 g
s
0 .1 .656 r
.81123 .65433 m .81089 .65317 L p .81607 .66189 L F P
0 g
s
0 .16 .7 r
.81123 .65433 m .81036 .65262 L .81089 .65317 L closepath p F P
0 g
s
0 .101 .644 r
.6262 .67164 m .63071 .67619 L .63301 .67987 L p F P
0 g
s
0 .061 .602 r
.62375 .66799 m .6262 .67164 L .63071 .67619 L p F P
0 g
s
0 .06 .604 r
.62229 .66646 m .62375 .66799 L .6262 .67164 L p F P
0 g
s
0 .269 .776 r
.65349 .70459 m .65119 .70285 L .64806 .69798 L p F P
0 g
s
.941 .894 .495 r
.83564 .74576 m .83572 .74981 L .83348 .75651 L p F P
0 g
s
.884 .803 .319 r
.83572 .74981 m .83564 .74576 L .83699 .73931 L p F P
0 g
s
0 0 .428 r
.82775 .68493 m .82854 .68892 L .83093 .69424 L p F P
0 g
s
0 0 .504 r
.82854 .68892 m .82775 .68493 L .82492 .67976 L p F P
0 g
s
0 .259 .769 r
.79873 .63626 m .7973 .63233 L .79192 .62803 L p F P
0 g
s
0 .258 .768 r
.79036 .62412 m .79192 .62803 L .7973 .63233 L p F P
0 g
s
.553 .703 .94 r
.76192 .79244 m .75966 .7927 L .75674 .78878 L p F P
0 g
s
.275 .501 .893 r
.71445 .76697 m .71857 .76832 L .71554 .76369 L p F P
0 g
s
.275 .501 .893 r
.71554 .76369 m .71375 .76306 L .71445 .76697 L p F P
0 g
s
.105 .42 .866 r
.75718 .59295 m .75909 .59389 L .75617 .58965 L p F P
0 g
s
.105 .42 .866 r
.75617 .58965 m .75508 .58912 L .75718 .59295 L p F P
0 g
s
.247 .555 .932 r
.69852 .55234 m .7052 .55406 L .70811 .55774 L p F P
0 g
s
0 .098 .643 r
.63975 .68813 m .63756 .68444 L .63301 .67987 L p F P
0 g
s
0 .073 .617 r
.63071 .67619 m .63301 .67987 L .63756 .68444 L p F P
0 g
s
.284 .498 .889 r
.70353 .75574 m .6993 .75425 L .69623 .74935 L p F P
0 g
s
.79 .936 .926 r
.8168 .78342 m .80676 .79088 L .80404 .78854 L p F P
0 g
s
.417 .59 .914 r
.73773 .77988 m .74037 .78372 L .74043 .78416 L p F P
0 g
s
.394 .596 .927 r
.74071 .7842 m .74043 .78416 L .74037 .78372 L closepath p F P
0 g
s
0 0 .499 r
.82401 .67578 m .82492 .67976 L .82775 .68493 L p F P
0 g
s
0 0 .562 r
.82492 .67976 m .82401 .67578 L .82075 .67075 L p F P
0 g
s
0 .228 .747 r
.80507 .64464 m .80379 .64069 L .79873 .63626 L p F P
0 g
s
0 .241 .757 r
.7973 .63233 m .79873 .63626 L .80379 .64069 L p F P
0 g
s
0 .155 .697 r
.81089 .65317 m .81036 .65262 L .8074 .64693 L p F P
0 g
s
0 0 .12 r
.83678 .72314 m .8363 .71915 L .83546 .71334 L p F P
0 g
s
.777 .598 .03 r
.8363 .71915 m .83678 .72314 L .83702 .72913 L p F P
0 g
s
.455 .651 .943 r
.74071 .7842 m .75381 .78481 L .75674 .78878 L p F P
0 g
s
.463 .635 .929 r
.75087 .78081 m .75381 .78481 L .74071 .7842 L p F P
0 g
s
.463 .635 .929 r
.74059 .78006 m .75087 .78081 L p .74071 .7842 L F P
0 g
s
.463 .635 .929 r
.74071 .7842 m .74037 .78372 L .74059 .78006 L p F P
0 g
s
.141 .407 .854 r
.69402 .74823 m .69291 .74438 L .68551 .74045 L p F P
0 g
s
.112 .393 .848 r
.68445 .73657 m .68551 .74045 L .69291 .74438 L p F P
0 g
s
.23 .544 .928 r
.70811 .55774 m .71467 .55956 L .7117 .55585 L p F P
0 g
s
.23 .544 .928 r
.7117 .55585 m .7052 .55406 L .70811 .55774 L p F P
0 g
s
0 0 .557 r
.81973 .66679 m .82075 .67075 L .82401 .67578 L p F P
0 g
s
0 .041 .61 r
.82075 .67075 m .81973 .66679 L .81607 .66189 L p F P
0 g
s
.894 .942 .835 r
.82474 .77514 m .8248 .7711 L p .81715 .78014 L F P
0 g
s
.894 .942 .835 r
.81715 .78014 m .81924 .78133 L .82474 .77514 L p F P
0 g
s
.917 .971 .782 r
.82876 .76586 m .83027 .76594 L p .82474 .77514 L F P
0 g
s
.917 .971 .782 r
.82474 .77514 m .8248 .7711 L .82876 .76586 L p F P
0 g
s
0 .17 .708 r
.80507 .64464 m .8074 .64693 L .80444 .64133 L p F P
0 g
s
0 .17 .708 r
.80444 .64133 m .80379 .64069 L .80507 .64464 L p F P
0 g
s
0 .111 .656 r
.64643 .69641 m .64435 .69271 L .63975 .68813 L p F P
0 g
s
0 .077 .624 r
.63756 .68444 m .63975 .68813 L .64435 .69271 L p F P
0 g
s
.533 .696 .944 r
.76192 .79244 m .77268 .79127 L .7698 .7877 L p F P
0 g
s
.533 .696 .944 r
.7698 .7877 m .76237 .7883 L .76192 .79244 L p F P
0 g
s
.553 .703 .94 r
.75674 .78878 m .76237 .7883 L .76192 .79244 L p F P
0 g
s
.459 .631 .928 r
.74037 .78372 m .73773 .77988 L .74059 .78006 L closepath p F P
0 g
s
0 .036 .606 r
.81493 .65794 m .81607 .66189 L .81973 .66679 L p F P
0 g
s
0 .1 .656 r
.81089 .65317 m .81493 .65794 L .81607 .66189 L p F P
0 g
s
.816 .696 .156 r
.83699 .73931 m .83697 .73872 L .83718 .7371 L closepath p F P
0 g
s
0 .089 .648 r
.80962 .64924 m .81089 .65317 L .81493 .65794 L p F P
0 g
s
0 .155 .697 r
.8074 .64693 m .80962 .64924 L .81089 .65317 L p F P
0 g
s
.17 .486 .901 r
.7345 .57478 m .73683 .57566 L .73389 .57172 L p F P
0 g
s
.17 .486 .901 r
.73389 .57172 m .73201 .57102 L .7345 .57478 L p F P
0 g
s
.203 .521 .917 r
.7205 .56423 m .71762 .56332 L .71467 .55956 L p F P
0 g
s
0 .123 .666 r
.64643 .69641 m .64806 .69798 L .64493 .69327 L p F P
0 g
s
0 .123 .666 r
.64493 .69327 m .64435 .69271 L .64643 .69641 L p F P
0 g
s
.79 .936 .926 r
.81715 .78014 m .8168 .78342 L p .80404 .78854 L F P
0 g
s
.837 .95 .892 r
.8168 .78342 m .81715 .78014 L .81924 .78133 L closepath p F P
0 g
s
.946 .959 .71 r
.82876 .76586 m .83016 .76352 L .83027 .76594 L closepath p F P
0 g
s
.964 .933 .622 r
.83348 .75651 m .83016 .76352 L .83027 .76594 L p F P
0 g
s
.063 .376 .841 r
.7749 .60818 m .77303 .60431 L .76631 .60048 L p F P
0 g
s
.054 .375 .841 r
.76429 .59664 m .76631 .60048 L .77303 .60431 L p F P
0 g
s
.082 .398 .854 r
.75909 .59389 m .76429 .59664 L .76631 .60048 L p F P
0 g
s
.616 .793 .967 r
.77554 .79476 m .78847 .79137 L .79127 .79438 L p F P
0 g
s
.601 .779 .966 r
.78847 .79137 m .77554 .79476 L .77268 .79127 L p F P
0 g
s
.07 .396 .853 r
.76429 .59664 m .75909 .59389 L .75617 .58965 L p F P
0 g
s
.141 .407 .854 r
.69402 .74823 m .69623 .74935 L .69316 .74451 L p F P
0 g
s
.141 .407 .854 r
.69316 .74451 m .69291 .74438 L .69402 .74823 L p F P
0 g
s
0 0 .107 r
.8349 .70934 m .83546 .71334 L .8363 .71915 L p F P
0 g
s
0 0 .24 r
.83546 .71334 m .8349 .70934 L .8335 .70371 L p F P
0 g
s
.687 .852 .962 r
.80183 .78961 m .79127 .79438 L .78847 .79137 L p F P
0 g
s
0 .269 .776 r
.64806 .69798 m .65173 .7008 L .65349 .70459 L p F P
0 g
s
0 .268 .775 r
.66086 .71267 m .65918 .70889 L .65349 .70459 L p F P
0 g
s
0 .245 .759 r
.65173 .7008 m .65349 .70459 L .65918 .70889 L p F P
0 g
s
.893 .807 .328 r
.83697 .73872 m .83699 .73931 L .83564 .74576 L p F P
0 g
s
.958 .942 .638 r
.83333 .75249 m .83348 .75651 L .83016 .76352 L p F P
0 g
s
.941 .894 .495 r
.83348 .75651 m .83333 .75249 L .83564 .74576 L p F P
0 g
s
.359 .561 .913 r
.72629 .77385 m .73475 .77553 L .73176 .77118 L p F P
0 g
s
.359 .561 .913 r
.73176 .77118 m .72589 .76987 L .72629 .77385 L p F P
0 g
s
.391 .575 .912 r
.71857 .76832 m .72589 .76987 L .72629 .77385 L p F P
0 g
s
0 .038 .576 r
.62375 .66799 m .62229 .66646 L .61914 .66232 L p F P
0 g
s
.004 .325 .811 r
.78298 .61604 m .78156 .61511 L .77865 .61051 L p F P
0 g
s
.124 .395 .847 r
.67605 .72875 m .67375 .72748 L .67065 .72253 L p F P
0 g
s
.627 .154 0 r
.61063 .65135 m .60757 .64783 L .60403 .64305 L p F P
0 g
s
0 .272 .778 r
.66823 .72077 m .6666 .71699 L .66086 .71267 L p F P
0 g
s
0 .246 .76 r
.65918 .70889 m .66086 .71267 L .6666 .71699 L p F P
0 g
s
.024 .345 .823 r
.7749 .60818 m .77865 .61051 L .77573 .60599 L p F P
0 g
s
.024 .345 .823 r
.77573 .60599 m .77303 .60431 L .7749 .60818 L p F P
0 g
s
.918 .805 .334 r
.83661 .73531 m .83697 .73872 L .83552 .74228 L p F P
0 g
s
.871 .713 .192 r
.83702 .72913 m .83661 .73531 L .83697 .73872 L p F P
0 g
s
.893 .807 .328 r
.83564 .74576 m .83552 .74228 L .83697 .73872 L p F P
0 g
s
.143 .463 .889 r
.73683 .57566 m .74267 .57808 L .74505 .58186 L p F P
0 g
s
.134 .462 .889 r
.74267 .57808 m .73683 .57566 L .73389 .57172 L p F P
0 g
s
.372 .566 .912 r
.72589 .76987 m .71857 .76832 L .71554 .76369 L p F P
0 g
s
.133 .448 .881 r
.75508 .58912 m .75285 .5853 L .74505 .58186 L p F P
0 g
s
.148 .465 .89 r
.74267 .57808 m .74505 .58186 L .75285 .5853 L p F P
0 g
s
0 0 .342 r
.8335 .70371 m .83285 .69971 L .83093 .69424 L p F P
0 g
s
0 0 .229 r
.83285 .69971 m .8335 .70371 L .8349 .70934 L p F P
0 g
s
0 .251 .763 r
.65173 .7008 m .64806 .69798 L .64493 .69327 L p F P
0 g
s
.595 .132 0 r
.61711 .65969 m .61422 .65613 L .61063 .65135 L p F P
0 g
s
.622 .148 0 r
.60757 .64783 m .61063 .65135 L .61422 .65613 L p F P
0 g
s
.188 .505 .91 r
.73201 .57102 m .72939 .56727 L .7205 .56423 L p F P
0 g
s
.181 .505 .91 r
.71773 .56052 m .7205 .56423 L .72939 .56727 L p F P
0 g
s
.203 .521 .917 r
.71467 .55956 m .71773 .56052 L .7205 .56423 L p F P
0 g
s
0 .145 .69 r
.80962 .64924 m .8074 .64693 L .80444 .64133 L p F P
0 g
s
.252 .493 .893 r
.71251 .75908 m .70353 .75574 L p .71375 .76306 L F P
0 g
s
.246 .478 .884 r
.70353 .75574 m .71251 .75908 L .70947 .75445 L p F P
0 g
s
.246 .478 .884 r
.70947 .75445 m .70277 .7518 L .70353 .75574 L p F P
0 g
s
.284 .498 .889 r
.69623 .74935 m .70277 .7518 L .70353 .75574 L p F P
0 g
s
0 .275 .78 r
.66823 .72077 m .67065 .72253 L .66755 .7177 L p F P
0 g
s
0 .275 .78 r
.66755 .7177 m .6666 .71699 L .66823 .72077 L p F P
0 g
s
.26 .488 .887 r
.70277 .7518 m .69623 .74935 L .69316 .74451 L p F P
0 g
s
.579 .115 0 r
.61711 .65969 m .61914 .66232 L .61599 .65844 L p F P
0 g
s
.579 .115 0 r
.61599 .65844 m .61422 .65613 L .61711 .65969 L p F P
0 g
s
.538 .694 .94 r
.76237 .7883 m .75674 .78878 L .75381 .78481 L p F P
0 g
s
0 .286 .787 r
.79036 .62412 m .78868 .62023 L .78298 .61604 L p F P
0 g
s
0 .285 .786 r
.78116 .61217 m .78298 .61604 L .78868 .62023 L p F P
0 g
s
.004 .325 .811 r
.77865 .61051 m .78116 .61217 L .78298 .61604 L p F P
0 g
s
.867 .715 .193 r
.83654 .72514 m .83702 .72913 L .83661 .73531 L p F P
0 g
s
.777 .598 .03 r
.83702 .72913 m .83654 .72514 L .8363 .71915 L p F P
0 g
s
0 0 .334 r
.83016 .69025 m .83093 .69424 L .83285 .69971 L p F P
0 g
s
0 0 .428 r
.83093 .69424 m .83016 .69025 L .82775 .68493 L p F P
0 g
s
.459 .63 .928 r
.74059 .78006 m .73773 .77988 L .73475 .77553 L p F P
0 g
s
0 .061 .602 r
.63071 .67619 m .62821 .67256 L .62375 .66799 L p F P
0 g
s
0 .039 .575 r
.6211 .66438 m .62375 .66799 L .62821 .67256 L p F P
0 g
s
0 .038 .576 r
.61914 .66232 m .6211 .66438 L .62375 .66799 L p F P
0 g
s
.107 .389 .846 r
.68445 .73657 m .68316 .73273 L .67605 .72875 L p F P
0 g
s
.069 .37 .837 r
.67477 .72489 m .67605 .72875 L .68316 .73273 L p F P
0 g
s
.124 .395 .847 r
.67065 .72253 m .67477 .72489 L .67605 .72875 L p F P
0 g
s
0 .258 .768 r
.7973 .63233 m .79577 .62842 L .79036 .62412 L p F P
0 g
s
0 .257 .767 r
.78868 .62023 m .79036 .62412 L .79577 .62842 L p F P
0 g
s
.943 .959 .732 r
.83016 .76352 m .82876 .76586 L .82624 .76535 L p F P
0 g
s
.943 .959 .732 r
.82624 .76535 m .82989 .75954 L .83016 .76352 L p F P
0 g
s
.958 .942 .638 r
.83016 .76352 m .82989 .75954 L .83333 .75249 L p F P
0 g
s
.687 .852 .962 r
.80237 .78702 m .80183 .78961 L p .78847 .79137 L F P
0 g
s
.716 .866 .952 r
.80183 .78961 m .80237 .78702 L .80404 .78854 L closepath p F P
0 g
s
.094 .419 .866 r
.75508 .58912 m .75617 .58965 L .75325 .5855 L p F P
0 g
s
.094 .419 .866 r
.75325 .5855 m .75285 .5853 L .75508 .58912 L p F P
0 g
s
0 0 .421 r
.82688 .68096 m .82775 .68493 L .83016 .69025 L p F P
0 g
s
0 0 .499 r
.82775 .68493 m .82688 .68096 L .82401 .67578 L p F P
0 g
s
0 .073 .617 r
.63756 .68444 m .63519 .68078 L .63071 .67619 L p F P
0 g
s
0 .05 .59 r
.62821 .67256 m .63071 .67619 L .63519 .68078 L p F P
0 g
s
.947 .9 .512 r
.83552 .74228 m .83564 .74576 L .83333 .75249 L p F P
0 g
s
0 .241 .757 r
.8015 .636 m .7973 .63233 L p .80379 .64069 L F P
0 g
s
0 .214 .739 r
.7973 .63233 m .8015 .636 L .79856 .63087 L p F P
0 g
s
0 .214 .739 r
.79856 .63087 m .79577 .62842 L .7973 .63233 L p F P
0 g
s
.915 .975 .779 r
.8248 .7711 m .82876 .76586 L .82624 .76535 L p F P
0 g
s
.79 .936 .926 r
.80404 .78854 m .81661 .77979 L .81715 .78014 L p F P
0 g
s
.793 .882 .911 r
.80237 .78702 m .80404 .78854 L .81661 .77979 L p F P
0 g
s
.263 .502 .897 r
.71554 .76369 m .71375 .76306 L .71296 .75977 L closepath p F P
0 g
s
.252 .493 .893 r
.71375 .76306 m .71296 .75977 L .71251 .75908 L p F P
0 g
s
0 0 .493 r
.82302 .67182 m .82401 .67578 L .82688 .68096 L p F P
0 g
s
0 0 .557 r
.82401 .67578 m .82302 .67182 L .81973 .66679 L p F P
0 g
s
.195 .521 .918 r
.71773 .56052 m .71467 .55956 L .7117 .55585 L p F P
0 g
s
0 .077 .624 r
.6418 .68873 m .63756 .68444 L p .64435 .69271 L F P
0 g
s
0 .072 .616 r
.63756 .68444 m .6418 .68873 L .63867 .68434 L p F P
0 g
s
0 .072 .616 r
.63867 .68434 m .63519 .68078 L .63756 .68444 L p F P
0 g
s
.161 .486 .901 r
.73201 .57102 m .73389 .57172 L .73095 .56786 L p F P
0 g
s
.161 .486 .901 r
.73095 .56786 m .72939 .56727 L .73201 .57102 L p F P
0 g
s
0 .164 .704 r
.80444 .64133 m .80379 .64069 L .80321 .63905 L closepath p F P
0 g
s
0 .241 .757 r
.80379 .64069 m .80321 .63905 L .8015 .636 L p F P
0 g
s
.794 .608 .045 r
.83575 .71515 m .8363 .71915 L .83654 .72514 L p F P
0 g
s
0 0 .107 r
.8363 .71915 m .83575 .71515 L .8349 .70934 L p F P
0 g
s
.112 .393 .848 r
.69009 .73969 m .68445 .73657 L p .69291 .74438 L F P
0 g
s
.097 .38 .841 r
.68445 .73657 m .69009 .73969 L .68701 .73494 L p F P
0 g
s
.097 .38 .841 r
.68701 .73494 m .68316 .73273 L .68445 .73657 L p F P
0 g
s
.07 .396 .853 r
.75617 .58965 m .76214 .59282 L .76429 .59664 L p F P
0 g
s
.058 .393 .852 r
.76214 .59282 m .75617 .58965 L .75325 .5855 L p F P
0 g
s
.894 .942 .835 r
.8248 .7711 m .8171 .77933 L .81715 .78014 L p F P
0 g
s
.856 .937 .875 r
.81661 .77979 m .8171 .77933 L .81715 .78014 L closepath p F P
0 g
s
0 0 .553 r
.81861 .66284 m .81973 .66679 L .82302 .67182 L p F P
0 g
s
0 .036 .606 r
.81973 .66679 m .81861 .66284 L .81493 .65794 L p F P
0 g
s
.434 .619 .929 r
.74059 .78006 m .75087 .78081 L .74792 .77677 L p F P
0 g
s
.434 .619 .929 r
.74792 .77677 m .74042 .77603 L .74059 .78006 L p F P
0 g
s
.459 .63 .928 r
.73475 .77553 m .74042 .77603 L .74059 .78006 L p F P
0 g
s
.587 .767 .965 r
.78564 .78825 m .77268 .79127 L .7698 .7877 L p F P
0 g
s
.601 .779 .966 r
.77268 .79127 m .78564 .78825 L .78847 .79137 L p F P
0 g
s
0 .084 .644 r
.80825 .64532 m .80962 .64924 L .81368 .654 L p F P
0 g
s
0 .145 .69 r
.80444 .64133 m .80825 .64532 L .80962 .64924 L p F P
0 g
s
0 .089 .648 r
.81493 .65794 m .81368 .654 L .80962 .64924 L p F P
0 g
s
0 .031 .602 r
.81368 .654 m .81493 .65794 L .81861 .66284 L p F P
0 g
s
.093 .381 .842 r
.67477 .72489 m .67065 .72253 L .66755 .7177 L p F P
0 g
s
0 .111 .652 r
.64493 .69327 m .64435 .69271 L .64285 .69026 L closepath p F P
0 g
s
0 .077 .624 r
.64435 .69271 m .64285 .69026 L .6418 .68873 L p F P
0 g
s
.877 .943 .854 r
.82487 .76704 m .8248 .7711 L .8171 .77933 L p F P
0 g
s
.915 .975 .779 r
.82624 .76535 m .82487 .76704 L .8248 .7711 L p F P
0 g
s
0 .321 .809 r
.78116 .61217 m .77865 .61051 L .77573 .60599 L p F P
0 g
s
.054 .375 .841 r
.77303 .60431 m .77103 .60046 L .76429 .59664 L p F P
0 g
s
.044 .375 .841 r
.76214 .59282 m .76429 .59664 L .77103 .60046 L p F P
0 g
s
0 .134 .681 r
.80825 .64532 m .80444 .64133 L .80321 .63905 L p F P
0 g
s
.687 .852 .962 r
.78847 .79137 m .80129 .78602 L .80237 .78702 L p F P
0 g
s
.671 .838 .963 r
.80129 .78602 m .78847 .79137 L .78564 .78825 L p F P
0 g
s
0 .017 .548 r
.6211 .66438 m .61914 .66232 L .61599 .65844 L p F P
0 g
s
.515 .691 .948 r
.76237 .7883 m .7698 .7877 L .7669 .78406 L p F P
0 g
s
.515 .691 .948 r
.7669 .78406 m .76215 .78431 L .76237 .7883 L p F P
0 g
s
.538 .694 .94 r
.75381 .78481 m .76215 .78431 L .76237 .7883 L p F P
0 g
s
.372 .566 .912 r
.71554 .76369 m .7252 .76595 L .72589 .76987 L p F P
0 g
s
.353 .556 .911 r
.7252 .76595 m .71554 .76369 L .71296 .75977 L p F P
0 g
s
0 .251 .763 r
.64493 .69327 m .64977 .69707 L .65173 .7008 L p F P
0 g
s
0 .234 .749 r
.64977 .69707 m .64493 .69327 L .64285 .69026 L p F P
0 g
s
.845 .928 .884 r
.8171 .77933 m .81661 .77979 L .81394 .77789 L p F P
0 g
s
.845 .928 .884 r
.81394 .77789 m .81678 .77539 L .8171 .77933 L p F P
0 g
s
.877 .943 .854 r
.8171 .77933 m .81678 .77539 L .82487 .76704 L p F P
0 g
s
.793 .882 .911 r
.81661 .77979 m .81394 .77789 L p .80237 .78702 L F P
0 g
s
0 .245 .759 r
.65918 .70889 m .65729 .70515 L .65173 .7008 L p F P
0 g
s
0 .222 .741 r
.64977 .69707 m .65173 .7008 L .65729 .70515 L p F P
0 g
s
.128 .406 .855 r
.69316 .74451 m .69291 .74438 L .69273 .74384 L closepath p F P
0 g
s
.112 .393 .848 r
.69291 .74438 m .69273 .74384 L .69009 .73969 L p F P
0 g
s
.134 .462 .889 r
.73389 .57172 m .74016 .57432 L .74267 .57808 L p F P
0 g
s
.124 .461 .889 r
.74016 .57432 m .73389 .57172 L .73095 .56786 L p F P
0 g
s
0 0 .229 r
.8349 .70934 m .83426 .70535 L .83285 .69971 L p F P
0 g
s
.71 .494 0 r
.83426 .70535 m .8349 .70934 L .83575 .71515 L p F P
0 g
s
.26 .488 .887 r
.69316 .74451 m .70176 .74792 L .70277 .7518 L p F P
0 g
s
.237 .477 .885 r
.70176 .74792 m .69316 .74451 L .69273 .74384 L p F P
0 g
s
.918 .805 .334 r
.83552 .74228 m .83546 .74172 L .83661 .73531 L p F P
0 g
s
.933 .814 .356 r
.83611 .73134 m .83661 .73531 L .83546 .74172 L p F P
0 g
s
.867 .715 .193 r
.83661 .73531 m .83611 .73134 L .83654 .72514 L p F P
0 g
s
.011 .341 .821 r
.77303 .60431 m .77573 .60599 L .77281 .60157 L p F P
0 g
s
.011 .341 .821 r
.77281 .60157 m .77103 .60046 L .77303 .60431 L p F P
0 g
s
.148 .465 .89 r
.75032 .58144 m .74267 .57808 L p .75285 .5853 L F P
0 g
s
.112 .446 .881 r
.74267 .57808 m .75032 .58144 L .74739 .57749 L p F P
0 g
s
.112 .446 .881 r
.74739 .57749 m .74016 .57432 L .74267 .57808 L p F P
0 g
s
.237 .477 .885 r
.69273 .74384 m .69195 .74046 L p .70176 .74792 L F P
0 g
s
.227 .469 .881 r
.69273 .74384 m .69009 .73969 L .69195 .74046 L closepath p F P
0 g
s
.622 .148 0 r
.61422 .65613 m .61115 .65261 L .60757 .64783 L p F P
0 g
s
0 .246 .76 r
.66444 .71298 m .65918 .70889 L p .6666 .71699 L F P
0 g
s
0 .237 .754 r
.65918 .70889 m .66444 .71298 L .66132 .70835 L p F P
0 g
s
0 .237 .754 r
.66132 .70835 m .65729 .70515 L .65918 .70889 L p F P
0 g
s
.959 .944 .651 r
.83313 .74846 m .83333 .75249 L .82989 .75954 L p F P
0 g
s
.947 .9 .512 r
.8352 .74262 m .83552 .74228 L p .83333 .75249 L F P
0 g
s
.947 .9 .512 r
.83333 .75249 m .83313 .74846 L .8352 .74262 L p F P
0 g
s
.181 .505 .91 r
.72939 .56727 m .72663 .56356 L .71773 .56052 L p F P
0 g
s
.172 .505 .911 r
.71482 .55684 m .71773 .56052 L .72663 .56356 L p F P
0 g
s
.195 .521 .918 r
.7117 .55585 m .71482 .55684 L .71773 .56052 L p F P
0 g
s
0 .134 .681 r
.80321 .63905 m .80234 .63677 L p .80825 .64532 L F P
0 g
s
0 .193 .724 r
.80321 .63905 m .8015 .636 L .80234 .63677 L closepath p F P
0 g
s
.523 .685 .94 r
.76215 .78431 m .75381 .78481 L .75087 .78081 L p F P
0 g
s
.335 .552 .914 r
.72589 .76987 m .73176 .77118 L .72876 .76684 L p F P
0 g
s
.335 .552 .914 r
.72876 .76684 m .7252 .76595 L .72589 .76987 L p F P
0 g
s
.442 .622 .928 r
.74042 .77603 m .73475 .77553 L .73176 .77118 L p F P
0 g
s
.606 .131 0 r
.61422 .65613 m .61599 .65844 L .61284 .65481 L p F P
0 g
s
.606 .131 0 r
.61284 .65481 m .61115 .65261 L .61422 .65613 L p F P
0 g
s
.756 .871 .931 r
.80129 .78602 m .80217 .78551 L .80237 .78702 L closepath p F P
0 g
s
.793 .882 .911 r
.81394 .77789 m .80217 .78551 L .80237 .78702 L p F P
0 g
s
0 0 .219 r
.8321 .69572 m .83285 .69971 L .83426 .70535 L p F P
0 g
s
0 0 .334 r
.83285 .69971 m .8321 .69572 L .83016 .69025 L p F P
0 g
s
0 .268 .775 r
.66755 .7177 m .6666 .71699 L .66526 .71424 L closepath p F P
0 g
s
0 .246 .76 r
.6666 .71699 m .66526 .71424 L .66444 .71298 L p F P
0 g
s
0 .285 .786 r
.78868 .62023 m .78689 .61635 L .78116 .61217 L p F P
0 g
s
0 .283 .784 r
.77924 .60832 m .78116 .61217 L .78689 .61635 L p F P
0 g
s
0 .321 .809 r
.77573 .60599 m .77924 .60832 L .78116 .61217 L p F P
0 g
s
.218 .467 .882 r
.70277 .7518 m .70947 .75445 L .70642 .74987 L p F P
0 g
s
.218 .467 .882 r
.70642 .74987 m .70176 .74792 L .70277 .7518 L p F P
0 g
s
0 .039 .575 r
.62821 .67256 m .62552 .66896 L .6211 .66438 L p F P
0 g
s
0 .019 .549 r
.61824 .66081 m .6211 .66438 L .62552 .66896 L p F P
0 g
s
0 .017 .548 r
.61599 .65844 m .61824 .66081 L .6211 .66438 L p F P
0 g
s
0 .234 .749 r
.64285 .69026 m .64215 .68902 L p .64977 .69707 L F P
0 g
s
0 .217 .737 r
.64285 .69026 m .6418 .68873 L .64215 .68902 L closepath p F P
0 g
s
0 0 .325 r
.82931 .68627 m .83016 .69025 L .8321 .69572 L p F P
0 g
s
0 0 .421 r
.83016 .69025 m .82931 .68627 L .82688 .68096 L p F P
0 g
s
.88 .724 .21 r
.83599 .72115 m .83654 .72514 L .83611 .73134 L p F P
0 g
s
.794 .608 .045 r
.83654 .72514 m .83599 .72115 L .83575 .71515 L p F P
0 g
s
.083 .417 .865 r
.75325 .5855 m .75285 .5853 L .75123 .58269 L closepath p F P
0 g
s
.148 .465 .89 r
.75285 .5853 m .75123 .58269 L .75032 .58144 L p F P
0 g
s
0 .257 .767 r
.79577 .62842 m .79412 .62452 L .78868 .62023 L p F P
0 g
s
0 .255 .766 r
.78689 .61635 m .78868 .62023 L .79412 .62452 L p F P
0 g
s
.093 .381 .842 r
.66755 .7177 m .67327 .72107 L .67477 .72489 L p F P
0 g
s
.063 .368 .836 r
.67327 .72107 m .66755 .7177 L .66526 .71424 L p F P
0 g
s
0 .05 .59 r
.63519 .68078 m .63264 .67716 L .62821 .67256 L p F P
0 g
s
0 .029 .565 r
.62552 .66896 m .62821 .67256 L .63264 .67716 L p F P
0 g
s
.069 .37 .837 r
.68316 .73273 m .68166 .72893 L .67477 .72489 L p F P
0 g
s
.031 .351 .827 r
.67327 .72107 m .67477 .72489 L .68166 .72893 L p F P
0 g
s
.353 .556 .911 r
.71296 .75977 m .7129 .75917 L p .7252 .76595 L F P
0 g
s
.346 .55 .909 r
.71296 .75977 m .71251 .75908 L .7129 .75917 L closepath p F P
0 g
s
0 .188 .721 r
.80234 .63677 m .8015 .636 L .79856 .63087 L p F P
0 g
s
.953 .871 .461 r
.8352 .74262 m .83546 .74172 L .83552 .74228 L closepath p F P
0 g
s
.058 .393 .852 r
.75325 .5855 m .75988 .58901 L .76214 .59282 L p F P
0 g
s
.045 .39 .85 r
.75988 .58901 m .75325 .5855 L .75123 .58269 L p F P
0 g
s
0 0 .414 r
.8259 .67699 m .82688 .68096 L .82931 .68627 L p F P
0 g
s
0 0 .493 r
.82688 .68096 m .8259 .67699 L .82302 .67182 L p F P
0 g
s
.947 .945 .744 r
.82989 .75954 m .82959 .75556 L p .82488 .7649 L F P
0 g
s
.947 .945 .744 r
.82488 .7649 m .82624 .76535 L .82989 .75954 L p F P
0 g
s
.959 .944 .651 r
.82989 .75954 m .82959 .75556 L .83313 .74846 L p F P
0 g
s
0 .316 .806 r
.77924 .60832 m .77573 .60599 L .77281 .60157 L p F P
0 g
s
.587 .767 .965 r
.7698 .7877 m .78281 .78503 L .78564 .78825 L p F P
0 g
s
.574 .756 .964 r
.78281 .78503 m .7698 .7877 L .7669 .78406 L p F P
0 g
s
.744 .861 .935 r
.80217 .78551 m .80129 .78602 L .79852 .78332 L p F P
0 g
s
.671 .838 .963 r
.78564 .78825 m .79852 .78332 L .80129 .78602 L p F P
0 g
s
0 .206 .733 r
.79577 .62842 m .79856 .63087 L .79563 .62585 L p F P
0 g
s
0 .206 .733 r
.79563 .62585 m .79412 .62452 L .79577 .62842 L p F P
0 g
s
.152 .486 .901 r
.72939 .56727 m .73095 .56786 L .728 .56406 L p F P
0 g
s
.152 .486 .901 r
.728 .56406 m .72663 .56356 L .72939 .56727 L p F P
0 g
s
0 .052 .593 r
.63519 .68078 m .63867 .68434 L .63553 .68014 L p F P
0 g
s
0 .052 .593 r
.63553 .68014 m .63264 .67716 L .63519 .68078 L p F P
0 g
s
.344 .551 .91 r
.7129 .75917 m .71251 .75908 L .70947 .75445 L p F P
0 g
s
.744 .861 .935 r
.79852 .78332 m .80158 .78164 L .80217 .78551 L p F P
0 g
s
.777 .909 .931 r
.81124 .77579 m .80158 .78164 L .80217 .78551 L p F P
0 g
s
.777 .909 .931 r
.80217 .78551 m .81394 .77789 L .81124 .77579 L p F P
0 g
s
.965 .883 .497 r
.83546 .74172 m .8352 .74262 L .83289 .74442 L p F P
0 g
s
.965 .883 .497 r
.83289 .74442 m .83492 .73776 L .83546 .74172 L p F P
0 g
s
.933 .814 .356 r
.83546 .74172 m .83492 .73776 L .83611 .73134 L p F P
0 g
s
0 .207 .728 r
.64215 .68902 m .6418 .68873 L .63867 .68434 L p F P
0 g
s
.353 .556 .911 r
.7129 .75917 m .72424 .76209 L .7252 .76595 L p F P
0 g
s
.292 .537 .914 r
.71227 .7552 m .7129 .75917 L .72424 .76209 L p F P
0 g
s
.344 .551 .91 r
.70947 .75445 m .71227 .7552 L .7129 .75917 L p F P
0 g
s
0 0 .487 r
.82192 .66786 m .82302 .67182 L .8259 .67699 L p F P
0 g
s
0 0 .553 r
.82302 .67182 m .82192 .66786 L .81861 .66284 L p F P
0 g
s
0 .134 .681 r
.80234 .63677 m .80677 .64141 L .80825 .64532 L p F P
0 g
s
0 .127 .675 r
.80073 .63288 m .80234 .63677 L .80677 .64141 L p F P
0 g
s
0 .188 .721 r
.79856 .63087 m .80073 .63288 L .80234 .63677 L p F P
0 g
s
0 0 .519 r
.61824 .66081 m .61599 .65844 L .61284 .65481 L p F P
0 g
s
.22 .469 .883 r
.69195 .74046 m .69009 .73969 L .68701 .73494 L p F P
0 g
s
.064 .366 .835 r
.68316 .73273 m .68701 .73494 L .68392 .73028 L p F P
0 g
s
.064 .366 .835 r
.68392 .73028 m .68166 .72893 L .68316 .73273 L p F P
0 g
s
0 0 .548 r
.81739 .6589 m .81861 .66284 L .82192 .66786 L p F P
0 g
s
0 .031 .602 r
.81861 .66284 m .81739 .6589 L .81368 .654 L p F P
0 g
s
0 .234 .749 r
.64215 .68902 m .6476 .69337 L .64977 .69707 L p F P
0 g
s
0 .2 .721 r
.63988 .68533 m .64215 .68902 L .6476 .69337 L p F P
0 g
s
0 .207 .728 r
.63867 .68434 m .63988 .68533 L .64215 .68902 L p F P
0 g
s
.951 .901 .517 r
.83313 .74846 m .8352 .74262 L .83289 .74442 L p F P
0 g
s
0 .084 .644 r
.81368 .654 m .81233 .65008 L .80825 .64532 L p F P
0 g
s
0 .079 .64 r
.80677 .64141 m .80825 .64532 L .81233 .65008 L p F P
0 g
s
0 .026 .598 r
.81233 .65008 m .81368 .654 L .81739 .6589 L p F P
0 g
s
.809 .617 .06 r
.83512 .71116 m .83575 .71515 L .83599 .72115 L p F P
0 g
s
.71 .494 0 r
.83575 .71515 m .83512 .71116 L .83426 .70535 L p F P
0 g
s
.044 .375 .841 r
.77103 .60046 m .76892 .59663 L .76214 .59282 L p F P
0 g
s
.034 .374 .841 r
.75988 .58901 m .76214 .59282 L .76892 .59663 L p F P
0 g
s
.657 .824 .964 r
.79852 .78332 m .78564 .78825 L .78281 .78503 L p F P
0 g
s
.442 .622 .928 r
.73176 .77118 m .73989 .77209 L .74042 .77603 L p F P
0 g
s
.413 .612 .932 r
.74042 .77603 m .74792 .77677 L .74495 .77271 L p F P
0 g
s
.413 .612 .932 r
.74495 .77271 m .73989 .77209 L .74042 .77603 L p F P
0 g
s
.124 .461 .889 r
.73095 .56786 m .73753 .57058 L .74016 .57432 L p F P
0 g
s
.114 .46 .888 r
.73753 .57058 m .73095 .56786 L .728 .56406 L p F P
0 g
s
.909 .968 .804 r
.82487 .76704 m .82488 .7649 L .82624 .76535 L closepath p F P
0 g
s
.868 .939 .864 r
.82488 .7649 m .82487 .76704 L .81678 .77539 L p F P
0 g
s
0 .222 .741 r
.65729 .70515 m .65522 .70144 L .64977 .69707 L p F P
0 g
s
0 .201 .723 r
.6476 .69337 m .64977 .69707 L .65522 .70144 L p F P
0 g
s
.425 .613 .928 r
.73989 .77209 m .73176 .77118 L .72876 .76684 L p F P
0 g
s
.523 .685 .94 r
.75087 .78081 m .76149 .78044 L .76215 .78431 L p F P
0 g
s
.508 .676 .94 r
.76149 .78044 m .75087 .78081 L .74792 .77677 L p F P
0 g
s
.496 .684 .95 r
.76215 .78431 m .7669 .78406 L .764 .78037 L p F P
0 g
s
.496 .684 .95 r
.764 .78037 m .76149 .78044 L .76215 .78431 L p F P
0 g
s
.834 .921 .892 r
.81678 .77539 m .81394 .77789 L .81124 .77579 L p F P
0 g
s
.063 .368 .836 r
.66526 .71424 m .66485 .71323 L p .67327 .72107 L F P
0 g
s
.05 .356 .829 r
.66526 .71424 m .66444 .71298 L .66485 .71323 L closepath p F P
0 g
s
.237 .477 .885 r
.69195 .74046 m .70052 .74409 L .70176 .74792 L p F P
0 g
s
.167 .448 .878 r
.69081 .73658 m .69195 .74046 L .70052 .74409 L p F P
0 g
s
.22 .469 .883 r
.68701 .73494 m .69081 .73658 L .69195 .74046 L p F P
0 g
s
.868 .939 .864 r
.82366 .76433 m .82488 .7649 L p .81678 .77539 L F P
0 g
s
.868 .939 .864 r
.81678 .77539 m .81644 .77143 L .82366 .76433 L p F P
0 g
s
.834 .921 .892 r
.81124 .77579 m .81644 .77143 L .81678 .77539 L p F P
0 g
s
.172 .505 .911 r
.72663 .56356 m .72374 .55986 L .71482 .55684 L p F P
0 g
s
.102 .445 .88 r
.74016 .57432 m .74739 .57749 L .74446 .57361 L p F P
0 g
s
.102 .445 .88 r
.74446 .57361 m .73753 .57058 L .74016 .57432 L p F P
0 g
s
0 .338 .819 r
.77103 .60046 m .77281 .60157 L .76989 .59724 L p F P
0 g
s
0 .338 .819 r
.76989 .59724 m .76892 .59663 L .77103 .60046 L p F P
0 g
s
0 0 .219 r
.83426 .70535 m .83353 .70136 L .8321 .69572 L p F P
0 g
s
.727 .503 0 r
.83353 .70136 m .83426 .70535 L .83512 .71116 L p F P
0 g
s
0 .219 .739 r
.65729 .70515 m .66132 .70835 L .6582 .70386 L p F P
0 g
s
0 .219 .739 r
.6582 .70386 m .65522 .70144 L .65729 .70515 L p F P
0 g
s
.942 .82 .372 r
.83553 .72736 m .83611 .73134 L .83492 .73776 L p F P
0 g
s
.88 .724 .21 r
.83611 .73134 m .83553 .72736 L .83599 .72115 L p F P
0 g
s
.09 .425 .87 r
.75123 .58269 m .75032 .58144 L .75048 .58152 L closepath p F P
0 g
s
.045 .39 .85 r
.75123 .58269 m .75048 .58152 L p .75988 .58901 L F P
0 g
s
.033 .353 .828 r
.66485 .71323 m .66444 .71298 L .66132 .70835 L p F P
0 g
s
.959 .945 .663 r
.83288 .74443 m .83313 .74846 L .82959 .75556 L p F P
0 g
s
.951 .901 .517 r
.83289 .74442 m .83288 .74443 L .83313 .74846 L p F P
0 g
s
.311 .543 .914 r
.7252 .76595 m .72876 .76684 L .72575 .7625 L p F P
0 g
s
.311 .543 .914 r
.72575 .7625 m .72424 .76209 L .7252 .76595 L p F P
0 g
s
0 .179 .714 r
.80073 .63288 m .79856 .63087 L .79563 .62585 L p F P
0 g
s
0 .019 .549 r
.62552 .66896 m .62264 .6654 L .61824 .66081 L p F P
0 g
s
0 .003 .524 r
.61519 .65729 m .61824 .66081 L .62264 .6654 L p F P
0 g
s
0 0 .519 r
.61284 .65481 m .61519 .65729 L .61824 .66081 L p F P
0 g
s
0 .283 .784 r
.78689 .61635 m .78499 .6125 L .77924 .60832 L p F P
0 g
s
0 .28 .783 r
.7772 .60449 m .77924 .60832 L .78499 .6125 L p F P
0 g
s
0 .316 .806 r
.77281 .60157 m .7772 .60449 L .77924 .60832 L p F P
0 g
s
.063 .368 .836 r
.66485 .71323 m .67155 .7173 L .67327 .72107 L p F P
0 g
s
0 .336 .818 r
.66309 .70945 m .66485 .71323 L .67155 .7173 L p F P
0 g
s
.033 .353 .828 r
.66132 .70835 m .66309 .70945 L .66485 .71323 L p F P
0 g
s
0 0 .325 r
.8321 .69572 m .83127 .69174 L .82931 .68627 L p F P
0 g
s
0 0 .212 r
.83127 .69174 m .8321 .69572 L .83353 .70136 L p F P
0 g
s
.19 .456 .88 r
.70176 .74792 m .70642 .74987 L .70336 .74534 L p F P
0 g
s
.19 .456 .88 r
.70336 .74534 m .70052 .74409 L .70176 .74792 L p F P
0 g
s
.323 .542 .91 r
.71227 .7552 m .70947 .75445 L .70642 .74987 L p F P
0 g
s
.079 .423 .869 r
.75048 .58152 m .75032 .58144 L .74739 .57749 L p F P
0 g
s
0 .311 .802 r
.7772 .60449 m .77281 .60157 L .76989 .59724 L p F P
0 g
s
.045 .39 .85 r
.75048 .58152 m .7575 .58523 L .75988 .58901 L p F P
0 g
s
.034 .389 .849 r
.74796 .57776 m .75048 .58152 L .7575 .58523 L p F P
0 g
s
.079 .423 .869 r
.74739 .57749 m .74796 .57776 L .75048 .58152 L p F P
0 g
s
0 .029 .565 r
.63264 .67716 m .62992 .67357 L .62552 .66896 L p F P
0 g
s
0 .011 .54 r
.62264 .6654 m .62552 .66896 L .62992 .67357 L p F P
0 g
s
.195 .458 .88 r
.69081 .73658 m .68701 .73494 L .68392 .73028 L p F P
0 g
s
0 .255 .766 r
.79412 .62452 m .79237 .62064 L .78689 .61635 L p F P
0 g
s
0 .27 .776 r
.78499 .6125 m .78689 .61635 L .79237 .62064 L p F P
0 g
s
.574 .756 .964 r
.7669 .78406 m .77995 .78172 L .78281 .78503 L p F P
0 g
s
.561 .746 .963 r
.77995 .78172 m .7669 .78406 L .764 .78037 L p F P
0 g
s
0 .189 .71 r
.63988 .68533 m .63867 .68434 L .63553 .68014 L p F P
0 g
s
0 0 .314 r
.82836 .6823 m .82931 .68627 L .83127 .69174 L p F P
0 g
s
0 0 .414 r
.82931 .68627 m .82836 .6823 L .8259 .67699 L p F P
0 g
s
.893 .732 .225 r
.83535 .71717 m .83599 .72115 L .83553 .72736 L p F P
0 g
s
.809 .617 .06 r
.83599 .72115 m .83535 .71717 L .83512 .71116 L p F P
0 g
s
.916 .951 .803 r
.82366 .76433 m .82467 .76304 L .82488 .7649 L closepath p F P
0 g
s
.947 .945 .744 r
.82959 .75556 m .82467 .76304 L .82488 .7649 L p F P
0 g
s
.031 .351 .827 r
.68166 .72893 m .67996 .72517 L .67327 .72107 L p F P
0 g
s
0 .328 .813 r
.67155 .7173 m .67327 .72107 L .67996 .72517 L p F P
0 g
s
.142 .485 .901 r
.72663 .56356 m .728 .56406 L .72504 .56035 L p F P
0 g
s
.142 .485 .901 r
.72504 .56035 m .72374 .55986 L .72663 .56356 L p F P
0 g
s
0 .034 .57 r
.63264 .67716 m .63553 .68014 L .63239 .67614 L p F P
0 g
s
0 .034 .57 r
.63239 .67614 m .62992 .67357 L .63264 .67716 L p F P
0 g
s
.732 .855 .939 r
.80158 .78164 m .79852 .78332 L .79573 .7805 L p F P
0 g
s
.657 .824 .964 r
.78281 .78503 m .79573 .7805 L .79852 .78332 L p F P
0 g
s
0 .198 .727 r
.79412 .62452 m .79563 .62585 L .79269 .62093 L p F P
0 g
s
0 .198 .727 r
.79269 .62093 m .79237 .62064 L .79412 .62452 L p F P
0 g
s
0 0 .406 r
.82483 .67303 m .8259 .67699 L .82836 .6823 L p F P
0 g
s
0 0 .487 r
.8259 .67699 m .82483 .67303 L .82192 .66786 L p F P
0 g
s
.938 .951 .762 r
.82923 .75157 m .82959 .75556 L .82467 .76304 L p F P
0 g
s
.959 .945 .663 r
.82959 .75556 m .82923 .75157 L .83288 .74443 L p F P
0 g
s
.643 .812 .964 r
.79573 .7805 m .78281 .78503 L .77995 .78172 L p F P
0 g
s
0 .127 .675 r
.80677 .64141 m .80518 .63752 L .80073 .63288 L p F P
0 g
s
0 .122 .671 r
.79901 .629 m .80073 .63288 L .80518 .63752 L p F P
0 g
s
0 .179 .714 r
.79563 .62585 m .79901 .629 L .80073 .63288 L p F P
0 g
s
0 0 .487 r
.82072 .66392 m .82192 .66786 L .82483 .67303 L p F P
0 g
s
0 0 .548 r
.82192 .66786 m .82072 .66392 L .81739 .6589 L p F P
0 g
s
.425 .613 .928 r
.72876 .76684 m .73906 .76821 L .73989 .77209 L p F P
0 g
s
.408 .605 .928 r
.73906 .76821 m .72876 .76684 L .72575 .7625 L p F P
0 g
s
.732 .855 .939 r
.79573 .7805 m .80106 .77773 L .80158 .78164 L p F P
0 g
s
.763 .894 .936 r
.80852 .77351 m .80106 .77773 L .80158 .78164 L p F P
0 g
s
.763 .894 .936 r
.80158 .78164 m .81124 .77579 L .80852 .77351 L p F P
0 g
s
0 .2 .721 r
.6476 .69337 m .64525 .68971 L .63988 .68533 L p F P
0 g
s
0 .181 .702 r
.6374 .68169 m .63988 .68533 L .64525 .68971 L p F P
0 g
s
0 .189 .71 r
.63553 .68014 m .6374 .68169 L .63988 .68533 L p F P
0 g
s
.034 .374 .841 r
.76892 .59663 m .76668 .59282 L .75988 .58901 L p F P
0 g
s
.048 .392 .851 r
.7575 .58523 m .75988 .58901 L .76668 .59282 L p F P
0 g
s
.98 .884 .524 r
.83492 .73776 m .83431 .7338 L p .83288 .74443 L F P
0 g
s
.98 .884 .524 r
.83288 .74443 m .83289 .74442 L .83492 .73776 L p F P
0 g
s
.942 .82 .372 r
.83492 .73776 m .83431 .7338 L .83553 .72736 L p F P
0 g
s
.508 .676 .94 r
.74792 .77677 m .7605 .77663 L .76149 .78044 L p F P
0 g
s
.493 .668 .941 r
.7605 .77663 m .74792 .77677 L .74495 .77271 L p F P
0 g
s
.114 .46 .888 r
.728 .56406 m .73477 .56686 L .73753 .57058 L p F P
0 g
s
.104 .458 .887 r
.73477 .56686 m .728 .56406 L .72504 .56035 L p F P
0 g
s
0 .079 .64 r
.81233 .65008 m .81087 .64617 L .80677 .64141 L p F P
0 g
s
0 .075 .635 r
.80518 .63752 m .80677 .64141 L .81087 .64617 L p F P
0 g
s
.292 .537 .914 r
.72273 .75817 m .71227 .7552 L p .72424 .76209 L F P
0 g
s
.292 .525 .905 r
.71227 .7552 m .72273 .75817 L .7197 .75383 L p F P
0 g
s
.292 .525 .905 r
.7197 .75383 m .71137 .75129 L .71227 .7552 L p F P
0 g
s
.323 .542 .91 r
.70642 .74987 m .71137 .75129 L .71227 .7552 L p F P
0 g
s
.031 .351 .827 r
.68166 .72893 m .68392 .73028 L .68083 .72571 L p F P
0 g
s
.031 .351 .827 r
.68083 .72571 m .67996 .72517 L .68166 .72893 L p F P
0 g
s
0 0 .557 r
.81606 .65497 m .81739 .6589 L .82072 .66392 L p F P
0 g
s
0 .026 .598 r
.81739 .6589 m .81606 .65497 L .81233 .65008 L p F P
0 g
s
0 .021 .593 r
.81087 .64617 m .81233 .65008 L .81606 .65497 L p F P
0 g
s
.824 .626 .074 r
.8344 .70718 m .83512 .71116 L .83535 .71717 L p F P
0 g
s
.727 .503 0 r
.83512 .71116 m .8344 .70718 L .83353 .70136 L p F P
0 g
s
0 .201 .723 r
.65522 .70144 m .65296 .69777 L .6476 .69337 L p F P
0 g
s
0 .181 .704 r
.64525 .68971 m .6476 .69337 L .65296 .69777 L p F P
0 g
s
0 .17 .706 r
.79901 .629 m .79563 .62585 L .79269 .62093 L p F P
0 g
s
.392 .605 .933 r
.73989 .77209 m .74495 .77271 L .74198 .76864 L p F P
0 g
s
.392 .605 .933 r
.74198 .76864 m .73906 .76821 L .73989 .77209 L p F P
0 g
s
.001 .339 .82 r
.66309 .70945 m .66132 .70835 L .6582 .70386 L p F P
0 g
s
.092 .444 .88 r
.73753 .57058 m .74446 .57361 L .74152 .56981 L p F P
0 g
s
.092 .444 .88 r
.74152 .56981 m .73477 .56686 L .73753 .57058 L p F P
0 g
s
0 .334 .816 r
.76892 .59663 m .76989 .59724 L .76697 .593 L p F P
0 g
s
0 .334 .816 r
.76697 .593 m .76668 .59282 L .76892 .59663 L p F P
0 g
s
.908 .946 .816 r
.82467 .76304 m .82366 .76433 L .82103 .76289 L p F P
0 g
s
.908 .946 .816 r
.82103 .76289 m .82414 .75911 L .82467 .76304 L p F P
0 g
s
.938 .951 .762 r
.82467 .76304 m .82414 .75911 L .82923 .75157 L p F P
0 g
s
.479 .677 .952 r
.76149 .78044 m .764 .78037 L .76108 .77663 L p F P
0 g
s
.479 .677 .952 r
.76108 .77663 m .7605 .77663 L .76149 .78044 L p F P
0 g
s
.867 .953 .864 r
.81644 .77143 m .82366 .76433 L .82103 .76289 L p F P
0 g
s
.167 .448 .878 r
.70052 .74409 m .69907 .7403 L .69081 .73658 L p F P
0 g
s
.131 .43 .87 r
.68943 .73275 m .69081 .73658 L .69907 .7403 L p F P
0 g
s
.195 .458 .88 r
.68392 .73028 m .68943 .73275 L .69081 .73658 L p F P
0 g
s
.823 .916 .9 r
.81644 .77143 m .81124 .77579 L .80852 .77351 L p F P
0 g
s
0 .202 .724 r
.65522 .70144 m .6582 .70386 L .65508 .69951 L p F P
0 g
s
0 .202 .724 r
.65508 .69951 m .65296 .69777 L .65522 .70144 L p F P
0 g
s
.303 .534 .909 r
.71137 .75129 m .70642 .74987 L .70336 .74534 L p F P
0 g
s
0 0 .212 r
.83225 .69559 m .83127 .69174 L p .83351 .70128 L F P
0 g
s
0 0 .212 r
.83353 .70136 m .8335 .70121 L .83351 .70128 L F
.8335 .70121 m .83225 .69559 L .83351 .70128 L F
.746 .513 0 r
.8344 .70718 m .83386 .70457 L .83286 .69811 L p F P
0 g
s
0 0 .212 r
.83353 .70136 m .83284 .69801 L .83225 .69559 L p F P
0 g
s
.746 .513 0 r
.83286 .69811 m .83284 .69801 L p .83287 .69815 L F P
0 g
s
.746 .513 0 r
.8344 .70718 m .83286 .69811 L .83287 .69815 L F
.83284 .69801 m .83353 .70136 L .8344 .70718 L p F P
0 g
s
.823 .916 .9 r
.80852 .77351 m .81612 .76746 L .81644 .77143 L p F P
0 g
s
.867 .953 .864 r
.82103 .76289 m .81612 .76746 L .81644 .77143 L p F P
0 g
s
.169 .448 .877 r
.68943 .73275 m .68392 .73028 L .68083 .72571 L p F P
0 g
s
0 .003 .524 r
.62264 .6654 m .61958 .66188 L .61519 .65729 L p F P
0 g
s
.951 .826 .387 r
.83488 .72339 m .83553 .72736 L .83431 .7338 L p F P
0 g
s
.893 .732 .225 r
.83553 .72736 m .83488 .72339 L .83535 .71717 L p F P
0 g
s
0 .311 .802 r
.76989 .59724 m .77504 .60067 L .7772 .60449 L p F P
0 g
s
0 .306 .798 r
.77504 .60067 m .76989 .59724 L .76697 .593 L p F P
0 g
s
0 .28 .783 r
.78499 .6125 m .78298 .60865 L .7772 .60449 L p F P
0 g
s
0 .278 .78 r
.77504 .60067 m .7772 .60449 L .78298 .60865 L p F P
0 g
s
.068 .421 .867 r
.74796 .57776 m .74739 .57749 L .74446 .57361 L p F P
0 g
s
0 .172 .691 r
.6374 .68169 m .63553 .68014 L .63239 .67614 L p F P
0 g
s
.303 .545 .917 r
.72575 .7625 m .72424 .76209 L .7233 .75898 L closepath p F P
0 g
s
.292 .537 .914 r
.72424 .76209 m .7233 .75898 L .72273 .75817 L p F P
0 g
s
0 .336 .818 r
.67155 .7173 m .66965 .71357 L .66309 .70945 L p F P
0 g
s
0 .319 .807 r
.66113 .70572 m .66309 .70945 L .66965 .71357 L p F P
0 g
s
.001 .339 .82 r
.6582 .70386 m .66113 .70572 L .66309 .70945 L p F P
0 g
s
.961 .914 .558 r
.83288 .74443 m .83288 .74443 L .83289 .74442 L closepath p F P
0 g
s
.957 .948 .687 r
.83288 .74443 m .83288 .74443 L .82923 .75157 L p F P
0 g
s
.561 .746 .963 r
.764 .78037 m .77708 .77833 L .77995 .78172 L p F P
0 g
s
.548 .736 .963 r
.77708 .77833 m .764 .78037 L .76108 .77663 L p F P
0 g
s
.975 .923 .623 r
.83042 .74465 m .83222 .7405 L .83288 .74443 L closepath p F P
0 g
s
.98 .884 .524 r
.83431 .7338 m .83222 .7405 L .83288 .74443 L p F P
0 g
s
.957 .948 .687 r
.83042 .74465 m .83288 .74443 L p .82923 .75157 L F P
0 g
s
0 0 .185 r
.83225 .69559 m .83127 .69174 L .83095 .69037 L closepath p F P
0 g
s
0 0 .314 r
.82873 .68335 m .82836 .6823 L p .83127 .69174 L F P
0 g
s
0 0 .314 r
.83127 .69174 m .83095 .69037 L .82873 .68335 L p F P
0 g
s
0 .011 .54 r
.62992 .67357 m .62702 .67002 L .62264 .6654 L p F P
0 g
s
0 0 .516 r
.61958 .66188 m .62264 .6654 L .62702 .67002 L p F P
0 g
s
.034 .389 .849 r
.7575 .58523 m .75499 .58146 L .74796 .57776 L p F P
0 g
s
.023 .387 .847 r
.74532 .57402 m .74796 .57776 L .75499 .58146 L p F P
0 g
s
.068 .421 .867 r
.74446 .57361 m .74532 .57402 L .74796 .57776 L p F P
0 g
s
.162 .444 .876 r
.70052 .74409 m .70336 .74534 L .7003 .74086 L p F P
0 g
s
.162 .444 .876 r
.7003 .74086 m .69907 .7403 L .70052 .74409 L p F P
0 g
s
0 .27 .776 r
.78977 .61624 m .78499 .6125 L p .79237 .62064 L F P
0 g
s
0 .242 .757 r
.78499 .6125 m .78977 .61624 L .78685 .61169 L p F P
0 g
s
0 .242 .757 r
.78685 .61169 m .78298 .60865 L .78499 .6125 L p F P
0 g
s
.408 .605 .928 r
.72575 .7625 m .73797 .76438 L .73906 .76821 L p F P
0 g
s
.391 .598 .928 r
.73797 .76438 m .72575 .7625 L .7233 .75898 L p F P
0 g
s
0 .018 .546 r
.62992 .67357 m .63239 .67614 L .62924 .67234 L p F P
0 g
s
0 .018 .546 r
.62924 .67234 m .62702 .67002 L .62992 .67357 L p F P
0 g
s
0 0 .285 r
.82873 .68335 m .82836 .6823 L .82819 .68167 L closepath p F P
0 g
s
0 0 .406 r
.8255 .6745 m .82483 .67303 L p .82836 .6823 L F P
0 g
s
0 0 .406 r
.82836 .6823 m .82819 .68167 L .8255 .6745 L p F P
0 g
s
0 .328 .813 r
.67774 .72122 m .67155 .7173 L p .67996 .72517 L F P
0 g
s
0 .323 .81 r
.67155 .7173 m .67774 .72122 L .67464 .7168 L p F P
0 g
s
0 .323 .81 r
.67464 .7168 m .66965 .71357 L .67155 .7173 L p F P
0 g
s
.72 .849 .943 r
.80106 .77773 m .79573 .7805 L .79293 .77756 L p F P
0 g
s
.643 .812 .964 r
.77995 .78172 m .79293 .77756 L .79573 .7805 L p F P
0 g
s
.493 .668 .941 r
.74495 .77271 m .75815 .77284 L p .7605 .77663 L F P
0 g
s
.456 .665 .952 r
.75815 .77284 m .74495 .77271 L .74198 .76864 L p F P
0 g
s
.824 .626 .074 r
.83535 .71717 m .83463 .71319 L .8344 .70718 L p F P
0 g
s
.905 .739 .24 r
.83463 .71319 m .83535 .71717 L .83488 .72339 L p F P
0 g
s
.63 .801 .964 r
.79293 .77756 m .77995 .78172 L .77708 .77833 L p F P
0 g
s
0 .192 .722 r
.79269 .62093 m .79237 .62064 L .79179 .61945 L closepath p F P
0 g
s
0 .27 .776 r
.79237 .62064 m .79179 .61945 L .78977 .61624 L p F P
0 g
s
0 0 .377 r
.8255 .6745 m .82483 .67303 L .82444 .67172 L closepath p F P
0 g
s
0 0 .487 r
.82237 .66687 m .82072 .66392 L p .82483 .67303 L F P
0 g
s
0 0 .487 r
.82483 .67303 m .82444 .67172 L .82237 .66687 L p F P
0 g
s
.104 .458 .887 r
.72504 .56035 m .73188 .56316 L .73477 .56686 L p F P
0 g
s
0 .17 .706 r
.79269 .62093 m .79719 .62514 L .79901 .629 L p F P
0 g
s
0 .16 .698 r
.79719 .62514 m .79269 .62093 L .79179 .61945 L p F P
0 g
s
.048 .392 .851 r
.76405 .58888 m .7575 .58523 L p .76668 .59282 L F P
0 g
s
.008 .369 .837 r
.7575 .58523 m .76405 .58888 L .76113 .58488 L p F P
0 g
s
.008 .369 .837 r
.76113 .58488 m .75499 .58146 L .7575 .58523 L p F P
0 g
s
0 .181 .702 r
.64525 .68971 m .64271 .68609 L .6374 .68169 L p F P
0 g
s
0 .164 .683 r
.63472 .67809 m .6374 .68169 L .64271 .68609 L p F P
0 g
s
0 .172 .691 r
.63239 .67614 m .63472 .67809 L .6374 .68169 L p F P
0 g
s
0 0 .261 r
.83095 .69037 m .82873 .68335 L .83023 .6878 L closepath p F P
0 g
s
0 0 .253 r
.83023 .6878 m .82873 .68335 L .82819 .68167 L p F P
0 g
s
0 0 .253 r
.82819 .68167 m .82718 .67838 L p .83023 .6878 L F P
0 g
s
0 0 .352 r
.82819 .68167 m .8255 .6745 L .82718 .67838 L closepath p F P
0 g
s
0 .122 .671 r
.80518 .63752 m .80349 .63364 L .79901 .629 L p F P
0 g
s
0 .117 .666 r
.79719 .62514 m .79901 .629 L .80349 .63364 L p F P
0 g
s
.703 .433 0 r
.83095 .69037 m .83023 .6878 L p .83269 .69739 L F P
0 g
s
.703 .433 0 r
.83269 .69739 m .83225 .69559 L .83095 .69037 L p F P
0 g
s
0 .325 .811 r
.66113 .70572 m .6582 .70386 L .65508 .69951 L p F P
0 g
s
0 0 .557 r
.81929 .65979 m .81606 .65497 L p .82072 .66392 L F P
0 g
s
0 0 .557 r
.82072 .66392 m .81953 .6603 L .81929 .65979 L p F P
0 g
s
0 0 .459 r
.82237 .66687 m .82072 .66392 L .81953 .6603 L closepath p F P
0 g
s
.935 .949 .77 r
.82883 .74757 m .82923 .75157 L .82414 .75911 L p F P
0 g
s
.957 .948 .687 r
.82923 .75157 m .82883 .74757 L .83042 .74465 L p F P
0 g
s
0 .075 .635 r
.81087 .64617 m .80931 .64227 L .80518 .63752 L p F P
0 g
s
0 .069 .63 r
.80349 .63364 m .80518 .63752 L .80931 .64227 L p F P
0 g
s
.013 .347 .825 r
.68083 .72571 m .67996 .72517 L .67863 .72252 L closepath p F P
0 g
s
0 .328 .813 r
.67996 .72517 m .67863 .72252 L .67774 .72122 L p F P
0 g
s
0 0 .523 r
.81606 .65497 m .81929 .65979 L .81627 .65353 L p F P
0 g
s
0 0 .523 r
.81627 .65353 m .81463 .65105 L .81606 .65497 L p F P
0 g
s
0 .021 .593 r
.81606 .65497 m .81463 .65105 L .81087 .64617 L p F P
0 g
s
0 .016 .587 r
.80931 .64227 m .81087 .64617 L .81463 .65105 L p F P
0 g
s
.72 .849 .943 r
.79293 .77756 m .80067 .77377 L .80106 .77773 L p F P
0 g
s
.749 .881 .94 r
.80577 .77107 m .80067 .77377 L .80106 .77773 L p F P
0 g
s
.749 .881 .94 r
.80106 .77773 m .80852 .77351 L .80577 .77107 L p F P
0 g
s
.977 .889 .531 r
.83363 .72985 m .83431 .7338 L .83222 .7405 L p F P
0 g
s
.951 .826 .387 r
.83431 .7338 m .83363 .72985 L .83488 .72339 L p F P
0 g
s
.268 .516 .905 r
.71137 .75129 m .7197 .75383 L .71667 .74953 L p F P
0 g
s
.268 .516 .905 r
.71667 .74953 m .71021 .74743 L .71137 .75129 L p F P
0 g
s
.303 .534 .909 r
.70336 .74534 m .71021 .74743 L .71137 .75129 L p F P
0 g
s
.282 .525 .908 r
.71021 .74743 m .70336 .74534 L .7003 .74086 L p F P
0 g
s
0 .181 .704 r
.65296 .69777 m .65054 .69414 L .64525 .68971 L p F P
0 g
s
0 .163 .686 r
.64271 .68609 m .64525 .68971 L .65054 .69414 L p F P
0 g
s
.081 .442 .878 r
.73477 .56686 m .74152 .56981 L .73858 .56608 L p F P
0 g
s
.081 .442 .878 r
.73858 .56608 m .73188 .56316 L .73477 .56686 L p F P
0 g
s
0 .16 .698 r
.79179 .61945 m .79044 .61679 L p .79719 .62514 L F P
0 g
s
0 .22 .742 r
.79179 .61945 m .78977 .61624 L .79044 .61679 L closepath p F P
0 g
s
.839 .634 .089 r
.83386 .70457 m .8344 .70718 L .83463 .71319 L p F P
0 g
s
0 0 .344 r
.82718 .67838 m .8255 .6745 L .82444 .67172 L p F P
0 g
s
.693 .428 0 r
.83284 .69801 m .83225 .69559 L .83269 .69739 L closepath p F P
0 g
s
.169 .448 .877 r
.68083 .72571 m .68784 .72897 L .68943 .73275 L p F P
0 g
s
.144 .438 .874 r
.68784 .72897 m .68083 .72571 L .67863 .72252 L p F P
0 g
s
0 .33 .814 r
.76697 .593 m .76668 .59282 L .76548 .59088 L closepath p F P
0 g
s
.048 .392 .851 r
.76668 .59282 m .76548 .59088 L .76405 .58888 L p F P
0 g
s
0 0 .344 r
.82444 .67172 m .82357 .66911 L p .82718 .67838 L F P
0 g
s
0 0 .434 r
.82444 .67172 m .82237 .66687 L .82357 .66911 L closepath p F P
0 g
s
.788 .542 0 r
.83269 .69739 m .83284 .69801 L .83386 .70457 L p F P
0 g
s
.372 .597 .934 r
.73906 .76821 m .74198 .76864 L .739 .76456 L p F P
0 g
s
.372 .597 .934 r
.739 .76456 m .73797 .76438 L .73906 .76821 L p F P
0 g
s
0 .306 .798 r
.76697 .593 m .77277 .59687 L .77504 .60067 L p F P
0 g
s
0 .301 .794 r
.77277 .59687 m .76697 .593 L .76548 .59088 L p F P
0 g
s
0 .185 .708 r
.65296 .69777 m .65508 .69951 L .65196 .69532 L p F P
0 g
s
0 .185 .708 r
.65196 .69532 m .65054 .69414 L .65296 .69777 L p F P
0 g
s
.9 .941 .827 r
.82414 .75911 m .82103 .76289 L .81837 .7612 L p F P
0 g
s
.9 .941 .827 r
.81837 .7612 m .82356 .75517 L .82414 .75911 L p F P
0 g
s
.935 .949 .77 r
.82414 .75911 m .82356 .75517 L .82883 .74757 L p F P
0 g
s
.131 .43 .87 r
.69724 .73645 m .68943 .73275 L p .69907 .7403 L F P
0 g
s
.128 .424 .867 r
.68943 .73275 m .69724 .73645 L .69417 .73206 L p F P
0 g
s
.128 .424 .867 r
.69417 .73206 m .68784 .72897 L .68943 .73275 L p F P
0 g
s
.477 .678 .953 r
.76108 .77663 m .7605 .77663 L .76014 .77542 L closepath p F P
0 g
s
.493 .668 .941 r
.75815 .77284 m .76014 .77542 L .7605 .77663 L p F P
0 g
s
.812 .91 .907 r
.81612 .76746 m .80852 .77351 L .80577 .77107 L p F P
0 g
s
0 .155 .671 r
.63472 .67809 m .63239 .67614 L .62924 .67234 L p F P
0 g
s
.391 .598 .928 r
.7233 .75898 m .72318 .75824 L p .73797 .76438 L F P
0 g
s
.388 .594 .927 r
.7233 .75898 m .72273 .75817 L .72318 .75824 L closepath p F P
0 g
s
.057 .419 .866 r
.74532 .57402 m .74446 .57361 L .74152 .56981 L p F P
0 g
s
.548 .736 .963 r
.76108 .77663 m .7742 .77488 L .77708 .77833 L p F P
0 g
s
.55 .715 .949 r
.77131 .77138 m .7742 .77488 L .76108 .77663 L p F P
0 g
s
.55 .715 .949 r
.76029 .77259 m .77131 .77138 L p .76108 .77663 L F P
0 g
s
.55 .715 .949 r
.76108 .77663 m .76014 .77542 L .76029 .77259 L p F P
0 g
s
.788 .542 0 r
.83386 .70457 m .83352 .70322 L .83269 .69739 L p F P
0 g
s
.807 .554 0 r
.83159 .69347 m .83269 .69739 L .83352 .70322 L p F P
0 g
s
.703 .433 0 r
.83023 .6878 m .83159 .69347 L .83269 .69739 L p F P
0 g
s
.856 .941 .875 r
.81612 .76746 m .82103 .76289 L .81837 .7612 L p F P
0 g
s
0 .278 .78 r
.78298 .60865 m .78084 .60483 L .77504 .60067 L p F P
0 g
s
0 .275 .777 r
.77277 .59687 m .77504 .60067 L .78084 .60483 L p F P
0 g
s
.812 .91 .907 r
.80577 .77107 m .8158 .76346 L .81612 .76746 L p F P
0 g
s
.856 .941 .875 r
.81837 .7612 m .8158 .76346 L .81612 .76746 L p F P
0 g
s
.958 .83 .401 r
.83415 .71942 m .83488 .72339 L .83363 .72985 L p F P
0 g
s
.905 .739 .24 r
.83488 .72339 m .83415 .71942 L .83463 .71319 L p F P
0 g
s
0 0 .516 r
.62702 .67002 m .62396 .66651 L .61958 .66188 L p F P
0 g
s
.387 .595 .928 r
.72318 .75824 m .72273 .75817 L .7197 .75383 L p F P
0 g
s
0 0 .427 r
.82357 .66911 m .82237 .66687 L .81953 .6603 L p F P
0 g
s
.023 .387 .847 r
.75499 .58146 m .75237 .57772 L .74532 .57402 L p F P
0 g
s
.011 .385 .845 r
.74256 .5703 m .74532 .57402 L .75237 .57772 L p F P
0 g
s
.057 .419 .866 r
.74152 .56981 m .74256 .5703 L .74532 .57402 L p F P
0 g
s
0 .319 .807 r
.66965 .71357 m .66755 .70987 L .66113 .70572 L p F P
0 g
s
0 .303 .795 r
.65897 .70202 m .66113 .70572 L .66755 .70987 L p F P
0 g
s
0 .325 .811 r
.65508 .69951 m .65897 .70202 L .66113 .70572 L p F P
0 g
s
.391 .598 .928 r
.72318 .75824 m .73601 .76047 L p .73797 .76438 L F P
0 g
s
.363 .58 .925 r
.72318 .75824 m .73601 .76047 L .73301 .75637 L p F P
0 g
s
.363 .58 .925 r
.73301 .75637 m .72236 .75431 L .72318 .75824 L p F P
0 g
s
.387 .595 .928 r
.7197 .75383 m .72236 .75431 L .72318 .75824 L p F P
0 g
s
.456 .665 .952 r
.74198 .76864 m .7552 .76901 L .75815 .77284 L p F P
0 g
s
.444 .657 .951 r
.7552 .76901 m .74198 .76864 L .739 .76456 L p F P
0 g
s
.98 .915 .638 r
.83222 .7405 m .83148 .73657 L p .82848 .74447 L F P
0 g
s
.98 .915 .638 r
.82848 .74447 m .83042 .74465 L .83222 .7405 L p F P
0 g
s
.977 .889 .531 r
.83222 .7405 m .83148 .73657 L .83363 .72985 L p F P
0 g
s
0 0 .253 r
.82718 .67838 m .82903 .68389 L .83023 .6878 L p F P
0 g
s
.737 .455 0 r
.82903 .68389 m .83023 .6878 L .83159 .69347 L p F P
0 g
s
0 .236 .751 r
.78298 .60865 m .78685 .61169 L .78393 .60726 L p F P
0 g
s
0 .236 .751 r
.78393 .60726 m .78084 .60483 L .78298 .60865 L p F P
0 g
s
0 .215 .737 r
.79044 .61679 m .78977 .61624 L .78685 .61169 L p F P
0 g
s
.148 .444 .877 r
.7003 .74086 m .69907 .7403 L .69766 .73706 L closepath p F P
0 g
s
.131 .43 .87 r
.69907 .7403 m .69766 .73706 L .69724 .73645 L p F P
0 g
s
0 .003 .524 r
.62702 .67002 m .62924 .67234 L .6261 .66874 L p F P
0 g
s
0 .003 .524 r
.6261 .66874 m .62396 .66651 L .62702 .67002 L p F P
0 g
s
.547 .712 .948 r
.76014 .77542 m .75815 .77284 L .76029 .77259 L closepath p F P
0 g
s
0 .301 .794 r
.76548 .59088 m .7643 .58903 L p .77277 .59687 L F P
0 g
s
0 .346 .824 r
.76548 .59088 m .76405 .58888 L .7643 .58903 L closepath p F P
0 g
s
.63 .801 .964 r
.77708 .77833 m .7901 .77452 L .79293 .77756 L p F P
0 g
s
.618 .79 .964 r
.7901 .77452 m .77708 .77833 L .7742 .77488 L p F P
0 g
s
.144 .438 .874 r
.67863 .72252 m .67817 .72142 L p .68784 .72897 L F P
0 g
s
.136 .43 .87 r
.67863 .72252 m .67774 .72122 L .67817 .72142 L closepath p F P
0 g
s
.708 .843 .947 r
.80067 .77377 m .79293 .77756 L .7901 .77452 L p F P
0 g
s
0 .312 .801 r
.65897 .70202 m .65508 .69951 L .65196 .69532 L p F P
0 g
s
0 .309 .801 r
.66965 .71357 m .67464 .7168 L .67153 .7125 L p F P
0 g
s
0 .309 .801 r
.67153 .7125 m .66755 .70987 L .66965 .71357 L p F P
0 g
s
0 0 .23 r
.82588 .67447 m .82718 .67838 L .82903 .68389 L p F P
0 g
s
0 0 .344 r
.82357 .66911 m .82588 .67447 L .82718 .67838 L p F P
0 g
s
0 .16 .698 r
.79044 .61679 m .79526 .6213 L .79719 .62514 L p F P
0 g
s
0 .154 .692 r
.78838 .61296 m .79044 .61679 L .79526 .6213 L p F P
0 g
s
0 .215 .737 r
.78685 .61169 m .78838 .61296 L .79044 .61679 L p F P
0 g
s
.869 .648 .117 r
.83352 .70322 m .83386 .70457 L .83399 .71003 L p F P
0 g
s
.839 .634 .089 r
.83463 .71319 m .83399 .71003 L .83386 .70457 L p F P
0 g
s
0 .366 .834 r
.75499 .58146 m .76113 .58488 L .7582 .58097 L p F P
0 g
s
0 .366 .834 r
.7582 .58097 m .75237 .57772 L .75499 .58146 L p F P
0 g
s
0 .164 .683 r
.64271 .68609 m .64 .6825 L .63472 .67809 L p F P
0 g
s
0 .148 .665 r
.63186 .67453 m .63472 .67809 L .64 .6825 L p F P
0 g
s
0 .155 .671 r
.62924 .67234 m .63186 .67453 L .63472 .67809 L p F P
0 g
s
.918 .748 .259 r
.83399 .71003 m .83463 .71319 L .83415 .71942 L p F P
0 g
s
.282 .525 .908 r
.7003 .74086 m .70883 .74362 L .71021 .74743 L p F P
0 g
s
.262 .517 .907 r
.70883 .74362 m .7003 .74086 L .69766 .73706 L p F P
0 g
s
.959 .947 .69 r
.82883 .74757 m .82848 .74447 L .83042 .74465 L closepath p F P
0 g
s
0 0 .322 r
.82216 .66521 m .82357 .66911 L .82588 .67447 L p F P
0 g
s
0 0 .427 r
.81941 .65999 m .82216 .66521 L .82357 .66911 L p F P
0 g
s
0 0 .427 r
.81953 .6603 m .81941 .65999 L p .82357 .66911 L F P
0 g
s
0 0 .507 r
.81953 .6603 m .81929 .65979 L .81941 .65999 L closepath p F P
0 g
s
0 .117 .666 r
.80349 .63364 m .80169 .62977 L .79719 .62514 L p F P
0 g
s
0 .112 .66 r
.79526 .6213 m .79719 .62514 L .80169 .62977 L p F P
0 g
s
.124 .429 .87 r
.67817 .72142 m .67774 .72122 L .67464 .7168 L p F P
0 g
s
0 0 .498 r
.81941 .65999 m .81929 .65979 L .81627 .65353 L p F P
0 g
s
0 .069 .63 r
.80931 .64227 m .80764 .63839 L .80349 .63364 L p F P
0 g
s
0 .064 .624 r
.80169 .62977 m .80349 .63364 L .80764 .63839 L p F P
0 g
s
0 0 .402 r
.81789 .65611 m .81941 .65999 L .82216 .66521 L p F P
0 g
s
0 0 .498 r
.81627 .65353 m .81789 .65611 L .81941 .65999 L p F P
0 g
s
.144 .438 .874 r
.67817 .72142 m .68605 .72522 L .68784 .72897 L p F P
0 g
s
.087 .413 .863 r
.67638 .71766 m .67817 .72142 L .68605 .72522 L p F P
0 g
s
.124 .429 .87 r
.67464 .7168 m .67638 .71766 L .67817 .72142 L p F P
0 g
s
0 .016 .587 r
.81463 .65105 m .81309 .64715 L .80931 .64227 L p F P
0 g
s
0 .023 .592 r
.80764 .63839 m .80931 .64227 L .81309 .64715 L p F P
0 g
s
0 0 .507 r
.81463 .65105 m .81627 .65353 L .81325 .64739 L p F P
0 g
s
0 0 .507 r
.81325 .64739 m .81309 .64715 L .81463 .65105 L p F P
0 g
s
0 .163 .686 r
.65054 .69414 m .64795 .69053 L .64271 .68609 L p F P
0 g
s
0 .147 .668 r
.64 .6825 m .64271 .68609 L .64795 .69053 L p F P
0 g
s
.93 .946 .78 r
.82848 .74447 m .82883 .74757 L .82356 .75517 L p F P
0 g
s
0 .343 .821 r
.7643 .58903 m .76405 .58888 L .76113 .58488 L p F P
0 g
s
.244 .507 .904 r
.71021 .74743 m .71667 .74953 L .71363 .74527 L p F P
0 g
s
.244 .507 .904 r
.71363 .74527 m .70883 .74362 L .71021 .74743 L p F P
0 g
s
.981 .891 .543 r
.83287 .7259 m .83363 .72985 L .83148 .73657 L p F P
0 g
s
.958 .83 .401 r
.83363 .72985 m .83287 .7259 L .83415 .71942 L p F P
0 g
s
.708 .843 .947 r
.7901 .77452 m .80046 .76975 L .80067 .77377 L p F P
0 g
s
.735 .868 .943 r
.803 .76849 m .80046 .76975 L .80067 .77377 L p F P
0 g
s
.735 .868 .943 r
.80067 .77377 m .80577 .77107 L .803 .76849 L p F P
0 g
s
0 .301 .794 r
.7643 .58903 m .77038 .59309 L .77277 .59687 L p F P
0 g
s
0 .297 .79 r
.76178 .58527 m .7643 .58903 L .77038 .59309 L p F P
0 g
s
0 .343 .821 r
.76113 .58488 m .76178 .58527 L .7643 .58903 L p F P
0 g
s
.869 .648 .117 r
.83399 .71003 m .83378 .70924 L .83352 .70322 L p F P
0 g
s
.885 .658 .137 r
.83242 .69931 m .83352 .70322 L .83378 .70924 L p F P
0 g
s
.807 .554 0 r
.83352 .70322 m .83242 .69931 L .83159 .69347 L p F P
0 g
s
0 .139 .651 r
.63186 .67453 m .62924 .67234 L .6261 .66874 L p F P
0 g
s
.548 .711 .948 r
.76029 .77259 m .75815 .77284 L .7552 .76901 L p F P
0 g
s
.046 .417 .864 r
.74256 .5703 m .74152 .56981 L .73858 .56608 L p F P
0 g
s
0 .17 .691 r
.65054 .69414 m .65196 .69532 L .64883 .69127 L p F P
0 g
s
0 .17 .691 r
.64883 .69127 m .64795 .69053 L .65054 .69414 L p F P
0 g
s
.367 .599 .937 r
.739 .76456 m .73797 .76438 L .73721 .76211 L closepath p F P
0 g
s
.391 .598 .928 r
.73601 .76047 m .73721 .76211 L .73797 .76438 L p F P
0 g
s
.369 .588 .928 r
.72236 .75431 m .7197 .75383 L .71667 .74953 L p F P
0 g
s
.1 .413 .862 r
.68784 .72897 m .69417 .73206 L .69109 .72776 L p F P
0 g
s
.1 .413 .862 r
.69109 .72776 m .68605 .72522 L .68784 .72897 L p F P
0 g
s
.802 .904 .913 r
.8158 .76346 m .80577 .77107 L .803 .76849 L p F P
0 g
s
0 .275 .777 r
.78084 .60483 m .77859 .60103 L .77277 .59687 L p F P
0 g
s
0 .271 .774 r
.77038 .59309 m .77277 .59687 L .77859 .60103 L p F P
0 g
s
.892 .937 .838 r
.82356 .75517 m .81837 .7612 L .81569 .75929 L p F P
0 g
s
.892 .937 .838 r
.81569 .75929 m .82294 .75123 L .82356 .75517 L p F P
0 g
s
.93 .946 .78 r
.8279 .7443 m .82848 .74447 L p .82356 .75517 L F P
0 g
s
.93 .946 .78 r
.82356 .75517 m .82294 .75123 L .8279 .7443 L p F P
0 g
s
.444 .657 .951 r
.739 .76456 m .75225 .76516 L .7552 .76901 L p F P
0 g
s
.456 .649 .942 r
.74929 .7613 m .75225 .76516 L .739 .76456 L p F P
0 g
s
.456 .649 .942 r
.73697 .76052 m .74929 .7613 L p .739 .76456 L F P
0 g
s
.456 .649 .942 r
.739 .76456 m .73721 .76211 L .73697 .76052 L p F P
0 g
s
.823 .563 .01 r
.8304 .68956 m .83159 .69347 L .83242 .69931 L p F P
0 g
s
.737 .455 0 r
.83159 .69347 m .8304 .68956 L .82903 .68389 L p F P
0 g
s
.011 .385 .845 r
.75237 .57772 m .74962 .574 L .74256 .5703 L p F P
0 g
s
0 .382 .843 r
.73968 .5666 m .74256 .5703 L .74962 .574 L p F P
0 g
s
.046 .417 .864 r
.73858 .56608 m .73968 .5666 L .74256 .5703 L p F P
0 g
s
0 .207 .73 r
.78838 .61296 m .78685 .61169 L .78393 .60726 L p F P
0 g
s
.53 .705 .951 r
.76029 .77259 m .77131 .77138 L .7684 .76783 L p F P
0 g
s
.53 .705 .951 r
.7684 .76783 m .75997 .76856 L .76029 .77259 L p F P
0 g
s
.548 .711 .948 r
.7552 .76901 m .75997 .76856 L .76029 .77259 L p F P
0 g
s
0 .303 .795 r
.66755 .70987 m .66529 .70621 L .65897 .70202 L p F P
0 g
s
0 .287 .783 r
.65661 .69836 m .65897 .70202 L .66529 .70621 L p F P
0 g
s
0 .312 .801 r
.65196 .69532 m .65661 .69836 L .65897 .70202 L p F P
0 g
s
0 0 .481 r
.81789 .65611 m .81627 .65353 L .81325 .64739 L p F P
0 g
s
.802 .904 .913 r
.803 .76849 m .81551 .75944 L .8158 .76346 L p F P
0 g
s
.844 .929 .885 r
.81569 .75929 m .81551 .75944 L .8158 .76346 L p F P
0 g
s
.844 .929 .885 r
.8158 .76346 m .81837 .7612 L .81569 .75929 L p F P
0 g
s
.262 .517 .907 r
.69766 .73706 m .69748 .73653 L p .70883 .74362 L F P
0 g
s
.257 .512 .905 r
.69766 .73706 m .69724 .73645 L .69748 .73653 L closepath p F P
0 g
s
.965 .834 .415 r
.83334 .71546 m .83415 .71942 L .83287 .7259 L p F P
0 g
s
.918 .748 .259 r
.83364 .71183 m .83399 .71003 L p .83415 .71942 L F P
0 g
s
.918 .748 .259 r
.83415 .71942 m .83334 .71546 L .83364 .71183 L p F P
0 g
s
0 .299 .79 r
.65661 .69836 m .65196 .69532 L .64883 .69127 L p F P
0 g
s
0 .229 .745 r
.78084 .60483 m .78393 .60726 L .78101 .60293 L p F P
0 g
s
0 .229 .745 r
.78101 .60293 m .77859 .60103 L .78084 .60483 L p F P
0 g
s
.606 .78 .964 r
.78726 .77139 m .7742 .77488 L .77131 .77138 L p F P
0 g
s
.618 .79 .964 r
.7742 .77488 m .78726 .77139 L .7901 .77452 L p F P
0 g
s
.343 .573 .926 r
.72236 .75431 m .73301 .75637 L .73 .75228 L p F P
0 g
s
.343 .573 .926 r
.73 .75228 m .72126 .75043 L .72236 .75431 L p F P
0 g
s
.369 .588 .928 r
.71667 .74953 m .72126 .75043 L .72236 .75431 L p F P
0 g
s
.755 .465 0 r
.82774 .67999 m .82903 .68389 L .8304 .68956 L p F P
0 g
s
0 0 .23 r
.82903 .68389 m .82774 .67999 L .82588 .67447 L p F P
0 g
s
.25 .512 .906 r
.69748 .73653 m .69724 .73645 L .69417 .73206 L p F P
0 g
s
.98 .915 .638 r
.83148 .73657 m .8283 .74359 L .82848 .74447 L p F P
0 g
s
.976 .922 .657 r
.83067 .73264 m .83148 .73657 L .8283 .74359 L p F P
0 g
s
.981 .891 .543 r
.83148 .73657 m .83067 .73264 L .83287 .7259 L p F P
0 g
s
.695 .845 .955 r
.80046 .76975 m .7901 .77452 L .78726 .77139 L p F P
0 g
s
.262 .517 .907 r
.69748 .73653 m .70725 .73985 L .70883 .74362 L p F P
0 g
s
.209 .498 .904 r
.69602 .73271 m .69748 .73653 L .70725 .73985 L p F P
0 g
s
.25 .512 .906 r
.69417 .73206 m .69602 .73271 L .69748 .73653 L p F P
0 g
s
.928 .739 .255 r
.83364 .71183 m .83378 .70924 L .83399 .71003 L closepath p F P
0 g
s
.098 .419 .866 r
.67638 .71766 m .67464 .7168 L .67153 .7125 L p F P
0 g
s
0 .296 .79 r
.66755 .70987 m .67153 .7125 L .66843 .70831 L p F P
0 g
s
0 .296 .79 r
.66843 .70831 m .66529 .70621 L .66755 .70987 L p F P
0 g
s
0 .154 .692 r
.79526 .6213 m .79321 .61747 L .78838 .61296 L p F P
0 g
s
0 .149 .686 r
.78621 .60915 m .78838 .61296 L .79321 .61747 L p F P
0 g
s
0 .207 .73 r
.78393 .60726 m .78621 .60915 L .78838 .61296 L p F P
0 g
s
0 .362 .831 r
.75237 .57772 m .7582 .58097 L .75527 .57715 L p F P
0 g
s
0 .362 .831 r
.75527 .57715 m .74962 .574 L .75237 .57772 L p F P
0 g
s
0 .148 .665 r
.64 .6825 m .63711 .67895 L .63186 .67453 L p F P
0 g
s
0 .135 .647 r
.6288 .67101 m .63186 .67453 L .63711 .67895 L p F P
0 g
s
0 .139 .651 r
.6261 .66874 m .6288 .67101 L .63186 .67453 L p F P
0 g
s
0 0 .322 r
.82588 .67447 m .82448 .67058 L .82216 .66521 L p F P
0 g
s
.684 .37 0 r
.82448 .67058 m .82588 .67447 L .82774 .67999 L p F P
0 g
s
0 .112 .66 r
.80169 .62977 m .79977 .62592 L .79526 .6213 L p F P
0 g
s
0 .106 .654 r
.79321 .61747 m .79526 .6213 L .79977 .62592 L p F P
0 g
s
.45 .644 .941 r
.73721 .76211 m .73601 .76047 L .73697 .76052 L closepath p F P
0 g
s
.96 .936 .714 r
.8279 .7443 m .8283 .74359 L .82848 .74447 L closepath p F P
0 g
s
0 0 .309 r
.82065 .66133 m .82216 .66521 L .82448 .67058 L p F P
0 g
s
0 0 .402 r
.82216 .66521 m .82065 .66133 L .81789 .65611 L p F P
0 g
s
.949 .748 .285 r
.83378 .70924 m .83268 .70533 L p .83305 .71421 L F P
0 g
s
.949 .748 .285 r
.83305 .71421 m .83364 .71183 L .83378 .70924 L p F P
0 g
s
.885 .658 .137 r
.83378 .70924 m .83268 .70533 L .83242 .69931 L p F P
0 g
s
0 .339 .817 r
.76178 .58527 m .76113 .58488 L .7582 .58097 L p F P
0 g
s
0 .064 .624 r
.80764 .63839 m .80586 .63452 L .80169 .62977 L p F P
0 g
s
0 .058 .617 r
.79977 .62592 m .80169 .62977 L .80586 .63452 L p F P
0 g
s
0 0 .39 r
.81626 .65224 m .81789 .65611 L .82065 .66133 L p F P
0 g
s
0 0 .481 r
.81325 .64739 m .81626 .65224 L .81789 .65611 L p F P
0 g
s
0 .147 .668 r
.64795 .69053 m .6452 .68696 L .64 .6825 L p F P
0 g
s
0 .132 .65 r
.63711 .67895 m .64 .6825 L .6452 .68696 L p F P
0 g
s
.087 .413 .863 r
.68605 .72522 m .68408 .7215 L .67638 .71766 L p F P
0 g
s
.058 .4 .856 r
.67439 .71393 m .67638 .71766 L .68408 .7215 L p F P
0 g
s
.098 .419 .866 r
.67153 .7125 m .67439 .71393 L .67638 .71766 L p F P
0 g
s
0 .023 .592 r
.81027 .6418 m .80764 .63839 L p .81309 .64715 L F P
0 g
s
0 0 .558 r
.80764 .63839 m .81027 .6418 L .8073 .6364 L p F P
0 g
s
0 0 .558 r
.8073 .6364 m .80586 .63452 L .80764 .63839 L p F P
0 g
s
0 0 .494 r
.81325 .64739 m .81309 .64715 L .81291 .64671 L closepath p F P
0 g
s
0 .023 .592 r
.81309 .64715 m .81291 .64671 L .81027 .6418 L p F P
0 g
s
.352 .581 .928 r
.72126 .75043 m .71667 .74953 L .71363 .74527 L p F P
0 g
s
0 0 .461 r
.81626 .65224 m .81325 .64739 L .81291 .64671 L p F P
0 g
s
.535 .704 .949 r
.75997 .76856 m .7552 .76901 L .75225 .76516 L p F P
0 g
s
0 .297 .79 r
.77038 .59309 m .76788 .58932 L .76178 .58527 L p F P
0 g
s
0 .293 .786 r
.75914 .58153 m .76178 .58527 L .76788 .58932 L p F P
0 g
s
0 .339 .817 r
.7582 .58097 m .75914 .58153 L .76178 .58527 L p F P
0 g
s
.221 .499 .902 r
.70883 .74362 m .71363 .74527 L .71059 .74105 L p F P
0 g
s
.221 .499 .902 r
.71059 .74105 m .70725 .73985 L .70883 .74362 L p F P
0 g
s
0 0 .461 r
.81291 .64671 m .81136 .64329 L p .81626 .65224 L F P
0 g
s
0 0 .541 r
.81291 .64671 m .81027 .6418 L .81136 .64329 L closepath p F P
0 g
s
.956 .933 .729 r
.8283 .74359 m .8279 .7443 L .8253 .74325 L p F P
0 g
s
.956 .933 .729 r
.8253 .74325 m .8274 .7397 L .8283 .74359 L p F P
0 g
s
.976 .922 .657 r
.8283 .74359 m .8274 .7397 L .83067 .73264 L p F P
0 g
s
.984 .892 .555 r
.83203 .72195 m .83287 .7259 L .83067 .73264 L p F P
0 g
s
.965 .834 .415 r
.83287 .7259 m .83203 .72195 L .83334 .71546 L p F P
0 g
s
.93 .952 .778 r
.82294 .75123 m .8279 .7443 L .8253 .74325 L p F P
0 g
s
0 .156 .675 r
.64795 .69053 m .64883 .69127 L .6457 .68738 L p F P
0 g
s
0 .156 .675 r
.6457 .68738 m .6452 .68696 L .64795 .69053 L p F P
0 g
s
.93 .754 .274 r
.83334 .71546 m .83305 .71421 L .83364 .71183 L closepath p F P
0 g
s
.897 .665 .153 r
.83123 .69541 m .83242 .69931 L .83268 .70533 L p F P
0 g
s
.823 .563 .01 r
.83242 .69931 m .83123 .69541 L .8304 .68956 L p F P
0 g
s
.695 .845 .955 r
.80051 .76606 m .80046 .76975 L p .78726 .77139 L F P
0 g
s
.722 .857 .946 r
.80046 .76975 m .80051 .76606 L .803 .76849 L closepath p F P
0 g
s
.449 .645 .942 r
.73697 .76052 m .73601 .76047 L .73301 .75637 L p F P
0 g
s
0 .2 .723 r
.78621 .60915 m .78393 .60726 L .78101 .60293 L p F P
0 g
s
0 .271 .774 r
.77859 .60103 m .77622 .59724 L .77038 .59309 L p F P
0 g
s
0 .267 .77 r
.76788 .58932 m .77038 .59309 L .77622 .59724 L p F P
0 g
s
.428 .633 .941 r
.73697 .76052 m .74929 .7613 L .74631 .75743 L p F P
0 g
s
.428 .633 .941 r
.74631 .75743 m .73612 .75659 L .73697 .76052 L p F P
0 g
s
.449 .645 .942 r
.73301 .75637 m .73612 .75659 L .73697 .76052 L p F P
0 g
s
0 .382 .843 r
.74962 .574 m .74674 .5703 L .73968 .5666 L p F P
0 g
s
.799 .874 .902 r
.80051 .76606 m .803 .76849 L .81551 .75944 L p F P
0 g
s
.073 .402 .857 r
.68605 .72522 m .69109 .72776 L .688 .72354 L p F P
0 g
s
.073 .402 .857 r
.688 .72354 m .68408 .7215 L .68605 .72522 L p F P
0 g
s
0 .299 .79 r
.64883 .69127 m .65408 .69474 L .65661 .69836 L p F P
0 g
s
0 .286 .778 r
.65408 .69474 m .64883 .69127 L .6457 .68738 L p F P
0 g
s
.229 .505 .905 r
.69602 .73271 m .69417 .73206 L .69109 .72776 L p F P
0 g
s
.838 .571 .026 r
.82911 .68567 m .8304 .68956 L .83123 .69541 L p F P
0 g
s
.755 .465 0 r
.8304 .68956 m .82911 .68567 L .82774 .67999 L p F P
0 g
s
0 .287 .783 r
.66529 .70621 m .66285 .70257 L .65661 .69836 L p F P
0 g
s
0 .273 .77 r
.65408 .69474 m .65661 .69836 L .66285 .70257 L p F P
0 g
s
.889 .914 .836 r
.82294 .75123 m .82227 .74728 L p .81548 .75914 L F P
0 g
s
.889 .914 .836 r
.81548 .75914 m .81569 .75929 L .82294 .75123 L p F P
0 g
s
.93 .952 .778 r
.8253 .74325 m .82227 .74728 L .82294 .75123 L p F P
0 g
s
.606 .78 .964 r
.77131 .77138 m .78441 .76819 L .78726 .77139 L p F P
0 g
s
.594 .772 .964 r
.78441 .76819 m .77131 .77138 L .7684 .76783 L p F P
0 g
s
.072 .409 .861 r
.67439 .71393 m .67153 .7125 L .66843 .70831 L p F P
0 g
s
.515 .7 .954 r
.75997 .76856 m .7684 .76783 L .76548 .76424 L p F P
0 g
s
.515 .7 .954 r
.76548 .76424 m .75915 .76466 L .75997 .76856 L p F P
0 g
s
.535 .704 .949 r
.75225 .76516 m .75915 .76466 L .75997 .76856 L p F P
0 g
s
0 .222 .739 r
.77859 .60103 m .78101 .60293 L .77809 .59871 L p F P
0 g
s
0 .222 .739 r
.77809 .59871 m .77622 .59724 L .77859 .60103 L p F P
0 g
s
.974 .843 .44 r
.83305 .71421 m .83334 .71546 L .83203 .72195 L p F P
0 g
s
.695 .845 .955 r
.78726 .77139 m .80022 .76577 L .80051 .76606 L p F P
0 g
s
.683 .835 .956 r
.80022 .76577 m .78726 .77139 L .78441 .76819 L p F P
0 g
s
.832 .919 .893 r
.81551 .75944 m .81548 .75914 L .81569 .75929 L closepath p F P
0 g
s
.799 .874 .902 r
.81551 .75944 m .81548 .75914 L p .80051 .76606 L F P
0 g
s
.772 .474 0 r
.82635 .6761 m .82774 .67999 L .82911 .68567 L p F P
0 g
s
.684 .37 0 r
.82774 .67999 m .82635 .6761 L .82448 .67058 L p F P
0 g
s
.323 .567 .927 r
.72126 .75043 m .73 .75228 L .72698 .74822 L p F P
0 g
s
.323 .567 .927 r
.72698 .74822 m .71993 .74661 L .72126 .75043 L p F P
0 g
s
.352 .581 .928 r
.71363 .74527 m .71993 .74661 L .72126 .75043 L p F P
0 g
s
0 .135 .647 r
.63711 .67895 m .63405 .67543 L .6288 .67101 L p F P
0 g
s
0 .359 .828 r
.74962 .574 m .75527 .57715 L .75234 .57341 L p F P
0 g
s
0 .359 .828 r
.75234 .57341 m .74674 .5703 L .74962 .574 L p F P
0 g
s
.209 .498 .904 r
.70725 .73985 m .70548 .73611 L .69602 .73271 L p F P
0 g
s
.184 .487 .9 r
.69433 .72893 m .69602 .73271 L .70548 .73611 L p F P
0 g
s
.229 .505 .905 r
.69109 .72776 m .69433 .72893 L .69602 .73271 L p F P
0 g
s
.855 .91 .871 r
.81296 .75709 m .8146 .75557 L .81548 .75914 L closepath p F P
0 g
s
.799 .874 .902 r
.81548 .75914 m .81296 .75709 L p .80051 .76606 L F P
0 g
s
.889 .914 .836 r
.82227 .74728 m .8146 .75557 L .81548 .75914 L p F P
0 g
s
0 .283 .78 r
.66529 .70621 m .66843 .70831 L .66531 .70425 L p F P
0 g
s
0 .283 .78 r
.66531 .70425 m .66285 .70257 L .66529 .70621 L p F P
0 g
s
0 0 .531 r
.81136 .64329 m .81027 .6418 L .8073 .6364 L p F P
0 g
s
.975 .92 .666 r
.82978 .72872 m .83067 .73264 L .8274 .7397 L p F P
0 g
s
.984 .892 .555 r
.83067 .73264 m .82978 .72872 L .83203 .72195 L p F P
0 g
s
0 .149 .686 r
.79321 .61747 m .79106 .61366 L .78621 .60915 L p F P
0 g
s
0 .143 .679 r
.78392 .60536 m .78621 .60915 L .79106 .61366 L p F P
0 g
s
0 .2 .723 r
.78101 .60293 m .78392 .60536 L .78621 .60915 L p F P
0 g
s
0 0 .309 r
.82448 .67058 m .82298 .6667 L .82065 .66133 L p F P
0 g
s
.702 .379 0 r
.82298 .6667 m .82448 .67058 L .82635 .6761 L p F P
0 g
s
0 .335 .814 r
.75914 .58153 m .7582 .58097 L .75527 .57715 L p F P
0 g
s
0 .106 .654 r
.79977 .62592 m .79774 .62209 L .79321 .61747 L p F P
0 g
s
0 .1 .647 r
.79106 .61366 m .79321 .61747 L .79774 .62209 L p F P
0 g
s
.335 .574 .929 r
.71993 .74661 m .71363 .74527 L .71059 .74105 L p F P
0 g
s
0 0 .295 r
.81903 .65746 m .82065 .66133 L .82298 .6667 L p F P
0 g
s
0 0 .39 r
.82065 .66133 m .81903 .65746 L .81626 .65224 L p F P
0 g
s
0 .132 .65 r
.6452 .68696 m .64229 .68341 L .63711 .67895 L p F P
0 g
s
0 .12 .633 r
.63405 .67543 m .63711 .67895 L .64229 .68341 L p F P
0 g
s
.522 .698 .95 r
.75915 .76466 m .75225 .76516 L .74929 .7613 L p F P
0 g
s
.977 .819 .409 r
.83152 .71614 m .83229 .71155 L .83305 .71421 L closepath p F P
0 g
s
.949 .748 .285 r
.83268 .70533 m .83229 .71155 L .83305 .71421 L p F P
0 g
s
.974 .843 .44 r
.83152 .71614 m .83305 .71421 L p .83203 .72195 L F P
0 g
s
0 .058 .617 r
.80586 .63452 m .80396 .63067 L .79977 .62592 L p F P
0 g
s
0 .072 .626 r
.79774 .62209 m .79977 .62592 L .80396 .63067 L p F P
0 g
s
.952 .754 .296 r
.83148 .70144 m .83268 .70533 L .83229 .71155 L p F P
0 g
s
.897 .665 .153 r
.83268 .70533 m .83148 .70144 L .83123 .69541 L p F P
0 g
s
0 0 .377 r
.81453 .64838 m .81626 .65224 L .81903 .65746 L p F P
0 g
s
0 0 .461 r
.81136 .64329 m .81453 .64838 L .81626 .65224 L p F P
0 g
s
0 0 .544 r
.80586 .63452 m .8073 .6364 L .80433 .63115 L p F P
0 g
s
0 0 .544 r
.80433 .63115 m .80396 .63067 L .80586 .63452 L p F P
0 g
s
.058 .4 .856 r
.68408 .7215 m .68193 .71782 L .67439 .71393 L p F P
0 g
s
.031 .388 .848 r
.6722 .71025 m .67439 .71393 L .68193 .71782 L p F P
0 g
s
.072 .409 .861 r
.66843 .70831 m .6722 .71025 L .67439 .71393 L p F P
0 g
s
0 .293 .786 r
.76788 .58932 m .76525 .58558 L .75914 .58153 L p F P
0 g
s
0 .289 .781 r
.75639 .57781 m .75914 .58153 L .76525 .58558 L p F P
0 g
s
0 .335 .814 r
.75527 .57715 m .75639 .57781 L .75914 .58153 L p F P
0 g
s
0 0 .447 r
.80951 .63945 m .81136 .64329 L .81453 .64838 L p F P
0 g
s
0 0 .531 r
.8073 .6364 m .80951 .63945 L .81136 .64329 L p F P
0 g
s
.434 .639 .943 r
.73612 .75659 m .73301 .75637 L .73 .75228 L p F P
0 g
s
0 .192 .715 r
.78392 .60536 m .78101 .60293 L .77809 .59871 L p F P
0 g
s
0 .143 .659 r
.6452 .68696 m .6457 .68738 L .64256 .68364 L p F P
0 g
s
0 .143 .659 r
.64256 .68364 m .64229 .68341 L .6452 .68696 L p F P
0 g
s
.198 .49 .9 r
.70725 .73985 m .71059 .74105 L .70753 .73688 L p F P
0 g
s
.198 .49 .9 r
.70753 .73688 m .70548 .73611 L .70725 .73985 L p F P
0 g
s
.951 .931 .743 r
.8274 .7397 m .8253 .74325 L .82267 .74192 L p F P
0 g
s
.951 .931 .743 r
.82267 .74192 m .82643 .73581 L .8274 .7397 L p F P
0 g
s
.975 .92 .666 r
.8274 .7397 m .82643 .73581 L .82978 .72872 L p F P
0 g
s
.208 .497 .903 r
.69433 .72893 m .69109 .72776 L .688 .72354 L p F P
0 g
s
.986 .893 .565 r
.83111 .71801 m .83203 .72195 L .82978 .72872 L p F P
0 g
s
.974 .843 .44 r
.83203 .72195 m .83111 .71801 L .83152 .71614 L p F P
0 g
s
.765 .864 .922 r
.80022 .76577 m .80039 .76566 L .80051 .76606 L closepath p F P
0 g
s
.799 .874 .902 r
.81296 .75709 m .80039 .76566 L .80051 .76606 L p F P
0 g
s
.909 .671 .169 r
.82995 .69152 m .83123 .69541 L .83148 .70144 L p F P
0 g
s
.838 .571 .026 r
.83123 .69541 m .82995 .69152 L .82911 .68567 L p F P
0 g
s
0 .286 .778 r
.6457 .68738 m .65137 .69116 L .65408 .69474 L p F P
0 g
s
0 .274 .766 r
.65137 .69116 m .6457 .68738 L .64256 .68364 L p F P
0 g
s
0 .267 .77 r
.77622 .59724 m .77373 .59347 L .76788 .58932 L p F P
0 g
s
0 .263 .765 r
.76525 .58558 m .76788 .58932 L .77373 .59347 L p F P
0 g
s
.046 .399 .855 r
.6722 .71025 m .66843 .70831 L .66531 .70425 L p F P
0 g
s
.755 .856 .925 r
.80039 .76566 m .80022 .76577 L .79741 .76291 L p F P
0 g
s
.683 .835 .956 r
.78441 .76819 m .79741 .76291 L .80022 .76577 L p F P
0 g
s
.755 .856 .925 r
.79741 .76291 m .79917 .76188 L .80039 .76566 L p F P
0 g
s
.789 .897 .92 r
.81022 .75472 m .79917 .76188 L .80039 .76566 L p F P
0 g
s
.789 .897 .92 r
.80039 .76566 m .81296 .75709 L .81022 .75472 L p F P
0 g
s
.048 .392 .851 r
.68408 .7215 m .688 .72354 L .68492 .7194 L p F P
0 g
s
.048 .392 .851 r
.68492 .7194 m .68193 .71782 L .68408 .7215 L p F P
0 g
s
.594 .772 .964 r
.7684 .76783 m .78154 .76492 L .78441 .76819 L p F P
0 g
s
.583 .764 .964 r
.78154 .76492 m .7684 .76783 L .76548 .76424 L p F P
0 g
s
.923 .944 .794 r
.82227 .74728 m .8253 .74325 L .82267 .74192 L p F P
0 g
s
0 0 .516 r
.80951 .63945 m .8073 .6364 L .80433 .63115 L p F P
0 g
s
.434 .639 .943 r
.73 .75228 m .73499 .75272 L .73612 .75659 L p F P
0 g
s
.412 .629 .943 r
.73612 .75659 m .74631 .75743 L .74333 .75356 L p F P
0 g
s
.412 .629 .943 r
.74333 .75356 m .73499 .75272 L .73612 .75659 L p F P
0 g
s
0 .273 .77 r
.66285 .70257 m .66026 .69897 L .65408 .69474 L p F P
0 g
s
0 .261 .758 r
.65137 .69116 m .65408 .69474 L .66026 .69897 L p F P
0 g
s
.853 .579 .042 r
.82773 .68178 m .82911 .68567 L .82995 .69152 L p F P
0 g
s
.772 .474 0 r
.82911 .68567 m .82773 .68178 L .82635 .6761 L p F P
0 g
s
0 .215 .731 r
.77622 .59724 m .77809 .59871 L .77516 .59461 L p F P
0 g
s
0 .215 .731 r
.77516 .59461 m .77373 .59347 L .77622 .59724 L p F P
0 g
s
.672 .825 .957 r
.79741 .76291 m .78441 .76819 L .78154 .76492 L p F P
0 g
s
.879 .918 .848 r
.82156 .74333 m .82227 .74728 L .8146 .75557 L p F P
0 g
s
.923 .944 .794 r
.82267 .74192 m .82156 .74333 L .82227 .74728 L p F P
0 g
s
.5 .695 .956 r
.75915 .76466 m .76548 .76424 L .76255 .76062 L p F P
0 g
s
.5 .695 .956 r
.76255 .76062 m .75799 .76083 L .75915 .76466 L p F P
0 g
s
.522 .698 .95 r
.74929 .7613 m .75799 .76083 L .75915 .76466 L p F P
0 g
s
.987 .819 .431 r
.83229 .71155 m .83108 .70767 L p .8308 .71679 L F P
0 g
s
.987 .819 .431 r
.8308 .71679 m .83152 .71614 L .83229 .71155 L p F P
0 g
s
.952 .754 .296 r
.83229 .71155 m .83108 .70767 L .83148 .70144 L p F P
0 g
s
.702 .379 0 r
.82635 .6761 m .82486 .67222 L .82298 .6667 L p F P
0 g
s
.788 .483 0 r
.82486 .67222 m .82635 .6761 L .82773 .68178 L p F P
0 g
s
.335 .574 .929 r
.71059 .74105 m .71838 .74283 L .71993 .74661 L p F P
0 g
s
.317 .568 .929 r
.71838 .74283 m .71059 .74105 L .70753 .73688 L p F P
0 g
s
0 .271 .769 r
.66285 .70257 m .66531 .70425 L .6622 .7003 L p F P
0 g
s
0 .271 .769 r
.6622 .7003 m .66026 .69897 L .66285 .70257 L p F P
0 g
s
0 .143 .679 r
.79106 .61366 m .78878 .60986 L .78392 .60536 L p F P
0 g
s
0 .137 .672 r
.78152 .60158 m .78392 .60536 L .78878 .60986 L p F P
0 g
s
0 .192 .715 r
.77809 .59871 m .78152 .60158 L .78392 .60536 L p F P
0 g
s
.879 .918 .848 r
.8146 .75557 m .81358 .75171 L .82156 .74333 L p F P
0 g
s
.846 .905 .877 r
.8146 .75557 m .81296 .75709 L .81022 .75472 L p F P
0 g
s
.846 .905 .877 r
.81022 .75472 m .81358 .75171 L .8146 .75557 L p F P
0 g
s
.304 .56 .927 r
.71993 .74661 m .72698 .74822 L .72396 .74419 L p F P
0 g
s
.304 .56 .927 r
.72396 .74419 m .71838 .74283 L .71993 .74661 L p F P
0 g
s
.184 .487 .9 r
.70548 .73611 m .70354 .73241 L .69433 .72893 L p F P
0 g
s
.147 .467 .891 r
.69245 .72519 m .69433 .72893 L .70354 .73241 L p F P
0 g
s
.208 .497 .903 r
.688 .72354 m .69245 .72519 L .69433 .72893 L p F P
0 g
s
0 .331 .809 r
.75639 .57781 m .75527 .57715 L .75234 .57341 L p F P
0 g
s
.509 .692 .951 r
.75799 .76083 m .74929 .7613 L .74631 .75743 L p F P
0 g
s
.974 .919 .674 r
.82881 .7248 m .82978 .72872 L .82643 .73581 L p F P
0 g
s
.986 .893 .565 r
.82978 .72872 m .82881 .7248 L .83111 .71801 L p F P
0 g
s
0 0 .295 r
.82298 .6667 m .82137 .66283 L .81903 .65746 L p F P
0 g
s
.719 .388 0 r
.82137 .66283 m .82298 .6667 L .82486 .67222 L p F P
0 g
s
0 .1 .647 r
.79774 .62209 m .7956 .61828 L .79106 .61366 L p F P
0 g
s
0 .093 .639 r
.78878 .60986 m .79106 .61366 L .7956 .61828 L p F P
0 g
s
0 .12 .633 r
.64229 .68341 m .63923 .6799 L .63405 .67543 L p F P
0 g
s
.42 .633 .943 r
.73499 .75272 m .73 .75228 L .72698 .74822 L p F P
0 g
s
0 .184 .707 r
.78152 .60158 m .77809 .59871 L .77516 .59461 L p F P
0 g
s
.651 .299 0 r
.81731 .6536 m .81903 .65746 L .82137 .66283 L p F P
0 g
s
0 0 .377 r
.81903 .65746 m .81731 .6536 L .81453 .64838 L p F P
0 g
s
0 .072 .626 r
.80138 .62621 m .79774 .62209 L p .80396 .63067 L F P
0 g
s
0 .035 .593 r
.79774 .62209 m .80138 .62621 L .79844 .62151 L p F P
0 g
s
0 .035 .593 r
.79844 .62151 m .7956 .61828 L .79774 .62209 L p F P
0 g
s
0 .289 .781 r
.76525 .58558 m .7625 .58186 L .75639 .57781 L p F P
0 g
s
0 .284 .776 r
.75352 .57411 m .75639 .57781 L .7625 .58186 L p F P
0 g
s
0 .331 .809 r
.75234 .57341 m .75352 .57411 L .75639 .57781 L p F P
0 g
s
.96 .758 .31 r
.83019 .69755 m .83148 .70144 L .83108 .70767 L p F P
0 g
s
.909 .671 .169 r
.83148 .70144 m .83019 .69755 L .82995 .69152 L p F P
0 g
s
0 0 .364 r
.81269 .64453 m .81453 .64838 L .81731 .6536 L p F P
0 g
s
0 0 .447 r
.81453 .64838 m .81269 .64453 L .80951 .63945 L p F P
0 g
s
.031 .388 .848 r
.68193 .71782 m .67962 .71417 L .6722 .71025 L p F P
0 g
s
.005 .377 .841 r
.66983 .7066 m .6722 .71025 L .67962 .71417 L p F P
0 g
s
.046 .399 .855 r
.66531 .70425 m .66983 .7066 L .6722 .71025 L p F P
0 g
s
0 0 .531 r
.80433 .63115 m .80396 .63067 L .80319 .62919 L closepath p F P
0 g
s
0 .072 .626 r
.80396 .63067 m .80319 .62919 L .80138 .62621 L p F P
0 g
s
0 0 .435 r
.80755 .63562 m .80951 .63945 L .81269 .64453 L p F P
0 g
s
0 0 .516 r
.80433 .63115 m .80755 .63562 L .80951 .63945 L p F P
0 g
s
.187 .49 .901 r
.69245 .72519 m .688 .72354 L .68492 .7194 L p F P
0 g
s
0 .131 .643 r
.64229 .68341 m .64256 .68364 L .63942 .68007 L p F P
0 g
s
0 .131 .643 r
.63942 .68007 m .63923 .6799 L .64229 .68341 L p F P
0 g
s
0 0 .499 r
.80755 .63562 m .80433 .63115 L .80319 .62919 L p F P
0 g
s
.98 .844 .451 r
.83111 .71801 m .8308 .71679 L .83152 .71614 L closepath p F P
0 g
s
0 .274 .766 r
.64256 .68364 m .64849 .68761 L .65137 .69116 L p F P
0 g
s
0 .263 .753 r
.64849 .68761 m .64256 .68364 L .63942 .68007 L p F P
0 g
s
.021 .39 .849 r
.66983 .7066 m .66531 .70425 L .6622 .7003 L p F P
0 g
s
.177 .482 .898 r
.70548 .73611 m .70753 .73688 L .70448 .73277 L p F P
0 g
s
.177 .482 .898 r
.70448 .73277 m .70354 .73241 L .70548 .73611 L p F P
0 g
s
0 .263 .765 r
.77373 .59347 m .77111 .58973 L .76525 .58558 L p F P
0 g
s
0 .258 .759 r
.7625 .58186 m .76525 .58558 L .77111 .58973 L p F P
0 g
s
.949 .916 .747 r
.82643 .73581 m .82538 .73192 L p .82109 .74097 L F P
0 g
s
.949 .916 .747 r
.82109 .74097 m .82267 .74192 L .82643 .73581 L p F P
0 g
s
.974 .919 .674 r
.82643 .73581 m .82538 .73192 L .82881 .7248 L p F P
0 g
s
.583 .764 .964 r
.76548 .76424 m .77865 .76159 L .78154 .76492 L p F P
0 g
s
.573 .756 .965 r
.77865 .76159 m .76548 .76424 L .76255 .76062 L p F P
0 g
s
.92 .677 .184 r
.82856 .68763 m .82995 .69152 L .83019 .69755 L p F P
0 g
s
.853 .579 .042 r
.82995 .69152 m .82856 .68763 L .82773 .68178 L p F P
0 g
s
.987 .895 .584 r
.8308 .71679 m .83111 .71801 L .82881 .7248 L p F P
0 g
s
.746 .851 .928 r
.79917 .76188 m .79741 .76291 L .79458 .75996 L p F P
0 g
s
.672 .825 .957 r
.78154 .76492 m .79458 .75996 L .79741 .76291 L p F P
0 g
s
.023 .382 .845 r
.68193 .71782 m .68492 .7194 L .68182 .71536 L p F P
0 g
s
.023 .382 .845 r
.68182 .71536 m .67962 .71417 L .68193 .71782 L p F P
0 g
s
0 .261 .758 r
.66026 .69897 m .65751 .6954 L .65137 .69116 L p F P
0 g
s
0 .25 .746 r
.64849 .68761 m .65137 .69116 L .65751 .6954 L p F P
0 g
s
0 0 .499 r
.80319 .62919 m .80191 .62684 L p .80755 .63562 L F P
0 g
s
0 .014 .575 r
.80319 .62919 m .80138 .62621 L .80191 .62684 L closepath p F P
0 g
s
.746 .851 .928 r
.79458 .75996 m .79793 .75808 L .79917 .76188 L p F P
0 g
s
.777 .886 .924 r
.80745 .75222 m .79793 .75808 L .79917 .76188 L p F P
0 g
s
.777 .886 .924 r
.79917 .76188 m .81022 .75472 L .80745 .75222 L p F P
0 g
s
0 .208 .724 r
.77373 .59347 m .77516 .59461 L .77224 .59062 L p F P
0 g
s
0 .208 .724 r
.77224 .59062 m .77111 .58973 L .77373 .59347 L p F P
0 g
s
.661 .816 .958 r
.79458 .75996 m .78154 .76492 L .77865 .76159 L p F P
0 g
s
.395 .624 .944 r
.73499 .75272 m .74333 .75356 L .74034 .74969 L p F P
0 g
s
.395 .624 .944 r
.74034 .74969 m .7336 .74891 L .73499 .75272 L p F P
0 g
s
.42 .633 .943 r
.72698 .74822 m .7336 .74891 L .73499 .75272 L p F P
0 g
s
.317 .568 .929 r
.70753 .73688 m .71663 .73908 L .71838 .74283 L p F P
0 g
s
.3 .562 .928 r
.71663 .73908 m .70753 .73688 L .70448 .73277 L p F P
0 g
s
.866 .586 .058 r
.82624 .6779 m .82773 .68178 L .82856 .68763 L p F P
0 g
s
.788 .483 0 r
.82773 .68178 m .82624 .6779 L .82486 .67222 L p F P
0 g
s
.915 .937 .808 r
.82156 .74333 m .82109 .74097 L .82267 .74192 L closepath p F P
0 g
s
.993 .868 .534 r
.8291 .71712 m .82994 .71412 L .8308 .71679 L closepath p F P
0 g
s
.987 .819 .431 r
.83108 .70767 m .82994 .71412 L .8308 .71679 L p F P
0 g
s
.987 .895 .584 r
.8291 .71712 m .8308 .71679 L p .82881 .7248 L F P
0 g
s
.872 .913 .854 r
.82109 .74097 m .82156 .74333 L .81358 .75171 L p F P
0 g
s
.509 .692 .951 r
.74631 .75743 m .75655 .75706 L .75799 .76083 L p F P
0 g
s
.497 .687 .952 r
.75655 .75706 m .74631 .75743 L .74333 .75356 L p F P
0 g
s
0 .26 .758 r
.66026 .69897 m .6622 .7003 L .65907 .69648 L p F P
0 g
s
0 .26 .758 r
.65907 .69648 m .65751 .6954 L .66026 .69897 L p F P
0 g
s
0 .137 .672 r
.78878 .60986 m .7864 .60608 L .78152 .60158 L p F P
0 g
s
0 .13 .664 r
.77901 .59782 m .78152 .60158 L .7864 .60608 L p F P
0 g
s
0 .184 .707 r
.77516 .59461 m .77901 .59782 L .78152 .60158 L p F P
0 g
s
.486 .69 .958 r
.75799 .76083 m .76255 .76062 L .7596 .75697 L p F P
0 g
s
.486 .69 .958 r
.7596 .75697 m .75655 .75706 L .75799 .76083 L p F P
0 g
s
.989 .824 .442 r
.82977 .7038 m .83108 .70767 L .82994 .71412 L p F P
0 g
s
.96 .758 .31 r
.83108 .70767 m .82977 .7038 L .83019 .69755 L p F P
0 g
s
.719 .388 0 r
.82486 .67222 m .82326 .66835 L .82137 .66283 L p F P
0 g
s
.803 .491 0 r
.82326 .66835 m .82486 .67222 L .82624 .6779 L p F P
0 g
s
.406 .628 .944 r
.7336 .74891 m .72698 .74822 L .72396 .74419 L p F P
0 g
s
.147 .467 .891 r
.70141 .72872 m .69245 .72519 L p .70354 .73241 L F P
0 g
s
.154 .47 .893 r
.69245 .72519 m .70141 .72872 L .69834 .72471 L p F P
0 g
s
.154 .47 .893 r
.69834 .72471 m .69038 .72149 L .69245 .72519 L p F P
0 g
s
.187 .49 .901 r
.68492 .7194 m .69038 .72149 L .69245 .72519 L p F P
0 g
s
.838 .9 .882 r
.81358 .75171 m .81022 .75472 L .80745 .75222 L p F P
0 g
s
.838 .9 .882 r
.80745 .75222 m .81252 .74785 L .81358 .75171 L p F P
0 g
s
.872 .913 .854 r
.82 .74024 m .82109 .74097 L p .81358 .75171 L F P
0 g
s
.872 .913 .854 r
.81358 .75171 m .81252 .74785 L .82 .74024 L p F P
0 g
s
.285 .554 .926 r
.71838 .74283 m .72396 .74419 L .72093 .74019 L p F P
0 g
s
.285 .554 .926 r
.72093 .74019 m .71663 .73908 L .71838 .74283 L p F P
0 g
s
0 .176 .698 r
.77901 .59782 m .77516 .59461 L .77224 .59062 L p F P
0 g
s
0 .093 .639 r
.7956 .61828 m .79335 .61448 L .78878 .60986 L p F P
0 g
s
0 .087 .631 r
.7864 .60608 m .78878 .60986 L .79335 .61448 L p F P
0 g
s
.736 .397 0 r
.81966 .65897 m .82137 .66283 L .82326 .66835 L p F P
0 g
s
.651 .299 0 r
.82137 .66283 m .81966 .65897 L .81731 .6536 L p F P
0 g
s
0 .005 .565 r
.80191 .62684 m .80138 .62621 L .79844 .62151 L p F P
0 g
s
.973 .917 .682 r
.82776 .72089 m .82881 .7248 L .82538 .73192 L p F P
0 g
s
.987 .895 .584 r
.82881 .7248 m .82776 .72089 L .8291 .71712 L p F P
0 g
s
.166 .483 .899 r
.69038 .72149 m .68492 .7194 L .68182 .71536 L p F P
0 g
s
0 .284 .776 r
.7625 .58186 m .75963 .57815 L .75352 .57411 L p F P
0 g
s
0 .024 .58 r
.7956 .61828 m .79844 .62151 L .79551 .61695 L p F P
0 g
s
0 .024 .58 r
.79551 .61695 m .79335 .61448 L .7956 .61828 L p F P
0 g
s
0 0 .364 r
.81731 .6536 m .81548 .64976 L .81269 .64453 L p F P
0 g
s
.669 .308 0 r
.81548 .64976 m .81731 .6536 L .81966 .65897 L p F P
0 g
s
.005 .377 .841 r
.67962 .71417 m .67716 .71055 L .66983 .7066 L p F P
0 g
s
0 .367 .833 r
.66729 .70298 m .66983 .7066 L .67716 .71055 L p F P
0 g
s
.021 .39 .849 r
.6622 .7003 m .66729 .70298 L .66983 .7066 L p F P
0 g
s
0 0 .499 r
.80191 .62684 m .80549 .6318 L .80755 .63562 L p F P
0 g
s
0 0 .483 r
.79973 .62304 m .80191 .62684 L .80549 .6318 L p F P
0 g
s
0 .005 .565 r
.79844 .62151 m .79973 .62304 L .80191 .62684 L p F P
0 g
s
0 0 .35 r
.81075 .6407 m .81269 .64453 L .81548 .64976 L p F P
0 g
s
0 0 .435 r
.81269 .64453 m .81075 .6407 L .80755 .63562 L p F P
0 g
s
0 0 .422 r
.80549 .6318 m .80755 .63562 L .81075 .6407 L p F P
0 g
s
.92 .677 .184 r
.83019 .69755 m .8288 .69368 L .82856 .68763 L p F P
0 g
s
.967 .761 .324 r
.8288 .69368 m .83019 .69755 L .82977 .7038 L p F P
0 g
s
0 .382 .842 r
.66729 .70298 m .6622 .7003 L .65907 .69648 L p F P
0 g
s
0 .263 .753 r
.63942 .68007 m .64544 .68409 L .64849 .68761 L p F P
0 g
s
.573 .756 .965 r
.76255 .76062 m .77576 .7582 L .77865 .76159 L p F P
0 g
s
.563 .75 .965 r
.77576 .7582 m .76255 .76062 L .7596 .75697 L p F P
0 g
s
0 .258 .759 r
.77111 .58973 m .76837 .586 L .7625 .58186 L p F P
0 g
s
0 .252 .753 r
.75963 .57815 m .7625 .58186 L .76837 .586 L p F P
0 g
s
.166 .481 .898 r
.70448 .73277 m .70354 .73241 L .70152 .72887 L closepath p F P
0 g
s
.147 .467 .891 r
.70354 .73241 m .70152 .72887 L .70141 .72872 L p F P
0 g
s
.92 .922 .798 r
.82 .74024 m .82062 .73942 L .82109 .74097 L closepath p F P
0 g
s
.949 .916 .747 r
.82538 .73192 m .82062 .73942 L .82109 .74097 L p F P
0 g
s
.737 .846 .931 r
.79793 .75808 m .79458 .75996 L .79174 .75692 L p F P
0 g
s
.661 .816 .958 r
.77865 .76159 m .79174 .75692 L .79458 .75996 L p F P
0 g
s
.93 .682 .199 r
.82708 .68376 m .82856 .68763 L .8288 .69368 L p F P
0 g
s
.866 .586 .058 r
.82856 .68763 m .82708 .68376 L .82624 .6779 L p F P
0 g
s
0 .25 .746 r
.65751 .6954 m .6546 .69186 L .64849 .68761 L p F P
0 g
s
0 .241 .735 r
.64544 .68409 m .64849 .68761 L .6546 .69186 L p F P
0 g
s
.942 .919 .76 r
.82425 .72804 m .82538 .73192 L .82062 .73942 L p F P
0 g
s
.973 .917 .682 r
.82538 .73192 m .82425 .72804 L .82776 .72089 L p F P
0 g
s
0 .373 .838 r
.67962 .71417 m .68182 .71536 L .67872 .71141 L p F P
0 g
s
0 .373 .838 r
.67872 .71141 m .67716 .71055 L .67962 .71417 L p F P
0 g
s
.3 .562 .928 r
.70448 .73277 m .71472 .73537 L .71663 .73908 L p F P
0 g
s
.284 .557 .928 r
.71472 .73537 m .70448 .73277 L .70152 .72887 L p F P
0 g
s
.996 .863 .548 r
.82994 .71412 m .82861 .71026 L p .82666 .71711 L F P
0 g
s
.996 .863 .548 r
.82666 .71711 m .8291 .71712 L .82994 .71412 L p F P
0 g
s
.989 .824 .442 r
.82994 .71412 m .82861 .71026 L .82977 .7038 L p F P
0 g
s
.651 .808 .959 r
.79174 .75692 m .77865 .76159 L .77576 .7582 L p F P
0 g
s
0 .201 .716 r
.77111 .58973 m .77224 .59062 L .76932 .58675 L p F P
0 g
s
0 .201 .716 r
.76932 .58675 m .76837 .586 L .77111 .58973 L p F P
0 g
s
.737 .846 .931 r
.79174 .75692 m .79668 .75427 L .79793 .75808 L p F P
0 g
s
.767 .877 .927 r
.80466 .74958 m .79668 .75427 L .79793 .75808 L p F P
0 g
s
.767 .877 .927 r
.79793 .75808 m .80745 .75222 L .80466 .74958 L p F P
0 g
s
.497 .687 .952 r
.74333 .75356 m .7549 .75333 L .75655 .75706 L p F P
0 g
s
.485 .682 .953 r
.7549 .75333 m .74333 .75356 L .74034 .74969 L p F P
0 g
s
.406 .628 .944 r
.72396 .74419 m .732 .74514 L .7336 .74891 L p F P
0 g
s
.38 .619 .945 r
.7336 .74891 m .74034 .74969 L .73734 .74584 L p F P
0 g
s
.38 .619 .945 r
.73734 .74584 m .732 .74514 L .7336 .74891 L p F P
0 g
s
.879 .593 .074 r
.82465 .67404 m .82624 .6779 L .82708 .68376 L p F P
0 g
s
.803 .491 0 r
.82624 .6779 m .82465 .67404 L .82326 .66835 L p F P
0 g
s
.392 .623 .945 r
.732 .74514 m .72396 .74419 L .72093 .74019 L p F P
0 g
s
0 .25 .746 r
.65751 .6954 m .65907 .69648 L .65595 .69279 L p F P
0 g
s
0 .25 .746 r
.65595 .69279 m .6546 .69186 L .65751 .6954 L p F P
0 g
s
.989 .893 .589 r
.82776 .72089 m .82666 .71711 L .8291 .71712 L closepath p F P
0 g
s
0 .13 .664 r
.7864 .60608 m .78389 .60232 L .77901 .59782 L p F P
0 g
s
0 .123 .655 r
.77638 .59408 m .77901 .59782 L .78389 .60232 L p F P
0 g
s
0 .176 .698 r
.77224 .59062 m .77638 .59408 L .77901 .59782 L p F P
0 g
s
0 0 .551 r
.79973 .62304 m .79844 .62151 L .79551 .61695 L p F P
0 g
s
0 .168 .689 r
.77638 .59408 m .77224 .59062 L .76932 .58675 L p F P
0 g
s
.913 .916 .806 r
.82062 .73942 m .82 .74024 L .81729 .73823 L p F P
0 g
s
.913 .916 .806 r
.81729 .73823 m .81937 .73558 L .82062 .73942 L p F P
0 g
s
.942 .919 .76 r
.82062 .73942 m .81937 .73558 L .82425 .72804 L p F P
0 g
s
.736 .397 0 r
.82326 .66835 m .82156 .6645 L .81966 .65897 L p F P
0 g
s
.818 .499 0 r
.82156 .6645 m .82326 .66835 L .82465 .67404 L p F P
0 g
s
.166 .483 .899 r
.68182 .71536 m .68813 .71782 L .69038 .72149 L p F P
0 g
s
.146 .477 .897 r
.68813 .71782 m .68182 .71536 L .67872 .71141 L p F P
0 g
s
.473 .685 .959 r
.75655 .75706 m .7596 .75697 L .75665 .75331 L p F P
0 g
s
.473 .685 .959 r
.75665 .75331 m .7549 .75333 L .75655 .75706 L p F P
0 g
s
.874 .925 .856 r
.81252 .74785 m .82 .74024 L .81729 .73823 L p F P
0 g
s
.992 .825 .453 r
.82837 .69993 m .82977 .7038 L .82861 .71026 L p F P
0 g
s
.967 .761 .324 r
.82977 .7038 m .82837 .69993 L .8288 .69368 L p F P
0 g
s
.133 .463 .89 r
.69038 .72149 m .69834 .72471 L .69526 .72077 L p F P
0 g
s
.133 .463 .89 r
.69526 .72077 m .68813 .71782 L .69038 .72149 L p F P
0 g
s
0 .087 .631 r
.79335 .61448 m .79097 .6107 L .7864 .60608 L p F P
0 g
s
0 .079 .621 r
.78389 .60232 m .7864 .60608 L .79097 .6107 L p F P
0 g
s
.83 .895 .887 r
.81252 .74785 m .80745 .75222 L .80466 .74958 L p F P
0 g
s
.267 .548 .926 r
.71663 .73908 m .72093 .74019 L .71789 .73623 L p F P
0 g
s
.267 .548 .926 r
.71789 .73623 m .71472 .73537 L .71663 .73908 L p F P
0 g
s
.83 .895 .887 r
.80466 .74958 m .81139 .74399 L .81252 .74785 L p F P
0 g
s
.874 .925 .856 r
.81729 .73823 m .81139 .74399 L .81252 .74785 L p F P
0 g
s
.752 .406 0 r
.81785 .65513 m .81966 .65897 L .82156 .6645 L p F P
0 g
s
.669 .308 0 r
.81966 .65897 m .81785 .65513 L .81548 .64976 L p F P
0 g
s
0 .012 .566 r
.79335 .61448 m .79551 .61695 L .79258 .61254 L p F P
0 g
s
0 .012 .566 r
.79258 .61254 m .79097 .6107 L .79335 .61448 L p F P
0 g
s
.972 .914 .689 r
.82666 .71711 m .82776 .72089 L .82425 .72804 L p F P
0 g
s
0 .382 .842 r
.65907 .69648 m .66458 .6994 L .66729 .70298 L p F P
0 g
s
0 .374 .835 r
.66458 .6994 m .65907 .69648 L .65595 .69279 L p F P
0 g
s
0 0 .35 r
.81548 .64976 m .81355 .64593 L .81075 .6407 L p F P
0 g
s
.686 .317 0 r
.81355 .64593 m .81548 .64976 L .81785 .65513 L p F P
0 g
s
0 .367 .833 r
.67716 .71055 m .67454 .70696 L .66729 .70298 L p F P
0 g
s
0 .358 .826 r
.66458 .6994 m .66729 .70298 L .67454 .70696 L p F P
0 g
s
0 0 .483 r
.80549 .6318 m .80331 .628 L .79973 .62304 L p F P
0 g
s
0 0 .471 r
.79743 .61926 m .79973 .62304 L .80331 .628 L p F P
0 g
s
0 0 .551 r
.79551 .61695 m .79743 .61926 L .79973 .62304 L p F P
0 g
s
0 0 .422 r
.81075 .6407 m .80869 .63689 L .80549 .6318 L p F P
0 g
s
0 0 .335 r
.80869 .63689 m .81075 .6407 L .81355 .64593 L p F P
0 g
s
0 0 .408 r
.80331 .628 m .80549 .6318 L .80869 .63689 L p F P
0 g
s
.563 .75 .965 r
.7596 .75697 m .77284 .75478 L .77576 .7582 L p F P
0 g
s
.554 .744 .965 r
.77284 .75478 m .7596 .75697 L .75665 .75331 L p F P
0 g
s
.974 .763 .337 r
.82731 .68982 m .8288 .69368 L .82837 .69993 L p F P
0 g
s
.93 .682 .199 r
.8288 .69368 m .82731 .68982 L .82708 .68376 L p F P
0 g
s
0 .252 .753 r
.76837 .586 m .76551 .5823 L .75963 .57815 L p F P
0 g
s
.284 .557 .928 r
.70152 .72887 m .70146 .72873 L p .71472 .73537 L F P
0 g
s
.285 .556 .927 r
.70152 .72887 m .70141 .72872 L .70146 .72873 L closepath p F P
0 g
s
.279 .557 .929 r
.70146 .72873 m .70141 .72872 L .69834 .72471 L p F P
0 g
s
.284 .557 .928 r
.70146 .72873 m .71263 .73169 L .71472 .73537 L p F P
0 g
s
.246 .545 .927 r
.69947 .725 m .70146 .72873 L .71263 .73169 L p F P
0 g
s
.279 .557 .929 r
.69834 .72471 m .69947 .725 L .70146 .72873 L p F P
0 g
s
0 .241 .735 r
.6546 .69186 m .65154 .68834 L .64544 .68409 L p F P
0 g
s
.729 .842 .934 r
.79668 .75427 m .79174 .75692 L .78888 .75381 L p F P
0 g
s
.651 .808 .959 r
.77576 .7582 m .78888 .75381 L .79174 .75692 L p F P
0 g
s
0 .364 .832 r
.67716 .71055 m .67872 .71141 L .67562 .70755 L p F P
0 g
s
0 .364 .832 r
.67562 .70755 m .67454 .70696 L .67716 .71055 L p F P
0 g
s
.641 .801 .96 r
.78888 .75381 m .77576 .7582 L .77284 .75478 L p F P
0 g
s
.939 .686 .214 r
.82549 .6799 m .82708 .68376 L .82731 .68982 L p F P
0 g
s
.879 .593 .074 r
.82708 .68376 m .82549 .6799 L .82465 .67404 L p F P
0 g
s
0 .194 .707 r
.76837 .586 m .76932 .58675 L .76639 .58299 L p F P
0 g
s
0 .194 .707 r
.76639 .58299 m .76551 .5823 L .76837 .586 L p F P
0 g
s
.485 .682 .953 r
.74034 .74969 m .75308 .74964 L .7549 .75333 L p F P
0 g
s
.473 .677 .954 r
.75308 .74964 m .74034 .74969 L .73734 .74584 L p F P
0 g
s
.939 .915 .765 r
.82304 .72416 m .82425 .72804 L .81937 .73558 L p F P
0 g
s
.972 .914 .689 r
.82658 .71708 m .82666 .71711 L p .82425 .72804 L F P
0 g
s
.972 .914 .689 r
.82425 .72804 m .82304 .72416 L .82658 .71708 L p F P
0 g
s
.996 .863 .548 r
.82861 .71026 m .82662 .71698 L .82666 .71711 L p F P
0 g
s
.995 .868 .565 r
.82719 .70641 m .82861 .71026 L .82662 .71698 L p F P
0 g
s
.992 .825 .453 r
.82861 .71026 m .82719 .70641 L .82837 .69993 L p F P
0 g
s
.392 .623 .945 r
.72093 .74019 m .73021 .74141 L .732 .74514 L p F P
0 g
s
.378 .619 .946 r
.73021 .74141 m .72093 .74019 L .71789 .73623 L p F P
0 g
s
0 0 .536 r
.79743 .61926 m .79551 .61695 L .79258 .61254 L p F P
0 g
s
.729 .842 .934 r
.78888 .75381 m .79542 .75044 L .79668 .75427 L p F P
0 g
s
.756 .867 .93 r
.80186 .74684 m .79542 .75044 L .79668 .75427 L p F P
0 g
s
.756 .867 .93 r
.79668 .75427 m .80466 .74958 L .80186 .74684 L p F P
0 g
s
0 .242 .736 r
.6546 .69186 m .65595 .69279 L .65281 .68923 L p F P
0 g
s
0 .242 .736 r
.65281 .68923 m .65154 .68834 L .6546 .69186 L p F P
0 g
s
0 .168 .689 r
.76932 .58675 m .77363 .59036 L .77638 .59408 L p F P
0 g
s
0 .16 .679 r
.77363 .59036 m .76932 .58675 L .76639 .58299 L p F P
0 g
s
0 .123 .655 r
.78389 .60232 m .78127 .59858 L .77638 .59408 L p F P
0 g
s
0 .115 .645 r
.77363 .59036 m .77638 .59408 L .78127 .59858 L p F P
0 g
s
.365 .614 .946 r
.732 .74514 m .73734 .74584 L .73433 .742 L p F P
0 g
s
.365 .614 .946 r
.73433 .742 m .73021 .74141 L .732 .74514 L p F P
0 g
s
.89 .599 .089 r
.82296 .67019 m .82465 .67404 L .82549 .6799 L p F P
0 g
s
.818 .499 0 r
.82465 .67404 m .82296 .67019 L .82156 .6645 L p F P
0 g
s
.146 .477 .897 r
.67872 .71141 m .68571 .71419 L .68813 .71782 L p F P
0 g
s
.127 .471 .894 r
.68571 .71419 m .67872 .71141 L .67562 .70755 L p F P
0 g
s
0 .079 .621 r
.79097 .6107 m .78848 .60693 L .78389 .60232 L p F P
0 g
s
0 .071 .611 r
.78127 .59858 m .78389 .60232 L .78848 .60693 L p F P
0 g
s
.752 .406 0 r
.82156 .6645 m .81975 .66066 L .81785 .65513 L p F P
0 g
s
.832 .506 0 r
.81975 .66066 m .82156 .6645 L .82296 .67019 L p F P
0 g
s
.114 .457 .887 r
.68813 .71782 m .69526 .72077 L .69217 .7169 L p F P
0 g
s
.114 .457 .887 r
.69217 .7169 m .68571 .71419 L .68813 .71782 L p F P
0 g
s
.907 .912 .813 r
.81937 .73558 m .81729 .73823 L .81456 .73605 L p F P
0 g
s
.907 .912 .813 r
.81456 .73605 m .81803 .73175 L .81937 .73558 L p F P
0 g
s
.939 .915 .765 r
.81937 .73558 m .81803 .73175 L .82304 .72416 L p F P
0 g
s
.46 .68 .96 r
.7549 .75333 m .75665 .75331 L .75368 .74964 L p F P
0 g
s
.46 .68 .96 r
.75368 .74964 m .75308 .74964 L .7549 .75333 L p F P
0 g
s
.995 .825 .464 r
.82687 .69608 m .82837 .69993 L .82719 .70641 L p F P
0 g
s
.974 .763 .337 r
.82837 .69993 m .82687 .69608 L .82731 .68982 L p F P
0 g
s
.25 .542 .925 r
.71472 .73537 m .71789 .73623 L .71484 .73231 L p F P
0 g
s
.25 .542 .925 r
.71484 .73231 m .71263 .73169 L .71472 .73537 L p F P
0 g
s
.822 .89 .891 r
.81139 .74399 m .80466 .74958 L .80186 .74684 L p F P
0 g
s
0 .374 .835 r
.65595 .69279 m .66169 .69585 L .66458 .6994 L p F P
0 g
s
0 .366 .828 r
.66169 .69585 m .65595 .69279 L .65281 .68923 L p F P
0 g
s
.865 .916 .863 r
.81139 .74399 m .81729 .73823 L .81456 .73605 L p F P
0 g
s
0 .001 .552 r
.79097 .6107 m .79258 .61254 L .78965 .60828 L p F P
0 g
s
0 .001 .552 r
.78965 .60828 m .78848 .60693 L .79097 .6107 L p F P
0 g
s
.768 .414 0 r
.81592 .6513 m .81785 .65513 L .81975 .66066 L p F P
0 g
s
.686 .317 0 r
.81785 .65513 m .81592 .6513 L .81355 .64593 L p F P
0 g
s
.822 .89 .891 r
.80186 .74684 m .81022 .74013 L .81139 .74399 L p F P
0 g
s
.865 .916 .863 r
.81456 .73605 m .81022 .74013 L .81139 .74399 L p F P
0 g
s
0 .358 .826 r
.67454 .70696 m .67178 .70339 L .66458 .6994 L p F P
0 g
s
0 .351 .819 r
.66169 .69585 m .66458 .6994 L .67178 .70339 L p F P
0 g
s
.987 .893 .631 r
.82658 .71708 m .82662 .71698 L .82666 .71711 L closepath p F P
0 g
s
0 0 .471 r
.80331 .628 m .80102 .62421 L .79743 .61926 L p F P
0 g
s
0 0 .457 r
.79503 .61549 m .79743 .61926 L .80102 .62421 L p F P
0 g
s
0 0 .536 r
.79258 .61254 m .79503 .61549 L .79743 .61926 L p F P
0 g
s
.703 .326 0 r
.8115 .64211 m .81355 .64593 L .81592 .6513 L p F P
0 g
s
0 0 .335 r
.81355 .64593 m .8115 .64211 L .80869 .63689 L p F P
0 g
s
.554 .744 .965 r
.75665 .75331 m .76992 .75132 L .77284 .75478 L p F P
0 g
s
.545 .738 .965 r
.76992 .75132 m .75665 .75331 L .75368 .74964 L p F P
0 g
s
.984 .891 .645 r
.82662 .71698 m .82658 .71708 L .82396 .71604 L p F P
0 g
s
.984 .891 .645 r
.82396 .71604 m .82515 .71315 L .82662 .71698 L p F P
0 g
s
.995 .868 .565 r
.82662 .71698 m .82515 .71315 L .82719 .70641 L p F P
0 g
s
.972 .915 .689 r
.82304 .72416 m .82658 .71708 L .82396 .71604 L p F P
0 g
s
0 0 .408 r
.80869 .63689 m .80652 .63309 L .80331 .628 L p F P
0 g
s
0 0 .394 r
.80102 .62421 m .80331 .628 L .80652 .63309 L p F P
0 g
s
.64 .244 0 r
.80652 .63309 m .80869 .63689 L .8115 .64211 L p F P
0 g
s
.263 .553 .929 r
.69947 .725 m .69834 .72471 L .69526 .72077 L p F P
0 g
s
.979 .765 .35 r
.82572 .68596 m .82731 .68982 L .82687 .69608 L p F P
0 g
s
.939 .686 .214 r
.82731 .68982 m .82572 .68596 L .82549 .6799 L p F P
0 g
s
.246 .545 .927 r
.71263 .73169 m .7104 .72803 L .69947 .725 L p F P
0 g
s
.229 .539 .925 r
.69729 .72132 m .69947 .725 L .7104 .72803 L p F P
0 g
s
.263 .553 .929 r
.69526 .72077 m .69729 .72132 L .69947 .725 L p F P
0 g
s
.641 .801 .96 r
.77284 .75478 m .78601 .75063 L .78888 .75381 L p F P
0 g
s
.721 .837 .937 r
.79542 .75044 m .78888 .75381 L .78601 .75063 L p F P
0 g
s
.473 .677 .954 r
.73734 .74584 m .75071 .74595 L p .75308 .74964 L F P
0 g
s
.447 .675 .961 r
.75071 .74595 m .73734 .74584 L .73433 .742 L p F P
0 g
s
.632 .794 .96 r
.78601 .75063 m .77284 .75478 L .76992 .75132 L p F P
0 g
s
.378 .619 .946 r
.71789 .73623 m .72824 .73771 L .73021 .74141 L p F P
0 g
s
.365 .615 .947 r
.72824 .73771 m .71789 .73623 L .71484 .73231 L p F P
0 g
s
0 0 .521 r
.79503 .61549 m .79258 .61254 L .78965 .60828 L p F P
0 g
s
0 .357 .825 r
.67454 .70696 m .67562 .70755 L .67251 .70379 L p F P
0 g
s
0 .357 .825 r
.67251 .70379 m .67178 .70339 L .67454 .70696 L p F P
0 g
s
.947 .69 .228 r
.8238 .67606 m .82549 .6799 L .82572 .68596 L p F P
0 g
s
.89 .599 .089 r
.82549 .6799 m .8238 .67606 L .82296 .67019 L p F P
0 g
s
.996 .866 .573 r
.82566 .70257 m .82719 .70641 L .82515 .71315 L p F P
0 g
s
.995 .825 .464 r
.82719 .70641 m .82566 .70257 L .82687 .69608 L p F P
0 g
s
.936 .911 .77 r
.82175 .72029 m .82304 .72416 L .81803 .73175 L p F P
0 g
s
.972 .915 .689 r
.82396 .71604 m .82175 .72029 L .82304 .72416 L p F P
0 g
s
.127 .471 .894 r
.67562 .70755 m .68314 .71058 L .68571 .71419 L p F P
0 g
s
.108 .465 .891 r
.68314 .71058 m .67562 .70755 L .67251 .70379 L p F P
0 g
s
0 .16 .679 r
.76639 .58299 m .77077 .58666 L .77363 .59036 L p F P
0 g
s
0 .115 .645 r
.78127 .59858 m .77853 .59485 L .77363 .59036 L p F P
0 g
s
0 .107 .634 r
.77077 .58666 m .77363 .59036 L .77853 .59485 L p F P
0 g
s
.721 .837 .937 r
.78601 .75063 m .79416 .7466 L .79542 .75044 L p F P
0 g
s
.746 .859 .932 r
.79903 .74399 m .79416 .7466 L .79542 .75044 L p F P
0 g
s
.746 .859 .932 r
.79542 .75044 m .80186 .74684 L .79903 .74399 L p F P
0 g
s
.901 .604 .105 r
.82116 .66635 m .82296 .67019 L .8238 .67606 L p F P
0 g
s
.832 .506 0 r
.82296 .67019 m .82116 .66635 L .81975 .66066 L p F P
0 g
s
.351 .61 .947 r
.73021 .74141 m .73433 .742 L .73131 .73818 L p F P
0 g
s
.351 .61 .947 r
.73131 .73818 m .72824 .73771 L .73021 .74141 L p F P
0 g
s
0 .071 .611 r
.78848 .60693 m .78586 .60319 L .78127 .59858 L p F P
0 g
s
0 .063 .599 r
.77853 .59485 m .78127 .59858 L .78586 .60319 L p F P
0 g
s
.095 .451 .883 r
.68571 .71419 m .69217 .7169 L .68908 .71311 L p F P
0 g
s
.095 .451 .883 r
.68908 .71311 m .68314 .71058 L .68571 .71419 L p F P
0 g
s
.845 .513 0 r
.81784 .65683 m .81975 .66066 L .82116 .66635 L p F P
0 g
s
.768 .414 0 r
.81975 .66066 m .81784 .65683 L .81592 .6513 L p F P
0 g
s
0 .366 .828 r
.65281 .68923 m .65865 .69233 L .66169 .69585 L p F P
0 g
s
.459 .682 .962 r
.75368 .74964 m .75308 .74964 L .75191 .74744 L closepath p F P
0 g
s
.473 .677 .954 r
.75071 .74595 m .75191 .74744 L .75308 .74964 L p F P
0 g
s
.901 .907 .819 r
.81803 .73175 m .81456 .73605 L .8118 .73371 L p F P
0 g
s
.901 .907 .819 r
.8118 .73371 m .81662 .72792 L .81803 .73175 L p F P
0 g
s
.936 .911 .77 r
.81803 .73175 m .81662 .72792 L .82175 .72029 L p F P
0 g
s
.997 .824 .474 r
.82527 .69223 m .82687 .69608 L .82566 .70257 L p F P
0 g
s
.979 .765 .35 r
.82687 .69608 m .82527 .69223 L .82572 .68596 L p F P
0 g
s
.234 .537 .924 r
.71263 .73169 m .71484 .73231 L .71179 .72844 L p F P
0 g
s
.234 .537 .924 r
.71179 .72844 m .7104 .72803 L .71263 .73169 L p F P
0 g
s
0 0 .537 r
.78848 .60693 m .78965 .60828 L .78673 .60418 L p F P
0 g
s
0 0 .537 r
.78673 .60418 m .78586 .60319 L .78848 .60693 L p F P
0 g
s
.815 .885 .895 r
.81022 .74013 m .80186 .74684 L .79903 .74399 L p F P
0 g
s
.545 .738 .965 r
.75368 .74964 m .76699 .74783 L .76992 .75132 L p F P
0 g
s
.549 .727 .957 r
.76404 .74432 m .76699 .74783 L .75368 .74964 L p F P
0 g
s
.549 .727 .957 r
.7515 .74585 m .76404 .74432 L p .75368 .74964 L F P
0 g
s
.549 .727 .957 r
.75368 .74964 m .75191 .74744 L .7515 .74585 L p F P
0 g
s
.783 .422 0 r
.81388 .64749 m .81592 .6513 L .81784 .65683 L p F P
0 g
s
.703 .326 0 r
.81592 .6513 m .81388 .64749 L .8115 .64211 L p F P
0 g
s
0 .351 .819 r
.67178 .70339 m .66887 .69985 L .66169 .69585 L p F P
0 g
s
0 .345 .813 r
.65865 .69233 m .66169 .69585 L .66887 .69985 L p F P
0 g
s
0 0 .457 r
.80102 .62421 m .79863 .62045 L .79503 .61549 L p F P
0 g
s
0 0 .443 r
.79251 .61174 m .79503 .61549 L .79863 .62045 L p F P
0 g
s
0 0 .521 r
.78965 .60828 m .79251 .61174 L .79503 .61549 L p F P
0 g
s
.247 .549 .929 r
.69729 .72132 m .69526 .72077 L .69217 .7169 L p F P
0 g
s
.856 .907 .868 r
.81022 .74013 m .81456 .73605 L .8118 .73371 L p F P
0 g
s
.72 .334 0 r
.80934 .63831 m .8115 .64211 L .81388 .64749 L p F P
0 g
s
.64 .244 0 r
.8115 .64211 m .80934 .63831 L .80652 .63309 L p F P
0 g
s
.815 .885 .895 r
.79903 .74399 m .80898 .73626 L .81022 .74013 L p F P
0 g
s
.856 .907 .868 r
.8118 .73371 m .80898 .73626 L .81022 .74013 L p F P
0 g
s
0 0 .394 r
.80652 .63309 m .80425 .6293 L .80102 .62421 L p F P
0 g
s
.598 .179 0 r
.79863 .62045 m .80102 .62421 L .80425 .6293 L p F P
0 g
s
.657 .253 0 r
.80425 .6293 m .80652 .63309 L .80934 .63831 L p F P
0 g
s
.981 .889 .657 r
.82515 .71315 m .82396 .71604 L .82131 .71468 L p F P
0 g
s
.981 .889 .657 r
.82131 .71468 m .8236 .70933 L .82515 .71315 L p F P
0 g
s
.996 .866 .573 r
.82515 .71315 m .8236 .70933 L .82566 .70257 L p F P
0 g
s
0 0 .505 r
.79251 .61174 m .78965 .60828 L .78673 .60418 L p F P
0 g
s
.447 .675 .961 r
.73433 .742 m .74773 .74226 L .75071 .74595 L p F P
0 g
s
.438 .672 .962 r
.74773 .74226 m .73433 .742 L .73131 .73818 L p F P
0 g
s
.984 .766 .362 r
.82403 .68212 m .82572 .68596 L .82527 .69223 L p F P
0 g
s
.947 .69 .228 r
.82572 .68596 m .82403 .68212 L .8238 .67606 L p F P
0 g
s
.365 .615 .947 r
.71484 .73231 m .72612 .73403 L .72824 .73771 L p F P
0 g
s
.352 .611 .947 r
.72612 .73403 m .71484 .73231 L .71179 .72844 L p F P
0 g
s
.632 .794 .96 r
.76992 .75132 m .78312 .7474 L .78601 .75063 L p F P
0 g
s
.624 .788 .961 r
.78312 .7474 m .76992 .75132 L .76699 .74783 L p F P
0 g
s
.714 .833 .939 r
.79416 .7466 m .78601 .75063 L .78312 .7474 L p F P
0 g
s
.229 .539 .925 r
.7104 .72803 m .70801 .7244 L .69729 .72132 L p F P
0 g
s
.214 .534 .924 r
.69493 .71766 m .69729 .72132 L .70801 .7244 L p F P
0 g
s
.247 .549 .929 r
.69217 .7169 m .69493 .71766 L .69729 .72132 L p F P
0 g
s
.967 .91 .704 r
.82175 .72029 m .82396 .71604 L .82131 .71468 L p F P
0 g
s
0 .35 .819 r
.67178 .70339 m .67251 .70379 L .66939 .70014 L p F P
0 g
s
0 .35 .819 r
.66939 .70014 m .66887 .69985 L .67178 .70339 L p F P
0 g
s
.108 .465 .891 r
.67251 .70379 m .6804 .707 L .68314 .71058 L p F P
0 g
s
.09 .461 .887 r
.6804 .707 m .67251 .70379 L .66939 .70014 L p F P
0 g
s
.546 .725 .957 r
.75191 .74744 m .75071 .74595 L .7515 .74585 L closepath p F P
0 g
s
.954 .692 .242 r
.822 .67222 m .8238 .67606 L .82403 .68212 L p F P
0 g
s
.901 .604 .105 r
.8238 .67606 m .822 .67222 L .82116 .66635 L p F P
0 g
s
0 .107 .634 r
.77853 .59485 m .77567 .59115 L .77077 .58666 L p F P
0 g
s
.995 .863 .581 r
.82404 .69874 m .82566 .70257 L .8236 .70933 L p F P
0 g
s
.997 .824 .474 r
.82566 .70257 m .82404 .69874 L .82527 .69223 L p F P
0 g
s
.932 .907 .774 r
.82036 .71643 m .82175 .72029 L .81662 .72792 L p F P
0 g
s
.967 .91 .704 r
.82131 .71468 m .82036 .71643 L .82175 .72029 L p F P
0 g
s
.911 .608 .12 r
.81925 .66253 m .82116 .66635 L .822 .67222 L p F P
0 g
s
.845 .513 0 r
.82116 .66635 m .81925 .66253 L .81784 .65683 L p F P
0 g
s
.337 .605 .947 r
.72824 .73771 m .73131 .73818 L .72829 .73439 L p F P
0 g
s
.337 .605 .947 r
.72829 .73439 m .72612 .73403 L .72824 .73771 L p F P
0 g
s
.714 .833 .939 r
.78312 .7474 m .79291 .74274 L .79416 .7466 L p F P
0 g
s
.737 .851 .934 r
.79619 .74106 m .79291 .74274 L .79416 .7466 L p F P
0 g
s
.737 .851 .934 r
.79416 .7466 m .79903 .74399 L .79619 .74106 L p F P
0 g
s
0 .063 .599 r
.78586 .60319 m .78313 .59947 L .77853 .59485 L p F P
0 g
s
0 .054 .586 r
.77567 .59115 m .77853 .59485 L .78313 .59947 L p F P
0 g
s
.078 .446 .88 r
.68314 .71058 m .68908 .71311 L .68598 .7094 L p F P
0 g
s
.078 .446 .88 r
.68598 .7094 m .6804 .707 L .68314 .71058 L p F P
0 g
s
.545 .726 .958 r
.7515 .74585 m .75071 .74595 L .74773 .74226 L p F P
0 g
s
.857 .519 .003 r
.81581 .65302 m .81784 .65683 L .81925 .66253 L p F P
0 g
s
.783 .422 0 r
.81784 .65683 m .81581 .65302 L .81388 .64749 L p F P
0 g
s
0 0 .522 r
.78586 .60319 m .78673 .60418 L .78381 .60025 L p F P
0 g
s
0 0 .522 r
.78381 .60025 m .78313 .59947 L .78586 .60319 L p F P
0 g
s
.232 .545 .928 r
.69493 .71766 m .69217 .7169 L .68908 .71311 L p F P
0 g
s
0 .345 .813 r
.66887 .69985 m .66581 .69633 L .65865 .69233 L p F P
0 g
s
.219 .532 .922 r
.7104 .72803 m .71179 .72844 L .70873 .72461 L p F P
0 g
s
.219 .532 .922 r
.70873 .72461 m .70801 .7244 L .7104 .72803 L p F P
0 g
s
.534 .72 .959 r
.7515 .74585 m .76404 .74432 L .76109 .74079 L p F P
0 g
s
.534 .72 .959 r
.76109 .74079 m .7502 .74198 L .7515 .74585 L p F P
0 g
s
.545 .726 .958 r
.74773 .74226 m .7502 .74198 L .7515 .74585 L p F P
0 g
s
.999 .823 .484 r
.82357 .6884 m .82527 .69223 L .82404 .69874 L p F P
0 g
s
.984 .766 .362 r
.82527 .69223 m .82357 .6884 L .82403 .68212 L p F P
0 g
s
.808 .88 .898 r
.80898 .73626 m .79903 .74399 L .79619 .74106 L p F P
0 g
s
.895 .903 .824 r
.81662 .72792 m .8118 .73371 L .80902 .73122 L p F P
0 g
s
.895 .903 .824 r
.80902 .73122 m .81512 .7241 L .81662 .72792 L p F P
0 g
s
.932 .907 .774 r
.81662 .72792 m .81512 .7241 L .82036 .71643 L p F P
0 g
s
.798 .429 0 r
.81174 .64369 m .81388 .64749 L .81581 .65302 L p F P
0 g
s
.72 .334 0 r
.81388 .64749 m .81174 .64369 L .80934 .63831 L p F P
0 g
s
0 0 .443 r
.79863 .62045 m .79611 .61669 L .79251 .61174 L p F P
0 g
s
0 0 .427 r
.78988 .608 m .79251 .61174 L .79611 .61669 L p F P
0 g
s
0 0 .505 r
.78673 .60418 m .78988 .608 L .79251 .61174 L p F P
0 g
s
.736 .343 0 r
.80707 .63453 m .80934 .63831 L .81174 .64369 L p F P
0 g
s
.657 .253 0 r
.80934 .63831 m .80707 .63453 L .80425 .6293 L p F P
0 g
s
.598 .179 0 r
.80425 .6293 m .80185 .62554 L .79863 .62045 L p F P
0 g
s
.615 .188 0 r
.79611 .61669 m .79863 .62045 L .80185 .62554 L p F P
0 g
s
.674 .262 0 r
.80185 .62554 m .80425 .6293 L .80707 .63453 L p F P
0 g
s
0 0 .489 r
.78988 .608 m .78673 .60418 L .78381 .60025 L p F P
0 g
s
.847 .899 .873 r
.80902 .73122 m .80768 .7324 L .80898 .73626 L p F P
0 g
s
.847 .899 .873 r
.80898 .73626 m .8118 .73371 L .80902 .73122 L p F P
0 g
s
.808 .88 .898 r
.79619 .74106 m .80768 .7324 L .80898 .73626 L p F P
0 g
s
.438 .672 .962 r
.73131 .73818 m .74473 .73857 L .74773 .74226 L p F P
0 g
s
.43 .669 .962 r
.74473 .73857 m .73131 .73818 L .72829 .73439 L p F P
0 g
s
.352 .611 .947 r
.71179 .72844 m .72385 .73038 L .72612 .73403 L p F P
0 g
s
.34 .608 .948 r
.72385 .73038 m .71179 .72844 L .70873 .72461 L p F P
0 g
s
.979 .88 .662 r
.8236 .70933 m .82194 .70552 L p .81919 .71339 L F P
0 g
s
.979 .88 .662 r
.81919 .71339 m .82131 .71468 L .8236 .70933 L p F P
0 g
s
.995 .863 .581 r
.8236 .70933 m .82194 .70552 L .82404 .69874 L p F P
0 g
s
.624 .788 .961 r
.76699 .74783 m .78022 .74411 L .78312 .7474 L p F P
0 g
s
.616 .783 .961 r
.78022 .74411 m .76699 .74783 L .76404 .74432 L p F P
0 g
s
.988 .766 .374 r
.82223 .67829 m .82403 .68212 L .82357 .6884 L p F P
0 g
s
.954 .692 .242 r
.82403 .68212 m .82223 .67829 L .822 .67222 L p F P
0 g
s
.707 .83 .941 r
.79291 .74274 m .78312 .7474 L .78022 .74411 L p F P
0 g
s
0 .345 .813 r
.66887 .69985 m .66939 .70014 L .66627 .69658 L p F P
0 g
s
0 .345 .813 r
.66627 .69658 m .66581 .69633 L .66887 .69985 L p F P
0 g
s
.214 .534 .924 r
.70801 .7244 m .7055 .72079 L .69493 .71766 L p F P
0 g
s
.177 .514 .915 r
.69239 .71404 m .69493 .71766 L .7055 .72079 L p F P
0 g
s
.232 .545 .928 r
.68908 .71311 m .69239 .71404 L .69493 .71766 L p F P
0 g
s
.09 .461 .887 r
.66939 .70014 m .67751 .70345 L .6804 .707 L p F P
0 g
s
.074 .457 .884 r
.67751 .70345 m .66939 .70014 L .66627 .69658 L p F P
0 g
s
.961 .694 .255 r
.8201 .6684 m .822 .67222 L .82223 .67829 L p F P
0 g
s
.911 .608 .12 r
.822 .67222 m .8201 .6684 L .81925 .66253 L p F P
0 g
s
.962 .905 .717 r
.82036 .71643 m .81919 .71339 L .82131 .71468 L closepath p F P
0 g
s
.995 .86 .588 r
.82232 .69492 m .82404 .69874 L .82194 .70552 L p F P
0 g
s
.999 .823 .484 r
.82404 .69874 m .82232 .69492 L .82357 .6884 L p F P
0 g
s
.929 .903 .779 r
.81919 .71339 m .82036 .71643 L .81512 .7241 L p F P
0 g
s
0 .054 .586 r
.78313 .59947 m .78027 .59576 L .77567 .59115 L p F P
0 g
s
.919 .61 .132 r
.81722 .65872 m .81925 .66253 L .8201 .6684 L p F P
0 g
s
.857 .519 .003 r
.81925 .66253 m .81722 .65872 L .81581 .65302 L p F P
0 g
s
.325 .602 .947 r
.72612 .73403 m .72829 .73439 L .72525 .73063 L p F P
0 g
s
.325 .602 .947 r
.72525 .73063 m .72385 .73038 L .72612 .73403 L p F P
0 g
s
.537 .723 .959 r
.7502 .74198 m .74773 .74226 L .74473 .73857 L p F P
0 g
s
.063 .442 .877 r
.6804 .707 m .68598 .7094 L .68288 .70577 L p F P
0 g
s
.063 .442 .877 r
.68288 .70577 m .67751 .70345 L .6804 .707 L p F P
0 g
s
.707 .83 .941 r
.78022 .74411 m .79168 .73885 L .79291 .74274 L p F P
0 g
s
.728 .844 .936 r
.79333 .73804 m .79168 .73885 L .79291 .74274 L p F P
0 g
s
.728 .844 .936 r
.79291 .74274 m .79619 .74106 L .79333 .73804 L p F P
0 g
s
.218 .542 .927 r
.69239 .71404 m .68908 .71311 L .68598 .7094 L p F P
0 g
s
0 0 .506 r
.78313 .59947 m .78381 .60025 L .78089 .59647 L p F P
0 g
s
0 0 .506 r
.78089 .59647 m .78027 .59576 L .78313 .59947 L p F P
0 g
s
.866 .521 .014 r
.81367 .64922 m .81581 .65302 L .81722 .65872 L p F P
0 g
s
.798 .429 0 r
.81581 .65302 m .81367 .64922 L .81174 .64369 L p F P
0 g
s
.205 .528 .921 r
.70801 .7244 m .70873 .72461 L .70566 .72084 L p F P
0 g
s
.205 .528 .921 r
.70566 .72084 m .7055 .72079 L .70801 .7244 L p F P
0 g
s
0 0 .427 r
.79611 .61669 m .79349 .61296 L .78988 .608 L p F P
0 g
s
.577 .13 0 r
.78714 .60428 m .78988 .608 L .79349 .61296 L p F P
0 g
s
0 0 .489 r
.78381 .60025 m .78714 .60428 L .78988 .608 L p F P
0 g
s
.803 .882 .904 r
.80768 .7324 m .79619 .74106 L .79333 .73804 L p F P
0 g
s
.802 .425 0 r
.80947 .63991 m .81174 .64369 L .81367 .64922 L p F P
0 g
s
.736 .343 0 r
.81174 .64369 m .80947 .63991 L .80707 .63453 L p F P
0 g
s
1 .821 .493 r
.82176 .68458 m .82357 .6884 L .82232 .69492 L p F P
0 g
s
.988 .766 .374 r
.82357 .6884 m .82176 .68458 L .82223 .67829 L p F P
0 g
s
.891 .888 .822 r
.81512 .7241 m .81353 .72029 L p .80637 .72875 L F P
0 g
s
.891 .888 .822 r
.80637 .72875 m .80902 .73122 L .81512 .7241 L p F P
0 g
s
.929 .903 .779 r
.81862 .71298 m .81919 .71339 L p .81512 .7241 L F P
0 g
s
.929 .903 .779 r
.81512 .7241 m .81353 .72029 L .81862 .71298 L p F P
0 g
s
.525 .718 .961 r
.7502 .74198 m .76109 .74079 L .75812 .73724 L p F P
0 g
s
.525 .718 .961 r
.75812 .73724 m .74857 .73817 L .7502 .74198 L p F P
0 g
s
.537 .723 .959 r
.74473 .73857 m .74857 .73817 L .7502 .74198 L p F P
0 g
s
.615 .188 0 r
.80185 .62554 m .79935 .62178 L .79611 .61669 L p F P
0 g
s
.632 .198 0 r
.79349 .61296 m .79611 .61669 L .79935 .62178 L p F P
0 g
s
.43 .669 .962 r
.72829 .73439 m .74173 .73489 L .74473 .73857 L p F P
0 g
s
.423 .667 .963 r
.74173 .73489 m .72829 .73439 L .72525 .73063 L p F P
0 g
s
0 0 .474 r
.78714 .60428 m .78381 .60025 L .78089 .59647 L p F P
0 g
s
.34 .608 .948 r
.70873 .72461 m .72144 .72676 L .72385 .73038 L p F P
0 g
s
.328 .606 .949 r
.72144 .72676 m .70873 .72461 L .70566 .72084 L p F P
0 g
s
.751 .351 0 r
.80469 .63076 m .80707 .63453 L .80947 .63991 L p F P
0 g
s
.674 .262 0 r
.80707 .63453 m .80469 .63076 L .80185 .62554 L p F P
0 g
s
.691 .271 0 r
.79935 .62178 m .80185 .62554 L .80469 .63076 L p F P
0 g
s
.616 .783 .961 r
.76404 .74432 m .77731 .74078 L .78022 .74411 L p F P
0 g
s
.609 .778 .962 r
.77731 .74078 m .76404 .74432 L .76109 .74079 L p F P
0 g
s
.839 .891 .877 r
.80768 .7324 m .80637 .72875 L .80902 .73122 L closepath p F P
0 g
s
.803 .882 .904 r
.80637 .72875 m .80768 .7324 L p .79333 .73804 L F P
0 g
s
.979 .88 .662 r
.82194 .70552 m .81883 .71259 L .81919 .71339 L p F P
0 g
s
.976 .881 .672 r
.82019 .70171 m .82194 .70552 L .81883 .71259 L p F P
0 g
s
.995 .86 .588 r
.82194 .70552 m .82019 .70171 L .82232 .69492 L p F P
0 g
s
.7 .83 .945 r
.79168 .73885 m .78022 .74411 L .77731 .74078 L p F P
0 g
s
.961 .694 .255 r
.82223 .67829 m .82032 .67448 L .8201 .6684 L p F P
0 g
s
.991 .765 .385 r
.82032 .67448 m .82223 .67829 L .82176 .68458 L p F P
0 g
s
.177 .514 .915 r
.70258 .71712 m .69239 .71404 L p .7055 .72079 L F P
0 g
s
.195 .528 .921 r
.69239 .71404 m .70258 .71712 L .6995 .71345 L p F P
0 g
s
.195 .528 .921 r
.6995 .71345 m .68969 .71046 L .69239 .71404 L p F P
0 g
s
.218 .542 .927 r
.68598 .7094 m .68969 .71046 L .69239 .71404 L p F P
0 g
s
.074 .457 .884 r
.66627 .69658 m .67447 .69993 L .67751 .70345 L p F P
0 g
s
.958 .894 .721 r
.81862 .71298 m .81883 .71259 L .81919 .71339 L closepath p F P
0 g
s
.966 .696 .269 r
.81808 .66461 m .8201 .6684 L .82032 .67448 L p F P
0 g
s
.919 .61 .132 r
.81807 .66456 m .81722 .65872 L p .8201 .6684 L F P
0 g
s
.919 .61 .132 r
.8201 .6684 m .81808 .66461 L .81807 .66456 L p F P
0 g
s
.993 .857 .594 r
.8205 .69112 m .82232 .69492 L .82019 .70171 L p F P
0 g
s
1 .821 .493 r
.82232 .69492 m .8205 .69112 L .82176 .68458 L p F P
0 g
s
.528 .72 .961 r
.74857 .73817 m .74473 .73857 L .74173 .73489 L p F P
0 g
s
.954 .89 .728 r
.81883 .71259 m .81862 .71298 L .81587 .71086 L p F P
0 g
s
.954 .89 .728 r
.81587 .71086 m .81702 .70881 L .81883 .71259 L p F P
0 g
s
.976 .881 .672 r
.81883 .71259 m .81702 .70881 L .82019 .70171 L p F P
0 g
s
.929 .906 .779 r
.81353 .72029 m .81862 .71298 L .81587 .71086 L p F P
0 g
s
.204 .54 .927 r
.68969 .71046 m .68598 .7094 L .68288 .70577 L p F P
0 g
s
.314 .599 .947 r
.72385 .73038 m .72525 .73063 L .72221 .7269 L p F P
0 g
s
.314 .599 .947 r
.72221 .7269 m .72144 .72676 L .72385 .73038 L p F P
0 g
s
.929 .616 .152 r
.81807 .66456 m .81722 .65872 L .81616 .65683 L closepath p F P
0 g
s
.866 .521 .014 r
.81454 .65277 m .81367 .64922 L p .81722 .65872 L F P
0 g
s
.866 .521 .014 r
.81722 .65872 m .81616 .65683 L .81454 .65277 L p F P
0 g
s
.049 .439 .874 r
.67751 .70345 m .68288 .70577 L .67977 .70222 L p F P
0 g
s
.049 .439 .874 r
.67977 .70222 m .67447 .69993 L .67751 .70345 L p F P
0 g
s
.7 .83 .945 r
.79046 .73495 m .79168 .73885 L p .77731 .74078 L F P
0 g
s
.72 .838 .937 r
.79168 .73885 m .79046 .73495 L .79333 .73804 L closepath p F P
0 g
s
.883 .534 .042 r
.81454 .65277 m .81367 .64922 L .81154 .64566 L closepath p F P
0 g
s
.802 .425 0 r
.81136 .64532 m .80947 .63991 L p .81367 .64922 L F P
0 g
s
.802 .425 0 r
.81367 .64922 m .81154 .64566 L .81136 .64532 L p F P
0 g
s
.198 .528 .921 r
.70566 .72084 m .7055 .72079 L .70448 .71941 L closepath p F P
0 g
s
.177 .514 .915 r
.7055 .72079 m .70448 .71941 L .70258 .71712 L p F P
0 g
s
.577 .13 0 r
.79349 .61296 m .79074 .60924 L .78714 .60428 L p F P
0 g
s
0 0 .474 r
.78089 .59647 m .78428 .60058 L .78714 .60428 L p F P
0 g
s
.594 .139 0 r
.78428 .60058 m .78714 .60428 L .79074 .60924 L p F P
0 g
s
.423 .667 .963 r
.72525 .73063 m .73871 .73122 L .74173 .73489 L p F P
0 g
s
.416 .665 .963 r
.73871 .73122 m .72525 .73063 L .72221 .7269 L p F P
0 g
s
.328 .606 .949 r
.70566 .72084 m .7189 .72315 L .72144 .72676 L p F P
0 g
s
.317 .604 .949 r
.7189 .72315 m .70566 .72084 L .70448 .71941 L p F P
0 g
s
.803 .882 .904 r
.79333 .73804 m .80622 .7286 L .80637 .72875 L p F P
0 g
s
.799 .856 .893 r
.79046 .73495 m .79333 .73804 L .80622 .7286 L p F P
0 g
s
.828 .448 0 r
.80947 .63991 m .81136 .64532 L .80833 .63973 L p F P
0 g
s
.828 .448 0 r
.80833 .63973 m .80709 .63614 L .80947 .63991 L p F P
0 g
s
.751 .351 0 r
.80947 .63991 m .80709 .63614 L .80469 .63076 L p F P
0 g
s
.632 .198 0 r
.79935 .62178 m .79672 .61805 L .79349 .61296 L p F P
0 g
s
.649 .207 0 r
.79074 .60924 m .79349 .61296 L .79672 .61805 L p F P
0 g
s
1 .818 .501 r
.81984 .68078 m .82176 .68458 L .8205 .69112 L p F P
0 g
s
.991 .765 .385 r
.82176 .68458 m .81984 .68078 L .82032 .67448 L p F P
0 g
s
.766 .359 0 r
.80218 .62701 m .80469 .63076 L .80709 .63614 L p F P
0 g
s
.691 .271 0 r
.80469 .63076 m .80218 .62701 L .79935 .62178 L p F P
0 g
s
.707 .28 0 r
.79672 .61805 m .79935 .62178 L .80218 .62701 L p F P
0 g
s
.891 .888 .822 r
.81353 .72029 m .80628 .72854 L .80637 .72875 L p F P
0 g
s
.884 .887 .83 r
.81184 .71648 m .81353 .72029 L .80628 .72854 L p F P
0 g
s
.929 .906 .779 r
.81587 .71086 m .81184 .71648 L .81353 .72029 L p F P
0 g
s
.516 .716 .963 r
.74857 .73817 m .75812 .73724 L .75514 .73369 L p F P
0 g
s
.516 .716 .963 r
.75514 .73369 m .74668 .73442 L .74857 .73817 L p F P
0 g
s
.528 .72 .961 r
.74173 .73489 m .74668 .73442 L .74857 .73817 L p F P
0 g
s
.609 .778 .962 r
.76109 .74079 m .77438 .73742 L .77731 .74078 L p F P
0 g
s
.603 .774 .962 r
.77438 .73742 m .76109 .74079 L .75812 .73724 L p F P
0 g
s
.862 .886 .853 r
.80622 .7286 m .80628 .72854 L .80637 .72875 L closepath p F P
0 g
s
.7 .83 .945 r
.77731 .74078 m .79046 .73495 L .79046 .73495 L p F P
0 g
s
.693 .824 .945 r
.79046 .73495 m .77731 .74078 L .77438 .73742 L p F P
0 g
s
.973 .876 .677 r
.81833 .69792 m .82019 .70171 L .81702 .70881 L p F P
0 g
s
.993 .857 .594 r
.82019 .70171 m .81833 .69792 L .8205 .69112 L p F P
0 g
s
.934 .621 .164 r
.81616 .65683 m .81505 .65493 L p .81808 .6646 L F P
0 g
s
.934 .621 .164 r
.81808 .6646 m .81807 .66456 L .81616 .65683 L p F P
0 g
s
.884 .54 .047 r
.81616 .65683 m .81454 .65277 L .81505 .65493 L closepath p F P
0 g
s
.856 .881 .855 r
.80628 .72854 m .80622 .7286 L .80339 .72579 L p F P
0 g
s
.856 .881 .855 r
.80339 .72579 m .80442 .72479 L .80628 .72854 L p F P
0 g
s
.884 .887 .83 r
.80628 .72854 m .80442 .72479 L .81184 .71648 L p F P
0 g
s
.799 .856 .893 r
.80622 .7286 m .80339 .72579 L p .79046 .73495 L F P
0 g
s
.183 .526 .921 r
.68969 .71046 m .6995 .71345 L .69641 .70984 L p F P
0 g
s
.183 .526 .921 r
.69641 .70984 m .68682 .7069 L .68969 .71046 L p F P
0 g
s
.204 .54 .927 r
.68288 .70577 m .68682 .7069 L .68969 .71046 L p F P
0 g
s
.317 .604 .949 r
.70448 .71941 m .70294 .71718 L p .7189 .72315 L F P
0 g
s
.326 .608 .95 r
.70448 .71941 m .70258 .71712 L .70294 .71718 L closepath p F P
0 g
s
.993 .764 .395 r
.8183 .67068 m .82032 .67448 L .81984 .68078 L p F P
0 g
s
.966 .696 .269 r
.81808 .66466 m .81808 .66461 L p .82032 .67448 L F P
0 g
s
.966 .696 .269 r
.82032 .67448 m .8183 .67068 L .81808 .66466 L p F P
0 g
s
.892 .544 .06 r
.81505 .65493 m .81454 .65277 L .81154 .64566 L p F P
0 g
s
.929 .618 .153 r
.81808 .66461 m .81807 .66456 L .81808 .6646 L closepath p F P
0 g
s
.968 .692 .271 r
.81808 .66466 m .81808 .6646 L .81808 .66461 L closepath p F P
0 g
s
.973 .692 .287 r
.81808 .6646 m .81587 .66083 L p .8175 .66927 L F P
0 g
s
.973 .692 .287 r
.8175 .66927 m .81808 .66466 L .81808 .6646 L p F P
0 g
s
.934 .621 .164 r
.81505 .65493 m .81587 .66083 L .81808 .6646 L p F P
0 g
s
.971 .696 .282 r
.8183 .67068 m .8175 .66927 L .81808 .66466 L closepath p F P
0 g
s
.521 .718 .962 r
.74668 .73442 m .74173 .73489 L .73871 .73122 L p F P
0 g
s
.192 .539 .926 r
.68682 .7069 m .68288 .70577 L .67977 .70222 L p F P
0 g
s
.992 .853 .6 r
.81856 .68732 m .8205 .69112 L .81833 .69792 L p F P
0 g
s
1 .818 .501 r
.8205 .69112 m .81856 .68732 L .81984 .68078 L p F P
0 g
s
.95 .886 .734 r
.81702 .70881 m .81587 .71086 L .81311 .70855 L p F P
0 g
s
.95 .886 .734 r
.81311 .70855 m .81512 .70504 L .81702 .70881 L p F P
0 g
s
.973 .876 .677 r
.81702 .70881 m .81512 .70504 L .81833 .69792 L p F P
0 g
s
.303 .596 .947 r
.72144 .72676 m .72221 .7269 L .71916 .7232 L p F P
0 g
s
.303 .596 .947 r
.71916 .7232 m .7189 .72315 L .72144 .72676 L p F P
0 g
s
.943 .626 .185 r
.81274 .65118 m .81505 .65493 L .81587 .66083 L p F P
0 g
s
.892 .544 .06 r
.81141 .64544 m .81274 .65118 L .81505 .65493 L p F P
0 g
s
.892 .544 .06 r
.81154 .64566 m .81141 .64544 L p .81505 .65493 L F P
0 g
s
.83 .455 0 r
.81154 .64566 m .81136 .64532 L .81141 .64544 L closepath p F P
0 g
s
.416 .665 .963 r
.72221 .7269 m .73569 .72757 L .73871 .73122 L p F P
0 g
s
.41 .664 .964 r
.73569 .72757 m .72221 .7269 L .71916 .7232 L p F P
0 g
s
.321 .61 .952 r
.70294 .71718 m .70258 .71712 L .6995 .71345 L p F P
0 g
s
.841 .462 0 r
.81141 .64544 m .81136 .64532 L .80833 .63973 L p F P
0 g
s
.923 .899 .785 r
.81184 .71648 m .81587 .71086 L .81311 .70855 L p F P
0 g
s
.594 .139 0 r
.79074 .60924 m .78789 .60554 L .78428 .60058 L p F P
0 g
s
.904 .553 .084 r
.80898 .64169 m .81141 .64544 L .81274 .65118 L p F P
0 g
s
.841 .462 0 r
.80833 .63973 m .80898 .64169 L .81141 .64544 L p F P
0 g
s
.317 .604 .949 r
.70294 .71718 m .7161 .71953 L p .7189 .72315 L F P
0 g
s
.304 .6 .949 r
.70294 .71718 m .7161 .71953 L .71303 .7159 L p F P
0 g
s
.304 .6 .949 r
.71303 .7159 m .70027 .71358 L .70294 .71718 L p F P
0 g
s
.321 .61 .952 r
.6995 .71345 m .70027 .71358 L .70294 .71718 L p F P
0 g
s
.649 .207 0 r
.79672 .61805 m .79398 .61433 L .79074 .60924 L p F P
0 g
s
.665 .216 0 r
.78789 .60554 m .79074 .60924 L .79398 .61433 L p F P
0 g
s
.769 .849 .911 r
.79046 .73495 m .79046 .73494 L .79046 .73495 L closepath p F P
0 g
s
.799 .856 .893 r
.80339 .72579 m .79046 .73494 L .79046 .73495 L p F P
0 g
s
.764 .845 .912 r
.79046 .73494 m .79046 .73495 L .78757 .73177 L p F P
0 g
s
.693 .824 .945 r
.77438 .73742 m .78757 .73177 L .79046 .73495 L p F P
0 g
s
.764 .845 .912 r
.78757 .73177 m .78839 .73126 L .79046 .73494 L p F P
0 g
s
.794 .87 .904 r
.80055 .72289 m .78839 .73126 L .79046 .73494 L p F P
0 g
s
.794 .87 .904 r
.79046 .73494 m .80339 .72579 L .80055 .72289 L p F P
0 g
s
.842 .458 0 r
.80709 .63614 m .80833 .63973 L .80533 .63452 L p F P
0 g
s
.842 .458 0 r
.80533 .63452 m .8046 .63239 L .80709 .63614 L p F P
0 g
s
.766 .359 0 r
.80709 .63614 m .8046 .63239 L .80218 .62701 L p F P
0 g
s
.707 .28 0 r
.80218 .62701 m .79957 .62328 L .79672 .61805 L p F P
0 g
s
.722 .289 0 r
.79398 .61433 m .79672 .61805 L .79957 .62328 L p F P
0 g
s
.779 .367 0 r
.79957 .62328 m .80218 .62701 L .8046 .63239 L p F P
0 g
s
.603 .774 .962 r
.75812 .73724 m .77144 .73402 L .77438 .73742 L p F P
0 g
s
.598 .771 .963 r
.77144 .73402 m .75812 .73724 L .75514 .73369 L p F P
0 g
s
1 .815 .509 r
.81782 .67699 m .81984 .68078 L .81856 .68732 L p F P
0 g
s
.993 .764 .395 r
.81984 .68078 m .81782 .67699 L .8183 .67068 L p F P
0 g
s
.88 .883 .831 r
.81006 .71269 m .81184 .71648 L .80442 .72479 L p F P
0 g
s
.923 .899 .785 r
.81311 .70855 m .81006 .71269 L .81184 .71648 L p F P
0 g
s
.509 .715 .965 r
.74668 .73442 m .75514 .73369 L .75215 .73012 L p F P
0 g
s
.509 .715 .965 r
.75215 .73012 m .74458 .73072 L .74668 .73442 L p F P
0 g
s
.521 .718 .962 r
.73871 .73122 m .74458 .73072 L .74668 .73442 L p F P
0 g
s
.687 .819 .946 r
.78757 .73177 m .77438 .73742 L .77144 .73402 L p F P
0 g
s
.971 .872 .681 r
.81637 .69414 m .81833 .69792 L .81512 .70504 L p F P
0 g
s
.992 .853 .6 r
.81833 .69792 m .81637 .69414 L .81856 .68732 L p F P
0 g
s
.172 .526 .92 r
.68682 .7069 m .69641 .70984 L .69331 .70629 L p F P
0 g
s
.172 .526 .92 r
.69331 .70629 m .68379 .70337 L .68682 .7069 L p F P
0 g
s
.192 .539 .926 r
.67977 .70222 m .68379 .70337 L .68682 .7069 L p F P
0 g
s
.851 .876 .858 r
.80442 .72479 m .80339 .72579 L .80055 .72289 L p F P
0 g
s
.851 .876 .858 r
.80055 .72289 m .80248 .72106 L .80442 .72479 L p F P
0 g
s
.88 .883 .831 r
.80442 .72479 m .80248 .72106 L .81006 .71269 L p F P
0 g
s
.995 .764 .409 r
.8175 .66927 m .8183 .67068 L .81782 .67699 L p F P
0 g
s
.514 .717 .964 r
.74458 .73072 m .73871 .73122 L .73569 .72757 L p F P
0 g
s
.853 .471 0 r
.80898 .64169 m .80833 .63973 L .80533 .63452 L p F P
0 g
s
.973 .692 .287 r
.81587 .66083 m .81611 .66691 L .8175 .66927 L p F P
0 g
s
.976 .694 .298 r
.81355 .65708 m .81587 .66083 L .81611 .66691 L p F P
0 g
s
.943 .626 .185 r
.81587 .66083 m .81355 .65708 L .81274 .65118 L p F P
0 g
s
.99 .849 .605 r
.81652 .68354 m .81856 .68732 L .81637 .69414 L p F P
0 g
s
1 .815 .509 r
.81856 .68732 m .81652 .68354 L .81782 .67699 L p F P
0 g
s
.993 .75 .391 r
.81595 .6699 m .81611 .66691 L .8175 .66927 L closepath p F P
0 g
s
.995 .764 .409 r
.81595 .6699 m .8175 .66927 L p .81782 .67699 L F P
0 g
s
.299 .597 .948 r
.71916 .7232 m .7189 .72315 L .71715 .72079 L closepath p F P
0 g
s
.317 .604 .949 r
.7161 .71953 m .71715 .72079 L .7189 .72315 L p F P
0 g
s
.948 .628 .198 r
.81031 .64743 m .81274 .65118 L .81355 .65708 L p F P
0 g
s
.904 .553 .084 r
.81274 .65118 m .81031 .64743 L .80898 .64169 L p F P
0 g
s
.946 .881 .739 r
.81512 .70504 m .81311 .70855 L .81031 .70606 L p F P
0 g
s
.946 .881 .739 r
.81031 .70606 m .81312 .70128 L .81512 .70504 L p F P
0 g
s
.971 .872 .681 r
.81512 .70504 m .81312 .70128 L .81637 .69414 L p F P
0 g
s
.41 .664 .964 r
.71916 .7232 m .73266 .72393 L .73569 .72757 L p F P
0 g
s
.427 .671 .964 r
.72962 .72032 m .73266 .72393 L .71916 .7232 L p F P
0 g
s
.427 .671 .964 r
.7163 .71954 m .72962 .72032 L p .71916 .7232 L F P
0 g
s
.427 .671 .964 r
.71916 .7232 m .71715 .72079 L .7163 .71954 L p F P
0 g
s
.311 .609 .953 r
.70027 .71358 m .6995 .71345 L .69641 .70984 L p F P
0 g
s
.853 .471 0 r
.80533 .63452 m .80645 .63796 L .80898 .64169 L p F P
0 g
s
.911 .556 .099 r
.80645 .63796 m .80898 .64169 L .81031 .64743 L p F P
0 g
s
.295 .6 .95 r
.70027 .71358 m .71303 .7159 L .70996 .71231 L p F P
0 g
s
.295 .6 .95 r
.70996 .71231 m .69743 .71001 L .70027 .71358 L p F P
0 g
s
.311 .609 .953 r
.69641 .70984 m .69743 .71001 L .70027 .71358 L p F P
0 g
s
.665 .216 0 r
.79398 .61433 m .79113 .61063 L .78789 .60554 L p F P
0 g
s
.759 .842 .914 r
.78839 .73126 m .78757 .73177 L .78466 .72853 L p F P
0 g
s
.687 .819 .946 r
.77144 .73402 m .78466 .72853 L .78757 .73177 L p F P
0 g
s
.854 .466 0 r
.8046 .63239 m .80533 .63452 L .80234 .62973 L p F P
0 g
s
.854 .466 0 r
.80234 .62973 m .80198 .62866 L .8046 .63239 L p F P
0 g
s
.779 .367 0 r
.8046 .63239 m .80198 .62866 L .79957 .62328 L p F P
0 g
s
.598 .771 .963 r
.75514 .73369 m .76849 .73059 L .77144 .73402 L p F P
0 g
s
.593 .768 .963 r
.76849 .73059 m .75514 .73369 L .75215 .73012 L p F P
0 g
s
.722 .289 0 r
.79957 .62328 m .79683 .61957 L .79398 .61433 L p F P
0 g
s
.736 .298 0 r
.79113 .61063 m .79398 .61433 L .79683 .61957 L p F P
0 g
s
.917 .892 .791 r
.81006 .71269 m .81311 .70855 L .81031 .70606 L p F P
0 g
s
.759 .842 .914 r
.78466 .72853 m .78625 .72757 L .78839 .73126 L p F P
0 g
s
.788 .863 .905 r
.79769 .7199 m .78625 .72757 L .78839 .73126 L p F P
0 g
s
.788 .863 .905 r
.78839 .73126 m .80055 .72289 L .79769 .7199 L p F P
0 g
s
.792 .375 0 r
.79683 .61957 m .79957 .62328 L .80198 .62866 L p F P
0 g
s
.999 .812 .516 r
.81567 .67321 m .81782 .67699 L .81652 .68354 L p F P
0 g
s
.995 .764 .409 r
.81782 .67699 m .81567 .67321 L .81595 .6699 L p F P
0 g
s
.682 .815 .947 r
.78466 .72853 m .77144 .73402 L .76849 .73059 L p F P
0 g
s
.502 .713 .966 r
.74458 .73072 m .75215 .73012 L .74915 .72656 L p F P
0 g
s
.502 .713 .966 r
.74915 .72656 m .7423 .72705 L .74458 .73072 L p F P
0 g
s
.514 .717 .964 r
.73569 .72757 m .7423 .72705 L .74458 .73072 L p F P
0 g
s
.877 .879 .833 r
.80817 .70891 m .81006 .71269 L .80248 .72106 L p F P
0 g
s
.917 .892 .791 r
.81031 .70606 m .80817 .70891 L .81006 .71269 L p F P
0 g
s
.968 .867 .684 r
.8143 .69038 m .81637 .69414 L .81312 .70128 L p F P
0 g
s
.99 .849 .605 r
.81637 .69414 m .8143 .69038 L .81652 .68354 L p F P
0 g
s
.864 .478 0 r
.80645 .63796 m .80533 .63452 L .80234 .62973 L p F P
0 g
s
.847 .872 .86 r
.80248 .72106 m .80055 .72289 L .79769 .7199 L p F P
0 g
s
.847 .872 .86 r
.79769 .7199 m .80044 .71733 L .80248 .72106 L p F P
0 g
s
.877 .879 .833 r
.80248 .72106 m .80044 .71733 L .80817 .70891 L p F P
0 g
s
.993 .747 .402 r
.81611 .66691 m .81379 .66317 L p .81373 .66998 L F P
0 g
s
.993 .747 .402 r
.81373 .66998 m .81595 .6699 L .81611 .66691 L p F P
0 g
s
.976 .694 .298 r
.81611 .66691 m .81379 .66317 L .81355 .65708 L p F P
0 g
s
.417 .666 .963 r
.71715 .72079 m .7161 .71953 L .7163 .71954 L closepath p F P
0 g
s
.507 .715 .965 r
.7423 .72705 m .73569 .72757 L .73266 .72393 L p F P
0 g
s
.978 .694 .309 r
.81112 .65334 m .81355 .65708 L .81379 .66317 L p F P
0 g
s
.948 .628 .198 r
.81355 .65708 m .81112 .65334 L .81031 .64743 L p F P
0 g
s
.995 .762 .418 r
.81567 .67321 m .81373 .66998 L .81595 .6699 L closepath p F P
0 g
s
.414 .667 .965 r
.7163 .71954 m .7161 .71953 L .71303 .7159 L p F P
0 g
s
.988 .844 .61 r
.81437 .67978 m .81652 .68354 L .8143 .69038 L p F P
0 g
s
.999 .812 .516 r
.81652 .68354 m .81437 .67978 L .81567 .67321 L p F P
0 g
s
.402 .661 .964 r
.7163 .71954 m .72962 .72032 L .72657 .71672 L p F P
0 g
s
.402 .661 .964 r
.72657 .71672 m .71365 .71593 L .7163 .71954 L p F P
0 g
s
.414 .667 .965 r
.71303 .7159 m .71365 .71593 L .7163 .71954 L p F P
0 g
s
.303 .61 .954 r
.69743 .71001 m .69641 .70984 L .69331 .70629 L p F P
0 g
s
.952 .629 .211 r
.80778 .6437 m .81031 .64743 L .81112 .65334 L p F P
0 g
s
.911 .556 .099 r
.81031 .64743 m .80778 .6437 L .80645 .63796 L p F P
0 g
s
.941 .877 .743 r
.81312 .70128 m .81031 .70606 L .8075 .70342 L p F P
0 g
s
.941 .877 .743 r
.8075 .70342 m .81101 .69754 L .81312 .70128 L p F P
0 g
s
.968 .867 .684 r
.81312 .70128 m .81101 .69754 L .8143 .69038 L p F P
0 g
s
.864 .478 0 r
.80234 .62973 m .80381 .63424 L .80645 .63796 L p F P
0 g
s
.917 .559 .113 r
.80381 .63424 m .80645 .63796 L .80778 .6437 L p F P
0 g
s
.288 .6 .951 r
.69743 .71001 m .70996 .71231 L .70687 .70877 L p F P
0 g
s
.288 .6 .951 r
.70687 .70877 m .69441 .70648 L .69743 .71001 L p F P
0 g
s
.303 .61 .954 r
.69331 .70629 m .69441 .70648 L .69743 .71001 L p F P
0 g
s
.593 .768 .963 r
.75215 .73012 m .76553 .72713 L .76849 .73059 L p F P
0 g
s
.588 .765 .963 r
.76553 .72713 m .75215 .73012 L .74915 .72656 L p F P
0 g
s
.865 .472 0 r
.80198 .62866 m .80234 .62973 L .79939 .62538 L p F P
0 g
s
.865 .472 0 r
.79939 .62538 m .79925 .62495 L .80198 .62866 L p F P
0 g
s
.792 .375 0 r
.80198 .62866 m .79925 .62495 L .79683 .61957 L p F P
0 g
s
.736 .298 0 r
.79683 .61957 m .79397 .61587 L .79113 .61063 L p F P
0 g
s
.755 .839 .915 r
.78625 .72757 m .78466 .72853 L .78174 .72525 L p F P
0 g
s
.682 .815 .947 r
.76849 .73059 m .78174 .72525 L .78466 .72853 L p F P
0 g
s
.804 .382 0 r
.79397 .61587 m .79683 .61957 L .79925 .62495 L p F P
0 g
s
.755 .839 .915 r
.78174 .72525 m .78402 .7239 L .78625 .72757 L p F P
0 g
s
.782 .858 .907 r
.79481 .71681 m .78402 .7239 L .78625 .72757 L p F P
0 g
s
.782 .858 .907 r
.78625 .72757 m .79769 .7199 L .79481 .71681 L p F P
0 g
s
.911 .886 .795 r
.80817 .70891 m .81031 .70606 L .8075 .70342 L p F P
0 g
s
.998 .808 .523 r
.81373 .66998 m .81567 .67321 L .81437 .67978 L p F P
0 g
s
.677 .811 .947 r
.78174 .72525 m .76849 .73059 L .76553 .72713 L p F P
0 g
s
.874 .485 .015 r
.80381 .63424 m .80234 .62973 L .79939 .62538 L p F P
0 g
s
.497 .713 .967 r
.7423 .72705 m .74915 .72656 L .74614 .723 L p F P
0 g
s
.497 .713 .967 r
.74614 .723 m .73985 .72341 L .7423 .72705 L p F P
0 g
s
.507 .715 .965 r
.73266 .72393 m .73985 .72341 L .7423 .72705 L p F P
0 g
s
.873 .875 .834 r
.80617 .70514 m .80817 .70891 L .80044 .71733 L p F P
0 g
s
.911 .886 .795 r
.8075 .70342 m .80617 .70514 L .80817 .70891 L p F P
0 g
s
.966 .863 .687 r
.81212 .68663 m .8143 .69038 L .81101 .69754 L p F P
0 g
s
.988 .844 .61 r
.8143 .69038 m .81212 .68663 L .81437 .67978 L p F P
0 g
s
.843 .868 .862 r
.80044 .71733 m .79769 .7199 L .79481 .71681 L p F P
0 g
s
.843 .868 .862 r
.79481 .71681 m .7983 .71361 L .80044 .71733 L p F P
0 g
s
.873 .875 .834 r
.80044 .71733 m .7983 .71361 L .80617 .70514 L p F P
0 g
s
.993 .747 .402 r
.81379 .66317 m .81341 .66946 L .81373 .66998 L p F P
0 g
s
.994 .748 .412 r
.81136 .65944 m .81379 .66317 L .81341 .66946 L p F P
0 g
s
.978 .694 .309 r
.81379 .66317 m .81136 .65944 L .81112 .65334 L p F P
0 g
s
.502 .715 .967 r
.73985 .72341 m .73266 .72393 L .72962 .72032 L p F P
0 g
s
.98 .693 .319 r
.80859 .64962 m .81112 .65334 L .81136 .65944 L p F P
0 g
s
.952 .629 .211 r
.81112 .65334 m .80859 .64962 L .80778 .6437 L p F P
0 g
s
.408 .668 .967 r
.71365 .71593 m .71303 .7159 L .70996 .71231 L p F P
0 g
s
.397 .661 .966 r
.71365 .71593 m .72657 .71672 L .72351 .71315 L p F P
0 g
s
.397 .661 .966 r
.72351 .71315 m .71082 .71236 L .71365 .71593 L p F P
0 g
s
.408 .668 .967 r
.70996 .71231 m .71082 .71236 L .71365 .71593 L p F P
0 g
s
.955 .63 .224 r
.80514 .63999 m .80778 .6437 L .80859 .64962 L p F P
0 g
s
.917 .559 .113 r
.80778 .6437 m .80514 .63999 L .80381 .63424 L p F P
0 g
s
.986 .839 .614 r
.8121 .67603 m .81437 .67978 L .81212 .68663 L p F P
0 g
s
.998 .808 .523 r
.81335 .66979 m .81373 .66998 L p .81437 .67978 L F P
0 g
s
.998 .808 .523 r
.81437 .67978 m .8121 .67603 L .81335 .66979 L p F P
0 g
s
.938 .872 .747 r
.81101 .69754 m .8075 .70342 L .80466 .70062 L p F P
0 g
s
.938 .872 .747 r
.80466 .70062 m .80879 .6938 L .81101 .69754 L p F P
0 g
s
.966 .863 .687 r
.81101 .69754 m .80879 .6938 L .81212 .68663 L p F P
0 g
s
.922 .562 .128 r
.80106 .63054 m .80381 .63424 L .80514 .63999 L p F P
0 g
s
.874 .485 .015 r
.79939 .62538 m .80106 .63054 L .80381 .63424 L p F P
0 g
s
.588 .765 .963 r
.74915 .72656 m .76256 .72366 L .76553 .72713 L p F P
0 g
s
.585 .763 .964 r
.76256 .72366 m .74915 .72656 L .74614 .723 L p F P
0 g
s
.873 .478 .015 r
.79925 .62495 m .79939 .62538 L .79646 .62147 L p F P
0 g
s
.873 .478 .015 r
.79646 .62147 m .79639 .62126 L .79925 .62495 L p F P
0 g
s
.804 .382 0 r
.79925 .62495 m .79639 .62126 L .79397 .61587 L p F P
0 g
s
.752 .836 .916 r
.78402 .7239 m .78174 .72525 L .77881 .72191 L p F P
0 g
s
.677 .811 .947 r
.76553 .72713 m .77881 .72191 L .78174 .72525 L p F P
0 g
s
.998 .79 .49 r
.81335 .66979 m .81341 .66946 L .81373 .66998 L closepath p F P
0 g
s
.882 .49 .033 r
.80106 .63054 m .79939 .62538 L .79646 .62147 L p F P
0 g
s
.752 .836 .916 r
.77881 .72191 m .7817 .72023 L .78402 .7239 L p F P
0 g
s
.777 .852 .907 r
.79191 .71365 m .7817 .72023 L .78402 .7239 L p F P
0 g
s
.777 .852 .907 r
.78402 .7239 m .79481 .71681 L .79191 .71365 L p F P
0 g
s
.673 .807 .947 r
.77881 .72191 m .76553 .72713 L .76256 .72366 L p F P
0 g
s
.997 .787 .499 r
.81341 .66946 m .81335 .66979 L .81061 .66795 L p F P
0 g
s
.997 .787 .499 r
.81061 .66795 m .81097 .66573 L .81341 .66946 L p F P
0 g
s
.994 .748 .412 r
.81341 .66946 m .81097 .66573 L .81136 .65944 L p F P
0 g
s
.997 .804 .527 r
.8121 .67603 m .81335 .66979 L .81061 .66795 L p F P
0 g
s
.906 .88 .798 r
.80617 .70514 m .8075 .70342 L .80466 .70062 L p F P
0 g
s
.492 .712 .969 r
.73985 .72341 m .74614 .723 L .74312 .71943 L p F P
0 g
s
.492 .712 .969 r
.74312 .71943 m .73725 .71979 L .73985 .72341 L p F P
0 g
s
.502 .715 .967 r
.72962 .72032 m .73725 .71979 L .73985 .72341 L p F P
0 g
s
.87 .871 .835 r
.80406 .70139 m .80617 .70514 L .7983 .71361 L p F P
0 g
s
.906 .88 .798 r
.80466 .70062 m .80406 .70139 L .80617 .70514 L p F P
0 g
s
.963 .858 .689 r
.80983 .68289 m .81212 .68663 L .80879 .6938 L p F P
0 g
s
.986 .839 .614 r
.81212 .68663 m .80983 .68289 L .8121 .67603 L p F P
0 g
s
.993 .745 .42 r
.80882 .65572 m .81136 .65944 L .81097 .66573 L p F P
0 g
s
.98 .693 .319 r
.81136 .65944 m .80882 .65572 L .80859 .64962 L p F P
0 g
s
.497 .715 .968 r
.73725 .71979 m .72962 .72032 L .72657 .71672 L p F P
0 g
s
.839 .864 .863 r
.7983 .71361 m .79481 .71681 L .79191 .71365 L p F P
0 g
s
.839 .864 .863 r
.79191 .71365 m .79607 .70991 L .7983 .71361 L p F P
0 g
s
.87 .871 .835 r
.7983 .71361 m .79607 .70991 L .80406 .70139 L p F P
0 g
s
.98 .691 .329 r
.80594 .64591 m .80859 .64962 L .80882 .65572 L p F P
0 g
s
.955 .63 .224 r
.80859 .64962 m .80594 .64591 L .80514 .63999 L p F P
0 g
s
.403 .669 .968 r
.71082 .71236 m .70996 .71231 L .70687 .70877 L p F P
0 g
s
.403 .669 .968 r
.70687 .70877 m .70782 .70882 L .71082 .71236 L p F P
0 g
s
.392 .663 .967 r
.71082 .71236 m .72351 .71315 L .72044 .70961 L p F P
0 g
s
.392 .663 .967 r
.72044 .70961 m .70782 .70882 L .71082 .71236 L p F P
0 g
s
.958 .63 .236 r
.80239 .63629 m .80514 .63999 L .80594 .64591 L p F P
0 g
s
.922 .562 .128 r
.80514 .63999 m .80239 .63629 L .80106 .63054 L p F P
0 g
s
.983 .834 .618 r
.80971 .6723 m .8121 .67603 L .80983 .68289 L p F P
0 g
s
.997 .804 .527 r
.81061 .66795 m .80971 .6723 L .8121 .67603 L p F P
0 g
s
.927 .564 .141 r
.7982 .62685 m .80106 .63054 L .80239 .63629 L p F P
0 g
s
.882 .49 .033 r
.79646 .62147 m .7982 .62685 L .80106 .63054 L p F P
0 g
s
.585 .763 .964 r
.74614 .723 m .75957 .72016 L .76256 .72366 L p F P
0 g
s
.582 .762 .964 r
.75957 .72016 m .74614 .723 L .74312 .71943 L p F P
0 g
s
.934 .863 .746 r
.80879 .6938 m .80647 .69008 L p .80191 .6978 L F P
0 g
s
.934 .863 .746 r
.80191 .6978 m .80466 .70062 L .80879 .6938 L p F P
0 g
s
.963 .858 .689 r
.80879 .6938 m .80647 .69008 L .80983 .68289 L p F P
0 g
s
.748 .833 .916 r
.7817 .72023 m .77881 .72191 L .77586 .71854 L p F P
0 g
s
.673 .807 .947 r
.76256 .72366 m .77586 .71854 L .77881 .72191 L p F P
0 g
s
.67 .805 .947 r
.77586 .71854 m .76256 .72366 L .75957 .72016 L p F P
0 g
s
.748 .833 .916 r
.77586 .71854 m .77929 .71657 L .7817 .72023 L p F P
0 g
s
.772 .847 .908 r
.789 .71042 m .77929 .71657 L .7817 .72023 L p F P
0 g
s
.772 .847 .908 r
.7817 .72023 m .79191 .71365 L .789 .71042 L p F P
0 g
s
.995 .784 .506 r
.81097 .66573 m .81061 .66795 L .80782 .66567 L p F P
0 g
s
.995 .784 .506 r
.80782 .66567 m .80842 .66202 L .81097 .66573 L p F P
0 g
s
.993 .745 .42 r
.81097 .66573 m .80842 .66202 L .80882 .65572 L p F P
0 g
s
.488 .712 .97 r
.73725 .71979 m .74312 .71943 L .74009 .71588 L p F P
0 g
s
.488 .712 .97 r
.74009 .71588 m .73452 .7162 L .73725 .71979 L p F P
0 g
s
.497 .715 .968 r
.72657 .71672 m .73452 .7162 L .73725 .71979 L p F P
0 g
s
.901 .874 .801 r
.80406 .70139 m .80191 .6978 L .80466 .70062 L closepath p F P
0 g
s
.867 .866 .835 r
.80191 .6978 m .80406 .70139 L .79607 .70991 L p F P
0 g
s
.493 .715 .97 r
.73452 .7162 m .72657 .71672 L .72351 .71315 L p F P
0 g
s
.994 .8 .536 r
.80971 .6723 m .81061 .66795 L .80782 .66567 L p F P
0 g
s
.96 .852 .691 r
.80743 .67917 m .80983 .68289 L .80647 .69008 L p F P
0 g
s
.983 .834 .618 r
.80983 .68289 m .80743 .67917 L .80971 .6723 L p F P
0 g
s
.993 .742 .427 r
.80617 .65202 m .80882 .65572 L .80842 .66202 L p F P
0 g
s
.98 .691 .329 r
.80882 .65572 m .80617 .65202 L .80594 .64591 L p F P
0 g
s
.835 .86 .863 r
.79607 .70991 m .79191 .71365 L .789 .71042 L p F P
0 g
s
.835 .86 .863 r
.789 .71042 m .79372 .70622 L .79607 .70991 L p F P
0 g
s
.867 .866 .835 r
.8018 .69768 m .80191 .6978 L p .79607 .70991 L F P
0 g
s
.867 .866 .835 r
.79607 .70991 m .79372 .70622 L .8018 .69768 L p F P
0 g
s
.981 .69 .339 r
.80319 .64221 m .80594 .64591 L .80617 .65202 L p F P
0 g
s
.958 .63 .236 r
.80594 .64591 m .80319 .64221 L .80239 .63629 L p F P
0 g
s
.96 .63 .247 r
.79952 .63261 m .80239 .63629 L .80319 .64221 L p F P
0 g
s
.927 .564 .141 r
.80239 .63629 m .79952 .63261 L .7982 .62685 L p F P
0 g
s
.98 .829 .621 r
.8072 .66858 m .80971 .6723 L .80743 .67917 L p F P
0 g
s
.994 .8 .536 r
.80782 .66567 m .8072 .66858 L .80971 .6723 L p F P
0 g
s
.582 .762 .964 r
.74312 .71943 m .75657 .71665 L .75957 .72016 L p F P
0 g
s
.58 .761 .964 r
.75657 .71665 m .74312 .71943 L .74009 .71588 L p F P
0 g
s
.934 .863 .746 r
.80647 .69008 m .80182 .69766 L .80191 .6978 L p F P
0 g
s
.93 .86 .75 r
.80403 .68638 m .80647 .69008 L .80182 .69766 L p F P
0 g
s
.96 .852 .691 r
.80647 .69008 m .80403 .68638 L .80743 .67917 L p F P
0 g
s
.746 .831 .917 r
.77929 .71657 m .77586 .71854 L .77291 .71512 L p F P
0 g
s
.67 .805 .947 r
.75957 .72016 m .77291 .71512 L .77586 .71854 L p F P
0 g
s
.668 .802 .947 r
.77291 .71512 m .75957 .72016 L .75657 .71665 L p F P
0 g
s
.746 .831 .917 r
.77291 .71512 m .77677 .71293 L .77929 .71657 L p F P
0 g
s
.768 .843 .908 r
.78607 .70711 m .77677 .71293 L .77929 .71657 L p F P
0 g
s
.768 .843 .908 r
.77929 .71657 m .789 .71042 L .78607 .70711 L p F P
0 g
s
.993 .781 .513 r
.80842 .66202 m .80782 .66567 L .80498 .66298 L p F P
0 g
s
.993 .781 .513 r
.80498 .66298 m .80576 .65833 L .80842 .66202 L p F P
0 g
s
.993 .742 .427 r
.80842 .66202 m .80576 .65833 L .80617 .65202 L p F P
0 g
s
.485 .712 .971 r
.73452 .7162 m .74009 .71588 L .73705 .71232 L p F P
0 g
s
.485 .712 .971 r
.73705 .71232 m .73165 .71263 L .73452 .7162 L p F P
0 g
s
.493 .715 .97 r
.72351 .71315 m .73165 .71263 L .73452 .7162 L p F P
0 g
s
.91 .868 .784 r
.8018 .69768 m .80182 .69766 L .80191 .6978 L closepath p F P
0 g
s
.907 .863 .785 r
.80182 .69766 m .8018 .69768 L .79891 .69456 L p F P
0 g
s
.907 .863 .785 r
.79891 .69456 m .79934 .69397 L .80182 .69766 L p F P
0 g
s
.93 .86 .75 r
.80182 .69766 m .79934 .69397 L .80403 .68638 L p F P
0 g
s
.868 .867 .835 r
.79372 .70622 m .8018 .69768 L .79891 .69456 L p F P
0 g
s
.49 .716 .971 r
.73165 .71263 m .72351 .71315 L .72044 .70961 L p F P
0 g
s
.991 .739 .434 r
.80341 .64833 m .80617 .65202 L .80576 .65833 L p F P
0 g
s
.981 .69 .339 r
.80617 .65202 m .80341 .64833 L .80319 .64221 L p F P
0 g
s
.957 .847 .693 r
.8049 .67547 m .80743 .67917 L .80403 .68638 L p F P
0 g
s
.98 .829 .621 r
.80743 .67917 m .8049 .67547 L .8072 .66858 L p F P
0 g
s
.833 .857 .864 r
.79372 .70622 m .789 .71042 L .78607 .70711 L p F P
0 g
s
.833 .857 .864 r
.78607 .70711 m .79126 .70254 L .79372 .70622 L p F P
0 g
s
.868 .867 .835 r
.79891 .69456 m .79126 .70254 L .79372 .70622 L p F P
0 g
s
.991 .796 .544 r
.8072 .66858 m .80782 .66567 L .80498 .66298 L p F P
0 g
s
.981 .688 .348 r
.80032 .63854 m .80319 .64221 L .80341 .64833 L p F P
0 g
s
.96 .63 .247 r
.80319 .64221 m .80032 .63854 L .79952 .63261 L p F P
0 g
s
.58 .761 .964 r
.74009 .71588 m .75356 .71312 L .75657 .71665 L p F P
0 g
s
.579 .76 .964 r
.75356 .71312 m .74009 .71588 L .73705 .71232 L p F P
0 g
s
.977 .823 .624 r
.80457 .66489 m .8072 .66858 L .8049 .67547 L p F P
0 g
s
.991 .796 .544 r
.80498 .66298 m .80457 .66489 L .8072 .66858 L p F P
0 g
s
.928 .856 .75 r
.80148 .68269 m .80403 .68638 L .79934 .69397 L p F P
0 g
s
.957 .847 .693 r
.80403 .68638 m .80148 .68269 L .8049 .67547 L p F P
0 g
s
.744 .828 .917 r
.77677 .71293 m .77291 .71512 L .76993 .71167 L p F P
0 g
s
.668 .802 .947 r
.75657 .71665 m .76993 .71167 L .77291 .71512 L p F P
0 g
s
.666 .8 .946 r
.76993 .71167 m .75657 .71665 L .75356 .71312 L p F P
0 g
s
.744 .828 .917 r
.76993 .71167 m .77415 .70929 L .77677 .71293 L p F P
0 g
s
.765 .839 .908 r
.78313 .70374 m .77415 .70929 L .77677 .71293 L p F P
0 g
s
.765 .839 .908 r
.77677 .71293 m .78607 .70711 L .78313 .70374 L p F P
0 g
s
.991 .777 .518 r
.80576 .65833 m .80498 .66298 L .80211 .6599 L p F P
0 g
s
.991 .777 .518 r
.80211 .6599 m .803 .65465 L .80576 .65833 L p F P
0 g
s
.991 .739 .434 r
.80576 .65833 m .803 .65465 L .80341 .64833 L p F P
0 g
s
.484 .713 .972 r
.73165 .71263 m .73705 .71232 L .734 .70877 L p F P
0 g
s
.484 .713 .972 r
.734 .70877 m .72865 .70908 L .73165 .71263 L p F P
0 g
s
.49 .716 .971 r
.72044 .70961 m .72865 .70908 L .73165 .71263 L p F P
0 g
s
.904 .858 .786 r
.79934 .69397 m .79891 .69456 L .796 .69132 L p F P
0 g
s
.904 .858 .786 r
.796 .69132 m .79675 .6903 L .79934 .69397 L p F P
0 g
s
.928 .856 .75 r
.79934 .69397 m .79675 .6903 L .80148 .68269 L p F P
0 g
s
.864 .862 .836 r
.79126 .70254 m .79891 .69456 L .796 .69132 L p F P
0 g
s
.99 .735 .441 r
.80054 .64466 m .80341 .64833 L .803 .65465 L p F P
0 g
s
.981 .688 .348 r
.80341 .64833 m .80054 .64466 L .80032 .63854 L p F P
0 g
s
.954 .842 .694 r
.80226 .67178 m .8049 .67547 L .80148 .68269 L p F P
0 g
s
.977 .823 .624 r
.8049 .67547 m .80226 .67178 L .80457 .66489 L p F P
0 g
s
.83 .853 .863 r
.79126 .70254 m .78607 .70711 L .78313 .70374 L p F P
0 g
s
.864 .862 .836 r
.796 .69132 m .78869 .69887 L .79126 .70254 L p F P
0 g
s
.83 .853 .863 r
.78313 .70374 m .78869 .69887 L .79126 .70254 L p F P
0 g
s
.988 .791 .551 r
.80457 .66489 m .80498 .66298 L .80211 .6599 L p F P
0 g
s
.579 .76 .964 r
.73705 .71232 m .75054 .70958 L .75356 .71312 L p F P
0 g
s
.579 .76 .965 r
.75054 .70958 m .73705 .71232 L .734 .70877 L p F P
0 g
s
.974 .818 .626 r
.80182 .66121 m .80457 .66489 L .80226 .67178 L p F P
0 g
s
.988 .791 .551 r
.80211 .6599 m .80182 .66121 L .80457 .66489 L p F P
0 g
s
.925 .851 .751 r
.79882 .67902 m .80148 .68269 L .79675 .6903 L p F P
0 g
s
.954 .842 .694 r
.80148 .68269 m .79882 .67902 L .80226 .67178 L p F P
0 g
s
.742 .826 .916 r
.77415 .70929 m .76993 .71167 L .76695 .70818 L p F P
0 g
s
.666 .8 .946 r
.75356 .71312 m .76695 .70818 L .76993 .71167 L p F P
0 g
s
.665 .798 .946 r
.76695 .70818 m .75356 .71312 L .75054 .70958 L p F P
0 g
s
.742 .826 .916 r
.76695 .70818 m .77143 .70567 L .77415 .70929 L p F P
0 g
s
.762 .835 .908 r
.78017 .7003 m .77143 .70567 L .77415 .70929 L p F P
0 g
s
.762 .835 .908 r
.77415 .70929 m .78313 .70374 L .78017 .7003 L p F P
0 g
s
.988 .772 .523 r
.803 .65465 m .80211 .6599 L .79919 .65644 L p F P
0 g
s
.988 .772 .523 r
.79919 .65644 m .80012 .65098 L .803 .65465 L p F P
0 g
s
.99 .735 .441 r
.803 .65465 m .80012 .65098 L .80054 .64466 L p F P
0 g
s
.901 .854 .786 r
.79675 .6903 m .796 .69132 L .79308 .68797 L p F P
0 g
s
.901 .854 .786 r
.79308 .68797 m .79406 .68665 L .79675 .6903 L p F P
0 g
s
.925 .851 .751 r
.79675 .6903 m .79406 .68665 L .79882 .67902 L p F P
0 g
s
.86 .856 .836 r
.78869 .69887 m .796 .69132 L .79308 .68797 L p F P
0 g
s
.951 .836 .695 r
.7995 .66811 m .80226 .67178 L .79882 .67902 L p F P
0 g
s
.974 .818 .626 r
.80226 .67178 m .7995 .66811 L .80182 .66121 L p F P
0 g
s
.828 .849 .863 r
.78869 .69887 m .78313 .70374 L .78017 .7003 L p F P
0 g
s
.828 .849 .863 r
.78017 .7003 m .78601 .69523 L .78869 .69887 L p F P
0 g
s
.86 .856 .836 r
.79308 .68797 m .78601 .69523 L .78869 .69887 L p F P
0 g
s
.985 .786 .555 r
.80182 .66121 m .80211 .6599 L .79919 .65644 L p F P
0 g
s
.579 .76 .965 r
.734 .70877 m .74751 .70603 L .75054 .70958 L p F P
0 g
s
.971 .812 .628 r
.79895 .65755 m .80182 .66121 L .7995 .66811 L p F P
0 g
s
.985 .786 .555 r
.79919 .65644 m .79895 .65755 L .80182 .66121 L p F P
0 g
s
.741 .824 .916 r
.77143 .70567 m .76695 .70818 L .76395 .70465 L p F P
0 g
s
.665 .798 .946 r
.75054 .70958 m .76395 .70465 L .76695 .70818 L p F P
0 g
s
.922 .846 .75 r
.79604 .67536 m .79882 .67902 L .79406 .68665 L p F P
0 g
s
.951 .836 .695 r
.79882 .67902 m .79604 .67536 L .7995 .66811 L p F P
0 g
s
.665 .797 .945 r
.76395 .70465 m .75054 .70958 L .74751 .70603 L p F P
0 g
s
.741 .824 .916 r
.76395 .70465 m .76859 .70207 L .77143 .70567 L p F P
0 g
s
.76 .831 .907 r
.7772 .6968 m .76859 .70207 L .77143 .70567 L p F P
0 g
s
.76 .831 .907 r
.77143 .70567 m .78017 .7003 L .7772 .6968 L p F P
0 g
s
.899 .849 .786 r
.79406 .68665 m .79308 .68797 L .79014 .68451 L p F P
0 g
s
.899 .849 .786 r
.79014 .68451 m .79126 .68301 L .79406 .68665 L p F P
0 g
s
.922 .846 .75 r
.79406 .68665 m .79126 .68301 L .79604 .67536 L p F P
0 g
s
.857 .851 .835 r
.78601 .69523 m .79308 .68797 L .79014 .68451 L p F P
0 g
s
.948 .83 .695 r
.79661 .66446 m .7995 .66811 L .79604 .67536 L p F P
0 g
s
.971 .812 .628 r
.7995 .66811 m .79661 .66446 L .79895 .65755 L p F P
0 g
s
.826 .845 .862 r
.78601 .69523 m .78017 .7003 L .7772 .6968 L p F P
0 g
s
.826 .845 .862 r
.7772 .6968 m .78321 .6916 L .78601 .69523 L p F P
0 g
s
.857 .851 .835 r
.79014 .68451 m .78321 .6916 L .78601 .69523 L p F P
0 g
s
.741 .822 .915 r
.76859 .70207 m .76395 .70465 L .76094 .70109 L p F P
0 g
s
.665 .797 .945 r
.74751 .70603 m .76094 .70109 L .76395 .70465 L p F P
0 g
s
.92 .841 .75 r
.79314 .67172 m .79604 .67536 L .79126 .68301 L p F P
0 g
s
.948 .83 .695 r
.79604 .67536 m .79314 .67172 L .79661 .66446 L p F P
0 g
s
.741 .822 .915 r
.76094 .70109 m .76564 .69848 L .76859 .70207 L p F P
0 g
s
.759 .828 .906 r
.77421 .69324 m .76564 .69848 L .76859 .70207 L p F P
0 g
s
.759 .828 .906 r
.76859 .70207 m .7772 .6968 L .77421 .69324 L p F P
0 g
s
.897 .845 .785 r
.79126 .68301 m .79014 .68451 L .78718 .68095 L p F P
0 g
s
.897 .845 .785 r
.78718 .68095 m .78835 .67938 L .79126 .68301 L p F P
0 g
s
.92 .841 .75 r
.79126 .68301 m .78835 .67938 L .79314 .67172 L p F P
0 g
s
.855 .846 .834 r
.78321 .6916 m .79014 .68451 L .78718 .68095 L p F P
0 g
s
.825 .842 .861 r
.78321 .6916 m .7772 .6968 L .77421 .69324 L p F P
0 g
s
.825 .842 .861 r
.77421 .69324 m .78028 .68798 L .78321 .6916 L p F P
0 g
s
.855 .846 .834 r
.78718 .68095 m .78028 .68798 L .78321 .6916 L p F P
0 g
s
.25 Mabswid
.76525 0 m
.91897 .25046 L
s
.91897 .25046 m
1 .91579 L
s
1 .91579 m
.82344 .69767 L
s
.82344 .69767 m
.76525 0 L
s
.07962 .26912 m
0 .93168 L
s
0 .93168 m
.82344 .69767 L
s
.82344 .69767 m
.76525 0 L
s
.76525 0 m
.07962 .26912 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 634.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900002NR000`400?l00000o`00003ooooonfZh
oookJP;o0000QooonfX00?oooo]Z]OoonfX3o`000003oookJ_l0003ooo]Z08Kooo]Z003ooookJ[?o
oo]Z0_l00004oookJP;o0000Q_oonfX00?oooo]Z/?oonfX3o`0000Kooo]Z00?o0000oookJ_l00000
QOoonfX00?oooo]Z[_oonfX2o`0000Wooo]Z00?o0000oookJ_l00000QOoonfX00?oooo]ZZooonfX3
o`0000_ooo]Z00Co0000oookJ_oonf[o0000Q?oonfX00?oooo]ZZ?oonfX3o`0000kooo]Z00Co0000
oookJ_oonf[o0000Q?oonfX00?oooo]ZY_oonfX2o`0001;ooo]Z00Co0000oookJ_oonf[o0000Pooo
nfX00?oooo]ZXooonfX3o`0001Cooo]Z00Go0000oookJ_oonf[ooo]Zo`000022oookJP00oooonfZQ
oookJP;o00005ooonfX01Ol0003ooo]ZoookJ_oonf[o000008;ooo]Z003ooookJYkooo]Z0ol0000I
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0OooonfX00?oooo]ZW?oonfX2o`00
01cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP1ooookJP00oooonfZIoookJP?o
00007_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z07kooo]Z003ooookJYOooo]Z
0_l0000QoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0OOoonfX00?oooo]ZU?oo
nfX3o`0002?ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP1moookJP00oooonfZA
oookJP?o00009_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z07cooo]Z003ooook
JXoooo]Z0_l0000YoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0O?oonfX00?oo
oo]ZS?oonfX3o`0002_ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP1koookJP00
oooonfZ:oookJP;o0000;_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z07[ooo]Z
003ooookJXOooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0N_oo
nfX00?oooo]ZQOoonfX2o`0003Cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP1i
oookJP00oooonfZ2oookJP?o0000=_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z
07Sooo]Z003ooookJX3ooo]Z0_l0000ioookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oo
nfX0N?oonfX00?oooo]ZOOoonfX3o`00027ooo]Z2?l0000BoookJP03o`000?oonf[ooo]Z00Wooo]Z
00?o0000oookJ_oonfX0MooonfX00?oooo]ZNooonfX2o`0001kooo]Z1_l00002ohj/jP04o`000?mc
WN_oLig[o`0000;oH9;Z0ol0000?oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
MooonfX00?oooo]ZN?oonfX3o`0001gooo]Z0ol00002ojFgiP03o`000?nD[nWo000000CoSZcZ00Co
0000og>MjomcWN_o00000_mPT^X00ol0003o5F7Ho`00000>oookJP03o`000?oonf[ooo]Z00[ooo]Z
00?o0000oookJ_oonfX0M_oonfX00?oooo]ZMOoonfX3o`0001gooo]Z0ol00006ojFgiPko000000?o
5F7Ho`000?oonfX03?oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z07Gooo]Z003o
oookJW?ooo]Z0_l0000NoookJP;o000000?o/[cRo`000?nU]nH01_nU]nH01?l0003oU:oYoiB_jOl0
0003ohj/j@04o`000?mcWN_oLig[o`0000;oH97Y00Co>GSRo`000?l0003o00003?oonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z07Gooo]Z003ooookJW3ooo]Z0ol0000NoookJP;o0000
1?nb_>800ol0003oYKOVojFgiP03o`000003ojFgiOl0003oU:oY00;oU:oY2ol00002oaMRe`03o`00
0?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP1doookJP00oooo
nfY^oookJP;o00007ooonfX2o`0000Oo/[cR0_l00005ojFgi@;o000000?oU:kYo`000?n>ZnT00_n>
ZnT01?l0003oLicZog>Lj_l00002of6@j0Go00002_oonfX00ol0003ooo]ZoookJP0<oookJP03o`00
0?oonf[ooo]Z07Cooo]Z003ooookJV_ooo]Z0ol0000PoookJP03o`000?nl`=go000000;o/[cR0ol0
0002ok:lhP03o`000?nU]nGoYKOU00?o00000_nU]^D01Ol0003oU:kYoiB^jOl0003oSZ_Y00Co0000
00CoLicZo`000?mQT>SoHI3X1Ol00009oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oo
nfX0LooonfX00?oooo]ZJOoonfX2o`00027ooo]Z0_l00003okc0g@;o00001_nb_>82o`0000KoYKKU
1?l00002ohfZj@03o`000?mcVn[oLi_Z00So00002_oonfX00ol0003ooo]ZoookJP0=oookJP03o`00
0?oonf[ooo]Z07;ooo]Z003ooookJVKooo]Z0ol0000QoookJP;o00000_nk`=d01?l0003o_<3Mo`00
0?l00004ok:lhP;o00000_nb_>800ol0003oYKKUojFfi@03o`000004ojBfiOl0003oTjkYo`0000Co
SJ[Y00Co0000og>Kj_mcVn[o00000_mPSnL01OljMn7o0000o`000?l0=kgo000000Wooo]Z00?o0000
oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP1boookJP00oooonfYToookJP;o00008_oonfX2o`00
00Go^l3M00Go0000okc1gOnl`Mgo0000ok:lhP02o`0000Go/[cR0_l00005ojBfi@go000000?o>WOQ
o`000?l000000_l00008oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0LOoonfX0
0?oooo]ZHOoonfX3o`0002?ooo]Z00Go0000ol?3f_o3`m[o0000ok_0g@02o`000004ok_0g_l0003o
_<7Mokc1g@;o00000onb_>83o`000004ok6lh_l0003oY;KUojBfi@?o000000CoY;KUo`000?nC[NSo
00001?n=ZNP01?l0003oLi[Yog>JjOl00002of2>iPKo00001ooonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z077ooo]Z003ooookJUoooo]Z0_l0000UoookJP04o`000?o3`m[o`l?Jol?3
fP;o00001?nk`=h2o`000003okc1g_l0003o/[cR00;o00001Ona_>82o`0000GoY;KU00?o0000oi>]
j?l000000_n=ZNP9o`000004oaaQeol0003o0000o`0000Oooo]Z00?o0000oookJ_oonfX03ooonfX0
0ol0003ooo]ZoookJP1`oookJP00oooonfYLoookJP?o00009_oonfX02?l0003o`l?Jol?3f_o3`m[o
0000ol?3f_l0003o^l3N0_l000001?nk`Mko0000okc1g_nl`Mh2o`0000Co/KcR0_l000000ona_>;o
0000ojBfi@06ojBfi@Co00000on<Z>P00ol0003oLYWXo`000002of2>i`Ko00001_oonfX00ol0003o
oo]ZoookJP0@oookJP03o`000?oonf[ooo]Z06oooo]Z003ooookJUWooo]Z0ol0000VoookJP?o0000
0_o3`mX2o`0000;o`l?J0_l00004ok_1gP;o00000_nl`Mh01?l0003o/KcRo`000?l00004ok6lhP03
o`000?nT]^Go000000;o00000_nS]ND00ol0003oTZgXo`000003ohbXj0?o000000KoLYWXo`000?mP
S^OoH8kWo`000?lJGmD3o`0000Kooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP1_
oookJP00oooonfYGoookJP;o0000:?oonfX01?l0003obLGFolW5e_l00005ol?3fP03o`000?o3a=[o
000000Co^l7N00Co0000okc1g_nl`Mko_<7N0_l00006ok6lhP;o00001_nS]ND5o`0000;oRjOW00?o
0000og6Hj?l000000_l000000omPS^Oo0000o`000003o`0000Gooo]Z00?o0000oookJ_oonfX04Ooo
nfX00ol0003ooo]ZoookJP1^oookJP00oooonfYDoookJP?o0000:OoonfX01?l0003obLGFolW5e_o9
aMH2o`0000?o`l?J00Oo0000ol?4f_o3a=[o`lCJo`000?nk`Mko000000;o^l7O00Go0000okc1g_l0
003o^l7No`000002ok6lhP?o00000_na_>800ol0003oXkGUoj>ei@03o`0000;oXkCU0_l00005oh^W
i`;o00000_mOSNH6o`0000Gooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP1]oook
JP00oooonfYBoookJP;o0000:ooonfX01ol0003obLGFolW5e_o9aMKo0000olW5e_l000000_o3`mX0
0ol0003o`lCJol?4fP02ol?4fP;o00001?nk`Ml00ol0003o^l7Nok_1gP03o`0000Ko/KcR0_l00006
oj>di@Wo000000?oGhgVo`000?l000001Ol00004oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000
oookJ_oonfX0KOoonfX00?oooo]ZCooonfX3o`0002cooo]Z00Go0000olW5e_o9aMKobLGFo`000003
olW5eP03o`000?o3`m[o`lCJ00?o`lCJ00Co0000ol;4g?l0003o^l7O0_l000001_nk`Moo0000ok_1
g_l0003o^l7Oo`0000Co/KcR0_l000001?n`^n;o0000oj>diOnS]>D3o`0000;oX[?U00?oTJ_Xo`00
0?n9YNL01?n9YNL2o`0000;oGhcU00Co0000oobkM_l0003onk9M0_l00004oookJP03o`000?oonf[o
oo]Z01?ooo]Z00?o0000oookJ_oonfX0K?oonfX00?oooo]ZCOoonfX2o`0002kooo]Z00Go0000olW5
e_o9aMKobLGFo`000003olW5eP;o00000oo3a=X2o`0000;o`/CL0_l00004ok_1g`06o`000?nk`Moo
^l7Ook_1gol0003o/KcR0_l00004ok2khP;o00001_nR/nD01?nAZnSo0000ohVUion9YNL5o`000005
oen<iOl0003oo;]fo`000?ok/Ud00ol00003oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX0K?oonfX00?oooo]ZB_oonfX3o`0002oooo]Z0ol000000oo9aMKo0000olW5eP02olW5eP06
o`000?o:a]Oob/KGo`000?o3a=[o00000oo2a=`02?l0003o`lCKol?4fol0003o^l7Oo`000?nj`]oo
00000onk`Ml2o`0000?o/;_R0_l00002ojnkhP03o`000?nR/nGoX[?U00CoX[?U1?l00003ohRTiP03
ofnFiol0003oGX[U00Oo00000ooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z06_o
oo]Z003ooookJTSooo]Z0_l0000aoookJP03o`000?o?a];oclKB00;o00000_o9aMH2o`0000?ob/KG
0_l00003ol;4g003o`000?o3a=_o`lCK00;o`lCK00Co0000ok[2gonj`]oo^/;O0ol000000onk`]oo
0000ok2khP02o`0000Go[k_R0ol00004oj6bi@03o`000?n8Y>KoR:CV00CoR:CV00KoKiKWo`000?l0
003on/67o`000?ol_7@4o`0000?ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP1Z
oookJP00oooonfY5oookJP?o0000<_oonfX00ol0003oclKBolo6dP03o`0000;obLGF1?o:a]L00ol0
003obLOGo`000002ol;4g0Co`lCK00?o0000ol?4fol000000onj`]l01?l0003o^l;Ook_2gonk`]l2
o`0000Co[k_R0_l000000on_^^;o0000oj6bi@06oj6bi@Wo000000?on/67o`000?ol_7@01?l00003
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0J_oonfX00?oooo]Z@_oonfX3o`00
03Cooo]Z00Co0000olo6d_o?a];o00000_o?am82o`0000Cob/KG00Go0000olW7eoo9amOobLOGo`00
0003ol?4f`;o00000oo3a=/2o`000005ok[2h?l0003o^l;Ook_2gol000000_nj`^001?l0003o[k_R
o`000?l00004ojnjhP03o`000?nQ/^Go000000;o00000_nO/ND00ol0003oQZ;VohJRiP04ohJRiPGo
000000?ooKeco`000?l000000_l00002oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oo
nfX0JOoonfX00?oooo]Z@?oonfX2o`0003Kooo]Z0_l000000oo?a];o0000olo7dP03olo7dP05o`00
0?o:a]Oob/KGol[6eol000000oo9amL01Oo9amSo0000o`000?o3a=_o000000?o`lCK00Co0000ol;4
g?o2a=co00000_nj`^000ol0003o^/;Pok[2h002ok[2h0;o00001_n_^^82o`0000KoWk7U1ol00000
1OogaYOo0000o`000?l0003ooKec00Co00000_oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oo
nf[ooo]Z06Wooo]Z003ooookJSgooo]Z0ol0000foookJP;o00000_o>a]800ol0003oclOBolo7dP02
olo7dP05o`000?o@b=?o0000ol[6eol000000_o9amL01?l0003obLOHolW7f?o9amP2o`0000;o`lCK
0_l00004ol;4g003o`000?ni`^7o000000;o^/;P0_l000001?ni`^7o0000ojnjh_n_^^83o`0000;o
[[[R00?o0000oinaiOnO/ND00ol000000onN/>Go0000oh>Sj004oh>Sj003o`000?ogaYOo000000So
000000?ooo]Zo`000?oonfX05ooonfX00ol0003ooo]ZoookJP1XoookJP00oooonfXkoookJP;o0000
>?oonfX01?l0003oe<O>o`000?o>a]82o`0000?oclOB00?o0000om38doo@b=<00_l00002olW7e`04
o`000?o9amSobLOHolW7f0?o000000?o`lCKo`000?o2a=`00oo2a=`01?l0003o`/GLo`000?ni`^42
o`0000Co^L;Q0ol00006ojjjhP;o00001OnN/>D00ol0003oPj?Xoh>Sj002oh>Sj0?o000000?on<NG
o`000?ola8D01Ol000000ooonf[o0000oookJP0HoookJP03o`000?oonf[ooo]Z06Oooo]Z003ooook
JSSooo]Z0ol0000ioookJP05o`000?oDalkoe<O>omC7c_l000000_o>am<00ol0003oclOBo`000002
om38d`05o`000?oAb=;o0000olW7eol000000oo9amP00ol0003obLSIolW8f@02o`0000?o`/CL0_l0
0003ol;5g003o`000?nh`^7o000000?o^L;Q00?o0000okW2hOl000000_n^^^83o`0000;o[KWS00Go
0000oij`iOnN/>GoW[3Uo`000002oij`i@Go00000_odb:001?l0003on<NGo`000?ola8D7o`0001Wo
oo]Z00?o0000oookJ_oonfX0IooonfX00?oooo]Z=_oonfX2o`0003cooo]Z00Co0000omC7c_oDalko
e<O>0_l00002olk7d`04o`000?o@b=?od<SCo`0000?odLSB00Go0000olW7f?o9amSobLOHo`000004
olW8f@;o000000?o`/CLo`000?o2aM`00_o2aM`00ol0003o`/GLo`000002okS2h@03o`000?ni`^7o
^L;Q00;o^L;Q0ol00006ojfih`?o00000onM/>D2o`0000;oQIoT00?o0000ooC8X?odb:000_l00000
0ooibIKo0000o`000002o`000004oo^dDol0003o0000o`0001[ooo]Z00?o0000oookJ_oonfX0I_oo
nfX00?oooo]Z<ooonfX3o`0003gooo]Z00Go0000om?7c_l0003oe<O>o`000002omC8cP05o`000?o?
b=?o0000om38dol000000ooAb=801Oo?bM?o0000o`000?o9amSo000000?obLSI00Go0000olW9fOl0
003ob/SHo`000003ol;5g007o`000?o2aMco`/GLol;5g?l0003o^<;Qo`000003okW2h@03o`000?ng
`N;o000000Co[KWS0_l000000on[^>?o0000oif`i@04oif`i@Oo000000GomLVPo`000?oibIKo0000
ooc6Q`06o`0001[ooo]Z00?o0000oookJ_oonfX0I_oonfX00?oooo]Z<OoonfX2o`0003oooo]Z00?o
0000om?7c_oCalh00_l00002omC8cP;o000000?oclSCo`000?l000000_oAb=801?l0003oclWColo9
doo?bM<2o`0000;obLSI0_l00003olW9f@;o00000_o2aM`00ol0003o`/GLol;5g003ol;5g0;o0000
0_ni`^44okO1hP04o`000?n]^N?o0000o`0000CoZkSS00Oo0000oif`iOl0003o0000oi^_iOl0003o
UZ_U00;o00000_oabJL01_l0003omLVPo`000?oibIKo0000ooc6Q`;o000000Coo/5_o`000?l0003o
00006ooonfX00ol0003ooo]ZoookJP1UoookJP00oooonfX^oookJP?o0000?ooonfX2o`0000;odlO>
00Go0000om?8col0003oe<S>o`000002omG9c`05o`000?o?bMCo0000om78d_l000000oo?bM<3o`00
0003olW8fOl0003obLWI00;obLWI00Co0000olW9f_l0003obLSI0_l00004ol;5g005o`000?o1aMgo
0000okO2h_l000001Ong`N82o`0000OoZkSS00?o0000oi^_iOnK[nD00_nK[nD00ol0003oUZ_Uo`00
0002oo79Y`;o000000Gom/^Po`000?ojbYGo0000oog8QP05o`0001cooo]Z00?o0000oookJ_oonfX0
I?oonfX00?oooo]Z;?oonfX2o`0004;ooo]Z0_l000000ooCalko0000om?8c`02om?8c`05o`000?oE
bLooeLW?omG9col000000_o?bM@01Ol0003oclWColo9doo?bM?o000000;oclWD0_l00002olW9f@;o
00000oo9bMX2o`0000?o`/GL0_l00003ol75g@;o00000ong`N82o`000004okJohOl0003oZkSSoj^h
h`?o00000_nZ]n<01Ol0003oVjoUoi^_iOl0003oVjoU00Go000000Gol/^Wo`000?ofbj3o0000oo[:
U@03o`000003ook2L?l0003o000000;o00006ooonfX00ol0003ooo]ZoookJP1ToookJP00oooonfXY
oookJP?o0000@ooonfX01?l0003of<S9o`000?l00004om?8c`;o000000KoeLW?o`000?oEb/oo0000
olo9e?l00002olo9d`04o`000?o?bMCoclWDolo9e0;o000000?obLWIo`000?o9bMX01?o9bMX01Ol0
003obLWIo`000?o2aMco000000?o`LGM00Co0000ol36goo0a]oo00000_ng`N800ol0003o][oQokJo
h@02okJoh@;o00001_nZ]n<2o`0000;oVZkU0_l00002ono:[@04o`000?obbjOo0000ooK;X0?o0000
00ConlbDo`000?l0003oo/=`0ol0000LoookJP03o`000?oonf[ooo]Z06?ooo]Z003ooookJRKooo]Z
0ol00015oookJP05o`000?oHb<Wof<S9omS8bOl000000ooCb<l01?l0003oe<W@omC9d?l00003omG:
c`04o`000?o?b]Go0000o`0000?oclWD00Cocl[Eo`000?o@b]Co00000oo9bMX2o`000003olS:fol0
003obLWI00;o00000_o1aMd2o`0000?o`<KO0_l00003okJoh@;o00000_ne_^400ol0003oZ[OSojZg
h`03o`0000;oZ;KS00Go0000oiZ^iOnJ[^GoVZkUo`000002ono:[@;o000000KollbWo`000?ogcIoo
mlfOo`000?okc9@2o`000004ook3L?l0003o0000o`0001gooo]Z00?o0000oookJ_oonfX0H_oonfX0
0?oooo]Z9?oonfX2o`0004Oooo]Z00Co0000omS8bOoHb<Wof<S90ol000001?oCb<oo0000omC9d?oD
bM02o`0000;oeL[?0_l000001Oo?b]Go0000olo9e?o?bMCo000000?ocl[E00Go0000om3;eOl0003o
bLWJo`000004olS:f`05o`000?o9bM[o0000ol75gOl000000oo0a]l01Ol0003o_lKPo`000?l0003o
][oQ00;o00001One_^42o`0000KoZ;KS1?l000001_o_bZgo0000oo3<[Ol0003ollbWo`0000;omlfO
0_l000001?olcICo0000o`000?ona6d2o`0001gooo]Z00?o0000oookJ_oonfX0H_oonfX00?oooo]Z
8OoonfX3o`0004Wooo]Z0_l000001?oHb<Wo0000omW9b_oIbLX2o`0000;oe<W@00?o0000omC;d?oD
bm000_l00002omG;d0;o000000?oclWDo`000?o?b]D00_o?b]D01Ol0003oclcGo`000?o@bmGo0000
00;ob<[K0_l000000oo8b]co0000olW9fP02o`0000;o`<KO0_l00003oko6h0;o00001?ne_^42o`00
0004okBnhOl0003oZ;KSojRfh`?o00000_nW]N<2o`0000;ok<^b00Go0000oo3<[Oo`c:go0000oo?<
Y`03o`000003ooS>Wol0003oo<fD00;o000000?oo/A]o`000?l000007_oonfX00ol0003ooo]Zoook
JP1QoookJP00oooonfXOoookJP;o0000BooonfX01?l0003oelS:omO8b_l00003omW9bP;o000000?o
e<W@o`000?oDbm000_oDbm001Ol0003oeL_@omG;d?l0003oe/gA00;o00000oo?b]D01?l0003oclcG
olo<eoo?c=L2o`000003olS:fol0003ob<[L00?ob<[L00Go0000olS:fol0003o`<KOo`000003oko6
h006o`000?nna^7o0000oko5g_l0003o]KkQ0_l00004okBnh@;o00001_nW]N<00ol0003ok<^bonc;
/P03o`000008oo7=[Ol0003om<jWooC>Yol0003on<jOo`000?olcI@6o`0001gooo]Z00?o0000oook
J_oonfX0HOoonfX00?oooo]Z7?oonfX3o`0004cooo]Z00?o0000omO8b_oGb<X00_l00002omW9bP04
o`000?oIb/_ofL[;o`0000?oe<_@0_l000001?oEbm3o0000omK=dOoFcM42o`0000;ocl[E00So0000
olo<eoo?c=OoclcGolo=f?l0003od<cFo`0000?ob<[L00Co0000olO;gOl0003ob<[K0_l00003oko6
h004o`000?nna^7o_/KQokk6h@?o00000ond_^42o`0000;o/kgQ00?o0000ojNehonW]N<00ol00000
1?nU/n?o0000o`000?l00002ong</P03o`000?oacJgo000000;om<jW0_l000001Ooiciko0000ooc>
Tol0003ool^200?o00007_oonfX00ol0003ooo]ZoookJP1PoookJP00oooonfXJoookJP;o0000C_oo
nfX2o`000004omO8b_l0003of<W;omS9b`;o00000_oIb//3o`000005omC;d?l0003oe<cAomC<dOl0
00000_oFcM400ol0003oe/kBolo<e`02o`0000;oclcG00?o0000olo=f?o?cMP00_l000001?o?cMOo
0000olS:g?l00002olO;g@;o00000_o8bm`00ol0003o_lKPo`000004okk6h@04o`000?nnaMoo0000
okBnh@;o00001Onc_N42o`0000?oYK?S00Co0000onS;^OoXbkWo00000_o]c;800ol0003olLf]o`00
0002o`000007ooG?Yol0003onLnNo`000?olcY?o0000ooo;PP04o`0001kooo]Z00?o0000oookJ_oo
nfX0GooonfX00?oooo]Z5ooonfX3o`00053ooo]Z00?o0000omc8aOl000000ooHbL/01?l0003ofL[;
omW:bol00002om[;b`;o00000_oDc=42o`000003omK=dOl0003oe/kB00;oe/kB0_l000000oo?c=Oo
0000olo=f002olo=f003o`000?o?cMOoclgG00;o00000oo7bmd01?l0003ob<_LolS;g?o8bm`2o`00
00;o_/KQ0_l000000onma^7o0000okk5g`02o`0000?o/kgQ0ol000000ona_>;o0000ojFch`02ojFc
h`09o`000?oXbkWoj<^ionS;^Ol0003okLbbo`000?o^c[;o000000;olLj]00Co0000ooG?Yol0003o
nLnN0_l000000oomd9;o0000o`000003o`0001kooo]Z00?o0000oookJ_oonfX0GooonfX00?oooo]Z
5OoonfX2o`0005;ooo]Z00Co0000omc8aOl0003o00000ooHbL/00ol0003ofL[;o`000003om[;b`;o
000000Goe<cAo`000?oDcM;oe<gBo`000003omK>dP;o0000013oeLgBo`000?o?cMSoclgHo`000?o>
c]Wo0000olo=eol0003oclkHo`000?o7bmgo0000olK;gOl0003ob<_L0_l000001?o7bmgo0000okk6
hOl00004okg6h@04o`000?nmaN3o0000ok>mh@;o00001Ona_>801?l0003oYK?So`000?l00002onS;
^@03o`000?oYcKWo000000;ok/jb00?o0000oo7>[OoacZd00_l000001Oofd:Ko0000oo[AW_l0003o
oM2B00Go00007ooonfX00ol0003ooo]ZoookJP1NoookJP00oooonfXBoookJP?o0000DooonfX00ol0
003og<S5omc8a@03o`000004omS9bol0003ofL_<o`0000?of/_;0_l000000ooJc<co0000omC=dP02
omC=dP04o`000?oFc];oe/kBo`0000;oe/gA0_l000000oo?cMSo0000olk>f@02olk>f@05o`000?o?
c]SoclkHolo>f?l000000oo6bmd01?l0003oal_MolO;gOo7bmd2o`0000?o_LKQ00Co0000ok_6h_l0
003o_LGP0_l00007ok6lhP?o000000Goi/^ko`000?oXbkWo0000onW=^@02o`00000;onk>/_l0003o
lLj]o`000?obd:go0000ooK@Y_l0003on]6No`000?omd9800ol000000oomaFGo0000o`00000Noook
JP03o`000?oonf[ooo]Z05kooo]Z003ooookJQ3ooo]Z0_l0001EoookJP04o`000?oLb<Gog<S5o`00
00;ogLW60_l00002omW;c0;o000000[of/_;o`000?oJc<cof/c<o`000?oJc/go0000omC=d_l0003o
e<kC0_l00002omK=d@;o000000?oeLkBo`000?o>c]T00_o>c]T2o`0000;oclkH00Co0000olk>fOl0
003oa/_M0_l00002olO;g@06o`000?o6c=koa/cNo`000?nma^7o00000_nka^82o`0000;o_<GQ00?o
0000ok6lh_na_>800ol000001?n`^n;o0000oj>bhol00002onK;^`08o`000?oYcKWojLfio`000?o]
c[Co0000ono?/_l00002oo;@[@07o`000?ofd:Ko0000o`000?ojdYgo0000oogAT002o`000003oog5
IOl0003o000001oooo]Z00?o0000oookJ_oonfX0GOoonfX00?oooo]Z3OoonfX3o`0005Kooo]Z00Go
0000omc8a_l0003og<S5o`000002omg9aP;o000000GofL_<o`000?oIc<gofLc=o`000003om[<c004
o`000?oJc/go0000o`0000;oe<kC00Co0000omK=dOoFcM7o00000_oEc]<01Ol0003oeLoCo`000?o>
c]Wo000000;oc/kJ0_l00002olk>f@;o00000_o5bmh2o`0000?oa/cN0_l00003ok_6hP04o`000?nl
aN7o_<GQokc5h@?o00001On`^n802?l0003oi/^konK;^ooVbk_o0000onW=^Ol0003oj/ji0_l00000
2oo_ck;o0000oo;@[Ol0003olm6]o`000?ogdZKo0000oo[BWOl0003ooM6@00Go00008?oonfX00ol0
003ooo]ZoookJP1LoookJP00oooonfX:oookJP?o0000F?oonfX01Ol0003og<S6omc8a_oLb<Ko0000
00;ogLW600Co0000omk;a_l0003o00000ooIc<d02Ol0003of/c<om[<c?l0003of/k=o`000?oKclgo
0000omC>d`02o`000004omK=dOl0003oeLkComG>d`;o00000_oEcm<01Ol0003oc/kJolk>f_o>c][o
000000;oc/kI00Co0000olk?f_l0003oaL_N0_l00002olK<gP;o000000Ooa<_Po`000?nka^;o0000
ok[5hol0003o_<GQ00;o000000Co^/GRo`000?n`^n;o/;_R0ol000001on^^N;o0000o`000?oVbk_o
0000onO=_?l000000_oZc[T3o`000006ono@/ol0003olm6]oo?A[Ol0003omm:V0_l000000ookdico
0000ookBS`05o`0001oooo]Z00?o0000oookJ_oonfX0G?oonfX00?oooo]Z2?oonfX2o`0005[ooo]Z
00Co0000omc8a_oLb<Kog<S60_l000002_oMbLKo0000omk;a_oNblKo0000omk<aol0003ofLc=o`00
0?oIcLd2o`0000;of/k=00?o0000om_?cOoKcld00_l000001OoDcmCo0000omG>dooEc]?o000000;o
e<oD0ol000001_o>c][o0000olg?fol0003oc/kIo`0000;oc/oJ0_l000001?o4bmoo0000olK<g_l0
0003olC;h0;o00000onjaN<01?l0003o^/GRok[5h_njaN83o`0000?o[[WR00Co0000onC;__oTbkko
00000_oWcK`3o`0000;ojlni0ol00002oo?A[@;o000000Gon=>Vo`000?okdico0000ookBS`05o`00
023ooo]Z00?o0000oookJ_oonfX0FooonfX00?oooo]Z1OoonfX3o`0005cooo]Z0_l000001OoLb<Ko
0000omc:aooLb/Oo000000;og/_600Go0000omk<aol0003og/c7o`000002omW=c@09o`000?oJc/go
f/k=o`000?oJclko0000om_?cOl0003ofm3>00;o000000?oeLkCo`000?oDcm@00_oDcm@01?l0003o
eM3DomG@e?l00003olg?f`04o`000?o>cm[oc/oJo`0000;ocM3L0_l00004olC;h007o`000?o3b=ko
`lSNol?8g_l0003o^<GSo`000002ok[5hP04o`000?nha>?o^<CSo`0000;o[[WR00Oo0000onC;__oT
bkkoi<^no`000?oWcKco000000;oj<jl00Go0000on_?^Oo[ckWo0000onkA]003o`000005ooCB[Ol0
003on=>Vo`000?okdi`00_l000000oondhko0000o`000002o`00023ooo]Z00?o0000oookJ_oonfX0
FooonfX00?oooo]Z0ooonfX2o`0005kooo]Z00Co0000on78`?oQb<3o00000ooLb/L00ol0003og/_6
o`000003omk<a`;o000000GofLg=o`000?l0003of/k=o`000003om[?cP06o`000?oKd<kofm3>o`00
0?oDd=Go00000ooDcm@2o`000005omG@e?l0003oe=7Fo`000?o=cm/00_l000000oo>cm[o0000olg@
g002olg@g0;o00000oo4bn002Ol0003o`lSNol?8g_o3b=ko`/SNo`000?nhaN?o0000ok[5hP04okS4
h`Go000000Coi<^no`000?oUcKko00000ooXc[`01?l0003ojlnio`000?o/dKT2o`000003oo3A/ol0
003om=:]00;o000000Gon=BUo`000?ole9_o0000ookCSP04o`00027ooo]Z00?o0000oookJ_oonfX0
F_oonfX00?oooo]Z0ol0001PoookJP03o`000?oQb<3ohLS000;o000000Cog<[7o`000?oMc<Oo0000
1?oNc<L01_l0003oglk8o`000?l0003of/o>o`0000;of/o>00Ko0000om[@col0003ofm3>o`000?oK
dLl2o`0000;oe<oD00Co0000omCAeooDdMOo00000ooDdMH01?l0003oc<oLo`000?o>cmX3olg@g003
o`000?o;d=go000000;oa<_P0_o3b=h2o`0000?o`/SN0_l00003okS4h`;o000000Co]/3Qo`000?l0
003ohL_30_l00002onG=_P05o`000?oXc[coj<jlo`000?oXck`00_l000000oo/dKWo0000onoB]@03
o`000007ooGD[?l0003on=BUo`000?ole9_o0000ookCSP05o`00027ooo]Z00?o0000oookJ_oonfX0
FOoonfX00?gooo]Z0_l0001RoookJP05o`000?oQb<3ohLS0o`000?oQb/400_l00002omg<a`07o`00
0?oNc<Oog/c7omk<aol0003og/k8o`000002omo?b0;o000000?of/o>o`000?oJd<l00_oJd<l01?l0
003ofm7?o`000?oKdm03o`0000;oe=7G0_l00002omCAeP;o000000Coc<oLo`000?o=d=cocM3L0_l0
0003ol_@g@;o000000?o`lSNo`000?o2b=h00_o2b=h01?l0003o`<[Ro`000?l00002okS4h`05o`00
0?nf`>7o]/3QokK0hOl000000_oQbl<2o`000003onG=__l0003oi/jo00;o00000_oXck`01Ol0003o
k=6ioncA^Ol0003okm:e00?o000000?omMB/o`000?ohe:D00_l000000ooleY[o0000o`000004o`00
027ooo]Z00?o0000oookJ_oonfX0FOoonfX00?[ooo]Z0ol0001ToookJP;o000000?ohLS0o`000?oQ
b/400_l000001_oMc<Oo0000omk=b?l0003og/c7o`0000;og/k800Ko0000omo?b?oOclSo0000om[@
col00003om[@c`?o00000ooKdm001?l0003oe=7GomCAeol00002om?Bf0;o000000Coe=;Go`000?l0
003o00000_o=d=`4ol_@g@04ol[@g_l0003o0000o`0000;o`/SN0_l00003ol3:hP;o00000onf`>42
o`0000?ohL_30ol00002onK>_`09o`000?oXckcoj<nlonS?_?l0003ok=6io`000?o/d[Wo000000;o
l=>e0_l000001OoeeZgo0000ooWFY?l0003oo=JJ00Ko00008_oonfX00ol0003ooo]ZoookJP1Hoook
JP00n?oonfX2o`0006Kooo]Z00Co0000on38`OoPb<7o00000_oQb/43o`0000?og/g800Go0000omk>
b?oNc/So0000omo?b@02o`000003on3AbOl0003o000000;of]3?00?o0000om[BdOl000000ooKdm02
o`000003omCAeol0003odm;H00;odm;H00?o0000omCBeol000000ooDe=P00ol0003obm3Mol_@g@02
o`0000;ob]3N00Go0000ol[>gOl0003o`/SNo`000005ol3:hP;o000000Co]/3Qo`000?l0003o];kQ
0_l000001?oQbl?o0000on7=`ooQcL<2o`000007onK>_ol0003o0000onS?_?l0003ojM2lo`000002
oncB^@03o`000?o`dkGo000000;o000000GomMJ]o`000?oieZCo0000oocFVP03o`000003ooo@M_l0
003o000002?ooo]Z00?o0000oookJ_oonfX0EooonfX00?Gooo]Z0ol0001WoookJP03o`000?oPb<7o
h<S100;o000000CohL[1o`000?oRc<7oh/c10_l000001OoNcLSo0000o`000?oNc/So000000;oglo9
00?o0000on3AbOoPdLT01?l00002om[Bd@04o`000?oKdm3ofm?@o`0000;of];A00Go0000om?Bf?oC
d]So0000om?Cf@02o`0000?oe=CH0_l000000oo;d=go0000ol[@gP02ol[@gP05olW@gol0003ob/kM
ol[>gOl000000oo0b^82o`000004okk9hol0003o`<OPo`0000;o];kQ00Co0000omo;a?oOblCo0000
0_oQcL<2o`000005onC>`Ol0003oi/noonK?_ol000000_oYd;`01Ol0003ok=:io`000?o]dkWo0000
00;okmFg00Oo0000ooGF[Ol0003o0000oo[HY?l0003ooMNI00;o000000Coom1fo`000?l0003o0000
8_oonfX00ol0003ooo]ZoookJP1GoookJP00l_oonfX3o`0006Wooo]Z0_l000001OoPb<7o0000on7:
`OoQb/7o000000;oh/c10_l000001OoScL;o0000omk?bOoNclWo000000;oglo90_l000001OoPdLWo
0000on3Bb_oPd/[o000000;of];A00Co0000om[Dd_l0003o00000_oJd]42o`000005om[Cd_l0003o
dm?Iom?CfOl000000ooDe=P01?l0003od]7Ho`000?l00002ol[@gP04o`000?o9d=oobM3OolW@g`?o
000000?o`<[Ro`000?l000001?nnbN<2o`0000;o];kQ00Ko0000omo;a?oOblCo0000on7=`ol00002
on;>``;o000000Ooi/noo`000?l0003ojM2lo`000?oZd[co000000;okM>i00?o0000onoE]oo_eKL0
1?l000000oojf:Co0000oogGV@02o`000004ooo@M_l0003o0000o`0002?ooo]Z00?o0000oookJ_oo
nfX0E_oonfX00?3ooo]Z0_l0001[oookJP04o`000?oPbL7oh<W1o`0000?ohL[100?o0000on;<`Ol0
00000_oScL82o`000005omk?bOl0003o0000omo?bOl000000_oOdLX00ol0003oh=;:on3BbP02o`00
0005om[BdOl0003of]CBom[Dd_l000000_oJd]400ol0003of]?Bo`000002o`000003om?CfOl0003o
000000;oe=CH00?o0000om;Af?oBdMP00_l000000oo:d=ko0000olW@g`03olW@g`04o`000?o9cmko
bLoNo`0000?o_/WS0_l000000onmbNCo0000okk7h@02o`0000;ogl_400?o0000on3<aOl000000ooR
c/<00ol0003oiLo1o`000002onO@_`07o`000?oZd[coj]:lo`000?o]dkWo0000onkE^@02o`000005
oo7F]Ol0003omMR_o`000?ojf:@02?l0000SoookJP03o`000?oonf[ooo]Z05Kooo]Z003]oookJP?o
0000K?oonfX01Ol0003oi<Rko`000?oPbL7o000000;ohL[100?o0000on;<`_l000000ooScL800ol0
003ohlo3o`000002omoAbP07o`000?oOdL[ogm7:omoAb_l0003oh=;:o`000002on3Cb`;o000000Go
f]CBo`000?l0003of];Ao`000002om[CdP04o`000?oJeM?of]GCo`0000;od]CJ0_l00002om;Af004
om3Dg?l0003odM;Io`0000?obM3O00Wo0000olO@hOl0003obLoNo`000?o8cn3o0000okk9hol00000
0onmbN@4o`000005omo;a?l0003oh<c5on3<aOl000000_oRc/<00ol0003ohlo4o`000002o`000005
onO@_ol0003oj]:lo`000?o[dk`00_l000001_o^eKWo0000oo7F]Ooae[Go0000ooGH[`;o000000?o
n]VTo`000?l000001Ol0000ToookJP03o`000?oonf[ooo]Z05Gooo]Z003[oookJP;o0000KooonfX0
2_l0003oi<RkonC8^ol0003ohL_2o`000?oQb/7o0000on;<`_l00002on?=`P03o`000?oScl?o0000
00;o000000Oogm7:o`000?oOdL[ogm7:o`000?oOd/_o000000?oh=?;00?o0000omoDc?l000000_oJ
eM<00ol0003of]?Bom[CdP02o`000008om[Edol0003ofMKEo`000?oBe=[o0000om;Af?l00003om3D
g005o`000?oAdm_o0000olW@gol000000_o7d>42o`0000;ob<oP0_l00004okg9i0;o00000_oLblP0
2?l0003oh<c5on3<aOl0003ohLg5o`000?oRc/?o00000_oScl@01?l0003oi]31o`000?oWdL02o`00
000:on_C_?l0003ok]FionkE^Ol0003olMJeo`000?obf;Go0000ooGI/@?o000000?ooMRHo`000?l0
00000ol0000UoookJP03o`000?oonf[ooo]Z05Cooo]Z003XoookJP?o0000L?oonfX01_l0003oiLRk
o`000?oTb;_o0000on7;`P;o000000Soh/c2o`000?oSc/?o0000on?=`_l0003ohlo3o`0000;oi=74
00Co0000omoBbol0003o00000_oOd//01Ol0003oh=?;on3Cbol0003ogmC<00;o000000Gof]GCo`00
0?l0003of]?Bo`000002omWGeP04o`000?oIe]GofMKEomWFe@?o00000oo@e=`00oo?e=go0000om7C
f`02o`0000?oam3Q00Oo0000olS?h?l0003o0000olG?h_l0003o_LWT00;o000000?o^lSTo`000?oL
blP00_oLblP2o`000005on3<aOl0003ohLg5on7=aOl000000_oScl@2o`000004onK@`Ol0003oim70
o`0000;ojm>l00Go0000onkE^Ol0003okmJio`000002oo;H]@04o`000?oefK7o0000oo[JYPOo0000
9OoonfX00ol0003ooo]ZoookJP1DoookJP00i_oonfX2o`0007?ooo]Z00[o0000onG8^ooUb;_o0000
onG:_?l0003oh/g2o`000?oRc<;o00000_oSc/<01Ol0003ohlo3on??`ol0003oi=7400;o000000Ko
gm;;o`000?oOd/_ogm;;o`000?oOeLd2o`0000;ogmC<00Co0000omoFcOl0003ofMKE0_l00002omWG
eP;o00000_oIe]D00ol0003ofMSFo`000002om3Dg003o`000?o?e=gocmCM00;o000000God=CLo`00
0?l0003o0000olK?hP02o`0000?oaLoR0_l00002ok_8i0;o00000_oLblP01?l0003og<c8o`000?l0
0002on7=a@;o000000Kohlo4o`000?oSd<Cohm34o`000?oVd/82o`000004on_C_?l0003ok=Bmo`00
00;okmJi00So0000oo;H]Ol0003olmVeo`000?offjoo0000oo[KYPOo00009OoonfX00ol0003ooo]Z
oookJP1CoookJP00hooonfX3o`0007Cooo]Z00Ko0000onG8^ooUb;_oiLRko`000?oUb[`2o`000004
on;=`_l0003ohlk3on?>``;o000000Cohlo3o`000?oTdLCo00000_oTd/D2o`000005omoBbol0003o
gmG=omoEcOl000000_oOe<`3o`000003on3Gcol0003o000000;ofMOF00?o0000omSHeooHf=L00_l0
00001OoIf=Ko0000o`000?o@e=co000000?ocmCM00?o0000om3Dg?o@e=`00_o?eMh00ol0003oa/oR
o`000003olG?hP03o`000?o4bmooa<_O00;o00000_oKblT2o`0000;og<c80_l000001OoQcLGo0000
on7?aOoQclGo000000;ohm340_l000001?oVd/;o0000o`000?l00002oncD_@04o`000?o_e[Wo0000
onoG^@;o000000GolmVeo`000?offjoo0000oo[KYP07o`0002Gooo]Z00?o0000oookJ_oonfX0Dooo
nfX00>7ooo]Z0_l0001goookJP;o000000CoiLRko`000?oVb[_o00000_oVc;`2o`000005on?>`ol0
003ohm34on?@a?l000000_oTdL@00ol0003oi=;5o`000002onGDaP03o`000?oOeLgogmG=00;o0000
00CogmC<o`000?oOe/ko00000ooPell00ol0003ofMOFo`000003omSHe`04o`000?oIf=Ko0000omOE
e`;o00000oo?e=d2o`000004om3Dg?o?eMkocmGNoloEgP?o00000_o5cn801Ol0003oa<_OolC;goo4
bmoo000000?ofl_900Co0000omc<b?oLc<Sog<c80ol00003on7?a@03o`000?oSd<Co000000;oi=74
00Oo0000onOC`_oWdl;o0000oncD_Ol0003ok=Jm00;o000000CokmNio`000?ocfKGolmVe0_l00000
0oogg:ko0000oo[MZ002o`000004oooJR_l0003o0000o`0002Kooo]Z00?o0000oookJ_oonfX0D_oo
nfX00=kooo]Z0ol0001hoookJP04o`000?oUb;_oiLRko`0000;oi/Zk0_l000001?oVc;co0000o`00
0?l00002on?@a0;o000000Coi=74o`000?oTd/Go00000ooUe<H00ol0003ogmG=o`000002omoGc`04
o`000?oOe/kogmK>o`0000;oh=O?00?o0000omoGcol000000ooHf=L3o`0000?oemGG0_l000001?o?
e=go0000olkEg_l00003oloEgP05o`000?o<e>3o0000o`000?o5cn801?o4bml02Ol0003ofl_9om_;
bOoKblWo0000om_<b_l0003og<c8o`000002omg=b@06o`000?oQclGohLo5o`000?oRd<Ko00000ooT
dL@00ol0003oim?2onOC`P03o`000006oncF_Ol0003okmNionoG^Ol0003olmVe0_l00002ooOL[P03
o`000?ojgJSo000000Go00009ooonfX00ol0003ooo]ZoookJP1AoookJP00g?oonfX2o`0007[ooo]Z
00Oo0000onG8^ooUb;_oiLRko`000?oVb[_o000000;oilbl00Ko0000onO>_OoWc[go0000on?@a?l0
0002onCBa@04o`000?oTd/Goi=;5o`0000;oiMC60ol00003omoGc`04o`000?oOe/ko0000omoGc`;o
00000_oOell2o`000004omSHeol0003oemSHo`0000;oemGG00?o0000omKIfol000000_l000000oo>
eMko0000o`000002oloEgP05o`000?o<e>3oc=CPolcDh?l000000_o4bml2o`000005ol;9h?l0003o
0000om_;bOl000000ooKc<X00ol0003ogLg9omg=b@04o`0000;oh]3600Go0000onCAa?oTdLCo0000
onGBa002o`00000;onOD`_l0003ok=JmoncF_Ol0003okmNio`000?o`fKWo0000oo?J]?l000000_og
g:h3o`000003ookNVOl0003o000000;o00009ooonfX00ol0003ooo]ZoookJP1AoookJP00fOoonfX3
o`0007cooo]Z0_l000001?oUb;_o0000onK;_?l00003onO<_003o`000?oWc[goiljm00;o00000ooT
d/D01?l0003oi=;5o`000?oUe<H2o`0000;oiMG60_l000001?oOeloo0000o`000?l00002omoGc`05
o`000?oOeloogmO?o`000?oNf=400_l000001OoGf=So0000o`000?oGeMOo000000;oe]WK00Co0000
omKHfOoFf=Wo00000_o=eN02o`0000?oc=CP00Cob]CQo`000?l0003o00000_o2bN02o`000003omW:
bol0003oflc:00;oflc:0_l000001OoMcLWo0000omk>bOoNc/Wo000000;oh]3600Co0000on;Aa_l0
003o00000_oUd/@00ol0003oimC2onOD`P03o`000006ongG_Ol0003ol=Vioo3I^Ol0003olmZd1?l0
00000ookgZGo0000ookNV@04o`0002Sooo]Z00?o0000oookJ_oonfX0D?oonfX00=Kooo]Z0ol0001n
oookJP04o`000?oUbK_oiLVko`0000;oi/^l00Go0000onO<_?oWc;co0000onO>_@02o`000006onS@
_Ol0003o0000onCBaOl0003oi=C60_l000001?oUe<Ko0000onGEa_oUeLH2o`000004onGFb?l0003o
gmS@o`0000;ogmO?0_l000002?oOeloo0000omkHdOoNf=7o0000omkJd_l0003oemWJ0_l00002omKI
f`;o000000Koe]SIo`000?oEfM_o0000olgEh?l00002olcDh008o`000?o:e>7ob]CQo`000?o:dMoo
0000ol;9h?l00002omS:c0;o00000_oKc<X01?l0003og<g:omc=b_l00003omk>b@;o000000Coh]36
o`000?oRdLKo00000ooUd/@01?l0003oimC2o`000?oWe/@2o`00000;ongG_Ol0003ol=Vio`000?oa
f[Wo0000ooCL]?l0003on=f^o`000?okgZD00ol000000oonfhCo0000o`00000XoookJP03o`000?oo
nf[ooo]Z053ooo]Z003DoookJP;o0000POoonfX2o`00000:onG9^ol0003oi/^lo`000?oWcKco0000
onO<_?l0003oiljmo`0000;oj=2m0ol00002onCDaP06o`000?oUe<KoiMC6o`000?oUeLKo00000_oU
elP01_l0003oiMS9o`000?l0003ogmO?o`0000;og][B00?o0000omkHdOoNf=401?l000001_oGfM[o
0000omKIfooFfM_o0000omCJg0;o00000_oEfM/3o`000004olcDh?o:e>7ob]CQol[Dh@;o000000?o
b]7Oo`000?l000000ooHb/`4o`0000?og<g:00Co0000omk>bOoNc/Wo00000_oMcl/00ol0003oh]76
on;AaP02o`000004onGBa?l0003oiMC5o`0000;oimK400Go0000oncH_ol0003okMRmo`000002oo7J
^@05o`000?odg;Co0000o`000?ohgjd01?l000000oonfhCo0000o`00000YoookJP03o`000?oonf[o
oo]Z04oooo]Z003AoookJP?o0000PooonfX01?l0003ojLReo`000?oVbk`2o`0000;oilfl00Oo0000
onO>_OoWc[go0000onS@_Ol0003ojM6m00;o000000Ooi=C6o`000?l0003oiMC6o`000?oUe/Oo0000
00?oiMO80_l00002onGJb`03o`000?oNf];og][B00;o000000Cog]SAo`000?oNfM?o00000_oNfm@2
o`000005omKIfol0003oe=[LomCJg?l000000_oEfM/01?l0003od]KKo`000?l00003ol[Dh@06o`00
0?o8dn;o0000o`000?o8d^7o00000_oHb/`01?l0003of<_=omS;cOl00003omc=bP04o`000?oLc/[o
0000o`0000;ogLo;0_l000001OoRdLKo0000on?Ba_oSd/Ko000000;oiMC500Co0000onOFa?l0003o
jMO30_l000001?o]f;go0000oo7J^Ooaf[T2o`000003ooGM]?l0003on=n]00So0000:OoonfX00ol0
003ooo]ZoookJP1>oookJP00cooonfX2o`0008Gooo]Z00Ko0000onW8]?l0003o0000onK;_?l00003
onO=_005o`000?oWc[go0000onS@_Ol000000_oYdKd00ol0003ojM?0o`000002onGFa`04o`000?oU
e/OoiMK7o`0000;oiMO80_l00003onGJb`04o`000?oNf];o0000omkLe0;o000000Kog]WCo`000?l0
003og]_Do`000?oLf]D2o`000006omCJg?l0003odm[Mo`000?oEfM_o00000ooBe]/2o`000008ol[D
hOl0003ob=?RolSCh_l0003ob=;Qo`000?oGb/d2o`0000?of<_=0_l000001OoLcL[o0000omc>b_oL
c/[o000000;ogLo;00Co0000omo@b_oOd<[o00000ooSd/H01Ol0003oiMC5o`000?oVeLGo000000;o
jMO300?o0000oncI_ol000000ol000001Oobg;Wo0000ooGM]?l0003on=n]00?o000000?oo]nEo`00
0?l000000_l0000YoookJP03o`000?oonf[ooo]Z04kooo]Z003<oookJP?o0000QooonfX02ol0003o
jLRdo`000?oZb[Go0000onO=_?l0003oilflo`000?oWckgo000000;oj=2m00co0000onWA_Ol0003o
jM>oo`000?oYeL7o0000onGFaol0003oiMK7o`000?oUfLX2o`000004onGHbOl0003oiM[;onGJb`Co
000000Gog]cDo`000?oNfM?o0000omcMe`02o`0000;og=[E00?o0000om_Ke_l000000_oCf]d2o`00
00?od]KK00Ood=[Oo`000?l0003o0000olSCh_l0003oa]?T00;o00000_oGb/d01_l0003of<_=omS;
cOoHblgo0000omW<c@;o00000_oLc/X2o`000003omg?bol0003ogm3:00;ogm3:0_l000000ooSd/Ko
0000on?Ca`02o`000005onKEaOl0003ojMO3o`000?oYf<<00_l000001?o]f[oo0000oo;L^Oobg;T2
o`000003ooKN/ol0003onN2/00;o000000?oo]nEo`000?l000000_l0000ZoookJP03o`000?oonf[o
oo]Z04gooo]Z003:oookJP;o0000ROoonfX00ol0003ojLRdonW8]004o`000009onO=_?l0003oilnm
onO?_Ol0003oj=2mo`000?oYd[ko000000;ojM>o00Go0000onWE`OoYeL7o0000onGHb@02o`000005
onGIb_l0003oiMS9o`000?oUf//00_l000001?oTf/co0000onCLcOoTg<d3o`0000;og=gG00?o0000
omcJeOoLf]D00_l000001_oKfmKo0000o`000?oCf]go0000om;Ff`;o00000_o@f]l01Ol0003odMSN
om7Hg_l0003oa]?T00;o00000_oGb/d01Ol0003oel_>o`000?oHblgo000000;ofLc=0_l000001OoL
c/[o0000omg?booMcl_o000000?ogm3:00Co0000omoBb_l0003o00000_oSdlL01?l0003oi]G5o`00
0?oWe/D2o`000004onWH`ol0003okMZoongJ_`Co00000_ofg[<00ol0003onN2/o`000006o`0002_o
oo]Z00?o0000oookJ_oonfX0C?oonfX00<Oooo]Z0ol0002;oookJP03o`000?oYb;Co000000;oj/Zd
00So0000on_<]_l0003o0000onO?_Ol0003oj=6oo`0000;ojM:n00Co0000onWC_ol0003oj]K00_l0
00001?oZf<;o0000o`000?oUfLX2o`000005onGHbOl0003oiM[;o`000?oTf/`00_l000001?oTg<go
0000o`000?l00002omcMe`;o000000Gog=[Eo`000?oKfmKofm_Fo`000002om_Mf0?o00000oo@f]l2
o`000004om7Hg_l0003o0000olKCi0;o000000?oel[=o`000?oGblh00_oGblh01?l0003ofLc=omW<
cOl00002omW=cP04o`000?oMcl_ogLo;omg?b`;o000000Cogm3:o`000?oOd/[ogm;:0_l000001ooS
dlOo0000o`000?oVeLGo0000onOFaOl000000_oYf<<01?l0003okMZoo`000?o/g<43o`0000;om]jc
2Ol0000[oookJP03o`000?oonf[ooo]Z04cooo]Z0035oookJP;o0000SOoonfX00ol0003ojLRdo`00
0003on[:]003o`000?o[c;Ko000000;o00000_oXdKl01?l0003ojM:no`000?oYe;l2o`000004on[F
`?l0003oj]S2on[H`P?o00000_oUfl`00ol0003oiM[;onGJb`02o`0000;oi=c=00Ko0000onCNcooT
g/oo0000omcMeol00002om_Nf003o`000?oKfmKofm_F00;o000000CofmgHo`000?oJgm[o00000oo@
f]l01Ol0003ocmWQo`000?l0003ocmWP00;o000000?oe<W@o`000?l000000ooGblh2o`000004omW<
cOl0003ofLg>omW=cP;o00000_oMcl/01?l0003ogM3;omg@bol00003omoBbP04o`000?oRdlSo0000
onCDa`;o00000_oWe/D01Ol0003ojMS3o`000?oZf/?o000000;ok=c100?o0000oo7N^ol000000ol0
00000oojhJ_o0000o`000005o`0002cooo]Z00?o0000oookJ_oonfX0BooonfX00<;ooo]Z0ol0002>
oookJP03o`000?oYb;CojLRd00;o000000Coj/Zdo`000?o/c;Go00000_o/c[H01?l0003oj=6oo`00
0?oYe;l2o`000008onWD_ol0003oj]K0on[F`?l0003oj]S2o`000?oZfL82o`000004onGKc?l0003o
0000onGJb`;o00000ooTg<d00ol0003oi=k?o`000003o`000006om_Nf?l0003o0000om_Ke_l0003o
fMoK0_l000001_oJgm[o0000o`000?l0003od=[Oo`0000;ocmWQ00Co0000oloIh?l0003o00000_oD
bM001Ol0003oe/_?o`000?oGblko000000;of<c>00So0000omW=c_oIcLko0000omS>col0003ogLo;
o`0000?ogM3;00ko0000omoBb_oOd/[o0000on3Cbol0003ohmC9o`000?oTe/So0000onOFaOl0003o
imS5o`0000;oj][300Co0000oncL`Ol0003ok]g00ol000000oofh;?o0000oo[QZ`03o`000004oogQ
TOl0003o0000o`0002cooo]Z00?o0000oookJ_oonfX0BooonfX00<3ooo]Z0_l0002AoookJP?o0000
0_o[b[@02?l0003ok<beonc<]Ol0003ok<jfo`000?o]d;Ko00000_oYe;l02?l0003ojMBoonWD_ol0
003oj]K0o`000?oZf<;o00000_oZfL800ol0003oj][4o`000003o`000004onCNc_l0003oi=c=onCL
c@?o00000_oRgM001?l0003oh]oAo`000?oJgmX2o`0000;ofMoK00Co0000om[Of_l0003oemoM0ol0
00000oo?fN7o0000olgIhP03o`0000;oe<W@00Go0000omC;d?l0003oe/_?o`000002omS<cP;o0000
00?ofLg>o`000?oHc/l00_oHc/l01_l0003ogM3;omg@booMd<_o0000omkAc0;o00000_oPdl/01_l0
003ohmC9o`000?l0003oi=K8o`0000;oimS500Co0000on[J`ol0003ojm_30_l000000oo^gL3o0000
oo;O^`04o`000004oo[SZol0003o0000oogQT@?o0000;OoonfX00ol0003ooo]ZoookJP1:oookJP00
_OoonfX3o`0009;ooo]Z00Co0000on[8/ooZb;?o00000_o[b[@01Ol0003ok<beo`000?o]c[Go0000
00;okM2f0_l000001_oYe;oo0000onWD_ol0003oj]O1o`0000;oj]S200Co0000on[I`_l0003oj][4
0_l000001OoZgLGo0000onCNc_l0003oi>3@00;o000000Gohn7Ao`000?oRgM3o0000on;OdP02o`00
0003on;Qdol0003o000000;ofMoK0ol00002omOOg@05o`000?oGgMcoemgLo`000?o=fN800ol00002
omC9d004o`000?oDbm3oe<_@omC;d0;o000000Gof<c>o`000?oHcLoof<g?o`000004omS>c`;o0000
00?ogM3;o`000?oNdL`00_l00002on3Cb`03o`000?oQe<_o000000;ohmK90_l000000ooWf<Go0000
onSIa@02o`000003on_K`ol0003ok]g000?o000000GolN6mo`000?ofhkGo0000oo[SZ`06o`0002ko
oo]Z00?o0000oookJ_oonfX0BOoonfX00;[ooo]Z0ol0002EoookJP08o`000?oZb;?oj/Rco`000?o[
b[Co0000onc=]?l00002ong>]@08o`000?o]d;KokM2fo`000?o]d[So0000on[F`Ol00002on[G`@05
o`000?oZf<;o0000on[J`ol000000_oZf/@00ol0003oj]g5on[Ma@03o`000004onCPd?l0003ohn7A
on?Qd@;o00000_oRgm800ol0003oh^7Con;Qd`02o`000004omWOfol0003of=oLo`0000?oemoM00Co
0000omOMg?l0003oe]kN0_l000001?oBbM7o0000omC9d?l00003omC;d0;o000000?oe/c@o`000?oH
cLl00_oHcLl01_l0003of<k?omS>cooHc/oo0000om[@c`;o000000Kog]7<o`000?oNd/co0000on3C
bol00002on7Db`03o`000?oSe/WohmK900?o00000_oXfLD00ol0003ojm_3o`000002o`000006onoN
`?l0003olN6moo7Q_Ol0003om^>e0ol000000ooli9oo0000o`000002o`0002kooo]Z00?o0000oook
J_oonfX0BOoonfX00;Sooo]Z0_l0002GoookJP;o000000Coj/Rco`000?o[bkCo00000_o/cK@00ol0
003okLjeong>]@03o`000003onkB]ol0003ok]Bi00;o000000Coj]O1o`000?oZf/?o00000_oZf/<0
2Ol0003oj][4on[Ja?l0003oj]g5o`000?oYgLOo0000onWOb002o`000003on?QdOl0003o000000?o
h]oB00Co0000on;Qdol0003ogmoE0_l000000ooHgmco0000o`000002omOOg@04omGOgol0003o0000
omKNgP;o000000CodLWBo`000?oBbM7o00000ooDbm003?l0003oe<cAomC<dOl0003oe/g@o`000?oH
cLoo0000omS>col0003of<k?o`0000;of]3?0ol00003omkBc003o`000?oQe<_ohMC;00;o000000?o
hmK9o`000?oTelT00_l00002onSIa@;o000000Kok=c3o`000?o_g/3okmk0o`000?oahKd4o`000003
ooWU[?l0003o000000Co0000;ooonfX00ol0003ooo]ZoookJP18oookJP00]OoonfX3o`0009Wooo]Z
0ol00002on_;]0?o000000GokLneo`000?l0003ok]6fo`000002onkB]`03o`000?o^e;Wo000000;o
00000_oZf/<01?l0003oj][3o`000?o[g<D2o`000006on[MaOl0003ojMg7onWMaol0003ojMo80ol0
00001?oRh]?o0000on;Od_oRgm83o`0000;ogmoE00?o0000omoQe_l000000_l000001OoGgmgoeMoO
omGOgol0003oe]kN00;o00000ooAbM801Ol0003odl[Ao`000?oDbm3o000000;oe<cA0_l00002omK=
d003o`000?oHc/oof<k?00;o00000_oJd<l00ol0003ofm7?om_Ac`02o`000005omkBc?l0003o0000
on7Dbol000000_oQeL/00ol0003oi=O9onCGb@02o`000003onSIaOl0003o000000;ok=c300Co0000
onoN`?l0003okn2o0ol000000ooei;Oo0000ooWU[006o`0002oooo]Z00?o0000oookJ_oonfX0B?oo
nfX00;?ooo]Z0_l0002KoookJP03o`000?o^aj_ok/N[00?o00000_o/cK@02_l0003okLneong?]Ol0
003ok]6fo`000?o^d[Oo0000onoE^?l00002onoG^P04o`000?oZf/?o0000on_Ma0;o000000?ojmc5
o`000?oZgLD00_l000001OoYgLOo0000o`000?l0003oj>3:00?o000000GohN?Eo`000?l0003oh>CF
o`000002omoOe@?o00000_oLh=P01?l0003oeMoOo`000?oCgn43o`0000?odLWB0_l000000ooCb]7o
0000o`000002omC<d@0<o`000?oEcM7oeLgAo`000?oFcM3o0000omS>col0003ofLo?o`000?oJd<oo
00000_oKdLl2o`000005omgBc_l0003ogm?<omoCc?l000000ooQeL/01?l0003oi=O9o`000?oSf</2
o`000005onWJa_l0003ok=c3o`000?o]g/<00_l000000oo_h;oo0000oo?R^`02o`000004ooOU]Ol0
003o0000oo_WX`Co0000<?oonfX00ol0003ooo]ZoookJP17oookJP00/?oonfX3o`0009gooo]Z0_l0
00001?o^aj_o0000onc;/_l00002onc=]003o`000?o]ckGokLne00;o000000Gok]>go`000?o_eKSo
kmFho`000002onoG^P?o000000?ojmg4o`000?o[g<D00ol000001_oZglOo0000o`000?oYglSo0000
onSPbPCo000000?ohN?Eo`000?oPi=H00_l000001?oOgmGo0000omgUfOl00002omcPf0?o00000_oC
gn42o`000004om39dol0003odLWBo`0000;odL[C00Go0000om?;d_l0003oe<cAo`000004omG=d@03
o`000?oGc]7o000000?ofLo?00Co0000om_AcooKdLoo00000_oKd/l2o`000003omoCc?l0003o0000
00;ohMG;00?o0000on;Gbol000000_oSf</01?l0003oim_7o`000?oYflH2o`000004ongN`ol0003o
kn2oonoP_`;o000000?oln>ko`000?ogiKD00_l000000ookij?o0000o`000002o`00037ooo]Z00?o
0000oookJ_oonfX0A_oonfX00:kooo]Z0_l0002OoookJP05o`000?o_ajWoklNYo`000?o_bJ/00_l0
00000oo/cKCo0000onk@]@02o`000007onkA]_l0003ok]>go`000?o_eKSo0000onoG^@02o`000003
onoI^_l0003okm^m00?o000000Koj^38o`000?oZglOoj]o7o`000?oYglP3o`000004onSQbol0003o
inC>onOTcP?o000000CognGHo`000?l0003ogNGI0_l000001OoLh=So0000o`000?l0003ofn?K00?o
00000_o@bM<2o`0000?odL[C00Co0000om?;d_oCbm;o00000ooEcM401?l0003oe/gBo`000?oGc]42
o`000005omW?col0003o0000om_Acol000000ooKd/l00ol0003ogM?>o`000002omoDc@;o00000_oR
el/01?l0003ohmS;o`000?oUf/X4o`0000;okMk300Co0000onoP_ol0003o00000_ochk/01?l0003o
mnFeo`000?ojj:/5o`00037ooo]Z00?o0000oookJ_oonfX0A_oonfX00:_ooo]Z0ol0002QoookJP07
o`000?o_ajWoklNYo`000?o_bJ_o0000oo7;ZP02o`000004onk@]Ol0003ok]6fonkA]P;o000000Go
kmJho`000?o_ekWokmNio`000002onoI^P03o`000?o_fkgo000000;o000000Coj^38o`000?oZglOo
j]o70_l000001OoYh/[o0000onSQbooXhL_o000000;oinC>0ol000001OoOiMSo0000omgUfOl0003o
g>GK00;o000000Kog>3Io`000?oKhm_o0000omOOgOl00002om39d`03o`000?o@bM?o000000;odL[C
00Go0000om;;dol0003odl_Bo`000002omG=d@05o`000?oFcM;oe/gBomK=d_l000000_oGcm401?l0
003ofM3@omW@d?l00003om_Bc`;o000000GogM?>o`000?l0003ogmC=o`000002on;Gb`?o00000_oU
f/X02ol0003oj=c8onSLb?l0003okMk3o`000?o]gl?o0000oo3Q_ol0003oln>k00Co000000?on^R[
o`000?l000000ol0000boookJP03o`000?oonf[ooo]Z04Gooo]Z002YoookJP;o0000Y?oonfX3o`00
0004oo39ZOl0003olL^Zoo7;ZP;o000000Sok]2eo`000?o^dKKo0000onoD]ol0003okmJho`0000;o
kmNi00[o0000onoI^_l0003ol=^lo`000?o`g[ko0000onkN`Ol0003oj^?90ol00002onWRbP04o`00
0?oXhL_o0000onOTcP;o000000?oiN?@o`000?oUiM400ol00002omcUf`03o`000?oLh=Wo000000;o
000000GoemoMo`000?l0003od<WCo`000003om39d`;o00000_oBbm<2o`000003omC<d_l0003o0000
00?oe/gB0_l000001?oGcm7o0000o`000?oId=02o`0000;ofm;?00Co0000omcCcooLdloo00000_oN
e<h2o`000004on;Gbol0003ohmS;o`0000;oiM[:0_l000001OoXg<So0000onOMbOl0003okMo300?o
000000OolN>oo`000?l0003o0000ooOW]?l0003on^R[00Go0000<_oonfX00ol0003ooo]ZoookJP15
oookJP00Y_oonfX3o`000:Gooo]Z00Ko0000oo36Yoo`aZOo0000oo39ZOl00002oo7;ZP05o`000?oa
cZko0000onoC]_l000000_o_e;L00ol0003okmJho`000002o`000004oo3J^_l0003ol=^loo3K_0;o
000000?okmjoo`000?l000000_l000001OoYi<_o0000onWRb_l0003oj>K?00;o000000?oinC>o`00
0?oUhm000ol000001?oSi=?o0000o`000?oLiM/3o`000004omWUg_l0003o0000o`0000;oc/SD00Co
0000om39doo@bM?od<WC0_l00002om;;d`05o`000?oBc=?o0000omC<d_l000000ooFcM801?l0003o
e/kBomK>d_l00002omS@d@03o`000?oJdM3of]7@00;o00000_oLdll2o`000005omkDc_l0003o0000
on3FcOl000000_oSf</00ol0003oiM[:o`000002onKKbP03o`000?oWgLWoimg900Go000000?olN>o
o`000?odiKX02Ol0000coookJP03o`000?oonf[ooo]Z04Cooo]Z002SoookJP?o0000Z?oonfX01Ol0
003ol<JWoo36Yol0003ol<VY00?o000000_ol/j[o`000?l0003okm>fo`000?o_e;Oo0000oo3H^Ol0
003ol=Vio`000002oo3J^P03o`000?o`fkco000000;o000000?okmjoo`000?o_hL400ol000001_oY
i/go0000o`000?oXi/oo0000onOTcP?o000000KoiNGAo`000?oSi=?ohnCCo`000?oSi]@3o`0000;o
fNGN00Go0000olg8eOo=b=Go0000olk8e002o`000006om39dol0003odL_Do`000?oBbm?o00000ooB
c=<01Ol0003oe<gBo`000?oFcM;o000000;oe/kB0_l00002omS@d@;o000000Kof]7@o`000?oLdloo
g=??o`000?oLe=02o`0000;og]K?0_l000001?oSf<_o0000on?Ic?l00003onKKbP03o`000?oWgLWo
000000;o000000Cok>75o`000?oahkoolN>o1Ol000000oojjJWo0000o`000003o`0003Cooo]Z00?o
0000oookJ_oonfX0@ooonfX00:7ooo]Z0_l0002[oookJP05o`000?o`aZOo0000oo79Yol000000_ob
bjT01?l0003ol/j[o`000?obd:h3o`0000;ol=Ri00Wo0000oo3I^Ol0003ol=Zjo`000?o`gKco0000
oo3N_Ol000000_o_g[l2o`000003onkR`ol0003o000000;o000000Ooj>K?o`000?l0003o0000onKY
d_l0003oiNGA00;o000000GohnCCo`000?l0003o0000on;Ye`02o`000003omWUg_l0003ocLSE00?o
cLSE00Co0000olk9eOo>bMGo00000ooAbm@02Ol0003od/cCom;<dooBc=?o0000om;=e?l0003oe<gB
o`000002omK>dP03o`000?oGcm;oeloB00;o00000_oHdM82o`000005omcCcol0003og=C@omcDd?l0
00000_oNe/l01?l0003og]O@o`000?l00002on?Ic003o`000?oVfl[oi]_:00?o000000CojMo8o`00
0?o/hLGok>751?l000000ooei[Wo0000ooOX/`03o`000004oo_XVol0003o0000o`0003Cooo]Z00?o
0000oookJ_oonfX0@ooonfX009kooo]Z0ol0002/oookJP03o`000?oaaZGo000000;olLVW00?o0000
oo;;ZOobbjT00_l000001_ocd:co0000oo?C[_ocdjko0000oo3H^@?o000000Sol=flo`000?o`gKco
l=flo`000?o`g[go0000onoN_`;o00000_o^h/<00ol0003ok^G5o`000002o`000003onOXd?l0003o
i^WB00?o000000Kohn[Fo`000?l0003ohnKDo`000?oRjML2o`000003omgTfOl0003ocLSE00;ocLSE
00Co0000olk9e_l0003oc/WE0_l00002om7;e005o`000?oAbmCo0000om;<dol000000_oBcM@3o`00
0003omK>d_l0003oeloB00;oeloB00?o0000omSAd_oHdM800_l000000ooJd]7o0000omcDd002omcD
d003o`000?oNe/oo000000;og]O@0_l000000ooSfLco0000onCJc002o`00000<onKLb_l0003ojMo8
onWOb?l0003ok>75o`000?o/h/Oo0000oo7T_ol0003omNJi0_l000001?ohjK7o0000o`000?okj9/3
o`0003Gooo]Z00?o0000oookJ_oonfX0@_oonfX009cooo]Z0_l0002_oookJP03o`000?oaaZGo0000
00;olLVW00Oo0000oo;;ZOl0003olljZo`000?ocd:co000000;olm>^0ol000001Ooaf[Wo0000oo3M
_?l0003ol=fl00?o000000Col>6oo`000?o_hL7o00000_o^h/<2o`000003ongUaol0003okNO800Go
000000Cohn[Fo`000?l0003ohnKD0ol000000ooNiMWo0000o`000003olg8e@05o`000?o>bMKoc/WF
olk9e_l000000_o?b]H2o`0000?odL_D00So0000om;=e?oBcMCo0000om?>e?l0003oe<kCo`0000?o
eloB0_l000001?oHdM;o0000omWBd_oId]82o`0000;og=C@00?o0000omgEd?l000000ooNem000ol0
003oh]W>o`000002onCJc008o`000?oVg<[oi]c:o`000?oYglSo0000onWPb?l00002oncRa`Co0000
00?omNRjo`000?ohjK401_l0000foookJP03o`000?oonf[ooo]Z047ooo]Z002IoookJP?o0000/Ooo
nfX2o`000005oo;8YOl0003o0000oo?;Yol000000_occZX2o`000006ooCC[?l0003o0000ooCE[_l0
003om=Ra0ol000001?oagkgo0000o`000?l00002oo3Q_`;o000000CoknC2o`000?l0003o00000_o]
iLL00ol0003okNO8o`000003o`000003on?Ze_l0003oh^_H00Co000000Oog^GIo`000?l0003oblOG
o`000?o=b=Go000000?oc/WF0_l000000oo?b]Ko0000o`000003om7;e0;o000000?od/gDo`000?oC
c]@00_oCc]@2o`0000;oeloB00Co0000omOAdooGdM?o00000_oId]800ol0003ofM?Bo`000002o`00
00;ogMG@00ko0000omkGd?oNem3o0000omoHd?l0003oh][>o`000?oTf/co0000onKLb_l0003oimk:
o`0000;ojN3800?o0000oncRaol000000_l000000oo_i/?o0000o`000004o`000004oo[YV?l0003o
0000o`0003Kooo]Z00?o0000oookJ_oonfX0@OoonfX009Oooo]Z0_l0002coookJP03o`000?obaJ;o
000000;ol/RU00?o0000oo?;Yol000000_l000002?oddJ[o0000ooCC[?oddjco0000ooCE[_l0003o
m=Ra0ol000001Ooagkgo0000oo3R_ol0003ol>6o00?o000000GoknC2o`000?o^iLCo0000ongUa`03
o`000003on_Wbol0003ojn[<00Go000000Coh>_Jo`000?oNiMWo00000_o:amL00ol0003oblOGo`00
0003olk9eP04o`000?o>b]Koc/[Fo`0000;ocl_F00?o0000om7;e?l000000_oAc=D01_l0003odlkD
om?>e?oCc]Co0000om?>e@?o00000_oGdM<2o`000003omWBd_l0003ofM?B00;ofM?B00Go0000omgE
d?oMeM3o0000omgFd002o`0000;ogmS@00Ko0000on;Jc_oRf/ko0000onCKcOl00002onONbP03o`00
0?oYh<So000000;o000000?okNC6o`000?o_i/<01ol000000oojjISo0000o`00000hoookJP03o`00
0?oonf[ooo]Z043ooo]Z002DoookJP?o0000]OoonfX00ol0003ol/FRo`000002oo;8Y@;o00000_od
cZP00ol0003om=6Zo`000002ooCC[0;o000000GomMR_o`000?oef[;o0000ooCL]003o`000005oo3T
`?l0003ol>K3o`000?o_i<801Ol000001_o]j<So0000on_Wboo[il_o0000on_Zc0;o000000?oj>c@
o`000?oPjmX00ol00004ol[7e`05o`000?o;b=Oo0000olk9e_l000000_o>b]H2o`0000?ocl_F00Go
0000om7<eOoAc=GodLcEo`000002om?>e003o`000?oCc]GodlkE00;o00000_oGdM<01?l0003of=7C
omSAdol00003omWCdP04o`000?oHe=Co0000o`0000;ogMK@00Go0000omoHd?oOf=3o0000on3Id002
o`000004on?Kc_l0003o0000onONbP?o000000Coj^78o`000?o]i<KokNC60_l000001Ooaj<;o0000
oo?Z_Ol0003omnbc00Go0000>?oonfX00ol0003ooo]ZoookJP10oookJP00T_oonfX2o`000;Sooo]Z
0_l000001Oocb:;o0000o`000?odbjGo000000;om<jX0_l000002_oedj_o0000o`000?oeeZgo0000
ooGH[ol0003omMZbo`000?odg;@3o`000003oo3T`?l0003ol>K300;o000000Gok^W6o`000?o^j<Ko
0000ongXb002o`000003on_Wbol0003o000000;o000000?oj>c@o`000?l000000ol00003ol[7e`04
o`000?o:b=So0000ol_8e`;o00000_o>b]H02ol0003oc/_Folk;e_l0003ocl_Fo`000?o?c=Ko0000
om7<eOl0003od/gE00;o00000_oCc]D01Ol0003od/oFo`000?oGdM?o000000?of=7C00Co0000omWC
d_oIdm;o00000_oHe=@2o`000005omgFd?l0003o0000omoHd?l000000_oPfM001?l0003ohm_>o`00
0?oRg=02o`000006onOObol0003oj^78on[Qb?l0003okNC60_l00002oo7X`P03o`000?ocj[go0000
00?o000000?on>bKo`000?l00000>OoonfX00ol0003ooo]ZoookJP0ooookJP00SooonfX3o`000;Wo
oo]Z00?o0000oo?4WOl000000_ocb:800ol0003om<^Uo`000002o`000004ooKAZ?l0003omM>[o`00
00;omMJ]0_l000001ooffk3o0000ooGL/_l0003om=jeo`000?odhKP01?l00002onkYaP05o`000?o^
j<Ko0000o`000?o[k/d00_l000000oo[j/co0000o`000002o`000004onGZdol0003o0000o`0000?o
b/OG00Wo0000ol[8f?o:b=Sob/SHo`000?o;bMSo0000olk:e_l000001?o>bmH00ol0003oclcFolo<
eP02o`0000;od/gE00Co0000om?>eOoCc]Go00000ooBcmH01_l0003of=7ComSAdooHdM?o0000omSB
d`;o00000_oHe=@2o`000005omcFd_l0003og]OAomkGdOl000000_oPfM03o`0000;oh]c@0_l00000
2OoWgl_o0000on[Qb?l0003ojn?8o`000?o^iLGo0000oo7X`P04o`000003ooK]]_l0003o000000?o
0000>_oonfX00ol0003ooo]ZoookJP0noookJP00SOoonfX2o`000;cooo]Z0ol00002oo?8XP;o0000
0_oecZD01_l0003om]6Xo`000?oedj_o0000ooGF[@;o00000_offk001Ol0003omMbbo`000?l0003o
mN6f00Go000000?ok^W6o`000?l000000_l00002on_^c@0>o`000?o[j/co0000o`000?oXk=3o0000
onGZdol0003oalKJo`000?o7amWo0000ol[7eol00003ol[8f0;oblWH00?o0000ol_9f?l000000oo>
bmH02?l0003oclcGo`000?o?c=Ko0000om3=eol0003od/gE0_l000000ooCc]Go0000om;?eP02om;?
eP?o000000?of=7Co`000?oHd]<00_l00002omSDe003o`000?oJe]?of]KC00;o000000Oog]OAo`00
0?l0003oh=W@o`000?oQfm3o000000?oh]c@00Ko0000onKOcOl0003oj>3;o`000?o[hlP3o`000007
onkVaOl0003o0000o`000?odjk_o0000ooK]]P05o`0003[ooo]Z00?o0000oookJ_oonfX0?_oonfX0
08[ooo]Z0ol0002noookJPGo000000ComL^Ro`000?oecZGomLjU0_l000001_oge:So0000ooOGZol0
003om]V^o`0000;om]^`0_l000001oofgk?o0000ooGQ]_l0003om>>io`000?ociK/01?l000001?o/
kL[o0000on_^cOo[k/d3o`0000;oj>c@0_l00003olO6fP03o`000?o7amWo000000;ob/SH00?o0000
ol_9f?o;bMP00_o;bMP01Ol0003oc<[Ho`000?o>bmKo000000?oclcG00?o0000om3=eoo@cML00_l0
0002om;>eP05o`000?oBcmKod/oFom;?e_l000000_oDdMH2o`000006omSBdol0003of=?Do`000?oH
e=Co00000ooJe]<00ol0003og=OBo`000002omkHd@04o`000?oQfm3ohM_@o`0000;oh]c@00Co0000
onCNcol0003oin7=0ol000001_o[i<So0000o`000?o^i/Go0000oo7Y`@Wo0000>ooonfX00ol0003o
oo]ZoookJP0moookJP00QooonfX3o`000<3ooo]Z00oo0000ooO0Soog`8oo0000ooK7W?l0003omL^R
o`000?oecZGo0000ooOAYOl0003ommBXo`000?ogej/00_l000001?ogg:oo0000o`000?l00002ooKO
/`03o`000?oehKKo000000?o000000?olnNmo`000?objKl00ol000001_o[k/go0000o`000?oXl=7o
0000onS/d0;o00001Oo7a]X2o`000003ol[8f?l0003oblWH00;oblWH00Co0000ol_:fOl0003oc<[H
0_l00002olo<e`05o`000?o?c=Oo0000om3=eol000000_o@c]L00ol0003od/kFo`000002om;?eP07
o`000?oDdMKoe=7FomCAe_l0003oe];Eo`000003omSCe004o`000?oJe]?of]KCom[Fd`Co000000Ko
g]SAo`000?l0003ohM_@o`000?oRg=02o`000004onCNcol0003o0000onOQc@?o000000?ojnC8o`00
0?o^i/D01_l000000oogk[;o0000o`000003o`0003_ooo]Z00?o0000oookJ_oonfX0?OoonfX008Go
oo]Z0_l00033oookJP03o`000?og`8ooml2?00Co000000KomljRo`000?ogdJGomm6Uo`000?oge:P2
o`000007ooOJ[?l0003ommb_o`000?ofg[7o0000ooKO/`04o`000004ooCU^_l0003olnNmoo?W_@co
00001?o7a]X01Ol0003oalOJo`000?o7am[o000000?oblWH00Wo0000ol_:fOo;b]Wobl[Io`000?o<
bmWo0000olo<eol000000oo?c=L01?l0003od<kGom3>eoo@c]L2o`000003om;?e_l0003o000000?o
e=7F00?oeM;Fo`000?oFd]D00_l000000ooHdmCo0000o`000002om[Fd`03o`000?oKemCo000000;o
gMSC1?l00002on;Ld004o`000?oTg/oo0000onCOc`;o000000?oi^;>o`000?oZiLX00ol000001Oo_
j<Go0000oo;Z`?l0003om>bj00Oo0000??oonfX00ol0003ooo]ZoookJP0loookJP00P_oonfX3o`00
0<Gooo]Z0ol000000ooi`Xko0000ooW7U005o`000007ooSEY_l0003on=NYo`000?ogfZco0000ooOL
[`02o`000009ooOQ/_l0003o0000o`000?oei;Oo0000ooCU^_l0003olnNm00;o000000GolN[2o`00
0?o_k<Go0000ono^aP04o`000004ol?5g?l0003oalKJolO6fP;o00000oo7amX01Ol0003ob<SJo`00
0?o;bMSo000000?obl[I00Gobl_Io`000?o<bmWoc<_Io`000003olo<e`;o00000_o@c]L01Ol0003o
d<oGo`000?oBcmKo000000;oe=7F00Go0000omGBe_oEd]KoeM;Fo`000002omOCeP03o`000?oIe=Co
fMCD00;o000000GofmODo`000?l0003ogMSCo`000002omgId`03o`000?oRg=3oh]c@00?o00000_oT
gll01Ol0003oi^;>o`000?l0003oj^G:00;o000000CoknS5o`000?l0003ol^[00ol000000oogkk3o
0000o`000003o`0003gooo]Z00?o0000oookJ_oonfX0>ooonfX0083ooo]Z0_l00038oookJP0@o`00
0?oi_HKo0000ooW2S_l0003onLNDo`000?ohbi[o0000ooWAXOl0003on=FVo`000?ohejWo0000ooOJ
[0;o000000Gon=n`o`000?oghK;o0000ooKS]@02o`000007ooGX^Ol0003om>Vko`000?ocj[ko0000
oo7Z`P04o`000003ong^b_l0003o000000?o`lGL0_l00003olO7fP04o`000?o7b=[o0000olS8fP;o
00000_o;b]T01?l0003obl_Iol_;fOo;bmT2o`000004olg<fOl0003oclcGo`0000;oclgH0_l00002
om3?e`?o000000?oe=7Fo`000?oEd]H00_oEd]H00ooEdmKo0000omOCeP02o`000005omWDe?l0003o
0000om_Ge?l000000_oKf=@02Ol0003ogMWComgIdooMfM?o0000on;Ld?l0003oh]g@o`000003onCO
c`;o00000_oWhld00ol0003ojnK;o`000005o`000003ooG^^?l0003omnn`00Go0000?OoonfX00ol0
003ooo]ZoookJP0koookJP00OOoonfX3o`000<[ooo]Z00Wo0000ooVmQ_l0003o0000oo[5SOl0003o
n/VBo`000?ojcYX00_l000002_oheJKo0000o`000?oifj[o0000ooSO[_l0003on=n`o`000?oghK83
o`0000;omNRi00?o0000ooCY^ol000001?l000001?o_k/Go0000ong^b_l00002ol?5g004o`000?o3
aMco0000o`0000?oalOJ00Wo0000olO8f_o7b=[oalSJo`000?o8bM[o0000ol_:fOl000001?o;bmT0
0ol0003ocLcIolg<f@02o`0000?oclgH00Co0000om3?eoo@cmOo00000_oAcmP2o`0000;oeM;F00Go
0000omGCe_oEdmKoeM?Fo`000002omODeP04o`000?oIe]Co0000o`0000;ofmSD0_l00002omgId`06
o`000?oLf]Co0000o`000?oRgM3o00000_oTgll2o`0000?oin?=00Oo0000on_Vbol0003o0000onkZ
aol0003ol^bo00Wo0000?_oonfX00ol0003ooo]ZoookJP0joookJP00NooonfX2o`000<gooo]Z1?l0
00000oojaHgo0000oo[9TP05o`000005ooWHYOl0003onM^Zo`000?ohgjh01Ol000001?ofi[Ko0000
ooGX^Ooej;T5o`000003oo7^`ol0003oknk500;o00001?o3aM`01_l0003o`lKLol?6g?l0003oalOJ
o`0000?oalSJ0_o7bM/00ol0003ob<WJo`000003ol_;f@0=o`000?o<bmWo0000olg<fOl0003ocLgI
o`000?o?cMSo0000om3>f?l0003od<oGo`000003om7?f0;o000000?oeM;Fo`000?oEdmH00_oEdmH2
o`000003omODe_l0003oemGF00;o00000_oKf=@00ol0003og=WDomcIe002o`000006omcJe?l0003o
0000on7Md_l0003oh]kA0_l000001?oUhLoo0000onOScOoWhld3o`000003on[Wc?l0003ok^[700Go
000000?om_2_o`000?l000000_l0000ooookJP03o`000?oonf[ooo]Z03[ooo]Z001hoookJP?o0000
cooonfX01Ol0003on[Qho`000?l0003on/F=00?o000000?onlbBo`000?okd9P01ol000001Oohi;;o
0000ooKW]Ol0003om^Jf00Co000000?ol^noo`000?obkL001Ol00003ol?5g005o`000?o3a]co`lKL
o`000?o3a]`00_l00002olO8fP03o`000?o7bM_oalWK00;oalWK00Go0000olS:fol0003obl_Io`00
0003olc;f@05o`000?o=cMWocLgIolg=fOl000000oo@c]P00ol0003odLoHom7?f002o`0000;odM3H
00Ko0000omGCe_oEdmKoeM?Fo`000?oFe=L2o`0000;oemGF0_l000000ooKf=Co0000omcIe002omcI
e004o`000?oLf]Co0000omkLe0?o000000Goh]kAo`000?oUhLoo0000onGRc`02o`000003onSUcOl0
003oj^O<00go0000@?oonfX00ol0003ooo]ZoookJP0ioookJP00M_oonfX2o`000=;ooo]Z00?o0000
ooZhN?l000000ol000001Oolahco0000oo_<T_l0003onm2H00[o000000Oom^Vfo`000?oek;Wo0000
oo?^_?l0003ol^no00Go00000_noa=h00ol0003o`lGLo`000004ol?6g005o`000?o4amco0000olO8
f_l000000oo7bM/00ol0003ob<WKo`000002olS:f`04o`000?o<bmWoc<_Io`0000;oc<cJ00Ko0000
olg=fOl0003ocLkJo`000?o@c]P2o`000003om7?f?l0003odM3H00;odM3H0ol000001OoEdmKo0000
omKDeooFe=Oo000000;oemGF00Co0000omOFf?oGe]So00000ooLfM@3o`0000;og]cD00?o0000on7N
d_oQg]800ol00002onGRc`03o`000?oXiLgo000000;o000000GojnW;o`000?o]jlSo0000oo3^``08
o`00047ooo]Z00?o0000oookJ_oonfX0>?oonfX007?ooo]Z0ol0003DoookJP;o000000GonkYfo`00
0?ol`X?o0000ooc7S002o`000003oog?T_l0003oo=>H00;o000000?onmZQo`000?okgJH03?l00000
0oo_llCo0000oko4gP03oko4gP;o00000_o3a]`2o`000005ol?7gOl0003oa<OLolC7g?l000000oo7
bM/01?l0003ob<WKolS9foo8bM/3o`000003olc;fOl0003oc<cJ00?oc<cJ00Go0000olg>f_o=c][o
cLkJo`000002om3?f009o`000?oAd=SodM3Hom7@f?l0003od=7Jo`000?oCdmSo000000;oe]CG0_l0
00000ooGeMKo0000omOFf002omOFf0;o000000Cog=WDo`000?oLf]Co00000ooNg=@01?l0003ohMkB
o`000?oPgm@2o`000006onGRcol0003o0000o`000?oYi/go00000_o[jL/00ol0003okN_8o`000002
o`000003oo?a_?l0003om?:b00Co0000@OoonfX00ol0003ooo]ZoookJP0hoookJP00LOoonfX2o`00
0=Oooo]Z0_l000000ook^WKo0000ooc2P`02o`000005oog:Rol0003ooLnBo`000?oldiP00ol00000
1Oolg:7o0000oo_OYOl0003on^:Z00[o00000onoa=h2o`000004oko5g_l0003o`lKLo`0000Co`lOM
0_l000001?o4b=go0000olO9fol00004olS9f`04o`000?o9bm_obL_Ko`0000?oc<cJ00?o0000olg=
f_l000000_o=c]X2o`000003om3?f?l0003o000000;odM3H00Co0000om3Af_o@dM[od=7J0_l00000
1OoFe=Oo0000omKEeooFeMOo000000?oemKH00Go0000omSHeol0003o0000omcJe002o`0000;og]cD
00?o0000omoMe?l000000_oPgm@01Ol0003oi>?Ao`000?oVhm3o000000;ojNK=00?o0000on_Ybol0
00000ol000000ooakl;o0000oo?a_006o`0004;ooo]Z00?o0000oookJ_oonfX0=ooonfX006kooo]Z
0ol0003IoookJPGo000000GooLB1o`000?ombX_o0000oog?TP03o`000005oogIW?l0003oo=bQo`00
0?okgjD00ol000001Ooiijko0000ooSZ/_l0003om^bf00Co00000_noa=h01?l0003o_lGNoko5g_no
aMh2o`0000Go`lOM00?o0000olC8gOo4b=d00_l00002olS9f`;o000000Sob<[Ko`000?o9bm_o0000
olW;fol0003oc<cJo`0000?ocLgJ0_l00002olk>fP05o`000?o@d=Wod=3Io`000?oAd=P00oo@dMX0
1?oCdmWo0000omCCf?l00003omKEe`04o`000?oGe]SoemKHo`0000;of=SG00?o0000om_Je_l00000
0_oLfmD2o`000006omoMe?l0003o0000on3Oe?l0003oh^7C1?l000001ooYi/go0000o`000?l0003o
k>[:o`000?o^kLH01_l000001?oclZ7o0000o`000?l00013oookJP03o`000?oonf[ooo]Z03Kooo]Z
001[oookJP?o0000g?oonfX2o`000004oo^`Gol0003o0000oog4P@;o000000?oo/f9o`000?ondY40
0_l000001?omfIco0000o`000?olh:42o`000005oo[UZOl0003onNN^o`000?ohj[800ol000001?nh
`^;o0000okk4g_l00004oko5gP05o`000?noaMoo_lGOo`000?o3amd00_l000002?o4amgo0000olC8
gOl0003oa<SMo`000?o8bM_o00001?o8b]/00ol0003obL_KolW;f`02o`0000CocLgJ00So0000olk>
f_o>c][o0000olk?f_l0003od=3Io`0000;od=7J00[o0000om?CfOoCdmWodm?Io`000?oDe=Wo0000
omKEeol0003oe]KG0_l00002omSHe`0:omWIeol0003o0000om_Keol0003og=_Eo`000?oOgMCo0000
omoOe0;o00000_oRhM<00ol0003oi>CAo`000002o`000003onWWcOl0003ok>[:00Ko000000?olo:i
o`000?l000001?l00013oookJP03o`000?oonf[ooo]Z03Kooo]Z001YoookJP;o0000gooonfX8o`00
0003ook=ROl0003oo]:A00?o000000?ooMfLo`000?olh:400_l000000oojiJWo0000o`000002o`00
00Go^<;R0_l00003oko5gP04o`000?noaMoo_lGOoko5g`;o00001?o4amd00ol0003oa<SMolC8g@02
o`0000?ob<[K00So0000olW;g?l0003obL_Ko`000?o:c=co0000olg=fP;o000000CocLkJo`000?o>
c][o00000_o>cmX3o`000003om3Af_l0003odm?I00?odm?I00Go0000omCDfOl0003o0000omKFe`02
o`000005omSHeol0003ofMWGomWIeol000000ooKfmL3o`0000;ogmoD00?o0000on;QdooRhM<00ol0
00000ooTiM?o0000onSXc`03o`000005onc/b_l0003o0000o`000?oal<402?l00014oookJP03o`00
0?oonf[ooo]Z03Gooo]Z001VoookJP?o0000hOoonfX5o`000004oofnL?l0003o0000ook=R@;o0000
00Soo]F@o`000?l0003ooMfLo`000?olh:7o0000oo_VY@?o00001?nh`^82o`0000;o^<;R0_l00002
oko5gP?o_lGO00Co0000oko6gol0003oa<OM0_l000001?o4b=go0000olC8gOl00002olG9g@03o`00
0?o8b]_o000000?obL_L00Go0000ol[<g?o:c=cob/cLo`000004olg>fP08o`000?o>cm[oc/oJo`00
0?o>d=_o0000om7AfOl00004om?Cf@03om?DfOl0003o000000;oe=GI00Co0000omOGf?l0003o0000
0ooIfML01_l0003ofm_Gom_Keol0003ofmcGo`0000;ogmoD0_l000001?oRhM?o0000on;Rdol00002
onCUd`03o`000?oXj<oo000000;o000000?ok>c:o`000?o_k/D02_l00014oookJP03o`000?oonf[o
oo]Z03Gooo]Z001ToookJP;o0000iOoonfX4o`000007oofnL?l0003o0000o`000?ood8Oo0000ookE
T008o`0000;o[[kV00Co0000okS2h_l0003o00001Onh`^82o`0000;o_lGO0_l00002oko6g`;o0000
1?o4b=d01?l0003oaLWMolG9gOo5bMd2o`0000?obL_L0_l00002ol[<g009o`000?o:cMco0000olg>
f_l0003ocLoKo`000?o>cm[o000000;oc]3K0ol00003om?Cf@;odmCI00?o0000omCEfOoDeMT00_l0
00000ooGemSo0000omWIe`02omWIe`04o`000?oJf]Oo0000o`0000;ofmcG00Co0000omoOe?l0003o
h>3D0_l000001?oRh]?o0000o`000?oTiM<3o`000003onOYdOl0003ojnc<00Co000000?olO:oo`00
0?oclkP01?l000000ooonf[o0000oookJP14oookJP03o`000?oonf[ooo]Z03Cooo]Z001QoookJP?o
0000j?oonfX4o`000008ook0KOl0003o0000ooo@Qol0003oo]F@o`000?ongIH4o`0000Go[[kV00?o
0000okS2h_nh`^800_nh`^82o`000003okS3h_l0003o000000;o_lGO0onoa]l00ol0003o`<KOo`00
0003olC8g@05o`000?o4b=go0000olG9gOl000000_o5b]h00ol0003obL_Lo`000002olW<g0;o0000
0_o:cM`2o`0000;ocLoK0_l00002olk@f`03o`000?o>dMcoc]7L00;o000000Oodm?Iom?DfOoCe=Wo
dmGIo`000?oDeMWo000000;oeMKI0_l00002omWIe`04o`000?oJf]Oo0000o`0000;ofmcG1?l00000
1OoPh=Co0000on;Rdol0003ohnCC00;o000000?oiNKBo`000?oWjM400ol000000ooZkLgo0000ono_
aP08o`000003oookJ_l0003ooo]Z04Gooo]Z00?o0000oookJ_oonfX0<ooonfX005oooo]Z0_l0003[
oookJPCo000000Goo/1]o`000?l0003o0000oooCQ@05o`0000?o[[kV0ol000000on^_^Ko0000okS2
hP02okS2hP03o`000?nh`n;o^<?R00;o^<?R0_l00003oko6g`07o`000?o0a]oo`<KOol36gol0003o
a<SMo`000003olC8g@04o`000?o5b]koaL[NolG:gP;o00000oo9c=`01ol0003ob/gLol[=g?l0003o
blkLo`000?o=cm/00_l00002olk@f`03o`000?o>dMcoc]7L00;oc]7L00?o0000om?DfOl000000ooC
eMT01?l0003oeMKIomGFfOoEe]T4o`000008om[Jeol0003of]_Ho`000?oKg=Oo0000om_Mf?l00002
omkPeP?o00000_oSi=<00ol0003oiNKBo`000002o`000004onS[d?l0003oj^g=on[]c@[o000000?o
oo]Zo`000?oonfX0AOoonfX00ol0003ooo]ZoookJP0coookJP00G?oonfX3o`000>kooo]Z0_l00000
0om1Q^Wo0000o`000004o`0000?oV;G/00Co0000ojjni_l0003o00001On^_^H3o`0000?o^<?R00?o
0000okS3honh`n<00_l00002oko6g`Co`<KO0_l00003olC8g@;o00000_o5b]h02Ol0003oa/_No`00
0?o9c=co0000olW=g?l0003ob/gLo`000003ol_>g003o`000?o>d=_o000000;oc]3K0oo>dM`01?l0
003od=;Ko`000?l00003om?Ef@;o00000_oEe]T01_l0003oe=OKomCGfol0003of][Go`0000;of]_H
0_l000001ooKgMSo0000o`000?oNh=Ko0000omkQeol000000_oSi=<3o`000006onKXdOl0003oj>_@
onS[d?l0003oj^g=0_l000000oo]lLWo0000oo3d`@06o`000003oookJ_l0003ooo]Z04Kooo]Z00?o
0000oookJ_oonfX0<_oonfX005[ooo]Z0_l0003boookJP06o`11a?l0003o0000o`000?m/Wnoo0000
1_nH]N`00ol0003o[[kVojjniP05ojjniP04o`000?nh`n;o^<?RokS3hP;o00001?nh`n<2o`0000?o
`<KO0_l00002ol;7gP03o`000?o4b=go000000;oaLWN0_l00002olK;gP;o00000oo9cM`02Ol0003o
blkLol_>g?o;c]co0000ol_?gOl0003oc]3Ko`000002olkAg0;o00000_o@d]/01Ol0003odMCKo`00
0?oCeMWo000000;oe=KJ0_l00002omCGf`03omKIf_l0003o000000?of]_H00Co0000om_Mf?l0003o
gMoG0_l00002omkQe`05o`000?oSi=?o0000on?Udol000000_oVj=400ol0003oj>_@o`000003o`00
00;okO792?l000000ooonf[o0000oookJP16oookJP03o`000?oonf[ooo]Z03;ooo]Z001GoookJP?o
0000m?oonfX2o`0000;oAHKX1Ol00004oiRek003o`000?n^_^Ko[[kV00?o00000_n^_nH00ol0003o
^<?Ro`000004okS3h`04o`000?nia>?o0000o`0000;o`<KO00?o0000ol;7g_o2amh00_o2amh2o`00
00?oaLWN00Co0000olK;g_o6bmko00000_o6bmh01?l0003obLgLo`000?l00002ol_>g003o`000?o;
cmgobloM00?o000000?oc]7Lo`000?o@d]/00_o@d]/2o`0000;odMCK00Oo0000omCFf_oDe][oe=KJ
o`000?oDem_o000000;oe]WJ00Co0000omSKfOl0003of]_H0ol00002omgOe`03o`000?oNhMOog^7G
00Co000000?ohnGCo`000?oVj=400ol000001OoYk<oo0000on__c?l0003okO7900?o000000?ol?Jj
o`000?l000000_l00002oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0<OoonfX0
05Cooo]Z0ol0003hoookJP;o000000CoAHKXo`000?l0003o00001onH]N`2o`0000Ko[[oV00Co0000
okS3honh`n?o^<?S0_l00003okW4h`;o00001?o2amh2o`000008ol78h?l0003oaLWNo`000?o5b]ko
0000olK;g_l00003olK;gP;o00000_o:cM`2o`0000;obloM00Go0000ol_?gOl0003oc]3Ko`000003
om3Bf`03o`000?o@dmcod=?L00?o000000?oe=KJo`000?oDemX00_l00003omKIfP06o`000?oHfmWo
f=_Io`000?oJg=So00000_oMgmL2o`000004omkQeol0003og^;Ho`0000;oh^GE0ol000000ooVjM;o
0000onW/c`06o`000003onoe`ol0003o000000Co00000_oonfX00ol0003ooo]ZoookJP17oookJP03
o`000?oonf[ooo]Z033ooo]Z001BoookJP;o0000o?oonfX2o`000005odZ6j?l0003o0000o`000?nH
]N`00ol00003oiVfk003o`000?n^_nKo[[oV00?o00000_n^_nH00ol0003o^<?So`000006okW4h`05
o`000?o2amko`/ONol;7g_l000001?o1b>001Ol0003oaL[NolG:g_o5b]ko000000?oa/_N00Co0000
olK<g_l0003ob/gL0_l00002ol_?g@03o`000?o;cmgobloM00?o00000_o@d]/01_l0003od=?Lom3C
g?o@dmco0000om;Eg0;o00000_oDemX01_l0003oe]WJomKIf_oFfM[o0000omOJfP;o000000Gof=cJ
o`000?l0003ogMoGo`000002omgPf007o`000?oNh]Sog^;Ho`000?oRiMGo0000on7Ve`02o`000008
onKYd_l0003o0000onW]col0003ok?3;o`000?o^llL4o`000004onkfZOl0003o0000o`0000;ooo]Z
00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP0`oookJP00CooonfX3o`000?kooo]Z1ol0
0007oiVfk0;o00001_n^_nH01?l0003o^LCSokW4honia><3o`0000;o^LCR00?o0000ol;7g_l00000
0oo1b>001Ol0003o`LWPol79h?l0003oaL[N00;o00000_o6bmh00ol0003oa/cNolK<gP02o`000004
ol[>gOl0003obloMo`0000;obloM00Co0000olcAgOo<dMgoc=7M0_l00003om3Cg003om7Dg?l0003o
000000?od]KL0_l00002omKIfP07o`000?oGf][o0000o`000?oHg=[o0000omSMf`02o`0000;ogN3H
0_l000001OoNh]So0000omoTeol0003ohNKG00;o000000CoiN[Co`000?l0003ojNg?0_l000001Oo/
l<_o0000o`000?l0003okoJo00;o000000Cok_JYo`000?l0003o00000ooonfX00ol0003ooo]Zoook
JP17oookJP03o`000?oonf[ooo]Z02oooo]Z001=oookJP;o0000oooonfX3oookJP06o`9@cOl0003o
ChOWo`000?maXNko00000_nI]^`3o`0000;oV[K/00?o0000ojjoi_n^_nH00ol00002ojo0iP04o`00
0?nia>?o0000o`0000Go^LCR00Co0000ol78h?o1b>3o`LSP0_l00004ol79h003o`000?o6bmkoa/_N
00;o00000_o6c=h01_l0003oalgNolO=g_l0003ob/kMo`0000;obloM00?o0000olcAgOo<dMd00_o<
dMd00ol0003od=?Lo`000003om7Dg004o`000?oBe]cod]KLom;Fg0;o000000Koe=OJo`000?l0003o
em[Jo`000?oGfmX2o`0000;of=gK0_l000000ooMh=So0000omgQf002o`000005omoTeol0003o0000
o`000?oRj=H00_l000000ooUjmCo0000o`000004o`000003onkdaOl0003okoJo00Go00001?oonfX0
0ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02oooo]Z001:oookJP?o0000oooonfX5oook
JP03o`000?l2D<go000000;oChOW0ol00006oiZfk0;o00001_n_`>H00ol0003o^LCRokW4hP02okW4
hP;o000000Go^/CRo`000?l0003o`LSPo`000004ol79h004o`000?o2b^7o0000olK;gP;o00000_o6
c=h01?l0003oalgNolO=g_o7cMh3o`0000;obloM1?o<dMd00oo=d]go0000o`000003om7Dg0;o0000
0_oBe]`00ol0003od]OLo`000002o`000005omOJf_l0003oem_JomOKf_l000000_oHgM/2o`000003
om_PfOl0003ogN7H00;o000000CognCGo`000?l0003o00000_oRj=H00ol0003oiN_Do`000002o`00
0003onS_dOl0003ok?7;00Co000000?okoNco`000?l000000_l00004oookJP03o`000?oonf[ooo]Z
04Sooo]Z00?o0000oookJ_oonfX0;_oonfX004Sooo]Z0_l0003ooookJPWooo]Z0_l000001Om?QnOo
0000o`000?meX^ko000000;oV[K/0ol000000onK]n_o0000ojo0iP03ojo0iP;o00000_n``NH01?l0
003o^LCRo`000?l00004ok[4hP;o00000oo1bN000ol0003o`/[Qol;:h@02ol;:h@03o`000?o6c=ko
000000;oa/cN0_o7cMh2o`000004olW>g_l0003obloMo`0000?oc=7M00So0000olgBgOo=d]go0000
olkDg_l0003odMCLo`0000;odMGL0_l000001?oBemco0000om;HgOoBf=d2o`0000;oem_J0_l00000
1_oHgM_o0000omWOfooIgm_o0000omcQfPCo000000Coh>GGo`000?oRj=Koh^SF0ol000000ooTk=Go
0000onS_d@04o`000004ongea_l0003o0000onog/`?o00001OoonfX00ol0003ooo]ZoookJP18oook
JP;o0000;ooonfX004Gooo]Z0ol0003ooookJP_ooo]Z0_l00002oeb;i@Go00001OnK]n/01?l0003o
[l3Vo`000?l00005ok31iP04o`000?nja>;o^/CRok[4hP;o000000Co^lGRo`000?l0003o`LWP0_l0
0003ol;:h@04o`000?o2bn7o`/_Qol;;h@;o00000_o7cMh01?l0003obLkNolW>g_o9c]h3o`0000;o
c=7M0oo=d]d01Oo=dmko0000olkDg_o>e=ko000000?odMGL00?o0000om;Gg?l000000ooBf=d2o`00
0003omOKf_l0003oemcK00;o00000_oIgm/01ooJh=_o0000omcQf_l0003og>;Jo`000?oPiML00_l0
00001?oRj=Ko0000on?Ye_l00002onC/e@Co000000?ojO?>o`000?l000001_l00005oookJP03o`00
0?oonf[ooo]Z04Gooo]Z0ol000000ooonf[o0000oookJP0^oookJP00@ooonfX2o`000?oooo]Z3ooo
nfX2o`0000;oG8_U00?o0000ogVSkOl000001onK]n/01?l0003o/<7Vok31i_n``NH3o`000003ok71
i_l0003o^/CR00;o00001?nkaN82o`0000?o`/[Q0_l00004ol;;h@04olK<g_l0003oalgNo`0000?o
bLkN00?o0000olS?goo8cml00_l00002olgBg@04o`000?o=dmkocM?NolgCgP?o000000GodMGLo`00
0?oAe]co0000om;Gg003om;Hg@;o000000?oeM_Lo`000?oGg=/00_l000001?oIgm_o0000om[PfooJ
h=/2o`000003omcRf_l0003o000000Co000000CohnWFo`000?l0003oi>cE0_l000001?oWl=;o0000
onWcc_oYllh8o`0000Gooo]Z00?o0000oookJ_oonfX0@_oonfX3o`0000Cooo]Z00?o0000oookJ_oo
nfX0;OoonfX0043ooo]Z0ol0003ooookJQ7ooo]Z0_l00002oeV<j003oeb;iOl0003o000000Co0000
0onM^>/01?l0003o/<7Vo`000?l00005ok71iP04o`000?nkaN;o^lGRok_5hP;o000000Ko_<KRo`00
0?nkan?o0000ol;:hOl00002ol;;h@;o00000oo2bn42o`0000?obLkN00Co0000olS?goo8cmoob<oO
0_l000000oo=d]go0000olgCgP03olgCgP04o`000?o>e=ko0000o`0000;odMKL00Ko0000om;HgOoB
f=god]SMo`000?oDf]d2o`000003omGLg?l0003of=gK00;o00000_oJh=/2o`000003omcRf_l0003o
fn?K00;o000000GognKIo`000?oSjMKo0000on?ZeP03o`0000;oio3B00?o0000onWcc_l000000_l0
00000oo/nL7o0000o`000002o`0000Kooo]Z00?o0000oookJ_oonfX0?ooonfX3o`0000Oooo]Z00?o
0000oookJ_oonfX0;OoonfX003kooo]Z0_l0003ooookJQGooo]Z0_l00002oeV<j004o`000?mmYNgo
OJG]o`0000KoWKS[00?o0000ok71i_na`NH00_na`NH2o`0000;o//;V00?o0000ok_5h_l000001?nl
a^83o`0000;o`/_Q00?o0000ol;;hOo2bn400_o2bn400oo3c>7o0000o`000002olW>gP?ob<oO00Go
0000olW@gol0003obM7Po`000003olgCgP04o`000?o>e=ko0000o`0000;ocmGN0ol00002om;Hg@07
o`000?oDf]goe=[Mo`000?oEg=co0000omKLg@02o`0000;of^3K00Co0000om[Qfol0003o00000_oK
hm/00ol0003ognKIomoVf@02o`000006on?Ze_l0003o0000onK^dol0003oio3B1?l000000oo[mlWo
0000o`000004o`0000Kooo]Z00?o0000oookJ_oonfX0??oonfX3o`0000[ooo]Z00?o0000oookJ_oo
nfX0;OoonfX003_ooo]Z0ol0003ooookJQOooo]Z2ol00004oinij`04o`000?na`NKo0000o`0000Go
//;V00?o0000okc6h_nla^800onla^801Ol0003o_<OSo`000?o2bn7o000000;o`/_Q0_l00003ol?<
h@04olC=hOl0003ob<oOolS?g`;o00000oo9d=l01Ol0003ob];Po`000?o=dmko000000;oc]CN00Oo
0000oloEg_o?eMko0000oloFg_l0003od]OM00;o00000_oDf]d00ooDfmgo0000o`000002omKLg@;o
000000Gof^3Ko`000?oJhM_of^7Ko`000002om_Sf`;o000000KognKIo`000?l0003oh^_Ho`000?oS
jmH4o`000003onSbd?l0003o000000Co000000Coj_Vco`000?l0003o00001_oonfX00ol0003ooo]Z
oookJP0ioookJP?o00003_oonfX00ol0003ooo]ZoookJP0/oookJP00>?oonfX3o`000?oooo]Z6_oo
nfX00ol0003o65gDo`000002of>@j004o`000?n2YncoPZO/o`0000OoWkW[00?o0000ok;2i_nb`^H0
0_nb`^H2o`000003ok?3i_l0003o_<KR00?o000000?o_<ORo`000?nlan<00ol000000oo2bn7o0000
ol?<h@04ol?<h@;o000000?ob<oOo`000?o9d=l00_o9d=l01?l0003obM7Oo`000?o:d^02o`0000;o
c]CN0_l000001?o?eMko0000oloFg_o?e]h3o`000005omCJgOl0003oe=_MomCKgOl000000_oFg=d0
0ol0003oeMkNo`000002o`000006om[Qfol0003o0000om_Sfol0003ogNGJ1?l000001ooRjmSo0000
o`000?l0003oi^oCo`000?oXl]000_l000000ooZm/_o0000oncha@05o`0000Oooo]Z00?o0000oook
J_oonfX0=_oonfX3o`00017ooo]Z00?o0000oookJ_oonfX0;?oonfX003Kooo]Z0_l0000OoookJPoo
0000k_oonfX5o`000005of>@j?l0003oPZO/oh:Wk?l000000_nO^N/3o`0000;oX[[Z00Co0000ok;2
i_l0003o00001?nc`nH00ol0003o_<ORokc7hP02okc7hP;o00000_nmb><2o`0000?o`lcQ0_l00000
1?o4cN7o0000o`000?l00003olW@g`03o`000?o9dMoobM7O00;o000000Gobm?Po`000?o>e=ko0000
olkDgP02o`0000;ocmKN00?o0000om3Hgoo@f=l00_l00002omCKg@;o000000Goe]cMo`000?oEg]ko
eMkNo`000002omWQg@05o`000?oJh]_o0000o`000?oMiMX00ol000001_oPjMWo0000o`000?oQk=Wo
0000onC_e@Co00000_oZm//7o`0000Oooo]Z00?o0000oookJ_oonfX0<ooonfX3o`0001Cooo]Z00?o
0000oookJ_oonfX0;?oonfX003?ooo]Z0ol0000LoookJPGo00000_nD/n`00ol0003oPZc_oh:/k`02
oh:/k`03ohB/kol0003oK:;a00;oK:;a00?oKj?ao`000?m@Tnl01?l0003[oookJP?o00000_m/U>L6
o`0000KoX[[Z00Co0000ok?3i_nc`nKo/l?V0_l00002okC4iP05o`000?nlan;o0000okg7h_l00000
0_nmb><01_l0003o_/WSokk9hol0003o`lcQo`0000?oa<gQ00Ko0000olG>h_o5c^;o0000olW@gol0
0003olWAg`03o`000?o;dn3obm?P00;o00000_o>e=h01?l0003ocmKNoloFg_l00003om3Hg`;o0000
00?oe=_Mo`000?oDg=d00_l00002omGNgP05omOPgOl0003ofN7Mo`000?oIh]d00_l000001?oMiM[o
0000omgVfol00002on3Yf@03o`000?oQk=WohNcI00;o000000Goho3Go`000?l0003o0000on[fb`04
o`000003onSi[ol0003o000000Sooo]Z00?o0000oookJ_oonfX0<OoonfX2o`0001Oooo]Z00?o0000
oookJ_oonfX0;?oonfX0037ooo]Z0_l0000LoookJP?o00000_nT^>L00ol0003oTk;/oi>bk00Ao`00
0003oeBFl?l0003o000000;o0000j?oonfX4o`000003ofbDiol0003oQj[/00;oQj[/00?o0000oj:j
j_nR^^X00ol00002ojBkjP04o`000?nc`nKo0000o`0000Go]<CV00Co0000okg7h_nman;o_LOR0_l0
0003okk9h`;o00000_o4cN400ol0003oaLgQo`000002olG>hP;o00000_o9dMl01Ol0003ob];Po`00
0?o;dn3o000000;obm?P0ol00002oloFgP?od=SO00CodMWOo`000?oBf]oo00000_oDg=d00ol0003o
eMkNo`000002omOPg@;o000000?ofN;Mo`000?oHhmh00_l000001?oMi]_o0000on3YfOoPjMT2o`00
0004on7/fOl0003o0000on?`e`co00002OoonfX00ol0003ooo]ZoookJP0]oookJP?o00006OoonfX0
0ol0003ooo]ZoookJP0/oookJP00;_oonfX3o`0001cooo]Z0_l00006ojBhi`04o`000?nC/ncoTk?/
o`0000;oUK?/00?o0000oh:/l?n2[?000_n2[?000ol0003oJj;aof^Rl@02of^Rl@03ofnTlOl0003o
CYC`00Co000000Co=8CZo`000?l0003o0000iOoonfX01?l008ko0000o`000?liLmh8o`0000KoY;_Z
00?o0000okC4i_nda>H00_nda>H2o`0000;o]LGV00Co0000okg7h_nman;o00000_nnbN<2o`000004
oko9hol0003oa<gQo`0000?oaLgQ0_l000001?o6cn;o0000olWAgol00002ol[Bh009o`000?o;dn3o
bm?Pol_Ch?l0003oc=CPo`000?o>e]oo000000?od=SO0_oAfMl2o`000003om;Kgol0003o000000;o
00000ooGh=d00ol0003ofN;Mo`000002omSSgP;o000000GogNKKo`000?oPjMWo0000on3[f@07o`00
0003onGddol0003oioO>00Oo00002OoonfX00ol0003ooo]ZoookJP0ZoookJP?o00007?oonfX00ol0
003ooo]ZoookJP0/oookJP00;OoonfX00ol0003ooo]ZoookJP0JoookJP?o00000onb^n43o`0000?o
Y;SW00?o0000oi>ck?nC/n`01ol000000on2[?3o0000o`000007o`000003oe>Gl?l0003o000000;o
000000?o1fSKo`000?l00000hooonfX5o`000003ogJIi_l0003oS:c/00?oS:c/00?o0000ojBkj_nT
^nX00ol00002ojJmj@04o`000?nda>Ko0000o`0000Go]LGV00Go0000okk8h_l0003o_/WSo`000003
oko9h`;o00001?o5cN400ol0003oa/oRolK?hP02o`0000;ob];P0_l00002ol_Ch003o`000?o<e>3o
c=CP00?o000000?od=SOo`000?oAfMl00_oAfMl01?l0003od]_Oo`000?oCg=l2o`0000?oen3M0ol0
0002omSSgP03o`000?oKi]co000000?o00000_oPjmT4o`000004onCbeOl0003oiOCConGdd`Co0000
00Coio^no`000?l0003o00002_oonfX00ol0003ooo]ZoookJP0WoookJP?o00007ooonfX00ol0003o
oo]ZoookJP0/oookJP00;OoonfX00ol0003ooo]ZoookJP0HoookJP;o00000onb^n42o`0000;o/[_Q
00?o0000ojBhionT^>L00onT^>L01?l0003oU;?]oiBckOl00002oiFdk003o`000?n2[O3oPZg`00?o
PZg`00Go0000of^Sl_m[Xo;oJj?bo`000002odfEl0Co000000?o<XG[o`000?l000000_l0003Roook
JP;o000000Ko1S^lo`000?l0003o0000ogJIi_l00002ohb/k0Co00001_nV_NT01?l0003o]LGVokG5
i_neaNH3o`000003okO6i_l0003o_/SR00;o00000onobN<02_l0003o`L_Rol7;h_l0003oaLgQo`00
0?o5c^7o0000olK?h_l00002olK@hP;o00000_o:dn02o`0000;oc=CP00?o0000olgFhOo=e^400_l0
0002om7Ig`04o`000?oAf]oo0000o`0000;odmcO0ol000001?oGh=go0000omOQgOl00002omSSgP?o
00000_oKimd2o`000005on3[fOl0003o0000on;_f?l000000_oTl]D00ol0003oiOCCo`000002o`00
0003onSjb?l0003o000000?o00002_oonfX00ol0003ooo]ZoookJP0ToookJP?o00008_oonfX00ol0
003ooo]ZoookJP0/oookJP00;OoonfX2o`0001Oooo]Z0_l000000onm_M[o0000ok:kh@02o`0000Go
/[_Q0ol00003ojBhi`03o`000?nD/ngoU;?]00Ko00000on2[_401?l0003oIJ7bofFQl_m[Xo85o`00
0005obV1jOl0003o0000o`000?l4ImX00ol0003QoookJP?o000000?oB7gQo`000?l000000ol00002
oi2_j`03o`000?nV_NWoY[gY00?o00000_nY_^T01?l0003o]LGVo`000?l00005okO6iP03o`000?no
bN;o000000;o_lWS00Co0000ol7;h_o1bn;o`L_R0_l00002olG>h@08o`000?o6d>;oa]3RolK@h_l0
003ob=;Qo`000?o:dn02o`0000;oc=CP00Co0000olgFhOo=e^7ocMKQ0_l000001OoAfMoo0000om7J
gooAf]oo000000;odmcO00?o0000om?Ngol000000_l000001ooGhMgo0000o`000?oHhmko0000om[U
gOl000000_oKimd2o`000004omk[fol0003o0000on;_f0;o000000?oi?;Eo`000?l000000_l00000
0ooWnLgo0000o`000005o`0000[ooo]Z00?o0000oookJ_oonfX08OoonfX3o`0002Kooo]Z00?o0000
oookJ_oonfX0:ooonfX002gooo]Z00?o0000oookJ_l000005OoonfX01_l0003o`;kHol2nf?l0003o
_KgJo`0000Co/[_Q0_l000000onb^n7o0000ojBhi`02ojBhi`04o`000?nT^>OoY;SWo`0000;oU;?]
00Co0000oiJdkOnF]>go00001On2[_401_l0003oIJ7bofFQl_mUXO;o0000odNBk`Go000000?o<HK[
o`000?l000001?l0003OoookJP03o`000?lbDlGo000000;o000000CoOYcUo`000?n@[n_oT:o[1Ol0
0006ojVnj@03o`000?nga^Ko]lKV00;o]lKV0_l00002okS7iP03oko9h_l0003o_lWS00?o`L_R0_l0
00000oo1cNCo0000olG>h@02o`0000;oa]3R00?o0000olSBhOo8d^400_l000000oo;dn3o0000olcD
h004olgFh@04olgGhOl0003oc]WQo`0000;odM[O0_l000001OoCg=oo0000om?NgooCg]oo000000;o
eN3O00Go0000omOQg_l0003o0000om[Ug@02o`000003om_WgOl0003og>WL00So000000?oi??Eo`00
0?l000001?l000001?oVnk[o0000o`000?l0000;oookJP03o`000?oonf[ooo]Z01kooo]Z0ol0000Y
oookJP03o`000?oonf[ooo]Z02_ooo]Z000]oookJP04o`000?oonf[ooo]Zo`0001?ooo]Z00?o0000
ol2nf?o0_]P00_o0_]P01?l0003o_KgIo`000?nb^n42o`0000Co/[_Q0ol00004ojFii`03o`000?nD
/ngoU;?]00Ko00000on3[_400ol0003oK:KcofbVl`06o`000005obR2jOl0003o0000o`000?l1ImX0
1?l0003NoookJP?o00000_mCN]/4o`0000?oUj_T00?o0000ojVnjOnY_^T00_nY_^T2o`0000;oZl3Y
00Co0000okO6i_l0003o00001OnhanH01Ol0003o`L_Rol7;h_o1bn;o000000Co`LgT00?o0000olK?
hOo6cn400_l00002olSBh@03o`000?o8dn;ob=?R00;o00000_o=e^42o`0000;ocMOQ0_l000001_o?
fN7o0000o`000?oAfmoo0000om?Lg`;odmkO00Goe=oPo`000?oEh=oo0000omKQg`02o`000003om[U
gOl0003of^KM00;o00000_oLjM`00ol0003og^cKomg/g002o`000003on7`fOl0003oi??E00Go0000
00?oio_3o`000?l000000_l0000<oookJP03o`000?oonf[ooo]Z01_ooo]Z0ol0000/oookJP03o`00
0?oonf[ooo]Z02_ooo]Z000/oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03ooo
nfX02?l0003o`;kHol2nf?o0_]So0000ol2meol0003o_KgI0_l00003ok:kh@;o00000_nb^n000ol0
003oYKWWojFii`04ojFii`04o`000?nE]>goUKC]o`0000;oU[G]1?l00002oh>^lA;o0000gOoonfX0
1?l0003o;5?7obaCaol00002oe=jf`03o`000?nGZnCoUj_T00CoUj_T00Co0000ojVnjOl0003o0000
1On[`>T01?l0003o^<OVokS7i_nhanH3o`000005okW6i?o1bn;o0000ol7;h_l000000oo1cN@01_l0
003o`/kTol;>i?l0003oa/oQo`0000;ob=;Q00?o0000olSCh_o8dn800_o8dn800ol0003ocMKQo`00
0004olgGh@07o`000?o?fN7o0000oloJhOl0003odM_Oo`000002om?Ng`;oe=oP0_l000000ooFhMoo
0000omOSh002o`0000;of^KM00?o0000omcYg?oLjM`00_l00002omg/g003o`000?oQl=Wo000000?o
000000?oi_OAo`000?oWn//01_l0000<oookJP03o`000?oonf[ooo]Z01Wooo]Z0_l0000_oookJP03
o`000?oonf[ooo]Z02_ooo]Z000/oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
3OoonfX01Ol0003ob[o@o`000?o0_]So000000?o`;gG00Ko0000okfmfOnm_MWo0000ok:khOl00005
ok:kh0?o00001?nU^NL2o`000005oiFdkOl0003o0000oiNfkOl000001On3[o400ol0003oKJOdoffW
m002offWm004o`000?m?V?;o0000o`0000;o9h?Y1ol0003LoookJP;o000000?o;5?7o`000?mOP=/0
0ol00006oiN[i004o`000?n[`>WoZl3Yoj_0j@?o000000?o[/;Xo`000?nhanH00_l00005okW6i004
o`000?o1cNCo`LgTol7=i0;o00001?o2c^@2o`000003olSBhOo8dn;ob=?R00;ob=?R00Co0000olSD
h_l0003o00000oo=en401?l0003oc]SQo`000?l00002oloJh@?o000000OodmkOomCOh?oDgn3oe=oP
o`000?oFhMoo000000;oen?P0_l000001?oJi]go0000o`000?oLjM`2o`0000;ogNcL3ol0000=oook
JP03o`000?oonf[ooo]Z01Kooo]Z0ol0000aoookJP03o`000?oonf[ooo]Z02_ooo]Z000/oookJP03
o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX02_oonfX2o`0000;ob[o@0_l00002ol2me`05
o`000?o0_MOo`;gGo`000?nm_MT00_l00003ok:kh0;o00000_nc_>000ol0003oYKWWo`000002o`00
00;oY[WW00Go0000oiJekOnF]Ngo0000oiNfk@06o`000003oh>_lOl0003o000000Ko000000?oE9cc
o`000?lWQ>X01ol0003KoookJP;o000000?o;5?7o`000?mOP=/00_mOP=/4o`0000?oU[?/00Co0000
oj_0jOl0003o00001On^`^P00ol0003o^LKTokW6i002okW6i0;o000000Go^lOTo`000?l0003o`LgT
o`000004ol;>i004o`000?o3c^?o`lkSo`0000?ob=?R0_l00002olSDhP05o`000?o:e^?o0000olgG
hOl000000_o>f>401?l0003ocm[QoloJhOl00002om3LhP05o`000?oDgn3oe=oPo`000?oDh>000_l0
0002omOSh003o`000?oHi]oo000000;o000000Gog>WLo`000?oMj]go0000omg/g003o`000003on3a
fol0003o000000?o00000_oTnlh5o`0000gooo]Z00?o0000oookJ_oonfX04ooonfX3o`0003Cooo]Z
00?o0000oookJ_oonfX0:ooonfX002cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zoook
JP08oookJP05o`000?o>_l_o0000olZod?l000000oo:_/l00ol0003o`;gGol2me`02ol2me`06o`00
0?nn_MWo_[gIo`000?nb^n3o00001Onc_>000ol0003oY[WWojJii`04ojJii`Go000000?oV;O]o`00
0?n4/?800on4/?82o`0000CoKjWd00?o0000oe6Jl_l000002_l0003IoookJP?o000000Go02Z`o`00
0?mOP=_o0000oen0f`02o`0000?oU[?/00Co0000oiJck?nF/nco00001?n^`^P2o`0000;o/<?X00Co
0000okW6i?l0003o00000onkan@3o`000003ol;>i?l0003o000000?o`lkS00Ko0000ol??hol0003o
0000olSCh_l00003olSDhP03olWEh_l0003ob]KS00;o000000Koc]SQo`000?o>fN7o0000oloJhOl0
0003om3LhP?o00000_oDh>000ol0003oen?PomOSh003o`0000;of>KP0_l000003?oMj]go0000o`00
0?l0003ognoKo`000?oPlM_ohO?Io`000?oRm]Oo0000on?he0So00003OoonfX00ol0003ooo]Zoook
JP0@oookJP?o0000=ooonfX00ol0003ooo]ZoookJP0[oookJP00;?oonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z00Kooo]Z00Go0000oljoboo>_l_oc[o;o`000003olZnc`05o`000?o:
_/oo0000ol2meol000000_o0_=H01?l0003o_[gIo`000?l00003ok>lh0;o00000_nc_>000ol0003o
Y[WWo`000002o`0000;oY[[W00Co0000oiNfkOnG]^goUkK]1_l000000on4/?;o0000o`000009o`00
0003obN5jol0003o000000Ko0000eooonfX3o`000004o`0Z/?l0003oMh_JogN;fPKo00001?nK]^/0
1?l0003o[/;Xo`000?l00005ok33j003o`000?nkanCo^lOT00?o^lOT00Co0000okc:iOl0003o0000
0oo3c^<2o`0000;o`loS0ol00002olSDhP03o`000?o9eN;obMGR00;o000000?obmOSo`000?l00000
0_o>fN400ol0003ocm[Qom3LhP02om3LhP05om3Mh_l0003od]oRo`000?oDh>000_l000001?oGhn3o
0000omOTh?l00002omSVh0Ko000000GognoKo`000?l0003ohO?Io`000002on;fe`Co000000?ohog6
o`000?oPoKX00_l0000>oookJP03o`000?oonf[ooo]Z00gooo]Z0ol0000joookJP03o`000?oonf[o
oo]Z02_ooo]Z000/oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX01?oonfX02Ol0
003oc[o;oljoboo>_l_o0000oljnbol0003ob[k?o`000003olZnc`03o`000?o0_=Ko`;cF00;o`;cF
00Ko0000okjlf?nn_=So0000ok>lh?l00005ok>lh003o`000?nV^^OoY[[W00CoY[[W0_l00002oiRf
k@03o`000?nJ]ngo000000GoQK7b1Ol000000om>V_?o0000oeBNm00;o`000=Kooo]Z1Ol00003ogN;
fP03o`000?n4Y>Wo000000OoVkK[00?o0000ok33j?n``nP00_n``nP2o`000003ok;5j?l0003o^lOT
00?o000000?o_<WTo`000?nlb^D00_nmbnD00ol0003o`lkSo`000004ol??h`05o`000?o5d^Co0000
olSDh_l000000oo9eN800ol0003obmOSol_Gh`02ol_Hh`03o`000?o>fN7o000000?od=cR00Cod=gR
o`000?oBgn;od]oR0ol000000ooGhn3o0000omOTh002o`000007omSVh?l0003ofNSOo`000?oKjmko
0000om_]gP03o`0000;ohO?I00?o0000on;feol000000_l000000ooTo<co0000o`000004o`0000oo
oo]Z00?o0000oookJ_oonfX02OoonfX3o`0003gooo]Z00?o0000oookJ_oonfX0:ooonfX002cooo]Z
00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP03oookJP;o000000?oc[o;o`000?o>_//0
0_o>_//01?l0003ob[k?olZncoo:_/l2o`000003ol2le_l0003o000000;o`KcF00Co0000okjlf?l0
003o00000onc_>02o`0000;o];cO00?o0000ojJjiol000000_l00002ojNjiP04o`000?nH]^goV;K]
oiRfk@Go00000on6/_800ol0003oKZSdo`00000;o`000003o`1]g?l0003o000000;o0000eOoonfX3
o`000003oaDk^?l0003o000000;o000000CoMh_Jo`000?n4Y>Wo00000_nK]^/3o`0000;oWkW[00Co
0000ok33j?l0003o00001?nbaNP00ol0003o_<WTokc9i002okc9i004o`000?nmbnGo_L_Uokg;i@;o
00000_o3cn<2o`000003olCAhol0003oaM;T00;o00000_o9eN801?l0003ob]KSo`000?o;en<3ol_H
h`?o000000?od=cRom3Mh_o@gN800_l000001?oBgn;o0000om7QhooAhN<2o`000003omOTh?l0003o
enGP00;o000000CofNSOo`000?l0003ofn_N0_oKkMh01?l0003ogO3Mo`000?oQlmT4o`000003onCj
dOl0003o000000Go00004?oonfX00ol0003ooo]ZoookJP06oookJP?o0000@OoonfX00ol0003ooo]Z
oookJP0ZoookJP00;?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0
0003oljnb`05o`000?o>_L[o0000olZncol000000_o9_Lh00ol0003o`KcFol6leP03ol6leP;o0000
00Co_[cHo`000?nc_>3o00001Ond_=l00ol0003oYk[VojNjiP04ojNjiP;o00000onI]nd00onK^>co
0000ohJblP04ohJblPKo000000?oD9cdo`000?l000000_l000000ol^Rngo0000o`000005o`000=Co
oo]Z0ol000000ol/B;co0000o`000002og>@h0Ko00001_nO^N/01?l0003o//GXok;5j?nbaNP2o`00
00;o]<KX00Ko0000okc9i?l0003o_L[To`000?nmbnD2o`000004okk<iOl0003o`loSo`0000?oa=7S
0_l00002olGCi0;o00000_o:e^<01Ol0003obmSSol_Hhoo;f>?o000000;oc=[S0_l000000oo@gN;o
0000om7NhP02o`0000;odN7S0_l000001_oDi>;o0000omOUh?oGiN3o0000omWXg`;o000000Gofn_N
om_]g_oKkMko0000omg`g@05o`000003on;ge_l0003o000000;o000000?ohOg1o`000?l000000_l0
000@oookJP03o`000?oonf[ooo]Z00?ooo]Z0ol00014oookJP03o`000?oonf[ooo]Z02[ooo]Z000/
oookJP03o`000?oonf[ooo]Z00[ooo]Z00Co0000oookJ_oonf[o00000_oI_[l2o`000003oljnbol0
003oc[g:00;oc[g:0_l000001Oo9_Lko0000olVmc_l0003o`KcF00;o00000oo1^mD3o`0000?o];cO
0_l000001?ne_=oo0000ojNji_nW^^H3o`0000;oZ;[V00?o0000oiVgkOnI]nd00_nI]nd4o`0000?o
R;?b00?o0000og2ZmOl000000_md[_H01?l0003oDYkdo`000?mHXoH:o`000=;ooo]Z1?l00002oba8
_0;o00000_mcT>001?l0003oRjWYoh^YjOl00002oinij`?o00000_nT_>X01?l0003o//GXo`000?l0
0005okC6j003o`000?nmb^Co_L[T00;o00000onnc>D2o`0000Coa=7S00Oo0000olGCi?o5dnCo0000
olKCi?l0003ob]KS00;o000000?obmSSo`000?l000000_o<f^<01?o=fnCo0000o`000?l00002om7N
hP05o`000?oAhN?odN7So`000?oCh^800_l000000ooEiN;o0000omOVh@02o`000004omWYh?l0003o
fngNom_]gP?o000000?og?3No`000?oOm=/02ol0000AoookJP04o`000?oonf[ooo]ZoookJP;o0000
AooonfX00ol0003ooo]ZoookJP0ZoookJP00:ooonfX00ol0003ooo]ZoookJP0<oookJP;o00000_oI
_[l01?l0003of;foomRm_ol00003oljmbP04o`000?o>_<Woc[c9o`0000?obKg>00Go0000ol6keOo1
^mGo`K_Eo`000002ol6ke004o`000?nn_=So0000o`0000Go]KcO0_l00006ojRjiP;o00001?nJ^>d4
o`0000;oR;?b2ol000000olbS^oo0000o`000005o`000=7ooo]Z1?l00002oba8_003o`000?mKPMko
000000Oo00001_nT_>X00ol0003o]<KXokC6j002okC6j0;o00000_nfb>P00ol0003o_L[To`000003
okk<i@09o`000?o1c^Co`LkTo`000?o4dN?o0000olGBi?l0003oaM?T00?oa]?T0_l000000oo;en?o
0000ol_Hh`02olcJh`07o`000?o=fnCo0000o`000?o>gNCo0000om7NhP02o`000008om7Qhol0003o
dn;Rom?Rh_l0003oeNGRo`000?oDi^<2o`000004omWYh?l0003o0000om_]gP?o000000Gog?3Nomgc
gOl0003o0000omoffP02o`000003on7kd_l0003o000000Go00004OoonfX4o`0004Wooo]Z00?o0000
oookJ_oonfX0:_oonfX002_ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ofKjoo`000003omRm
_`;o000000?oc[g:o`000?o>_<T00_o>_<T2o`000006olVmc_l0003obKc=o`000?o1^mGo00001?o1
^m@01?l0003o_kcGo`000?ne_=l3o`0000;o][cN00?o0000ojRji_nX^^H00ol000000onY^^Ko0000
oiZhk@03o`0000;oW;W]0_l00003ohVbl@;o000000SoLZceo`000?mg[oKoMjofo`000?mDXOGo0000
oe^Um`Go000000?o073Ko`000?l000000_l0003?oookJPCo00000_mGHl@2o`000004oe^1g_moU]oo
OiKOo`0000CoTZgY00?o0000ojBlj_nT_>X00ol00002ojRnjP04o`000?nda^So0000o`0000Go]/SX
0_l00002okk<i@Co`LkT0_l00002olGBi005o`000?o6dnCoa]?TolKCi?l000000_o8e^@2o`0000;o
c=[S00Co0000olgKi?o=fnCo00000_o>gN@2o`000003om7Oh_l0003o000000;odn;R00?odn?Ro`00
0?l000000_oDi^<00ol0003oenWRo`000003o`000004om_^gol0003o0000omgcg@;o000000?ogoKJ
o`000?oOn=P01?l000001?oMo/?o0000o`000?l0000@oookJP?o0000C?oonfX00ol0003ooo]Zoook
JP0ZoookJP00:ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oM_KSo000000?of;fo00Co0000
omRl__oH_;ko00000oo>_<T01?l0003oc[c9oljlbOl00003olVlc@05o`000?o1^mCo`K_Dol6ke?l0
00000_o2^]<00ol0003o_kcGo`000006okJlgP;o00001OnY^^H00ol0003oW;W]oibik@04oibik@Co
00000_n>]_800ol0003oMJkfo`000003o`000005oeNSm_l0003o0000o`000?l_Snl02Ol0003<oook
JPKo00000_mGHl@3o`000004ognFgol0003oTZgYoi:]j@Go00001_nX_^X01?l0003o]/SXokK8j?nf
b>P3o`000004okO9j?l0003o_lcTo`0000?o`LkT0_l00002ol7AiP03o`000?o6dnCo000000;oa]?T
00So0000olSFi?l0003o0000olSGiOl0003oc=[So`0000;ocM_T00CocMcTo`000?o>gNCo00000_o?
g^@2o`000003om?Rh_l0003odn?R00;o00000_oDi^<00ooFj>;o0000o`000002omOZhP04o`000?oK
k]oo0000o`0000;ogO?M00?o0000omoff_l000001?l000000ooOo/go0000o`000002o`0000kooo]Z
0ol00002oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0:_oonfX002_ooo]Z00?o
0000oookJ_oonfX02ooonfX00ol0003ogKfhomfm^002o`000009omRm_ol0003of;bnomRl__l0003o
ekbno`000?o>_<Wo000000?oc[c90_l000001_o9_<go0000olZlcOl0003o`K_Do`0000Co`[[C0ol0
00001?nf_=ko0000o`000?l00002okJlgP03o`000?nY^^Ko000000;o00000on[^nD3o`0000?oW[W/
0_l00002ohjflQKo0000b_oonfX7o`0000;oEf?400?o0000ofEleOmUO=D01?l00003oiZXh@03o`00
0?nX_^[oZ;kZ00?o00000_n[`NX01?l0003o]/SXo`000?l00005okO9j0;o00000_o1c^@01?l0003o
`M7Vol7Ai_l00002ol;BiP03olKCi?l0003oa]?T00;ob=KT00Co0000olSGiOo8enGob=OU0_l00000
1?o=fnCo0000olgLi?o=g>@2o`0000;ocmkT00Co0000om3Pi?l0003o00000_oChn801?l0003oe>KS
o`000?oFj>82o`0000;oen[R00Cof>cRo`000?l0003o00000_oMlmd6o`000005on3ldol0003o0000
o`000?oDnZl00_l0000;oookJP?o00001OoonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[o
oo]Z02[ooo]Z000[oookJP03o`000?oonf[ooo]Z00_ooo]Z0ol00002omfl^0;o000000?of;bno`00
0?oG_;h00_oG_;h01Ol0003oc[c9oljlbOo>_<Wo000000;oc[c900Go0000olZlcOo:_<gob[c=o`00
0003ol:jd`04o`000?o2^];o`[[Bol:jdP;o00001_nf_=h01?l0003oZk_Uoj^kiOn[^nD2o`0000;o
[;_T00?o0000oijik?nN^N`00onN^N`3o`0000?oT;Sa00Ko0000ogN`m_mg/?KoMk3fogfcm_l00003
oeZVm`_o0000b?oonfX8o`000003ob0j/ol0003oIGcE00?oIGcE00?o0000oiZXhOnJZ>401?nJZ>42
o`0000KoZl7Z00?o0000okO9j?ngbNP00_ngbNP2o`0000;o^/SU0_l00002ol7AiP;o00001?o2d^H0
1?l0003ob=KTolSFi?l00003olSGi@04o`000?o9fNGo0000o`0000?ocMcT00Co0000oloNi?o?g^Co
00000_o@h>@2om7Si004o`000?oCi>?o0000o`0000;oe^SR00Co0000omOZh_l0003of>cR0_l00000
0ooJkn7o0000o`000005o`000003on3je_l0003o000000Go00002OoonfX3o`0000Sooo]Z00?o0000
oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0ZoookJP00:ooonfX00ol0003ooo]ZoookJP0:oook
JP04o`000?oR^jooh[^_o`0000;ogKbh00?o0000ombk]ol000000ooG_;h01Ol0003oek^no`000?o>
_<Wo000000?oc[c90_l000001_o:_<go0000olZkc?l0003o`[[Co`0000Go`[[B0_l000001?nf_=ko
0000o`000?l00003okRjfP03o`000?n/^nCo[;_T00Co[;_T0ol00003oinjj`03o`000?n=]?3o0000
00ko00000_leUO47o`000<Gooo]Z2?l000001Ol];Yoo0000ob0j/ol0003oOXSC00Go000000CoVZSQ
o`000?l0003o00000_nI]>/00ol0003oZl7Zoj_1jP03o`0000;o[/CY00Co0000okO9j?l0003o0000
0onjb>D01Ol0003o^lcWo`000?o1dNKo000000Co`];V00Co0000ol?BiOl0003o00000oo8enD01?l0
003obMSUo`000?o9fND2ol[Ji@;o000000?oc]gTo`000?o?g^@00_o@h>@2o`000003om7Si?l0003o
dN?T00;o000000?oe^SRo`000?oFj>800_l00002omS/hP04o`000?oJkn7o0000o`0000;ofo?O0ol0
00000ooPn]Ko0000o`000005o`0000Oooo]Z0ol0000;oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o
0000oookJ_oonfX0:OoonfX002_ooo]Z00?o0000oookJ_oonfX02OoonfX01?l0003oh[^_on:k[ooR
^jl3o`0000;og;^g0_l000000ooG_;ko0000omNk_P02omNk_P05o`000?o>_<Woc[c9oljlbOl00000
0_o>^lP2o`000003olZkc?l0003o000000?o`[[B0_l00003ol:id@04o`000?nh^][o^;[JokRjfP;o
00000_nh^]/00ol0003o[;_To`000002o`0000;o[K_T00?o0000oinjjonO^^/00onO^^/00ol0003o
T;K`o`000002oi>il@Go00000_mj/_L01_l0003oGJWhoefYn?mMZOSo0000ocVIl`Wo0000`_oonfX9
o`000004obd^Wol0003o0000o`0000CoOXSC0ol00006oiVdj`;o00001_n^a>T00ol0003o^/SUok[8
i@02o`000003okc:iOl0003o^lcW00;o00000oo2d^H2o`0000;o`m;U00Go0000olCEi_l0003ob=OU
o`000002olWHi@08o`000?o:f^Gob][Uo`000?o<g>Goc]gTo`000?o?g^@2om3Pi007o`000?o@hNCo
0000o`000?oAhnCo0000om;Vi@02o`0000;oe^SR00Co0000omS/h_oHk>;of>gR0ol000000ooKlmoo
0000om_egP0;o`0000Cooo]Z0ol0000>oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oo
nfX0:OoonfX002_ooo]Z00?o0000oookJ_oonfX02OoonfX2o`000004on:k[ol0003oh[Z_on:j[`?o
00000_oL^[L01?l0003oek^nomNk__oG^kh3o`000005oljlbOl0003oc[_8oljkb?l000000_o>^lP3
o`000003ol:jd_l0003o000000?o`[WA00Ko0000ol>kd_l0003o0000okRjf_l00004okRjf`;o0000
1_n]^n@3o`0000CoXK[[0ol00003oiJjl003o`000?mn]?OoO[Cg00;oO[Cg00Co0000ofFYmomUZOOo
GJWh3?l0002ooookJP_o00000_liBkT2o`0000?oOXSC00?o0000ohRRi_l000000_nI]>/3o`0000;o
WkW[00?o0000ojk4jOn^a>T00ol000001?naa^Wo0000ok[8iOl00003okc:i@;o00000_nlcNL00ol0
003o`];Vo`000003ol?Bi@03o`000?o4eNKoa=GV00;o000000KobMSUo`000?o9fNGo0000ol[JiOl0
0002olcLi@?o000000Ood>3To`000?o@hNCod>7To`000?oAhnCo000000;od^KU00?o0000omCXi?l0
00000ol000001?oHkN;o0000o`000?oJlN02o`000005om_eg_l0003o0000o`000?oMnmP01?l00000
0ooFo[oo0000o`000003oookJP;o00004OoonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[o
oo]Z02Wooo]Z000ZoookJP03o`000?oonf[ooo]Z00[ooo]Z00Ko0000onRhX_l0003o0000on:j[ol0
0002on6i[`03o`000?oL^[Oog;Zg00;o000000Coek^no`000?oG^[goekZm0ol000000oo>^lSo0000
oljkb002oljkb004o`000?o>^/Oo0000o`0000?o`[WA0_l00003ol>kdP?o00000onh^]/00ol0003o
^K[Jo`000002ojfki0?o000000Co[k_So`000?nQ^^_oXK[[0ol000001OnS^n[o0000oi:gl?nB]o3o
000000;oU[[`1Ol000000omn]?Oo0000ofFYm`09o`000003oklo0?l0003o000000;o0000_OoonfX9
o`000003o`00Lol0003o000000;o>D^i2_l00006oinij`;o00001Onaa^T00ol0003o_<[Uokc:i@02
okc:i@04o`000?nlcNOo_<gWokc=i`;o00000_o3d^D00ol0003oa=?Vo`000002o`000003olGFi_l0
003o000000;obMWU0_l00002olcLi@03o`000?o<gNKo000000;o000000?od>7To`000?o@h^@00_l0
0002om;Vi@04o`000?oDj>Co0000omCZi0;o00000_oHkN801Ol0003of_7Po`000?l0003ofoGN00Co
000000?ogO_Homcle_l000002?l0000DoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oo
nfX0:OoonfX002[ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003oj;RRo`000002o`0000?ohKV_
0ol00002om^i]`04o`000?oG^[goekZmomNj_@;o000000?odK[3o`000?o>^lP00_o>^lP01?l0003o
c[[7oljjaoo>^/L2o`000003ol:idOl0003o`k_B00?o`k_B00Oo0000olFhc_l0003o^[WHo`000?nh
^]_o000000;o^K[J0ol00005ojnkh`;o00001OnS^nX5o`000003oiRkl?l0003oP[Kf00;oP[Kf00?o
0000oh:fm_n2]_H01_l000000om=YOSo0000o`000006o`000;[ooo]Z2ol000001?l007?o0000o`00
0?mQI;h3o`0000?oNXoK00Co0000oi2Yion@ZNOo00000_nO^N/3o`0000;oY;c[00?o0000ok76jOna
a^T00ol00003ok?8j@;o000000?o_LcVo`000?nlcNL00_l000000onocnKo0000o`000003olCCiP04
o`000?o5e^KoaMKVolGFiP;oamSV00?o0000olWIiOl000000_o<g>D01Ol0003oc=gVolcMi_l0003o
cN3V00;o000000?od>;To`000?oAhn@00ooBi^D2o`0000;oe>[T00Go0000omK]hol0003o0000om[a
h002o`000003om_eg_l0003ofoKN00;o000000?ogO_Ho`000?l000001_l0000GoookJP03o`000?oo
nf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0:OoonfX002[ooo]Z00?o0000oookJ_oonfX02OoonfX0
0ol0003ojkBHo`000002onNgXP;o000000GohKV_o`000?oP^:koh;R^o`000002om^i]`;o000000Wo
ekZmo`000?oF^Kcoe[Vlo`000?oA^L;o0000oljkb?l000000oo>^/L01?l0003oc[[7o`000?l00004
ol>kdP04o`000?o5^<koaKS>olFhcPCo000000Ko^K[Jo`000?ni^]Wo^K[Io`000?n_^n<3o`0000;o
/;_R00?o0000oj>kj_l000000_l00002ojFkj@04o`000?nE^?3oUKS`oiFhl0Go00000on5]oH00ol0
003oK:kho`000002og6cn@co0000]_oonfX=o`000003o`00Lol0003oHFBn00;oHFBn0ol000001?mj
Sm_o0000oi2Yion@ZNL4o`0000KoY;c[0_l00003ok?8j@;o000000?o]/[Yo`000?nmc>H00_l00003
oko?iP05o`000?o0d^So`=;Xo`000?o4dnH00_l00002olGFiP?oamSV0_l00002olcLi@?oc=gV00?o
c=kVo`000?o=h>H00_o?h^D2o`000003om;ViOl0003od^KU00;o00000_oDj^@01?oDjnCo0000o`00
0?oFkn<5o`000003om_fg_l0003og?[K00;o000000?og?gFo`000?l000001?l0000HoookJP03o`00
0?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0:OoonfX002[ooo]Z00?o0000oookJ_oonfX02Ooo
nfX01Ol0003ojkBHo`000?l0003oikNR00?o00000ooP^:h3o`0000;ofkRf00Co0000omJi_?oF^Kco
e[Vl0_l000000ooA^L;o0000oljja`02oljja`05o`000?o>^/Ooc[[7oljjaol000000oo3^m801?l0
003oaKS>olFhc_o5^<h2olBhc`04o`000?nk^MOo^kWGo`0000?o^K[I0_l00006ok2khP03o`000?nU
^nWoYK_Y00CoYK_Y0_l00003oiRjk`;oVk__0ol00002ohFgmQ7o0000]?oonfX=o`000004o`00N_l0
003o5afGo`0000;oHFBn00?o0000ofQid?mXNM001?l00002oiRTg@03o`000?nT_>_oY;c[00;oY;c[
0_l00002ojW0jP04o`000?ncb>Wo0000o`0000Co]/[Y00?o0000okg=i_l000000_nocnH00ol0003o
`=;Xol3Bj002ol3Bj004o`000?o5e>Ko0000olGFiP?oamSV00Co0000olOIiol0003o00000_o<gNH0
1?l0003oc=kVo`000?o=h>H2oloRi@04o`000?o?hnKo0000o`0000;od^KU00Co0000omCZi?oDj^Co
e>_T0_l00002omK_h`03o`000?oGl^?oeo;S00?o000000Cog?[Ko`000?l0003og?gF1?l000000oo:
mjSo0000oookJP0HoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0:OoonfX002[o
oo]Z00?o0000oookJ_oonfX02OoonfX3o`000004on^cV?l0003oi[JRonJfXP;o000000Goh;R^o`00
0?oO]jkogkN^o`000002om^h]P;o000000Woe[Vlo`000?oF^;coe[Rlo`000?oA^<7o0000oljjaol0
00000oo>^/L2oljiaP03o`000?o3^m;o000000;oaKS>00?o0000olBhcoo4^<l00_o4^<l01_l0003o
_;SFokbhe_l0003o^K[Io`0000;o^[[H00?o0000ok2kh_l000000_l00002ok:kh@03o`000?nU^nWo
000000;o00000_nW^nP00ol0003oV;[_oiRjk`02oiRjk`;o00001?n;]O84o`000003og2anOl0003o
000000go0000[ooonfXAo`000004oaLMUol0003oHFBno`0000?oJ7W@0_l00005oiRTg@04o`000?nT
_>_o0000o`0000GoZL3Z00Co0000okK:jOnfb^Wo]/[Y0_l00002okW9iP;o000000?o_loVol3Bj?o0
d^P00_o0d^P00ol0003o`MCXol7Dj002o`0000;oamSV0_l00002olOIi`04o`000?o9g>Oo0000o`00
00;oc=kV00Co0000oloRiOo?h^Go00000_o?hnH01?l0003od>KVo`000?oBinD2o`0000;oe>_T00Co
0000omK_hooFkn?o00000_oGl^<00ol0003ofOKPo`00000:o`0001[ooo]Z00?o0000oookJ_oonfX0
B_oonfX00ol0003ooo]ZoookJP0YoookJP00:_oonfX00ol0003ooo]ZoookJP09oookJP04o`000?o^
/8co0000on^cV0;o000000Coi[JRo`000?oT]JGo00000ooO]jh3o`0000;of[Rf0ol000001?oF^;co
0000om6h`OoA^<42o`000003oljjaol0003oc[W600?oc[W60_l000000oo5^<ko0000olBhc`03olBh
c`03o`000?o4^<ko000000;o_;SF0ol000000onj^]So0000o`000006ok:kh@03o`000?nW^nSoYk_X
00CoYk_X0_l00004oi^kk`Co00000on?^o@01Ol0003oMKCiogFdnOme]?WoNkSi00So000000?o^cH0
o`000?l000000ol0002/oookJQ?o000000?o>DJdo`000?l000001?mXNM000ol0003oV:CMoiRTg@04
oiRTg@04o`000?nY`>[oZL3ZojW0jP?o000000?o[L?Zo`000?nfb^T00_l00005okW9iP04o`000?o0
d^So0000o`0000?o`MCX00Co0000ol;Dioo2e>Oo00000_o7f>H3olOIi`06olSJiol0003o0000olWM
iol0003oc=kV0_l000002?o?h^Go0000oloSi_o?hnKo0000om3Vi_l0003odNSV0_l000002OoDjnCo
0000omC/i?l0003oe^oSo`000?oGl^?o0000omSdhP02o`000003omWhgol0003ofO[M00So00006_oo
nfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Sooo]Z000ZoookJP03o`000?oonf[o
oo]Z00Wooo]Z00?o0000onj`S?l000000_l000000ooZ/YSo0000onJdXP03o`000005omng[_l0003o
gkJ^omnf[_l000000_oJ^;H02Ol0003of[NeomZg]Ol0003oe[Rko`000?oA^<7o0000om6g_`02o`00
00?oc[W600?o0000oljhaOl000000_l00003olBhc`03o`000?o4^<koa;S>00;o00001?nm^=@01Ol0
003o^kWGok^ieol0003o/[_Q00?o00000onc^ml3o`0000CoZK_W0ol00003oifkk@;o00000_n?^o@9
o`000003omeZ3Ol0003o000000[o0000Z?oonfXAo`000004o`H0N_l0003o:R^Mo`0000;o>DJd00Co
0000oh>7con3QlooPhO?1Ol00003oiNbjP04o`000?nY`>[o0000o`0000Go[L?Z00?o0000okW9i_ni
bNH00_nibNH2o`000003ok_;iol0003o000000?o`MCX0_l00003ol;Di`;o000000CoamWWo`000?o8
f^Oob=[W0_l00002olWMi`?o00000_o?h^D2oloSiP03oloTi_l0003o000000;odNSV00?o0000om;[
i_l000000_l000001OoFkn?oe_3To`000?l0003of?CR00Co000000?ofO[MomWlfol000001_l0000K
oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX0:?oonfX002[ooo]Z00?o0000oook
J_oonfX02?oonfX00ol0003ol:]oo`000002onf_S@Co000000Coi[BRo`000?oS]:Go00000ooO]Zh3
o`0000?of[Ne0_l000002OoF^;_o0000om6g_ooA]koo0000om6f__l0003oc[W6o`000003oljha@05
o`000?o7]l[o0000olBhcol000000_o4^<h00ol0003oaKS=o`000002okfhe005o`000?nn]m?o_[OC
o`000?nk^ML00_l00003ok>kg`;o000000Co]K_No`000?nY^nOoZK_W0ol000000on[^nGo0000oifk
k@02oifkk@03o`000?nM^ngoWK_]00?o00000_nC_?<=o`000003ol0l0?l0003o000000Ko0000Y?oo
nfXCo`000003o`H0N_lJ7iSo000000;o000000?o>DJdo`000?n3Qll00on3Qll2o`0000?oUk;Z00Co
0000oiNbj_nG/^[o00001?n]`nX2o`0000;o/<KZ00Co0000okW9i_l0003o00000_nkbnL2o`000004
okc>j?l0003o`MCXo`0000Co`]CW00Co0000ol?Gj?l0003o00000oo8f^L01?l0003obMgWo`000?l0
0002ol[Oj0;o000000?ocn?Vo`000?o?i>H00_l00002om7XiP03om7Yiol0003o000000;od^cW00Co
0000omK`i?l0003o00000_oHm>82o`000003omSigol0003ofOcK00Oo00007?oonfX00ol0003ooo]Z
oookJP1;oookJP03o`000?oonf[ooo]Z02Sooo]Z000ZoookJP03o`000?oonf[ooo]Z00Sooo]Z00Wo
0000oo2[Ool0003o0000onf_SOl0003ok:j=o`000?oY/IP00_l000001OoS]:Go0000o`000?oO]Zko
000000;og[F^0_l000001?oJ]kGo0000omZf]OoJ][D2o`000003om6g_ol0003odKJn00;odKJn00Co
0000oljhaOo>^<Goc[S50_l000001_o7]l[o0000o`000?l0003oa;S>o`0000?oaKS=0_l00004okjg
d`?o000000?o/k_Oo`000?l000001?ne^mh2o`0000GoZk_U0ol00004oj2lk0Go000000CoUkgbo`00
0?mo^OSoOkWh4ol0002PoookJPco000000?o0006o`000?l000001ol000001?lW9YWo0000of=N]omS
G[L;o`0000CoW[SZ00Co0000ojg3j_l0003o00001On`a^X00ol0003o^l_Wok_;i`02ok_;i`03o`00
0?nlc^So_<kX00;o00000_o2e>L2o`000004ol?Eiol0003o`mOXolCHj0?o000000?obM_Wo`000?l0
00000oo:gnP01?o;h>So0000o`000?l00002oloTiP04o`000?oAj>KodNSVom7Yi`;o00000_oBk>L0
0ooCk^Ko0000o`000002o`000006omSdh_l0003o0000omSigol0003ofOcK0_l000000ooGo]Ko0000
o`000003o`0001cooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0XoookJP00:Ooo
nfX00ol0003ooo]ZoookJP09oookJP?o000000CokjZ0o`000?o/[Xgok:j=1Ol00002on>cY@;o0000
00Gog[F^o`000?oN]:gog[B]o`000003omZf]@?o00000ooA][h01Ol0003odKJno`000?o>^<Go0000
00;ocKO400Co0000olRfbOo8]/Wob;K90_l00003olFhc@05o`000?nn]m?o_[OCokjgdol000000ono
]]42o`0000?o]K_N0_l00002okRgf003o`000?n[^nGo000000;o00000_n]^n@00ol0003oX;c/o`00
0002o`0000;oXkc[00Co0000oi>jlOnC^_7oTk[a1Ol000000ooVO1oo0000o`00000Ao`0009cooo]Z
3Ol000000ol000Ko0000o`000007o`0000;o9bJI0_l000000omSG[Oo0000ofn2eP03oh2>f004o`00
0?nCZNGoTjWUo`0000OoW[SZ00Co0000ok36j_n`a^[o/<KZ0ol000000oncbN[o0000ok_;i`02o`00
0008okc=iol0003o0000o`000?nnd>So0000ol;Diol00002ol?Ei`04o`000?o3enSoa=SXo`0000;o
a]_X0_l00002ol[Oj0;o000000Cobn3Xo`000?o<hnSoc>?X0_l000000oo?iNOo0000o`000002om7Y
i`06o`000?oBk>Oo0000om?^i_l0003oe?3U1Ol000000ooHnMoo0000omWlf`02o`000003omOne_l0
003o000000?o00007OoonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Sooo]Z000Y
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oo6UL?l000001?l00002onb]S@07o`000?oX/9So
0000o`000?oS/jGo0000on:bY002o`0000;og[B]0_l000001?oJ][Go0000omVe]?oI]K@2o`000003
om6f__l0003odKJn00;odKJn0_l000001_o=]lCo0000oljf`ol0003ob;K9o`0000;ob;G700Oo0000
olFhcOl0003oa[O<o`000?nn]m?o000000Go_kKA0_l000000one^mko0000okRgf004okRgf003o`00
0?n]^nCo[K_T00Co[K_T00?o0000oj>ljonS_>/01?nS_>/2o`0000?oUkca00?oVkk`o`000?l00000
1?l000000ooOKa[o0000o`000006o`000003okD[0?l0003o000000Ko0000V?oonfXIo`0000;o9bJI
00?o0000oe]O_Ol000000_l000000om_P]KoP8kHo`000004oi>Yi@03o`000?nN^>[oW[SZ00?o0000
00?oY;g[o`000?n`a^X00_l00005ok?9jP03o`000?nlcNOo_<gW00;o00000onnd>P2o`0000?o`mGW
00?o0000olCHj?l000000oo6fnP2o`000003ol[Oj?l0003obn3X00;obn3X00?o0000olcSj?o<hnP0
0_o=iNP2o`000003om7Yiol0003odNWW00;o000000WodnkVo`000?oDl>Goe?3UomCbiOl0003oeOGT
o`000?oFnN402?l000000oo3nKCo0000oookJP0MoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000
oookJ_oonfX0:?oonfX002Wooo]Z00?o0000oookJ_oonfX02OoonfX3o`000004oo2TLOl0003okZV0
o`0000;ok:f=1Ol00002on:bY004o`000?oQ/JCo0000o`0000;ogK>]00Oo0000omVe]?oI]KCofKFd
o`000?oI];Co000000?odKJn00?o0000om6e__oA]Kh00_l00002oljf``03o`000?o8]LOob;G700;o
b;G700Go0000olJgc?o6]lcoa[O<o`000003oknfd@;o00000oo0]M001?l0003o^;OHokRgf?nh]mP2
o`0000;o]kSI00?o0000ojfki?l000000_l00002ojnkhP03o`000?nS_>_o000000;o00000_nV_>T0
0ol0003oUkcaoiNll@02oiNll@Co000000?oiW`Uo`000?l000001?l00002omEM3POo000000?oYaT0
o`000?l000001?l0002CoookJQGo000000?o001@o`000?l706L00_l000001_lj<iko0000o`000?l0
003oFenmo`0000;oPX;:2_l00005ojBmj`03o`000?ncbN[o/lWZ00;o/lWZ0_l00003okG;j`;o0000
0_nnd>P2o`0000?o_mCZ00?o0000olCGj?l000001?o6fnP01?l0003oa]cYo`000?l00002ol_Pj004
o`000?o;hNSo0000olcSj0?ocNGX0ol000000ooAjNOo0000o`000002om?^iP06o`000?oDl>Goe?;U
o`000?oEmNCoeOOS0_l000000ooFn^3o0000omGlgP04o`000003ol?i]?l0003o000001kooo]Z00?o
0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0XoookJP00:OoonfX00ol0003ooo]ZoookJP0:
oookJP;o000000?ol:Aao`000?l000000ol00002on^/S@03o`000?oW[iSo000000;o00000ooQ/J@0
0ol0003ogK>]omfc[@02o`000004omVe]?l0003ofKBdomVd]0;o000000?odKJno`000?oA]Kh00_oA
]Kh01Ol0003odKBmo`000?o>]/?o000000?ob;G700Wo0000olVda_l0003oa[O<o`000?o6]l_o0000
oknfdOl000000oo0]M001Ol0003o`KSAol6hdOl0003o^KOG00;o00000ong^=T2o`0000Ko[k_R00?o
0000ojJljOnV_>T01?nV_>T2o`0000CoVkg`1Ol000000ooRM2?o0000o`00000Co`0008oooo]Z5ol0
00001Ol0053o0000o`000?lS4H;o000000;o>S>N00?o0000od15/?l000001On2P/X00ol0003oVjGL
oi^Ug003oi^Ug003o`000?nT_N_oY;g[00?o00000_nY`N/01?l0003o/lWZo`000?l00003okG;j`06
o`000?nib^So^L[Xo`000?nnd>So00000onoe>X01?l0003o`=KZol3Fj_l00003olKKj0;o00000_o6
g>T2olSOj@;o000000?obn7Xo`000?o<hnP00oo=iNP01?o=i^So0000om3Zj?o@j^P3o`000004om?^
i_l0003oe?3UomCbi@;o000000OoeOOSo`000?l0003oe_[Po`000?oEo=koe?gK00Ko00008?oonfX0
0ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z02Sooo]Z000YoookJP03o`000?oonf[ooo]Z
00[ooo]Z1?l000001?o`Xg;o0000onjXPOl00002on^/S@?o000000?oiJjJo`000?l000000_oQ/J@3
o`0000;ogK:/0_l000000ooI];Co0000omRc/`03o`0000;odKFn00Wo0000om6d_OoA];godKBmo`00
0?o>]/;o0000olReaol000000oo9]<H2o`000003olJgbol0003o000000?o`;G@00Co0000ol6hdOo1
^=7o`KSA0_l00002okZfe@05o`000?ng^=Wo0000okVhf?l000000_n_^n83o`000004ok6khOl0003o
Y[cYojJlj@?o00000_nX_>L3o`0000;oW[g^00Go0000oo:HD?l0003o0000onIl:P04o`000003omYV
6ol0003oef4E013o0000RooonfX@o`000003o`L05ol0003o000E00;o000000?o000Zo`000?l00000
1?l00002ob<APP06o`000?lj<iko>S>No`000?mYGk?o00001On2P/X01Ol0003oVjGLoi^Ug?nKYMco
000000;oVjGL0_l00006ojW1j`04o`000?nebn_o0000o`0000Co^L[X0_l00003okoDjP;o00000_o0
e^X00oo2e^Wo0000o`000002olKKj0;oa]cY00GoamgYo`000?o8gnWo0000olWQj@03o`0000;ocNGX
0_o=i^P01Ol0003od>[Xo`000?l0003ocn_X00Co000000?oe?;Uo`000?l000000_oEmn<01Ol0003o
e_[PomGkh?l0003oe?gK00Ko00008OoonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z
02Sooo]Z000YoookJP03o`000?oonf[ooo]Z00[ooo]Z00Go0000onj?AOl0003o0000oo2SLP05o`00
00;ojZ^>00Co0000onF^V_l0003oi:fJ0_l00002on6`Y0;o000000?ogK:/o`000?oL/J`00_l00002
omRc/`05o`000?oD/[Oo0000om6e__l000000_oA];d01Ol0003odKBlo`000?o>]/;o000000?obKC6
00?o0000olVfaoo9]/L00_l000001?o7]/[o0000ol2ed?l00003ol6hd@03o`000?o1]Lko000000?o
^[KE0_l000001?ni^=So0000o`000?l00005ok6kh@;o00000_nX_>L2o`0000;oZkcV00Ko0000oijm
k_nN_NkoW[g^o`000?obV50<o`000003om9H4Ol0003ocU8;00oo0000Q?oonfXBo`000003o`L05ol0
003o000000Ko000000Co401Jo`000?lE06_o00000_lS4H800old;Yco0000o`000002ofUO/`Co0000
00?oPX;:o`000?l000000ol00004oiZdj@03o`000?nY`N_oZL7[00?o00000_n]aN/01?l0003o^L[X
okW:j?nib^P2o`000007ok_=j?l0003o^/oZo`000?noe>[o0000ol3FjP02o`000003ol;FjOl0003o
`m[[00;o000000Goa]cYo`000?o7gNWo0000olSOj@02olWQj@03o`000?o9h^[obN;Z00;o000000?o
cNKXo`000?o=inT00_l00003olo[j003om7^j?oAl>SodO3X00?o00000_oEmn<2o`000003omGkh?l0
003o000000Ko00008_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Oooo]Z000Y
oookJP03o`000?oonf[ooo]Z00[ooo]Z1_l000000oo_XW?o0000onfWP@02o`000004onZ[S_l0003o
0000o`0000;oi:fJ0_l000001?oQ/:Co0000on2_Y?l00002omba[004o`000?oL/Jco0000omRc/`;o
000000Goe;:go`000?l0003odKBmo`000003om6d_0?o000000?obKC6o`000?o9]/L00_o9]/L01Ol0
003ob[G6o`000?o7]/[o000000;o`KSA0_l00003ol6ecP;o00000onk]M<2o`000003okZheol0003o
/K_Q00?o00000onc^]h00ol0003oZkcVoj^liP04oj^liPKo000000?ol9MCo`000?l000001?l00000
0ooLJb?o0000omUT7@05o`000003ol]>2ol0003oadP400ko0000OooonfX;o`000003oa/00?l0003o
000000So000000?o0P0Qo`000?l000000_l000001_l904Oo0000oa00F_l0003o5@1[oblJQP;o0000
00?o?C:Ko`000?l000000_l000000omdP=7o0000ogj:e@02ogj:e@03o`000?nBYN;o000000OoV[CY
0_l00002ojg5j`;o00000_nab>/00ol0003o^L[Xo`000002ok_=j003o`000?njcn[o000000;o0000
00?o`=KZo`000?o2e^T00_o2e^T2o`000003ol?Ij_l0003o000000;oamgY00Co0000olWQjOo9hNWo
00000oo9h^X3o`000003olgWjOl0003o000000?ocn_X00GodNkXom7`j?oAl>So0000om;ci`05o`00
0003omGkh?l0003o000000Oo00008_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z
02Oooo]Z000YoookJP03o`000?oonf[ooo]Z00_ooo]Z2Ol000000oo/YX;o0000onVZSP03o`000004
onB]V_l0003oi:bJo`0000;oh:nT0ol00003omba[004o`000?oH/[;of;:bo`0000;oe;6e0_l00003
om6d_004o`000?oA/kco0000o`0000?obKK700Co0000olZea_o:]LKob[G60_l00002ol6hd@Co`KG>
00Go0000ol:dcOl0003o^kGCo`000003okfdd@03o`000?nj^=Oo000000?o/k[N0_l00002okNff003
o`000?n[_>Ko000000;o00000_n^^n@00ol0003oX[g/o`000002o`000003oo2GDol0003o000000So
000000?oe5hKo`000?oCFaP01Ol000000oo4@`?o0000okll000>o`0007Sooo]Z3ol000000olA003o
0000o`000004o`000003o`h07ol0003o000000;o000000?o4`0oo`000?l904L01ol00002ocdbV`03
o`000?mRH;[oHV2j00Co000000?oOX[Eo`000?nBYN800_nBYN800ol0003oV[CYoiZdj@03o`000003
oj:jj_l0003o[LG[00;o00001Onab>/01?l0003o^lgXok_=j?nkcNP2o`0000;o^m3Y0_l00002ol;F
j@05o`000?o3f>Wo0000ol?Ij_l000000_o5g>X3o`000003olWQjOo9h^[obN;Z00;obN;Z00Go0000
ol_Uj_o;in[obnOZo`000002olo[j003o`000?o?k>So000000;odO3X00Ko0000om;ciooBlnOodOGW
o`000?oBmnD9o`000003ok;aZ?nRi93ooo]Z02;ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003o
oo]ZoookJP0WoookJP00:?oonfX00ol0003ooo]ZoookJP0<oookJPOo000000?okZ5co`000?o/YX80
1?l000001?oWZHoo0000onB/V_oT[9X3o`0000;ogjjS00Co0000omba[?oL/Jcog;6/0_l000002OoH
/[;o0000omBa]OoD/KGo0000omBa]Ol0003odKBlo`000002om6c_0?o000000?obKK7o`000?o:]LH0
0_o:]LH3olZda@;o00000oo1]Lh01Ol0003o`[C=ol:dcOo2]<go000000Go_KCA0ol000000onc^]ko
0000okNff004okNff003o`000?n^^nCo[[_T00Co[[_T00?o0000ojFmj_l000000ol000000oo_UUKo
0000o`000003o`000003omi`;_l0003ofFLT00Co000000CocU@Fo`000?l0003ob4X;1ol000000on_
9@3o0000o`00000:o`0007;ooo]Z4Ol000000olA003o0000o`000004o`000003o`h07ol0003o0000
00So000000?o9@Eao`000?l`6hH00_l000000olm<Y_o0000o`000002of9P^P03o`000?n5PLOoQH77
00Wo00001OnR^^X00ol0003o/LS[ok78j`02ok78j`;o00000_ncbn/01Ol0003o^lgXo`000?l0003o
^m3Y00;o00000_nndnX2o`000003ol?HjOl0003o`mWZ00?oaMcZ00Co0000olGMjoo5gN_o00000_o9
h^X2o`000005ol[Sj_l0003obnOZol_Wj_o<j>X00ol000001?o?k>So0000om7`j?oAl>P2o`000009
om;ciooAmNOo0000om;giOoBnNCo0000om7lhOl0003odOkM00Ko00009?oonfX00ol0003ooo]Zoook
JP1;oookJP03o`000?oonf[ooo]Z02Oooo]Z000XoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000
on9c5ol000000_l000000oo^V63o0000o`000003o`000004on^UP_l0003o0000onNYS`?o00000_oS
ZiX00ol0003ogjjSomn^X`02o`000004omba[?l0003ofk2[om^`Z`Co00000ooD/KD2o`000004om6c
_?l0003odK:kom6b^`?o000000?ob[G6o`000?o:]<D00oo:]<D01Ol0003oaK?8o`000?o1]Lko0000
00?o`[C=0_l00003okfdd@03o`000?nn/loo_[??00;o_[??00Co0000okNff?ng]]So]kKH0_l00002
okNgf@03o`000?n^^nCo000000;o00000_n`^n82o`000004oo>WK_l0003o0000onnFEP;o000000?o
jhe?o`000?oXQTL01?l000001OoHIb[o0000om=M7ol0003ocU@F00Go00000_nl>@0Bo`0006cooo]Z
4_l000000ol/01;o0000o`000004o`000005ob/0<Ol0003o0000o`000?lT03l01Ol000000olQ067o
0000o`000002o`000004oc0KQ_l0003oBSfOo`0000;oCdb_0_l00003ohF1a`03o`000?n;U=Oo0000
00CoVj;J00?o0000oj:jj_nR^^X00ol00002ojNoj`04o`000?nab>_o0000o`0000Go/l_[0_l00000
0onkd>Wo0000okkCjP02okkCjP05o`000?noenco0000ol?HjOl000000oo5g>X01Ol0003oaMg[olGM
jol0003oa^7[00;o00000_o:hnX01?l0003obnOZol_Wj_o<j>X2o`000005olk/j_l0003o0000o`00
0?oAl>P00_l000001_oBlnOodOGWom7eiol0003od_WTo`0000;odOcQ00GodOkMolonfol0003oc?oC
okkj^`02o`0002Gooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP0WoookJP00:?oo
nfX00ol0003ooo]ZoookJP0=oookJPKo000000OokIMQo`000?l0003o0000on^UP_l0003ojJ>200;o
000000CoiZR?o`000?oSZi[ohj^J0ol00002omj]X`?o000000?ofk2[o`000?oK[j/00_l00003omBa
]@03o`000?oD/;Co000000?odK:k00?o0000olfa__o=/Kh00_l00004olZda@03olZb`ol0003oaK?8
00?o000000Oo`[C=o`000?o3]<co`kC<o`000?nm]=7o000000?o_[??00Ko0000oknfdOno]]7o0000
okNff?l00004okNgf@;o00001_n`^n800ol0003oljM^o`000003o`000003onjDFOl0003ojhe?00;o
000000?oiXA9o`000?oSOD408_l0001ToookJQCo000000?o;00Bo`000?l000001Ol000002Ol[037o
0000o`000?l0003o900oo`000?lL04Go0000ob80D@05o`0000;o?2:800Go0000odXlWol0003o0000
og=U]002o`0000GoQH7700?o0000oi^Rf_nKX]X01?nKX]X2o`0000KoYko[00Co0000ok?;joncbn_o
/l_[0ol00002okK=k003o`000?nndn[o_]?Z00;o_]?Z00Co0000okoGk?noenco_mO/0_l00002olGL
jP?oaMg[00Woa]k[o`000?l0003ob>?[o`000?o:hn[o0000ol_Wj_l000000_o<j>X00ol0003oc^cZ
o`000002olg^jP;o000000OodO3Xo`000?l0003odOGWo`000?oBnNCo000000;odOcQ00?o0000olon
fol000001?l0000VoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oonfX09ooonfX002So
oo]Z00?o0000oookJ_oonfX03OoonfX00ol0003of6<0o`000009o`0000;ojJ>21Ol00002on:ZVPCo
00000_oN[:<02?l0003ofjn[om^_Zol0003of:j]o`000?oD/KGo00000_oD/;@2o`000008om6b^ol0
003odK6jo`000?o=/Kko0000olf__?l00002olZda@?ob[;300Co0000olFbaoo5//OoaK;70ol00000
0oo3]<co0000o`000002okjcc`;o00000ono]]44o`0000;o]kOI00?o0000okRgeol000000_n`^n83
o`000005ok:jgol0003o0000o`000?obYG001_l000000ooYRe7o0000onJ4B@02o`000005on5j@ol0
003o0000o`000?oJK3<01?l000000oo?FR?o0000ol]A6P06o`0000;o]S404Ol0001LoookJPko0000
00?o<@00o`000?l000003?l000000olc02go0000o`000003o`000003ob@0?ol0003o000000Go0000
00Co=A5eo`000?l0003o?2:80_l000000om:?9oo0000og=U]002og=U]0Co00000_n5PLL4o`0000Co
V[;X00?o0000ojNojonW_n/00ol000000on/a>_o0000ok?;j`02o`0000?o]/g/00Co0000okW=jOl0
003o00000_nndnX3okoGk003o`000?o0en_o`=O[00;o000000GoaMg[o`000?o6g^_oa]k[o`000003
olSSj`Co00000_o<j>X00oo<jN_o0000o`000002olg^jP03o`000?o?l>Woc_;Y00;o000000?odOGW
o`000?oBnN@00_l000000ooAo>7o0000olonf`05o`0002Oooo]Z00?o0000oookJ_oonfX0BooonfX0
0ol0003ooo]ZoookJP0WoookJP00:?oonfX00ol0003ooo]ZoookJP0>oookJPGo00000_o/SDd2o`00
0008on^ML_l0003o0000onVSP_l0003oj::2o`000?oUYhl4o`0000;ohJVJ00?o0000omj/XooN[:<0
0ol000000ooJ[Z[o0000omR^[@02o`000004omB`]?l0003oe:ndomB_]0?o000000?odK6jo`000?o=
[k`00_o=[k`3o`000006olZb`ol0003obk;2o`000?o5//Oo00000oo6/<D01Ol0003oa;C:o`000?nn
/loo000000Co_kKA00?o0000ol:ab_l000000_ni]=@3o`000004okRgeol0003o0000o`0000Co/[[O
00Co0000oo>^Ool0003olZE`0_l000001Oo^VfGo0000o`000?l0003ojH]A00Go000000?ohGY3o`00
0?l000000_l000000ooHJSGo0000omAS;P05o`000003olU@7_l0003o000000Go000000?o]C40o`00
0?l000004Ol0001CoookJQWo000000Go>P0Jo`000?l0003o0000oc/0:@08o`000003ob@0?ol0003o
000000?o000000Go<P=To`000?le4GGo=A5eod4VR@02o`0000;oI4^O0_l00003og=U]0;o00001?n2
R]82o`0000OoV[;X0_l00005ojc4j`03o`000?nfcNco]/g/00;o00000onicNT01?njd^co0000o`00
0?noen`2o`0000?o`=O[00Co0000ol;Kk?l0003o00000_o6g^/01Ol0003ob>?[olSSjoo8hn_o0000
00;ob>C/0ol000000oo<jN_o0000olg^jP02olg^jP04o`000?o?l>Woc_;Yolkbj@;o000000Ooc_OX
o`000?l0003o0000om7lhOl0003ocokK00Go0000:?oonfX00ol0003ooo]ZoookJP1;oookJP03o`00
0?oonf[ooo]Z02Oooo]Z000XoookJP03o`000?oonf[ooo]Z00oooo]Z1Ol000000oo/SDgo0000o`00
0002o`000004onZMM?l0003o0000onRRPP?o00000_oTYXl00ol0003ohJVJon6YVP03o`0000;ogJbS
00Co0000omZ^Z_oJ[Z[o00000_oG[Jd2o`0000;oe:nd00?o0000omB_/ooD[k<00_l00003olf__004
o`000?o=/;gocK2mo`0000?obk;200Wo0000olJ`aOo6/<Goa[35o`000?o7//Ko0000olBdb_l00000
1?no]]401?l0003o`[7:ol:ab_o2/LX2o`0000?o^k?B0_l000000onj]mKo0000ok:jg`04o`000005
oo>^Ool0003o0000o`000?o`Xg800_l000001Oo/VFOo0000o`000?l0003oihUC00Ko00000_oKL3`4
o`000004om5O;_l0003ocEPVoleH9PGo000000?o_d<Do`000?l000001Ol000000onR603o0000o`00
0003o`000003ohP00?l0003o000000[o0000BOoonfXJo`000003ocl05?l0003o000000Co000000?o
>`0Yo`000?l000000_l000001Old03Ko0000o`000?ld04Go=@1600?o000000Co=`1Jo`000?l0003o
<P=T0_l000001?le4GGo0000odLZROl00003ofA;W`?o000000GoLfFdo`000?mlPlooO8??o`000002
oh::dP05o`000?nDY>3oU:CPo`000?nJ/^P00ol00002oj6ijP03o`000?n/a>_o[<C[00?o00000on_
b>`00ol0003o^LgYokW=j@02okW=j@;o000000?o^]3[o`000?l000000_o0en/2o`000004ol7Ijol0
003o0000ol?Mk0;o000000Goa^3[o`000?o8hn_ob>?[o`000002olSTk0;o00000_o9jN`01_l0003o
cNkZolg^j_l0003ocNkZo`0000;oc_;Y00Go0000om3fioo>mnSoc_OXoloji@02o`000003olgmhOl0
003o000000Co0000:OoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z02Kooo]Z000X
oookJP03o`000?oonf[ooo]Z00oooo]Z1ol000000oo[SDoo0000o`000002o`000005onVLMOl0003o
0000onNQPol000000_oTYXl3o`0000;ohJRJ00?o0000omf/XooM[:<00_l000001_oJ[Z[o0000omN]
[OoG[Jgo0000omN/[0;o00000ooD[k<3o`000008olf__?l0003ocK2molf`_Ol0003oc[2lo`000?o;
//82o`0000;oa[3500Co0000olNba_o7//Koak;60ol00002oknfd@Co`[7:0_l00003ok^cdP06o`00
0?nl//oo_;;?o`000?nj]mKo00000_nf]=L00ol0003ol;F@o`000002oo6/P0Go000000?ok9UWo`00
0?l000000_l000000ooUQUCo0000on9oC005o`000003omQ]?Ol0003oe6He00Go00000_o9DbD7o`00
0003ok0]1?l0003o000000[o000000?oSP00o`000?l000002ol0000ooookJQGo000000?o?@00o`00
0?l000001Ol00002ocl050So000000?o>`0_o`000?ld03H00ol000000old04Go0000o`000002o`00
0003ocL0F_l0003o000000;o000000?o@a]io`000?l000000_m7:XT01ol0003oI4^OofA;Wol0003o
HeR`o`000?m]J;/03?l00006oj6ijP;o00000on_b>`2o`000003ok;;k?l0003o^LgY00;o000000So
^m3Yo`000?l0003o0000okgDjol0003o`=O[o`0000;o`MW[00Co0000ol?Mk?o3gNco00000_o4gn`0
0ol0003ob>?[olSSj`03olSTk005olSUk?l0003obNW/olWYk?o:j^`00ol000000oo=k^[o0000olkb
j@02olkbj@06o`000?o>mnSoc_OXolojiOo>n^Go00000_o=oN400oo:om[o0000o`000002o`0002[o
oo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0VoookJP00:?oonfX00ol0003ooo]Z
oookJP0@oookJP?o000000?ohW@Po`000?l000000ol00002on^EI004o`000?oYW7Go0000onNQP`?o
00000_oTYHl00ol0003ohJRJon6XVP03o`0000;ogJ^R0ol000001?oG[Jgoejb/omN/[?oG[:`2o`00
0004omB_/ol0003oe:jcomB^/`?o000000?ocK2mo`000?o>/;`00_o>/;`5o`0000Coak;600Co0000
olRba?o8//Co00001?o2/LX01_l0003o`K;<ol6bc?l0003o^k?Bo`0000Co_;;?0ol000000onf]=Oo
0000oo2eT002o`000007oo6/P?l0003okjZ1o`000?o^XG?o0000onbII`02o`0000;oihiN00Ko0000
onF6E?l0003o0000ommlCOl00002omadA@Go000000?odF8eo`000?l000000ol000001?o2BB7o0000
oka16?nl@AP<o`000003ojPR0?l0003o000000Co000000?oQ`00o`000?l000004?l0000_oookJQSo
000000?oA`00o`000?l000004Ol00002oc/0;`05o`000?ld03Ko0000oc/0?_l000000_ld04D00ol0
003o?P1Bo`000002o`000003od@BJol0003o000000;o@a]i00?o0000odLZROm7:XT00ol000001OmT
Bioo0000of=H/?mSF;3o000000CoRhG700?o0000ohjEe_l000001?nLX]T00ol0003oXKWZoj6ijP03
o`0000;oYko[00Co0000ojo8k?l0003o00001?nbbn`00ol0003o^m3Yok_@j@02o`0000?o_MC[0_l0
0002ol7Ij`04o`000?o3gNco`mg/o`0000?oa=o/0_l000002?o8i>co0000olSUk?o8iNco0000olWY
k?l0003ob^[/0_l000000oo<k^_o0000o`000002o`000007olkbjOl0003oc_OXolkgj?l0003oc_[U
o`000002olgmh@03olWof_l0003o000000?o0000:ooonfX00ol0003ooo]ZoookJP1;oookJP03o`00
0?oonf[ooo]Z02Kooo]Z000XoookJP03o`000?oonf[ooo]Z017ooo]Z1Ol000001OoXPSco0000onZ<
DOl0003ojiET00Go000000?oiZ63o`000?l000001?l00002on2XV@Co000000?og:ZRo`000?l00000
0ooG[:`01?l0003oej^/o`000?l00002omB^/`;o000000?od:ffo`000?l000000oo>/;`01?l0003o
cZnkolj_^ol00004olNbaP05o`000?o8//Cob;;4o`000?o8/L<00_l000000oo2/L[o0000ol6bc002
ol6bc0;o00000onl//l01?l0003o_KGAokfedOnm]M45o`000004onjcT?l0003okjZ1onnZP@Go0000
00?ojYMYo`000?oWSUh00ol000000ooRQ5Ko0000o`000003o`000004omQaAOl0003oeFTmomEY?@Go
000000?oaU8Zo`000?o2BB401?l000000oo2Bb?o0000o`000004o`000003okDg4ol0003o000000Co
000000?oVa<0o`000?l000001Ol000000on9003o0000o`00000Eo`0001Wooo]Z:?l000000om<00go
0000o`000006o`000003odh0:ol0003o000000?o000000?o>`0_o`000?l000000_l000000olk03ko
0000o`000006o`0000;oA19[00?o0000od<KNOm36gT00_l000001?m7:XWo0000oeM1VomG@I/2o`00
0004of=H/?l0003oHeR`o`0000GoRhG700?o0000oibRfOnLX]T01?nLX]T2o`0000KoYko[00Co0000
ok;;k?nbbnco//_/0_l00003okG>k@04o`000?nme>_o_MC[okgDj`;o00000onmf>d2o`000006ol?M
k?o4gncoa=o/olCOk?l0003oa>3]0ol00002olSUk003o`000?o9jNcob^[/00;ob^[/00Go0000olc^
jol0003obno/o`000002olccj`;o000000Ooc_OXo`000?o>n^Go0000olgmhOl0003obOoJ00?o0000
00?o/_Feoh?AOOoonfX0:ooonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Kooo]Z
000WoookJP03o`000?oonf[ooo]Z01?ooo]Z2_l000000ooYU6Ko0000onRKMP03o`0000;oiIn400?o
0000on>TSol000000ol00002omnWV@03o`000?oLZZ;og:ZR00;o000000Koejb/o`000?oGZjcoej^/
o`000?oFZj/2o`0000;odjfb0_l000001?o@[;Go0000olj`_?l00002olj_^`06o`000?o>[[[o0000
o`000?o7//Ko00000_o8//@01Ol0003ob;73olRa`ol0003o`k3700?o000000Oo`K;<o`000?o2//[o
`[;:o`000?nl//oo000000?o_KGA00?o0000ol2_bOl000000_o[^j400ol0003ok[>@o`000002o`00
00;okJR200?o0000onbOMOl000001?l000001_oUS5oo0000o`000?l0003ogh5Go`0000;og7U>1Ol0
0002olmS>`03o`000?o;FS?o000000Co00000_o7Db`5o`000003ok]17Ol0003o000000?o000000?o
ZR/=o`000?l000001?l00002oihG04Co000000?o@`00o`000?l000006ol000000om>02_o0000o`00
0003o`000004odd0>_l0003o0000odP0?`;o000000Oo>`0no`000?l0003o0000ocd0DOl0003oCQ=T
00;o00000_m44V/2o`000003od<KNOl0003oECF>00;o00000omG@I/01?l0003oKVBfofiT]_m^I;H3
o`0000CoRhG71?l00004oibcj003o`000?nW_n_oYko[00?o000000?o[<C/o`000?nbbn`00_l00003
okG>k@03o`000?nic^[o000000;o_MC[00Ko0000okgHkOnmf>go_MS]o`000?nof>`2o`0000;oa=o/
00?o0000olCPkOo4h>d00_l00002olKTk@?o00000oo:j^`00ol0003oc>k[o`000002ol__k0;oc??[
00Go0000ol_hjOo;n>Wo0000olkji@03o`000003olWof_l0003o000000;o000000?oPm5moookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Kooo]Z000WoookJP03o`00
0?oonf[ooo]Z01?ooo]Z0ol000000ooKIPgo0000on9e9`02o`000003onV<Dol0003o000000?o0000
00CoiiYfo`000?oUWhCoiIn40ol00002on:SS`03o`000?oOYiWogjNI00;o000000?og:ZRo`000?oI
Z:@01?l00003omJ[Z`;o000000?odjfbo`000?o@[;D00_o@[;D2o`000003olj_^ol0003ocZjj00;o
cZjj0ol000000oo8//Co0000olRa``02olRa``;o00000_o4[lD4o`000003ol:bb_l0003o000000?o
_KGA00Co0000ol2_bOo0[lWo00000_o[^j43o`000004onbaTOl0003o0000onfXPP?o000000?ojIef
o`000?l000000ol000001?oRRF7o0000o`000?oOPEL3o`000006omQcCOl0003odf]4om=[A?l0003o
cf<k0ol00002om1T?@Go00000_o4DS06o`000003ok4e6?l0003o000000_o000000?oUa80o`000?l0
0000Gol00002odd0>PWo000000CoC@eJocd0DOl0003oCQ=T1Ol000000omC9ggo0000o`000002oeDe
SP04o`000?mQBZ7o0000oeM1V`;o00000_m^I;H00ol0003oRGo2ohUo`P05o`000003oiVKeOl0003o
W;?X00KoW;?X0_l00005ojc4k003o`000?nec^go]Lk]00;o00000onic^X2o`0000;o_MS]0_l00002
okoHk003o`000?o0g>go`=c]00;o00000_o4h>d00ol0003oa^C]olKTk@02o`000003olKVkOl0003o
anW]00;o000000?ob^_/o`000?o;kn`00_o;kn`00oo<ln_o0000o`000002ol_hj@;o000000Gob__U
o`000?l0003o0000ol?nf@04o`0002kooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]Zoook
JP0VoookJP009ooonfX00ol0003ooo]ZoookJP0DoookJPWo000000?oj8aEo`000?oXU6L01Ol00002
onBOQ003o`000?oRXhoohZ>?00?o00000_oNYYT4o`0000;ofJNS00Ko0000omJ[ZooFZj_oeZ^[o`00
0?oFZZ/2o`0000?od:be00Co0000om2[]?l0003o00000oo>[[X00ol0003obZblolZ/_003o`000006
olRa`ol0003ob:o1o`000?o4[lGo00001?o4[L<3o`0000;o_KGA1?o0[lT3o`0000;oj[VQ00Co0000
onbaTOl0003ojZjB0_l000001_o[YX?o0000onVMM_l0003oiiYgo`0000;oiI5[00?o0000on:9HOl0
00000_l00002om]kEP03o`000?oHLdgo000000Co00000_oDJdD3o`000004oleR@?l0003obEXholUJ
>0Co000000?o^dL/o`000?l000001?l00002ok@j70Go000000?oYRTDo`000?l00000Eol000000omI
02?o0000o`000004o`0000;oC`0_2Ol000000omA2E7o0000o`000002odd=FP;o000000?oCQ=To`00
0?mC7g400_l00002oe<WO@;o00000_mE=Hh2o`0000;oHDZQ00?o0000og1U]_m`IKH00_l00003ohUo
`P04o`000?n9S=3oRHc@o`0000?oVI_E00?o0000oibcj?l000000_l00002oj>jjP03o`000?n/a>co
[<C/00?o00000on_b>`00ol0003o^LkZokW>jP02okW>jP03o`000?njd^co^];/00;o00000_nof>`0
0ol0003o`=[]o`000002o`000007ol;Ok_l0003o0000olCRkOl0003oa^C]o`000003olKVk@06olOY
kOl0003oan_^olO[k_l0003obno/0_l000000oo<ln_oboC[o`000003ol_hj@05o`000?o:nnGob__U
olOnh?l000000_o3o]T00onmoLoo0000o`00000_oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000
oookJ_oonfX09_oonfX002Oooo]Z00?o0000oookJ_oonfX05OoonfX<o`000003onRCJ?l0003o0000
00Ko00000_oQXY02o`000003omjVVOl0003ogZFI00;o00000_oIYj<2o`000007omJ[Zol0003oeZZ[
omJZZol0003oeZVZo`000002om2/]@;od:^d00Wo0000om2[/ol0003ocZjjo`000?o>[KWo0000olZ/
_?l000000_o:[K`2o`0000;ob:o100?o0000olB]`oo4[L<00_o4[L<00ol0003oaZo4olJ_a002o`00
00Co`:o90_l000001?oV_joo0000onZiXOoZ^J43o`0000;ojZjB00?o0000on^VPol000000_l00002
onNJM`03o`000?oUTF_o000000;o00000_oOQV85o`0000;ofgYE1Ol00002om5YB0Go00000_o0Cc@2
o`000003ok]7;?l0003o000000Oo00000_n/=1l<o`000003oiTK3?l0003o000000Co000000?oSPT0
o`000?l00000:?l000000omR003o0000o`000009o`000003of<02ol0003o000000Ko00000omP0282
o`0000;oF@0S1_l000000omL03Ko0000o`000003o`000005oe00@?l0003o0000oeX=C_l000000omA
2E401Ol0003oC@eJodd=F_l0003oEAUV00;o000000?oDamao`000?l000000_mC9gd01Ol0003oHCf?
o`000?mE=Hko000000;oIdnR0_l00002ogm//`;o00001On9Ol82o`0000CoVI_E0_l00006oj>jjP;o
00000on_b>`2o`000007ok;<kOl0003o^LkZo`000?nid>co0000ok[Bk002o`000005ok_Hk_l0003o
_mS/o`000?o0f^d00_l00002ol;OkP03o`000?o2hNko`^7^00;o00000_o6i^d01?l0003oa^O]o`00
0?l00002olO[kPGo000000?oboC[o`000?l000000_o;n>T01Ol0003ob__Uol[kiOo7o^3o000000;o
`okI00?o_Og?o`000?l00000<?oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Ko
oo]Z000WoookJP03o`000?oonf[ooo]Z01Kooo]Z1ol000000ooVPD?o0000o`000003o`000006onNB
JOl0003oiIUhonFIN?l0003oi9j51?l000001_oQXY3o0000o`000?oNYIWo0000om^SVP;o00000_oI
Yj<4o`0000?oeZVZ1?l00003om2[/`?o000000?ocZfio`000?o:[K`00_o:[K`01Ol0003objbko`00
0?o8[l7o000000?oa:g300?o0000olJ_a?o6[l@00_o6[l@3o`000006ol2_bOl0003ogL6momg1_Ol0
003oi;f_0_l00002onRgX@03o`000?oZ[Y;ojZjB00?o000000?oj:>4o`000?l000001?l000000ooR
SVco0000o`000002o`000004omb2H_l0003ogH9Momf2G@?o000000Cof7QHo`000?oDLE3oe75@0ol0
00001?o=IDSo0000olAG??o4Ec`3o`000003ol1?=?l0003o000000Ko000000?o/SdZo`000?l00000
1?l00002ojhf80Co00000_nQ9QT6o`000003oiPG1ol0003o000000So000000?oR`L0o`000?n<30D0
4ol000000ome003o0000o`00000Ko`000003ofP08_l0003oH00R00?o000000?oH`0Vo`000?l00000
1?l00002oe`0=PGo000000CoG@]7o`000?l0003oFPe>0_l00002oe49D@?o000000?oC@eJo`000?mE
6FH00_l000001_mC7g7o0000oeh_Ool0003oDbMmo`0000;oHCf?0_l00003ofM?XP04o`000?moK;?o
Ofbcogm//`Go00000_n9Ol800ol0003oVI_EoiVKe@04oiR]i@03o`000?nS^^[oXk[Z00?o00000_nX
`N/01?l0003o[lS/o`000?l00004ok;<k@?o000000?o^];/o`000?nkf>h00onkf>h00ol0003o`=[]
o`000003ol;OkP05o`000?o2hNko`^7^o`000?o3i>l00_l00002olKWk@06o`000?o7jnkoan_^olO[
k_o8k>ko00000_o8l>d4o`0000;oboSY00Go0000ol[kiOl0003oaokPo`000002ol?nf@?o0000<Ooo
nfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z02Gooo]Z000WoookJP03o`000?oonf[o
oo]Z01Oooo]Z1ol000001?oVPD?o0000o`000?oWReP2o`000003onNBJOl0003oiIUh00?o00000_oS
WHD01?l0003ohJ:@o`000?oPXI02o`0000;ofj>J1?l00002omRVX`;o00000_oFZJX01?l0003odjN/
om>W[?l00003om2[/`03o`000?o@Z[;od:Zb00;o00000_o:[K`01?l0003objbkol^/^oo;[;/3o`00
0003olB]`ol0003oaZo400;oaZo400Go0000olJ_`oo6[l?o0000ol6^a`03o`000005omg1_Ol0003o
0000onBm[ol000000_oX]j43o`0000;oj:bB0ol00002onJQQ@03o`000?oTV7So000000;o00000_oO
Rf`00ol0003og89Ro`000003o`000004om^0Gol0003o0000omQhF0?o00000_o@KE05o`000003olAG
??l0003o000000Co000000?o`UDno`000?l000001_l00002ok@o:`Co000000?oYc4To`000?l00000
4Ol000000on?4a7o0000o`00000Oo`0000?oM@0A00?o0000ofd05Om]01D02_l000000omX02;o0000
o`00000:o`000003ofH9>Ol0003o000000Go000000?oG@]7o`000?l000000ol000001_mO5eSo0000
o`000?l0003oF1ALoe/HG`Go000000CoDamao`000?mN;gooGRmo0_l00002of4mS`;o000000?oJ4nQ
o`000?mWCj800_l00002ogm//`03o`000?n7Q/_o000000GoQhW>00?o0000oiR]iOnH[ND01OnH[ND2
o`0000KoZ<7[00Co0000ok;<kOnbc>go//c]0_l00003okK<j`04o`000?nkf>ko^mS^ok_HkP;o0000
0onlf^l00ol0003o`]o^ol;OkP03ol;QkP03ol?Rk_l0003o`nC_00;oa>O_0_l000001Oo7jnko0000
olS/k_o8k>ko000000;ob?3]0_l000000oo8mNco0000olWhjP04o`000003olOnh?l0003o`okI00Co
0000<_oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z02Gooo]Z000WoookJP03o`00
0?oonf[ooo]Z01Sooo]Z2?l000000ooUPDGo0000onN;F005o`000004onFHNOl0003o0000on>MQ@?o
00000_oPXI02o`000005om^SV_l0003ofj:Jom^RV_l000000_oHYZ<01Ol0003of:FRo`000?oFZJ[o
000000;odjN/0_l000000oo@Zk?o0000om2Z/P02om2Z/P05o`000?o@ZK7o0000olZ]_?l000000oo;
[;/00ol0003objbjol^/^P03o`000003olJ_a?l0003oaZo300?oaZo30_l00002om;3b`05o`000?oK
_kgofknmo`000?oS_;000_l00002onJdX@;o000000?oj:bBo`000?oVZY<00_l000001?oVXHGo0000
o`000?l00002on:EN@Go00000_oNR6P3o`000003omQlH?l0003o000000;oe7AH0ol000001?o:IDko
0000o`000?o8GdH4o`0000;oaUe61Ol000000oniBc[o0000o`00000Ao`0000;oX2`V1_l00002oiHO
7Q_o000000?oNP@Co`000?l000006_l00002of/;=`?o00000_mV2CT=o`0000;oGaMH0_l00002oePD
G0Co000000CoGRMcof0YM?l0003o00000_mN;gl2o`0000;oHCf?00Co0000og1DX_l0003oJ4nQ1_l0
0003ohN6b`07o`000?n7RLkoQhW>ohN9c_l0003oUj7Ko`000002oiR]i@?o00000_nP]^P00ol0003o
Z<7[ojS1j`03o`000003ojg6k?l0003o//c]00;o00001?nfc>/2o`000003ok_Hk_l0003o000000?o
_=[_00Co0000okkJk_l0003o00000_o2hNh01?l0003o`n;^o`000?o3i>l2olCWk`04o`000?o4j>oo
0000o`0000;ob>c^00Co0000olS`kOo8lNgo00000_o8mN`3o`000006olOijOo6o>Koa_cVo`000?o1
o]oo_?gG1?l0000coookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX09OoonfX002Oo
oo]Z00?o0000oookJ_oonfX06_oonfX:o`000003onJ:F_l0003oiY9Z00?o000000Coi9Mio`000?l0
003ohYb51?l000000ooMWY3o0000o`000002om^RVP?o00000ooHYJ84o`0000;odZN/0ol000001?o@
Z[;o0000om2Y/Oo@ZK44o`000003ol^/^ol0003objbj00;objbj00?o0000olNZ_?o7Z[`00_l00003
olJ_``;o00000_oB`l/01Ol0003odL7;o`000?oK_kgo000000;ohkb`0_l000000ooV]:7o0000onBb
XP02o`000003onJZTol0003ohjND00;o000000Oohij6o`000?l0003ohYEio`000?oOTWWo000000;o
hHma0ol000001?oKQ6Wo0000o`000?oHO604o`0000;ocVeF0_l000001?o:IDko0000o`000?l00002
olYUCPCo00000_nmDd<2o`000004okU;>_l0003o0000ok]>?0Go00000_nbA3P6o`000003ojHe<Ol0
003o000000Go000000?oWRLQo`000?l000007Ol00003oh@C9003o`000?mj2Ako000000Co000000?o
N0`Xo`000?l000001?l00003ogD><003o`000?m`33;o000000;o000000?oLa0go`000?l000000_l0
00000om_3c_o0000o`000009o`0000;oHA5>0ol000001?mO5eSo0000o`000?mT7f42oePDG0;o0000
00CoI2E[o`000?mN9g?oGRMc0_l000001omN;goo0000o`000?mZ@Xoo0000of4mSol000000_m`E:82
o`0000CoPffa1?l000000on7Q/_o0000ohN9cP07o`0000KoX;KX0_l00005ojg6k004o`000?nfc>_o
]/c[okK<j`;o000000Co^=3/o`000?l0003o00000_nlf^l2o`0000;o_][^00?o0000okoNkonog^l0
0_l00002ol?RkP07o`000?o4inooa>O_o`000?o4j>oo0000olK/k`04o`000004olSakOl0003ob?G/
olSek0?o000000GoaoWYolKli_o6o>Ko0000ol7ng`02okcme`?o0000=?oonfX00ol0003ooo]Zoook
JP1<oookJP03o`000?oonf[ooo]Z02Gooo]Z000VoookJP03o`000?oonf[ooo]Z01cooo]Z00?o03fi
o`000?l0Dl`00_l000000ooRMS;o0000o`000005o`000004onFAJol0003o0000onBGN@?o00000_oQ
W8D01?l0003ogIj@o`000?oLWY02o`0000;ofZ:J0ol000000ooHYJ;o0000omRUXP02o`0000;odZN/
00?o0000om:VZooBYZ/00_l00002om2Y/@04o`000?o=Yk;ocJNbolfW/P?o000000Wobjbjo`000?o;
ZkWo0000olNZ_?l0003ob:Zlo`000?o6[l<00_l00002om;3b`0;o`000?oA`L_odL7;om71bol0003o
f[fmo`000?oS_;3o0000on6j/?l000000_oT/Z801?l0003oh[2Ro`000?l00002on>WU004o`000?oS
WXKo0000on2KQP;o000000?ogi9io`000?l000000_l000001?oNS7;o0000o`000?oKQ6T3o`0000;o
e7QP1?l000000oo=K5Oo0000o`000002oli[D`Co000000?oaF1=o`000?l000002_l000000oncB3oo
0000o`000004o`0000;o/DDl1?l000000onV=C7o0000oj@b;@02oj@b;A;o00000onC8b/2oh`K9Pko
00000_n14bL4o`0000?oOaD`00?o0000ogD><?me3S002_l000000om_3c_o0000o`000007o`000004
ofPEC?l0003o0000of`KDPCo000000CoJR1Lo`000?l0003oI1mQ1?l000000omT9F_o0000o`000002
oehWL`Co00000omZ@Xl2o`0000?oL5BR00?o0000oh=]/On3KK400_n3KK42o`0000?oTXW61?l00004
oijQe`03o`000?nP]^SoX;KX00?o00000_nV_NX00ol0003o[LK/ojg6k003o`0000?o/<[]00Co0000
okS@k?nhd>co^=3/0_l00002okWDkP;o00000onnf^h01?l0003o_mk_o`000?l00002ol3Ql0;o0000
0_o4inl2olCXk`;oa^c_00Co0000olG]kol0003oa_7^0ol000000oo8mNco0000o`000002olOij@05
o`000?o6o>Ko0000ol7ngonloML01?l0000eoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oook
J_oonfX09OoonfX002Kooo]Z00?o0000oookJ_oonfX07OoonfX2o`000007o`1Qe_l0003o0000o`00
0?oQMSGo0000onB1B@05o`000005onBAK?l0003o0000on>GN_l000000_oQW8D3o`0000;og9j@1?l0
0002omZQVP03o`000?oHYJ;of:FR00Co00000ooBYZ/01_l0003odZJZo`000?o@ZK7od:R`o`0000;o
cJNb00?o0000olfW/oo=Yk<00_l00002ol^[^@04o`000?o8Z[cob:ZlolRZ_0?o000000?od/?;o`00
0?oA`L/00_oA`L/01Ol0003od;o:o`000?oJ_Kgo000000;ohKZ`0ol00003on:`XP03o`000?oSYiCo
hjND00?o00000_oPVhH3o`0000;oh9Ak0_l000001?oNS7;o0000o`000?l00002omN1J@Co00000_o@
M6000ol0003odG9Jom5bFP03o`0000;obVQE1?l00002ol5JB`Go00000_ngCdL3o`000003ok=8?ol0
003o]4Pn00;o]4Pn1Ol000000on[?SWo0000o`00000;o`0000CoVRdc0_l00002oiDT:`Ko00001?n>
7RXGo`000003og/G=ol0003o000000oo000000CoLAe>o`000?l0003oK1]B0ol00002ofXPG0;o0000
00CoI1mQo`000?l0003oJRY/1?l000001OmZ<GOo0000o`000?l0003oJ3N100;o00000omZ@Xl2o`00
0003og1DXOl0003oL5BR00;o00000on3KK400ol0003oRXC7o`000005oi:9aP03o`000?nNXMOoWZ7G
00CoWZ7G0_l00006ojJmjP;o00000on`b^d2o`000003ok;>k_l0003o^=3/00;o00000_nie>h2o`00
00;o^]W`0ol000001_nog^oo0000ol3Ql?o0hO3o0000ol7Rl0?o000000Goa>S_o`000?l0003oa^c_
o`000002olG]k`04olKak_l0003oaO;_olGbk`Co000000?oaoWYo`000?l000001_l0000goookJP03
o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX09OoonfX002Kooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0>kOo0000o`000003o`000006on5f=Ol0003o0000on>1Bol0003oi8UM0_l000000ooT
TFco0000o`000004o`000003omnIQOl0003o000000;o00000_oLWI000ol0003ofZ6JomZQVP03o`00
0003omNTXOl0003oe::S00Co00000ooBYZX3o`000003olfW/_l0003ocJNc00;ocJNc00Ko0000olfW
/_l0003obj^io`000?o8Z[`2o`000004okS0h?l0003ob/?Co`0000?odL7;00Ko0000om2ob_o@_l[o
d;o:o`000?oH^kd2o`0000;ogkR`0_l00002on:`XP?o00000_oQYI@5o`000005on:LQ_l0003oh9Ak
o`000?oMTW`00_l00002omZ9LP?o00000_oBNVP00ol0003od7APo`000004o`0000;ocW1M1?l00002
ol=PD`Co00000_o1GU45o`000003okQ?A_l0003o000000Go00000_n]@d49o`000003oj@i>ol0003o
XC@f00;oXC@f5Ol00004ohdS=P04o`000?n46S;oQ1Xboh@J<PGo00001?n27S/00ol0003oOA/no`00
0009o`0000;oMQe:2Ol000000om/6e;o0000o`000005o`000003oflYI_l0003o000000?oJRY/0_l0
0002ofXaM`;o00000omX=h42o`0000;oJT:?00?o0000ogeIW_l000000_m`E:44o`000003oh=]/Ol0
003oRXC700;oRXC700Co0000oi:9a_nBRLKoTXW60_l00002oijQe`?o00000_nN/^H00ol0003oY[gZ
ojJmjP03o`0000;oZlC/00Co0000ok3:kOl0003o00001?nbc^h2o`0000;o^MC^00Co0000ok[Il?nj
fO3o00000_nlf^l2o`000003ol3Ql?l0003o000000?o`N;`00?o0000ol;Wl?l000000_l000001?o6
k>ooaNg_olG]koo5k^l2o`0000;oaO;_0_l000000oo5mngo`o[Zol?jjP08o`0003Sooo]Z00?o0000
oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0UoookJP009_oonfX00ol0003ooo]ZoookJP0Ooook
JP;o000000?o063Do`000?l000001?l000000ooSPD_o0000onB9G@03o`000003on>@KOl0003o0000
00Co00000_oNV8H00ol0003og9f@ombMT003o`0000;ofJ2I1Ol00002omBRX`?o000000CodZJZo`00
0?oBYJWodZFY0ol000000oo=Yk?o0000olfW/P02olfW/P?o00001?nh`>001Ol0003obL;Co`000?oA
`L_o000000?od;o:00Go0000olnnb_l0003of;^mo`000002omnh/004o`000?oM][7o0000o`0000;o
h:jS1?l00002omjRU@;o000000CohYb6o`000?l0003o00000_oMTW`4o`0000;oehIc1_l00002om9h
I@Co00000_o6IeX3o`000004ol=PDol0003oaFAEolETE@Co00000_nlF506o`0000;o/D]91_l00004
oja2?P03o`000?nY@D;o0000027o00000on<9d000ol0003oPQhko`00000;o`0000;oOB9:1?l00000
0omi8e3o0000o`000002o`0000?oMB=E1_l00003oflYIP;o00000_mZ:V`3o`000005ofXaMol0003o
0000og8oPol000000_mX=h42o`000003og=9T?l0003o000000?oOEVN0_l00003ohM`/Pko00001_nN
/^H2o`0000KoZlC/00Co0000ok;>k_nbc^ko//k^0_l000001Onfc^co0000o`000?l0003o^]W`00;o
00001?nlf^l3o`0000Co`N;`00?o`^O`o`000?l000000_o2j?43o`000003olG^kol0003oaO;_00;o
aO;_0_l000000oo5mngo`o[Zol?jjP02o`000004ol3liOnkoMko0000okGle@;o0000>_oonfX00ol0
003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Gooo]Z000VoookJP03o`000?oonf[ooo]Z023o
oo]Z00?o03Zdo`000?l000000ol00002obN0j0Co000000?ohhUNo`000?l000000ol00002on2CN@;o
000000CogYR6o`000?l0003o00000_oKW904o`0000;ofJ2I0_l00002omBRX`03o`000?oDXZ;oe::R
00;o00000_oBYJT00ol0003ocj>[olnSZ`03o`000003olfW/_l0003o000000?o^<3P0_l00002okRo
g`03o`000?o9`]?o000000?od;o:00Co0000olnnb_o?_/[ockk:0ol000001OoO^;3ogKJaomff/OoM
][7o000000;oh:jS00Co0000omf/XooM[:?o00000_oNXYD3o`0000;ogiZ71?l00002omZ?O@;o0000
00?oehIco`000?oCPW<00_l00002omEoJ`?o00000_o=M6D5o`000003olIWFol0003o000000?o0000
0_nmG5H3o`000003okaHD?l0003o000000;o^eYC1?l000000onaBdWo0000ok5:A`02ok5:A`Wo0000
00?oYSe0o`000?nU?dH00_nU?dH00ol0003oXC]4o`000005oi`gA@;o00001OnG;cd@o`0000;oR2M3
1?l00003ohDXBP03o`000?mm8T[o000000;o000000?oPBQ@o`000?l000000_l000001?mm:EOo0000
ogDSEOme8eD7o`000003ogPaJ?l0003oKbUV00;o000000KoM3=_o`000?l0003o0000og4fMomc>GT2
o`0000?oLSn30ol000001?mbB93o0000og=9T?l00003ogeIWP;o00000on7L;82o`0000GoU8S500?o
0000oi:BdOl000001?nNWmD00ol0003oW[;VoijbiP03o`000004ojFkjOl0003oZlC/oj_4k0?o0000
0on^bNd2o`0000Co]/k/00Co0000okOCk_l0003o00000onlf^l4o`0000;o_^7a0ol000000oo2io3o
0000ol;Xl@02ol;Xl@;o00000_o2k_400ol0003oaO;_olGbk`02o`0000;oaOO]0_o3n^X2o`000003
ol3liOnkoMko000000?o0000>ooonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z02Go
oo]Z000VoookJP03o`000?oonf[ooo]Z027ooo]Z0_l000000ol0Gm?o0000o`000003o`000003oc25
jol0003o?8c^00Co00000_oQS6/01?l0003oh9=io`000?oOTWX2o`000003omfHQ_l0003o000000;o
00000_oKW902o`000003omVPVOl0003oeYjJ00;o00000ooDXZ800ol0003oe:6Ro`000002o`0000;o
cj>[1?l00002ojFkj@03o`000?nh`>3o000000Go^;oO00Go0000olS1e?l0003od;o:o`000003olnn
bP05o`000?o=_<WocKc9olflbOl000000ooM][43o`0000?ogJbS0ol000000ooLX9Go0000o`000003
o`0000;og9R70_l000000ooJSggo0000omJ;O@02o`000003om>2Lol0003o000000?o00000_oAO6d4
o`0000;obFmU1Ol00002olEYH0Co000000?o_EaFo`000?l000001Ol00002okIDDPWo000000?oZdI;
o`000?l000000_nY@dLEo`0000?oUC9700?o0000oiDcB?l000000_n=:d@;o`0000?oQBQ:1?l00000
0on1:53o0000o`000002o`0000;oOBUG2_l00003ogPaJ0;o00000_md<fl2o`0000;oLCIg0ol00003
og8oP`;o00000ombB903o`000005ogeIW_l0003o0000ohA^/_l000000_n7L;800ol0003oSXG5o`00
0006oiB8a@03o`000?nNWmGoWYoE00CoWYoE0_l00005ojFkj@;o00000on^bNd2o`0000;o/Lg^00Co
0000okK>k?l0003o]]7^0ol00002okWIl@05o`000?nlf^oo0000okgLkol000000onnhO401?l0003o
_n?ao`000?l00002ol;Xl@Co00000_o2k_400ol0003o`o7`o`000002o`000003olGgkOo4mngo0000
00;o00000_o0o>D00onkoMko0000o`000002o`0003cooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0
003ooo]ZoookJP0ToookJP009_oonfX00ol0003ooo]ZoookJP0SoookJPGo000000?o9H3Xo`000?l0
00002_l00002omnBNP?o00000_oLUhH2o`000003om^LT?l0003ofY^@00;o00000_oFWYX4o`0000?o
e:6R1Ol00006ojFkj@04o`000?nh_moo^;oOokRog`;o00000_ng_]l00ol0003ob<7Do`000003olnn
bP03o`000?o=_<WocKc900;ocKc90_l000001?oM][7o0000om^d/OoK];42o`000004omf/Xol0003o
fjVTom^YY0Co00000_oNX982o`000003ombHQol0003ofIB800;o00000_oFRgd4o`0000;oeHEf1?l0
0002olehK@Go00000_o:LVP5o`000003ol1TGol0003o000000Co00000_ngF5P6o`0000Co]5AE00?o
0000ojm>DOl000008Ol00003oi<gD@03o`000?n;;dkoRbm>00ko000000?oQC5Jo`000?l000002_l0
0004ogPaJ0;o000000KoM3=_o`000?l0003oNSijo`000?ma=WL2o`000003ogY5QOl0003oLSn300;o
000000GoNdjAo`000?mbB93oLTR@o`000002og]IWPGo000000?oQ6jbo`000?l000000on>QLD00ol0
003oU8S5oiB8a@02oiB8a@Go00000onN/>@00ol0003oYK_YojFkj@03o`0000;oZL;[00Co0000ojk9
kOl0003o00001OnacNh01?l0003o]]7^o`000?l00005okWIl@03o`000?nmg>oo000000?o_^7a00Co
0000okoSlOnoho7o`>Oa0_l00002ol;Yl004o`000?o2k_7o`^kaol;^l@?o000000Co`_?`o`000?o1
mnko`OO^0ol000000oo0o>Go0000o`000004o`0003gooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0
003ooo]ZoookJP0ToookJP009_oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?l0G];o000000Co
000000?o;XG[o`000?ljS>h00_l000000om>U_7o0000oe:Hl@0:o`000003ombGQol0003o000000;o
fY^@2_l00004oiNgkP03o`000?nU^nWoYK_Y00?o000000?oYK_Yo`000?nh_ml00_l00005okNng`05
o`000?o7`MCo0000olnnb_l000001?o=_<T2olfmb`;o00000ooK];401?l0003ofK:bo`000?l00002
om^YY004o`000?oHYjCo0000o`0000;ogZ2B00Co0000om^NTol0003o00000_oIU8P4o`000003om>8
OOl0003o000000?o00000_oAPGH5o`000003olUdK?l0003o000000?o00000oo5KFL2o`000003ol1T
Gol0003o000000;o`6IR1?l000000ongF5So0000okMGE`02okMGE`_o00000on[C5D00ol0003oZ4QC
o`000005oj=5E003o`000?nN?TooWSi?00CoWSi?0_l00005oi/lC`;oTcMA2?l00003oi0gE003o`00
0?n8<EKoR35F00Co00000on6<ed3o`0000?oPSES1?l00003oglgJP03o`000?mh<FSo000000;o0000
00?oOCYao`000?l000000omj?WX2o`000003ogU4Q?l0003oNTF500;o00001?mkCY42o`0000;oNeVN
0_l00004ohA^/Pco000000?oWYkDo`000?nN/>@01OnN/>@2o`0000KoZL;[00?o0000ok7=k_nacNh0
0_nacNh2o`0000;o]<k]00?o0000okWIlOnifO400_nifO42o`0000;o^M_a0_l00002okkQl@;o_n?a
00?o_^Cao`000?l000000oo0jO801?l0003o`^kao`000?o3ko02o`000003ol;cl?l0003o000000;o
`OO^00Oo0000okojjol0003o^_cUo`000?neo=go[O[C00?o0000?_oonfX00ol0003ooo]ZoookJP1<
oookJP03o`000?oonf[ooo]Z02Cooo]Z000UoookJP03o`000?oonf[ooo]Z02Kooo]Z1?l000000ol5
K]go0000o`00000:o`0000CoHJ3c0_l000000om_Yo?o0000o`000003o`0000?oO:gb00?o0000ohRa
lOn8/O400_n8/O400ol0003oUkO^oiNgkP04oiNgkP;o00001OnU^nT00ol0003o]kkOokNng`02okNn
g`;o00000_ng_]l00ol0003oal7Do`000002o`0000;ocKc90oo=_L/01Ol0003oeKZoo`000?oK];7o
000000;ofK:b00Co0000omJ`/_l0003o00000_oHYj@5o`0000;ofijC1?l00002omFAR@;o000000Co
ehamo`000?oDRWooe8Yo0ol000002OoAPGKo0000ol]kMOo;NgGo0000olUdK?l0003ocGQ]o`000002
olUfK`co00000_nkH647o`0000?o/5=J0_l00003ojmAF1co00001?nE>eH01?l0003oT3MDoi0gE?n@
=e@6o`0000?oS3QL1?l00002ohTjH`Co000000?oQSe[o`000?mo=fX00omo=fX3o`0000;oOCYa0_l0
0004ogXnNP;o000000?oNDB4o`000?mjAHD00_l00004og]>T@;o00000_mkFIh00ol0003oS6n]o`00
0004ohA^/P;o00001OnFRlD00ol0003oU9??o`000004oijNe003o`000?nN/>Co000000;o00000_nT
^NP00ol0003oZL;[ojW2j`03o`0000;o[LO]00Co0000ok7=k_l0003o00001?ndc^d2o`000003okWI
lOl0003o000000;o^M_a00?o0000ok_Ll?l000000_l000000onoho7o0000okkTl@02o`0000?o`>Wb
00Ko`>[bo`000?l0003o`no`o`000?o2lo02o`0000?o`OO^00[o0000okojjol0003o^_cUokGlgOl0
003o[O[Co`000?nBjK3o0000?ooonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z02Co
oo]Z000UoookJP03o`000?oonf[ooo]Z02Sooo]Z1_l000000ol/QN_o0000ocR<kP02o`000003odbF
lOl0003oDIWb00co000000?oNjcbo`000?l000002_l00004oiNgkP03o`000?nU^nWo000000;o0000
0_nU^nT01?l0003o]kkOo`000?l00005okNng`05o`000?o6`=Goa/3EolK0eOl000000oo=_L/01?l0
003obkc<o`000?oE^[l4o`0000?oe[2b0ol000001OoHYjCo0000ombVW_oLYYko000000;ofijC00?o
0000omRKU?oHVi@00_l000000ooETHWo0000o`000003o`0000;oe8Yo00Co0000om26Ool0003o0000
0oo;NgD4o`0000;obGI_00Co0000ol=_Koo3Kfoo`fm_1Ol00002okmYJ@?o000000?o^f1Qo`000?l0
00000oniH6<:o`000004ojmAF?l0003o[4mIo`0000?oZDaH00Co0000ojQ<FonXC5_o00000onSAeT0
1_l0003oXTQKoj98FonRB5_o0000oie2F0oo00000_nC?Uh00ol0003oS3QLoh`hG005o`0000?oRCYS
0ol00004ohHmJ`03o`000?mo=f[o000000;o000000?oQ41co`000?l000000_l000000on2A7_o0000
ogXnNP03o`000003oh5:Q_l0003o000000;o000000?oPU>Ao`000?mkCY400ol000001?n6Gigo0000
og]IW_l00002oha_[@03o`000?n4K[;oQ6jb00;o000000?oTh:no`000?nFRlD01?nFRlD2o`0000Go
WYkD0_l00006ojBij0;o00001_n]and01?l0003o]<k]okC>kOndc^d2o`0000;o]M?_0_l000000oni
fo7o0000o`000002ok_Ll0;o000000Go_>7bo`000?l0003o_^Cao`000002ol3YlP07o`000?o0j_;o
`>[bo`000?o0ko;o0000ol3_lP03o`0000;o`OO^0_l000000onnn^[o0000o`000002o`000003ojgi
d_l0003o0000047ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0ToookJP009Ooo
nfX00ol0003ooo]ZoookJP0YoookJP?o000000?o0VkLo`000?lOOnL02_l00004of2Ql`;o00000om_
Yo<00ol0003oNjgco`000003ogb]l`06o`000?n7/_7oQk;aohNblOn8/_7o00001_nG]nh00ol0003o
YK_YojFkj@04ojFkj@03o`000?ng_]oo]kkO00;o]kkO0_l00002okFmg`07o`000?o6`=Go0000olBo
e_l0003ocKg;o`000003ol^lc005o`000?oC^/7odk[1om>j`Ol000000ooF/;800ol0003odjjcom>^
/`02o`0000;og:JN0ol00003omRKU003o`000?oDV9Go000000;o00000_oGTXP4o`0000;od8Io0ol0
00001?o;NgGo0000olenM_o=OWH3o`000003olUfKol0003o`fm_00;o`fm_00?o0000olAaKoo4LFl0
1Ol000000onlIFOo0000o`000006o`0000;o]5]Q00?o0000ok=IH?l000000on]EV8Do`0000CoWTMN
00?o0000oi]4G_nKA5h01?nKA5h00ol0003oTcmOo`000006o`0000?oT3mT00?o0000ohTjHol00000
0_l000001?n=@V_o0000ohHmJon6?F/5o`0000?oQ41c0_l00003oh94N`?o00000on1BXH2o`0000?o
PE>B0ol00004ohIOW@;o00001?n<Kjd2o`0000CoTh:n00Co0000oiJ;aOnFRlGoUX_51Ol00004oin`
h`03o`000?nT^NSoY;WX00?o000000CoZL7[o`000?n]ango[LO]0ol00003ok3<k`;o000000?o]]7^
o`000?l000000_l000000ongeo3o0000o`000003ok_Ll004o`000?nlhO;o0000o`0000;o_>?b0ol0
0003ol3ZlP;o`>ob00?o0000ol3_l_l000000_nolo44o`000003okkjj_l0003o000000Co0000@ooo
nfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z02Cooo]Z000UoookJP03o`000?oonf[o
oo]Z02[ooo]Z1?l000001OlAN>?o0000o`000?l0003o=Xc^00;o000000CoBiOao`000?m?VO;oCiWb
6?l00004oiJgkP03o`000?nU^nWo000000;o00000_nT^nT01?l0003o]kkOo`000?l00005okFmg`05
o`000?o4_mKoa;oFolBoe_l000000oo;_<`2o`0000?odk[10_l000000ooF/;;o0000om>^/`02om>^
/`04o`000?oA[;Co0000o`0000;ofJFP1?l00003omBHU@?o000000Coei:8o`000?oDT8Woe9291?l0
0002olb2O`Go00000_o9NWP6o`0000?oa75_00?o0000okeZL?nmJW001_l00003okEPJ0co00001_n[
DUl00ol0003oYDeOojE=G`04ojE=G`04o`000?nNAekoWTMNoii7GPgo00001?nFA6H8o`0000?oSD9[
1?l00003oh]5L`03o`000?n4@7?o000000;o000000?oR4Umo`000?l000000_l000001?n7ChOo0000
oh5:Q_n1BXH2o`000003ohMHTol0003oPE>B00;oPE>B1?l00002ohIOW@;o00001?n<Kjd2o`0000Go
Th:n1Ol000000onPX=Co0000oin`h`06oin`h`;o00001OnY`N/2o`0000?o/<c_0_l00003ok;@l0;o
00000_ngeo02o`0000?o^=_b00Co0000okcQl_nlhO;o00000_nlho83o`000004okgZlol0003o0000
ol3ZlPCo`>ob0onolo42o`000009okchk_nkn^_o^O[Zo`000?ndnnCo[_[Ko`000?nUmm3oUnno04Co
oo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0ToookJP009OoonfX00ol0003ooo]Z
oookJP0[oookJP[o000000?o?93_o`000?l000002Ol00003ofjXm003o`000?mj[O?o000000?oNjgc
00Ko0000ohNbl_n7/_;oQk;bohRblOl00006oiJgkP03o`000?nT^nWoY;_Y00CoY;_Y00?o0000okFm
gone_Ml00_ne_Ml2o`0000;o];cP00Oo0000olBoe_l0003o`[oGo`000?o;_<co000000;ob;_=00?o
0000om>j`Ol000000_oA^/<2o`0000;odjjc00?o0000om6/]?oA[;@00ol000001?oIYJ3o0000omJR
XOoFXZ43o`000004omBHUOl0003o0000omJIT`?o000000Coe929o`000?o@S8Wod8b91Ol00002olf4
P0Go00000_o5MWL4o`000003olAaKol0003o_FY`00?o_FY`00?o0000oke[KonmJfl01?l00002okEP
J003o`000?neGVOo]EiW00;o]EiW00Go0000ok9MJOnbGFWo0000ojmJJ00Ao`0000?oXe5Z00Co0000
oie;J?nMBfSo00000onMBfP00ol0003oUTAVoiI4IP04o`0000?oTdQ^00Go0000oiA7KOnDAfgo0000
ohe2J`03o`000004oi5:M?l0003oRdEcoh]5L`Go00000_n8BGd3o`0000CoQdn70ol00003ohMHT`Co
000000CoR6:Oo`000?n4HZ?oQ6:S3?l00003oi>Cd@03o`000?nGUM3o000000CoX:3D00?o0000oin`
honO/><00ol000001?nU^NOo0000ojW1jonY`N/3o`0000;o[<O]00Co0000ok3<kol0003o00000onb
d?000ol0003o]M7_o`000002okOGl006o`000?nhfo;o^=_bokSKl_l0003o^Mcb0_l000000onlho;o
0000o`000002o`0000;o_N[c00?o0000okg[lol000000_l00002ol3_lP07okoclOl0003o0000o`00
0?nln>ko0000ok_jj`02okWjjP05okCki?n^n]_o0000ojGgd?nGkkl0AOoonfX00ol0003ooo]Zoook
JP1<oookJP03o`000?oonf[ooo]Z02Cooo]Z000UoookJP03o`000?oonf[ooo]Z02gooo]Z0ol00000
1Ol>Mn;o0000oaUmi_l0003o=8c^00So00000_mNXO@Do`0000CoU[O_0ol00004ojBkj@04o`000?ne
_Moo0000o`0000Go];cP00Co0000ol:oeoo2_mOo`[oG0ol000000oo8^lgo0000o`000003om6j``05
o`000?o?^/Go0000om>^/ol000000_oA[;@00ol0003oeZj_omJ^[`02o`0000;oeZ:Q00?o0000om:O
X_oBWj800ol000001?oFVI?o0000om>FU?oCUY@3o`000004om2<ROl0003oc8V:olb9RPCo000000Co
cHB0o`000?o9Oh7obGn11Ol00002olAgN@_o00000_niJ74=o`0000Go[EY[0_l00005ojQFJ`;o0000
0onSDFX<o`0000?oVTa]00?o0000oi=8K_nCB6h01_l00003oi5:M0Co00000on?CWd4o`000003ohiD
Qol0003oQdn700?oQdn70_l00004ohMHT`;o00001On8HYl2o`0000?oS76_00?o0000oh]f]_l00000
0onHR<47oi>Cd@03o`000?nPX=CoX:3D00CoX:3D0_l00005ojFii`;o00001_n/and00ol0003o/]3`
ok;@l002o`0000;o]M7_00?o]]Oao`000?l000000_nhfo82o`0000?o^Mcb00Go^^7co`000?l0003o
_NGbo`000003okgZl`03o`000?nmjo?o_N_c00;o000000Ko_O3co`000?l0003o_oCao`000?nln>h2
o`000003ok_jjonin^[o^O[Z00Go0000A_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[o
oo]Z02?ooo]Z000UoookJP03o`000?oonf[ooo]Z02kooo]Z0_l000000ol0H]7o0000o`000002o`00
00;o<Xc^0_l000000om7Uo;o0000odbIl`07o`0000?oKJSd00?o0000ogV]m?l000000_mj[_@00ol0
003oQ[;bohJblP03ohJblPCo00000onE]nl00ol0003oY;_YojBkj@04ojBkj@04o`000?nd_>3o];cP
okBlh0?o000000Co/[cQo`000?o2_mOo00001?o1_mP01_l0003oaKW?olFicol0003odK[3o`0000?o
ck[50ol000000ooA[;Co0000omJ^[`02omJ^[`?o00001?oBWj84o`0000?odiJD00Co0000olnCU?l0
003o00000_o<RHX2o`0000;ocHV91?l000000oo9Oh7o0000o`000002olMnP0Co00000oo0LWP2o`00
00?o_W5i1_l00005okIVLP;o00000_naH6lBo`0000;oYEM`00?o0000oimAKonODFl00_nODFl00ol0
003oWe5_o`000002oiY<K@Ko00000onFCgH00ol0003oTDYdoi5:M003o`000003oiECO_l0003oSdim
00;oSdim0ol00004ohiDQ`03o`000?n7ChOo000000;o000000?oSEbCo`000?n7F9<00ol000000on?
Ij3o0000ohQRW`03ohQRW`;o00001?n<LJl2o`0000GoV8S10onCTm42o`000004oijOeOl0003oX:3D
oj2Pe0?o000000CoXK7So`000?nU^NOoYKWW0ol00002ojW1j`03o`000?n/ango[<O]00?o00000on_
c>l01?l0003o]M7_okGAkonedNl2o`0000;o]]Oa0_l00004okWLlP;o00000onji?@00ol0003o_N[c
okgZl`03okg[l`07okg_lol0003o_O3co`000?nlm?7o0000ok_dl@04o`0000;o^O[Z1Ol00017oook
JP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX08ooonfX002Gooo]Z00?o0000oookJ_oo
nfX0<?oonfX4o`000003oaEliOl0003o000000Oo000000?oFJ3do`000?mLX_@03_l00004ohJblP03
o`000?nE]nooUKO_00?oUKO_0ol00005oj>kjP;o00001Onb_>401Ol0003o`KoHol6of?o1_mSo0000
00;o_[oJ00Co0000olFicol0003o00000oo?^/D01?l0003oc;?2olbc`_o</l83o`000004omJ^[ol0
003odjV^om>Y[P?o000000GodYnRo`000?o?WJ?o0000omBOW`04o`0000?oci>D1Ol00003olf9R@03
o`000?o8QH[ob8F:00?o00000_o7OX000ol0003oa7b1olAlP@07o`0000?o_W5i00?o0000okY^N?nj
KWP03?l000001OnaH6oo0000ojmOLOn_Gg7o000000;oZea`00?o0000ojYKLOnZFg400_nZFg401Ol0
003oYEM`ojEGL?l0003oYEM`00co00000onNEGL00ol0003oUTmfoiI?MP06o`0000?oUE=n00?o0000
ohm>OOl000000_l00002oi=IR004o`000?n>E8OoSUB7ohiDQ`?o00000on=G9<3o`0000CoSfNP00?o
0000ohQRWol000000_l000001?nCMZko0000ohaa[on<LJl2o`000003oiN3_?l0003oV8S100CoV8S1
0_nCTm400ol0003oWYoEo`000004o`0000GoXK7S0_l00006ojW1j`;o00000on_c>l2o`0000;o/M3`
00?o0000okGAkonfeo400_nfeo42o`0000;o]]cc1?l00003ok[Tm005o`000?nkjOCo0000o`000?nm
jo<00_l000000onmko?o_O3cokg`l`02okcdl@04o`000?nkm?7o0000okShk`?o000000Ko[O[So`00
0?nVn=Wo0000ohgY^_l00019oookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX08ooo
nfX002Gooo]Z00?o0000oookJ_oonfX0<OoonfX6o`000007oc2<k_l0003o0000o`000?m5Uo;o0000
odZIl`07o`0000?oK:Se00?o0000ogR^m?l000000_mi[_@00ol0003oQ[;bohJblP04ohJblP?o0000
0onF^O000ol0003oXk_Zoj>kjP03o`0000;oX[[[00?o0000ok:lhOl000000_l00002ok6kh@03o`00
0?o1_mSo000000Co_[oJ0_l000001?o2^=3o0000olnjaOl00003olbc`P03o`000?o9//?obK;300;o
00000ooCZJh00ol0003od:N_om2W[`03o`000003olnMXol0003o000000;odYfO0ol000001?o?TiCo
0000olb@UOo<T9D4o`000003olf9ROl0003ob8F:00;ob8F:1ol000001_o4O87o0000ol5hPOo1N87o
0000ol5iP@Co000000Ko_W5io`000?njKWSo0000okU]N?l00005okAXN@04o`000?ncIgSo/fMhok=W
N17o000000?oYeeho`000?nQF7L01OnQF7L01?l0003oWUEgoiiEMonNEGL6o`0000?oVUQo00?o0000
oiACOol000000_nEDgh3o`0000CoTeV800?o0000ohiDQol000000_l000001?nBH9?o0000oheLTon=
G9<2o`000003oi=ZX?l0003oSfNP00?oSfNP0ol00005oi=f[P;o00001?nGPk`00ol0003oV8S1oiR8
`@02o`000004oiR8`Ol0003o0000o`0000?oXj?F00?o0000oj6ahonQ/N<00ol00002ojJjj003o`00
0?nY`N_oZL7[00?o00000_n/anh01?l0003o[lc_o`000?l00002ok7@l004o`000?ndd_3o0000o`00
00;o]]Oa00Go0000okKLlonfg??o0000okSMl`02o`0000;o^^Cd0_l000000onkiOCo0000o`000002
o`000004ok[[m?l0003o0000okg`l`;o000000?o_?Caok_dlOnkm?400_nhn>l2o`0000?o[O[S00?o
Y_SIoi_bc?l00000BooonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z02?ooo]Z000T
oookJP03o`000?oonf[ooo]Z03?ooo]Z0_l000000ol0JmSo0000o`000002o`000003oc2<k_l0003o
=Y3_00Co000000CoEj3eo`000?mKX_GoFj;e3Ol00003ohFcl`03o`000?nF^O3oU[W`00;oU[W`1?l0
0006oj:jj`03o`000?na^n7o/K_Q00Co/K_Q00Go0000okjof_nn_m[o_[oJo`000003okbof`03o`00
0?o2^=3o000000?oc;?200?o0000olVb`oo9//<00_o9//<4o`0000Cod:N_00Co0000olbU/?l0003o
00000ooBWIl00ol0003ocYZPoljJX006o`0000;ocI2D1?l000000oo8QH[o0000o`000002olR5RP03
o`000?o4PX[oa8::00Co00000_o1NH401?l0003o_WN2okigP_nnMh8:o`000003okAXNOl0003o/fMh
00Co/fMh00?o0000ok1UN?l000000on]HWP01?l0003o[65hojaQN?l00004ojMMM`03o`000?nWGGSo
000000?oXEQg1ol00003oj1MP003o`000?nJF7ooVUQo00So000000CoVEf9o`000?nCFHSoTeV81Ol0
0005oi9PT`;o00000onCJZ000ol0003oSfNPohmWX002o`000003oiIe[?l0003oTgJ^00CoTgJ^0_l0
0005oiN3_0Go000000?oXIgAo`000?nSXmH01OnSXmH2o`0000KoY[[X0_l00006ojc7kP04o`000?na
d?3o0000o`0000;o]=;`0_ndeo82o`000003okKLlol0003o000000?o^=gc0_nhh_@2o`0000;o^nGd
0_nkj_@01ol0003o^^_dok[[m?l0003o^_3do`000?nil?@00_l00002ok_dl@04okShkol0003o0000
okCijP;o[O[S00CoY_SIo`000?l0003o0000C?oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oo
nf[ooo]Z02?ooo]Z000ToookJP03o`000?oonf[ooo]Z03Gooo]Z1?l000000ol>Nn?o0000o`000004
o`000003odRJlol0003o000000Wo00000_mg[_D6o`0000;oQK?c1?l00003oi:gl003o`000?nR^^_o
X[[[00?o000000CoX;[[o`000?na^n7o/K_Q0ol00002ojnkh`03o`000?nn_m[o000000Go_;oK0ol0
00000oo</l;o0000olVb``03olVb``04o`000?o6/LGo0000olna_0;o00000_o@Yjl01?l0003oc:F`
olbU/?o<YK04o`0000CocYZP00Co0000olZGXOo:Uj7o00001?o=T9@00ol0003ob8bDolR<U006o`00
00?oa8::00?o0000ol5oR_l000001_l000000onnMh;o0000o`000003ok]cP@04o`000?ngLH;o]g62
okMaPQ_o00000onUHGl2o`0000?oX5f01Ol00003oieQR@05o`000?nHGHSoV5f8o`000?nIGHT01?l0
0003oiQUU003o`000?nBH9?oTV2C00?oTV2C0_l00005oi=ZX0;o00001?nFMJ`01?l0003oTgJ^oi=f
[_nCMZh5o`0000?oVI?<00?o0000oiZCc?l000001?nQWM400ol0003oXj?Fo`000002o`0000;oY;?S
00?o0000ojJjj?nV^^P00ol00002ojW2j`03o`000?n/anko[<O^00?o00000_n^c?001?l0003o]=;`
okCBl?ndd_03o`000003okCHl_l0003o000000;o^=gc00?o0000okSRm?nhh_@00_l00002okSUm@?o
00000onjjo@2ok[`m006o`000?nil?Co0000o`000?ngm?;o]OO`2?l000000om^e9gooo]ZoookJP1<
oookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX08ooonfX002Cooo]Z00?o0000oook
J_oonfX0=_oonfX2o`000003o`1Jb?l0003o000000;o000000?o:H_]o`000?m1Uo801?l000001omF
X?Go0000o`000?l0003oIZSfo`000?mYZOH00_l00003ogJ^mP03o`000?mg[_Go000000CoPk?d0_l0
0003oi:gl0Co00001OnP^^/2o`0000Ko[k_S00Co0000okbofonl_m_o_;oK0_l00002ok^if004o`00
0?o6^loo0000o`0000?obK;300?o0000olJaaOo6/LD00_l00002olfc`003o`000?o@Yjoo000000?o
c:F`00?o0000olnV[_o?YZh00ol000000oo>VZ3o0000olZGX@02olZGX@?o000000?ocI2Do`000?o8
S9@00oo8S9@2o`0000;ob8bD0ol000001?o4PX[o0000ol5oR_l00002ol9oRP04o`000?nnOH[o_Wf:
okimRPGo000000?o^g>1o`000?ngLH800ongLH800ol0003o]6j2okA^PP03okA^PP;o00001On_JH00
0ol0003o[VR1o`000005ojUTP0;o00000onUHGl8o`0000;oXfF900?o0000oieQROnMHHT00onMHHT0
0ol0003oV5f8o`000002o`000003oieXU?l0003oV6FD00GoV6FD00?o0000oi9PTol000000_l00000
0onHKJ3o0000oi=ZX003oi=ZX0;o00000_nFMJ`8o`000003oif=`_nITlcoVI?<00GoVI?<00?o0000
oj6MdOnQWM400onQWM42o`0000KoY;?S0_l00006ojW2j`;o00000_n^c?02o`0000?o/=7a00Co]=;`
o`000?ndf?;o]=Sb0_l00002okCLm0;o00000_nhh_@00ol0003o^>GeokSUm@03o`000004okS[m_l0
003o0000o`0000;o^_3d0_nil?@00onhm?;o0000okOdlP02o`000003ok?gkol0003o000000;o0000
00?oWOCFo`000?l00000CooonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z02?ooo]Z
000ToookJP03o`000?oonf[ooo]Z03Sooo]Z3Ol000000omDXOGo0000oeRRmP08o`000003ogJ^m_l0
003o000000Co000000?oPk?do`000?l000000_l00003oi6gl@03o`000?nP^^_o000000;o00000_nO
^^`00ol0003o[k_Sojnkh`03o`0000;o[K_T00?o0000okbofol000001?nk^MP2o`0000;oa;_B00?o
0000olVb`ol000000_o6/LD00ol0003oaKC9o`000002olfc`0Co000000Koc:F`o`000?o:Y;;o0000
olnV[_l00002olfR[@Co000000CobYNQo`000?o<Uikoc9NN1?l000001?o8S9Co0000olJ;UOl00002
olR<U003o`000?o4R9Coa8RD00Oo00001?nnOHX2o`0000;o_7Z:8?l00003ojMYRP03o`000?nRIHWo
000000CoXfF900?o0000oieQROnMHHT01Ol000000onLIi?o0000oieXU002oieXU003o`000?nHIICo
V6FD00Go00001?nHKJ000ol0003oTfZPo`000006o`0000;oV7fd0ol00005oif=`P?oVI?<0_l00000
0onQWM7o0000o`000002o`0000?oXZgO00?o0000ojBchonT/n<00ol00002ojRlj003o`000?nY`^_o
ZL;[00?o00000_n/b>h2o`0000?o/=7a1?l00002okCHlP05o`000?ndg?Co]=cdo`000?nfgO@00ol0
00001_nhiOGo0000o`000?nhi_Go0000okS[mP;o000000Go^>cfokO_mOl0003o0000okW`m002okSd
lP;o]oCb00Oo0000ok?gkon_nN[o[_WYo`000?nVn>7oWOCF00?o0000D?oonfX00ol0003ooo]Zoook
JP1<oookJP03o`000?oonf[ooo]Z02?ooo]Z000ToookJP03o`000?oonf[ooo]Z03Wooo]Z1_l00000
0olUR^co0000o`000002ocnGlPKo00000_mUZ?L00ol0003oIjWfo`000003ogB^mP03o`000?mf[oKo
000000CoPk?d00?o0000oi6il_nA^O801Ol00006oinjk0;o00001_n]^n@00ol0003o^kWHok^if002
ok^if004o`000?nh^=Wo^;SIo`0000;oa;_B0_l000000oo6/LGo0000olFdb@02olFdb@;o00001?o:
]<@5o`0000CocJ:]00?o0000olVP[_o9X:h00_l00003olbGWP03o`000?o8U:3ob9BP00Ko00001?o4
R9@00ol0003o`HJEo`000002ol:7U0Oo00000onlNXX01ol0003o^GR;okUhRoniN8_o0000okMfR_l0
00001OneM8X00ol0003o/G6:ok5aRP04ok5aRP;o00001_n/KHX00ol0003oYfV:ojMYRP04ojMYRP03
o`000?nRIHWo000000;oXfF91Ol00003oj1[U004o`000?nLIi?o0000oieXU0Ko00000onLLJ400ol0
003oV6fPoiQ]X002oiQ]X0Ko000000?oVgnco`000?nHOK@00ol000000onNRkoo0000oif=`P05oif=
`P;oVI?<1?l000000onTY=Go0000oj:]g`05oj:]g`;o00001_nX_>P2o`0000;o[<S^0_l00002ojk=
l007o`000?n`dO7o0000o`000?nad_7o0000ok;DlP02o`0000;o]=cd00?o0000okKMm?nfgO@00_l0
00000onfhoKo0000o`000002okSVm@;o^>_f00?o0000okS/m_nhk?H00ol000000onflOGo0000o`00
0006o`000003ojKhhOl0003o000000;o0000D_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oo
nf[ooo]Z02;ooo]Z000ToookJP03o`000?oonf[ooo]Z03_ooo]Z00?o03NSo`000?l0LMX01Ol00000
1?lmUo;o0000o`000?l00002oe:QmQ3o000000GoPk?do`000?n@^O;oT;Wbo`000002ohnglPGo0000
0onM^^d00ol0003o[K_Tojfki003o`0000;oZk_U00?o0000ok^if?nk^MP01Onh^=T01?l0003o`K_D
ol6ke?o1^m@2o`0000?oaKC900?o0000olZda?o:]<@00_o:]<@01?l0003oaZc0olJ/`?o6[<02o`00
00?ocJ:]00Ko0000olVP[_o9X:kobJ2^o`000?o6Wk03o`0000Cob9BP00Co0000olFBXOl0003oaiBP
1?l000001?o4R9Co0000ol66UOl00002ol:7U003o`000?noQ9Co_hBD00;o_hBD3?l00005okEdRP03
o`000?naLH[o/G6:00Co/G6:0_l00003oja]RPoo00000_nVKi@00ol0003oX6^Doj1[U003oj1[U0Co
00000onPLil00ol0003oW76QoiaaX@03oiaaX@03o`000?nHKJ3o000000Go00001?nKOk<2o`0000Go
WX^o00Co0000oif=`_nMSL;oWHg20_l000000onMSL;o0000o`000005ojBTe@03o`000?nR[Moo0000
00;o00000_nV]nD00ol0003oZ;cXojRlj003o`000003oj[4k?l0003o[<S^00;o00001On^cO000ol0
003o/M;aok7Bl@03o`0000?o/][d00Go0000okKMm?l0003o0000okKSmP02o`0000?o]^Gf0_l00003
okS/mP05okK`mOl0003o]_7eokKamOl000000_ncm?<00ol0003o[_O_o`000002ojSgj@Co000000?o
MMb^oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z02;ooo]Z000T
oookJP03o`000?oonf[ooo]Z03gooo]Z2?l000000olmUo;o0000o`000002oe2QmPCo000000?oHjSg
o`000?l000000omc[oL00ol0003oM:ofo`000005oh:dm@04o`000?n@^O;o0000o`0000;oS[Ob00Go
0000oifjkOnM^^goWK[]o`000002oifjk@;o00001_n[^nD01?l0003o^;SIokRhfOnh^=T2o`0000;o
]KSL00?o0000ol6ke?l000000_nn_=L2o`000003olFdbOl0003ob[C400;ob[C400Ko0000olJ/`?o6
[<3oaZc0o`000?o3[<83o`000005olfR[Ol0003obJ2^olVP[_l000000_o6Wk000ol0003obZ2]o`00
0002o`000007olRDX?l0003oaI:QolFBXOl0003oaiBPo`000003olB@W`Wo000000Co_hBDo`000?nm
PiGo00000onmPYD01_l0003o^GnDokUoU?niOiCo0000okQnU1;o00000on^MYD00ol0003oZG>EojUc
U@04ojUcU@03o`000?nUKYCo000000CoYVnD00?o0000oj1[U?nPJi@01?l00006oj1cW`03o`000?nL
LJ7oW76Q00So000000CoWh:do`000?nKOk?oVgnc0ol000000onPS;ko0000oij;_`05oij;_`Go0000
00?oY:7Bo`000?nTY=D01OnTY=D2o`0000KoY[OU0_l00005oj[4k004o`000?n^cO3o[/g`ojk=l0?o
00000_nad?02o`0000;o/][d0ol00002ok?Mm@;o000000?o]^?fo`000?nfiOH00_nfiOH2o`0000?o
]N_g0_l00003okKam@05ok?dlol0003o0000o`000?n^mnl00onXmnT01?nOm^3o0000o`000?meg:iE
oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX08_oonfX002Cooo]Z00?o0000oook
J_oonfX0?_oonfX4o`000003oaF3i_l0003o7XSZ00Oo000000CoE:;fo`000?mQZ?OoHJSg2_l00003
oh2dmP05o`000?n>^??oS[Sco`000?n>]o801?l00004oi^jkP03o`000?n[^nGoZk_U00?o000000?o
Z;_Wo`000?nh^=T00_l00005okFhg003o`000?nn_=Oo_[cG00?o_[cG0ol000000oo:]<Co0000olJ/
`002olJ/`005o`000?o3[<;o`jc2o`000?o9[;`01?l000000oo9X:ko0000olJO/002olJO/0;o0000
0_o7WJ`4o`000003olFBXOl0003oa92O00Coa92O00Go0000ol6>XOl0003o`XnPo`000003okn<W`Oo
00001?niOi@00ol0003o^7jDo`000005okIlU003o`000?nbNYGo/WZE00Co/WZE0_l00005ojifU@;o
00001_nYLiD2o`0000;oYVnD1_l00002ojAfX0;o00001OnPLil4o`0000;oWgf]0ol00004oin2]0?o
00001OnPS;h00ol0003oWX^oo`000002o`000004oj6Gb_l0003o0000o`0000CoY:7B00?o0000ojBT
eOl000000_l00002ojFbh@03o`000?nV]nGoY[OU00?o000000CoZKoZo`000?nZa>coZ/C/0ol00003
ojc:k`;o00001?nad?000ol0003o/=Kco`000002o`0000;o/mge1Ol000001OnfiOKo0000o`000?ne
i_Oo000000?o]N_g0_l00003ok?`mP0:okKamOl0003o/_Cbo`000?n^mnoo0000ojSgjOl0003oXOKQ
oiofh0;o0000EooonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z02;ooo]Z000Soook
JP03o`000?oonf[ooo]Z047ooo]Z00?o06;;o`000?l0Jm<01Ol000000oldUO7o0000odjQmP0;o`00
00;oLJog1?l00002oh2dmPGo000000?oS;Oco`000?nK^^h01OnK^^h2o`0000GoZ;_W00?o0000okFh
g?ne^=`00_ne^=`2o`0000;o/[WN00Co0000okjleol0003o00001?nk_=X3o`000003olJ/`?l0003o
`jc200?o`jc200?o0000olN_`Oo7[l400_o7[l43o`0000;oaYn`00?o0000olNM[?o7WJ`00_o7WJ`0
0ol0003o`i^^ol>K[P04o`0000;oa92O00Go0000ol6>XOo1SZ7o`HjQo`000005okn<W`03o`000?nm
Rj7o000000;o_H^P2_l00002okIlU0;o00001OnbNYD00ol0003o/GVEo`000002ojifU@oo00000onX
N9h01Ol0003oY7JPojAfX?nTMZ3o000000;oYGRR00?o0000oj1cWol000000_l000001?nTPZoo0000
oimm[OnOOJd2o`000004oj>6]Ol0003oWh:doin2]0?o000000?oXXjoo`000?nPS;h01OnPS;h2o`00
00CoXIO:00?o0000ojBQd_nTXM801?nTXM82o`0000KoYK;Q0_l00005ojVojP;o00000on/b^l2o`00
0003ojk?lOl0003o/M3`00?o000000?o/=Kco`000?l000000_nafoH2o`0000;o]=ke1?l00002ok?U
m`03o`000?nejoOo]N_g00?o00000oncl?H2o`000003ojkdlol0003o000000Go000000?oWoKPo`00
0?oonfX0F?oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z02;ooo]Z000SoookJP03
o`000?oonf[ooo]Z04?ooo]Z3ol00002oenXn003of:Yn?l0003oKjog00?oKjog00?o0000ogndm_mo
]?H00omo]?H01?l0003oS;Scohbhlon<^?<5o`0000GoV[[_0ol00003ojJkj004o`000?ne^=co0000
o`0000Go/[WN00Co0000ok^lf_nk_=[o^kcJ0_l00002okVfeP04o`000?o2]loo0000o`0000?o`jc2
0_l00003olN_`@04o`000?o3Ykgo`jNmol>W_@Go000000?oaif/o`000?o3Vjh00oo3Vjh00ol0003o
aIVYolFIZ@0:o`000005okn<Wol0003o_H^Qokf;XOl000000_nmRj000ol0003o^XNOokZ7W`03okZ7
W`04o`000?ngQ9go]hBMokN4W@ko00000on`P:42o`0000Ko[7fQ00?o0000ojQhW_nXN9h01?nXN9h0
0ol0003oY7JPo`000006o`0000GoY8:_0_l00003oj>6]@?o00001OnRS[l00ol0003oX8bno`000002
o`000003oj>HbOl0003oXIO:00?o000000CoY9o@o`000?nTXM;oY:7B0ol00002ojF^gP03o`000?nU
/^7oYK;Q00?o000000CoZ;cWo`000?nY_n[oZKoZ0ol00002oj_6kP04o`000?n/b^oo0000o`0000Co
[/oa0_l00002ok3Fl`04o`000?nafoKo/M_fo`0000?o/Mgf00Co]=keok?Tmonci?Oo00000onciOL0
0ol0003o/^[ho`000002o`0000;o/o3f0ol00003ojkdl`?o000000CoXOGWo`000?l0003o0000Fooo
nfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z02;ooo]Z000SoookJP03o`000?oonf[o
oo]Z04Cooo]Z0ol000001OlHQnSo0000o`000?l0003o<IC`00Ko00000_mMZ?P6o`000003ofn_mol0
003o000000?o000000?oOkCfo`000?l000000on:^?@01?n:]oCo0000oiZjkonJ^^l3o`0000;oV;_`
00?o0000ojJkj?nV^nP00onV^nP01?l0003o/[WNok:ig_nb^Mh3o`000003ojnihOl0003o^kcJ00;o
00001?ni]]H2o`0000;o_kSC00?o0000ol>/`_l000000_o1[lP00ol0003oajo1o`000004ol>W_@03
o`000?o1Z<7o000000;oaJRl0ol00003ol>K[P05o`000?o5VJWoaIVYolFIZOl000001?o0Ujd01?l0
003o`IBYol6DZOo1U:T4o`000003okf;XOl0003o_H^P00Go^XNO0_l00005okN4W@;o00001OndQ:40
0ol0003o/h:Po`000004ok20X@03o`000?n_Oj7o000000Go[7fQ0_l00003ojQhWPGo00001OnWPjd0
0ol0003oY8:_ojB2[`03ojB2[`;o000000KoXhJeo`000?l0003o0000ojFA`?l00006oj:>_`;o0000
1OnSV<T00ol0003oY9o@ojBOd003ojBOd0;o00001_nU[]h2o`0000GoZ;cW0_l00006oj_6kP04o`00
0?n^co7o[/oaojk?l@;o000000Go/=7bok3Fm?l0003o0000ok7KmP02o`0000?o/Mgf00Co0000ok7R
mol0003o00000_nciOL2o`000003ok;Zn?l0003o000000;o/Nch1?l00002ojkdl`06o`000?nZm^oo
0000o`000?nQmNOoVO?N1?l0001LoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0
8_oonfX002?ooo]Z00?o0000oookJ_oonfX0AooonfX9o`000003odJOm_l0003o000000So00000_m^
[oP2o`000003oh2fmol0003o000000?o00000_n:^?@3o`0000KoV;_`0ol00004oj>kjP;o00001On_
^N400ol0003o^KKFokVfeP02okVfeP;o00000_ne]]T00ol0003o_kSCoknhd`03o`0000;o`Jo800?o
0000ol>W_Oo3Ykd00_o3Ykd01?l0003o`JS1ol6X`Oo1Z<42o`0000?o`jc21Ol000000oo5VJWo0000
ol2G[@03ol2G[@;o00001?o1U:T00ol0003o_IB]okfD[@0<o`0000;o]hBM00Co0000okJ5XOnfQJ7o
00000ondQ:401?l0003o/h:Pok>2X?l00004ok20X@go00000onZQjl00ol0003oYh>]ojN3[@05ojN3
[@03o`000?nTPZoo000000Go00001OnUTL000ol0003oXXjoo`000002o`000004ojFIbOl0003oXiS9
oj>Hb@?o000000CoYIo@o`000?l0003o00001?nV[=/00ol0003oYJkNojF^gP03o`000004ojRhiOl0
003oZ;cWojRli`?o00000_nZ`n`00ol0003oZlK^oj_6kP03o`0000;o[<c`0_l00003ok3AlP;o0000
00?o[mSeo`000?l000000_nagOH2o`000003ok7Omol0003o000000;o/>Gh0_l00002ok;Zn003o`00
0?nak?So/Nch00?o000000?o[_3foj_cm?n[lo@02?l00002oeo>Xekooo]Z00?o0000oookJ_oonfX0
C?oonfX00ol0003ooo]ZoookJP0RoookJP008ooonfX00ol0003ooo]ZoookJP18oookJPgo00001?mQ
[?T00ol0003oL;;iog2bn@02og2bn@03o`000?mi]OSo000000;oN[Cg00?o0000ohRhmOn8^?D00on8
^?D4o`0000?oUKgc00?o0000oj>kj_nS^nX00ol00002oj6kk003o`000?n_^N7o000000;o00000_n/
^^@01?l0003o^KKFokVfe_l00005okFff@03o`000?nl^]So_;[H00;o_;[H1Ol000000oo3Ykgo0000
ol6X`@02ol6X`@;o00001?o3[<801?l0003o_jBnoknT__noY;h4o`0000;o`9N]00Co0000okjH/?nn
V;3o00000_o1U:T00ol0003o_IB]okfD[@02okfD[@03o`000?nkT:[o^i2Z00?o^i2Z00?o0000okVB
[_l000000_nhTJhBo`000003ok69[?l0003o[XR]00;o[XR]00Co0000ojj9[_n^RJko00001OnZQjl2
o`0000GoYh>]1?l00004ojR@_@03o`000?nUTL3oYI7000CoYI700_l00005ojFIb@;o000000GoYIo@
o`000?l0003oYj[Io`000007ojJ/f`;o00001OnX^>D2o`0000KoZ/?/0_l00002ojc<l0;o00000on]
dO<00ol0003o/=7bojoHm@03o`0000?o[mcg00Co0000ok7OmonagoOo00000_n`iOP00ol0003o/NKh
ok3Yn002o`000006ok7/n?l0003o0000ojo_mol0003o[_3f0_n[lo@3o`000007oj?dk_l0003o0000
o`000?n?km_o0000oeo>X`1PoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX08_oo
nfX002?ooo]Z00?o0000oookJ_oonfX0B_oonfX4o`0000;o98o]1ol000000omGZ?So0000o`00000=
o`0000?oQ[Sf00?o0000oiFmlonE_O<00_nE_O<4o`0000KoXK_/00?o0000ojbji?n/^^@01?n/^^@0
0ol0003o]KKIokFff@02okFff@;o000000Co/[OMo`000?nl^]So_;[H0_l00003okVbd`03o`000?o0
/lko000000;o000000Co`JS1o`000?nnZlOo00000oo3[<800ol0003o_jBnoknT_P02oknT_P04o`00
0?o0Yl3o`:O0ol2W`0Ko000000?o`IBYo`000?nmU:d00onmU:d2o`0000Co^i2Z00Co0000okVB[_ni
TZko00000onhTJh4okN?[@03o`000?neSJgo000000Co]8b/00?o0000ok6:[?l000001?naRJ`01?l0
003o[XR]ojj8[Ol00004ojj9[P05o`000?nZQjooZXN_ojZ7[ol000000_n[RK400ol0003oYh>]o`00
0002o`0000;oZI6m00?o0000ojR@_OnXT;d00onXT;d01?l0003oYI70ojFA`?nUTL02o`000004ojNL
bol0003oYIW9ojFIb@?o00000_nWXM000ol0003oYj[IojNZf@03ojNZf@03o`000?nV[=_oYZcK00?o
000000CoZ;KSo`000?nX^>GoZ;SU0ol00002oj[1jP03o`000?nZ`ncoZ/?/00?o00000_n[bNl2o`00
00?o[M7c0_l000001?n^e_Go0000o`000?l00002ojoLm`?o000000?o/=kgo`000?l000000_n`iOP0
0ol0003o/NKhok7Vn003o`000003ojk/n?l0003o000000?o00000_n[lo@01?l0003oXoC^o`000?nL
m>L2o`0000;oSnoK00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oo
nf[ooo]Z027ooo]Z000SoookJP03o`000?oonf[ooo]Z04cooo]Z0_l000000ol0N]co0000o`000002
o`000003oc^Lm?l0003o000000_o00000_mg]?T6o`0000;oQ[Sf1?l00003oi6jl`03o`000?nQ^nco
XK_/00?o00000_nN_>h00ol0003o[;[To`000002o`0000;oZ;_V00Co0000okFffOl0003o00001?nb
]md2o`0000Go^K;C0_l00003okfedP?o000000Co_Z_7o`000?o3[<;o00001?noY;h00onnZLCo0000
ol2W`002ol2W`003o`000?nmXKco_J6l00;o_J6l2_l00003ok^@ZP06o`000?niTZko^I:^okVB[_l0
003o^96^1OngSjd2o`0000Ko]8b/00?o0000ok69[?naRJ`01?naRJ`2o`0000;o[XV^3?l00002ojVA
_@;o000000?oZYc7o`000?nXT;d01OnXT;d3o`0000CoYic;0_l00002ojNQd0;o000000?oZ:[Ho`00
0?nWZ]T01OnWZ]T2o`0000GoZ;KS0_l00006oj[1jP;o00000_n[bNl2o`0000;o[<ob00Go0000ojgA
lol0003o0000ojkFm@02o`0000?o[M_g0_l00003ok3Nm`03o`000?n^hoWo[^?i00;o00000_nai_P2
ojk[n0?o[^ch0ol000000onWl_Co0000o`000005o`000003oho_fol0003o000006Cooo]Z00?o0000
oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0QoookJP008ooonfX00ol0003ooo]ZoookJP1=oook
JPOo000000?o>9_co`000?l000000_l000001om@Y_So0000o`000?l0003oHjkjo`000?mV[oT00_l0
0003ogBdn@03o`000?mf]?Wo000000GoPkSg00?o0000oi:mm?l000001Ol00006oijlkP03o`000?nX
^nKoZ;_V00CoZ;_V00?o0000ok:ggOnb]md01?nb]md00ol0003o^K;CokVbd`02okVbd`;o00000_nf
/mH00ol0003o_KGBo`000003okZhe`Go00000_noY;h3okjYa003o`000?o0Yl3o000000Go_J6l00?o
_:K4o`000?nmY<000_nmY<001?l0003o^YnmokZO_OnjWkd=o`0000;o]hn]00?o0000okB<[?ndS:`0
1OndS:`;o`0000Co[YNo00?o0000ojfB^on]T[/00on]T[/01?l0003oZI6mo`000?l00003ojZLa`03
o`000?nXT;goZ92m00?oZ92m0_l00003ojNLb`;o00000_nXXm42o`0000GoZ:[H00?o0000ojNZfOl0
00000_l00002ojVdh@03o`000?nX]^?o000000;o00000_nY_^T00ol0003oZ/7Zoj[1jP03o`0000;o
ZlO^0_l00006ojc?lP;o000000?o[]Keo`000?n]foL00_n]foL00ol0003o[MghojgMn003o`000003
ojkSnOl0003o000000;o00000_n/jOT2o`0000?o[^ch00?o0000oj[`mol000001_l000001?nClNGo
0000o`000?l0001VoookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX08OoonfX002?o
oo]Z00?o0000oookJ_oonfX0CooonfX;o`0000;oCJKh2Ol000000omd]?Wo0000o`000005o`000005
oh>hmol0003oSkceohnlmOl000000_n>^_@4o`0000?oVkc_00?o0000ojRki_nX^nH00ol00002ojFk
j@03o`000?nb]mgo000000;o00000_n^^>401?l0003o^K;CokVbdol00005okJceP03o`000?nj^=Oo
^[SG00;o00000ong/M<00ol0003o_;7?o`000002o`0000;o_ZW40_l00005okfQ_0;o_:K400Co0000
okfT`?nmY<3o00001?njWkd00ol0003o^Yjko`000004okRJ^@;o00001?ngW/0;o`0000Co/IRn00?o
0000ok6H__l000001On^Ukl00ol0003o[Z79o`000005ojfB^`;o00001_nZW<L00ol0003oZ92mo`00
0002o`0000;oZZ7=0_l00002ojRSd@;o000000?oZZ_Ho`000?nXZ]P01OnXZ]P2o`0000KoZKCQ00?o
0000ojVnjOnY_^T01?nY_^T2o`0000;oZlO^0_l00002oj_=lP03o`000?n/co;o[<ob00Ko00000_n]
foL2o`0000;o[Mgh00?o0000ojgOnOl000001Ol00002ojcYn@;o00000_n[joT7o`000005oiockonM
l^koTo7Uo`000?n9k=X00ol0001WoookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX0
8OoonfX002;ooo]Z00?o0000oookJ_oonfX0D_oonfX6o`0000;o=Y_b00Co0000ocbNm?l0003oBjGg
1?l000000omQ[_[o0000o`000003o`0000;oL[Ci1?l00002oh6hn0;o000000KoSkceo`000?l0003o
0000oh^jmOl00005oi^lk`;o00001_nU^nT00ol0003o[[SQojjhh@04ojjhh@03o`000?nf/mKo][?F
00;o][?F0_l000001?nb]]_o0000okZheol00005okNad`;o00000oni]=D4o`0000Co_J6l1?nlY/@2
o`0000Go^Ynm0_l00004okRJ^@03o`000?nhX/;o000000?o]ik00_l00002okFL_P03o`000?ndVkko
]9^n00;o00000_ncV[d00ol0003o/IRnok6H_P02o`0000?o/IRn00?o0000ojjG_on^Ukl00_l00002
ojjQb@04o`000?n]T[_o[I:kojfB^`;o000000?o[J?=o`000?nZW<L00_nZW<L00ol0003oZYc7ojZL
a`02o`0000;oZZ7=0onYY]<01?l0003oZ:?Ao`000?l00004ojZ[f003o`000?nXZ]So000000;o0000
0_nY]>400ol0003oZKCQojVdh@03o`000004ojZmj?l0003oZKkYojVnj@?o00000onZa^h00ol0003o
Zlgboj_=lP04oj_=lP;o000000Co[=;do`000?l0003o00000on/fOL00ol0003o[Mgho`000005o`00
00;oZnCj0_l00002ojcYn@03o`000?n[joWoZn_i00;o00000_nVkoL00onQlOCo0000o`000007o`00
06[ooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0QoookJP008_oonfX00ol0003o
oo]ZoookJP1DoookJP;o00000_l7Pn4;o`0000;oGZkj00?oHJkjo`000?m_/oX01?m_/oX00ol0003o
PK[ioh6jn@02oh6jn@03o`000?n<^oKoS;_f00;oS;_f1Ol00004oiRll@?o00000onR_>`00ol0003o
[[SQojjhh@03o`0000;oZk[T00Co0000okJce_l0003o00001?nb]]/00ol0003o]k7CokNad`02okNa
d`;o000000Go/k?Ho`000?ni]=Go^KCEo`000004okN_d@Ko00000_nlY/@00ol0003o^YnmokZO_@03
okZO_@03o`000?nhY<Co000000?o^9Zi00Oo0000okRR`_nhX/;o^:;2o`000?ngW/3o000000Go]Ibn
0_l00005ok>J_@;o00001OnaV;h00ol0003o[YNoo`000005ojjQb@03o`000?n]T[_o000000Co[J?=
1Ol000000on/Y]7o0000ojVVd`06ojVVd`03o`000?nZZmSoZZ_H00CoZZ_H0_l00006ojVdh@;o0000
1OnZ_NP2o`0000;oZ/K^0ol000001?nZc?7o0000oj_=l_n[cO83o`0000;o[=7c0_l00002ojcIm`?o
00000_n[g?P3o`000004ojcRnOl0003oZnCjoj_TnP;o000000GoZNWjo`000?l0003oZn_io`000002
ojO^n003ojK_mol0003o000000So000000?oKmk4o`000?oonfX0J_oonfX00ol0003ooo]ZoookJP1=
oookJP03o`000?oonf[ooo]Z027ooo]Z000RoookJP03o`000?oonf[ooo]Z05Kooo]Z1Ol000000olR
Tnco0000o`000002o`0000;oB:Gg00?oCJOho`000?mK[OX01ol000000om_/o[o0000o`000005o`00
00CoRK_f00CoR;[fo`000?l0003o00001?nC_oD00ol0003oX[c/oj:lk003oj:lk0;o00001_n[^^@0
1?l0003o/[KKok:ffonb]]/2o`0000;o[[SP00Co0000okNadong/M?o00001?nc/mP2o`0000Go]joA
0_l00004okRbe0[o000000?o^:C4o`000?nhV[T01OnhX/82o`0000Go]Ibn0_l00005ok>J_@;o0000
1_naV;h2o`0000Ko[Z7900Co0000ojfScOn]Xlgo[J?=1?n/Ym800ol0003o[:KAojbVd@03ojbVd@03
o`000?nYY]?oZJKC00?o000000CoZjkIo`000?nZZmSoZZ_H0ol00002ojZeh@03o`000?nY]>7oZKCQ
00?o000000CoZ[gWo`000?nZ_NSoZ[gX0ol00003oj[5k@;o00001OnZc?42o`0000;o[=7c0_l00002
oj[Gm`?o00000_n[g?P3o`000005oj[Qn_l0003o0000oj_Tn_l000000_n[i_X5o`000003ojC]n?l0
003o000000?o00000_nOlO<01?nGlNgo0000ohk^i?n=k^<3o`0006gooo]Z00?o0000oookJ_oonfX0
COoonfX00ol0003ooo]ZoookJP0QoookJP008_oonfX00ol0003ooo]ZoookJP1HoookJQ3o000000Co
Fjgjo`000?l0003o00000_m[]?/9o`0000;oRK_f0ol00003oi>om@Go00001?nN_Nh3o`0000GoYk_X
00?o0000ojjhh?n^^>001?n^^>000ol0003o/k?Hok>cf004ok>cf003o`000?ng[m7o]joA00;o]joA
0_l000000onc/MKo0000okRbe003o`0000?o]Zg@00?o0000okR]col000001?nfZL`:o`0000Co]Ibn
00?o0000okBSaol000001?ncV[d00ol0003o/Z;7o`000002ok6H_P_o000000?o[jSAo`000?n/Ym80
0on/Ym82o`000003ojf/e_l0003o[:KA00Co[:KA0ol00005oj^^f@;o00001_nZ]N42o`0000GoZ[gW
0_l00002oj[5k@?o000000CoZL_ao`000?nZc?7oZ/ca0ol00003oj[@m003o`000?nZeoOoZ]Og00?o
00000_nYfoT2o`0000;oZmki1?l00003ojSUn`05oj_Vn_l0003oYn[jo`000?nWjoX01Ol00003oi__
l`Ko0000L?oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z027ooo]Z000RoookJP03
o`000?oonf[ooo]Z05_ooo]Z0_l0LLh2o`000004oa^Aj_l0003o0000ocNPl`Co000000?oG;3ko`00
0?l000000_l00003ofbfn`04o`000?mg^O_oMkWko`0000;oN;Sj1?l00002ohJkn0Co00000on?_?D0
0ol0003oW[g^o`000002o`0000;oVkk`00?o0000ojNkj?nW^nP00ol000001?nS_N_o0000ojjhh?n^
^>03o`0000;oZ[[U00?o0000ok>cf?l000000_l00002ok2fg@04o`000?ng[m7o]joAo`0000Co/k7F
00?o0000okJ]d?nf[M001?nf[M02o`0000Go]ZW<00?o/jgBo`000?nd[M400_nd[M401?l0003o]:_?
okB[condZllBo`0000Co/:O?00Co0000ojjVd?l0003o00001?n_Z=401?l0003o[:OBo`000?l00004
ojf/eP03o`000?n/Y]7o000000;o00000_n//M`00ol0003oZjkIo`000002o`0000;oZkOR00?o0000
ojZehOnZ]N400ol000001?nZ_NSo0000ojZmionZ_NL3o`0000?oZLC]0_l00005ojW;l@;o00000_nZ
d?@3o`000004ojWFmol0003o0000o`0000;oZM_i0_l00003ojWMnP04oj_NnOl0003oZ>?jo`0000?o
Z>Gk00Co0000ojCYnol0003o00000_nWjoX01?l0003oX^kho`000?l00003oi__l`Co000000?oMnCC
o`000?oonfX0LOoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z023ooo]Z000Roook
JP03o`000?oonf[ooo]Z05gooo]Z1?l000000olNU>_o0000o`000004o`000003odf[nOl0003o0000
00_o000000?oMKSko`000?n3_?T01?n3_?T7o`0000KoVkk`0_l00005oj>mj`;o00001_nZ^^D00ol0
003o/;KMok2fg@04ok2fg@04o`000?nc/MKo/k7Fok>aeP;o00000_n`]Md00ol0003o]Zg@okJ]d003
o`0000;o/[7G00?o0000okJYc?nfZL`01?nc[M800ol0003o]:gAo`000004okB[c`?o00001OncZ<h2
o`0000Go/ZO>0_l00005ok2Wc`;o00001_n_Z=42o`0000Ko[JcF0_l00006ojbag003o`000?n[]n;o
ZkOR00CoZkOR0_l00005ojZmj0;o00000_nYa>d3o`000004ojW:lOl0003oZL_aojW;l@?o00000onY
co@2o`000004ojWDm_l0003o0000o`0000?oZ=[i00Co0000ojWMn_nYgO[oZMgj0_l000001?nVh__o
0000o`000?nXiO/2o`000007ojKVnol0003o0000o`000?nTj_[o0000oik/n004o`000003oi__lol0
003o000000Go0000MOoonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z023ooo]Z000R
oookJP03o`000?oonf[ooo]Z05oooo]Z2_l00002odZZn0?o000000?oH[?ko`000?l000000ol00002
ogBhn`Go00000on0_?X00ol0003oSKkgohfnm`02ohfnm`Co00001?nE`OD00ol0003oXkg[o`000002
o`0000;oWkk^00?o0000ojZjiOnZ^^D00ol000001?nV_>Wo0000ok2fgOn`]]d3o`0000;o[;WS00?o
0000ok>ae_l000001On`]Md2o`0000Ko/[7G00?o0000ok>]d_nc[M801?nc[M800ol0003o]:_?okB[
c`02okB[c`03o`000?na/=Oo000000Co/jS>0_l000001?na[mKo0000ok:Wc_nbYlh3o`0000;o/:kF
00?o0000ok2Wcon`Yll00_l00002ojn_f003o`000?n_Z=7o[jSA00?o000000Co[K7Ko`000?n][=Ko
[JcF0ol00002ojbeg`03o`000?n//Mco[;7L00?o000000CoZkWTo`000?n[]n;oZkOR0ol00002ojZo
j@03o`000?nZ_NSo000000;o00000onYa>d2o`0000GoZL[a0_l00002ojW?m0Oo00000_nXf_T3o`00
00;oYmcj0_l00002ojKRn`;o000000?oYNCko`000?l000001Ol000000onQjo[o0000o`000002o`00
0003oiG^lol0003o000000Ko0000MooonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z
023ooo]Z000RoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o05^co`000?l000000_l00002oc6NlP03
ocVRm?l0003oAjWh00Go000000?oGk;ko`000?l000000ol00002og6hn`Co00000_n0_?X2o`0000Co
RKgh00CoUL7eo`000?nE`OGoUL7e1?l00006oinnkP;o00001OnV_>T2o`0000Ko[;WS00Co0000ok2e
gOn`]Mgo/;GM0_l00002ojbih`03o`000?nb/MOo/[7G00?o000000Co[kKNo`000?nc[M;o/jgB0ol0
0002ok2cfP03o`000?ndZloo]:_?00Co/K3G00Co0000ok>Xc_ncZ<ko00001?na[mH2o`0000Ko/:kF
00?o0000ojn_f?n_[mP01?n_[mP2o`0000Go[K7K0_l00006ojbeg`;o00001On[^N@2o`0000KoZ[oY
00Co0000ojW4kOnYa>goZLC]0_l00002ojS:lP03o`000?nYb_7o000000;o00000onXco@2o`000004
ojSDmol0003o0000o`0000?oY]Wj0_l00002ojOLnP?o000000CoY>7lo`000?l0003oYNCk1Ol00000
0onPjO_o0000o`000006o`000003oiC^l_l0003o000000;oO^OO0ol0001ioookJP03o`000?oonf[o
oo]Z04gooo]Z00?o0000oookJ_oonfX08?oonfX0027ooo]Z00?o0000oookJ_oonfX0IOoonfX=o`00
00?oG;7k00?oGk;ko`000?m]]o`00om]]o`00ol0003oM[clo`000007o`0000;oRKgh0ol00003oi6n
m@Co00001OnL_o43o`0000?oX[k]00?o0000ojbihon/^N<00ol000000onX_>So0000ok2eg@02o`00
00Go[;WS0_l00005ojnfgP;o00001_n`/mX00ol0003o/K3Gok6`e`04ok6`e`04o`000?na[mKo/JoF
ok6_eP;o000000?o[[GNo`000?n`[]H00on`[]H2o`000004ojfegol0003o[joHojn_f0?o00000_n]
]n000ol0003o[K7Ko`000002o`0000;o[;WS00?o0000ojbegon/]Ml00ol000001?n[_>Ko0000oj^i
i?n[^N@3o`0000;oZL7Z00?o0000ojZojOnZ_nT00ol00002ojS5kP;o00001_nXb_801?l0003oZ<od
ojS?m?nXco@2o`000004ojKCmol0003o0000o`0000;oY]Wj0ol00002ojGKn`;o000000?oYMoko`00
0?l000000_l00002oj;So0?o000000?oX>Wko`000?l000000ol000001?nIjoSo0000o`000?n?k?88
o`0007_ooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0PoookJP008OoonfX00ol0
003ooo]ZoookJP1WoookJPGo000000?o6iCYo`000?l000000om8ZoP3o`000003oebanol0003o0000
00?o000000?oKKOlo`000?mf_?`00_mf_?`00ol0003oN;_ko`000003ohFnnP03o`000?n5__[oQKkj
00Go000000CoSKkgo`000?nL_o7oW;oa0ol000000onE`oOo0000oj:nk@02oj:nk@03o`000?nR_^go
X[k]00;o00001OnX_>P01?l0003o[;WSojbihon/^N<3o`0000;oZ;cX00?o0000ojnfg_l000000_l0
0002oj^ji003o`000?n`/m[o/;?J00?o000000Co[KSQo`000?na/=Oo/K3G0ol00002ojjfg`03o`00
0?na[mKo000000Co[[GN00Co0000ok2^e_l0003o00001?n]]Ml2o`0000Ko[KOP00?o0000ojbihon/
^N<01?n/^N<2o`0000GoZkcV0_l00006ojW1jP;o00000_nXaNh2o`0000;oYl_b00?o0000ojS:l_nX
b_800ol00002ojO?m@;o000000CoY]?go`000?l0003o00000onTfOX2o`0000;oYM_k0_l000000onS
g_co0000o`000002o`0000;oX^?l1?l00002oicXn`?o000000GoVN_ho`000?nFk?OoT>ccoho/lP06
o`000003oe?=^Ooonf[ooo]Z07cooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0P
oookJP008OoonfX00ol0003ooo]ZoookJP1ZoookJP?o00000_lHTnL6o`000003odb^nOl0003o0000
00So000000?oM[clo`000?l000000ol00005oh:on`;o000000?oSl3go`000?l000000_l00003oiG3
m`Go00001OnN`?03o`0000CoY;k/0_l00006ojRlj003o`000?n[^^CoZk[T00CoZk[T0_l00005ojfh
h@;o00001_n^]]l00ol0003o[[GNojjegP04ojjegP04o`000?n]]Moo[KGOojfeg`;o00000_n[_>H0
0ol0003o[KOPojfgh003o`000004ojZmiol0003o[;WSojbih`?o00000_nY_nX00ol0003oZkcVo`00
0002o`0000;oZ<?]00?o0000ojW1j_nY`NX00ol00002ojO6l0;o00001_nWbo82o`0000;oYloe1_l0
0003ojCInP;o00000onSfo/00ol0003oXmklo`000003o`0000;oWn;l1?l00002oicXn`Go000000?o
T^[go`000?l000001ol00021oookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX08?oo
nfX0027ooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003o05^/o`000005o`000003oc6Rl_l0003o
000000Go000000?oHKOlo`000?l000001?l000000omc^oco0000o`000002o`0000?oO/7l00?o0000
oh_0nOn;`?T00on;`?T5o`0000;oTL3f1?l00004oi[1l`03o`000?nT_^co000000;o00000_nO`O00
0ol0003oZ;cXojRlj003o`000004ojBokOl0003oZk[Toj^ji0?o00000_nW_^X00ol0003o[KSQo`00
0002o`0000;oZKcX00?o0000ojjfgon^]]l00ol000001?nZ_>Ko0000ojjeg_n^]Mh3o`0000?oZk_V
00?o0000oj^li_n[_>H01?n[_>H2o`0000GoZ[gW0_l00006ojVojP03o`000?nX`ngoZ<?]00CoZ<?]
0_l00002ojO6l0;o00000_nUbo<00ol0003oYl_bojO;lP03o`000003ojC?m_l0003o000000?o0000
0_nTeOT00ol0003oX]Skoj;Hn`02o`0000;oXm_k1ol00002oioRo0Co00000_nHi_`?o`0008Cooo]Z
00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP0PoookJP008OoonfX00ol0003ooo]Zoook
JP1]oookJP06o`000?oonf[ooo]Zo`000?l0QMSo6IKX3?l000000omM]_co0000o`000003o`0000;o
Kk_m2?l00005ohK1n`Oo00001_nJ`O<00ol0003oWl7`oio1l004oio1l0;o00001OnT_nd2o`0000Ko
YkkZ00?o0000ojVlj?nY_>P01?nY_>P2o`0000GoZ[cV0_l00002oj^kiP?o000000CoYl3/o`000?n[
_>KoZkcV0ol00002ojO1k003o`000?nZ_NOo000000;o00000_nW`nd00ol0003oZKoZojVojP03o`00
00;oYlG_0ol00005ojK8l@03o`000?nUbo?oYL_c00CoYL_c0_l00002ojC?mP?o00000_nQe_X2o`00
00;oX]Sk0_l00003oj3Jo0?o00000_nNgod01?l0003oW>7moicQoOnLhOd3o`0000;oV>Kl1?l00002
ohoXn0Co000000?oR^Wbo`000?l000000_l000000omNeL_ooo]ZoookJP24oookJP03o`000?oonf[o
oo]Z04kooo]Z00?o0000oookJ_oonfX07ooonfX0027ooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0
003ooo]ZoookJP02oookJP03o`000?l0LL7o000000Ko000000CoAJcho`000?l0003o00000_mI]O`3
o`000003ofbmoOl0003o000000Wo00000on3`_`01_l0003oS/;hohk2n?n>`_So0000ohk2n0Co0000
0onBaOT4o`0000GoW<?c0ol00004oj32l@?o00001?nS`Nl3o`0000GoYL7]0ol00004ojK0k0;o0000
1OnW`>`2o`0000KoYl7/00?o0000ojO3kOnW`nd01?nW`nd2o`0000;oYlG_0_l00002ojC:l`03o`00
0?nVb?7oY/Sa00?o00000_nTc?D3o`0000;oXm7h0ol000001?nTcoKo0000oj7Fn_nQe_X2o`0000;o
WmSk0_l00002oj3Jo0?o000000CoVmomo`000?l0003o00000_nLhOd4o`0000?oU>Gl0ol00002ohoX
n0_o0000R?oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01oooo]Z000QoookJP03
o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX00ooonfX01ol0003o072oo`000?l0003o5iKU
o`000?m4[_L04_l000000omd__go0000o`000002o`0000;oPl;l0ol00005ohW3nPOo00000_nL`o<3
o`000004oi?7nOl0003oX<;aoj32l@?o00000_nHaoL00ol0003oXl7_o`000002o`0000;oWlCc00?o
0000ojG1kOnU`Nd00ol000001?nQa?7o0000ojK0k?nV`>`3o`0000;oXlCa00?o0000ojO0k?l00000
0_l00002ojC5l@03o`000?nW`NcoYl7/00?o00000_nTa_43o`0000GoY<Ob00?o0000ojC:lonTb_<0
1?nTb_<2o`0000;oY<ce1ol000000onQd_WoWmGkoioEn`02oioEn`;o00000_nOf?/2o`0000?oWM[l
0_l00002oi_Oo@;o00000onIh?d3o`0000;oU>Gl1?l00003oh[Vn0[o0000RooonfX00ol0003ooo]Z
oookJP1>oookJP03o`000?oonf[ooo]Z01oooo]Z000QoookJP03o`000?oonf[ooo]Z073ooo]Z00?o
0000oookJ_oonfX01OoonfXBo`000003oejio?l0003o000000;o00000om___h8o`0000CoQLCl1?l0
00000on@a?Wo0000o`000008o`0000?oV<Og1?l00006oio4l`;o00001OnQa?42o`0000KoXlCa00?o
0000ojC5lOnTaO401?nTaO42o`0000;oY<Ka0_l00002oj79m@03o`000?nTao;oY<Ob00?o000000?o
W/gho`000?l000000_l00003oio?n0Go00000_nNdoX00ol0003oW=GloicEo003o`0000GoWMOl00Co
0000oigJo?nMf_coWM[l1_l00003oiWPo@;oUn7m00Co0000oi3So?n@hocoT>?l0ol00002oh[Vn005
o`000?n8i_OoR>Kgo`000?mni?401Ol0002?oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oook
J_oonfX07ooonfX0027ooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP07oookJP03
o`1d`Ol0003o000000So00000_m5[oP2o`0000?oFk[l2Ol000000omg`_ko0000o`000003o`0000?o
OlGn00?o0000oh_5non;aO/01?n;aO/00ol0003oTLKioi76n@03oi76n@Go00000onDaOP3o`0000?o
UlWi1Ol00002oi[9n0Go00001?nOao@3o`0000CoX<Sd0_l00006oj79m@;o000000?oW/gho`000?l0
00001ol00004oicCn`;o00000_nLeO`2o`0000?oV]Om0ol00004oiWJo@Go000000?oU]ono`000?l0
00001?l00003oi3So0;oS^Ck00?o0000ohGTn?l000000_l000000on8i_Oo0000o`000005o`0009;o
oo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0OoookJP008?oonfX00ol0003ooo]Z
oookJP1coookJP03o`000?oonf[ooo]Z00[ooo]Z1?l000000olEV>?o0000o`00000<o`000003of6m
oOl0003o000000?o00000omb`Oh8o`0000CoQlKl0ol00005ohc7o1?o00000_nGb?P00ol0003oWlOd
o`000002o`0000?oUlcj0ol00003oiW=nPco00001?nLd?X01?l0003oW=?koicCnonLdo/2o`0000?o
VMGl00Co0000oi[GoOnJeogoV]Om1ol000001?nCg_ko0000o`000?l00002oi;NoPCo00000_n>hOd6
o`000003ohGTn?l0003o000000Co000000GoH]SNo`000?l0003oALK2o`00002FoookJP03o`000?oo
nf[ooo]Z04gooo]Z00?o0000oookJ_oonfX07ooonfX0023ooo]Z00?o0000oookJ_oonfX0M?oonfX0
0ol0003ooo]ZoookJP0=oookJP;o00000_lFVN82o`000003oc2Xkol0003o000000?o000000?oB;?h
o`000?l000000_l00002oeflo@?o000000?oK/;no`000?l000000ol000000omja?ko0000o`000003
o`0000;oPLSn1Ol00004ohS8o@?o00001?n<b_`00ol0003oULWioiG9n@03oiG9n@03o`000?nHb_Wo
V<[i00;oV<[i1?l00005oiO<nPKo00001?nFco`3o`0000CoUm7l0ol00004oiSCo0;o00000_nIeO`3
o`000003oiCGo_l0003o000000?o00000_nBfoh3oi3Lo`;o00000_nBg_h:o`000003oh;Rn?n0h_Oo
000000Ko000000CoH]SNo`000?l0003o0000V_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oo
nf[ooo]Z01oooo]Z000PoookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX03ooonfX6
o`000003obnXkol0003o000000?oA[Cg3ol00003ogG4oP[o00000on1b_l4o`0000?oS<[l0ol00004
oho;o0?o00001?nBc?`3o`0000CoU<kk00Co0000oiK?o?nFcocoU/ol0ol00002oi;Ao@?o00001OnD
dod3o`0000CoUMCm0_l00003oiCGoP05o`000?n>f_ooS][oohkJool000000on@g?l4ohgMoPGo0000
00?oQn3lo`000?l000000_l000000omjgoOo0000o`000005o`000003of7Gh_l0003oD<kB00;o0000
WOoonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z01oooo]Z000PoookJP03o`000?oo
nf[ooo]Z07Kooo]Z00?o0000oookJ_oonfX04_oonfX=o`000003od^gn?l0003o000000?o00000_mO
_od3o`000003og35ool0003o000000?o00001?mfaol:o`000003ohK<o_l0003o000000?o00001On<
c?d3o`0000CoS/km0ol00004oi7?o@;o00000_nBdOd2o`0000;oS=?o1?l00003ohkEo`Go00000_n<
f?l00ol0003oR]Wooh[Io`03o`000003ohcKool0003o000000Ko000000?oP]klo`000?l000000_n2
g_`4o`000004og[Omol0003oJ=[[ofSJj`;oJm_]00Ko0000oecDhOl0003o<kZkoc:i^Ol0002Qoook
JP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oonfX07ooonfX0023ooo]Z00?o0000oookJ_oo
nfX0MooonfX00ol0003ooo]ZoookJP0CoookJPKo000000Co08W<o`000?l_Z^ko;j[^0_l00003odRg
m`?o000000?oFkolo`000?l000004?l00003ogc9o`03o`000?n0c?ooP<co00;oP<co4ol00003oh[A
o`?o00001?n<dol6o`0000GoQmOo0_l00002oh[Io`?oQ]Wo1Ol000000on2g?goOmclogoLo002ogoL
o0;o00000_n2g_`00ol0003oLmceo`000002ofWIk`Ko000000?oG=CQo`000?l00000Y_oonfX00ol0
003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01kooo]Z000PoookJP03o`000?oonf[ooo]Z07So
oo]Z00?o0000oookJ_oonfX03ooonfX3o`0000Wooo]Z0_l000000olFWMko0000o`000006o`000003
odbjn?l0003o000000?o00000omQ`_d00ol0003oIlGnofO5oP02ofO5oPco00000omjc?l2o`0000Go
O/ko0_l00005oh;@o`;o00000_n4d_l00ol0003oP=?ooh3Co`02oh3Co`?o00001?n3eOl3o`0000;o
Q=Oo1_l00002og_Jo0;o000000?oNMWlo`000?l000000ol000000omcf_OoLM[gog7Jm`02o`0000;o
G]C[1Ol000000omEd>3oE<oNod?5c`2[oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oo
nfX07_oonfX0023ooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP0;oookJP?o0000
4OoonfX@o`000003odjmn?l0003o000000;o00000_mQa?d2o`0000GoIlSm0ol000000omec?oo0000
o`000003o`000003ogW?ool0003o000000Ko00001?mgdOl3o`0000CoN]?o2Ol00003og[Go@;oMmOl
1?l00002ogWIo0;oJmOe00?o0000of[GmOl000000_l000002omaf_Oo0000oekDjomNe>_oGmC/o`00
0?m8b=Wo0000ocZoc?li_/[o9:nf0:oooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]Zoook
JP0NoookJP008?oonfX00ol0003ooo]ZoookJP1joookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0000I
oookJP03oc/00?l0003o5j3M00Co000000Go<[3/o`000?l0003o0000odZlmP0<o`000003of;7o?l0
003o000000?o00001OmUb_`3o`0000CoJLgl0ol00004ofg@o@?o000000?oL=;lo`000?m/d_/00_m/
d_/=o`000003ofODm_l0003o000000Go000000CoFM3[o`000?m8b=go00000_lc^l/3o`000;Cooo]Z
00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0NoookJP007ooonfX00ol0003ooo]Zoook
JP1loookJP03o`000?oonf[ooo]Z00?ooo]Z0ol0000UoookJPGo000000?o=;?Zo`000?l000002_l0
00000om?`_Go0000o`00000@o`0000?oJLok1_l000000omMc_Go0000oe_=l`02oe_=l`Go000000?o
DL_[oe3:j_l000001_l000001Om3a=go0000obRba?l[]<Ko00000;cooo]Z00?o0000oookJ_oonfX0
C_oonfX00ol0003ooo]ZoookJP0NoookJP007ooonfX00ol0003ooo]ZoookJP1moookJP03o`000?oo
nf[o000000;o0000;_oonfX00olK003o0000o`00000=o`000003ocZijOl0003o000000So00000omC
ao<5o`0000GoA<;X0ol000001?m<an_o0000o`000?l00002ocFkf@Co0000aooonfX00ol0003ooo]Z
oookJP1>oookJP03o`000?oonf[ooo]Z01kooo]Z000OoookJP03o`000?oonf[ooo]Z07kooo]Z00?o
0000oookJ_oonfX0?ooonfX01?lD003o0000o`000?l00003o`bMa0Wo00000_l/]=T3o`000=Oooo]Z
00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0NoookJP007ooonfX00ol0003ooo]Zoook
JP1noookJP03o`000?oonf[ooo]Z0?oooo]Z;?oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oo
nf[ooo]Z01kooo]Z000OoookJP03o`000?oonf[ooo]Z07kooo]Z00?o0000oookJ_oonfX0oooonfX]
oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX07OoonfX001oooo]Z00?o0000oook
J_oonfX0O_oonfX00ol0003ooo]ZoookJP3ooookJRgooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0
003ooo]ZoookJP0MoookJP007ooonfX00ol0003ooo]ZoookJP1noookJP03o`000?oonf[ooo]Z0?oo
oo]Z;OoonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z01gooo]Z000OoookJP03o`00
0?oonf[ooo]Z07kooo]Z00?o0000oookJ_oonfX0oooonfX]oookJP03o`000?oonf[ooo]Z04kooo]Z
00?o0000oookJ_oonfX07OoonfX001oooo]Z00?o0000oookJ_oonfX0O_oonfX00ol0003ooo]Zoook
JP3ooookJRgooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0MoookJP007_oonfX0
0ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z0?oooo]Z;OoonfX00ol0003ooo]ZoookJP1>
oookJP03o`000?oonf[ooo]Z01gooo]Z000NoookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oook
J_oonfX0oooonfX]oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX07OoonfX001ko
oo]Z00?o0000oookJ_oonfX0O_oonfX00ol0003ooo]ZoookJP3ooookJRkooo]Z00?o0000oookJ_oo
nfX0C_oonfX00ol0003ooo]ZoookJP0MoookJP007_oonfX00ol0003ooo]ZoookJP1noookJP03o`00
0?oonf[ooo]Z0?oooo]Z;_oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01cooo]Z
000NoookJP03o`000?oonf[ooo]Z07kooo]Z00?o0000oookJ_oonfX0oooonfX^oookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX07?oonfX001kooo]Z00?o0000oookJ_oonfX0O_oonfX0
0ol0003ooo]ZoookJP3ooookJRkooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0L
oookJP007_oonfX00ol0003ooo]ZoookJP1noookJP03o`000?oonf[ooo]Z0?oooo]Z;_oonfX00ol0
003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01cooo]Z000NoookJP03o`000?oonf[ooo]Z07ko
oo]Z00?o0000oookJ_oonfX0oooonfX^oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX07?oonfX001gooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003ooo]ZoookJP3ooookJRoooo]Z
00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0LoookJP007OoonfX00ol0003ooo]Zoook
JP1ooookJP03o`000?oonf[ooo]Z0?oooo]Z;ooonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oo
nf[ooo]Z01cooo]Z000MoookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX0oooonfX_
oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX07?oonfX001gooo]Z00?o0000oook
J_oonfX0OooonfX00ol0003ooo]ZoookJP3ooookJRoooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0
003ooo]ZoookJP0LoookJP007OoonfX00ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z0?oo
oo]Z;ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01_ooo]Z000MoookJP03o`00
0?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX0oooonfX_oookJP03o`000?oonf[ooo]Z04oooo]Z
00?o0000oookJ_oonfX06ooonfX001gooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003ooo]Zoook
JP3ooookJRoooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0KoookJP007OoonfX0
0ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z0?oooo]Z;ooonfX00ol0003ooo]ZoookJP1?
oookJP03o`000?oonf[ooo]Z01_ooo]Z000MoookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oook
J_oonfX0oooonfX_oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX06ooonfX001co
oo]Z00?o0000oookJ_oonfX0P?oonfX00ol0003ooo]ZoookJP3ooookJRoooo]Z00?o0000oookJ_oo
nfX0CooonfX00ol0003ooo]ZoookJP0KoookJP007?oonfX00ol0003ooo]ZoookJP20oookJP03o`00
0?oonf[ooo]Z0?oooo]Z;ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01_ooo]Z
000LoookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX0oooonfX`oookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX06ooonfX001cooo]Z00?o0000oookJ_oonfX0OooonfX0
0ol0003ooo]ZoookJP3ooookJS7ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0J
oookJP007?oonfX00ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z0?oooo]Z<OoonfX00ol0
003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01[ooo]Z000LoookJP03o`000?oonf[ooo]Z07oo
oo]Z00?o0000oookJ_oonfX0oooonfXaoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oo
nfX06_oonfX001cooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003ooo]ZoookJP3ooookJS7ooo]Z
00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0JoookJP007?oonfX00ol0003ooo]Zoook
JP1ooookJP03o`000?oonf[ooo]Z0?oooo]Z<OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oo
nf[ooo]Z01[ooo]Z000KoookJP03o`000?oonf[ooo]Z083ooo]Z00?o0000oookJ_oonfX0oooonfXa
oookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oookJ_oonfX06_oonfX001_ooo]Z00?o0000oook
J_oonfX0P?oonfX00ol0003ooo]ZoookJP3ooookJS7ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0
003ooo]ZoookJP0JoookJP006ooonfX00ol0003ooo]ZoookJP20oookJP03o`000?oonf[ooo]Z0?oo
oo]Z<OoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01[ooo]Z000KoookJP03o`00
0?oonf[ooo]Z083ooo]Z00?o0000oookJ_oonfX0oooonfXaoookJP03o`000?oonf[ooo]Z053ooo]Z
00?o0000oookJ_oonfX06OoonfX001_ooo]Z00?o0000oookJ_oonfX0P?oonfX00ol0003ooo]Zoook
JP3ooookJS7ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0IoookJP006ooonfX0
0ol0003ooo]ZoookJP20oookJP03o`000?oonf[ooo]Z0?oooo]Z<OoonfX00ol0003ooo]ZoookJP1@
oookJP03o`000?oonf[ooo]Z01Wooo]Z000KoookJP03o`000?oonf[ooo]Z083ooo]Z00?o0000oook
J_oonfX0oooonfXaoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX06OoonfX001_o
oo]Z00?o0000oookJ_oonfX0P?oonfX00ol0003ooo]ZoookJP3ooookJS;ooo]Z00?o0000oookJ_oo
nfX0CooonfX00ol0003ooo]ZoookJP0IoookJP006ooonfX00ol0003ooo]ZoookJP20oookJP03o`00
0?oonf[ooo]Z0?oooo]Z<_oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01Wooo]Z
000JoookJP03o`000?oonf[ooo]Z087ooo]Z00?o0000oookJ_oonfX0oooonfXboookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX06OoonfX001[ooo]Z00?o0000oookJ_oonfX0P?oonfX0
0ol0003ooo]ZoookJP3AoookJPko0000DooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[o
oo]Z01Wooo]Z000JoookJP03o`000?oonf[ooo]Z083ooo]Z00?o0000oookJ_oonfX0bOoonfX8o`00
00?oOK;e00?o0000og:/mOmb[?D00_mb[?D00ol0003oL:_eo`000003ofFUm0So0000BooonfX00ol0
003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01Wooo]Z000JoookJP03o`000?oonf[ooo]Z083o
oo]Z00?o0000oookJ_oonfX0`ooonfX6o`0000CoS[[d0_l00003ogfbm@Ko00000_mb[?D00ol0003o
L:_eo`000005ofFUm0;o00000omIWO<7o`0004Cooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003o
oo]ZoookJP0HoookJP006_oonfX00ol0003ooo]ZoookJP20oookJP03o`000?oonf[ooo]Z0<3ooo]Z
0ol00003oio1l@03o`000?n>^_CoS[[d00GoS[[d1?l00003ogfam@04o`000?mbZoGoLZ_eog:[m@ko
00000_mIWO<2o`0000?oC9Ka0ol00011oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oo
nfX06?oonfX001[ooo]Z00?o0000oookJ_oonfX0P?oonfX00ol0003ooo]ZoookJP2moookJP?o0000
1onO`O44o`0000CoS[Wc0_l00005ogfam@03o`000?mbZoGoLZ_e00;oLZ_e00?o0000og6Zm?l00000
1OmVY?@00ol0003oI:?do`000002oeZMlPOo000000?oC9Kao`000?l000000_l0000noookJP03o`00
0?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX06?oonfX001[ooo]Z00?o0000oookJ_oonfX0P?oo
nfX00ol0003ooo]ZoookJP2joookJP?o00000_ngb^P00ol0003oWl7aoio1l@03o`0000?oWl7`00?o
0000ohjilon>^O<01On>^O<Co`000003ofJTm?l0003o000000?o00000_mJWO82o`0000;oCIG`1?l0
00000oloS^ko0000o`000002o`0003[ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]Zoook
JP0HoookJP006_oonfX00ol0003ooo]ZoookJP20oookJP03o`000?oonf[ooo]Z0;Sooo]Z0_l00006
okO:j0;o00001onO`O04o`0000CoS[Wc0_l00005ogjam005o`000?mbZoCoLZ_dog:[m?l000000_ma
Z_@00ol0003oIjCcofNTl`03ofNTl`;o00000omKW?86o`000003odfEl?l0003oBY?`00;o000000?o
?hk^o`000?ljRnd01Ol0000eoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX06?oo
nfX001Wooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP2goookJP03o`000?ngb^So
]l[X00;o]l[X0ol00002okO:j@03o`000?nO`O3oWl7`00?o00000_nN`?000ol0003oS[Wcohjil`02
ohjil`04o`000?n>^O?oS[Wcohjila?o000000?oIjCco`000?l000000ol000000omKW?;o0000o`00
0003odjEl0Co000000?o@8g^o`000?l000000_l000000olaQN_o0000obb1j@03o`0003;ooo]Z00?o
0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0HoookJP006OoonfX00ol0003ooo]ZoookJP21
oookJP03o`000?oonf[ooo]Z0;Kooo]Z00Co0000olk?fol0003o]l[X0_l00006okO:j@;o00001_nN
`?04o`0000CoS[Sc0_l00006ogj`m005o`000?mcZ_CoLj[dog>Zm?l000000_mbZO<00ol0003oIj?c
ofNSl`02ofNSl`;o00000omKW?84o`0000?oCYG`00?o0000od^Ckom;Tnl00ol00002ocb;k@Co0000
0_l/PNT2o`00033ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0HoookJP006Ooo
nfX00ol0003ooo]ZoookJP21oookJP03o`000?oonf[ooo]Z0;Kooo]Z0_l000000oo>cm_o0000okO:
j@03okO:j@?o000000Co]/[Yo`000?nN`?3oW/3`0ol00003oik0l003o`000?n>^??oS[Sc00GoS[Sc
4ol000000omWXo?o0000o`000005oe^LlPCo000000CoCYG`o`000?m;Tnoo00000_m2SNd4o`000003
oc>5j_l0003o000000Go0000;ooonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z01So
oo]Z000IoookJP03o`000?oonf[ooo]Z087ooo]Z00?o0000oookJ_oonfX0]OoonfX01ol0003ofM7@
omWAd?l0003oc]3Ko`000?ngb^T00_l00005okK:j@;o00001onN`?04o`0000CoSKOb00?o0000ogf_
m?mm[o@01?mm[o@01Ol0003oLjWcog>YlomcZO?o000000?oLZSc00Ko0000ofRRl_mXX_;oJ:;bo`00
0?mVXO88o`0000;oD9C`1ol000000olnRngo0000o`000003o`000004obj1j?l0003o0000oaYeh`;o
0000;OoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z01Oooo]Z000IoookJP03o`00
0?oonf[ooo]Z087ooo]Z00?o0000oookJ_oonfX0]?oonfX00ol0003ofM7@omWAd002o`000003olk@
fol0003o000000?o]/[Y0ol00002okG9j@03o`000?nN`?3oW/3`00?o00000onM_o000ol0003oSKOb
ohfglP05ohfglP03o`000?mm[oCo000000oo000000CoJ:;bo`000?mVXO;o00001?mLVo401_l0003o
FY[ao`000?l0003oD9C`o`0000;oCI;_00?o0000odB=kOl000000ol000001oleQN[o0000oc21j?l0
003o;X7Xo`000?lMMN<01?l0000[oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0
5ooonfX001Wooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP2coookJP04o`000?oI
dM3ofM7@o`0000;of]?A00Co0000olgAg?l0003o]/[Y0_l00006okG9j@;o00001onM_o04o`0000?o
RkOc00?o0000ogV/lomi[?<01Omi[?<01?l0003oLjScog>Xlol00003og:WlP04o`000?mXX_;oJ:;b
ofRRlPKo00000_mLVo42o`0000;oDIC_1ol00002od2:k003o`000?leQN[o000000?o<87X00Go0000
oaeeholMMN?o0000oaAah003o`0002Sooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]Zoook
JP0GoookJP006OoonfX00ol0003ooo]ZoookJP21oookJP03o`000?oonf[ooo]Z0;;ooo]Z00Co0000
omWAd?oIdM3o00000ooJdm42o`000003olgAg?l0003o]LWY00?o]LWY0ol00002okC9jP03o`000?nM
_o3oWKo`00?o00000onL__000ol0003oRkOcoh^gl`04oh^gla;o000000GoJ:;bo`000?mWXO7oIj7a
o`000002oefKl0Ko000000CoDIC_o`000?m>T^ko00000_m5SNd00ol0003o@8[/o`00000<o`000003
o`1Qeol0003o000002Kooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0GoookJP00
6OoonfX00ol0003ooo]ZoookJP21oookJP03o`000?oonf[ooo]Z0;7ooo]Z0_l000000ooIdM3o0000
om[Cd@02om[Cd@07o`000?oKeM;ofmGBo`000?o<dMko0000okG9j@02o`0000Ko]<WZ0_l00007oibn
l0Co00000on;]_<00ol0003oOJgbogf]lP05ogf]lP04o`000?mcYo;oLjObo`0000;oLZOb00Co0000
ofRQlOmXXO7oJ:7a1_l000001OmMVo3o0000oe^Il?mKVO3o000000;oDYC_1?l00002odF=k@03o`00
0?m1R^co@H[/00;o00000_lbPNP2o`0000;o7gKS0_l000001?lGLN7o0000o`000?l0HML2o`0002Co
oo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0GoookJP006OoonfX00ol0003ooo]Z
oookJP21oookJP03o`000?oonf[ooo]Z0;3ooo]Z00Co0000onS@__oXd;ko00000ooJdm401_l0003o
fmGBom_Ed_oKeM;o0000olcAgP;o00001?ndbNX3o`0000;o//S[00?o0000oibnl?nL__000ol00002
oi^ml003o`000?n;]_?oRkKc00GoRkKc00?o0000ogf]l_mm[O800_mm[O82o`000003ogf]l_l0003o
000000Go00000omXXO401?l0003oIj3aofNPlOl00002oejJl0Ko000000CoDYC_o`000?m?T^koCi;^
1?l00002od6:k004ocV5j_l0003o0000oc:1j0Go000000?o6W7Qo`000?l000001?l0000SoookJP03
o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX05ooonfX001Sooo]Z00?o0000oookJ_oonfX0
POoonfX00ol0003ooo]ZoookJP2aoookJP;o000000Goj=2no`000?l0003of]?Ao`000003om_EdP03
o`000?oKf=Co000000;obm;O00Co0000okC9j_l0003o00001_nbb>/2o`0000KoVkg`1_l000000on;
]_?o0000o`000003o`0000?oOJcb00Co0000og>Wl_mcYo;o00000_mbY_4;o`000004oejJl?l0003o
G9W_o`0000;oDi?^1?l00002odJ<k003o`000?m3R^_o000000;o000000?o<h3Xo`000?lbPNP00_l0
00000olRM^?o0000o`000002oaYah@03o`000?l2H]So0V;H00Co00008?oonfX00ol0003ooo]Zoook
JP1@oookJP03o`000?oonf[ooo]Z01Oooo]Z000HoookJP03o`000?oonf[ooo]Z087ooo]Z00?o0000
oookJ_oonfX0/OoonfX00ol0003ol/^Xo`000002onWC_P05o`000?oKeM;ofmGBom_Ed_l000000_oK
f=@01Ol0003obm;Ool_Bgoo;d]oo000000Co//S[0ol000001?n`an_o0000oi^ml?nK_O03o`0000;o
VKc`00?o0000ohVel_n9]O801?n9]O82o`0000OoOJcb00Co0000og>Wl_mcYo;o00000ombY_401?l0
003oJJ3aofVPlOl00002ofNOl004o`000?mNVNooGYW_oejIk`Co00000_mCTnh00ol0003oD97]oe2A
k@02o`000004odJ<k?l0003o@h[[od>:j`?o00000_lcP>P3o`000003ob9fhol0003o000000Co0000
00Co05cDo`000?l0B<Ko00007ooonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z01Oo
oo]Z000HoookJP03o`000?oonf[ooo]Z087ooo]Z00?o0000oookJ_oonfX0/OoonfX01Ol0003ol/^X
o`000?l0003ojM>n00;o000000cofmGBo`000?oKf=CofmSDo`000?oJg=So0000ol_Bgol0003ob=;Q
o`000?nbb>/2o`0000Go/<O[0_l00006oiVll004o`000?n9]O;oRKGbohVelP;o000000?oRKGbo`00
0?l000001Ol000000omm[?;o0000o`00000=o`0000?oGYW_00?o0000oebHkomLV>l01ol000000om8
S>co0000od>:j`03o`000007ocF0iol0003o0000o`000?l]O>Ko0000obAfh`02o`000008oaabhOl0
003o0000o`ESf?l0003o05cDo`000?l0B<H2o`0001gooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0
003ooo]ZoookJP0FoookJP006?oonfX00ol0003ooo]ZoookJP21oookJP03o`000?oonf[ooo]Z0;3o
oo]Z00?o0000ooS4Tol000000_occJT2o`000005on[F`?l0003ofmSDom_He?l000000_oJg=P2o`00
00;ob=;Q0_l00003ok37j`?o00000_n^a^`00ol0003oVKc`oiVll005oiVll0?o00000on8/o800ol0
003oRK?ao`000006ogf[l@03o`000?mcY_7o000000CoLZGa00Co0000ofVOl?mYWo3o00000_mXW_08
o`0000;oE9?^00?o0000oe6AkOmATNd00ol00003odB9j`?o00000_leP>L3o`000003obAfhol0003o
9GOS00;o000000?o26?Io`000?l000000ol000000ol0@<3o0000oookJP0KoookJP03o`000?oonf[o
oo]Z057ooo]Z00?o0000oookJ_oonfX05_oonfX001Sooo]Z00?o0000oookJ_oonfX0POoonfX00ol0
003ooo]ZoookJP2`oookJP07o`000?oha9?o0000o`000?occJWo0000oo?@ZP02o`00000<om_He?l0
003of]cHom[Lf?l0003ofMWGo`000?o8d^7o0000olKAhol0003o/<O[0_l00006ojk6k0Co00001?nH
^o000ol0003oR;?bohRclP02ohRclPWo000000?oOJ_ao`000?l000001ol000000omYWo3o0000ofRN
l002ofRNl004o`000?mOVNooGiW_o`0000;oGIO^0_l000002?mDTnko0000oe6AkOmATNgo0000odV<
jol0003oA8W[0_l000000om4RN_o0000o`000002o`000005obmli_l0003o9gKSobAfhol000000_lU
Mn<00ol0003o26?Io`QSf@04o`000003o`10`?l0003ooo]Z01[ooo]Z00?o0000oookJ_oonfX0DOoo
nfX00ol0003ooo]ZoookJP0FoookJP006?oonfX00ol0003ooo]ZoookJP21oookJP03o`000?oonf[o
oo]Z0;3ooo]Z0ol000001ooiai?o0000oo?@Z_ocd:[o0000on_I`_l000000_oJg=P01Ol0003ofMWG
omWIeooIfMOo000000;oa]7S0_l00004ojk6k0?o00000_n[aNd00ol0003oV;_`oiRkl005oiRkl0;o
00000_n7/_801Ol0003oR;;aohRblOn8/_7o000000KoOJ_`0_l00004og:Tl003o`000?mYW_3oJIk`
00Oo000000KoGiW_o`000?mMUnkoGIO^o`000?mET^d6o`0000?oBhc/1?l000001OlfOnOo0000o`00
0?l0003o9gKS00;o000000[o9GOSo`000?l;HmWo26?Io`000?l2G]Ko0000o`1;bOl0003o04300_l0
000JoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX05_oonfX001Sooo]Z00?o0000
oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP2`oookJP04o`000?oj^W_o0000ooW7T`?o000000Go
m=:/o`000?l0003of]cHo`000003omWIe`;o000000Koa]7So`000?o4dNCoa=7To`000?n^a^`2o`00
00KoZlG]1?l00004oiJil004o`000?n7/_;oQk;bohNblP[o000000?oOJ_`o`000?l000000ol00000
1?mbY?3o0000ofVNl?l00004ofRMk`03o`000?mOV>koGiS^00Ko00000omBT>`5o`0000;oBhc/00Ko
0000ocQoiol0003o=WoWo`000?laO>D2o`00000;ob9bhOl0003o0000o`000?l;HmWo26?Io`000?l2
G]Ko0000o`1;bOl000000_l0::d00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z053ooo]Z
00?o0000oookJ_oonfX05_oonfX001Sooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]Zoook
JP2`oookJP04o`000?oj^W_o0000o`0000;onlVB00Go0000ooCB[?l0003om]J/o`000003omWIe`04
o`000?oGf][oem[Jo`0000?oa=7T0_l00004oj_5k@;o00000onX`nd00ol0003oU[W`oiJil005oiJi
l0;o000000?oQ[7ao`000?n7/O400_n7/O400ol0003oOJW`ogfYl004ogfYl0;o00000omaXo0<o`00
00?oGIO^00Co0000oeJBkOl0003oDY3/1?l00002odN8jP03o`000?m;S>co000000Co>7oW0_l00000
1?lYM^?o0000o`000?lRL^42o`000007o`]SfOl0003o0000o`1Gd_l0003o04_9o`000002o`0X[@03
o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0FoookJP00
5ooonfX00ol0003ooo]ZoookJP22oookJP03o`000?oonf[ooo]Z0;3ooo]Z0_l000001?ol_7Wo0000
oo_9T_okbI82o`0000;om]J/0_l000001ooIfMOo0000omOJf_oGf][oe=_Mo`000?o4dN@00_l00002
ol7@iP?o00001onX`nd4o`0000?oUKS_00Ko0000ohJalOn6/O7oQ[7ao`000?n7/O48o`000003ogfY
l?l0003o000000;oLJ?`0_l000000omaXo3o0000o`000004ofRLk`03o`000?mPV>koH9S^00Ko0000
0omCT>`5o`0000;oAhSZ0ol000000olhOnOo0000oc=li@02o`000007ob=bhOl0003o0000o`000?l>
I=[o0000o`aTf@02o`000006o`1<b_l0003o04?3o`0X[Ol06j;o00005ooonfX00ol0003ooo]Zoook
JP1@oookJP03o`000?oonf[ooo]Z01Kooo]Z000GoookJP03o`000?oonf[ooo]Z08;ooo]Z00?o0000
oookJ_oonfX0/?oonfX2o`000006ooblNOl0003o0000o`000?olc97o00000_ofeZ`01OogfZko0000
o`000?oGf][o000000?oe=_M00Go0000ol7@i_o1d>Ko`M3Vo`000002okg?i`03o`000?nX`ngoZ<?]
00?o00000_nU`^d00ol0003oUKS_oiFhk`05oiFhk`Go00000_n5[o000ol0003oNjS`og^Xl005og^X
l003o`000?m]WnooKIo_00;oKIo_1ol000001?mXW>oo0000of2Hk_l00003oejFk@?o000000GoDi3/
o`000?l0003oDi3/o`000002odR7j@04o`000?m7R>[o0000o`0000;o>WoV0ol000000ol[Mn?o0000
o`000002ob=bh@Co000000So36CIo`000?l0C<[o0000o`13`ol0::go01^Ro`0001Kooo]Z00?o0000
oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0FoookJP005ooonfX00ol0003ooo]ZoookJP22oook
JP03o`000?oonf[ooo]Z0;3ooo]Z1?l000002_om_gKo0000ooc<TOl0003om]J/o`000?ogfZko0000
onWLa_l00002omCKg@03o`000?oAgN7o000000;o`M3V00Co0000okg?ionmcnOo_LoW0ol00006ojG2
k@Co00001?nC]^l00ol0003oQ:oao`000004ohF_l003o`000?mkZ?3oNjS`00CoNjS`00?o0000offO
kom]Wnl01?m]Wnl2o`0000?oJ9c^1?l00002oejFk@04o`000?mNU^go0000o`0000?oFI;/1Ol00002
odR7j@;o00000_ljOnH01?l0003o=GcUo`000?l[Mn<4o`000005oa5Uf_l0003o0000o`000?l<I=T0
0_l000001Ol0A<Go0000o`000?l06j;o000001Gooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003o
oo]ZoookJP0FoookJP005ooonfX00ol0003ooo]ZoookJP22oookJP03o`000?oonf[ooo]Z0;3ooo]Z
0_l000000ook/5oo0000oofoMP02o`000004oog@T?l0003ommZ^ooOJ[P?o000000?oimg:o`000?oA
gN400_oAgN42o`0000;o_LoW0_l000001?njenoo0000ojG2kOnU`^d3o`0000?oXko^00?o0000oi>f
konC]^l01OnC]^l?o`000003offOkol0003o000000Go00000_mXW>h2o`000003ofRLk_l0003oHiS]
00;oHiS]1_l00003oeVBk004o`000?m8Q^So0000odR7j@;o000000Go>goVo`000?ljOnKo0000ocEl
i@03o`0000;o9G;Q00Go0000oa5Uf_lAIM[o0000o`QOe`04o`000003o`0]/_l0003o000001Gooo]Z
00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0EoookJP005ooonfX00ol0003ooo]Zoook
JP22oookJP03o`000?oonf[ooo]Z0;3ooo]Z0_l000000ook/5oo0000oofoMP02o`000006oog@T?l0
003o0000o`000?oggJoo00000_oWgLX2o`0000;odMgQ00Co0000okg?ionmcnOo00001?njenl2o`00
00OoXko^1?l00004oi:ek`03oh>^lOl0003oQ:k`00CoQ:k`00?o0000ogZWkomjYnl00_mjYnl00ol0
003oNjK^o`000006og6QkP03o`000?mXV^goJ9[]00;oJ9[]1Ol00003of>Hk@04o`000?mDSN[oE8gZ
o`0000;oFI;/00?o0000odR6j?m8Q^P00_m8Q^P2o`0000;o>goV1Ol000000olWLN3o0000o`000003
o`000007o`]Oeol0003o0000o`1>c?l0ALKo0000o`0]/P02o`0001Cooo]Z00?o0000oookJ_oonfX0
DOoonfX00ol0003ooo]ZoookJP0EoookJP005ooonfX00ol0003ooo]ZoookJP22oookJP03o`000?oo
nf[ooo]Z0;3ooo]Z0_l000003Ook/5oo0000o`000?on`G?o0000oog@T?l0003oo]>?o`000?oggJoo
0000onOMb_l000000_oTg/h00ol0003ocMkUo`000002o`0000?o^]O_00Co0000okW<jOnic>Wo0000
0_nS_nh3o`0000?oX;g^00?o0000oi:ekonB]Nl01OnB]Nl;o`000003ogZWkol0003o000000Co0000
0_maXNh00ol0003oJ9[]ofRJk@04ofRJk@03o`000?mOTn_oGi?[00;o00000_mSV>d00ol0003oE8gZ
oeB=jP02oeB=jPCo000000?oB8KXo`000?m5Q>L00ol00002ocMli@Co000000Co9g7Po`000?l0003o
56GJ0_l000000ol;GmOo0000o`1>c002o`15aP04o`000?l049Wo0000o`0001;ooo]Z00?o0000oook
J_oonfX0DOoonfX00ol0003ooo]ZoookJP0EoookJP005ooonfX00ol0003ooo]ZoookJP22oookJP03
o`000?oonf[ooo]Z0;3ooo]Z1Ol000000oon`G?o0000o`000002ookCS`;o000000Gomn:ao`000?oT
g/koi=k>o`000002on7NdP05o`000?njenoo^]O_ok[Gkol000001Onic>T2o`0000OoX;g^1?l00003
ohfdl@03o`000?n0Zo3oP:_`00CoP:_`00?o0000ogZVkomjY^l00_mjY^l00ol0003oNZG^o`000004
og6OkPKo00000omXV^d00ol0003oGi?[oenCj`02oenCj`Co00000_mDSNX2o`0000?oBXKX0ol00002
oceoi@06o`000?lgO>Go0000oc1ghol0003o:77P0_l000001OlPK=go0000o`000?l=GmOo000000;o
04o=00Ko04K6o`15a_l0003o0000o`0@VOl0000BoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000
oookJ_oonfX05OoonfX001Oooo]Z00?o0000oookJ_oonfX0P_oonfX00ol0003ooo]ZoookJP2`oook
JPSo00000_ondhl2o`000004ooOR/Ol0003oi=k>o`0000;ohMkB0_l000000onjenoo0000o`000004
okW<j@04o`000?ndbN[o]<WZo`0000;oX;g^0ol00002oifkkP03o`000?n=]?7oSKCa00GoSKCa00Co
0000oh2[l?n0Zo3oP:_`2ol00005og6OkP;o00000omXVN`5o`0000?oGi?[0_l00002oeF=j@Go0000
0_m:Q^P00ol0003oAXCWo`000002o`0000;o?WoU00?o0000oc1ghol000000_lXLN001?l0003o5fKJ
oaMVf_l00002o`eOe`;o04o=00Ko04K6o`15a_l0<KOo026Yo`0@VOl0000AoookJP03o`000?oonf[o
oo]Z057ooo]Z00?o0000oookJ_oonfX05OoonfX001Kooo]Z00?o0000oookJ_oonfX0PooonfX00ol0
003ooo]ZoookJP2aoookJPCo000000?onk=Fo`000?l000000_l000001OooeXko0000o`000?ogi[?o
000000;ohMkB00Co0000onCYe?oTjMCo00000_nic>T2o`0000Ko]<WZ0_l00006oifkkPKo000000?o
SKCao`000?l000000_l00003oh>ZkP05o`000?miYNkoNJG^ogVUk_l000000_miY>h;o`0000;oJ9W/
0_l00003oenCj`03o`000?mOTn_o000000?o000000WoEHgYo`000?l0003oBhKWo`000?m:Q^So0000
odJ4iol000000_loOnD2o`000005ocioiOl0003o0000o`000?lXLN000_l000003OlGI][o0000oa1P
eol=GmOo0000o`1?cOl0003o04K6o`000?l0<KOo026YoiPS0?l000004?oonfX00ol0003ooo]Zoook
JP1AoookJP03o`000?oonf[ooo]Z01Gooo]Z000FoookJP03o`000?oonf[ooo]Z08;ooo]Z00?o0000
oookJ_oonfX0/_oonfX4o`000006oo^cE_l0003o0000ook5KOl0003oomJ>0_l000001?ogi[?o0000
on7Nd_l00002onCYe004o`000?o<fN?oc=WSo`0000Co]<WZ0ol000001?n`an_o0000oifkk_nM^nh3
o`0000;oV[W^00?o0000oh^cl?n;/o001?n;/o02o`0000KoPj[^00Go0000ogVUk_miYNkoNJG^o`00
0002ogVTkP03o`000?maW^goLIk]00;oLIk]00?o0000og6Mk?l000000omXV>`6o`0000;oGi?[0_l0
0003oeJ<j@?o00000_m;Q^L4o`000003ocmoiOl0003o>g_S00?o000000?o:W3Oo`000?lXLN000_l0
00001_lGI][o0000oa1Peol=GmOo0000o`1?c@;o000000Go03Zno`0S[?l059koV2<0o`00000@oook
JP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX05OoonfX001Kooo]Z00?o0000oookJ_oo
nfX0P_oonfX00ol0003ooo]ZoookJP2boookJPOo000000Soo/E]o`000?l0003o0000ooOV/ol0003o
mn^eo`0000;oi>WD00Oo0000on7/fOo<fN?o0000olOGiOl0003o]<WZ00;o00001On`an/2o`0000Ko
V[W^00Ko0000oh^cl?n;/o3oRk?`o`000?n;/o08o`000003oh>Zk_l0003o000000go00001?mXV>`2
o`0000?oH9;Z1?l00003oeJ<j@03o`000?mCR^So000000;o00000_m7PnH5o`0000;o>g_S00?o0000
obY`golZL=l00_l000001?lJIm_o0000o`000?l@H=L6o`000004o`0S[?l059koV2<0o`0000oooo]Z
00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP0EoookJP005_oonfX00ol0003ooo]Zoook
JP22oookJP03o`000?oonf[ooo]Z0;;ooo]Z2?l000002OonafSo0000o`000?ogi[?o0000ooO[]Ol0
003oi>WDo`000002on7/f@03o`000?o7enGoamOU00;o00000on`an/3o`0000;oZlC/00?o0000oiZi
k_nJ^Nh01OnJ^Nh3o`0000;oRK7`00Co0000ohb`k_n</>ko00001_n2Z>d00ol0003oNJC^o`000004
ogRSk@04o`000?maWNcoLIg/o`0000;oL9c/2?l00003of2BjP03o`000?mNT>Wo000000;o000000Co
EXcYo`000?mCR^So00000_m<Q^L00ol0003oAh?Vo`000002od5oi@06o`000?llNn?o0000oc]khol0
003o;G7O0_l00002obE]g@06o`000?lBH=Oo0000o`000?l6F=;o05;?0ol000001?l09:go02>/o`0D
W_l0000?oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX05?oonfX001Kooo]Z00?o
0000oookJ_oonfX0P_oonfX00ol0003ooo]ZoookJP2boookJPSo000000Goo/MXo`000?ongH_o0000
ooO[]@03o`0000;ohNcI0_l000001Oo7enGo0000ol;Dj?l0003o/<O[00;o00001_n[a>`4o`0000Co
V;O^00Ko0000ohVal?n9/O3oRK7`o`000?n</>h8o`000003oh:XkOl0003o000000Oo000000GoLIg/
o`000?m`W>coL9c/o`000003ofVHj`03o`000?mWU^[oIiKZ00Oo000000?oEhcXo`000?l000000ol0
00000om<Q^Oo0000odf6iP02odf6iP03od5oiOl0003o?7_S00;o?7_S0_l00002obeag`;o000000Co
7FOKo`000?l0003o4V3G0_l000001Ol0D/oo0000o`17b?l0003o02B]00?o00003_oonfX00ol0003o
oo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01Cooo]Z000FoookJP03o`000?oonf[ooo]Z08;ooo]Z
00?o0000oookJ_oonfX0/ooonfX9o`000003ookMRol0003omn^e00;o00000_oQk=T01?l0003oeo;S
omObhol00002ol;Dj0;o00001?n[a>`2o`0000?oYl7/00?o0000oiRgk_nH]nh01OnH]nh5o`0000;o
RJo^00?o0000oh2XkOn0Z>d01?n0Z>d2o`0000GoM9o/00?o0000og6Lk?maW>`01_l000001OmYV>_o
0000ofNFj_mWU^[o000000?oH97Y00?o0000oej@j?mNT>P00ol00002oeB9i`Go00000_m=Q^H5o`00
0005ocIfhOl0003o0000o`000?l]LMl00_l000001?lDGmOo0000o`000?l9FM<2o`000004o`18b?l0
003o0000o`0T[@?o00003OoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01Cooo]Z
000FoookJP03o`000?oonf[ooo]Z08;ooo]Z00?o0000oookJ_oonfX0/ooonfX:o`000006ooSTQOl0
003olOFjo`000?oQk=Wo00000_oGl^<01?oFin;o0000o`000?l00002okgAj@?o00001onW`N`4o`00
00?oU[G]00Co0000ohR_kon8[noo00001?n9[nh00ol0003oP:S]oh2Xk@04oh2Xk@03o`000?mdWnco
M9o/00CoM9o/00?o0000og6Lk?l000000om`Vn/00ol0003oJIOZofVGjP06o`000005of2AjOl0003o
GY3Xoej@j?l000000_mHS>L01ol0003oE8WWo`000?l0003oCXGVo`000?m;P^D01?l00002ocaihP?o
00000_l_LMl2o`000004obeagol0003o0000oaAOe`;o000000?o0E??o`000?l0B<P00_l000001?l0
5j?o0000o`000?l0000<oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX05?oonfX0
01Kooo]Z00?o0000oookJ_oonfX0P_oonfX00ol0003ooo]ZoookJP2coookJP03o`000?oML`7o0000
00Oo000000Oon>B5o`000?l0003ol_:mo`000?oGl^?o000000;oe^OR00Go0000okgAjOnmdNWo_M7Y
o`000002okKLl`03o`000?nW`NcoYl7/00?o00000_nS_^d00ol0003oU[G]oiJek@05oiJekA_o0000
00CoL9_[o`000?mYUn[o00000omWUNT00ol0003oHI7Yof6Aj@05o`000004oeR<iol0003oFHcWoeV<
i`Go00000_m;P^D01_l0003o?7WRocaih_llNN;o0000ocQfh0?o000000Co:VgMo`000?l0003o5UoF
0_l000002?l=F]?o0000o`18bOl0B<Wo04G6o`0g_?l09k7o01NS0_l0000<oookJP03o`000?oonf[o
oo]Z057ooo]Z00?o0000oookJ_oonfX05?oonfX001Kooo]Z00?o0000oookJ_oonfX0P_oonfX00ol0
003ooo]ZoookJP2coookJQ3o00000_oFin82o`000003okgAjOl0003o000000Co]]cc0_l00006oj>n
k@Co00001?nC/nd2o`0000GoQjg^00?o0000ognVkOmoY^d00omoY^d2o`0000KoN9o[00?oL9c[o`00
0?m_V^/00_m_V^/9o`000003of6AjOl0003oGhoX00;oGhoX1Ol000001OmIS>Oo0000odn5i_l0003o
BX7T00?o000000Go?WWQocaih_llNN;o?7WRo`000003oc5agP04o`000?lZKMgo:VgMo`0000;o5UoF
00?o0000o`eJdol000000_l0B<T01?l0ALKo03Nlo`0IYOl05j<2o`0000_ooo]Z00?o0000oookJ_oo
nfX0DOoonfX00ol0003ooo]ZoookJP0DoookJP005OoonfX00ol0003ooo]ZoookJP23oookJP03o`00
0?oonf[ooo]Z0;Cooo]Z2ol000001oojijco0000o`000?l0003oin[Ao`000?o?j>P00_l00004okKL
l`04o`000?nfc>[o]/cZo`0000;oXkk]0ol00002oinkk@03o`000?nC/ngoTk?]00GoTk?]2ol00000
0omoY^go0000o`000006o`000004ogROjol0003oKi[[ofnJj`;o000000CoKi[[o`000?mYU^Wo0000
0omWU>T4o`000005oen?j?l0003o0000oeV;iol000000_mGR>D4o`0000CoBX7T00Co0000ociihOln
NN7o?WWQ0_l00002oc5agP0?o`000?l[K=co:VgMo`000?lIH=Ko5UoFo`000?lFGmKo15C@o`19bOl0
B<Wo0474o`15a_l0003o01VU00?o00002_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[o
oo]Z01Cooo]Z000EoookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oookJ_oonfX0]OoonfX;o`00
0005ooW]Y_l0003oin[Ao`000?oPimP00_l000000onfg??o0000o`000006okK<jP;o00001_nO^nd4
o`0000CoS[;_00?o0000ohBYkOn4ZNd01?n4ZNd01Ol0003oOZG/ogjUk?mnYNco000000;oOjC[00?o
0000ogNNjomgW^/00omgW^/00ol0003oKiWYofnIj@02ofnIj@Co00000_mWU>T2o`0000;oHY3X00Oo
0000of>@iomST>OoHi3Wo`000?mIRnOo000000CoEhSU00?o0000odZ1i?m:PN@00_m:PN@5o`0000;o
>WKP00Ko<G7No`000?l[K=co:fcLobY]gOl00002oaUPeP06o`000?lFGmKo15C@o`19bOl0B<Wo0474
0_l0:;800ol06JGo0000o`00000:oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0
5?oonfX001Gooo]Z00?o0000oookJ_oonfX0PooonfX00ol0003ooo]ZoookJP2eoookJPWo000000?o
n]]ho`000?oikJH00_l000000ooPimSo0000on7ff002o`0000Co]/cZ0ol000001?n`an_o0000oink
kOnO^nd3o`0000;oW;W/00?o0000ohjbkon>/^l01On>/^l00ol0003oQ:W]ohBYk@02ohBYk@go0000
0_mgW^/2o`0000KoKiWY00?o0000ofRCiomXTnL00_mXTnL00ol0003oHY3Xo`000005of>@i`Co0000
00?oEhSUo`000?m<PN<00om:PN@01?l0003oAgkRo`000?m0NN43o`000003oc=bg_l0003o000000;o
:fcL0_l000002?lIH=Ko4e_Coa=KdolFGmKo0000o`19bOl0003o04740_l0:;83o`0000Wooo]Z00?o
0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX00ol0003ooo]ZoookJP23
oookJP03o`000?oonf[ooo]Z0;Kooo]Z2?l000001_ojfgSo0000o`000?l0003oh>OHo`0000;ohOKH
00Co0000olKKjOl0003o]/cZ0_l00005ok37j`;o00001_nL^N`01_l0003oS[;_ohjbkon>/^oo0000
ohjbk`Ko00000on6Z>/01?l0003oOJ?[ogfSjol00003ogfSj`04o`000?mgWN[oMigZogNMjPKo0000
0om_VNT00ol0003oJ9?WofRCi`04ofRCi`Co00000_mST>L01?l0003oEXOUoeJ7iOmFQnD3o`0000?o
C87S1?l000000om0NN7o0000od1ih@02o`000004obe/fol0003o0000o`0000;o767F00Wo6F3Foa=K
dolCFm?o0000o`1:bOl0003o0474o`0[]?l0:;800ol00009oookJP03o`000?oonf[ooo]Z05;ooo]Z
00?o0000oookJ_oonfX04ooonfX001Gooo]Z00?o0000oookJ_oonfX0PooonfX00ol0003ooo]Zoook
JP2foookJP[o000000?omO6Xo`000?l000000_oQm]P2o`000003olKKjOl0003o000000?o/<O[0_l0
0003oj_4k003o`000?nL^NcoW;W/00GoW;W/0ol00002ohb`kP03o`000?n>[nco000000OoQZS[00?o
0000ogfSjol000001?mmXn/01ol0003oMigZogNMj_mgWN[o0000ogJLjOl000000om_V>P7o`0000;o
J9?W00Co0000oen=i_mOSNKoGhgV1_l000000omFQnGo0000oe>4i004o`0000;oB7gR0_m2NN42o`00
00;o@7WQ0_l00002obe/f`04o`000?lLHMKo767Fo`0000;o4e_C00Ko0000o`1:bOl0003o0474o`0[
]?l0:;83o`0000Wooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0CoookJP005Ooo
nfX00ol0003ooo]ZoookJP23oookJP03o`000?oonf[ooo]Z0;Kooo]Z00?obEL0o`000?l000002Ol0
0002on7ff005o`000?o?nn?o0000o`000?noen/00ol00007oj_4k0Co00000onI]^`01Ol0003oS;3^
ohb`k_l0003oS;3^00Wo000000?oQZS[o`000?l000003Ol00004ofnHj0;o00000omXT^L6o`0000;o
GhgV0_l00003oeN6i0?o00000_m=P><4o`000003od9ihOl0003o?WKN00?o000000_o;V_Ko`000?l]
K=_o0000obIVfOlLHMKo0000oaAJdolCFm?o0000o`1;bP02o`12a003o`000?l0:kCo000000?o0000
2?oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01?ooo]Z000EoookJP03o`000?oo
nf[ooo]Z08?ooo]Z00?o0000oookJ_oonfX0]ooonfX00oo9E`3o0000o`000008o`000004on7ff?l0
003oco_Solokh`?o00000_nghoD00ol0003oZlC/oj_4k003o`0000?oY/3/00?o0000oiVfk?nI]^`0
1?nI]^`2o`0000;oRZk]00Go0000ohb^k?n<[^coS:k/o`000006ohFVjP03ogbRjol0003oO:7Z00?o
O:7Z00Go0000ogJLjOmfW>WoMYcYo`000002ogJKj0So00001?mXT^L2o`0000?oH8cU1?l00003oeN6
i006o`000?mDQ>?o0000o`000?m=P>?o00000_m9ON400ol0003o@WWQo`000002ocifgP04o`000?l^
Jm_o;V_Kobi[f`;o000000Co7f;Go`000?l0003o55[C0_l000001?l0Bl[o04;4o`12a?l0;KH4o`00
00Sooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0CoookJP005OoonfX00ol0003o
oo]ZoookJP23oookJP03o`000?oonf[ooo]Z0;Sooo]Z2_l000001OoQm]Soco_SolokhooDknGo0000
00Go]n?e0_l00007ojK0k0?o00001?nF/n`01?l0003oRZk]ohZ^kOl00002ohb^k0So000000?oQJKZ
o`000?l000000ol000001OmlXN[o0000ogJLjOmfW>Wo000000?oMY_X00Go0000ofnGj?m_UnSoKiOX
o`000002ofjEi`Oo00000omPS>D00ol0003oGX[Toej:i002o`000003oeN6i?l0003oE8CS00?oCX3R
00?o0000odUmhOm9ON400_m3N^02o`0000;o?WKN1?l000001?l^J][o0000o`000?lFF]82o`000004
o`]Bc_l0003o04;4o`12a0Ko00001ooonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z
01?ooo]Z000DoookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oookJ_oonfX0^_oonfX9o`000004
olokhol0003oe>oUo`0000Go]n?e0_nhc^X00ol0003oY/3/ojK0k003o`0000;oXKc/00?o0000oiJc
k?nF/n`01OnF/n`5o`0000;oR:[/00?o0000oh:Ujon2YN/01?n2YN/00ol0003oNYkYogZNj@02ogZN
j@_o000000GoKiOXo`000?m^UNOoKYGWo`000003ofRAiP03o`000?mVSnGoIXoU00;o000000GoH8cU
o`000?mNR^CoGX[To`000002oeR6h`?o00000_m>P>802_l0003oCWoQo`000?l0003o@g[Po`000?ln
M=ko0000ocifg_l00002oc1/fP;o000000?o;V[Jo`000?l000000_lFF]800ol0003o0dg;o`==b`02
o`12a0Ko00001_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01?ooo]Z000Doook
JP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oookJ_oonfX0^_oonfX:o`000003omC_iOl0003o0000
00;o]n?e1_nhc^X2o`0000KoXKc/1?l00004oi6ckP;o00001On8Z^`00ol0003oPZG[oh:Uj`03oh:U
j`;o00001_mjW^T00omfVnSo0000ogFJj003ogFJj003o`000?m_U^OoKiKW00Ko000000GoJ97Vo`00
0?mVSnGoIXoUo`000002of6<i@?o000000CoGX[To`000?mHQ^?o00000_mIQ^<00ol0003oCX3Ro`00
0004odioh@;o00000_lnM=h2o`0000;o<6cJ0_l/ImP01?l^J][o65[AoaQJdOlFF]82oaAHd@03o`==
bol0@/Co04;400Ko00001_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[ooo]Z01?ooo]Z
000DoookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oookJ_oonfX0^_oonfX9o`000004on;af?l0
003og_gCo`0000Co^<kZ0ol000001?nab>_o0000oj6lk?nQ_>`3o`0000?oWKW[00?o0000oi6ck_nA
/nh01?nA/nhKo`000004ogFJj?l0003oKiKWo`0000?oKYCV00?o0000ofRAi_mXTNH01Ol000001?mQ
S>Go0000oej9i?mNRN@6o`000003oeV6hol0003o000000?o000000?oCWoQo`000?loM=d00ol00000
1?liL=co0000oc1/f_l00002obaWf008obiZf_lHF]7o65[AoaIJd_lDF=7o0dg;o`000?l0@/@7o`00
00Gooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0CoookJP005?oonfX00ol0003o
oo]ZoookJP23oookJP03o`000?oonf[ooo]Z0;_ooo]Z1_l000000oo/lIOo0000o`000002omkmd`03
olGOk?l0003o^<kZ00;o00001Onab>/2o`0000OoWKW[0ol00003ohj`k@;o00001_n9YnT00ol0003o
PJ?Zoh6SjP02oh6SjP03o`000?n2X^So000000KoNikX00?o0000ogFHi_meV>H00_meV>H7o`000004
ofjDi_l0003oJ97Vo`0000?oIXoU1?l000001OmNRNCo0000oeV6homIQ^?o000000;oEh?Q0ol00003
od]kg`?o00000oloM=d2o`000003oc9/f_l0003o000000;o;6OH00Go0000oaQJdOlHF]7o0000oaAH
d@02o`000003o`12a?l0003o000000Co00001OoonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oo
nf[ooo]Z01;ooo]Z000DoookJP03o`000?oonf[ooo]Z08?ooo]Z00?o0000oookJ_oonfX0_?oonfX7
o`0000;og_gC00Co0000olGOk?l0003o00000onab>/3o`0000;oZl?/00?o0000oifijonM^N/00ol0
0003oiZej`05o`000?n>/>goS[3]ohj`kOl000000_nA[n/01?l0003oRJOYohVWjOn9YnT2o`000003
ohVWjOl0003o000000Wo00000_mkW^P00ol0003oMISVogFHiP04ogFHiP;o00000om^T^D7o`000004
ofJ?iOl0003oHH_To`0000?oHX_S00?oFHKSo`000?mGPn401?mGPn401_l0003oBg_Ood]kgom;Nmoo
0000odMhgP;o0000017o?gCMo`000?loLmco?g?Lo`000?l]I]Oo0000obaWf?l0003o6e_BoaQJdOl0
003o4eC?o`000?l0@/Co0000o`0j_`06o`0000Cooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003o
oo]ZoookJP0BoookJP005?oonfX00ol0003ooo]ZoookJP23oookJP03o`000?oonf[ooo]Z0;cooo]Z
1_l00002omkmd`03ol?ngol0003o000000;o_MS]0ol00006oj_3k0;o00001onJ]N/:o`0000?oR:KX
00Co0000oh6RjOn1X^Wo00000on1XNP01?l0003oNicWog^LiomkW>L7o`0000?oMISV00?o0000ofjB
iOm^T^D00om^T^D2o`0000?oIhgS1Ol00003of:;h`Co00000_mGPn400ol0003oC7_Ood]kg`02od]k
g`04o`000?m1M=go@GCMod5dg@;o000000Go?g?Lo`000?l0003o0000obeVe`02o`000005oa]Kd_l0
003o0000oa=Dcol000000_l0@/@7o`0000?ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]Z
oookJP0BoookJP005?oonfX00ol0003ooo]ZoookJP23oookJP03o`000?oonf[ooo]Z0;gooo]Z1Ol0
00001OoNoM?o`okOol?ngol0003o_MS]00;o000000Co/^?go`000?n[`ncoZl?/0ol00003ojFok003
o`000?nJ]N_oV[G[00?o00000_nG/^X01?l0003oS:g/ohb]k?l00003ohj]j`03o`000?n8Y^SoR:KX
00CoR:KX00?o0000oh6RjOl000001?n1XNP00ol0003oNicWog^Li`02og^Li`;o00001?mdUnH5o`00
00CoKY;U00?o0000ofN=homWSN<01?mWSN<01Ol0003oGhORo`000?l0003oHX_S00;o00000_mFP^04
o`0000?oC7_O0_l00002od5dg@;o?W3K00Co0000ocmcg?l]IMKo;FGF0_l000001OlUH=Co0000oaAD
c_lDE<ko000000;o04C500?o04;4o`000?l000001Ol00003oookJP03o`000?oonf[ooo]Z05;ooo]Z
00?o0000oookJ_oonfX04_oonfX001Cooo]Z00?o0000oookJ_oonfX0PooonfX00ol0003ooo]Zoook
JP2noookJP?o000000Cog_gCol?ngoo3o]ood?GX0_l00004ok;Sm`;o00001onU_n`2o`0000KoUk;Z
00?o0000ohb]k?l000000_n>[N/8o`000003ohRVj?l0003o000000co00001OmdUnH2o`0000?oKY;T
00?o0000ofjBiOl000000_l00004ofN=h`03o`000?mOQn;oGhOR00;oGhOR0ol00003oeJ2h0Co0000
00KoC7_Oo`000?m8N=go0000od5dgOl00003oci`f`05o`000?l]IMKo;FGFobeUe_l000000_lNG=83
oaADcP;o04C52?l00002oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX04_oonfX0
01Cooo]Z00?o0000oookJ_oonfX0PooonfX00ol0003ooo]ZoookJP2noookJPCo00000_o@mNP00ol0
003o/^?gok;Sm`02ok;Sm`04o`000?nec>co]Lc/o`0000;oYKo/0ol00002oj6jj`03o`000?nG/^[o
Uk;Z00GoUk;Z1Ol00002oh^ZjP03o`000?n5YNWoQJGY00GoQJGY00?o0000ogjNiomnW^L00omnW^L0
1?l0003oNY_VogZKi_l00002ogZJiP_o00000_m^T^@2o`0000?oIhcS1_l000001omOQn;o0000oef5
hOl0003oEh7Po`000?mFP^000_l00002odikgP?o00000_m3M=`2o`0000;o?W3K0_l`I]H2obeUeP04
obaTe_l0003o7UcBoaIDcP;o55C>00Go0000o`14aOl0003o0000oo^`EP05o`0000;ooo]Z00?o0000
oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0BoookJP004ooonfX00ol0003ooo]ZoookJP24oook
JP03o`000?oonf[ooo]Z0;kooo]Z1?l000001?oLmmgo0000ok;SmonbhoL2o`0000Go]Lc/0_l00006
oj6jj`Co00001?nB/^d00ol0003oRj[Zoh^ZjP04oh^ZjP03o`000?n5YNWoQJGY00CoQJGY00?o0000
ogjNiomnW^L01?mnW^L00ol0003oNY_Vo`000004ogZJiP04o`000?mdU^GoM9KUo`0000;oLiCT00Co
0000ofjAi?m^TNCoKY7T1?l00003ofN<h`03o`000?mUR^;o000000;oH8OQ1Ol00002oeN1h0?o0000
0_m>Nmh02Ol0003oCG[Mo`000?m3M=co0000oci_f_l0003o?W3Ko`000002oc1VeP03obeUe_l0003o
;6CF00;o000000Co5UC>oaADc_l0003o0TK60_l000000ook/5Ko0000o`000003o`0000?ooo]Z00?o
0000oookJ_oonfX0DOoonfX00ol0003ooo]ZoookJP0BoookJP004ooonfX00ol0003ooo]ZoookJP24
oookJP03o`000?oonf[ooo]Z0;kooo]Z00?o0000o`00>ol000001Ol00003okG<k0;o00001?n^a^`3
o`0000CoWKOZ00?o0000oi:bkOnB/^d01?nB/^dNo`000003ogBFiOl0003oLiCT00;oLiCT00Ko0000
ofjAi?m^TNCoKY7To`000?m]Sn<8o`0000;oH8OQ00?o0000oef4h?mMQ>000_l000001omGPN3o0000
oeAng_mDO]ko0000odikg_l000000om=N]d2o`0000;o?VoJ0_l00002oc1VeP;o000000Co;6CFoaQC
cOlHDlgo5UC>1?l000000ook/5Ko0000o`000004o`0000;ooo]Z00?o0000oookJ_oonfX0DOoonfX0
0ol0003ooo]ZoookJP0BoookJP004ooonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z
0;kooo]Z00?o0000o`00C?nZC`000ol000001?nng^oo0000o`000?l00003ojk6k0?o000000?oYl3/
o`000?nM]nX01_nM]nX3o`0000?oSjo[0_l00006oh^Vi`03o`000?n4XnSoQ:?X00;oQ:?X00?o0000
ohFRiol000001_moWNH00ol0003oMiOTogNGi004ogNGi0;oM9GT1_l000001Om^TNCo0000off?hom]
Sn?o000000?oIhcR00?o0000ofF9hOmURN400_l000001?mPQn7o0000oef4h?mMQ>03oeR1g`03o`00
0?mDO]koE7kN00;oCg_N0ol000000om=N]go0000ocm_f@03o`000007ocQ[eol0003o<6KFo`000?l[
HM?o0000obaTeP02oaQCc@03o`000?lCD<_o000000Go000000?olZ0bo`000?l000000_oonfX00ol0
003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z017ooo]Z000CoookJP03o`000?oonf[ooo]Z08Co
oo]Z00?o0000oookJ_oonfX0__oonfX00ol0003o001<o`000004o`0000;o/NSh00Co0000ojk6k?l0
003o00001OnW`>`4o`0000CoV[?Y00Go0000ohn_jon?[n_oSjo[o`000002oi:^j@04o`000?n;Y^Oo
RjKWoh^Vi`;o000000?oRjKWo`000?l000002_l000001?moWNKo0000o`000?mgUn@3o`0000;oMiOT
00?oM9GTo`000?mcU>@00omcU>@2ofj@h`Go00000_mWS>801?l0003oIHWQofF9hOmURN42of66h@Co
00000_mHPMl01_l0003oF83No`000?l0003oCg_No`0000;oBgOL0ol00003ocm_f@;o000000?o<VOF
o`000?l000000_l[HM<00ol0003o65?=oaQCc@03o`000003oofmKol0003o000000Go000000?ooo]Z
o`000?oonfX0DooonfX00ol0003ooo]ZoookJP0AoookJP004ooonfX00ol0003ooo]ZoookJP24oook
JP03o`000?oonf[ooo]Z0;gooo]Z00?o0000o`00;?l000001?l00004ok7Xn004o`000?nW`>coYl3/
ojO0k0?o000000?oXk_[o`000?nJ/nT01onJ/nT:o`0000?oRjGV0on3X^L01Ol0003oQ:7VohBQi_n4
XNKo000000GoOYcU0_l00004ogVGi0?o000000CoLiCTo`000?l0003o00000_mcU>@00om^T>?o0000
ofn?hP02ofn?hPOo000000?oIHWQof66hOl000000omQQMl00ol0003oF87Oo`000004oeR0gP;o0000
0_m;Mm`01Ol0003oAW?Jo`000?l0003o?foI00;o?VgH00Go0000obaQdol/HM?o0000ob]Qd`02oa]D
c@05oaQCcOl0003oo<F5o`000?om_Fl01ol000000ooonf[o0000oookJP1CoookJP03o`000?oonf[o
oo]Z017ooo]Z000CoookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX0_OoonfX00ol0
003o000/o`00G@05o`000003ok7Xn?l0003o]/k/00;o]/k/0_l00005oj>kj`03o`000?nJ/nWoV[?Y
00?o00000_nG/>P3ohj/jP05o`000?n?[>WoSjcYohn/jOl000001_n;YNH00on3X^Oo0000ohBQiP04
ohBQiP05o`000?mnW>GoOYcUogjLiOl000000_mnVn@00ol0003oNIOTogVGi003ogVGi003o`000?mc
T^;oLi;R00;oLi;R1ol00002ofn?hP;o00000omVR=l4o`0000CoHHGO1?l000001omHP=ko0000odaf
fol0003oBgOLo`000?m6LmX00om1KmT01?l0003o?VgHoci]f?l00003obaQd`09o`000?lKE<go6eC=
o`000?olaHGo0000oofmKol0003oo[e]00Oo0000E?oonfX00ol0003ooo]ZoookJP0AoookJP004ooo
nfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z0;gooo]Z00Co0000o`00;?l0003o001M
1?l00003okK>k003o`000?n^anco000000OoXk_[0_l00006oiN`j004ohj/j_l0003oSjcYohn/j@Wo
000000?oRjGVo`000?l000003ol00002ogVGi0;o00001_mcT^801?l0003oKHgQoff=hOm]SN44o`00
00GoIXSO00Co0000oej2g_l0003o00000_mQQMl01?l0003oEWcLoeIlg?mFO=`3o`0000;oC7KK0ol0
0002od5_f@;o?F_F00?o?VgHo`000?l]Gm800_l/HM<00ol0003o9E[?oa]Dc@05o`000003oojmKOl0
003o000000Go0000E?oonfX00ol0003ooo]ZoookJP0AoookJP004ooonfX00ol0003ooo]ZoookJP24
oookJP03o`000?oonf[ooo]Z0;cooo]Z0ol000001?l0053o0000o`00Nol005l3o`0000Go[/O/1?l0
0004oijgjP03o`000?nG/>SoUk3X00CoUk3X1?l00003ohbXj003o`000?n8Y>OoR:CW00CoR:CW0_l0
0005oh:Mi@?oOY_T00Go0000ogfJi?mmV^CoOI[To`000003ogVFh`Ko00000_mcT^800ol0003oLXoQ
o`000004off=h@;o000000?oIXOOofJ8gomVR=l00_mVR=l00ol0003oGX;Noej2gP02oej2gP?o0000
0omFO=`3o`000007odaffol0003oBgGJod]ef_l0003o@FoIo`000002oce[eP07oci]f?l0003o;EoB
obaQdol0003o9E[?oa]Dc@03o`000003oog6Q?l0003oo[e]00Oo0000E?oonfX00ol0003ooo]Zoook
JP0AoookJP004_oonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z0;gooo]Z0ol00000
0ol0053o001co`00F@03o`000004o`00MOl0003o0000o`0000?oZ<7/00?o0000oijgj_nN]nX01OnN
]nX3o`0000CoTZo[00?o0000ohbXj?n<Z>P01?n<Z>P00ol0003oR:CWohRTi`02ohRTi`03o`000?n7
X>Co000000Go000000?oPYgUogjKi?l000001OmmV^@01ol0003oNIKSogVFhomiU^?o0000ogRDh_l0
00000omcTN47o`000004off=hOl0003oJh_Oo`0000?oIXOO1Ol000000omNP]ko0000oeaog002oeMl
g003oeIlg?l0003oDWWK00?oCGKJ0_l000000om;MM[o0000od9_f002o`0000;o?F_F00?o0000obeO
d_l]Gm801?l000000oohcj3o0000oog6Q002o`000004oojnJol0003o0000ooVaC0?o0000E?oonfX0
0ol0003ooo]ZoookJP0AoookJP004_oonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z
0;gooo]Z0_l000001Ol005co0000o`000?l006So001k00;o000000?o0028o`04S?l000001OnX`N`4
o`0000?oVk?Y00?o0000oi:_jonB[n/00onB[n/?o`000003ohNQiOl0003oPYgT00?oPYgT4?l00003
og>Ah@03o`000?mbSn3o000000?oKHcP1_l000001?mVQmoo0000ofB5g_l00002oen2g@Co00000_mG
O=`3o`0000;oCGKJ00?o0000odYbf?l000000ol000002OlmJMGo0000oce[e_l0003o<67AobeOd_l0
003o;5k@o`000002ooS?X0;o000000?oo/N3o`000?on_V/00_l000000ooi/Dco0000o`000002o`00
05?ooo]Z00?o0000oookJ_oonfX04OoonfX001;ooo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0003o
oo]ZoookJP2loookJP?o000000Oo001Lo`00HOl0003o0000o`00J?l007_o002>00;o000000Co00B<
o`000?l0003o00000onS^nX00ol0003oVk?Yoi^cj@04oi^cj@Ko000000?oTJcXo`000?n=YND01_n=
YND01?l0003oQj;VohNRi_l00003ohNQi@03o`000?n2WNCoPYgT00?oPYgT00?o0000ogfHh_mmV>80
1?mmV>800ol0003oNIKRo`000003ogJBh@So00000om]S>000ol0003oJh[OofN7gP02ofN7gPGo0000
0_mOP]d01_l0003oGh7Lo`000?l0003oEgcLo`0000;oEW_K00?o0000odeff_l000001?m:L]P01?l0
003o?FWEoceYeOlmJMD2o`000007oc1QdOl0003o0000o`000?ohcj3o0000ooWAX006o`000003ooVa
C?l0003o000000;o0000E?oonfX00ol0003ooo]ZoookJP0@oookJP004_oonfX00ol0003ooo]Zoook
JP24oookJP03o`000?oonf[ooo]Z0;cooo]Z0ol000003?l005co001Qo`000?l007Oo001ao`00Nol0
07;o002>o`00K?l007Go00B<o`0000GoXk_Z0ol00004oiV`j0;oT:cY00?o0000oi6/j?nA[>P00_nA
[>P00ol0003oSJGUohfUi@02ohfUi@;o000000?oSJGUo`000?l000003ol00003ogfHhP03o`000?mf
T^7oMY;Q00?oMY;Q0_mcTN401?l0003oLHoPog6?h?maSn05o`0000;oJh[O0omWQmh00ol0003oIhKM
ofN6g@02o`000004oen2gOl0003oGh7Loen1g0Co00000_mFNm/3o`0000?oBW;H0_loJ]@2oceYe@;o
>fOD00Oo0000obYJc_lZF/ko0000ooS?X?l0003onM6P00co0000DooonfX00ol0003ooo]ZoookJP0@
oookJP004_oonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z0;_ooo]Z0ol000002ol0
05Oo0000o`00HOl006Go0000o`00LOl008co001bo`00S_l0003o00JG00Go00000_nO]^T00ol0003o
VK3XoiV`j005oiV`j0_o00000on;Y>D00ol0003oQIkSohFNh`03ohFNh`03o`000?n1W>?oPIcS00;o
PIcS00?o0000oh6Jh_l000001?mmUn43o`000004ogJBhOl0003o0000o`0000;oMY;Q00?oLi7Qo`00
0?maSn000omaSn02off<g`03o`000?m^Rmko000000;o000000?oIhONo`000?mWQ]d00omWQ]d02Ol0
003oH8;Mo`000?l0003oGh7Lo`000?mGO=co0000oeAhf@02o`000003oeIkfol0003oBW7G00;o0000
00?oBW;Ho`000?loJ]@00_loJ]@01ol0003o>fODo`000?laHM7o0000oo;D/Ol000000_oidJ001?l0
003on]:Oo`000?onc8T2o`000003oojoI_l0003o000000?o0000DooonfX00ol0003ooo]ZoookJP0@
oookJP004_oonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[ooo]Z0;[ooo]Z1?l000001Ol0
05Oo0000o`000?l006oo002300?o000000Go002>o`000?l0003o00JGo`0?VP02o`0000CoWkKY1?l0
0003oi>_j@03o`000?n?Z>KoSjSV00CoSjSV00?o0000oh^TiOn;Y>D01?n;Y>D00ol0003oQIkSohFN
h`04ohFNh`04o`000?n1W>?oPIcSo`0000?oPI[R00?o0000ogfGhOmmUn400ommUn400ol0003oN9;P
ogRBh002ogRBh0So000000?oLHoPoff<gol000001?m^Rmh5o`0000;oIhKM0_l000000omMO]_o0000
o`000002o`0000CoE7SI0_l00003odYae`;o00000_loJ]@2oc]UdP04oc]We?l0003o0000oo;D/@?o
00000_ojdYl00ol0003oo/b9o`000008o`0005;ooo]Z00?o0000oookJ_oonfX04?oonfX001;ooo]Z
00?o0000oookJ_oonfX0Q?oonfX00ol0003ooo]ZoookJP2joookJP05o`000?l002;o0000o`000?l0
05L00_l000001Ol006oo0000o`00O_l0003o002;00;o000000Co002=o`0=WOl0003o00nJ0ol00002
oibbj003o`000?nC[nWoTjoY00CoTjoY00?oTj[Vo`000?n?Z>H00_n?Z>HKo`000004ogfGhOl0003o
O9GPo`0000KoN9;P00?o0000og:=g_mbSMh00_mbSMh6o`0000;oKX_N00Co0000ofF3g?mUPmcoIH?L
0ol00005oeenf`03o`000?mDN=WoE7SI00;oE7SI00?o0000odaaeom<LML00_m:LML01Ol0003oAVgE
o`000?loJ]Co000000;o>fGB00?o0000oo;D/Ol000000_oce[401_l0003on]:Oo`000?oje9ko0000
ooo=QPSo0000D_oonfX00ol0003ooo]ZoookJP0@oookJP004_oonfX00ol0003ooo]ZoookJP24oook
JP03o`000?oonf[ooo]Z0;[ooo]Z1_l000000ol007co001_o`000003o`000007o`00Rol02Yco002=
o`000?l03Igo0026o`0?VP03o`0000;oW;;X00Go0000oi>_jOnC[nWo0000oi>_j@06o`0000?oSjGT
00?o0000ohVRi?n9X^@00_n9X^@00ol0003oRZ7So`000006ohFMhP03o`000?n2Vn;o000000CoOiSQ
00?o0000ogbFhOmlU^403?l00005og:=gP04o`000?m/R=goK8SMofb8g@?o00001OmUPm`00ol0003o
GWkJoeenf`03oeenf`03o`000?mEN=SoE7SI00;oE7SI0_l00002odaae`03o`000?m6KMGoAVgE00;o
@F[D0_l000001?lkIM;o0000oo;D/Ol00002oo?F/@08o`000?ojdYoo0000oo[DW_l0003oolf6o`00
0?oocXD6o`0005;ooo]Z00?o0000oookJ_oonfX04?oonfX001;ooo]Z00?o0000oookJ_oonfX0Q?oo
nfX00ol0003ooo]ZoookJP2hoookJPOo0000013o001/o`00O?l0003o001io`05TOl008Co001ko`00
Rol0003o00ZLo`000?l008Go0000o`00Q_l0003o02N[0_l00002oibbj0;o000000?oU:gWo`000?nB
ZnL00_nBZnL00ol0003oSjGTohnUi004ohnUi004o`000?n9X^CoRJ;To`0000?oRZ7S00?o0000ohFM
h_n5WN801?n5WN800ol0003oOiSQognHh@04ognHh@04o`000?mlU^7oO9KQo`0000;oNiCP00?o0000
ogNAgomgTMl00_mgTMl00ol0003oMXoNo`000003o`000004og:=g_l0003oL8_Mo`0000CoK8SM1?l0
00001?mUPmco0000of>1f_l00003oeinfP?o00000omEN=P3o`000003odaaeom;L=KoBg3F00;o0000
00Ko@F[Doc]TdOlkI=7o0000on_G_ol00002oo?F/@03o`000?odek7o000000;on]BN0_l00002ooo>
Q@Oo0000DOoonfX00ol0003ooo]ZoookJP0@oookJP004OoonfX00ol0003ooo]ZoookJP25oookJP03
o`000?oonf[ooo]Z0;Oooo]Z1?l000001Ol005[o0000o`00IOl0003o001/00;o000000co001io`00
0?l0003o0024o`00Rol0003o0028o`000?l008co0000o`00S_l06J@2o`000006o`0UZ_l0003oU[7Z
o`000?nD[NOo00000_nBZnL9o`000003ohnUi?l0003o000001So000000GoNiCPo`000?mgTMooMi7O
o`000002ogJ?gP04o`000?mbSMkoLXgNog:=gPKo000000CoK8SMo`000?mZQ]co00000_mVPm/4o`00
00?oGWkJ00Co0000oe]kfOmKNmWo00000_mEN=P01Ol0003oE7KHo`000?m<LMOo000000?oBg3F0ol0
0002on_G_`;o000000ColmJao`000?odek7o00000_oje9h2o`0000;oolj51ol0001AoookJP03o`00
0?oonf[ooo]Z013ooo]Z000AoookJP03o`000?oonf[ooo]Z08Gooo]Z00?o0000oookJ_oonfX0]ooo
nfX2o`000007o`00?_l0003o001Jo`00JOl0003o001fo`000002o`00Q@09o`00NOl0003o0000o`00
Q?l02iWo0000o`00SOl02Yco002<00;o000000?o002>o`0BWOl04Yd00ol000000onF/N[o0000o`00
0002o`0000?oTZKS00?o0000ohfTi?n=Y>@01On=Y>@00ol0003oR9kRohRNhP04ohRNhP07o`000?n5
W>;oQIcRohFLh_l0003oQ9[Po`000006oh2Gh003o`000?mkT]koNi;N00;oNi;N2Ol00003og:=gP03
o`000?m`R]goK8SL00;oK8SL1Ol00002ofJ3f`03o`000?mSP=[oHh3J00;o000000CoGWkJo`000?mK
NmWoFg_I0_mFN=P2o`000003oeAff?l0003oC77F00;o00000om;L=H01?lmI=3o0000on_G_ol00002
oncH_`04o`000?odek7o0000ooCH/@;o000000GonmFNo`000?l0003o0000ooo?Q006o`00057ooo]Z
00?o0000oookJ_oonfX04?oonfX0017ooo]Z00?o0000oookJ_oonfX0QOoonfX00ol0003ooo]Zoook
JP2foookJPGo000000Go001Jo`00JOl0003o001fo`000002o`00Q@?o000000Co0024o`00Rol0003o
002=1_l00002o`0BW@04o`0Y[_l08JKo0000o`0000OoTZKS00?o0000ohfTi?n=Y>@00on=Y>@2o`00
00CoR9kR1?l000000on5W>;o0000ohBJh002ohBJh003o`000?n0Un3oP9OP00?oP9OP00?o0000og^B
g_mkT]h01?mkT]h00ol0003oN97Oo`000003ogJ>g@Oo00000om/R=`00ol0003oK8KKofb6f`02o`00
0004ofJ3fol0003oHh3Jof>0fP?oGgkJ0ol000001?mKNmWoEWSHoe=de_mCM=H4o`000003odQ/dol0
003oBg3F00;o000000?ojmNoo`000?o/f;l00_o/f;l00ol0003om=Nao`000002ooCH/@06o`000?ok
eIko0000oocFWOl0003ooln41_l0001BoookJP03o`000?oonf[ooo]Z00oooo]Z000AoookJP03o`00
0?oonf[ooo]Z05oooo]Z1_l0000PoookJP03o`000?oonf[ooo]Z0;Gooo]Z1Ol000001_l005[o0000
o`00JOl007oo0000o`00P@?o000000Co0026o`000?l008oo002;0_l000002ol008So01RVo`000?l0
003o01VWo`00S_l06JCo01:Mo`0`]Ol0:Jko026V00?o00000onBY^<2o`000003oi:Vhol0003o0000
00Wo00000on8WN400ol0003oQI_Qo`00000>o`0000?oNi;N00?o0000ogJ>gOmfS]d00omfS]d00ol0
003oLXcMo`000003og29f`03o`000?m/R=co000000?oK8KK00?o0000ofJ3fomVPm/01?l00002oemn
fP06o`000?mNO=SoGWcHo`000?mFN=So00001?mCM=H01?l0003oB6cCodQ/dom8K=<2o`000006on_G
_ol0003ok=RooncH_ol0003ok=W00_l00002ooCH/@;o00000_oleYd2o`000003ooo@P_l0003o0000
00Co0000DOoonfX00ol0003ooo]ZoookJP0?oookJP004OoonfX00ol0003ooo]ZoookJP1KoookJPCo
00001?n8^_L4o`0001kooo]Z00?o0000oookJ_oonfX0]?oonfX7o`00000;o`00L?l0003o001oo`00
0?l0087o0000o`09S_l008_o0000o`0EVol008l00_l000001_l01YOo0000o`000?l06:Ko002<o`0O
[0;o000000Oo01VTo`0BWOl0003o02V^o`0QY_l0003o04?000?o00000onAY>84ohbRh`04o`000?n<
XN;oS:7Ro`0000OoR9gQ00?o0000oh>Hgon3V=l00_n3V=l00ol0003oP9KOoh2Fg`02oh2Fg`03o`00
0?moU=ko000000?oNi;N1_l00004ogJ>g@03o`000?m`RM_oL8WK00?oL8WK1Ol000001?m/Q]_o0000
ofJ3fol00003of=of@?o00001?mNO=P2o`0000?oDgCF0_m:KM<00om8K=?o0000om[He@02o`0000;o
k=Ro00Co0000oncI`?o/fL3o00000_odf;402?l0003omMZ`o`000?oleYgo0000oocHW?l0003oom22
1_l0001AoookJP03o`000?oonf[ooo]Z00oooo]Z000AoookJP03o`000?oonf[ooo]Z05Sooo]Z0ol0
0002ojW5k@03o`000?n8^_OoR;[g00CoR;[g0_l000000ol0F<_o0000oookJP0LoookJP03o`000?oo
nf[ooo]Z0;;ooo]Z2Ol000002Ol0073o0000o`00Ool0003o0021o`000?l02Hko0000o`00R`02o`0E
V`04o`02T_l06J?o00JGo`07V0;o01RV0_l000001?l07jco0000o`09VOl06J@2o`000003o`0Y[_l0
003o000000;o00001OnAY>82ohbRh`03o`000?n<XN;o000000Oo000000?oR9gQo`000?l000001?l0
00001On3V=oo0000oh2Fgon0U]oo000000?oOiCN00?o0000og^Bg_mkT]h00_mkT]h2o`0000CoMXgL
00?o0000ogJ>gOl000000_l00004og29f`04o`000?m[Q=[oJhCJof^4fP?o00001OmSOmT2oeaie`;o
00000_mNO=P02?l0003oE7?Eo`000?mCM=Ko0000odm_dom:KM?o00000ooJf=D2o`000004oncH_ol0
003ok=W0oncI`0;o000000Oom=Rao`000?oef[3o0000oocFWOl0003oo=RL00;o000000?oom60o`00
0?l000000ol0001AoookJP03o`000?oonf[ooo]Z00oooo]Z000AoookJP03o`000?oonf[ooo]Z05Go
oo]Z0ol00006ojW5k@?o00001?n8^oL4o`0001cooo]Z00?o0000oookJ_oonfX0/OoonfX6o`00000=
o`P0J?l0063o0000o`/0Mol0003o0@1no`000?lB4Xgo0000o`03ROl02Hko0000o`00R`02o`0EV`;o
000000Ko01VSo`000?l01iSo01RVo`000?l01YT3o`000004o`0[]?l0003o01>Oo`0c^0Wo000000Co
TJCRo`000?l0003o00000on;W^000ol0003oQicPohNLh003ohNLh0;o00001?n3Umh@o`0000GoMXgL
00Co0000og68fomaR=_oLHSK1?l00005of^4fP03o`000?mTOmSoHgoI00?oHgoI00?o0000oeaieomL
NML00_mLNML3o`0000;oE7?E0ol00003om[He@04o`000?oKfMGo0000o`0000;ok=W000So0000ongK
_oo]fkoo0000ooGJ/?l0003om]^`o`0000;oo=RL0_l000000ooodH3o0000o`000004o`00053ooo]Z
00?o0000oookJ_oonfX03ooonfX0017ooo]Z00?o0000oookJ_oonfX0D_oonfX3o`0000;o]/OW00?o
0000ojW5kOnYaNd00ol00002ojW5k@03o`000?n8^oOoR;_g00CoR;_g1?l0000JoookJP03o`000?oo
nf[ooo]Z0;7ooo]Z1ol000005?l806So0000o`P0M_l;07Oo0000o`40O_l0003o4Q:=o`000?l00hWo
0000o`/JVOl0003o00RCo`000?l04I_o00VHo`0IXol0003o00NH1?l000000ol07jco00jMo`000002
o`000005o`0CWol0<kSo0000o`000?l0BLL01?l00002ohnSh`03o`000?n;W^3oRikP00CoRikP00Go
0000ohNLh?n7W>3oQicPo`000002ohNJg`03o`000?n3UmkoPiON00CoPiON00?o0000ognCgOmoTmd0
0omoTmd01?l0003oNi7Mog^AgOl00002ogV>g0?o00000_mfSM`00ol0003oMH_Ko`000004og68f`03
o`000?m_Q]Wo000000;o000000CoJhCJo`000?mXPMSo00000omTOmP3o`0000?oG7WG00Go0000oeUf
eOl0003o0000oeAce@02o`0000?of]SE00?o0000om_IeOoKfMD00ol000002?o/fL3o0000ongK_oo]
fkoo0000ooGJ/?l0003om]^`0ol000001?omfI[o0000o`000?oodWh5o`00053ooo]Z00?o0000oook
J_oonfX03ooonfX0013ooo]Z00?o0000oookJ_oonfX0DOoonfX2o`0000Ko]/OW0_l00006ojW5k@?o
00001?n9_OP4o`0001Wooo]Z00?o0000oookJ_oonfX0/?oonfX8o`000003o`P0J?l0003o201f00;o
0000013o0@1no`000?lB4Xgo0000o`03ROl0003o2aZIo`000?l029?o0000o`0AVol0003o00VHo`00
0?l01iSo00000_l06ZL3o`000006o`0>WOl0003o0000o`0LYol0>koo03>h0_l000000ol0BLOo0000
o`00000Eo`0000?oPiON00?o0000ognCgOmoTmd01?moTmd2o`0000CoNHkL0omfSM`6o`000005og68
fol0003oKhKIofn6fOl000000_m[Q=T5o`0000;oI7oH00Ko0000of5leomMN]KoGG[Foeaieol00002
oeUfe@?oEG?E00Go0000om?Gg?l0003of]SEo`000002om_Ie@05o`000?oLfmKo0000onKJbOl00000
0_o]fkl00ol0003ok]boo`000002ooKK/004o`000?ogg:oo0000oogIVP;o000000?oom9no`000?l0
00000ol0001@oookJP03o`000?oonf[ooo]Z00oooo]Z000@oookJP03o`000?oonf[ooo]Z053ooo]Z
00?o0000okK7ionfanL00onfanL2o`0000;o]/OW00?o0000ojW5kOnYaNd00ol00003oj[5k@?o0000
0on9_OP4o`0001Sooo]Z00?o0000oookJ_oonfX0[ooonfX5o`000003oa40F?l0003o5P1]00;o0000
00So5`Ejo`P0M_l0003o0@1no`000?l:3H[o0000o``CT@?o000000So01:Ho`000?l0003o016Ko`00
0?l02ISo0000o`0DX@;o00000_l06ZL01Ol0003o02^do`0FYOl03Ygo03>k00;o000000?o03^oo`00
0?l0;[@00_l000000ol0@/;o0000o`000003o`0000KoRYgO00?o0000ohRKgol000001?n6V=h01?l0
003oPiONoh>Gg_n3Umh8o`000003ognCgOl0003o000000Co000000CoNHkLogJ=g?mfSMco00000omf
RmX00ol0003oLHSJog68fP03o`000005ofn6fOl0003oJhCIof^4fOl000000_mXPMP2ofEof0;o0000
0_mQO=L2oeejePCo000000?oEG?Eo`000?oCem`00_oCem`01?l0003ofmWEom_IeOl00003omcKeP;o
000000CokM^oo`000?o^g;ook]bo0ol00002ooOL[`;o000000?ooMZIo`000?oodWh01_l0001?oook
JP03o`000?oonf[ooo]Z00oooo]Z000@oookJP03o`000?oonf[ooo]Z04kooo]Z0_l00002okk8hP04
o`000?nfanOo0000o`0000Go]/OW0_l00003oj[5k@;o00000_n[aNd00ol0003oRkkhoh^nn003oh^n
n0Co00005ooonfX00ol0003ooo]ZoookJP2^oookJPSo000000Co5P1]o`000?lG1G[o5`Ej0ol00002
o`X=RP05o`000?l<4i7o0000o`0BUOl000000_l04YP3o`000007o`09V?l09Z_o01BQo`0CXOl02Y_o
0000o`0JY`02o`000003o`0[]?l05ZGo03>k00;o02>^00Wo0000o`0k_ol0003o0000o`1<b_l0003o
04;2o`000?l0GmD00ol00006ohZMg`03o`000?n6V=koQYSN00CoQYSN00Co0000oh>Gg_n3Umko0000
0_n2U=d00ol0003oOi;LognBg003ognBg0;o00001?mjS]/7o`000004ogJ;f_l0003oLHSJo`0000;o
KhGH1Ol00002ofR1f004o`000?mUOmSo0000ofAmeP?o000000CoGG[Fo`000?mLN=GoG7SE0_l00002
om?Gg005o`000?oCf=co0000om_IeOl000000ooLfmH01?l0003ogMcFomgLe_l00002onkL_`09o`00
0?o_g;kokmbno`000?ogg:oo0000ooOM[ol0003ooMZI00So0000D?oonfX00ol0003ooo]ZoookJP0>
oookJP004?oonfX00ol0003ooo]ZoookJP1<oookJP;o00000_nob>801?l0003o_/SRo`000?l00004
okK7i`;o00000_nganH01?l0003oZ/G]o`000?l00005oj_5k@?o00000_n=_oP2o`0000;okY9>0ol0
000DoookJP03o`000?oonf[ooo]Z0:gooo]Z1ol000001?lV1g;o0000oaH0KOl00002oaL5NP03o`00
0?lH3hGo000000;o2Pf:00Co0000o``CTOl0003o01:E0_l000003?l04YSo0000o`<NX_l0003o01:M
o`000?l09Z_o0000o`0CXOl0:[7o01ZWo`0000;o032g00?o01n/o`0FYOl0<k/00_l08jh02ol0@<?o
0000o`0c^Ol0003o04c:o`000?l0@/;o0000o`1OeOl0003o05S@01?o000000?oPYCMo`000?moT]`0
0_moT]`01?l0003oOI3Kogf@fol00005ogZ>f`03o`000?meRMWoMHWI00;oMHWI0ol00004ofn5f004
o`000?m/Q=WoJH3GofV0e`?o000000?oIGoHo`000?mTOMH00omTOMH4o`000004ol;Ciol0003odmOL
o`0000?odmSL00Go0000omcKe_oLfmKog=_Fo`000002omgLeP05o`000?oNgMGo0000onkL_ol00000
0_o_g;h01?l0003ommb_o`000?oggJl2o`000003ookKV?l0003o000000Go0000D?oonfX00ol0003o
oo]ZoookJP0>oookJP004?oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?nob>;o_lSR00?o_lSR
0_l000000onnb>;o0000okK7i`02o`0000Go]lOV00?o0000oj_5kOn[aNd00_n[aNd2o`0000;oZlG]
00Co0000ohfon?n=_oSoSKoh0ol000000oo^TTko0000o`000002o`0001?ooo]Z00?o0000oookJ_oo
nfX0ZooonfX6o`00000<obD0H?l0003o9PMbobH7L_lF06go0000ob@?OolG1G[o0000oalBQ_l0003o
:b6A0_l000000olL7iKo0000o`dHUP02o`00000>oaXWXOl0003o01FKo`<NX_l?:ZSo01:Mo`000?l0
9Z_o0000o`0CXOl0003o02Zao`000?l06:H2o`0`]`0;o`0O[?l0>Kko03>ko`0S[_l0003o0433o`00
0?l0<kWo04o=o`000?l0ALD01ol000001On9W=oo0000ohVJgOn9V]go000000KoQYOM00?o0000oh:C
fon2Tm/00_n2Tm/;o`0000;oNXkK00?o0000ogR;fOl000001OmeRMT3og25f0?oKhGH00?o0000ofV0
eomYP=L00omYP=L3o`0000?oI7gF0_l00003ol;Ci`;o00000ooCf=`01Ol0003odmWLo`000?oLfmKo
000000;ogMcF00Go0000omkMeOoNgMGog]gEo`000002onoL_P06o`000?o`gkoo0000ooOM[ol0003o
n=n^1?l000000ooodWWo0000o`000002o`00053ooo]Z00?o0000oookJ_oonfX03_oonfX0013ooo]Z
00?o0000oookJ_oonfX0BOoonfX2o`0000?o_lSR0_l00003okk8hP03o`000?nnb>;o000000Co]lOV
0_l00002okO6iP04o`000?n[aNgo0000o`0000GoZlG]1?l000001OocYFco0000o`000?l0003okI1A
00?o00004_oonfX00ol0003ooo]ZoookJP2ZoookJPKo000000Co9@1Po`000?l0003o9PMb0_l00000
0olW4Goo90moo`000002oalBQP06o`000?l[8I7o:b6Ao`000?lF6YCo00000_l=69H00ol0003o6RNQ
o`000002o`0EV`;o3bZX013o0000o`0VZol0003o01>Qo`000?l0:[7o02>]o`0HY_l0003o032go`00
0?l07jco03Vno`000?l08jko04C60_l0>;d00ol0003o04o=o`000002o`000005o`1Qeol0003o0000
o`000?lBM>800_l00003ohVJg@03o`000?n6UmgoQYOM00?oQYOM00?o0000oh:Cfon2Tm/00on2Tm/0
1Ol0003oOi;LognBg?moT]co000000;oO8kJ0omjSMX7o`0000;oMHWI0_l00005og25f0;o00001?mY
P=L00ol0003oHg_Eof=ke@04o`0000;o`]?W0_l00002ol;Dj003o`000?oCf=co000000?odmWL00Co
0000omgLe_oMg=Ko00000ooNgMD2o`000006onoL__l0003ol=nooo3O_ol0003ommf_0ol000001?on
fiSo0000o`000?oodWT5o`0004oooo]Z00?o0000oookJ_oonfX03_oonfX0013ooo]Z00?o0000oook
J_oonfX0B?oonfX01_l0003o`lWNol?9g_l0003o_lSRo`0000Ko_/SR00Co0000okk7hOl0003o]lOV
0_l00005okO6iP04o`000?n[aNgoZlG]oj_5k@?o00000_n/aN`02?l0003oT<7go`000?ocYFco0000
oo6SK_l0003okI1A0_l000000ooMJaoo0000o`00000@oookJP03o`000?oonf[ooo]Z0:Sooo]Z1?l0
00000olK03go0000o`000002o`000006ocHBM_l0003o0000oc<IP_l0003o9a5o0_l000001?lO4XKo
0000o`000?l[8I42o`000007oaHJU?lR9I_o0000o`dHU_l0003o6RNQo`000002o`0EV`06o`000?l?
:ZSo0000o`0HX_l0003o022X0ol000001ol08jgo0000o`0`]ol0003o01n/o`000?l0<[X00_l00000
0ol0A<Ko03Rmo`0h_@02o`000003o`19b?l0003o000000;o000000Co05_Co`000?l0003o4WCR3_l0
0002oh:Cf`03o`000?moT]co000000CoO8kJ0omjSMX00ol0003oN8_IogR;f@03ogF9f@Go00001?m`
QMP01ol0003oJX3FofZ0e_l0003oJH3Go`000?mWOMD01?l000001?nmd^[o0000ol;Ciol00004ol;D
j0;o00000ooCfM`2o`000003omgLe_l0003og]gE00;og]gE00Go0000omgMeOoMgMGo0000oo3O_`04
o`000005ooSO[_l0003onN2]o`000?ong9H00_l000000oondgKo0000o`000002o`0004oooo]Z00?o
0000oookJ_oonfX03_oonfX0013ooo]Z00?o0000oookJ_oonfX0AooonfX01?l0003o`lWNol?9g_o3
bMh2o`0000Co_/SR0_l00003okk7h@;o00001?nga^H2o`0000?o]lKV0_l00006ojc5k0Co000000Go
lJ=^o`000?l0003o0000on^>D`02o`000003omYV7Ol0003o000000kooo]Z00?o0000oookJ_oonfX0
Y_oonfX2o`000006oa/02ol0003o0000oa/0?Ol0003o<P=S0_l00002ocHBMP03o`000?lc6H;o<aV2
00?o000000?o;aj;o`000?lX7i400_l00002ob8PU@07o`000?lR9I_o8RFKo`000?l@7igo0000o`lS
X@04o`000009o`0PYOl06:;o3C6ao`0PZ?l07ZSo01RUo`@d]ol0003o022/00Co000000Ko03k1o`0b
^_l0003o02^do`000?l0>;d4o`000005o`19b?l0003o1F?Io`000?l0Fm<01?l000000ol<L=oo0000
o`000003o`0000;oQIGK00?o0000oh:Bfon2T]/00_n2T]/7o`000004ogb>f_l0003oNXgJo`0000Co
N8_I0omeRMT00ol0003oLhKHog>6f002o`0000;oL8GH00?o0000off2e_l000000omZP=H3o`0000;o
Z/ca00Co0000okgBj_nmd^[o00000oo2e>P2o`0000;o`mGX00?o0000om?Ig?l000000_oDf]`01Ol0
003og]gEomkMeOoNgMGo000000;ogMgE0ol000002Oo`gkoo0000oo3P__l0003on=n^o`000?oih:go
0000ookLUP07o`0004oooo]Z00?o0000oookJ_oonfX03_oonfX0013ooo]Z00?o0000oookJ_oonfX0
AOoonfX2o`0000?o`lWN00Go0000ol?8g_o3b=ko0000okk8hP02o`0000?o_/OQ00Ko0000okk7hOnn
an7o_/OQo`000?nga^H2o`0000?o]lKV00Co0000okK5iOnfaNGo00000_n/aN`3o`0000;o[/K/00?o
0000oo>^Ool000000_l000001oo_XFoo0000o`000?l0003ojHaDo`000?oJIQd00ol0000<oookJP03
o`000?oonf[ooo]Z0:Gooo]Z1?l000000ol[04?o0000o`000002oc83H`03o`000?lf4WKo=Q9f00;o
00000_lc6H800ol0003o<R2;o`000002o`0000;o:1nA00Co0000ob8PUOlR89Go00000_lR9I/00ol0
003o41nMo`000002o`lSX@09o`000?l28:?o0000o`000?l08:Go0000o`da/Ol0003o01jX00;o13Bg
00co02>]o`0P[?l0>Kgo03Vmo`0V/Ol0003o03Voo`0b^_l0003o04W9o`000?l0>;d8o`000004o`1K
dol0003o0000oaMfh`?o000000?o<HW]o`000?l/Q^/01?l00005oh:Bf`03o`000?mmS]WoOHkI00;o
OHkI1ol000001?mhRmWo0000ogF9fOl00003og>6f0?oL8GH0ol000001?m]P]Ko0000o`000?l00006
oj[<l@06o`000?nmd^[o_M;Zo`000?o2e>So00001?o3eNP2o`0000;oe=[L00Co0000omGKgOl0003o
g]gE1?l00002omkNe@;o000000Col>2no`000?obhKgo00000_oih:d2o`000003ookLU?l0003o0000
00Co0000CooonfX00ol0003ooo]ZoookJP0>oookJP003ooonfX00ol0003ooo]ZoookJP14oookJP;o
00000_o4bMh00ol0003o`lWNo`000003ol?8gP;o00000onnan42o`0000Co_/OQ0_l00002okO6iP;o
00001?nfaND3o`0000Go[/K/00Co0000oo>^Ool0003olJb00ol000001?o]Wg7o0000o`000?oYS5@2
o`000003omMR7Ol0003o000000_ooo]Z00?o0000oookJ_oonfX0XooonfX2o`000003oa001_l0003o
;@1400;o000000?o>0MUo`000?lb0f<00_l000001?lf4WKo0000od0RQ?lj7X<3o`00000Coc8PRol0
003o=RRBocHXT_lX7i7o0000oc0ZVOlR89Go0000ob<UV_lR9I_o0000oblbXol@7igo8BjVo`000?l?
8j7o2bBTo`000002oa`d[P06o`0PYOl0003o3C6ao`000?l07ZSo02F]0_l4=;L2o`0000;o03Vm00?o
02Jao`0n`Ol0>Kl00_l0;[L2o`14aP;o000000?o05KAo`000?l0CL/00_l000000ol;I][o0000o`1K
d`02o`000006oaMfhol0003o477Po`000?laRNgo00000ol/Q^/4o`000004oh:Bfol0003oPI3Io`00
00GoOHkI00?o0000ogV:f?miR]P00_miR]P7o`000003og>6f?m`QMSoL8GH00Co00001OnZc?43o`00
0003oj[<l_l0003o_M;Z00;o_M;Z00Co0000ol?Ej?o3eNSo`mGX0_l000001Oo3e^So0000omCJg?l0
003oeM_M00?o00000_oMgMD01_l0003og]kEomkNeOoNg]Go0000onWRb`;o000000Ool^6mo`000?oi
h:go0000ooWQ[?l0003oo]bD00;o000000CooM=co`000?l0003o0000CooonfX00ol0003ooo]Zoook
JP0>oookJP003ooonfX00ol0003ooo]ZoookJP13oookJP04o`000?o7bM_oalWKo`0000;oa<WN00Go
0000ol?8g_o3b=ko`lSNo`000002ol?8gP03o`000?nnan7o000000Co_/OQ00?o0000oko6h?noa^00
0_nnan000ol0003o]/GUokK5i@02okK5i@;o00000_nha^@00ol0003o[/K/ojk6k006o`000003oo6/
P?l0003okjZ100;o000000GokImao`000?l0003o0000onN:EP02o`000003omAN7Ol0003o000000Wo
oo]Z00?o0000oookJ_oonfX0XOoonfX5o`000005obd0A?l0003oAA5Yo`000?lh1fD00_l000000om4
7G[o0000o`000002od0RQ004ocXNPol0003oA2b>od@/SP;o00000_lf:9801?l0003o<2ZIoc0ZVOl0
0002ob<UVP03o`000?l_<Z?o;c:S00;o000000Co8BjVo`000?l;9:Co2bBT0olL=:h01?l0003o3C6a
o`000?l07ZP2o`000003o`@d]ol0:k;o022/00;o03Vm00Co0000o`0V/Ol0003o03Vo0_l0;[L2o`14
aP06o`000?l0?<7o0000o`1Ac_l0003o04_:0_l000000ol1H=Oo0000o`000002oa]gi0Co000000Co
;8K[o`000?l0003o;8K[0_l000000om9VO?o0000o`000005o`000004ogf>fOl0003oO8cHo`0000Go
NH[H00?o0000ogB5e_mdQMH00_mdQMH4o`0000?oU<;g00?o0000oj[<lOl000000_l00005oj[<lP;o
00000_nmdnX00ol0003o`mGXo`000003ol?Fj0Co000000GoeM_Mo`000?l0003ogMgEo`000003omkN
e@;o000000GojN;;o`000?oZi<[o0000oo?R^`02o`000004ooWQ[?l0003o0000ookMTPKo0000Cooo
nfX00ol0003ooo]ZoookJP0=oookJP003ooonfX00ol0003ooo]ZoookJP11oookJP;o00000oo7bM/2
o`0000;o`lSN00?o0000ol?8g_l000000oo3b=h2o`0000;o_/OQ0_l00005oko6h0;o00000onfaND0
0ol0003o^<KTokS6i002okS6i0?o00000_n_aN/00ol0003olKB;oo6dR`03o`0000;okjZ100Co0000
onfOLOl0003ojieb0ol000000ooTQeOo0000omAN7@03o`0000Oooo]Z00?o0000oookJ_oonfX0X?oo
nfX01Ol0003o3001o`000?l0003oDa1K00;o00000_m54FT3o`0000;oA1ej00Co0000od0RQ?m08XCo
@2:40_l00002od@/SP;o00000_lf:9801?l0003o<2ZIoc0ZVOl00002ob<UVP07oblbXol0003o;c:S
o`000?lG::?o8BjVo`000002o`/TY009oa4/Z_lL=:ko73B^o`000?l09J[o0000o`0Z[ol0003o02F]
00;o000000Go02^bo`000?l0>Kgo0000o`0V/@02o`=5a@03o`0e_?l0;[Oo0do<00;o04C600?o0000
o`QJdol000000_l00002oa9Xg003o`000?l1H=Oo000000?o00000_lCL^42o`0000;o;XK[1?l00003
odVIla?o00001onD`_L00ol0003oZ/cboj[<lP02oj[<lP?o00000_nZc?801_l0003o_M?ZokgCj_nm
dn[o0000ol?Fj0?o00000_o4enP00ol0003oeM_Mo`000002omGLg005o`000?oNg]Gog]kEomkNeOl0
00000_oOgmD00ol0003oj^C:on[TbP03o`000005ooWQ[?l0003on^6Yo`000?ongI801_l0001?oook
JP03o`000?oonf[ooo]Z00gooo]Z000?oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000olO9foo7
bM/00_o7bM/01?l0003oalSKolO8fol00002ol?8gP;o000000?o`lSNo`000?l000000oo3amd00ol0
003o_lKPoko6h002oko6h0;o00000onoa^02o`0000Co^<KT0_l00002okW5h`04o`000?n_aN_o0000
o`0000;olKB;00?o0000oo2bS?l000000_o_ZX43o`000003on^ML_l0003ojIYc00;o000000?oi8MG
o`000?l000000_o@FA`2o`0000Gooo]Z00?o0000oookJ_oonfX0W_oonfX01?l0003o@00/o`000?l0
0002oe<@F`;o00000_m54FT3o`0000;oA1ej0_l00002od0RQ0?o000000[oA2b>o`000?lo;I?o>BZC
ocHXT_l0003oA3JKoc0ZVOl0003o=C2N0_l000001?l[;j;o0000o`000?lO:j<2o`00000;ob/hZol0
003o0000oa4/Z_lL=:ko0000o`/[[?l09J[o6S^fo`0Z[ol0::l00ol000000ol0:k;o02fdo`000003
o`0000;o0dG500So03Flo`000?l3Clco04C6o`000?l0?/;o0000o`1Fd@;o000000Co4VSLo`000?l7
HmWo0F3G0_l000000olPN>Co0000o`000003o`000005obj6jol0003o0000obj6jol000000_m;VO<4
o`0000OoI:Wg00Go0000ogfgn?mm]oSoOKOho`000002og^fn003o`000?nD`_OoU<;g00Co00000onD
`_H01?l0003oZ/cbo`000?l00006oj[<lPKo00001?o4enP2o`0000;oeMcL00Go0000omKMg?l0003o
g]kEo`000003omoOe@03o`000?oZi<[o000000;ok>K800Co0000ooWQ[?l0003on^6Y0_l000000oon
gY3o0000o`000003o`0004oooo]Z00?o0000oookJ_oonfX03OoonfX000oooo]Z00?o0000oookJ_oo
nfX0?ooonfX01?l0003oalWKolO9foo7bM/2o`0000?oalSK0_l00003ol?7g@;o00000oo3amd01?l0
003o`lKMo`000?noa^02o`0000Co_lKP00Go0000oko5gonoaMoo0000okS6i002o`0000Co^LGS0_l0
00001?n`aN[o0000o`000?l00002oo2bS0?o00000_o]Z883o`0000;ojIYc00Co0000onB7Eol0003o
hXAH1_l00003oookJP03o`000?oonf[ooo]Z09cooo]Z0_l000001Om002co0000o`000?l0003oDa1K
00Go000000OoDbQno`000?l0003oA1ejo`000?m?;XWoARN700;o00000_m8;i02o`0000;o?bfC0_l0
0002od@fV`;o00000_le<9h01?l0003o:bnRo`000?l00002oal[X`04o`000?l[>:_o:cR[o`0000;o
4BbZ00co0000o`/[[?l;:jco0000oaXk]_l0003o02R_o`0U[Ol0003o02^bo`000?l0;K@2o`0g_007
o`000?l0<;So0dG5o`0m`Ol0=Kco0000o`=?c002o`00000:o`0n`_l0003o0000o`1FdOl0003o4VSL
o`000?l7HmWo0000o`1OeP?o000000Co67?Ro`000?l0003o00000_laQn/3o`0000CoBiWc0_l00000
0omTZOOo0000o`00000=o`0000SoU<;f00?o0000oj[<l_nZc?800_nZc?86o`0000;o_]?Z00Co0000
olCGj?o4enSoa=OX0_l00002olGHj0;o00000ooFgM`01ol0003ogmoEomoOeOoOgmGo0000on3QeOl0
00000_o/i/P00ol0003okNO7o`000002o`000003oo_SZ?l0003oo]j@00Go0000CooonfX00ol0003o
oo]ZoookJP0=oookJP003ooonfX00ol0003ooo]ZoookJP0moookJP;o000000Cob<WKo`000?o7bM_o
00001?o7b=/01_l0003oalOJolO7f_l0003o`lOMo`0000;o`lOM00?o0000ol?7gOl000000oo3a]d0
0ol0003o_lKPoko6h002oko6h003o`000?noaMoo_lGO00?o_lGO0ol000001?niaN?o0000o`000?l0
0002ok[5h`;o000000Kol;RCo`000?l0003ol;:<o`000?o^/8`2o`000003onfXP_l0003ojjJ300;o
000000OojIYco`000?l0003o0000on:4F?l0003ogX1I00Ko000000?ooo]Zo`000?oonfX0VooonfX2
o`000004od00;?l0003o0000odh;F0?o000000?oEAm`o`000?l000000omC:7h3o`0000;oCbj900?o
ARN7o`000?m8;i000_m8;i001?l0003o?bfCocl]Tolo;I<2o`0000;oA3JK00?o0000ocD`W_le<9h0
0_l000000ol[;j;o0000o`000002oal[X`04ob@bZOl0003o:cR[o`0000;o4BbZ00So0000o`/[[?l;
:jco0000oaXk]_l;<kCo0000o`0X[`;o4Cfk0ol00002o`0g_008o`000?l3ALGo0000o`0m`Ol0003o
35?>o`000?l0ALL2o`000004oa1Ne_l0003o0000oaU[g@;o000000Go1f?Io`000?l0003o0000obEj
i@03o`000003oc^;kOl0003o<HO[00Co000000?oCIWbo`000?l000000ol00006ofFYm`03o`000?mn
]oSoO[Oh00;oO[Oh00Co0000ogbfn?ml]_So00000_nD`_H4o`0000?oU<;f00?o0000oj[<l_l00000
0ol00004oj_=lP06o`000?nne>[o_]CZo`000?o4enSo00000oo5f>P01Ol0003oa][XolKJj?l0003o
e]gL00;o00000_oOgmD01_l0003oh>7Eon3QeOl0003ok>K8o`0000;okNO70ol000001?okhjSo0000
o`000?ong8`5o`0004kooo]Z00?o0000oookJ_oonfX03OoonfX000oooo]Z00?o0000oookJ_oonfX0
??oonfX01?l0003oblWHol_9f?o;bMP3o`0000?oalSK00Co0000olO7f_o7am[oalOJ0_l00004ol?7
g@08o`000?o3a]go`lKMol?6gOl0003o`lKLo`000?noa^02o`0000Co_lGO00Go0000oko5g_noaMko
0000okS4h`02o`0000Co^/GS0_l000000oo`^9?o0000onjeT`02o`000003onj`S?l0003ok:f=00;o
000000?ojjJ3o`000?oXXh@00_l000000ooVV7Co0000o`000002o`000005omj0FOl0003o0000o`00
0?o7CAP01?l0002IoookJPGo00000_m>2eP2o`0000?oEAm`00Co0000oe<XO_mC:7koDbQn0ol00003
odl^R@;o00000_m8;i002_l0003oB3BFo`000?lo;I?o0000odDgW?l0003oA3JKo`000?lj<Yd2o`00
00;o@CbT0_l000001?la=ZKo0000o`000?lT<ZT2o`000004oa/`Z_l0003o4BbZobPm/P;o000000Oo
332`oaXk]_l0003o2c>do`0X[olJ@[go4Cfk00;o03:g00Co02fdo`000?l0=kco03Jl0ol000000ol0
?L7o0000o`aCcP03o`0000?o45kF0_l000000ol>I]_o0000o`000002o`000004obYki_l0003o7GCS
oaedh`;o00000ol]PnX3o`0000?oCIWb0ol000000omUZOOo0000o`00000=o`0000KoU<;f0ol00004
oj_=lP?o00000_n[c_801?l0003o_]CZokkDj_l00002olGHj0;o00000oo6f^P2o`0000;oemkL0_l0
0002on3Qe@03o`000?oQh]Co000000;okNO700Co0000ongWaol0003omnRd2Ol0001>oookJP03o`00
0?oonf[ooo]Z00gooo]Z000?oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000ol_9f?o;bMP00_o;
bMP2o`000004olO8f_l0003oalSKo`0000?oalOJ00Ko0000olO7f_o7am[o0000ol?7gOl00002ol?6
g003o`000?o3a]go000000;o`lKL0_l00004oko5g`03o`000?noaMko_lGN00?o_lGN00Go0000okW4
h_nia>;o0000ok[5h`02o`000004ok[4h_l0003o0000o`0000;ok[FC0ol00002onb]S@?o00000_oX
Xh@3o`0000;ohiEf0ol00002om]mFP?o00000_no@0/2o`0009Gooo]Z0_l000000olf01oo0000o`00
0002odh;F0?o00000omE7g02o`0000;oDbQn00Co0000oe`gRol0003o00000_m?;XT2o`000003odhb
T?l0003o000000;oCSVH00CoB3BFo`000?m5=icoACNL0_l00003ocXbW@04o`000?m1?:Co@CbTod4l
Y0;o000000Go<CJVo`000?lT<ZWo93:Yo`000002oa/`ZP05o`000?lX?K;o:3fbo`000?l<<;000_l0
0002o`/c]003o`000?lJ@[go000000;o03:g00Oo4dK3o`0g_?l0003o03Jlo`000?l0A<Go03g100?o
000000Oo04_:o`000?l0003o0000oa1Ne_l0Dm3o7fgN00;o00000_l>I]/2o`000005obYki_l0003o
0000o`000?loS>d01?l000001?l]Pn[o0000oe6Jl_mAV_84o`0000OoIZWf00Go0000ogngmomo]oOo
OkOgo`000003ogbfn003o`000?nD`_KoU<;f00Co00000_nD`oH00ol0003oZlgbo`000002o`0000Ko
Zlkb00Go0000okoEj_l0003oaMSXo`000003olKJj0;o000000?ob=_Xo`000?oGg]`00_l00002on3Q
e@06o`000?oQh]CohN;Do`000?o]ilOo00000_o]ilL01?l0003omnRdo`000?ohj[03o`000005ooWG
L?l0003o0000oookJ_l00000COoonfX00ol0003ooo]ZoookJP0=oookJP003_oonfX00ol0003ooo]Z
oookJP0koookJP03o`000?o;bMSoblWH00;oblWH00Ko0000ol[8f?o:b=So0000olO8f_l00003olO7
fP04o`000?o7am[oalOJolO7fP;o00001?o3a]`2o`000006ol?6g?l0003o`lGLol?5g?l0003o_lGO
0_l00004oko5gP04o`000?noa=ko_lCNo`0000;o^LCR0ol000001?nja>;o0000onnjVOl00002onje
T`03o`000?o]/iCo000000;ok:f=00Oo0000onV[S_l0003o0000onRSQ?l0003oiZ6500;o000000?o
hiEfo`000?oPTWL00_l000000ooKOE[o0000omQhE`07o`00097ooo]Z0_l00002ocH07`06o`000?mU
8F?o0000odh;F?l0003oGRIb0_l000001omE7g3o0000o`000?mN<83o0000oe<XO_l000000_mL=h/0
1?l0003oDRn9o`000?l00002oeHiTP03odhbT?l0003oCSVH00;oCSVH0_l00002odDgW0;o00000olj
<Yd2o`00000Bod4lY?l0003o<SFUo`000?la=ZKo?D2/o`000?lT<ZWo=D2_o`000?lK<:[o7SJ_o`00
0?lX?K;o63Fao`000?l<<;3o9D>j0_l;<k@01ol8=KKo6T:mo``l^ol0003o03:go`000?lCA/<00_l0
00001?l0=[co0000o`14aOl00002oaEGd009o`000?l0Bl[o0000oaMQeol0003o45kFo`1Cd?l0003o
5VWL00Ko00000_lRM^<2o`0000?o=XS/0ol00004oe6JlP;o000000?oIZWfo`000?l000003_l00007
oiC3mP03o`000?n[c_;oZlkb00?oZlkb0ol000000on/c_;o0000okoEjP02o`0000?oa][X00Co0000
olSKj?o8fnSob=_X0_l000001?oHgmco0000on3QeOl00002on7Re003o`000?oRhmCo000000;okNO7
00Co0000onkXa_l0003on>Z`0_l000000ooliIGo0000ooWGL002o`0000;ooo]Z00?o0000oookJ_oo
nfX0B_oonfX00ol0003ooo]ZoookJP0=oookJP003_oonfX00ol0003ooo]ZoookJP0joookJP04o`00
0?o;bMSoblWHol_9f0;o00000oo:b=P2o`000004olO7f_l0003oalOJo`0000;oalOJ0_l00002olK6
fP03o`000?o3a]co000000?o`lGL0_l00003ol?5g003o`000?noaMko_lGN00;o_lGN00?o0000oko4
g_noa=h00onoa=h00ol0003o^/?Qok[3h@02ok[3h@03o`000?o_^YWokkZI00?o00000_o]/i@3o`00
00;ojJ^>00Co0000onNYS_l0003o00000_oVXHD3o`0000;oh99g0_l000000ooKOE[o0000omn8I`03
o`0000;odF<h0ol0002<oookJP?o000000CoC`0]o`000?l0003o00000_mU8F<2o`0000;oGRIb0ol0
0003oeh`P0;o00000_mL=h/4o`0000;oESVB0ol00002odhiV0;o000000OoCC^KodDgW?l0003o0000
odHkX?l0003o>S:M00;o000000?o?c^To`000?lb=JD00_lb=JD01?l0003o?D2/oce0[?l00002ocE0
[`04o`000?lN=Zoo0000o`0000;o63Fa00Wo0000obE3^_lU@k[o0000o`Pe]_lJ@[go0000o``l^ol0
<[L00_lLBlD00ol0003o03boo`0f_002oaMAb`;o04;400Go5EO@o`QAc_l8DLko04_:o`000002oaMQ
e`04o`000?l0Dm3o0000o`0000;o5VWL0_l000001?l_ONKo0000ob9fholRM^<4o`0000;o=XS/0ol0
0004oe6JlP03o`000?m]ZoKoKJ_f00GoKJ_f00?o0000oh2gmol000000ol00002ogffn003o`000?nD
`oKoU<?f00?o00000onE`oH00ol0003oZlkbo`000002o`0000Go[<kb00Co0000ol3Fj_l0003oa][X
0_l00003olSKj006o`000?o9g>OobMcWo`000?oHgmco00000_oQh]@01_l0003oh^?Don;Se?l0003o
kNO7o`0000;ok^S600Go0000ooSZ/?l0003o0000oocUU@05o`0000;ooo]Z00?o0000oookJ_oonfX0
BOoonfX00ol0003ooo]ZoookJP0=oookJP003_oonfX00ol0003ooo]ZoookJP0hoookJP;o000000Co
blWHo`000?o;bMSo00001?o:b=P00ol0003ob/OHol[7f004o`000003olO7f_l0003oa/KJ00?oa/KJ
0_l00002ol?5g00:o`000?o3aM_o`lGKol?5fol0003o`lGLo`000?o3a=_o0000oko5gP;o00001?no
a=h02?l0003o_l?Moko3gOl0003o^/?Qo`000?nj`n7o00000_o_^YT00ol0003okKRIo`000002onfc
U006o`000?o[/ICo0000o`000?oYZhko00000_oWZHh01Ol0003oiZ65onJQQOl0003ohij600Co0000
00?ogXmgo`000?l000000_l00002omb3I0Co000000Cobe/co`000?l0003o0000Q_oonfX3o`0000;o
C`0]1?l00002ofDQH`;o00000_mN9W83o`0000?oGS200_l00002oe`gR`0:o`000?mR@I?o0000oeTj
T_l0003oESVBo`000?mK@9So0000oe<kU`;o000000KoDcnMo`000?m=>i_o0000odXmXOl00002odHk
X003o`000?m0?:Go@3bU00;o00000olb=JD01?l0003o?D2/oce0[?l_?:h2ocE0[`0<obPj[ol0003o
7SJ_oc95]_l0003o63FaoaTj]Ol0003o9D>joaDk^?l0003o23Ff0_l000001ol<?;_o0000oaa;aOlL
BlGo0000o`0l_ol000000_lGDL/2o`12a009oaEGd?l8DLko257>o`1;b_l0003o5f7Go`000?l7FM?o
05?@00Co000000?o4VKKo`000?l000001Ol000001OljRNco0000o`000?lfR>co000000?oDi_b0_l0
00000omAV_;o0000off[mP0@o`0000OoUL?f00?o0000ojc>l_n/c_800_n/c_83o`0000;o[Lob00?o
0000ol3Fj_l000000oo8fnP2o`0000?obMcW0ol000001ooQh]Co0000on;Se?oRhmCo0000onCSd_l0
00000_o^j<H01?l0003oknW5o`000?ohjK02o`000003oocTT?l0003omMAV00;o00000ooonfX00ol0
003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z00cooo]Z000>oookJP03o`000?oonf[ooo]Z03Oo
oo]Z00Ko0000olg9e_o=bMKo0000ol_9f?l00003ol[8f0;o00000_o:amP01Ol0003ob/OGol[7eol0
003oalOI00;o00000oo6a]X00ol0003oa/GIolK5f@02o`0000Go`lGK0_l000000oo3a=_o0000o`00
0004oko4gP03o`000?no`mgo_l?M00?o_l?M00Co0000ok[3hOl0003ok[bN0_l00002onfhV@?o0000
0_o[/I@01?l0003oj:nEo`000?l00002onNYSP?o00000_oSWXH01Ol0003oh9^7on2KQol0003ogXmg
00;o00000_oOTgX3o`0000;of7iT0ol00002olEC<@?o0000POoonfX4o`000004odl0;Ol0003o0000
ofDNG`;o000000KoIB5So`000?l0003oJc5fo`000?mN9W82o`000003ofXiPol0003oGS2000;o0000
00CoICb;o`000?mL=h_o00000_mR@I<01?l0003oFCZBoeTjT_l00002oe]0V003o`000?mC>iOo0000
00;oDcnM00?oCC^Ko`000?l000000_m:?J402Om6>j3o0000oe14Y?l0003o@3bUo`000?m2?jOo0000
oc8eY@04o`0000;o;cb^00Co0000obPj[olX>Zoo7SJ_0_lbAKH01olH=K7o0000oaTj]OlU@k[o0000
oaDk^?l8=KH00_lUB/401?l<?;_o23bmo`000?lLBlD2o`i5``;o000000Go5e7;o`A7aol0@/Co04;4
o`000002o`QAcP05o`000?lOIMSo0000o`000?l7FM<00_l00002obA`g`;o00000_leOnL00ol0003o
9gSTobMhi003o`0000;o>XW/1Ol00002oe>KlPKo00000omXZOH01?l0003oPKOgoh6gmol00003ognf
m`03o`000?nE`oKoUL?f00Co00000onF`oH01?l0003o[<kbo`000?l00006ojg?lP05o`000?o1e^[o
0000olSKj?l000001?o9g>L00ol0003obmkWo`000002o`0000;oh^?D00Ko0000onCSd_oThm;o0000
onkXa_l00002onoYa@;o000000GonNZ^o`000?oli93o0000ooGDIP02o`0000?ooo]Z00?o0000oook
J_oonfX0BOoonfX00ol0003ooo]ZoookJP0<oookJP003_oonfX00ol0003ooo]ZoookJP0foookJP03
o`000?o=bMKocLWF00;ocLWF00Go0000ol_8eol0003ob/SHo`000003ol[7f004o`000?o:amOob/OG
ol[7e`;o00000_o7a]T00ol0003oa/KJo`000002olK5f@05o`000?o6aMSoa/GHo`000?o3aM/00_l0
0003ol?4f`;o000000?o`lCKo`000?noa=h00_l00004oko3g@03o`000?no`mgo_l?M00?o000000Co
k[bNo`000?l0003o00000_o/]YT3o`0000?oj:nE0ol00002onFVS`Co00000_oPVhL4o`0000;ogi=j
00Co0000omb@N_l0003o00000_oHOV@00ol0003odgYTo`000002olEC<@03o`000?noBBSo000000?o
0000N_oonfX5o`000003oe`2>Ol0003o000000?oIAiO0ol00002of/aMP?o000000?oJ3R2o`000?mZ
>H<00_l00003ofDlR`03oedhRol0003oHT6C00?oHT6C0ol00002oe]0V006oe<kUol0003oEd2Ko`00
0?mC?igo00000_mFA:400ol0003oBSfQo`000003oe14Y0;o00000_m2?jL00ol0003o>Sj[ocXnZ`02
o`0000;o;cb^0_l00002obPj[`05o`000?lbAKKo<TFfo`000?lI>[D00ol000001_lE>kSo0000obE:
`OlUB/7o0000o`Pl_@;o00000_l>AL<03?lPELco5e7;o`000?l4AlOo04;4o`000?lMG=;o257>o`00
0?l6Clgo0000oa5NeP?o000000So:g;Po`000?l0003o6FWLo`000?leOnOo0000obEgi0?o00000_ln
Rnd01?l0003o>XW/o`000?l00003oeNKlP[o000000?oJ:Wfo`000?l000001ol00008oiK3mP03o`00
0?n]co;o[Lob00;o[Lob0ol00002ojk@lP03o`000?o1e^[o000000?obMcW0_l000001oo;g^Oo0000
olcKi?o<fnCo0000on;Se?l000000_oThm801Ol0003oiNOBo`000?l0003oknW500?o000000GonNZ^
o`000?l0003o0000ooGDIP02o`0000Cooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]Zoook
JP0<oookJP003_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?o=bMKocLWF00;ocLWF00Co0000
olg8eOl0003oblSG0ol000000oo:amSo0000ol[7e`02ol[7e`04o`000?o9a]OobLKGo`0000;oalKI
0_l000000oo6aMWo0000olK5f003olK5f005o`000?o3a=_o`lCKol?4fol000000oo3a=X00ol0003o
`lCKo`000004oko3g@03o`000?no`mgo_l?M00?o_l?M00?o0000onbmX_l000000_o/^Yh01Ol0003o
k;JIonbfVOl0003oj[>J00;o00000_oX[iD01_l0003oiZfFo`000?l0003oiJJ?o`0000;ohZB@0_l0
00001?oPVhOo0000o`000?oRWHL4o`0000;og91j0ol000000ooHOVCo0000om=jI004o`000003okm9
:?l0003o000000Go0000LooonfX6o`000003oe`2>Ol0003o000000?oIAiO0ol00003of/aMP;o0000
0omX>883o`0000?oICb;0ol00003of91T`;o00000_mM@IP3o`0000?oEd2K0_l00003oeI4X@;o0000
0_m@A:@3o`0000;o@SnW00Oo0000ocXnZolj?Z_o0000odE7[ol0003o;cb^00;o>4>b0_lX>Zl01?l0
003o<TFfoc95]_lS?[H2oaTj]@;o;dZm00co5C^ho`000?l0003o9D[1oaA2_ol0003o23bmobEAb?l0
003o3TG3o`U5a?lPEL`2o`000004o`A7aol0003o0000oaeLdP;o000000Co9fSJo`000?l0003o4EkF
0_l00002ob]bh003o`000?lIJMco000000?o00000_lUMn@3o`0000;o?X_]1Ol00002oeNKlP;o0000
1_mZZ_H01Ol0003oPkOfoh>gm_n3]oKo000000?oP;Kg00?o0000oiK3m_nF`oH01?l00002oiO4mP03
o`000?n]co;o000000;o00001_n^d?82o`0000;obMcW00Co0000ol_Nioo;g^Oo00001?o<fn@2o`00
000<onCSd_l0003oiNOBonGWd_l0003oknW5o`000?o`j/?o0000ooWZ[_l0003onN^/1Ol00005oook
JP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX03?oonfX000kooo]Z00?o0000oookJ_oo
nfX0=?oonfX2o`0000?ocLWF00Go0000olg8eOo=b=GocLSEo`000003ol_7e`05o`000?o:amOob/OG
ol[7eol000000oo9a]L2o`0000?oalGH0_l00003olK5f005o`000?o6a=So0000ol?4fol000001Oo3
a=X3o`000003oko3gOl0003o000000Co_l?M00?o0000okk1g?l000000ol000001?o/^Yko0000o`00
0?l00002onZcVP04o`000?oX/I[o0000o`0000;oiZfF00Co0000onBZU_l0003o00000_oRY9000ol0
003ogj6Ao`000002o`000004on:MQol0003ogi^7omnKQ`;o000000Cog91jo`000?oIS7_ofHak1?l0
0002om1eH`Co00000_o9GT<6o`0006cooo]Z2ol000000om_9F3o0000o`000002o`000004og4eM_l0
003o0000of/aMP;o000000CoLd24o`000?mX>8;oJ3R20_l000000om`A8go0000ofDlR`02o`000008
ofi8Tol0003oHd6Co`000?mR@I?o0000ofI7VOl00002oee1V003o`000?mNAYgo000000;oEd2K0ol0
0002oeI4X@05o`000?mAAZKo0000oe14Y?l000000_m7@JH01ol0003o@SnWo`000?m<Ajco0000ocXn
Zol000000_m5Ajl01_l0003o>4>bocQ3/_lh@k;o0000obTo]0;o00000_lS?[H01?l0003o;dZmobm:
_Ol_B[d2o`000004obE:`Ol0003o54:oo`Pl_@;o9E7800Go3TG3o`000?l9ALCo0000oa5>bP02o`00
00;o9F3D0_l;Dll2o`000004oa]Sf?l0003o0000oa1Me@?o000000Go86cMo`000?l0003o0000obml
iP08o`000003oc^9k?l0003oFYcb00;oFYcb2Ol000000omZZ_Ko0000o`000008o`0000OoUlCf00?o
0000ojk@l_n^d?800on^d?83o`000003ojoAl_l0003o`]OY00;o00000_o;g^L00ol0003oc=_TolcK
i002olcKi004olgQiol0003oe^CPo`0000;oiNOB0_l000002Oo_jLGo0000oo3Z`ol0003onNZ^o`00
0?oijjco0000oo_TR`03o`0000Kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0<
oookJP003_oonfX00ol0003ooo]ZoookJP0doookJP05o`000?o>bMGo0000olg9e_l000000oo=b=D0
2Ol0003ocLOEo`000?o;amOo0000ol[6e_l0003ob/OGo`000003olW6e`06o`000?o9aMKobLGFo`00
0?o7aMSo00000_o6a=P00ol0003oa/GHo`000003olK4f004o`000?o3a=[o`lCJol?4fP;o00001?o3
`mX00ol0003o_l?Moko3g@02oko3g@04o`000?nn`Mco_/7Lo`0000;ojknV00?o0000on^kX_l00000
0_o[^9h2o`000004onZcV_l0003oj;6JonRaVP;o000000CoiZfFo`000?oTZYKoi:ZF1?l00002omnQ
T@Co00000_oOVhL01?l0003og9R8o`000?l00003omV<N`03o`000?oER7_oeHQk00;o000000Cod7ES
o`000?oCOF[odgeZ1?l000000oo1E3go0000o`000003o`0006Gooo]Z3Ol00003oflUH0;o00000oma
=GH01?l0003oM3Qho`000?l00003og=0Q0?o000000?oKdB=o`000?m`A8d00_l00004ofi8T`03of=1
Tol0003o000000;oITNI00Co0000oee1V?l0003o00000_mNAYd01omG@9_o0000of1:XOmPBZ7o0000
oeI4XOl000000omAAZH00ol0003oAd6VodM1YP02odM1YP04o`000?m<AjcoC4N/oda7[0;o00000_m5
Ajl01Ol0003o<d2aocQ3/_lh@k;o000000;o:Cnd00Go>dbio`000?lS?[Ko94:jo`000002obm:_@;o
000000Go9T[0o`000?l0003o54:oo`000002obEAb0Co00000_lAC/X00ol0003o9F3DobEPe003o`]C
c`03o`000?lKHmSo6f?H00;o00000_laMN400ol0003o86cMob1/g@08o`0000;oB8k]1Ol00002oeZL
lP;o00001_m/Z_H01Ol0003oQKOfohFgm_n5]oKo000000CoP[Og00?o0000oiO4m_nGa?H00ol00003
oiW5mP03o`000?n^d?;o000000;o00001On_dO82o`0000;obmkW00Go0000olcKi?o<fnCoc=_To`00
0003olgQi`;o000000[oiNOBo`000?oVj=7oi^SAo`000?o`j/?o0000oo7[`_l0003onN^/0_l00000
1?oki8_o0000o`000?l00007oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX03?oo
nfX000kooo]Z00?o0000oookJ_oonfX0<_oonfX2o`0000?oc/WE00Go0000olg8eOo=b=GocLSEo`00
0002olg7e@;o00000oo:a]H01Ol0003obLKGolW6eoo9a]Oo000000?obLGF0_l00004olK4f009o`00
0?o6a=Soa/CHolK4f?l0003oa/?Go`000?o3a=[o000000Co`l?J00Go0000ol?2fOo3`]Wo0000oko3
g@02o`0000?o_/7L00?o0000on^oY_o[_jH00ol00002on^hWP04o`000?oY]Igo0000o`0000;oj;6J
00Co0000onJ_Vol0003o00000_oTZYH00ol0003ohZRGon:XU`02o`000004omnQTOl0003o0000on6R
S`;o000000Cogi^7o`000?oLV8Sog9R80ol000001_oIS7_o0000omF8NooER7_o0000om:6N`?o0000
00CodgeZo`000?o>MfWocWMY1Ol000000onjBSCo0000o`000006o`0005_ooo]Z3Ol000000omg;F?o
0000oflUH003o`000003ogXmN?l0003oLCEf00;oLCEf0ol00003og=0Q0;o00001?m_A8d2o`0000Co
KTRC0_l000001?mWB9Wo0000ofI7VOmVAiT2o`0000;oHDJL00?o0000oei6WOl000001?mPBZ400ol0
003oDDJVoe56YP02oe56YP04o`000?m7@JKoAd6VodM1YP;o00000om<Aj`02om2AZoo0000odE7[ol0
003o=d6`o`000?lh@k;o0000od5;]Ol0003o:Cnd00;o>dbi00So8cjfo`000?lT@[[o;dZmo`000?lN
@[co5Sjko`0000;o;U3300Co54:ooaA5`Ol0003o9E780_lCBLD02?l9ALCo:5[?obQJcolAC/[o3Tk;
o`000?lUH=Co5EWA0_l;Dll02Ol0003o;F_Koa]Sf?l0003o667Go`000?laMN7o0000ob5^gP03o`00
0003ocEoiol0003o000000;o000000KoC8o]o`000?m8S^go0000ocn:k?l00003oefMlPSo00000_m/
Z_H00ol0003oQKOfohFgmP08o`0000OoVLGf00?o0000ojoAl_n_dO800_n_dO83o`0000;o/M;a00?o
0000ol_Niol000000_o<fn@00ol0003ocN7WolgQi`02olgQi`03olkQiOl0003of>KO00;o000000So
i^SAo`000?l0003ol>[3o`000?oajl;o0000ooW[[0;o000000ConnB;o`000?l0003o00001ooonfX0
0ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z00cooo]Z000=oookJP03o`000?oonf[ooo]Z
03;ooo]Z00Go0000om39doo@bM?od<WCo`000002olk8e003o`000?o=b=Go000000;ocLOE00Go0000
olg6e?o=a]CocLKDo`000002ol[6eP03o`000?o9a]Oo000000?obLGF00Ko0000olW4e_o9a=Ko0000
olK4f?l00002olK4e`03o`000?o6a=So000000?oa/?G00Co0000ol?3f_o3`m[o`l?J0_l00004ol?2
f@?o00000_nn`M`2o`000004on^oY_l0003ojKbVonVlYP?o00000ooY]Id3o`0000?oiZnK0ol00003
on:XU`03o`000?oOYIOo000000;o000000?ohJ:?o`000?oNWi000_l00002ombHR003o`000?oIU8So
fIB800Go000000?odXIko`000?oGRg`01?l00002oligJ@03o`000?o9LFSobG5X00?o000000Co^TXd
o`000?o1FDWo`EU92?l0001@oookJQ3o00000omg;F<3o`0000CoNSeh00?o0000og4eM_l000000_l0
00000omkAXKo0000og=0Q002o`000003ogQ:S_l0003oKdB=00;oKdB=0ol00002ofi8T`;o000000Co
L4jJo`000?mWB9WoIdRI0ol00003of56W0?o00000omPBZ400omMCJKo0000oe56YP02oe56YP06o`00
0?mAB:So0000odM1Y_l0003oC4R/0_l000000om<Ajco0000od96[`02o`0000?o=d6`00Co0000od5;
]Om1BkGo@D^e0_l00002oc]<^@03o`000?lT@[[o000000;o000000?o7T:lo`000?l^D<<00_l^D<<2
o`000004obQBaol0003o4dW5oa=9a@?o:5[?00Oo0000o`i>bol0003o0000oaEIdOl;Dloo000000;o
;F_K00?o6f?Ho`000?l000000ol000001?lQK]ko0000ocn3iol00003ocEoi`;o00000om<Snd6o`00
0004oefMl_l0003oEY[bo`0000?oKZ_f1Ol000000on7^?Ko0000ohBgmP03ohBgmP03o`000?nIaOKo
VLGf00Co00000onJa_H01?l0003o[m7bo`000?l00006ok7Bl@;o000000Coc=_To`000?o=hNOocN7W
0_l00003olkQi@04o`000?oKj=kofnSNo`0000;oj>W@00Co0000oo7[`_l0003ol^Zo0_l000000ooi
k:So0000o`000002o`0000Sooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0<oook
JP003OoonfX00ol0003ooo]ZoookJP0aoookJP07o`000?o@bM?od<WCom39dol0003od<SBo`000002
olk8e0;o000000?ocLOEo`000?o=a]@00_o=a]@00ol0003oc<KDo`000002ol[6eP?o000000?obLGF
o`000?o9a=H00_o9a=H2o`0000Coa/CG0ol000001_o6`mOo0000olK3eol0003o`l?Jo`0000Co`l;I
00Go0000ol?2f?o3`]So0000ol31fP03o`000003on_0Z?l0003o000000;ojKbV00?o0000onRjY_l0
00000ooY]Id01?l0003oik>No`000?l00002onJ_V`04o`000?oT[I_o0000o`0000;ohZRG00?o0000
omnUUooOYIL01?l00002omjOT0Co00000ooIU8P00ol0003oeI69omFAR@02o`0000;oeh]l00?o0000
omB8OOoDR7d00ol000001_o>MfWo0000olUaJ?o9LFSo0000olI/I0Oo000000?o^4i1o`000?l00000
1ol00014oookJPco000000?oLA4lo`000?l000000ol00003oghcI@03o`000?mg;F?o000000;o0000
00?oPT=jo`000?mj?GP00omj?GP3o`000004ogU5QOl0003oNdJ6og]6QP;o00001?mhBXh3o`000005
og=<U?l0003o0000ofi8Tol000000om`CYX00ol0003oIdRIo`000003o`0000;oHDJL00Co0000ofQ?
XOmXCj7o00000_mPBZ42oee=YP07oeQ9YOl0003oDDJVo`000?mEBjWo0000oe58Z002o`0000;oC4R/
0ol00002od96[`06odE9/Ol0003o=d6`ocM1/?llB;Go00000_m1BkD01OlcAkSo0000oc]<^OlkC;Wo
;DJi00;o94:j0_lhDL000olN@[co8DNoo`000002obi@``07oa]7`_l0003o0000obiGb_l0003o4dW5
o`000002obQJc`03oaAAc?l0003o000000;o;FCE00?o5EWAo`000?l000001?l00002ocQhhP;o0000
00?o8FkNo`000?l000002?l000000om<Sngo0000o`000003of2NlPSo00000om^ZoH00ol0003oQkSf
ohNhmP07o`0000SoV/Kf00?o0000ok7BlOnad_400_nad_43o`000004ok?DlOl0003o^=K_o`0000;o
cN7W00?o0000olkQiOo>hND00_o>hND00oo@h^Go0000om_XgP02o`000004onSYd?l0003o0000o`00
00;ol^Zo0_l000000ooik:So0000o`000002o`0000Wooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0
003ooo]ZoookJP0;oookJP003OoonfX00ol0003ooo]ZoookJP0`oookJP?o000000?od<WCo`000?o@
b=800_o@b=801Ol0003ocLODolg7e?o=amCo000000?ocLKD00Go0000olc6e?o<a]Coc<KDo`000004
ol[5e@05o`000?o9a=KobLCFolW4e_l000000_o9a=D00ol0003oa/CGo`000004olK3e`05o`000?o6
`mOoa/?GolK3eol000000oo3`]T2o`0000Co`l;H00?o0000oko0f_l000000_o[`:P01?l0003ojKfX
o`000?l00002onRjYPCo00000_oW/ih01?l0003oiK6No`000?l00002onB]V`04o`000?oQZi_o0000
o`0000?ogjFG00?o0000ombSV?l000000_l000001?oNWi3o0000ombMT?oLWI03o`000004omVDR?l0
003oeI69omFAR@Go00000_oDR7d00ol0003ochAmoln4O@04o`000005olUaJ?l0003oc7Q_olahKol0
00000oo6LF`5o`000003ok50<_l0003o000000So0000>OoonfX:o`0000GoM10e1?l00002ohDhI@04
o`000?mn<fGoOS=UoghcI@Co00001?n2@gX00ol0003oNSeho`000002o`000006oh5;Q_l0003oNDF5
ogU5QOl0003oNdJ60_l00004ogQ:SP;o00001?mcC9@2o`0000CoL4jJ0_l00003ofY=W@?o00000omX
Cj400ol0003oH4ZQoee=YP03oee=YP03oeQ9YOl0003o000000;oED^Y00KoDDRXoeU>ZomICZ_o0000
oda8[?l00002oe9>[`04o`000?m2AZooADVaodE9/@;o000000Co?4Reo`000?l0003o00000_lcAkP0
1OlkC;Wo0000obe6^Ol]A[Wo000000?o>5700_l000003_l`D<?o0000oa]7`_lKAl;o54G1o`000?l^
El[o4dW5o`000?l`G]3o:5[?o`000?lDDLco3Tk;1Ol000000oldK]co0000o`000002oaaTf@06ocQh
h_l0003o:W;Po`000?lQK]ko00000om3Q>P3o`0000;oDI7]1?l00004of2NlP03o`000?mIW?;o0000
00CoL:cf0_l000001?m^ZoKo0000ohVimOl00005ohJgmP03o`000?nJa_KoV/Kf00Co00000_nKaoH0
0ol0003o/M;ao`000002o`0000Go/mCa0_l000000oo=hNOo0000olkQi@02olkQi@03o`000?o@h^Go
d>;U00;o00000_oMj]`3o`0000;ol^Zo0_l00002ooW/Z004o`000?ojhXKo0000o`0000[ooo]Z00?o
0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0;oookJP003OoonfX00ol0003ooo]ZoookJP0_
oookJP05o`000?oAbM;odLWBom79d_l000000oo@b=802Ol0003oclOBo`000?o=amCo0000olg6dol0
003ocLKDo`000004olc6e009o`000?o<aM?o0000ol[5eOl0003obLCEo`000?o9a=Ko000000CobLCE
00Go0000olK3eoo6`mOoa/?Go`000002olK2eP07o`000?o6`mOo0000olK2e_l0003o`l;Io`000004
ol?2f003o`000?o2`=So`/3H00;o00000_o[`:P01?l0003ojKfXonVmZ?l00002onRjYP;o000000Go
j;NRo`000?oW/ikoik>No`000002onFaWP?o00000ooQZi/4o`0000;og:>H0_l000000ooNXiKo0000
o`000002ombMT003o`000?oIVY7ofIZA00Ko00000_oGThT4o`0000?ochAm00?o0000olb1OOo<PGd0
1?l000000oo<N6oo0000olIaK002olIaK003o`000?o2K6Wo`VaY00Ko000000?o]4a7o`000?l00000
3_l0000VoookJPgo00000on48d<00ol0003oM10eog@@=@05o`0000CoQCQU00?o0000oghcIOl00000
0_l00002ohQ8N`04o`000?n2@g[oPT=joh93NPCo00001?n1BhH00ol0003oNDF5o`000002o`000004
ogm?Sol0003oN4Z>ogQ:SP;o000000?oO5:Do`000?mcC9@00_mcC9@3o`0000?oL4jJ0_l00004ofY=
W@;o00001?mXCj400ol0003oH4fUo`000003oee=YP06o`000?mIBjOoFD^Wo`000?mEBjWo00000omI
CZ/2o`0000?oDTj_0_l00002odE9/@;o000000Go?4Reo`000?l0003o0000oc=7^003o`000003obe6
^Ol_B[go000000;o>57000Go9dVoo`000?l0003o=eK6o`000002oa]7`P03o`000?l^El[o;UO:00;o
000000?o<5k@o`000?l000000_l00003obeTe@;o00000_ldK]`5o`0000;o:W;P0ol00002od>4j003
o`000?lhOnKo000000;o000000?oDI7]o`000?m8SNd02?l00006og2/mP04o`000?n9^OGoRKWeo`00
00;oQ[Of1Ol00007oi_7mP03o`000?nce?7o/mCa00;o/mCa0ol000001?nde?3o0000o`000?l00003
olkQi@05o`000?o@h^God>;Uom3RiOl000000_oMj]`00ol0003ogncKomo/f`02o`000004oo;Z_ol0
003o0000ooW/Z0Go00002ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z00_ooo]Z
000=oookJP03o`000?oonf[ooo]Z02kooo]Z00Co0000om79d_oAbM;odLWB0_o@b=800ol0003od<SB
o`000003olo7dP04o`000?o=a]?ocLKColg6d`;o00000oo<a]@00ol0003oc<GColc5d`02o`0000?o
bLCE0_l00003olW4e@05o`000?o9`mCo0000olK3eol000001?o6`]H3o`000003olK2e_l0003o`l;H
00;o`l;H0_l00003ol;0f0Co00000ooY_JP3o`0000;oi[RV00Co0000onJeX_l0003o00000ooU/Ih0
1?l0003ohjnOo`000?l00002on6[V`03o`000?oOZ9cogjRL00;o000000?og:>Ho`000?oNXiH00_oN
XiH4o`0000?ofIZA00?o0000omFGTOoEUi400_l00002omNCR@03o`000?oDT8Woe92900?o000000?o
chAmo`000?o<PGd00_o<PGd00ol0003ocH9oolf2O`05o`000005olIaK?l0003o`VaYol9/JOl00000
0oo2KVh6o`000004ojdo>Ol0003o^5MEo`0000?o[DM74ol0000:oookJQWo00000_n48d<6o`0000?o
ST9[00Co0000ohDhIOn5>6GoQCQU1?l00004ohQ8N`03o`000?n2@g[o000000;o00000_n8D8L00ol0
003oPD^6oh5;QP02oh5;QP?o00000_mnChl00ol0003oOdn?o`000002o`0000?oO5:D00co0000og=<
U?mcC9Co0000ogIAVOl0003oL4jJo`000?m`CY[o0000og9BW_l00003ofY=W@03o`000?m`E:7o0000
00?oJ4nQ0_l00002of1=Y@04o`000?mMCJKo0000o`0000?oFD^W0_l00003oeU>Z`;o00000_mBCZl2
o`0000;oADVa00Go0000odi@]?m>D;Co?4Reo`000002odQA^009oc=7^?m3D[co@e:lod=B_?l]A[Wo
0000obm:_OlhDL3o000000;o9dVo0_l000000olgE/Ko6dO2oa]7`P02ocIKb`03obiGb_l0003o0000
00;o000000Co8ES?o`000?l0003o=6SF0_l]I=D01_l0003o7egCo`000?ldK]co0000obAXfP;o0000
00?o?7[Ro`000?l000000_l000001?m8Q^So0000o`000?m3Q>P2o`0000?oEI;]1?l00003ofBOl@03
o`000?mMWO;oGIgb00co00001?n8^?D00ol0003oVlOfoi_7mP03o`0000?oWLSf00Co0000ok?DlOl0
003o00001?nde?001_l0003o_=W_okcIkol0003oc^7Uo`0000?od>;U00Cod^?To`000?oMj]co0000
0_oOk=/00ol0003ognWJo`000009o`0000_ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]Z
oookJP0;oookJP003OoonfX00ol0003ooo]ZoookJP0]oookJP;o000000?odLWBo`000?o@b=800oo@
b=802Ol0003oclOBolo7d_o?am;o0000olo6d_l0003ocLKCo`000002olg5d`03o`000?o<a]Co0000
00;oc<GC00Ko0000olc4doo<a=?o0000olW4eOl00002olW3e003o`000?o9a=Go000000;obL?D0_l0
0003olK2eP03o`000?o6`]Koa/;F00;oa/;F00Go0000olK1e_l0003o`l;Ho`000004ol;0f0;o0000
0_oZ`JX01?l0003ojKfXonVmZ?l00002onNkZ004o`000?oV^:Koi[RVo`0000;oi[FR1?l00002on>_
W`04o`000?oQ[Ioo0000o`0000?ogjRL00Co0000ombVWOl0003o00000ooNXiH00ol0003og:6FombQ
UP04o`0000?oeINA1Ol00002omB@R@03o`000?o@S8Wod8b900Ko00000oo=PWl01?l0003oageoolMm
Ooo7OGl4o`000003olE`Jol0003o`Vi^00;o`Vi^00Co0000okeXK?nmJ6co_FQ/1_l00005oje7A`04
o`000?n^CE;o[TeBoji=DR;o00000on?:T000ol0003oQ1hioh@N>@0:o`000003oi92I_l0003oST9[
00CoST9[00?o0000ohDhIOl000000_l00002ohm=O003o`000?n8B7_oR4Qk00;oR4Qk0ol00005ohQ@
Q`03o`000?n1BhKo000000;o000000?oQEB?o`000?mnChl00_mnChl3o`0000GoO5:D0_l00004ogIA
V@06og1>V_l0003o0000o`000?mbDYko00000_mZCId00ol0003oL5BQog1DX@02o`000004ofQ?XOl0
003oIe:Uo`0000;oH4fU0_l000001_mOCjSo0000oeU;YomIBjOo0000of5BZ`?oFDj[00Go0000oe=?
/?l0003oDTj_o`000002odQ9/0;o00001?m>D;@01Ol0003oB56hodQA^?m8DKSo000000?o@e:l00?o
0000obm:_Ol000000_l00002obM9_`03o`000?lgE/Ko=eK600Go00000_lMDLT2o`0000;o8ES?00?o
0000ocAXe_ldJ=H00_l00002oc]bg0;o00000_lTJ=X01?l0003o?7[Rocajh_llN^82o`0000?oB8KX
0ol00003oeFBk@03o`000?m=SngoCHo]00;o00000_mTWo400ol0003oGIgbo`000007og:/mP;o0000
1?n8^?D5o`0000OoWLSf00Co0000okCDl?nde?3o]=C`0_l000001?nfeO3o0000okcIkonlfNl2o`00
00;od>;U00Go0000om;Si?oBhnCod^?To`000002omo/f`07o`000?oOjM[ognWJo`000?o/lL_o0000
onkca`06o`0000cooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0;oookJP003Ooo
nfX00ol0003ooo]ZoookJP0/oookJP04o`000?oBb=7od/SAo`0000?od<SB00Ko0000om37dOo@am7o
0000olo7d_l00002olo6dP;o00001?o=aM<2o`000003olc5dol0003oc<CC00?oc<CC00?o0000olW3
e?o9`m@00_o9`m@2o`000007olW3e?l0003ob<;DolS2e?l0003oa/;Fo`000003olK2eP06o`000?o6
`MGoa/7EolK1eOo6`MKo00001?o2`=P00ol0003o`koGo`000002on[1ZP;o000000CojKfXo`000?oW
^jSoik^X0ol000001?oT]JKo0000onJeX_l00002onFcX@04o`000?oS[ioohjnOo`0000;ohJfO1?l0
0003ombVW@Co00000ooLXIH00ol0003ofIjGomVNU`02o`0000;oeINA0_l00002omJHT@Co00000oo@
S8T00ol0003oc8V:olb9RP04o`000003olf2Ool0003oageo00?oageo00?o0000olEkO_l000001Ol0
00000oo2KVko0000okeXK002okeXK004o`000?nkJFoo^fU_ok]YK`_o000000Go[TeBo`000?nU?43o
YCa0o`000002oj<j?`03o`000?nR?4KoXSa600?oXSa60_l00006oihkB@?o00001OnH=DP00ol0003o
Sb]2o`000007o`0000CoVde^00?o0000oi94JOnBA6T00onBA6T01?l0003oST9[ohi2Jon>@V/5o`00
00GoSdel00?o0000ohQ8Nol000000_l000000on>EHSo0000ohQ@Q`03ohQ@Q`Co00001?n5E8l4o`00
00;oPUJF00?o0000ogaBU?mlDY@00_mlDY@2o`0000CoMU6I0_l00003og9CWP04o`000?mbDYko0000
o`0000CoL5BQ00?o0000ofQ?XOl000000_mWDZD02?mPCJGo0000ofMCYomWDjOo0000oem?Z?mIBjOo
00000omQDZ/00omICZ_o0000oe=?/002oe=?/0;o00000om8BK02o`0000?oCU2d00GoA4nho`000?m8
DKSoB56hoca>^`03od=B_003o`000?l_B[go;dZm00;o@5O20_lWBKl4o`000003obMAaol0003o=U_;
00;o9UG:00Go7E79ocMSdOlgHm7o0000ob5Hc`04o`000005obARe_l0003o>g;Lo`000?l]KM`00ol0
00001Om2O>?o?7[Rocajh_l0003o<7CQ00Co00000_lnPNL4o`000005odf?kOl0003o0000o`000?mW
X?402ol000000omb[?Ko0000o`000003o`0000CoS;[d00?o0000oig8m_nMb?H00ol00003oio9mP03
o`000?nde?3o000000Co]]G`0_l00002okkKkP;o00000_oBhn@01Ol0003oe>GSo`000?oOk=_o0000
00;ognWJ00?ohN_Io`000?l000000_o^llL6o`0000gooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0
003ooo]ZoookJP0;oookJP003OoonfX00ol0003ooo]ZoookJP0[oookJP04o`000?oCb<oo0000om;8
d@;o000000?od<SBo`000?o@am400oo@am42o`000007olo6d_l0003oclGAolo5dOl0003ocLGCo`00
0003olg5d`;o00000oo<a=<01Ol0003obl?Bo`000?o9`mCo000000?obL?D0_l00003olS2e005o`00
0?o6`]Koa/;FolK2e_l000001Oo6`MD3o`000003ol;0f?l0003o`koG00;o00000_oZ`JX00ol0003o
j;jZo`000003o`0000;oiKVX1?l00003onFcX@?o00000ooQ[Il00ol0003ogj^Oomn[W`02o`0000;o
g:JM00?o0000omfVVooMYY/01?l00003omVNU`03o`000?oFViOo000000?o00000_oFV9400ol0003o
e9FAomBET@03o`000004om2<ROl0003oc8V:olb9RP;o00000_o=RXX5o`000006olMmOol0003oaG]n
o`000?o7OGoo00000oo3NX07o`0000?o^fU_00Oo0000okMSK?ngHfco]f=/o`000?ngHfco000000?o
]69_7ol00003oie<J@;o00001_nKCFh01?l0003oTTAYoi94JOnBA6T7o`0000?oUE=m00Co0000ohm=
O?n?CGcoSdel1Ol00004ohiER003o`000?n8D8Oo000000;o00000_n;FI000ol0003oQEB?ohEDS`02
ohEDS`;o00001On2EYH00ol0003oO5:Do`000002o`000004ogiGV_l0003oMU6IogIAV@;o000000?o
NeRMo`000?mbDih00_mbDih3o`0000CoL5BQ0_l00002ofQBY@03o`000?mWDZGo000000CoIe>W0_l0
0004of5BZ`;o00000omCCk02oe=@/@0=o`000?m8BK3o0000o`000?m=D;Go0000odi@]?l0003oA4nh
o`000?m8DKSo0000oca>^`02od=B_004o`000?leC;go0000obm:_@Co000000Co:4_0oceJaolmF/Oo
00000_lWDLL2o`0000;o9UG:00Go0000ocMSdOlgHm7o=f?Ao`000003oc][e`03o`000?lTH]Ko96;F
00;o00000ol]KM`01?l0003o@WcSod9lhom2O><3o`000003odf8j?l0003o000000?o000000?oFYC]
o`000?mBTNd00_mBTNd4o`0000?oHIka00?o0000ogV]m?mi[O@01Omi[O@00ol0003oS;[dohbjm002
ohbjm0Ko00001onObOH00ol0003o]]G`okKEl002o`000009okSFkol0003o_]_^okkKk_l0003o`Mg^
o`000?oBhnCo000000?oe>GS00?o0000omoYf_oOjMX00_oQjmT00ol0003ok_?7onkca`02o`000003
ooCb[ooelJWo000000;o00003_oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z00_o
oo]Z000<oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000om?8cooCb<l00_l00002om;7d0;o0000
0oo@am400ol0003od<KAom36d@02o`0000?oclGA00Go0000olg5doo=aM?ocLGCo`000002olc4dP03
o`000?o<a=?o000000;obl?B0_l00003olW3e00:o`000?o9`]?obL;Co`000?o8`]Co0000olS1e?l0
003oa/;Fo`0000Coa/7E00?o0000olFoeOo5_mD01?l000000oo3_mOo0000onW1Z`02o`0000;oj;jZ
00Co0000onNlZ_oW_:[o00000_oU^JP01?l0003ohkNXon>gZ?l00002onFcX@03o`000?oS/J;ohk6R
00Co00000ooOZil02?l0003og:VPo`000?l0003ofZBMo`000?oMYY_o00000_oKY9X2o`0000;ofIjG
00Co0000omJKUooFViOoeY^G1?l00003omBET@03o`000?o@TI7od96A00Ko00000oo=RXX01?l0003o
b8F:olR5R_o8QHX6o`0000Co`gZ000Go0000ol1gOoo0Mgoo0000ol5hO`08o`0000?o]f=/00?o0000
okARKondHVl00ondHVl00ol0003o/F5bok5QLP02ok5QLP05o`000?n]Ffco[E]/ojeKK?l000000_nZ
Ef/00ol0003oZEM/ojUGK002ojUGK003o`000?nTDV_oY59[00;oY59[00Co0000oj=BJonSDV_o0000
1_nMC6T01?l0003oVde^oi]=K_nKCFh7o`0000?oVEIn00Co0000oiACO_nDDgko00000_nEDgd5o`00
00?oU5Z900?o0000ohiER?n>EHP00_n>EHP3o`0000GoReV@00?o0000ohEDSon5E8l00_l000000on8
FYKo0000oh9FUP03oh9FUPCo00000omnEiX3o`0000?oNeRM00Co0000og9CW_l0003o00000_mdEZ40
1ol0003oL5BQog1DXOm`E:7o0000og1GYOl000000_mXDZD3o`0000CoIe>W00?oIEJ/o`000?mQDZ/0
0omQDZ/2oeUA[P03o`000?mCCk3o000000?oDe2a00Ko0000ode@]Om=D;Go0000ode@]Ol00003odA?
^0;o00000_llC[/6o`0000;o@5O200_o<U?4o`000?lmF/Oo?E[7obmDaol0003o9e77o`000?lmHLgo
0000obIEbP02o`0000;o=f?A0_lWG]42oc][e`;o;6GG00Co96;Fo`000?m0MMgo00000_l]KM`5o`00
00;o=gOQ0ol00002odB4i`;o000000?oFYC]o`000?mBTNd00_mBTNd00ol0003oJj;aof^Rl@0;o`00
0003ogV]m?l0003o000000;o00001?n;_?L00ol0003oWlWfoio9mP04o`0000;oXL_e00?o0000okKE
l?l000001?nhe^l2o`0000;o`Mg^0_l00003omCUh`;o000000?ognWJon7[fOoQjmT00_l000000oo^
llOo0000onkba`02o`000004ooGaZOl0003o0000o`0000oooo]Z00?o0000oookJ_oonfX0?_oonfX0
0ol0003ooo]ZoookJP0;oookJP003?oonfX00ol0003ooo]ZoookJP0ZoookJP04o`000?oCb<oodlS?
o`0000;odlO?00Oo0000om;7d?l0003odLO@o`000?o@am7o000000?od<KA00Wo0000olo5d?l0003o
clGAo`000?o>a=7o0000olg5dol000001?o<a=82o`000007ol_3d_l0003obl;Bol_2d_l0003obL?D
o`000004olW2d`?o000000?ob<7Do`000?o6`MD00_o6`MD2o`0000?oaKoE00Goa[oCo`000?o3_mKo
`koFo`000003onW1Z`?o00000ooW_:X3o`0000?ohkNX0_l000001OoU/j7o0000on>aX_oS/J;o0000
00;ohJnR0_l00002omn[W`03o`000?oLZJ3og:VP00Co00000ooKY9X01?l0003ofJ6Ko`000?l00004
omJKU`;o000000KoeY^Go`000?l0003o0000omBETOl00003om2AT@03o`000?o=Si;ocHnB00Co0000
00?ocHZ:o`000?o8QHX00oo8QHX2o`0000;ob8F;1?l000001oo3NX3o0000ol1gOoo0Mgoo0000ol5h
Ool000001?nmMH000ol0003o^g9oo`00000>o`000004ok5QL_l0003o[E]/o`0000CoZUM[00Co0000
ojUGK?nYEfco00000onTDV/@o`0000?oX5ao00?o0000oiUFO_nIEWh01?nIEWh00ol0003oU5=no`00
0003o`000003oiUNROl0003oU5Z900GoU5Z900?o0000ohiER?l000000_l000000onAGI3o0000oh]I
T005oh]IT0?o00000on8FYH00ol0003oPUJFoh9FUP02o`000004ohAKV_l0003oOURKogiHV`;o0000
00?oOUNJo`000?mkF9d01?mkF9d2o`0000CoM5JQ0_l000001om`E:7o0000og1GYOm`EjGo0000ofQB
YOl000000_m_F:L2o`0000;oIe>W00Co0000ofEF[?l0003o00000_mQDZ/01?mME:ooFE6^oeUA[_mI
DJh2o`00000:oeEB/_mCD;7oDe2aoeYF]?l0003oCE2eo`000?m=D;GoE5Jgo`0000;oA4nh0_m>Ek/5
o`000003ocE<_OlhDL3o000000;o@5O200Co0000oc9Ca?lmF/Oo00000_l_E<L01_lWDLOo0000oceQ
cOlmHLgo9UG:o`0000;o?VOB00Ko=f?Ao`000?lWG]7o9ekAoc][eol00002obaUe`;o00000_m0MMd0
0ol]KMco0000o`000002odQoh`Co00000_mBR^P01Ol0003oA8CWo`000?l0003oGYK]00Co000000Co
DY7]o`000?m[X_7o00001?mUWo400ol0003oO:kcogb^l`04ogb^l`;o00001on;_?L2o`0000OoXL_e
00?o0000okSFkonhe^l00onhe^l01?l0003o`Mg^ol7Mk_l00002olCPk@05o`000?oDiN?o0000omKV
hOl000000_oQjmT01Ol0003ohnWFon?Ye_l0003ok_;700;o000000?omO6Yo`000?l000000_l0000?
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX02_oonfX000cooo]Z00?o0000oook
J_oonfX0:OoonfX01?l0003odlS?om?8col00004om?7c`;o000000?odLO@o`000?l000000oo@a]40
1Ol0003oclG@olo5d?o?aM3o000000?oc/CA00Go0000olc4d_o<a=;oc<CBo`000003olc3dP;o0000
0oo;`]801Ol0003obL;ColW2doo9`]?o000000CobL7C00Go0000olS1dol0003oa/7Eo`000004olFo
e@?oa[oC00?o0000ol>oe_l000000ooY`J/00ol0003oj;n[o`000002onNlZP04o`000?oU^Z[oiKZZ
o`0000;ohkNX00?o0000on6dZOoQ]:T01?l00003on6_XP04o`000?oO[J;o0000o`0000?og:VP00?o
0000omVVX_oIYZ800_l00002om^TVP03o`000?oIXI_ofJ6K00?o000000KoeY^Go`000?oBVISo0000
omJKUol00002omBIUPCo000000Cod96Ao`000?o=Si;ocHnB0_l00002olf?T@Go000000?ob8F:o`00
0?l000000_o8QH/01?l0003oa8:;olB2Roo4PX/7o`0000Go_GF00_l00003ok]bO`03o`000?ngL83o
]g2000?o]g2000?o0000ok=]POncKH400_ncKH4?o`0000?oZF=o0_l00007ojAOOP;o00001OnPG7l0
1?l0003oVEInoiUFO_nIEWh5o`0000;oV5f900Co0000oiUNROnIGXWo00001?nDFXT4o`0000CoTEf@
00?o0000oh]IT?n;FI000_n;FI03o`0000GoR5ZF0ol00003ohAKVP04o`000?mnF9_oOURKogiHV`?o
00001?mkF9d2o`0000GoM5JQ1?l00002og1GY@03ofQBYOl0003oKeRW00?oKeRW00?o0000ofMCYol0
00000omUEZ`00ol0003oHE:[o`000002oeeD[`07oeUA[_l0003oGeN`oemG/?l0003oDe2ao`000002
oeYF]003o`000?m=D;Go000000;oE5Jg1ol00002odUH_`;o000000?o>570o`000?m0El800_l00000
0olbDlCo0000o`000002obmDa`;o00000_lmHLd2o`0000;o?VOB0_l000001?lWG]7o0000o`000?l0
0002obaUe`;o00000_m0MMd3o`0000;oB7oS00Ko0000ocijh_l0003o0000oe::j?l00002odZ6i`?o
00000omGT^d?o`000003ogb^lol0003o000000?o00001?n=__L00ol0003oXL_eoj7;m@03o`0000Co
Y<ge0_l00002ok[Gk`03o`000?o1gNko000000?oa>3]0_l000001OoFi^7o0000o`000?oQjmWo0000
00?ohnWF0_l000000oo_l/Go0000ooGaZ@04o`00013ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0
003ooo]ZoookJP0:oookJP003?oonfX00ol0003ooo]ZoookJP0XoookJP;o000000?odlS?o`000?oC
all00ooCall00ol0003od/K?om;6c`02o`000004om76col0003od<KAo`0000?oclG@00Wo0000olo4
d?l0003oc/CAo`000?o>a=3o0000olc4d_l000000oo<`m802_l0003oc<;Aolc2dOl0003obl;Bo`00
0?o;`]7o0000olW2dol00003olW1d`06o`000?o7`=?oal3Co`000?o8`M?o00001?o5_mD4olJod`Co
000000CojL6[o`000?oX_j_oj;n[0_l000001?oW_:[o0000onFjZ_oU^ZX2o`000005on>gZ?l0003o
hKBYon6dZOl000000_oR/Z@2o`0000;ohJnR00?o0000omn]X_oO[J801?l00003omVVXP04o`000?oK
YYko0000o`0000?ofJ6K00?o0000omJNW?oFWY`01_l00003omBIUP03o`000?o@UYOod9JG00Ko0000
0oo=Si401?l0003obH^BolV;T_o9Ri86o`0000Coa8:;00Go0000ol5oRoo1Oh_o0000ol:0R`0:o`00
0003ok]bOol0003o]g2000?o]g2000?o0000okI^P?l000001OncKH42o`0000Go[fQo00?o0000ojeW
Ool000001onYHgl00ol0003oY5mnojAOOP05ojAOOP_o00000onMHXX01?l0003oV5f9oiQMROl00003
oiUNR@03o`000?nDFXWo000000;o00000_nGHY400ol0003oTEf@oi5MT003oi5MT003o`000?n;FI3o
000000;o00000_n>GiH00ol0003oR5ZFohQJUP02ohQJUP;o00001_n4FiX00omnF9_o0000o`000003
oh1KWP06o`000?mkF9go0000o`000?mlG:7o00001?mdEZ400omiG:Co0000og5GY@02og5GY@03o`00
0?m`EjGo000000GoKeRW0_l00003ofEF[0;o00000_mPE:d00ol0003oGEB_o`000004oemG/003o`00
0?mJE[CoFUJd00;oFUJd1ol00002odiG^`;oAEFn0_m9F;l2oceB_`;o000000Co@5O2odMLa?m7G<Co
<U?40_m4GlT00ol0003o;eC7o`000002o`00000=oceQcOl^G<ko;Uc>o`000?lnIm;o0000obmQd_l0
003o9ekAo`000?m1KmSo0000obaUe`02o`000003odIhg_m0MMgo000000;o=6oL00?o0000odQohol0
00000_lnN^83o`000003odZ6iol0003oBXKW00;oHiS]00So0000oeNBkOl0003o0000oeNBkOl0003o
Kj?ao`0000CoJJ7a00?o0000ogn_lomo[o<01?mo[o<2o`0000CoSKkg00Co0000ohfnmon=__OoSKkg
0_l00003ojC=m@?o00000_nVc_D01Ol0003o^]O_ok[Gkonjenoo000000;oa>3]0_l000000oo6h^co
0000o`000002omSWh004o`000?oSjMKohnWFon?YeP;o000000Goko;5o`000?o`ll?o0000ooGaYP03
o`00017ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0:oookJP003?oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oFb<go000000;o00000ooCall02Ol0003od/K?om;6cooBa/oo
0000om;5c_l0003odLK?o`000003olo5d004o`000?o?a=3oclC@olo4d0;o000000?oc/C@o`000?l0
00000oo<`m800ol0003oc<;Aolc2d@02olc2d@;o000000?obl;Ao`000?l000000oo9`M<01?l0003o
al3ColO0doo7`=<3o`0000?oaKoE0oo6_m<2o`000005olJndol0003ojL:]onW2[Ol000000_oX_j/0
1?l0003oikf[onNmZol00002onFjZP03o`000?oS^:[ohkRZ00Co000000Gogk:Xo`000?oR/ZCo0000
on6aY002o`0000?ogjfR00?o0000omf[XooMZj<00_l00002omVVXP03o`000?oKYYkofjJN00Co0000
1?oFWY`00ol0003odY^Mom:KW@05o`0000Cod9JG00?o0000olbBV?o<TYP01?l000000oo=Si7o0000
olV;TP03olV;TP;o00000_o8Ri84o`000004olB2Rol0003o`Gn;o`0000;o`X2;00?o0000okimRonn
OH/00onnOH/2o`0000;o_7^;5?l00002ojmXO`;o00000onYHgl=o`000003oj9UR_l0003oXfJ:00?o
XfJ:00?o0000oieRR_nMHXX01?nMHXX00ol0003oV5f9o`000006o`0000GoUf:A00?o0000oi5MT?nA
GI001Ol00005ohiOUP03o`000?n8FYKo000000;o000000?oRUnJo`000?n4FiX01?n4FiX2o`0000Go
P5^N0ol00002ogaLX@04o`000?mdEZ7oM5JQogAFX@;oNEbT00Co0000og5GYOmaEjGoLENU0ol00004
ofmHY`08ofiK[?l0003oIeJ[o`000?mUEZco0000ofIH[_l00003of1D[@;o00000omOEk001?l0003o
FeReo`000?mJE[@5o`000006oeAF]ol0003oC5Fko`000?m>Ek_o00000_m5EKh00om9F;oo0000oceB
_`02oceB_`03ocQA`?l0003oAec400;oAec400Go0000odAObOm4GlWoA5o9o`000003odATcP03o`00
0?l^G<ko;Uc>00?o00000_l_HM801?l0003o@FoHod5_f?m1KmP3o`000004odIhg_l0003o0000ocA_
g0;oCX;S00?o0000ocijh_lnN^800_mHSNP00ol0003oBXWYodZ9j@02o`000003of>HkOl0003oG9C/
00;oG9C/2?l000000omYXO7o0000ogn_l`02ogn_l`;o000000?oOjoco`000?l000000ol00005oi2o
m`04o`000?nTcOGo0000o`0000KoY/ke0_l000001?nlf>ko0000o`000?l00002olKRk003o`000?o9
iN_obNG[00?o00000_oSjMH01?l0003oi>oFo`000?l00002oo3c``Go00004_oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z00[ooo]Z000<oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o
0000omK8cOoFb<d00_l000001?oDalko0000om?7col00003om;6c`03o`000?oBaLkod/G>00;o0000
00CodLG?o`000?o?aM3o00000oo?a=000ol0003oc/?@olk3d002o`000004olk3d?l0003oc<?Bo`00
00?oc<;A00Co0000ol_1dOo;`M7obl7A0_l000001?o;`M7o0000olW1dol00003olO0d`04o`000?o8
_m7ob;oAolRod@Co000000?oa[oCo`000?o6_]<00_o6_]<00ol0003ojL:]onW2[@02o`000004onRo
Zol0003oikf[onNmZ`;o000000GoiKZZo`000?oS^:[ohkRZo`000002on:fZPCo00000ooQ/J@4o`00
00?ogJ^S00?o0000omZXXol000000_l00002om^VWP03o`000?oIY9kofJBN00?o000000?oeYjLo`00
0?oBVid00_oBVid2o`0000;odibK0_l00003om2FU`03o`000?o<TYSoc9:H00;o00000_o=TiL4o`00
0004olV;T_l0003oaXVBo`0000;ob8^B00Co0000olF7T_o5Qi;oaHNB1ol00005okimR`;o00000onl
Nh/00ol0003o^GR;okUhR`02okUhR`03o`000?ngMh_o000000Ko]GF;00?o0000ok5bRonaLX/00_na
LX/7o`0000Co[6f;00?o0000ojQZRonXJX/01OnXJX/00ol0003oXVF:o`000004oj=VRP04o`000?nM
HX[oWF::oieRRPGo000000?oVfBAo`000?nLIY400_nLIY400ol0003oUf:AoiMRT@02oiMRT@Go0000
0onCHiH00ol0003oSUnFohiOUP03ohiOUP?o00001On:GiX00ol0003oQ5^Jo`000002o`000003ohIO
WOl0003oP5^N00?oP5^N0_l00002ogaLXP;o000000?oO5bQo`000?mdEZ401?miG:@3o`0000;oLUVW
0_l00002ofmHY`;oKU^/00?o0000ofMFZomWEZ/00_l000001OmVF:ko0000of1D[OmPE:go000000;o
IeZ_00Co0000oemG/?l0003oFeRe0ol000001_mJE[Co0000oe=F^?l0003oDeJho`0000;oC5Fk00Co
0000odiF^ol0003o00000_m5EKh2o`0000?o?E:o00Ko0000odMLa?m7G<CoAec4oc]Iaol00002odAO
b@04ocMLbol0003oA6C>odATcP;o=eo>0_l^G<h2odA[e003o`000?l_HM;o000000;o000000Co@FoH
o`000?leJMOo=FWG0_l000001_lhLmko0000o`000?m>P^?o0000od1ni0;o000000?oF8gXo`000?m:
RNT01?m:RNT00ol0003oG9C/oebDk002o`0000;oG9C/00?oLZGao`000?m]X_000_m]X_05o`0000?o
P[7c00?o0000ogb`mOl000002?n@_oL00ol0003oY/keojK>m@02ojK>m@?o000000?oZM3eo`000?nl
f>h00_l00002olKRk0;o00000_o9iN/01ol0003oc=oVo`000?l0003ohnWFo`000?oTkmH00ol00000
0oo`ll?o0000o`000004o`0001?ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0:
oookJP003?oonfX00ol0003ooo]ZoookJP0UoookJP04o`000?oFb<goe/S=o`0000;oeLO<00?o0000
omC7c_l000000ooBa/l01?l0003od/G>om;5c_l00002om75cP03o`000?oAaLoo000000?oclC@00Wo
0000olk3d?o>`m3oc/?@o`000?o=`m3o0000olk3d?l000000oo<`]401Ol0003obl7Aol_1dOo;`M7o
000000;ob/3A00?o0000ol_1dOl000000oo7`=<01ol0003ob;oAolRodOo8_m7o0000olRndOl00000
0_o6_]<2o`0000;oa[kC00Co0000onO3/_l0003o00000_oX_jd2o`0000;oikf[00?o0000onFkZol0
00000ol00003on:fZP04o`000?oO]:[o0000o`0000?ohK6T00?o0000omn_Y?oO[j@00_l00002omf[
X`03o`000?oJZ:?ofZRS00Co00000ooIY9h00ol0003oeZ6OomJQW`03o`0000;odY^M00Ko0000om>L
VooCW9_odibKo`000?oAVI/3o`0000?oc9:H00?o0000olfCUoo=TiL00_o=TiL00ol0003obXnGolZ?
U`04o`0000;ob8^B00?o0000olF7T_o5Qi800_o5Qi800ol0003o`XFBo`000002ol:5TP[o000000?o
_7^;o`000?niN8/00oniN8/00ol0003o]gN;o`000006okEeR`03o`000?naLX_o/G:;00Co/G:;0_l0
0007oja]R`03o`000?nXJX_oZ6Z;00GoZ6Z;2ol00003oj1XT@04o`000?nKI97oVfBAo`0000?oW6JA
00?o0000oiMRTOl000000_l00002oiQWU`03o`000?nCHiKoTf>F00CoTf>F00?o0000ohiOU_l00000
0_l000000on?Hi[o0000ohYOVP03ohYOVPCo00001?n6Gid00ol0003oP5^No`000002o`000003oh9O
XOl0003oO5bR00;oO5bR0ol00004ogULY0;o00001OmbFJL00ol0003oKeRWofiK[003ofiK[004ofMF
Zol0003oKE^]ofeK[@;o000000?oH5B]o`000?mWFZl00_mWFZl4o`0000;oFeRe0ol00002oe=F^003
o`000?mIFkWo000000;oC5Fk00?o0000oeAL_OmDG;d00_m5EKh2oe1M`@04o`000?lmD[oo?E:oo`00
00;oAec400Go0000oc]IaolkFLOoA5o9o`000002ocMLb`03odATc_l0003o=eo>00;o=eo>00?o;Uc>
o`000?m4Jm@00_m4Jm@01Ol0003oAg;IodMbfOm7L]Wo000000;o=FWG0_m=Nmh2o`000003ocQcg_l0
003o000000;o00000_m0O^@5o`000003odZ9jOl0003o000000?oI9W]1?l00002offRl0;o000000?o
KJ;`o`000?n2/O<01?n2/O<00ol0003oO;3eo`000004o`0000CoT/7g00?o0000ojK>mOl000000_l0
0005ojW@m@05o`000?nnfNgo0000olKRk?l000000_o9iN/2o`0000?oc=oV0_l000001ooTkmKo0000
onK`dol0003ol??3o`000?oblKh01Ol0000CoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oook
J_oonfX02_oonfX000cooo]Z00?o0000oookJ_oonfX09?oonfX2o`000003omK8cOl0003oeLO<00?o
eLO<00Go0000om?6cOl0003od/K?o`000002om;5cP03o`000?oAaLkodLG>00;odLG>0ol000000oo?
a=3o0000olk3d002olk3d003o`000?o=`m3ocL?@00Co000000?oc<;Ao`000?o;`M400_o;`M401?l0
003ob/3Aol[0dOo:`=43o`0000;oal3C00Go0000olRodOo8_m7ob;oAo`000003olRnd@06o`000?o6
_]?o0000olJmd_l0003oa[kC0_l000001_oW`k;o0000onRo[OoX_jgo0000onNm[0;o00000_oU^j/0
0ol0003ohkV[on>iZ`02o`0000;oh[JZ00?o0000omndZ_oO]:X01?l00003omn_Y004o`000?oM[JGo
0000o`0000?ofZRS00?o0000omNVY?l000001?l00004omJQW`03o`000?oCWYoo000000;o00000ooC
W9/01?l0003odIVKom6IVooAVI/3o`000003olbBV?l0003ocI>G00?ocI>G00Ko0000olZ?Uoo:SiOo
bXnGo`000?o6SIP7o`000004olF7T_l0003o`XFBo`0000;o`XFB00?o0000okn3T_noPi800onoPi82
o`0000;o_86B3?l00002okEeR`;o00001_naLX/2o`0000?o[6f;3Ol000000onTK97o0000ojE]TP03
ojE]TP03o`000?nPJ97oX6RA00CoX6RA00?o0000oi]TTOl000000_nLIY44o`0000GoV6NG00?o0000
oi=SU_nCHiH00_nCHiH4o`0000CoSf>J00?o0000ohYOV_l000000_l00002ohaSW@03o`000?n6Gigo
QUnM00;oQUnM0ol00004oh9OX@Co00000_mmGZ@3o`000004ogULY?l0003oNEjWo`0000CoLUVW0_l0
00000om_FZ_o0000ofiK[002ofiK[003o`000?m]FjgoKE^]00;oKE^]0_l000000omWFZoo0000o`00
0002o`000003oemH/ol0003oFeRe00;oFeRe00Ko0000oemK]_mOFkKo0000oe=F^?l00002oeUK^@03
o`000?m<EK_oE5bm00?oE5bm0_l00003oe1M`@04o`000?m0El?o0000odMLa0;o000000Co>eW7o`00
0?l0003o00000_lgG</2o`0000?o=eo>0_l00002odA[e0;o=fOE0_m7L]T01ol0003o>VkJo`000?l0
003oCG_No`000?loMml00ol00002oe64i0Co00000omJS^T5o`0000CoI9W]00?o0000ogBVlOmdY_40
0_mdY_49o`0000;oOk7d00?o0000oi;1monB`OL01OnB`OL00ol0003oZM3eojW@m@02ojW@m@?o0000
0_n/do@00ol0003o_]W]o`000002olWUj`03o`000?o<gnKoc=oV00;oc=oV00?ocNOYo`000?oHkN80
0_l000001OoVl=?o0000oo3c`ol0003ol_6n00Co00005OoonfX00ol0003ooo]ZoookJP0joookJP03
o`000?oonf[ooo]Z00[ooo]Z000<oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000omK8c?oFb<`0
0_l00003omG7c004o`000?oDa/co0000om?6c@;o000000?od/G>o`000?oAaLh00ooAaLh00ol0003o
dLC=om74c@02o`0000?oc/?@00Co0000olg3d?o=`m3o00000oo>`Lh2o`0000?obl7A00Go0000ol[0
dOo:`=7ob/3Ao`000003ol^oc`;o00000oo8_m400ol0003ob;kAolRnd@02olRnd@;o00000oo6_M80
0ol0003oi/BdonK4]004o`0000?oikf/0ol00003on>iZ`04o`000?oR]j_o0000o`0000?ogkBZ0_l0
00001OoP/ZOo0000omn_Y?oO[jCo000000?ogJfU1?l00002omNVY0;o00000_oIYZ82o`0000?oeZ6O
00Co0000om>NWooCWYoodijO1?l00004om6IV`03o`000?o=UY_ocIJK00Co000000?ocI>Go`000?o:
SiL00oo:SiL00ol0003oaXfHo`000002olR>U`04o`000?o6S9OoaXbGolJ<U`Go000000?o`XFBo`00
0?noPi801?noPi82o`0000?o_86B00?o0000okUmT_niOI800_niOI800ol0003o^7bBo`000003okIk
TPoo00001?n]M9800ol0003oZG6BojUaTP05ojUaTP03o`000?nTK97o000000CoYFfB00Co0000oj1X
TOnPJ97oX6RA2?l00002oie[U`03o`000?nHIiOoV6NG00CoV6NG00?o0000oi=SU_l000000_l00002
oiAWVP03o`000?n?Hi[oSf>J00;oSf>J0ol00005ohaSW@03o`000?n6GigoQUnM00;o000000?oR6>Q
o`000?n2Gj400on2Gj42o`0000GoOEjT00?o0000ogQLYOl000000_l000000omiGZOo0000og9IY`02
og9IY`03o`000?mgGZWo000000;oKeZ[00Co0000ofiK[?l0003o00000om]Fjd4o`0000?oIeZ_00Go
0000oemH/omOF;?o0000oe]H]@02o`0000?oGe^f0_l00003oeUK^@;o00000omDG;d2odaK`@?oD5g1
00Co@eS2o`000?l0003oAec40_m=HLH2oc]Ia`;oBfC;00Go0000ocMLbol0003oBVW?o`000002ocMO
cP05o`000?m;KmCoBfoDodA[e?l000000_lgImD00om7L]Wo0000ocY^fP02ocY^fP?o00000oloMml0
0ol0003oDHCToe64i002oe64i0Co00000_mJS^T2o`0000;oJ9[]0_l000000omTVNgo0000ogBVl@06
ogBVl@05o`000?n5/_?oQK;cohFblol000000_mo/O@6o`0000CoUL?f00Co0000ojW@mOl0003o0000
1_n/do@2o`000003olWUjol0003oc=oV00;oc=oV00Ko0000olgWjOo=inWocNOYo`000?oKl=l2o`00
0003onSbd?l0003ol_6n00Go00005_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z
00[ooo]Z000;oookJP03o`000?oonf[ooo]Z02?ooo]Z00Wo0000omK8c?oFb<coe/S<o`000?oFal_o
0000omG7c?l000000ooDa/`2o`000003om?5cOl0003o000000?odLG>00Co0000om74cOoAa<go0000
0_oA`ld00ol0003oc/?@o`000002olg3d003o`000?o>`Lkoc/7>00;oc/7>00Go0000olg1c_l0003o
bl7Ao`000003ol[0d@03o`000?o;_loobko?00;obko?0ol000000oo8_m7o0000olRnd@02olRnd@;o
00000_o8_M001?l0003oa[gBo`000?l00002onK4]004o`000?oU`[?oiL:co`0000?oikf/00?o0000
onFl[?l000000_oS^J/01?l0003oh[N[on:gZooR]j/2o`000004omndZ_l0003ogK6[omfaZ`?o0000
00?ogjnTo`000?oM[JD00_oM[JD00ol0003ofj^Uom^[Y@02o`0000;oejJT00Go0000omVVX_oIYZ;o
0000omNTXP03o`0000CodijO0_l000001_oCWYoo0000o`000?l0003odIVKo`0000CocIJK00?o0000
olfFW?o=UY`01?l000000oo:SiOo0000olJ=V002olJ=V003o`000?o8SYOo000000CoaXbG00?o0000
ol:8Uoo2R9L01_l000001?noPi;o0000okf1T_l00003okb1TP03o`000?niOI;o^GfB00;o^GfB00?o
0000okQlT_l000001OnfNi82o`0000Ko/WRB0_l00007ojedTP03o`000?nYLI;oZG6B00GoZG6B0_l0
0002ojE]TPOo00000onQKIL00ol0003oWF^Goie[U`04oie[U`04o`000?nHIiOoV6NGoiQWU`Go0000
1OnDIiX00ol0003oSf>Jo`000002o`000003oi5WW_l0003oS6>M00GoS6>M0ol00003ohQSX@03o`00
0?n2Gj7oPUnQ00;o000000?oQF>To`000?mmGZ@01?mmGZ@2o`0000?oNEjW0ol000001OmbFJOoMejY
ogMNZOmgGZWo000000;oKeZ[0ol000001?m]Fjgo0000o`000?l00002of]M/@04o`000?mUF[7o0000
ofMJ[`;o00000omOF;<3o`0000;oGe^f00Co0000oeUL^_l0003o00000_mIFkT2oe9K_@;oE5bm00?o
0000odaK`Om<Fl400_m@GL401Ol0003o@eS2od=H`_m0El?o000000?oCF7600?o0000od]Tbom;I</0
0_m;I</2o`0000;oBVW?0_l000000olfGlkoBfoDod]_e002o`000004ocMWeOl0003o0000o`0000?o
>VkJ00So0000oe5ngol0003o0000ocmggol0003oEhOTo`0000;oDHCT0_l00003oen@j@Co00001?mX
V^d2o`000003ogBVlOl0003o000000[o00000_n3/o@00ol0003oUL?foiG3mP06oiG3mP03o`000?n/
doCo[=?d00;o[=?d0ol00003ojkEm004o`000?o<gnKoc=oVo`0000CocNOY00?ocnSXo`000?l00000
0_oMlmd8o`0001Oooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0:oookJP002ooo
nfX00ol0003ooo]ZoookJP0RoookJP05o`000?oFb<coe/S<omK8c?l000000ooFal/01Ol0003oe<K<
omC6c?oDa/co000000;oe<G;00Ko0000om;4c?oBa<co0000om75c_l00002om74c@04o`000?oA`lgo
dL?=om73c@?o000000?ocL?@o`000?o>`Lh00oo>`Lh00ol0003ocL7>olg1cP04o`000003ol[0dOl0
003obko?00?obko?00?o0000ol^ncoo;_/l01?l000000oo8_]7o0000olRmd003olRmd0Co000000?o
i/Bdo`000?oU`[<00_oU`[<2o`000004onNm[?l0003oiKb/onFl[0;o000000?ohkV[o`000?oR]j/0
0_oR]j/01?l0003oh;F/o`000?l00002omfaZ`03o`000?oO/:Oogk2W00?o000000?ogJfUo`000?oK
ZjD00_oKZjD01Ol0003of:RVo`000?oGYZCo000000;ofJJR00Co0000omNTX_oGY:;oejBR0ol00000
1_oCWYoo0000om2LX?l0003odijOo`0000;odIbN1?l000000oo=UY_o0000o`000003olfFW003o`00
0?o;Ti_obi>K00Oo00001?o6S9L01ol0003o`XRGol:8Uoo2R9Oo0000ol:9Uol000000oo1QiL;o`00
0003okUmT_l0003o000000Ko]W^B0_l00005ok9hTP03o`000?naMi;o000000Ko[GBB0_l00003ojUa
TPSo00000onWLYL00ol0003oXFfGoj5]U`04oj5]U`04o`000?nMJiOoWF^Goie[U`Oo00000onIJi/0
0ol0003oU6NJoiAWVP03oiAWVP?o00001OnAIih00ol0003oS6>MohaSW@02ohaSW@;o00001_n8Hj42
o`0000?oQF>T00Co0000ogeNY?mmGZCoOEjT0_l000000on1HZKo0000ogUNY`03ogUNY`?o00001?mg
GZT00om_FZ_o0000o`000003o`000003ofeK[Ol0003oJefa00?oJefa00Go0000ofEJ/OmWFZoo0000
of=K/`02oemH/`06o`000?mUGKGoIEfeo`000?mOFkKo00000omIG;X00ol0003oFE^io`000002oe9K
_@?o00000om<Fl42o`0000?o@eS20_l00002odeQaP;o@eo90om;I</01?loH/go0000odYYcom:JLl2
oceVdP09o`000?m;KmCoBfoDo`000?llJMGo0000ocMWeOl0003oCGKJ00;o000000?o>VkJo`000?mA
O]l00omAO]l2o`0000?oEhOT0ol00003oen@j@03o`000?mESNWoEHgY00?o00000_mXV^d2o`0000Oo
LJSc00Co0000ohRdl_n8]?;o00001?n3/o@00ol0003oUL?fo`000003o`0000?oV<Gf00Co0000ojcC
m?l0003o00001?n^eO@01Ol0003o/MSdo`000?o<gnKo000000;ocNOY0_l00002oloXj007o`000?oM
lmgogO?Mo`000?oNl=go0000on[ia`02o`000003onccW_l0003o000001Sooo]Z00?o0000oookJ_oo
nfX0>?oonfX00ol0003ooo]ZoookJP09oookJP002ooonfX00ol0003ooo]ZoookJP0RoookJP;o0000
00?oe/S<o`000?oFal/00_oFal/01Ol0003oeLK;o`000?oDa/co000000;oe<G;00?o0000omC4bol0
00000_oBa<`2o`000003om74cOl0003odL?=00;odL?=00?o0000om32c?o@`/`00ol00003olk1cP04
o`000?o=`LkocL7>o`0000;ocL3=00Co0000olbocol0003o00000oo;_ll01?l0003obkk?ol^ncoo;
_/l2o`0000;ob;k@0_l00003olRmd005o`000?o8_M3ob;g@o`000?oVa;@00_l00002onG2/`04o`00
0?oS_k?ohknco`0000;oiKb/00?o0000on>j[?oS^Z`00ol000002OoR]j_o0000on2e[?oP]Jco0000
omjc[?l0003ogK6[o`000002omn`Y`03o`000?oM[ZOogJjW00;o00000_oKZjD01?l0003of:RVomRX
Y_oHZ:H4o`0000CoejBR00?o0000omBQX_oDXJ801Ol00004om6LWP03o`000?o>VIoocYVO00Co0000
00?ocIJLo`000?o;Ti/00oo;Ti/01?l0003oaHnLolF?W?o5Si`9o`000003ol:8Uol0003o000000Go
`HNG00?o0000okf5Uol000000onmQ9P01?l0003o^82GokR0UonhP9LNo`0000CoZWBH0_l00005ojMb
U`03o`000?nQKIOoXFfG00?oXFfG1Ol00003oii_V`03o`000?nIJi_oVF^K00GoVF^K00?o0000oiAW
V_l000000_l000000onFJYko0000oi5WWP02oi5WWPgo00000_n8Hj42o`0000GoQF>T0ol00003oh5R
YP03o`000?miGZOoNEjW00;o000000?oOF:Yo`000?mfGj/00_l000001?mgGZWo0000o`000?l00003
og=N[0?o00001?m[GK42o`0000;oJejb00?o0000oemH/ol000001?mUGKD2o`0000?oFEbj0ol00003
oe9K_@;oFV6o00?o0000odaK`Om<Fl400_mFH/<00ol0003o@eS2od=H`P02oe9Ta`07o`000?m=HLKo
0000od=ObOl0003oBfC;o`000002ocmRc@?o00000olmI]82o`0000?o?6WE0_l00003odeffP?o0000
0_mAO]l00ol0003oAWWOo`000003o`0000;oCH;T0ol000001?mOT>Wo0000oeF=jOl00003ofbLk@[o
000000?oLJSco`000?l000001ol00008oiS5mP04o`000?n^eOCo[]GdojkEm0;o00000onaf?@3o`00
0003olgWjOl0003ocnSX00;ocnSX00Cod^[Vo`000?oMlmgo00000_oNl=d2o`000003on[hb?l0003o
000000;o00006?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z00Wooo]Z000;oook
JP03o`000?oonf[ooo]Z027ooo]Z00Co0000omW7b?l0003o00000ooFal/01?l0003oeLK;omG6booE
a//2o`000003omC5bol0003oe<C;00;oe<C;00Go0000om;3c?oB`lcod/?<o`000003om73c@03o`00
0?o@`/cod<;<00;od<;<00Go0000olo1cOl0003oc/7>o`000002olg1cP03o`000?o=`<gocL3=00;o
cL3=00Ko0000ol^oc_o;_lko0000ol^ocol00002ol^nc`;o00000_o:_/h01ol0003ob;k@o`000?o8
_M3o0000olRmd?l000000_o8_M002?l0003oi/BdonK4]?l0003oiL:co`000?oU`[?o00000_oS_k<2
o`000005onFl[?l0003ohkZ/on>j[?l000000_oR^:`2o`0000;oh;F/00?o0000omjc[?oN/j`01?l0
0003omf^Y`05o`000?oK[:Oo0000om^[YOl000000ooHZ:H2o`000006omRWY?l0003o0000o`000?oG
Y:;o00000ooDXJ800ol0003ocijSolnNX`04o`000003om6LW_l0003ocYVO00?ocYVO00?o0000ol^F
Wol000001?l000000oo;Ti_o0000olF?W003olF?W0;o00001?o6T9/00ol0003o`H^Lol6;W006o`00
0005ol67Uol0003o_HFGokf5Uol000000_nmQ9P00ol0003o^82GokR0U`03okR0U`;o00001_ngP9P2
o`0000Go/gbH00?o0000ok9kUol000001_n^N9P2o`0000OoZWBH00?o0000ojMbUonWLYL01?nWLYL0
0ol0003oXFfGoj5]U`04o`000003oj=bVol0003oWVnK00CoWVnK00?o0000oiU[VonIJi/00onIJi/4
o`0000?oUVZN1Ol00002oi5XW`?o00001?n=Ij800ol0003oR6BRohQTXP07o`0000;oQF>T0_l00005
oh5RYP?o00000ommHZT7o`0000?oLej/00Co0000og9Q/?m/GK3oK5f`0_l000000om[GK7o0000o`00
0004of]N/P?o00000omUGKD2oeiM^003o`000?mIG;[oFEbj00?oGV2l00?o0000oe9K_Ol000001?mJ
HKl2o`0000?oEV;30_l00003oe9Ta`?o000000KoBfC;o`000?l0003o?f;=o`000?m:JLl2oe1]d@;o
?FKB0_m@L]H2o`000003ocaYeOmBNM_oDWWK00;o000000WoCGKJo`000?l0003oEh7Oo`000?mAO]oo
0000odIigol000000_mLRN@4o`0000;oI9?Y1ol000001Om/W>go0000ofBJk_mTV^ko000000KoM:[c
00?o0000ohbfl_l000001On7]?<00ol0003oV<GfoiS5mP04o`0000;oVlOf00Co0000ojkEm?l0003o
00001Onaf?@01?l0003o_=kao`000?l00002oloXj003o`000?oBj^Kod^[V00;o00000_oNl=d00ooP
lM[o0000on[hb005o`0001Wooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP09oook
JP002ooonfX00ol0003ooo]ZoookJP0PoookJP04o`000?oIalSofLO8omW7b0;o000000?oe/O;o`00
0?oEa//00_oEa//00ol0003oeLG:omG5bP02o`0000?oe<C;0_l000001_oB`lco0000om72c?l0003o
dL?=o`0000Cod<;<00Co0000om31c?l0003ocl7=0_l000000oo=`Lko0000olg0c@03olg0c@03o`00
0?o=_lgo000000;obko>0_l000000oo;_/oo0000olZncP03olZncP;o00000oo8_M05o`0000;oi/Bd
00Co0000onG2/ooU`[?o00000ooS_k<00ooR_K?o0000o`000003o`0000?oh[R/00Co0000on2f[Ol0
003o00000ooN/j`00ol0003ofk6]om^a[@02o`0000;ogJjW00?o0000om^/YooK[:L00ol000001?oH
Z:Ko0000omFVYooEYZL2o`0000;oejJT1Ol00004olnNX`03o`000?oAWZ;odIjR00Co000000OocYVO
o`000?o;UYoobiJOo`000?o=V9ko000000;obiJN1Ol000000oo5Sico0000olJ@V`04olJ@V`04o`00
0?o1Rico`H^Lol6;W0;o00000oo1Ri`;o`0000;o^82G00?o0000okN0V?ngP9P01?ngP9P00ol0003o
]WjHo`000004ok=lV004o`000?nbNiOo/W^Go`0000Go[WRH00?o0000ojihUol000000onZM9P>o`00
00?oXW6K00?o0000oj=bVol000001_nNKi/00ol0003oVF^Ko`000002o`0000;oVVfN00?o0000oiIZ
W_l000000_l000001?nFJioo0000oi5XWonAJ9l3o`000003oi9[X_l0003oSFNR00CoSFNR0ol00004
ohUVY003o`000?n4I:GoQ6BU00Co00001?n1HZH2o`0000?oOF:Y1Ol00003ogIP[0;o000000CoLej/
og9Q/?mbHK3oLV6`0om/GK04o`0000?oJejb00Go0000ofQP]_l0003oI5jfo`000002ofEM]@?oGUfh
0_l000001?mJGK_oGV2loeiP_?mNH;`3o`0000?oFV6o00?oDV33o`000?mFH/<00_mFH/<2odeQa`;o
DVC700Go0000odIOb?m6GlSo@eo9o`000002oe5Xc003o`000?loH/go000000?oD6gA00?o?FKBo`00
0?m@L]H00om@L]H00ol0003oDWWKoe9if`02oe9if`?o00000_mGPMl4o`0000;oG8WT00Co0000oeB5
i?l0003o00000_mTTnT01?l0003oFhoYoe^?jOl00003og6Ok@[o000000?oM:[co`000?l000002?l0
0007oi_7mP04o`000?naf?Co/MSdok7Hm0?o000000Oo]MObo`000?l0003o_n7`o`000?o?j>So0000
00?od^[V00Co0000omk`gOoNl=goh?7J0_l000000ooZn<Sok?S3o`000002o`0001_ooo]Z00?o0000
oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP09oookJP002ooonfX00ol0003ooo]ZoookJP0Ooook
JP05o`000?oIalSofLO8omW7b?l000000_oHa/P01Ol0003oeLK;omG6booEa/_o000000?oeLG:00Go
0000om?4bol0003oe<C;o`000002om?3b`04o`000?oA`/codL;<om72c0;o00000oo@`/`01Ol0003o
d<7<om31c?o@`Lco000000;oc/3=0_l00003olg0c@05o`000?o=_lgocKo=olfocOl000000oo;_/h2
o`0000?ob[k>00Go0000olZmc_l0003ob;g@o`000004olRlc`04o`000?oVa;Co0000o`0000?oiL:c
0_l000001OoS_k?o0000on:m/ooR_K?o000000;ohk^^00Co0000on:h[?oR^:co00000ooP]Zd2o`00
0003omjc[?l0003ofk6]00;ofk6]00Co0000omf_ZOl0003o00000ooK[:L00ol0003ofJZWomVZY`03
o`000003omFVYol0003oejJT00?oejJT00?o0000omBSY?oDXj@00_l00003olnNX`05o`000?oAWZ;o
dIjRom6NX_l000000_o?W:44o`000003ol^FWol0003obiJN00?obiJN00Co0000olNCW_o7Tikoai>N
1Ol000000oo6T9_o0000ol6;W003ol6;W003o`000?o1Rico`H^L00?o`H^L00Co0000okj7VonnQi_o
00000_nmQi/01?l0003o^hFKok^5VonkQI/Oo`0000?oZgRK0_l00006ojMfW003o`000?nRLI_oXW6K
00;oXW6K00Co0000oj=bVonSLY_o00000onNKi/5o`0000CoVVfN0ol00003oiI[W`Co00001?nBJj80
1?l0003oSFNRoheWX_n=Ij82o`000003ohiYY?l0003oRFJT00CoRFJT0ol00003ohEVY`?o000000?o
PF:Vo`000?n1IJT01?l00002ogeRZ@;o00001OmfH:`2o`0000CoLV6`00?oK5f`o`000?maHK400_ma
HK42o`000005of]N/_l0003oJ62fofQP]_l000000_mTG[H00omUGKGoHEjio`000002oeiM^0?o0000
0omNH;`2oeQP`004o`000?mJHKooFV6oo`0000;oDV330_mFH/<01?l0003oCF77odeQaom=HLL2o`00
00?oAUo800?o0000oe5Xc?mAJ<`00_mAJ<`2o`0000?oD6gA0_l00003oe1beP;o00000omBNM/01_l0
003oAWOModIggOl0003oEh7Oo`0000;oCWcO0_l000001?mLRNCo0000oeB5i?mDQN@8o`0000?oLIo]
00Co0000ofVLk_mYW>ko00001omnZo02o`0000KoS;Ob00?o0000oi_7m_nKaoH00ol00004oik:mP;o
00001?neeo800ol0003o_n7`okoQl002o`0000;od^[V00Oo0000omG[i?l0003og_3Mon3af_l0003o
i?7E00;o000000Cok?S3o`000?l0003o00007?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oo
nf[ooo]Z00Wooo]Z000;oookJP03o`000?oonf[ooo]Z01kooo]Z00Go0000omW7b?oIalSofLO8o`00
0002omS6b005o`000?oHaLOo0000omG6bol000000ooEaLX01Ol0003odlC;om?4booCa<_o000000?o
dl?;0_l000001ooA`/co0000om72booA`/_o0000om32c?l000000oo@`L`02Ol0003od<3;o`000?o>
`<go0000oljoc?l0003ocL3=o`000003olfoc@05o`000?o=_/co0000ol^nc_l000000_o;_Ld00ol0
003ob[k>o`000003olZmcP04o`000?o8_<oob;c?olRlc`;o00000ooVa;@01?l0003oiL:conG2/ol0
0002on?0/`;o000000Goh[fco`000?oP^k?o0000on>k[P02o`000003on:h[?l0003oh;J]00;oh;J]
00Co0000omjd[Ol0003o00000ooK/Jd00ooI[jgo0000omf_Z@04o`0000?ofJZW00?o0000omJXZ?oF
Z:P00_l00003omNVY006o`000?oDXjCoe:>TomBSY?l0003odZ6U0ol000001Oo?WJ?o0000om6NX_oA
WZ;o000000?ocibQ00?o0000olVHXoo9V:<01?l000000oo;UYko0000olNCWP04olNCWP04o`000?o6
TYooaY:OolJBW`Go000000?o`H^Lo`000?o1Ri`00oo1Ri`01Ol0003o_XNKokj7VonnQi_o000000;o
_HNK00?o0000ok^5VonkQI/00onkQI/00ol0003o^8>LokR3W004okR3W003o`000?nfPI_o000000Co
/gnK00Co0000ok9nVonbOY_o00001?n_Ni/01?l0003o[W^KojikVol00005oj]hV`03o`000?n[N9_o
000000OoYgJL00Go0000oj9aVonRLI_o0000oj=bV`06o`0000?oWg6N00?o0000oiY]W_nJKIh00_nJ
KIh01?l0003oVfnOo`000?nFJil3o`0000;oUfjR00?o0000oi9[X_nBJj801?nBJj800ol0003oSFNR
o`000003ohiYY003o`000?n9IZCoRFJT00;oRFJT0_l00005ohEVY`03o`000?n0HjSo000000?o0000
00CoPFFYo`000?mmHZWoOF:Y0_l000000ommIJco0000ogIP[003ogIP[004o`000?mcHJooLf6_o`00
00?oLV6`00?o0000og5Q/OmaHK400_maHK401?l0003oJEjco`000?l00003ofQP]P;o000000GoJF:g
o`000?mQG[WoGUfho`000003ofAQ^P;oGV2l00Co0000oeQP`?mHH<3oF6300ol00002oe9P``?o0000
0om=HLL2oeQYb@03o`000?m6GlSoAUo800;oEVc=0omAJ<`00ol0003oEG3BoeE`dP02oe1]d@?o0000
00OoD7;Fo`000?m6KMGoAVgEo`000?mBNM_o000000?oAWOM00?o0000oeN1gol000000om>O=l2of:<
i@03o`000?mDQNCo000000;o000000?oJ9GYo`000?mRTNT00_mRTNT9o`0000OoOZ_`00Co0000ohbg
l_n<]o;oS;Ob1_l00003oik:mP?o000000?oXLgfo`000?neeo800ol000001?nhfO7o0000o`000?l0
0002ol?Tk`;o00000_oEjn@00ol0003oh?7Jo`000002onCae@03o`000?o/n<?o000000?o00007Ooo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z00Wooo]Z000;oookJP03o`000?oonf[o
oo]Z01gooo]Z00Go0000om[7aol0003ofLO8o`000002omS6b004o`000?oHaLOof<G7omS5a`;o0000
0_oEaLX02Ol0003odlC;om?4booCa<_o0000omC3bOl0003odl?;o`000002om?2bP03o`000?oA`/_o
dL;;00;odL;;0ol000000oo@`Lco0000om30b`02om30b`05o`000?o>_lcoc[o<oljoc?o=`<d00_l0
00000oo=_lgo0000olfnc002olfnc003o`000?o;_Lgobkg=00;obkg=0ol000002?o:_Lko0000olZl
c_l0003ob;c?o`000?o8_<oo00000ooVa;@2o`000006onG2/ol0003ohl2con?0/ol0003oh[jc0_l0
0002on2k/`03o`000?oQ^JkohKV^00;o00000_oP]Zd03?l0003og[B]omjd[Ol0003og;:]o`000?oK
/Jgo0000omV_[Ol0003ogJnYo`0000;ofjjY0_l00002omVZY`04o`000?oFZ:SoeZRXomJXZ0?o0000
00?oejJTo`000?oDXj@00_oDXj@01?l0003odZ6Uom:QYOoBXJD5o`0000?ocibQ00?o0000olVHXoo9
V:<00_o9V:<00ol0003obiRRol^HXP05o`000003olNCW_l0003o000000CoaY:O00Co0000ol>?W_o3
Siko`hnN2_l000000onnQi_o0000o`000005ok^5V`03o`000?niQ9co000000Co^8>L00Co0000okJ1
VonfPI_o00000oncOi/01Ol0003o/WjKok9nVonbOY_o000000Co[g^K00Go0000ojikVon^Ni_o[W^K
o`000004oj]hV`03o`000?n[N9_o000000?oYgJL2Ol00002ojAfW`03o`000?nOLIkoWg6N00CoWg6N
00Co0000oiY]W_nJKIkoVVfN1Ol00005oiM^XP03o`000?nBJj;oTV^R00;oTV^R0ol00005ohiYY003
o`000?n9IZCo000000;o000000?oRVRVo`000?n5IZL00on5IZL4o`0000?oPFFY0_l000000ommHZWo
0000ogeU[002ogeU[006o`000?mfH:coMV2/ogIP[?l0003oNfB^0omcHJl01?l0003oLV6`o`000?l0
0004og5Q/@;o00000_mZH;@01?l0003oJ62fo`000?l00003ofUR]`;o00001OmTHKX2o`0000?oF630
00Co0000oemU`OmOIL7o00000_mBH<<2oe]Va@03o`000?m=HLOoCF7700?oF6W900?oAUo8o`000?m7
HLT00omFK<d2o`000003odETcOmEL=;oEG3B00?o00000_mFM]H2o`000003odI]eOmHO=_oF7cK00?o
00000_m6Mmd2o`000006oeZ3h?l0003o0000o`000?mRS>Go00000omFR^L3o`0000;oHY7Y0_l00000
1?mRTNWoMJ7]ogFQkOl00003ofnNk@co00001?n<_?H00ol0003oW/[fo`000002o`0000GoXLgf00?o
0000okSIlOnhfO400_nhfO400ol0003o`nC_ol?Tk`02o`0000;oa^S^0ol000000ooPlM[oi?7EonCa
e@03o`000004ongh`?l0003o0000o`0001gooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Z
oookJP09oookJP002_oonfX00ol0003ooo]ZoookJP0MoookJP04o`000?oJalOof/O7om[7a`;o0000
00?of<K8o`000?oHaLL00ooHaLL3o`000005omG5b_l0003odlC;om?4bol000000ooD`lT2o`000006
om?2b_l0003od/;:o`000?oA`/_o00001?oA`L/02Ol0003od<3;om30boo@`<_o0000olnobol0003o
c[o<o`000003oljnc0;o00000oo=_/`2o`000003ol^mcOl0003obkg=00?obkg=0_l00002olZlcP04
o`000?o8_<oo0000o`0000;oi/Bd00Co0000onG2]?oU`[Co00000_oS`;<02?l0003oh[jcon:n/ol0
003oh;bco`000?oP^k?o00000_oQ^Jh01Ol0003oh;N]o`000?oP]Zgo000000;og[B]00?o0000ombb
[OoL/Zd00ol000000ooI[jgo0000om^^Z@02om^^Z@04o`000?oI[:Wo0000o`0000?oeZRX00Co0000
om>UZOl0003oeZNV0ol000000ooDXjCo0000om:QY@03om:QY@04o`000?o>WZKo0000om6OY0?o0000
00?ocibQo`000?o9V:<00oo9V:<01Ol0003obiRRol^HX_o;V:;o000000?ob9JQ1?l00002olJBW`03
o`000?o3Siko`hnN00?o`hnN00?o0000ol6=Woo1SIl00_o1SIl01?l0003o_8VOokb9WonlRIl=o`00
00;o^8>L00Co0000okJ1VonfPI_o00000oncOi/00ol0003o/WjKok9nV`02ok9nV`04o`000?n_Ni_o
[g^Ko`0000;o[W^K3Ol00004ojMgW`;o00001OnTMYl00ol0003oWg6NoimaWP02oimaWPOo00000_nL
LZ800ol0003oUfjRoiM^XP04oiM^XP03o`000?nBJj;o000000;o00000_nCKJ@00ol0003oSVVTohiY
Y002ohiYY0?o00001?n:J:H00ol0003oQFJWo`000003o`000003ohMXZ?l0003oPFFY00?oPFFY1_l0
0002ogeU[003o`000?mfH:coNfB^00;oNfB^00?o0000og=Q[omcHJl01?l00003og5Q/@03o`000?m_
HkGo000000?oJV2d00?o0000ofUQ]ol000001?mYH[L3o`0000?oI66j0_mSI;h00ol0003oF630oeQP
`004oemU`@03o`000?mBH<?oFfK500?oFfK50_l00003oeQYb@?o00000_mFK<d2oda[d003o`000?mE
L=;oEG3B00;oBfoE0_l000000omFM]Ko0000od]df@02o`000004oeQlfol0003oBgSMod]hg@;o0000
00?oAWOMo`000?mJPn000omJPn03o`0000?oEX[W0_l00004ofZGj@;o000000?oMJ7]o`000?m_W^d0
0om_W^d00ol0003oPZg`oh:]l004oh:]l0;o00001on<_?H00ol0003oXLgfoj7=mP02oj7=mP?o0000
0_nTcoH01?l0003o^=Wao`000?nkf_03o`0000?oa^S^00Co0000ol_QjOo;hNWo00000_oTlMD01_l0
003oi?ODo`000?o]n<3o0000oo3aVP;o00007_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z00Wooo]Z000:oookJP03o`000?oonf[ooo]Z01cooo]Z0_l00003om[7a`04o`000?oIa/Oo
0000o`0000?of<G700?o0000omO4aooGa<L00ol000000ooCa<_o0000omC3b@02omC3b@03o`000?oC
`/Wodl;900;o00000_oB`/X01Ol0003odL7;om71booA`L_o000000;od<3:00?o0000om30bol00000
0oo?_l/01Ol0003oc[k<oljnc?o>_/co000000;ocKk<00?o0000olfnc?l000000_o<_L`00ol0003o
bkg=ol^mc@02ol^mc@0<o`000?o9_<gobKc=o`000?o:_<ko0000olRlcol0003oi/Beo`000?oVa;Co
00000_oU`[@2o`000004on?0/ol0003oh[jco`0000?oh;bc1?l00003on2g[@Co00000ooL/Zd00ol0
003of[2]omZ`[@02o`0000;ofjjY00Co0000omV/ZOoI[:WofJbY0ol000001?oFZ:So0000om>UZOoC
YJT2o`0000;oeJFV1?l000001ooBXJGo0000oljNY_o>WZKo0000om6OY?l000000_o?WZ@4o`000004
olVHXol0003obINSo`0000;obiRR00?o0000olRFXOo8UZ400_o8UZ400ol0003oaI>Ro`000005o`00
00;o`hnN00?o0000ol6=Wol000000oo1SIl00ol0003o_8VOokb9W`02okb9W`03o`000?nlRIoo_8VO
00Co_8VO00?o0000okZ6W_l000000_nhQIlDo`0000;o[gfN00Go0000oj]jW_n[NYkoZgZNo`000002
oj]jWP03o`000?nWMiooYgNO00GoYgNO00?o0000ojAfWonTMYl01?nTMYl00ol0003oWg6No`000002
o`0000;oWg>Q0_l00006oiabXP03o`000?nGKZ;oUfjR00Go00001OnCKJ@00ol0003oSVVTo`000002
o`000003ohm/Y_l0003oRVRV00;oRVRV1?l000000on5IZOo0000ohMXZ002ohMXZ007o`000?n1IJWo
PFFYoh5UZOl0003oQ6R[o`000004ogeU[0;o000000?oMV2/og]T[_mkI:h00omkI:h00omcHJoo0000
ogMT/002ogMT/0;o000000GoLF6ao`000?m_HkGoKf>eo`000002ofYP]004o`000?m_I;Ko0000o`00
00?oJF:g00So0000ofIS^ol0003oHf:ko`000?mTHK[o0000oemR_@?oHfBn0_l00004oemU`@;o0000
0omKI/D2oe=Vb@03o`000?mHJLWoF6W900?oCfS=00?oEVc=o`000?m<Jm000_m<Jm000omEL=;o0000
od]_e@03od]_e@?o00000om;M=T2o`0000CoBgSM0_l00003oeZ3h003o`000?mTS^GoI8kU00?o0000
00?oEX[Wo`000?mZUnT01OmZUnT<o`000003oh:]l?l0003o000000Co00001?n?__H01?l0003oXLgf
o`000?l00006ojC?mP04o`000?nkf_3o^m[`o`0000?oa^S^0_l00002ol_Qj@05ol[_kOl0003o0000
o`000?oTmm@01ol0000OoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX02?oonfX0
00[ooo]Z00?o0000oookJ_oonfX07?oonfX01Ol0003of/K6o`000?oJalOo000000;ofLK700Go0000
omW5a_l0003of<G7o`000003omO4a`04o`000?oG`lKo0000o`0000?oe<?900So0000om?2bOoC`/Wo
dl;9o`000?oC`LSo0000om;2bP;o000000?odL7;o`000?o@`<X00oo@`<X3o`000006olnobol0003o
ckk;o`000?o>_/co00001?o=_/`2o`000003olbmc?l0003o000000?obkg=00Co0000olVlcOo9_<go
bKc=1Ol00002onK4]@04o`000?oU`[CoiL:do`0000;oi<2d0_l000000ooR_[?o0000on2l/`02on2l
/`04o`000?oO^[?o0000o`0000?oh;N]00Co0000omnf[_oO]Zko00000_oL/Zd02Ol0003of[2]omZ`
[OoJ/:go0000omN^[_l0003ofjjYo`000003omV/Z@03o`000?oGZZWoejZY00?o000000?odjFYo`00
0?oEYJH00ooEYJH00ol0003odZ>Vom:SYP03o`000003oljNY_l0003o000000?ocijT00Co0000olfK
Y?o=VjCocI^T1_l00004olRFX@06o`000?o5Tj;oaI>Ro`000?o6Tj7o00000oo5TZ48o`0000Go_8VO
00?o0000okb9WonlRIl00onlRIl01?l0003o^XJNokZ6W_l00003okR5W`05o`000?nfPiko]X>NokJ3
W_l000000_ncPIh00ol0003o/X2Nok:0WP03ok:0WP04o`000?n_OYko[gjNo`0000Co[gfN00Co0000
oj]jW_n[NYko00001?n[NYh00ol0003oYgNOojMgW`03ojMgW`;o00000onTMYl5o`0000CoWg>Q0_l0
0005oiabXPGo00000onHL:@00ol0003oTffToi=]Y003oi=]Y0?o00001?n?K:H4o`0000;oRVRV0_l0
0006ohMXZ0;oPFFY0on4J:/00ol0003oOFF/ogeU[002o`0000;oP6R]0ol00002og]T[P;o00001?mg
I;001?l0003oL6:bog5Q/Ol00003ofmS]@03ofYP]?l0003oKfBf00;oKfBf0_l000001OmYH[Oo0000
ofIS^omVHk_o000000;oHf:k00?oI66jo`000?mOH[d00omSI;h2oeeU`P04o`000?mOIL7oGfG1o`00
00;oF6G500?o0000oe]VaOl000000omCI/T3o`0000;oCfS=0ol00003oda[d0;o00001?m;KmD2oeYi
f0;o000000?oBgCIo`000?mLOm`00_l00002od]hg@04o`000?mOQ^7oGhKQoen6h@?o00001?mTS^D4
o`0000GoJYOY00?o0000ogJRkOmfX^d01?mfX^d00ol0003oQJo`ohF_l002ohF_l003o`000?mn[o?o
000000CoSkkf00Go0000ohnnm_n?__KoSkkfo`000004ojC?mP;o00001?nXd_H2o`0000;oa^S^00Co
0000ol_QjOo;hNWobn7Y0_o:knd2o`000003omWfh?l0003o000000?o000000?ogo6Do`000?oonfX0
8?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z00Sooo]Z000:oookJP03o`000?oo
nf[ooo]Z01cooo]Z0_l000001OoJa/Ko0000omW6aooIa/Oo000000?ofLG600Go0000omO4aooGa<Oo
elC7o`000002omO3aP?o000000?oe<?9o`000?oC`/T00_oC`/T01?l0003odl78om?1b?oC`LP2o`00
0003om;1bOl0003od<3:00?od<3:00Go0000olnoboo?_l_ocko;o`000003olnnb`05o`000?o=_/co
cKk<olfnc?l000000oo<_L`2o`000004olbmc?l0003obkg=o`0000?obKc=00So0000olVkc?o9^lco
bK_<o`000?oSa[[o0000onK4]@;o000000KoiL:do`000?oT`;Coi<2do`000?oR_[<2o`0000;oh;bc
00Co0000omnj/ooO^[?ogkZc0_l000000ooP]jgo0000omnf[P02omnf[P;o000000Gog;:]o`000?oJ
/:gof[2]o`000002omN^[PCo000000?ofJbYo`000?oGZZT00_oGZZT00ol0003oe:RZomBXZP02o`00
00?oeJFV00Go0000om:SY_oBXjKodZ>Vo`000002om2QY`Ko00001Oo=Vj@01?l0003ob9RUo`000?o;
VZ@3o`0000;ob9JQ00Ko0000olFCX_o5Tj;o0000olJCXOl00004olFBX@04o`000?o1Sj7o`HnQo`00
00;o`HnQ1ol00005okb9W`04o`000?njQYko^XJNo`0000;o^8FO00?o0000okJ3W_nfPih00onfPih2
o`0000Ko/X2N00?o0000ojmnW_l000001On_OIh01Ol0003oZgZNoj]jW_l0003oZgZN00ko00000onT
Mj800ol0003oWg>QoimcX@02oimcX@05o`000?nPM:;oX7BRo`000?nLLZ800ol00002oiacY003o`00
0?nHL:CoV72T00CoV72T00?o0000oi=]Y?l000000_l000001?nDKjGo0000ohm/Y_n?K:H5o`000006
ohYXY_l0003o0000o`000?n<JjSo00001On7J:P00ol0003oPFFYohAXZ`04ohAXZ`03ogeU[?l0003o
P6R]00?oP6R]00?o0000ogYU[omjIJl01?l00004ogMT/0;o00000_maHk<2o`000003ofmS]Ol0003o
KfBf00?oKfBf00Co0000ofQR^?l0003o00000omVHk/2o`0000;oJ6Fl00Co0000of=T__mSI;ko0000
0omMIL83o`0000;oF6G500Co0000oeYWaOl0003o00000_mCI/T01?l0003oGFg;oee]bol00002odmX
c@;oFg3?0_l000000om<Jm3o0000oeYdd`02o`0000;oBfoE00?o0000oeYif?mJNMP00_mJNMP2o`00
00?oG7oL0ol00003oen6h@03o`000?mEPn;o000000;o00000_mTS^D00ol0003oFX_Wo`000003ofnI
jP04o`000?mZUnWo0000ogJRk@[o000000?oQJo`o`000?l000001?l00006oi;1mP;o00000onXd_H3
o`000003oj_Fm_l0003o_]c_00;o00000_o;hNT4ol[_k@04o`000?oIm^3o0000omcjf`Ko00008_oo
nfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z00Sooo]Z000:oookJP03o`000?oonf[o
oo]Z01_ooo]Z00?o0000omc6`ooLa/<00ol000000ooIa/Oo0000omW5aP02omW5aP;o000000GoelC7
o`000?oG`lKoel?6o`000003omK2aP?o000000?odl;9o`000?oC`LP00_oC`LP00ol0003odl38om?0
b002o`0000?od<3:00go0000olnoboo?_l_ocko;o`000?o?_/Wo0000olnnbol0003oc[k:o`000?o=
_/co000000Coc;g<00Go0000olblb_l0003oc;g<o`000003olVlc@05o`000?o9^lcobK_<olVkc?l0
00000ooSa[X00ol0003oi<:eonC2]@02o`000009onC0]?l0003oh[jcon:n/ol0003ohKfco`000?oP
_;?o000000?ogkZc1?l00002omnf[P03o`000?oM]:kogKB^00?o000000?of[2]o`000?oG[Zh00_oG
[Zh00ol0003ofJf[omV]Z`02o`0000?oejZY00Co0000omBXZ_oDZ:[oe:RZ0ol000000ooEYJKo0000
om:SYP02om:SYP04o`000?o@XJOod:6Wom2QY`;o000000CocinVolnNY?l0003o00000oo=Vj@01_l0
003ob9RUolRHYOl0003obiZTo`0000;obIVT1Ol000000oo5Tj;o0000olFBX@04olFBX@04o`000?o1
Sj7o`HnQo`0000;o`HnQ00?o0000okn=XOnoSJ400_noSJ4Xo`0000?o[GjR00?o0000ojMiXOnWNJ40
0_nWNJ400ol0003oZ7ZQo`000007ojAgXP05o`000?nOLj7oWg>Qo`000?nPM:801?l00005oiacY003
o`000?nHL:CoV72T00;oV72T1?l00004oiA_Y@?o000000?oSfbVo`000?l000001_l00002oha[Z003
o`000?n7J:So000000;o000000?oR6^[o`000?n4J:/00on4J:/2o`0000KoP6R]0_l00003ogeX/0;o
00000_mgI;000ol0003oMVNco`000003og5S/`Co00001?m_I;H00ol0003oKFJiofeV^@02o`000003
ofIS^ol0003oJ6Fl00CoJ6Fl0_l00003oeeU`P04o`000?mSJL?oHfW3o`0000;oF6G500Ko0000of1[
aomPJlOo0000oe=VbOl00003oee]b`;oCfS=00?o0000oe]`comKL<l00_mKL<l2o`0000?oFWCC0ol0
0003oeYif007o`000?mAMMSo0000o`000?mLOmco0000oe9kg@03o`000004oen6hOl0003oEH?Ro`00
00?oJI7V1ol00002ofnIjP;o00001_mdY_400ol0003oRK7`ohVal002ohVal004o`000?n3/?;oPk3b
o`0000;oT/7f1?l00002oiK4m`03o`000?nXd_Ko000000;o00001On[e_H2o`000003ol_QjOl0003o
b^o]00;ob^o]00Wo0000olk]jOl0003o0000omcjfol0003ogOGLo`000?oUo<L00ol0000RoookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX02?oonfX000[ooo]Z00?o0000oookJ_oonfX0
6_oonfX01_l0003og<K3omc6`ooLa/?o0000om_5``;o00000ooIaLH00ol0003of<C6omS4aP02o`00
0003omO3a_l0003oe/;600?oe/;600Co0000omC1aooD`LOo00000ooC`LP02Ol0003odl38om?0b?oC
`<So0000om:oaol0003od<3:o`000003olnob`04o`000?o?_/Wockk9olnnb@?o000000?oc[k:o`00
0?o<_L`00oo<_L`01?l0003oc;c:olblb_o<_<X3o`000003olVlcOl0003obK_<00;obK_<0ol00000
2?oSa[[o0000on;4^_l0003oi<:eo`000?oS`KCo00000_oR_[<01?l0003ohKfcon6m/ooQ_K<3o`00
0009omnj/ol0003og;Rcombh/ol0003og[J_o`000?oO]Zko000000;ogKB^00?o0000om^b[_oK/Zh0
0ol00002omN^[P05o`000?oI[J_ofJf[o`000?oH[:/00ol00003omBXZP04o`000?oAYJ_o0000omBV
Z0?o000000?odZ>Vo`000?o@XJL00_o@XJL00ol0003ocIjWo`000002olnOYP06o`000?o>WZKo0000
o`000?o=VjCo00000oo8V:D00ol0003obIVTolVIY002olVIY004o`000?o4U:Coa9BTolBDY0Go0000
00?oaI:Qo`000?o1Sj400oo1Sj42o`0000Go_hfQ0_l00004okb;XP05o`000?nhQj7o^8NQokR7XOl0
00000_nhQj400ol0003o]hNRokN7XP03okN7XP03o`000?ncQ:;o/hBR00Go/hBR00?o0000ojn1X_n_
PJ801On_PJ82o`0000Ko[GjR00Go0000ojMiXOnWNJ7oYgVQo`000003ojQjX@04o`000?nTMj;oY7NR
ojAgXPSo00000_nQMj@00ol0003oW7>ToiacY004oiacY003o`000?nHL:Co000000;o00000_nHLZD0
0ol0003oU6nUo`000009o`000003oi1_ZOl0003oS6fZ00?oS6fZ1ol000001?n8Jj_o0000ohAXZon4
J:/2o`000003ohAZ[Ol0003oP6R]00CoP6R]0_l00004ogeX/004o`000?mfIK;oMfB`o`0000;oMVNc
00Co0000og5S/omaHk?o00000_meIk@01Ol0003oKVFgo`000?l0003oKfBf00;o00001?m]I[T2o`00
00GoJ6Fl0_mSI/000ol0003oGFG2oeeU`P04of=Y``;oF6G51OmPJlL2o`0000?oGFg;0ol00003oe]`
c`?o00000_mJM=<01_l0003oD73Co`000?l0003oFWWHo`0000;oDGGH0omRP]`3o`0000;oIHWQ1Ol0
0003ofVAiP04o`000?mQS^KoHHkVo`0000?oLicZ1ol00003ogBVl@03o`000?n9/O3oRK7`00Oo0000
1onFa?L00ol0003oZmKfoj_FmP02oj_FmP?o00000_n_f_H2o`0000;ob^o]0_l00002olk]j@03o`00
0?oLn]_o000000;ogOGL00?oiOc7o`000?l000000_l0000SoookJP03o`000?oonf[ooo]Z033ooo]Z
00?o0000oookJ_oonfX02?oonfX000[ooo]Z00?o0000oookJ_oonfX06OoonfX01Ol0003og<K3omc6
`ooLa/?o000000;oflG30ol000000ooIaLKo0000omS4aP02omS4aP04o`000?oG`lOoel?6o`0000?o
e/;600Co0000omK1a_l0003oe<770_l000000ooC`LSo0000om?0b002om?0b004o`000?oB_lOod[o7
om:oa`;o00000_o?_l/01Ol0003ockk9olnnbOo?_/Wo000000?ockg90ol00002olbmc005o`000?o<
_<[oc;c:olblb_l000000oo<^lT3o`000003olVkc?l0003o000000;ohlJk0ol000001?oRa;[o0000
on?1]?oS`K@2o`000003on:n/ol0003ohKfc00;ohKfc00Co0000omnk/ooO^k?o00000ooL^;<00ol0
003og[J_omjf[`04o`0000?ofk:^00?o0000omV`[ooI/:l00ol00002omV]Z`04o`000?oH[:_of:b[
omR/Z`?o000000Coe:RZo`000?oAYJ_odJF[0_l00002om>UZ0Co000000Cod:6Wo`000?o=WZOocIjW
0_l00004oljNYP?o00000_o8V:D01Ol0003obIVTolVIY?o9VJCo000000Goa9BT00Co0000olFDY?o5
U:CoaIBT2_l00002okn=X@04o`000?nmS:7o_HbQo`0000;o_8^R00?o0000okR7XOnhQj400_nhQj40
0ol0003o^8NQo`000006okN7XP03o`000?ncQ:;o/hBR00Go/hBR00?o0000ojn1X_n_PJ801On_PJ80
0ol0003o[GjRojenXP05ojenXP05o`000?nWNJ7oYgVQo`000?nXNZ401ol00003oj=hX`03o`000?nQ
MjCoXGNT00CoXGNT00?o0000oiacY?nLLj@00_nLLj@4o`0000CoV7:U1Ol000000onDL:Oo0000o`00
0002o`0000CoT6nY00?o0000oha]Z_n<KJX00on<KJX2o`0000CoR6^/1ol000001?n4JZgo0000oh1X
[On0J:d2o`000003oh5Z/?l0003oOFR`00?oOFR`0_l00002ogMV/`?o000000?oLF>co`000?meIk@0
0_meIk@00ol0003oKVFgofiU]`04o`0000?oKFJi00?o0000ofYX_Ol000000_l00002ofQU_003ofAW
`?mSI/3oHfK000;oHfK00_l00004of=Y``;o00001?mPJlL00omIJl_o0000o`000002oee]b`;oEFg>
00Go0000oe]`comKL<oo0000oe9/c`03oemhd`03o`000?m@L=?oD73C00?oH7cH0ol000001OmAMMSo
HX;Lof:2g?l0003oF8;P00;o00000_mURN400ol0003oGHGQoef5h@07o`000003of6>i_l0003oLicZ
00;oLicZ00?o0000of^Jk?l000001?mhZO42o`000005ogBVlOl0003o0000ohfcl?l000001?n8/_40
0ol0003oU/CgoiK4m`03o`0000?oVLOg00Co0000oj_Fm_l0003o00001On_f_H2o`000003ol[_kOl0
003oc^gY00;oc^gY00?odNoWo`000?l000000_oMmM`2o`000003onOl`Ol0003o000002Gooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP08oookJP002_oonfX00ol0003ooo]ZoookJP0I
oookJP;o000000Gog<K3o`000?oKaL?oflG3o`000002om_4``;o00000ooHa<H02?l0003oel?7omO3
aol0003oel;5o`000?oF`/Ko00000ooF`LH00ol0003oe<77omC1a`02o`0000;odl3800Go0000om:o
aooB_lOod[o7o`000002om:na`;o00000oo?_/T01Ol0003ockg9olnmbOo?_LWo000000?ockc80_l0
0003olblbP03o`000?o<^lWoc;_900;oc;_900?oc;[9o`000?o:^//00ol00002on?6^`05o`000?oR
a;[oh/Bjo`000?oP`[X00_l00002on:o]0;o00000_oQ_K<01?l0003ogk^comnk/ooO^k<2o`000006
ombh/ol0003ofkJco`000?oN]Zoo00000_oM]:l2o`0000;ofk:^00Co0000omV`[ooI/:oofK2_1?l0
0004omR/Z`03o`000?oEZJ_oeJV[00?o000000?odJF[o`000?oCYJP00ooCYJP00ol0003odJ>Xom6S
Z003o`000003olfNYol0003o000000CocYjV00?o0000ol^KY_o;VjH02Ol00002olBDY0;o00001?o5
U:@00ol0003o_i2Tokn@Y002okn@Y004o`000?o0T:Co`92Tol2@Y0Oo000000?o_8^Ro`000?nhQj40
1?nhQj42o`0000Go]hNR00?o0000okJ5X_l000001OncQ:800ol0003o/X>Ro`000006ojn1XP03o`00
0?n]OZ;o[GjR00;o[GjR2?l00003ojUmY003o`000?nSN:?oXgRS00?oXgRS0_l00006oj5gY003o`00
0?nLLjCo000000;o00000_nLM:D00ol0003oV7:Uo`000003o`000003oiUcYol0003oU72W00?o0000
0_nELZP00ol0003oT6nYoi1_Z@04oi1_Z@03o`000?n<KJ[o000000;o000000?oS6f[o`000?n8Jj`0
1?n8Jj`2o`0000CoQ6^^0_l00002oh1X[@?oPFZ`00Oo0000ogeX/?mmJ;3oOFR`o`000?mmJ[?o0000
00CoMfJc0ol00004ogEW]0;o00000omcJ;P2o`000005ofeV^Ol0003oJVRmofYX_Ol000000_mWI[d0
1?mXIKco0000ofAW`?mTIl02of=V`004o`000?mXJL7oJ6W1o`0000;oHfW300Co0000oeeZaomMJ/Oo
00000_mPJlL00ol0003oFF_;o`000002oea]b`;o000000CoEFg>o`000?mKL<ooFg3?0_l000000omB
K<ooGgSCoemhd`02oeIgf0;o00000_mPO=P01_l0003oEWcLoeIlg?l0003oHX;Lo`0000CoF8;P0ol0
00001?mMQN7o0000oef5hOl00002ofjDiP03o`000?mWT>KoIi3V00Co000000GoLicZo`000?m[V^co
Ji[/o`000006ogRYl@04o`000?n=/o3oSK?`o`0000;oR;;a1Ol00007oiW7m`04o`000?n_f_Ko[m[f
ojoJmP?o000000Co]=Wco`000?l0003o00000_o>kNT01?l0003odNoWom7_iol00002omgeg0;o0000
00Coioc1o`000?l0003o00009_oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z00So
oo]Z000:oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000omg6`_oMa/800_l000000ooKaL?o0000
om_4``02om_4``05o`000?oJ`l;o0000omS4a_l000000_oG`lL01Ol0003oel;5omO2aOoG`/Go0000
00?oe/7600Wo0000omG0aOl0003oe<77o`000?oD_lKo0000om?0b?l000000_oB_lL02Ol0003od[k7
om:naooB_/Oo0000om2mb?l0003ockk9o`000003olnmb@03o`000?o?_<Sockc800;ockc80ol00000
0oo<_<[o0000olbkb@03olbkb@?oc;[900?o0000olZib_l000000_oSa[/01?l0003oh/Bjon;4^_oR
a;X2o`000009on32^_l0003oh[ndon:o]?l0003ohKfco`000?oQ_K?o000000;ogk^c00?o0000omji
/ooN^K<00ol000000ooK][?o0000omfd[`02omfd[`04o`000?oK/joo0000o`0000?ofK2_00?o0000
omF]/?oE[K001?l000000ooH[:_o0000omFYZ`02omFYZ`03o`000?oCYjcodjN/00Co000000?odjFX
o`000?oAXjP00_oAXjP00ol0003oc9nZolbOZP04o`0000;ocYjV00?o0000ol^KY_o;VjH00_o;VjH2
o`0000?obIZV00?o0000olNHYOo7V:D01?l00003olFDY003o`000?noT:Co_i2T00?o_i2T00?o0000
ol2@Y?o0T:@00oo0T:@01Ol0003o^hbTok^<Y?l0003o_8bS02Co00000on[Oj@00ol0003oZGfTojUm
Y005ojUmY003o`000?nSN:?oXgRS00;oXgRS00Co0000ojAjY?nTNZCo00000_nQMj@5o`0000CoW7BU
1?l00003oiUcY`?o00001OnELZP00ol0003oT6nYoi1_Z@03oi1_Z@?o00001?n<KJ/01?l0003oR6^/
ohQ[[?n8Jj`2o`000003ohY][?l0003oQ6^^00?oQ6^^1_l00002oh5Z/003o`000?mmJ;3oOFZc00;o
OFZc00?o0000ogMV/omgI[<00_l000000omkJKCo0000ogAW]P02o`000003ogEW]?l0003o000000Go
LfRh0ol00003ofYX_@;o00000_m/JKh2o`000003of=V`?l0003oJ6W100?oJ6W10ol00002oeeZa`04
o`000?mOJlOo0000o`0000;oFF_;00Ko0000oea]bomRLLcoHW7<o`000?mEKLh2o`0000;oH7C@00?o
0000oemhdol000001OmFMmP3o`0000;oEWcL1?l00002oeR2h003o`000?mURN7o000000;oJ8cR0ol0
00000om^U>Ko0000ofN@iP02ofN@iP03o`000?mhW^[oN9kZ017o00000on=]O400ol0003oVLOgoiW7
m`04o`0000;oWL_g00Co0000ojoJm_l0003o00000ondfO<2o`0000;o_nGa0_l000001OoAknOo0000
omG`iOl0003ogOGL00Oo00009ooonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z00So
oo]Z0009oookJP03o`000?oonf[ooo]Z01Sooo]Z00Ko0000omg6`_oMa/;ogLK2o`000?oLa<82o`00
00;oflC300Go0000om[3`_oJ`l;of/?2o`000002omO3a`03o`000?oG`/Goel;500;oel;50_l00000
0ooF`LKo0000omG0a@02omG0a@04o`000?oD_lKoe;o6omBoaP;o000000?od[o7o`000?oB_/L00ooB
_/L2o`000006om2mb?l0003o0000o`000?o?_LWo00001Oo?_<P00oo>^lSo0000olfkb@03o`0000;o
c;_91?o<^/T01_l0003ob[W:o`000?l0003ohlJko`0000;oh/Bj00Go0000on72^_oQ`[[o0000omo0
^@02o`0000?ohKfc0_l000000ooO^k?o0000omji/`02omji/`03o`000?oL^;Cog;Rd00;o00000_oM
]:l01?l0003ofk>_om^c[ooK/jl3o`000003omV`[ol0003oeJf`00;oeJf`00?o0000omN/[?oG[:`0
0ol000000ooEZJ_o0000om>W[002om>W[0;o00000_oBYZX2o`0000?odJ>X00Go0000olbOZ_o<Wj[o
c9nZo`000002olfOZ0Go000000Cobi^Vo`000?o8VJOo00000_o9VZH00ol0003oaiRUolNHY@02olNH
Y@03o`000?o4UJKo000000Ko00000_noT:@2o`0000Co`92T00Oo0000ok^<Y?nkS:Co^hbTo`000?nl
S:?o000000Ko^hbT00?o0000okN9Y?ngRJ@01?ngRJ@00ol0003o]XNSo`000004ok>5Y004o`000?nb
Q:?o/XBSo`0000Go[h:T00?o0000ojn1Xol000001_n[Oj@00ol0003oZGfTojUmY005ojUmY006o`00
0?nSN:?oXgRSoj=hXol0003oY7ZT1Ol00003oj5hYP03o`000?nLM:Go000000Co000000?oWGJWo`00
0?nILjL00ol000000onIMJSo0000oiEbZ006oiEbZ003o`000?n@KjWo000000;o000000?oTG2Zo`00
0?n<KJ/01On<KJ/2ohQ[[005o`000?n:KJcoRVf/ohY][?l000000on4Jjh00ol0003oQVf_o`000004
oh1Z/0Co00001?mmJ[<00omgI[?o0000og]Y]002og]Y]003o`000?mdIkKoM6Nf00Co00001OmcJ;P0
0ol0003oKFNkofeW^`02o`000003ofYX_Ol0003oK6Vn00CoK6Vn00?o0000ofQY`OmXJL400omXJL40
1?l0003oJ6k5ofQ^aOl00002oeeZa`04o`000?mTKlSoI6o8o`0000;oFF_;00?o0000of9ac?mRLL`0
0_mRLL`00ol0003oH7C@of1dd003of1dd0;o00001?mFMmP00ol0003oI83IofB0f@02o`000004oeIl
g?l0003oIHGNofF5gP;o000000?oF8;Po`000?mXS>801OmXS>85o`000005ofN@i_l0003oN9kZogRN
j_l000000omaW>/00ol0003oPZ[^oh:ZkP05oh:ZkP03o`000?n=]O7oSKGa00;oSKGa1Ol00007oig;
m`03o`000?ndfO?o]=Wc00;o000000?o^=_bo`000?noiO400_l000000oo3j_3o0000o`000002omG`
i@06o`000?oMmMco0000on7ke?l0003ojoZm0_l0000XoookJP03o`000?oonf[ooo]Z02kooo]Z00?o
0000oookJ_oonfX01ooonfX000Wooo]Z00?o0000oookJ_oonfX05ooonfX01Ol0003ogLK2omg6`_oM
a/;o000000;og<C200Go0000omc3`Ol0003oflC3o`000003om[3`PCo00000ooG`/D00ol0003oel75
omO1a@03o`000006omG0aOl0003oeKo5o`000?oD_lKo00000_oC_lH2o`0000?od[k700Co0000om6m
a_oA_LKo00000oo@_<L2o`0000Cockc80oo>^lP01?l0003ocK[8olfjb?o=^/P2o`0000?oc;[900?o
0000olbibOl000000_oSa[/2o`000003on;4^_l0003ohL:j00;ohL:j0_l000000ooO`;Wo0000on6m
/`02on6m/`04o`000?oO_;Co0000o`0000;og[Vc00Wo0000ombh]?oL^;Cog;Rdo`000?oI]KCo0000
omfd[ol000000ooK/jl00ol0003of[6_omZa[`02o`0000;oeJf`0_l00002omN/[003o`000?oFZjgo
eZ^]00;o00000ooCYj`01_l0003ocjF]o`000?oBYZ[o0000om6UZ`?o00001?o<WjX01Ol0003ocInX
olfOZ?o=WjSo000000?oc9fX1Ol000000oo9VZKo0000olNHY@03olNHY@03o`000?o4UJKo000000;o
a9FV00Co0000ol>DYOo3U:Go`iBU1_l00002ol2@Y003o`000?nkS:Co^hbT00;o^hbT00?o0000ok^<
Y?nkS:@01?nkS:@2o`0000Go]hVT00Co0000okJ7XonfQj?o00000oncQJ@01Ol0003o/XBSok:4Xonb
Q:?o000000Co[h:T00Co0000ojn1Xon_PJ?o00001On[Oj@00ol0003oZgnTo`000003ojUmY0Wo0000
0_nUO:H00ol0003oXGRVoj5hYP02oj5hYP?o000000?oW7BUo`000?l000001Ol00004oiUeZ003o`00
0?nELZSoUG:X00?oUG:X1?l00004oi5`ZP03o`000?n<KJ_oS6f[00?oS6f[00?o0000ohQ[[?n:KJ`0
1?n:KJ`2ohA[[P05o`000?n6KJooQVf_ohI][ol000001On0J[000on3KK7oOFZcogeZ/`03o`000003
ogeZ/ol0003oNfVd00CoNfVd0_l00004ogQ[]`;o00000_mcJ;P2og5Z^`CoKFNk0_l00004ofaY_P;o
000000?oIf[2ofQY`OmXJL400_mXJL45ofQ^a@;o00001?mTKlP3o`0000?oHW7<00?o0000ofAgdOmP
M=000omPM=001?l0003oHg_Eo`000?l00002oeIgf003o`000?mTP=WoI83I00?oI83I00?o0000ofF5
g_mUQMh00omUQMh3o`0000CoJ8cR00?o0000og2Fiom`U^L00_m`U^L?o`000003oh:Zk_l0003o0000
00?o00001?n=_?H00ol0003oWL_goig;m`03o`0000CoXLkg00Co0000okSKl_nhfo;o^=_b0_l00002
ol?Zl004o`000?o9hn_obN?[olWSj`?o000000?ohO_Do`000?l000000ol0000YoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX01ooonfX000Wooo]Z00?o0000oookJ_oonfX05ooonfX2
o`000005omg6`_l0003og<C2omc4`_l000000ooL`l401Ol0003of/?2om[3`_oJ`l;o000000;of/;2
00Go0000omS1`ol0003oel;5o`000003omO1a@04o`000?oF`<Coe/34o`0000?oeKo500Wo0000om>o
a_oC_lKodko6o`000?oC_/Ko0000om:naol000000ooA_LH2o`000005om2laol0003ockc7olnlaol0
00000_o?_<P3oljkb005o`000?o>^lOo0000olfjb?l000000_o<^/P00ol0003oc;[9o`000002olbi
b@05o`000?oSa[_ohlJko`000?oRa;X00_l00002on72^P03o`000?oO`K[ogl6j00?o000000WohKfc
o`000?oO_;Cogkbdo`000?oN^[Co0000omji/ol000000_oL^;@01?l0003ofKFdomVe]?oI]K@3o`00
0003om^c[ol0003of[6_00;of[6_00Ko0000omR_/?l0003oeJf`o`000?oD[;02o`0000?oeZ^]00?o
0000omBY[Ol000000_l00002olnU[@;o00001?oAYJ/3o`000004olbOZ_l0003obijYo`0000;ocInX
00?o0000olbMZ?o<WJP00_o<WJP00ol0003oaYZYolJJZ@05o`000007olNHYOl0003oa9FVolBEY_l0
003oa9FVo`000005ol>DY@03o`000?o0TJKo000000;o`96V2ol00003ok^<Y003o`000?niRZCo0000
00?o]hVT00Go0000okJ7XonfQj?o]XNSo`000003ok>5Y005o`000?nbQ:?o/XBSok:4Xol000000on_
PZ@01Ol0003o[h6Sojn1Xon_PJ?o000000;oZgnT2Ol00004ojMmYP03o`000?nUO:KoYGbV00CoYGbV
2ol00003oiehZ@03o`000?nIMJSoVGFX00CoVGFX00?o0000oiEbZ?l000000_l00002oiEcZ@03o`00
0?nAL:[oTG2Z00CoTG2Z00?o0000oha]Zol000000_l000000on>Kjco0000ohY][003ohY][003o`00
0?n4JjkoQVf_00GoQVf_0on0J[03oh=]/@CoOFZc1?l00004og]Y]003o`000?mhJkOoN6^g00?oN6^g
00Co0000og5Y^OmcJ;So00000_maJ[/01?l0003oKFNkofeW^ol00002og5[_004o`000?m/JKkoK6Vn
o`0000;oJ6_200Co0000ofMZ`_mWJ/;oIf[20_l00004ofQ^a@;oHVk900Go0000ofA_b?mTKlSoI6o8
o`000002ofIdc@05o`000?mRLLco0000oeQ^c_l000000omTMm43o`0000?oHg_E0ol00004ofB0f@Co
00000_mUQMh2o`0000?oK8oS00?o0000ofR<h_l000000_l00005og2Fi`;o00001?miX>/00ol0003o
QZc^ohJ/kP04ohJ/kP03o`000?mo[O7o000000OoSKcf0_l00003oj7>m`?o00000_nUd_L01Ol0003o
^=_bokSKl_l0003o`n[`00;o00000oo9hn/2olKbkPSo0000:_oonfX00ol0003ooo]ZoookJP0/oook
JP03o`000?oonf[ooo]Z00Oooo]Z0009oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000omo4__oO
a;h00_l000000ooLa<;o0000omc3`@03omc3`@;o000000Wof/?2o`000?oJ`/;of/;2o`000?oI`L;o
0000omS1`ol000000ooG`LD01?l0003oe/34omK0a?oF`<@2o`000006omFoaOl0003oe;o5o`000?oC
_lKo00000ooC_/H01OoB_/Oo0000o`000?oA_LKo000000;odKc600?o0000olnlaoo?_<L00_o?_<L3
o`000003oljkb?l0003oc[_700;oc[_700?o0000olbjb?o<^/P00_o<^/P5o`000009on?6^ol0003o
h/Bjon;4^_l0003ohL>jo`000?oQ`[[o000000;ogl6j00Co0000omfn^_oM_[[o00000_oO_;@01?l0
003og[Zdomjj]?oN^[@3o`000003ombh]?l0003ofKFd00;ofKFd00?o0000om^d/?oK];000_l00002
omZa[`04o`000?oH[k3of:n`omR_/0Co00000ooFZjd00ol0003oe:V]omBY[@02omBY[@?o000000?o
cjF]o`000?oAYJ/00ooAYJ/00ol0003ocj:ZolnRZP06o`0000Coc9fX00Co0000olJJZOo6VZWoaYZY
0_l00003olRJZ0Co000000?oa9FVo`000?l000001?o3U:D01?l0003o`96Vol2AY_l00003ol2AYP03
o`000?nnSjGo_XnU00?o_XnU00Co0000ok^>Y_nkSZKo^hjV8?l000000on/P:Go0000ojb0Y@02ojb0
Y@03o`000?nWOJKoYgfV00CoYgfV0_l00004ojElYP?o000000GoXGRVo`000?l0003o0000oj1iY`02
o`0000KoWGRY00?o0000oiUeZ?nIMJP00onIMJP3o`0000GoUG>Y00?o0000oi5`Z_nAL:X00_nAL:X4
o`0000CoSVn/00?o0000ohY][?n:KJ`00_l000000on;Kjoo0000ohI][`04ohI][`03o`000?n0J[3o
Pffa00GoPffa0_mmJ[<01Ol0003oP6fcoh1]/ol0003oNV^f00;o000000?oNfVdo`000?l000001Omh
JkL2o`0000;oMVbj0ol000000om]Ik_o0000og5[_002og5[_004o`000?m[J[oo0000o`0000;oJ6_2
00Go0000ofMZ`_mWJ/;o0000ofa^``02o`0000;oJ6k500Oo0000of9^bOmRK/Wo0000ofA_bOmTKlSo
000000;oG6c90omVM<d4o`0000;oI7OA0omMN=D01?l0003oHg_Eof=keOl00002oe]geP;o000000Co
I83Io`000?mJO=[o00000omZRMh4o`0000CoK8oS0_l00004ogFIi`;o000000?oL9KWo`000?l00000
0ol000000omiX>_o0000ohJ/kP02ohJ/kP03o`000?n6[>ko000000Ko00001?nA_oH01?l0003oXLkg
o`000?l00006ojGBm`04o`000?nkgO7o0000o`0000?obN?[00Oo0000olKbk_o6l^ko0000omKjgol0
003oeoSQ00?o000000?odnn@oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oo
nf[ooo]Z00Oooo]Z0009oookJP03o`000?oonf[ooo]Z01Gooo]Z00Co0000omo4__oOa;koglBn1?l0
0003omc3`@03o`000?oK`/7ofl;100;o000000?of/;2o`000?oI`L800_oI`L801Ol0003of<33o`00
0?oG`LGo000000?oe/3400?o0000omJoa?oF_l@00ol000000ooD_lGo0000om>naP02om>naP04o`00
0?oA_LKodKg6om6maP;o000000?odKc6o`000?l000000oo?_<L01?l0003ock_7olnkaoo?^lL2o`00
00?oc[_700Go0000olbjb?o<^/Soc;[8o`000002olbib004o`000?oSa[_ohlJko`0000;oh/Bj00Go
0000on73^_oQ`k[ohL>jo`000002omo1^P04o`000?oM_[[ogKjjomfn^P;o000000?ogkbdo`000?oN
^[@00_oN^[@00ol0003ogKVdomfi]002o`0000?ofKFd00Sof;>do`000?oK];3o0000omZb/?l0003o
f[6_o`0000?of:n`00?o0000omJ^/?oF[[000ol000000ooFZjgo0000omBY[@03omBY[@03o`000?oA
YjgodJN]00Co000000?odJF[o`000?o?XZX00oo?XZX01?l0003obYn[o`000?o=X:X3o`0000;oc9fX
00Go0000olJJZOo6VZWoaYZYo`000005olRJZ003o`000?o3UZSo`iJX00Go00000_o3U:D01ol0003o
`96Vol2AY_o0TJKo0000ol2AY_l000001OnnSjD2o`0000Co^hjV00Go0000okV;YOniRjGo^H^Uo`00
0002okN:Y@03o`000?ndQjGo]8NU00;o]8NU00Co0000ok>6YOncQZGo00001?ncQjH01?l0003o[h>U
ojn3YOl00004ok65YP04o`000?n/P:Go[82Uo`0000Co[82U00?o0000ojMmY_nWOJH00onWOJH00ol0
003oZ7jVo`000008o`0000?oX7VW00?o0000oj5kZOl000001onMN:T00ol0003oVGFXo`000002o`00
0003oiUfZOl0003oUG>Y00GoUG>Y00?o0000oi5`Z_l000005?l000001?n6KJoo0000ohM_/Ol00006
oh=]/@03ogeZ/ol0003oP6fc00;oP6fc00?o0000ogY[]_mjJkH01Ol00003ogQ[]`03o`000?mgK;[o
000000CoMVbj0ol00004og5[_003o`000?m`KL3oL6g000?o000000?oIf[2o`000?m/K/<00_m/K/<4
o`0000;oHVk900?o0000ofA_bOmTKlT00_l000001?mLK<WoIWC=ofIdcOmVM<d3oemed@03o`000?mT
Mm7o000000?oGGSE00?o0000of=ke_l000000omKMmH3ofV3fPCo00000omZRMh00ol0003oHXGOof:5
g`07o`0000KoMIWW00?o0000ogNUkomgYNl00_mgYNl5o`0000;oRjo^00Co0000ohB_lOn4[o7o0000
1?nA_oH01Ol0003oTKofoi6om_nA_oKo000000CoYM;g0ol000001?nYe_Oo0000ok_MlOl00002olWS
j`05o`000?o6l^koa_;^olKbk_o<l>/00_l00002omOhh@04o`000?oOo/7o0000o`0002gooo]Z00?o
0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP07oookJP002OoonfX00ol0003ooo]ZoookJP0D
oookJP?o000000WoglBno`000?oN`kkog/>no`000?oM`koo0000omc3`Ol000000ooK`/401?l0003o
fl70om[2`_l00003omW1`P;o000000Kof<33o`000?l0003o0000omK0a?l00003omJoa008o`000?oE
_/?oeKk3o`000?oD_/Go0000om>na_l00003om6maP03o`000?oB_<God[c500;o000000CodKc6o`00
0?o?_<Oo00000oo?^lL02_l0003oc[[7oljjaol0003oc[_7o`000?o>^/Oo0000olbjb?l00002olbi
b0?o000000GohlJko`000?l0003oh/Bjo`000003on73^P;o000000?ogl6jo`000?oM_[X00_oM_[X0
0ooL_K[o0000o`000002o`000003omjj]?l0003ogKVd00;ogKVd00Go0000om^g]?l0003ofKFdo`00
0002omRc]004o`000?oJ/[3of[:`omZb/0?o000000?of:n`o`000?oF[[000_oF[[02o`000004omJ/
[_l0003o0000o`0000;oe:V]00Co0000om6W[OoAYjgodJN]0_l00002om6V[0?o00000_o?XZX01Ol0
003obYn[olZOZoo:Wj_o000000?oc9nZ1?l00002olJJZ@03o`000?o8VZSob9ZX00;ob9ZX00?o0000
ol>FZ?o3UZP00_o3UZP01?l0003o`iJXol>FZ?o3UZP;o`0000;o_XnU00Co0000okb>Y_nlSZKo0000
0_nkSZH00ol0003o^H^UokV;Y@02okV;Y@03o`000?ngRZGo000000Ko]8NU0_l00006ok>7YP;o0000
1_naQJH2o`0000Ko[82U00?o0000ojMmY_l000002?l00003ojAlZ003o`000?nPNJOoX7VW00;o0000
0onQNjT4oiehZ@Go00001OnIMZT00ol0003oUG>YoiEcZ@05o`0000GoTW>]00?o0000ohia[_n>LJh0
0on>LJh2o`0000GoRW2_00?o0000ohI^/?l000000ol000000on7Kk7o0000oh=]/@03oh=]/@;o0000
1On0KK<2o`0000CoOFff0_l000001OmhJkOo0000ogM/^_mgK;[o000000?oMVbj00Co0000ogA^__l0
003oL6bn0_l000000omaJkco0000og1]`005og1]`003o`000?m/K/?oK6k300?oK6k300?o0000ofaa
aom/LLL00_l000000omRK/Wo0000o`000002ofQcbP04o`000?mVM<goIWC=o`0000?oGgGA00Co0000
ofAhd_l0003o00000omMN=D2o`000004ofMne_l0003o0000o`0000;oJH?J00?o0000of23g_mPPmh0
1?l00003of:5g`05o`000?maT^?oLI;Sog6Bhol000000_mZSn@4o`0000;oMIWW0_l00006ogNUk`06
o`000?n;[nkoRjo^oh^_k_l0003oQ:oa1_l00004oiG3mP03o`000?nUd_Oo000000;o00001OnYe_L2
o`000003olWSjol0003oa_;^00;o00000_o<l>/01Ol0003oeoSQomOhhOoOmm[ogok100?o0000;Ooo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z00Oooo]Z0009oookJP03o`000?oonf[o
oo]Z01Cooo]Z00Co0000on34_?oPa;co00000ooN`kh2o`000003omg3_ol0003ofl;100;ofl;100So
0000om_1`?oK`L3o0000om[0`?l0003ofL72o`0000;ofL3100Go0000omNo`_oG_l;oeko2o`000003
omJoa004o`000?oE_/?oeKk3omFn``;o000000?oe;k5o`000?oA_LH00_oA_LH02Ol0003od[c5om:l
aOoB_<Go0000om6ka?l0003odKc6o`000003olnka`03o`000?o>^/Ooc[[700;oc[[70ol000000oo>
^/Oo0000olbib002olbib004o`000?oPal7oh<O1o`0000;oh/Bj00Go0000on73^_oQ`k[ohL>jo`00
0002omo1^P;o00000_oM_[X3ombm^P03o`000?oN^[Cog[Zd00;o00000_oM^K@01?l0003ofkNdom^g
]?oK]k@3o`000003omRc]?l0003of[:`00;of[:`00?o0000omRa/?oH/K000_l00002omJ^/003o`00
0?oBZk7odZ^a00;o00000_oDZjh3o`0000;odJN]00Ko0000oljT[_o>Y:ko0000om6V[?l00002olnU
[0Co00000_o:Wj/00ol0003oc9nZolbOZP02olbOZP03o`000?o:WJWobYfY00Ko000000?ob9ZXo`00
0?o3UZP00_o3UZP2o`0000Co`iJX00?o0000okjBZ?nnTZP00_nnTZP00ol0003o_i:XoknBZ002oknB
Z0_o00000_niRjD00ol0003o]hZUo`000006okB7Y@03o`000?ncQjKo/hNV00Go/hNV00Co0000ok65
Y_naQJKo/HFV4Ol00002ojV1Z003o`000?nTO:SoY7bX00GoY7bX0_l00003oj5kZ@Ko00000onMN:T0
0ol0003oVGJYoiUfZ@02oiUfZ@Oo000000?oUWJ]o`000?nBLjd01_nBLjd00ol0003oSW6^o`000002
o`000003ohib[_l0003oRW2_00?oRW2_0ol00004ohI_/@So00001?n0KK<2o`0000GoOFff00?o0000
ogM[^OmhJkL00ol000001?mgK;[oMVbjogI/^_l00002ogA^_P04o`000?m`K;koL6bnog1/_P?o0000
1?m`KL02o`000003of]^a?m/K/?oK6k300;oK6k31_m/LLL00ol0003oJ7?:ofQcbP03ofQcbP;o0000
1?mOMM400ol0003oJ7_BofQkdP02o`000003oeeheOl0003oIgkF00CoIgkF1?l00002of23gP04o`00
0?mZRMko0000off;g`Co000000?oLI;So`000?mZSn@00_mZSn@01?l0003oNIcWogVLiomiW>L@o`00
00?oRK3`00?o0000oiG3m_nE`oH01OnE`oH00ol0003oZMKgojWFm`02ojWFm`;o00000on]foL2o`00
0003olKbk_l0003oc?3[00;oc?3[00Kod?;Xo`000?oGn>7ogoOJo`000?oOo/42o`0002oooo]Z00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP07oookJP002OoonfX00ol0003ooo]ZoookJP0C
oookJP04o`000?oPa;coh<Blon34_0;o000000Wog/>no`000?oN`[gog/:mo`000?oL`[ko0000om_2
`Ol000000_oK`L001?l0003of/30om[0`?oJ`<02o`00000:omW0`Ol0003of;o1o`000?oG_l;o0000
omNn`_l0003oe[o4o`0000?oeKk300?o0000omFm`ooE_L<00_l00002om6maP05o`000?oB_<God[c5
om:laOl000000ooA^l@3o`000003olnkaol0003oc[[700?oc[[700Co0000oljia_o>^LKoc[W60ol0
00002?o<^LSo0000o`000?oPal7o0000omk6`?l0003oh/Bj0_l000000ooQ`k[o0000omo1^P02omo1
^P04o`000?oN_k[o0000o`0000?og;fj00So0000omjj]?oN^[Co0000ombi]?l0003ogKVdo`0000?o
fkNd00?o0000omVe]?oI]K@00ol000000ooJ/[3o0000omRa/002omRa/005o`000?oG[k7o0000omJ^
/?l000000_oBZk400ol0003oe:^^omB[[P02omB[[P05o`000?oBZJko0000om6W[Ol000000_o>Y:h2
o`0000CocjF/00?o0000olfR[?o=XZ`01?l00002olbOZP03o`000?o:WJWobYfY00;obYfY00?o0000
olFJZol000000_o7VjT3o`0000;o`iJX00?o0000ol>FZ?l000000_o3UZP00ol0003o_Y:XokjBZ003
okjBZ003o`000?noTZSo_i:X00?o_i:X00Oo0000okZ>YonjSZOo^XjWo`000?nkSZOo000000?o^XjX
5ol00004ojn5Z003o`000?n[PZSoZh:X00?oZh:X1?l00005ojV1Z003o`000?nTO:SoY7bX00CoY7bX
0_l000001?nQNjWo0000o`000?l00002oj5lZP03o`000?nMN:WoWGRY00CoWGRY00?o0000oiUfZOl0
00001_l00004oiIf[@03o`000?nBLjgoTW>]00?oTW>]1?l00004ohib[P07o`000?n:L:ooRW2_ohY`
[ol0003oS76`o`000006ohI_/@;o00001?n3K[<3o`000004oh1]/ol0003oP6nfo`0000GoOFff0_l0
0004og]^^@03o`000?mfK;[o000000CoM6jn00?o0000og1/__l000000omdKkh01?l0003oL6g0og1]
`?l00002ofe_a004o`000?m[K/CoJfk4of]^a0;o00001?m/LLL00ol0003oIFo8o`000004ofQcbP04
o`000?mZN<oo0000o`0000;oGgGA00?o0000ofQkd_mXNm800omXNm82o`0000GoIgkF00?o0000ofb6
fom/Q]/00_l000000omPPmko0000off;g`04off;g`Ko000000?oJXoTo`000?miW>L00omiW>L00ol0
003oLI[Yo`000007og^Xl003o`000?n?/^ko000000;oRK3`1ol00005oiW7m`;o00000on]foL2o`00
0004ok?Jm?l0003o0000o`0000;oc?3[00Go0000om3bj?l0003oeoSQomogfP05o`00033ooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP07oookJP002?oonfX00ol0003ooo]ZoookJP0D
oookJP04o`000?oPa;coh<Blo`0000;oh<>k00Co0000omk2_OoN`[gog/:m0_l000001OoL`[ko0000
o`000?oK`L3o000000Cof/3000Co0000omZo_ol0003o00000_oH_l401?l0003oekk2omNn`_oG_/83
o`000003omFn`ol0003oeKg300;oeKg300?o0000omBl`_l000000_l00002om:la@03o`000?oA^lCo
dK_400;odK_400Co0000om6ja?oA^/Co00001?o>^/L01Ol0003oc[W6oljia_o>^LKo000000?oc[S5
0_l000000ooPb<3o0000omk6`002omk6`003o`000?oQ`k[ohL>j00?o000000[ogl6jo`000?oN_k[o
g[njo`000?oM_[Wo0000ombm^_l0003of[^i0_l00003ombi]005o`000?oK]kCofkNdom^g]?l00000
0ooI]K@00ol0003oe[:eomJb]@02o`0000;of;6`00Co0000omN_/OoG[k7oejna0ol000000ooBZk7o
0000omB[[P02omB[[P04o`000?oBZJkodZV^om:Y[P?o00000_o>Y:h01Ol0003ocjF/olnU[?o?YJco
000000CocJ:/00?o0000olVO[Ol000001?l00002olZMZ@04o`000?o5VZ_oaIZ[o`0000;oai^Y00?o
0000olJJZ_o6VZX02_l00002okjBZ003o`000?noTZSo000000?o_i:X00?o0000okZ>YonjSZL00_nj
SZL2o`0000Oo^XjX00?o0000okN;Z?ngRjP01?ngRjP2o`0000Ko/hRX0_l00006ojn5Z0;o000000?o
Zh:Xo`000?l000000_l00002oj^2Z003o`000?nYPJSoZH6X00GoZH6X00?o0000ojAlZ?nTO:P01_l0
0005oj5lZP03o`000?nMN:WoWGRY00?oWGRY1_l00002oiYi[003o`000?nFMZgoUWJ]00CoUWJ]00?o
0000oi9c[Ol000000_l00002oi=d[P03o`000?n>LZkoSW:^00CoSW:^0_n:L:l3ohaa/003o`000?n6
Kk7oQVna00?oQVna0_l00005oh=^/`03o`000?moK[Go000000?o000000?oP6nfo`000?mmKKH00_mm
KKH00ol0003oOFnio`000004og]^^@Go00000_mdK[h2o`0000CoM6nn00Co0000ofm^`Ol0003o0000
0_m]Kl@01?l0003oJfk4of]^a?l00002ofmaa004o`000?m/LLOoK777o`0000;oIFo80om/M//4o`00
00?oJWS?1Ol00002ofQkdP;o000000?oK8;Go`000?mWO]H00_mWO]H00ol0003oK8KKofb6f`03ofb6
f`03o`000?m]RmooKH_O00CoKH_O0_l00003og:Ci13o000000?oNjS`o`000?l000000_l00004ohnd
l003o`000?nIaoOoVLOg00?o00000onMboL01?l0003o[M_go`000?l00002ok?Jm0;o00000_nnjO82
o`0000;od?;X00Co0000omogf_l0003ofogF0_l000000ooHjX?o0000oookJP0`oookJP03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX01ooonfX000Sooo]Z00?o0000oookJ_oonfX04ooonfX2
o`000003on34_?l0003oh<>k00;oh<>k0_l000001OoN`[go0000omg1_OoM`Kgo000000;og<6n0_l0
0003om[0`007o`000?oJ_koof[noo`000?oI_[oo0000omRo`@02o`000003omNn`_l0003oe[g200;o
e[g200Go0000omFm`ooE_L?oeKg3o`000003omBl`P05o`000?oC^l?o0000om:laOl000000ooA^l@0
1?l0003odK[4om6ja?oA^/@3o`000003oljjaol0003oc[W600;oc[W600Co0000oljhaOo>^<Goc[S5
0_l00002on38`0;o000000Kog/K0o`000?oMa;oo0000on73^_l00002omo1^P04o`000?oN_k[og[nj
o`0000?ogKji0ol000000ooJ^kWo0000ombi]002ombi]0;o000000?ofkNdo`000?oI]K@00_oI]K@0
1?l0003oe[:eomJb]OoF/[D3o`000003omRa/?l0003oejna00;oejna00?o0000omB]/OoD[K400ol0
0002omB[[P05o`000?oBZJkodZV^om:Y[_l000000_o@Yjh5o`000003olnU[?l0003ocJ:/00;ocJ:/
00Ko0000olVO[Oo9Wjgo0000olbP[?l00002olZO[0Go000000?oaIZ[o`000?l000001?o6VZX01_l0
003o`IJZol6FZ_l0003o`iNYo`0000?o`YJZ1ol000000onoTZSo0000okZ>Y`03okZ>Y`;o00001_nj
SZP2o`0000Go]h^X00?o0000okF9Yol000001OncR:P00ol0003o/XNWo`000005ojn5Z0Co00001_n[
PZP01?l0003oZH6XojV1Z?nYPJP8o`0000?oYGnZ00?o0000oj5lZ_nQO:X01OnQO:X00ol0003oWGRY
o`000005o`0000GoVWV/00?o0000oiIf[OnFMZd00onFMZd3o`0000GoTgB^00?o0000ohib[_n>LZh0
0_n>LZh2o`000003ohY`[on<LK3oS76`00?oS76`00?o0000ohI_/Ol000000_l000000on9LK;o0000
oh=^/`04oh=^/`;o00001?n0K[H3o`000005oge]]_l0003oOFnioge_^Ol000000omkK[T00ol0003o
NW2logE]_003ogE]_0?o00001_mdKkh00ol0003oLg72og=a`P03o`000003of]^a?l0003oKg7400;o
Kg7400Co0000of]bb?l0003o00000_mUKlP3ofafb`04o`000?mWMlooIgO?o`0000?oJWS?00?o0000
of=ecom]O]<00_m]O]<4o`0000CoK8;G1Ol00002ofb6f`;o00000ombSn03off;g`03o`000?mbTnCo
LY?T00?oLY?T00Co0000ogjOj?mnWnSo00000omhW>P00ol0003oQZW/ohJYk005ohJYk003o`000?n?
]?3oSkC`00;oSkC`1_l00007oig;m`03o`000?ncf_Co/m[d00;o/m[d00Go0000okkYl_l0003o0000
ol?^l004o`000003omogf_oKoMKogOk@00;o000000?of>Z3oookJ_oonfX0<OoonfX00ol0003ooo]Z
oookJP0WoookJP03o`000?oonf[ooo]Z00Kooo]Z0008oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o
0000on;3^Ol000000ooP`k/00ol0003ogl:komo2^`02o`00000:omg1_Ol0003ogL6mo`000?oL`Kko
0000om_0__l0003of/30o`0000;of[no00Go0000omVn_ooI_[oofKjoo`000002omRn`@09o`000?oF
_L;oe[g2omJm`_l0003oe[c1o`000?oE_L?o000000?oe;c200Co0000omBk`_l0003odk_30ol00000
0ooA^lCo0000om6ja002om6ja003o`000?o@^L?od;W300Co000000?oc[W6o`000?o>^<D00_o>^<D2
o`0000;oh<S000?o0000omo6`?oOa/000_l00002omg4_`04o`000?oO`K[ogl6jomo1^P;o000000?o
g[njo`000?oM_[T00_oM_[T02?l0003og;biombl^Ol0003ofKVio`000?oL^KCo00000_oK^;@3o`00
0003omVe]?l0003oe[:e00?oe[:e00?o0000omRa/OoH/K400ol000000ooG[k7o0000omB]/@02omB]
/@03o`000?oAZk;o000000Co000000?odZV^o`000?o@Yjh00oo@Yjh2o`0000;ocjF^0ol00002olfR
[005o`000?o9WjgobIn]olVO[Ol000001?o:Wj`01?l0003ob9f[olRMZoo8WJ/4o`0000;oaYZZ00?o
0000ol6FZ_o1UZX00_o1UZX00ol0003o`YJZol:FZP04ol:FZP03o`000?nmTZWo000000;o_Y>Y2_l0
0003okZ>Z003o`000?nhS:So000000Co]h^X00Go0000okF9YoneRJOo]HVWo`000003ok>8Z006o`00
0?nbQjOo/XNWok:7Yol0003o[hFX4Ol00004ojR1ZP;o00001OnUOjX00ol0003oXGbZoj5lZP03oj5l
ZPGo00000onNNj`00ol0003oVWV/oiYi[005oiYi[003o`000?nFMZgo000000;o000000?oUgN]o`00
0?nCM:h01OnCM:h00ol0003oSW:^o`000002o`0000;oSg>_00?o0000ohaa/?n<LK000on<LK02o`00
00CoRG6b00Co0000oh=^/on3K[?oPfjc0_l000000on6LKCo0000oh1^]P03oh1^]P;o00000ommKkP3
o`0000;oNfji1?mjL;`3ogE]_004o`000?miL;goNG2mo`0000CoM6nn00?o0000og=a`_mcLL801?mc
LL800ol0003oKg74ofmaa003ofmaa003o`000?m_MLWoKgG900?o000000?oK7K;o`000?mWMll00omW
Mll4o`0000;oHgG?0om]O]<2ofIof0;o00000om/P]L00ol0003oI7oHog6:g002og6:g0Go00001Omb
Sn0=o`000003ogRLj?l0003oQZW/00GoQZW/1Ol00004ohnmm@03o`000?nMboOoWL_g00Co00000_nQ
d?P01Ol0003o/m[do`000?l0003o]mgc00;o00000_o3k_001?l0003ob^O[ol[Wjoo:in/7o`0003Co
oo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP06oookJP002?oonfX00ol0003ooo]Z
oookJP0BoookJP03o`000?oR`kWoh/>i00;o000000?oh<>ko`000?oO`[/00_oO`[/01?l0003og/6k
o`000?l00002omg1_@04o`000?oK`;kofl2nom_0_P;o000000?of[noo`000?oI_[l00ooI_[l2o`00
0005omRn`Ol0003o0000omJm`_l000000ooF_<43o`000003omBl`_l0003oe;_200;oe;_200Co0000
om:j`ooB^/?od[[30ol000000ooA^/Co0000om2i``02om2i``04o`000?o?^<CockS4olnha0?o0000
00Koc[S5o`000?l0003o0000on38`?l00003omo6`004o`000?oNa;oo0000omg4_`;o000000Cogl6j
o`000?oN_kWog[ni0_l00002omfn^@04o`000?oL_;Wog;biombl^@;o000000?ofKVio`000?oK^;@0
0_oK^;@00ol0003of[JeomZf]@03o`0000;oe[:e0_oD/KD00ol0003of;6ao`000002omN`/P;o0000
0_oD[K401Ol0003odJ^bom6[/_oAZk;o000000?odZZ`0_l00003om2W[P03o`000?o<Y:oo000000;o
cjF^00?o0000oljT[_o>Y:h01?l00002olVO[@05o`000?o:WjcobYn/olZO[?l000001Oo8WJ/00ol0
003oaY^/olJK[005o`0000;o`IJZ00?o0000ol:FZ_o2UZX00oo2UZX01?l0003o_I:YokfBZOl00002
okjCZ@03o`000?nmTj[o_I>Z00?o_I>Z00Co0000okZ?Z_njSj[o^XnZ6?l00002ojn6Z@05o`000?n`
Qj[o/8NZok27Z_l000000on/PjT01?l0003o[8>Yojb3ZOl00007ojR1ZP03o`000?nUOj[oYGnZ00Go
YGnZ00?o0000oj5lZ_l000000_l000000onQO:_o0000o`000005oiik[003o`000?nJNJcoVWV/00?o
VWV/1?l00005oiMg[@03o`000?nCM:koTgB^00;oTgB^0ol00002ohmc[`Ko00000_n<LK02o`0000Ko
RG6b00?o0000oh=^/ol000000on6LK@01ol0003oP6jfoh1^]_n0K[Ko0000oh=a]ol000001_mmKkP0
0omkK[Wo0000o`000003ogY`_0;oMFfl00Go0000ogU`_OmiL;goNG2mo`000002og=_`0Co00001?mc
LL800ol0003oLWC6og9daP04ofmaa003o`000?m_MLWoKgG900?oKgG90ol00003ofMgc`04o`000?mY
NM3oKWc@ofild0;o00000_m]O]<01?l0003oIWoHofIof?mVOmP5o`0000;oI7oH0omaR]`00ol0003o
JXKLofZ6g004o`000004og:?h?l0003oJHgRo`0000KoN9SU00?o0000ogjQjOmnXNT00_mnXNT:o`00
00SoSkge0_l00007oj7@n006o`000?nggO?o]mgcokOMlol0003o`nk`0_l00003ol[Wj`03olSbkOoA
o>;o000000Co0000=OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z00Kooo]Z0008
oookJP03o`000?oonf[ooo]Z017ooo]Z00Co0000on;3^OoR`kWo00000_oQ`[T2o`0000;ogl:k00Oo
0000omk1^ooN`K_o0000omjo^_l0003ogL6m00;o000000Cofl2no`000?oK_kgofknm0_l00003omVn
_`03o`000?oI_KoofKfo00Co00000ooF_<401?l0003oe;c2omBl`_oD_<83o`000006omBk`_l0003o
dk[2o`000?oB^/?o00000ooB^/802Ol0003od;W3om2i`oo@^L?o0000om2h`ol0003ockS4o`000003
olnha0?o000000?oh<O0o`000?l000000_oOa/001?l0003og/Boomk4_ooNa;l2o`000003omc2_ol0
003og[ni00;og[ni00Go0000omjn^Ol0003ogKjio`000002ombl^@03o`000?oJ^k[of[^j00?o0000
00?ofkRdo`000?oJ][D00_oJ][D00ol0003of;FeomRe]@02o`0000?oe;6e00Wo0000omN`/_oG/;;o
ek2bo`000?oE[k;o0000omB]/Ol000000ooAZk801_l0003odZZ`om:Z/?oBZ[3o0000om6Y[`;o0000
00Cod:N^o`000?o<Y:ooc:B_0_l00004oljT[P03o`000?o<XZgoc::]00?o00000oo:Wj`00ol0003o
b9f[olRMZ`02olRMZ`;o00000oo6Vj`01?l0003oaIV[olFIZoo5VJ/5o`0000;o`YJZ00?o0000okfB
ZOnmTZT00_nmTZT2o`0000Go_I>Z0_l00005okZ?ZP04o`000?nhSJSo^8fXo`0000?o]hbY00?o0000
okB9ZOndRJT00_ndRJT00ol0003o/hVYo`000003o`0000;o/XVZ00Co0000ojn6ZOn_QZWo00001?n`
QjX01?l0003o[8>Yojb3ZOl00003ojb3Z@03o`000?nXPJ[oZ86Z00CoZ86Z0_l00004ojEoZPGo0000
0_nQO:/2o`000003oj9n[?l0003oWW^/00GoWW^/00?o0000oiYi[?l000000_l00002oiYi[@03o`00
0?nGMjgoUgN]00?oUgN]2ol00003oi1e/@03o`000?n<Lk;oS7>b00go00001?n6LK@2oh1^]PCoPg6g
00?o0000oge_^?mmKkP00_mmKkP01?n0LKWoNW2kogY`^omjL;/3o`000003ogY`_?l0003oNG2m00Co
NG2m0_l00003ogMb`0;o00000_mcLL800ol0003oKVo3ofi_``04og9daP;o00001Om_MLT3og1jc@;o
00000_mWMll00ol0003oKWc@ofild003ofild0?o00000omVOmP01?l0003oJh;Ho`000?m_QMP3o`00
0003og6:g?l0003oJXKL00;oJXKL00Co0000ogJBhOmfT^7oMY;Q1ol00003ogRHi@03o`000?mnXNWo
OZ7Y00CoOZ7Y00?o0000oh^]k?n;[N`00on;[N`00ol0003oPjg`o`000002ohnmm@?o00000onC`OH0
0ol0003oXM3hoj7@n003o`0000CoYMCh00Co0000ok_Ol_l0003o00000oo:in/00ol0003ob?;]o`00
0002o`000003omcifol0003oe_fm03Oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP06oookJP002?oonfX00ol0003ooo]ZoookJP0@oookJP?o000000_oh/>io`000?oQ`[WohL:io`00
0?oP`KWo0000omo2^ol0003og/6ko`000003omjo^P04o`000?oL_kcog;nlo`0000?ofknm00Go0000
omZn_Ol0003ofKjoo`000002omVm_`04o`000?oH_;kof;bnomRl_P;o000000?oe[c1o`000?oD_<80
0ooD_<801?l0003oe;[0omBj`?l00003om>j`P03o`000?oB^/;od[[200;od[[20_l000000oo@^L?o
0000om2h``02om2h``07o`000?o?^<CockS4olnha?l0003ocKO4o`000002on37`005o`000?oOa[oo
0000omo6`?l000000ooNa;l01?l0003ogL>oo`000?l00002omjo^@04o`000?oN_[Wog[jiomjn^@;o
000000?og;bio`000?oJ^kX00_oJ^kX00ol0003of;Rjo`000002o`0000;of[Je00So0000omRe]OoH
]KGof;Feo`000?oF/kGo0000omBa]@;o00000_oG/;801?l0003oeJnbomF_/_oE[k83o`000006om6[
/_l0003od:Vbo`000?oBZ[3o00001?oAZJl3o`000003olbT[ol0003ocZB^00?ocZB^00?o0000olbR
[Oo<XZd00_o<XZd7o`0000;ob9f[00Ko0000olFK[?o5Vjco0000olJK[?l00005olFIZ`;o00000_o2
Uj/;o`0000;o_I>Z00Co0000ok^@ZOnkT:Wo00000onjSjX01Ol0003o^8fXokR=Z?nhSJSo000000;o
]hbY00?o0000okB9ZOndRJT00_ndRJT4o`0000Ko/XVZ0_l00006ok27ZP;o00001On/PjT00ol0003o
Z86ZojR1ZP09o`0000?oY7n/00Co0000oj5lZonQO:_o00001?nROZ`00ol0003oWW^/oiik[005o`00
00KoVWV]00?o0000oiMg[Ol000001Ol00005oi=g/003o`000?n@MK7oT7Fa00?oT7Fa0ol00004ohad
/P04o`000?n8L[CoR7:do`0000;oRWBd00?o0000ohEb]_n5L[H00ol000000on6LKCoP6jfoh=a]`04
oh=a]`04o`000?mmKkSoOFnhoge_^0;oP76i1OmjL;/4o`0000CoNG2m00?o0000ogMb`?mgL/000omg
L/04o`0000;oKVo30ombM<H00ol0003oKgK:ofmfbP02o`0000?oKgG900?oJgO=og1jcOm`N/d00om`
N/d2o`0000GoKWc@00?o0000og22eOm`P]D00_l00002ofIof003o`000?m_QMSoKhGH00?oKhGH1Ol0
00000omZQ]co0000ogJBh@02ogJBh@04o`000?m_Sn7oKhoQo`0000?oOI_U1?l000000omnXNWo0000
o`00000=o`0000OoTl7f0_l00003ojGDn0?o000000CoZ][hok_Ol_l0003o00000_o:in/01?l0003o
b?;]olSbkOo8l^d2o`000004omcifol0003oe_fmokoRNCSooo]Z00?o0000oookJ_oonfX09?oonfX0
0ol0003ooo]ZoookJP06oookJP002?oonfX00ol0003ooo]ZoookJP0@oookJP04o`000?oT`[Co0000
o`0000;ohL:i00Co0000on31^OoP`KWoh<6i0_l000000ooN`K_o0000omjo^P02omjo^P;o000000Go
g;nlo`000?l0003ofknmo`000003omZn_@;o000000?ofKfoo`000?oH_;h00ooH_;h3o`0000Coe;c2
00Co0000omBj`?oD^/3oe;[00_l000000ooC^/;o0000o`000003om:j`P04o`000?o@^L?od;W3om2i
``;o000000Sod;S3o`000?o@^<?o0000olnha?l0003ocKO4o`0000;oh<O000Go0000omo6_ooOa[oo
glJoo`000003omk4_`08o`000?oM`koogL>oo`000?oK`Koo0000omjo^Ol00003omjn^@04o`000?oL
_KWo0000o`0000;of[^j00Wo0000omRh^_oH^;[of;Rjo`000?oJ]kKo0000omZf]Ol000000_oH]KD0
1?l0003oe[>eomJc]OoF/kD4o`000003omN`/_l0003oeJnb00;oeJnb00?o0000om>]/_oC[K801?l0
00000ooBZ[3o0000om6Y[`03om6Y[`03o`000?o?Yk3ocjN`00Go000000?ocZB^o`000?o<XZd00_o<
XZd00ol0003oain_o`000002olZP[@03o`000?o9WjkobIn^00Co000000CoaI^/o`000?o6Vjco0000
1?o5VJ/01?l0003o`YN[ol:GZol00002ol:GZ`03o`000?o1UZ_o`IJ[00?o`IJ[00Co0000okfCZonm
Tj_o_I>[3?l00002okR=Z0;o00000_ndRJT3o`000003okB9ZOl0003o/XVZ00Oo/XVZ00Co0000ok27
Z_n`Qj[o/8NZ3ol00004ojV3[003o`000?nTOjcoY7n/00CoY7n/0ol00003oj9n[0Go00000onNO:d0
0ol0003oVWV]oiYi[@03oiYi[@Oo000000?oUgV`o`000?nCMk001_nCMk000ol0003oT7Fao`000002
o`000003oi5f/Ol0003oS7Bb00GoS7Bb0_l00004ohYd]003o`000?n5L[KoQG:f00;oQG:f1Ol00002
oh=a]`03o`000?mmKkSoOFnh00CoP76i0_mjL;/2o`0000;oOW:l00Co0000ogQa__l0003o00000_mi
L;d00ol0003oMg;0ogMb`003ogMb`004o`000?mfMLCoMWG4ogIea0;o00000_mbM<H01Ol0003oKgK:
ofmfb_m_M/[o000000;oKWK:00CoKgG9o`000?l0003o00001?m`N/d00ol0003oJWO>o`000002o`00
0004ofild?l0003oJGkEo`0000CoL8;E0ol00005ofn5f004o`000?mcSMgoLhgMog>=g@So000000?o
KhoQo`000?mmVnD00ommVnD2o`0000KoOJO^00?o0000ohn`kOn?/>d00_n?/>d01?l0003oRJo_ohV_
kol00002oi?1mPCo00000_nGaOL00ol0003oYMCho`000002o`0000GoZ][h0_l000000oo:in_o0000
olSbk@02olSbk@04olcdj_l0003og?WKomGoe@?o0000>OoonfX00ol0003ooo]ZoookJP0SoookJP03
o`000?oonf[ooo]Z00Kooo]Z0008oookJP03o`000?oonf[ooo]Z00oooo]Z00Co0000onC2]?oT`[Co
i<:d0_l000000ooQ`[Wo0000on31^@02on31^@03o`000?oO`;So000000?og[nj00?o0000omfn^_oM
_[X01?l00003omZn_@03o`000?oI_KkofKfn00;o00000ooH_;h00ol0003of;bnomRl_P03o`000003
omBl`_l0003oe;[000;oe;[000?o0000omBj`?oD^/001?l000000ooB^/;o0000om2i``02om2i``03
o`000?o@^<;od;S200?o000000?od;S3o`000?o=]l@00ol000000ooPal3o0000omo6_`02omo6_`;o
000000Gog/Boo`000?oM`koogL>oo`000003om_1_`05o`000?oN_[Wog[jiomjn^Ol000000_oL_KT0
1Ol0003ofk^jo`000?oJ^k[o000000?of;Rj00?o0000omZg]_oJ]kH00ol000000ooH]KGo0000omJc
]@02omJc]@03o`000?oC/;Kodk2f00Co000000?oeJnbo`000?oC[K800ooC[K800ol0003ocjZcolnZ
/`03o`0000;odJV_00?o0000olnW/?o?Yk000_o?Yk02o`0000;ocZF_0ol00002olbR[@03o`000?o7
Wjooain_00;o00001?o9Wjh00ol0003oa9^^olBK[P06o`0000;oaIV[00Ko0000ol:GZoo2Uj_o0000
ol:GZol00005ol6FZ`;o00001?nmTj/01Ol0003o^Y2[okZ@ZonjT:_o000000;o^Y2[00Co0000okV@
[?niT:co^I2/5ol00004ojn7Z`03o`000?n[QJcoZhF/00CoZhF/00?o0000ojR2Zol000001OnYPj`0
0ol0003oY7n/ojAo[004ojAo[003o`000?nROZcoXWj/00?o00000_nROjh00ol0003oWWb]oiil[@04
oiil[@03o`000?nJNJgo000000Ko00001?nGNK000ol0003oTgN`oi=g/003oi=g/0Co00001?nAM[40
0ol0003oS7Bbohad/P03ohad/P;o00001On:M;@00ol0003oQG:fo`000002o`000003ohMd]_l0003o
PW:h00;oPW:h1ol00002oh1a^@03ogY`^ol0003oOW:l00?oOW:l00Co0000ogQa__mhLKkoN76n1Ol0
0003ogMb`003o`000?mfMLCoMWG400CoMWG40ol00003ofmfbP;o00000omcNLX2o`0000;oL7[=00?o
0000ofYgc_mZMlh00ombOm44o`0000CoL8;E0_l00002og>9fP05o`000?m_QMSoKhGHofn5f?l00000
1OmcSMd00ol0003oMY?Ro`000003ogJDhPWo00001_mmYnh00ol0003oSk3]o`000007o`0000OoUlGg
00?o0000oj[Jn?nZf_P00_nZf_P3o`000006ojkOn?l0003o0000o`000?o8l^go00000_o<m>X00ol0
003og?WKomGoe@03o`0003_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP06oook
JP001ooonfX00ol0003ooo]ZoookJP0@oookJP06o`000?oT`[Coi<:donC2]?l0003ohl6d0ol00000
1?oP`KWo0000omo0^?oO`;P2o`000003omjo^_l0003ogKjj00;ogKjj00?o0000omfn^_oM_[X00_l0
00000ooJ_[go0000omVm_P02omVm_P05o`000?oI_;co0000omRl__l000000ooH_;h2o`000006omJj
__l0003o0000o`000?oD^/3o00000ooD^/000ol0003odkVoom>i_`02o`0000?od;W300Go0000om2h
`_o@^<;od;S2o`000002om2g`@;o000000?ocKO4o`000?oLbLH00_l00003omo6_`03o`000?oNaKoo
g/Fo00;o000000?ogL>oo`000?oK`Kl00ooK`Kl2o`000005omjn^Ol0003og;fiombm^Ol000000ooK
^kX3o`000006omRh^_l0003oe[Njo`000?oJ]kKo00000_oH]KD2o`0000;oe[>e00Go0000om>`]_oC
/;Kodk2fo`000003omF_/`;o00000ooC[K801Ol0003ocjZcolnZ/oo?Z[?o000000;odJV`0ol00003
olnW/003o`000?o;Y;7objBa00;o00000oo<Y:l4o`000003olNO[ol0003obIn^00?obIn^00?o0000
olBK[_o4Vjh00oo4Vjh01?l0003oaI^]olFK[Oo5Vjd6o`000003ol:GZol0003o`IJ[00?o`IJ[00Co
0000okjDZonnU:_o00000_nmTj/00ol0003o^Y2[okZ@Z`03okZ@Z`;o00000oniT:`4o`0000Ko]Xf/
00?o0000okF<Zol000001OnbRZ/00ol0003o/XV[o`000006ojn7Z`;o00001on[QJ`00ol0003oZH>/
ojV3[004ojV3[003o`000?nTOjcoY7n/00Oo00001OnROjh00ol0003oWWb]oiil[@03oiil[@Ko0000
0_nKO;000ol0003oUgV`oiMi/004oiMi/003o`000?nCMk3o000000;o00000_nDN;400ol0003oTGJa
oi5f/@04oi5f/@03o`000?n<M;;o000000;o000000?oSGFco`000?n:M;@01?n:M;@2o`0000CoQgBf
00?o0000oh9b^?n2L[P00_l00002ohEd^@04o`000?moL[_oOg:kogmb^`?o00001_mnL[`3o`0000?o
O7Bo00Co0000ogMc`_mgLl;oMg;00ol00005ogIea0?oMWS80_l000000om_M/[o0000og=ibP04og=i
bP04o`000?m_N/ko0000o`0000;oJWO>00Go0000og9odOmbOm7oLWoAo`000002ofb1eP;o000000Go
L8;Eo`000?mXOmOoJ7oGo`000004og>9fPKo00000_mcSMd00ol0003oMYCRogJDhP03ogJDhP05o`00
0?n1W^KoPIkVoh6Ni_l000000_mkVnH9o`000003ohjbk_l0003oSk;^00CoSk;^00?o0000oiO5monG
aOL00ol00003oi_:n004o`000?nZf_So0000o`0000?o[]oh0_l000000onljOCo0000o`000002olcd
jP;o00000_oEomD3o`0003_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP06oook
JP001ooonfX00ol0003ooo]ZoookJP0@oookJP;o000000Coi<:do`000?oS`KCohl6d0_l000001OoR
`;Go0000omo0^?oO`;So000000;ogknh0ol000000ooM_[[o0000omfn^P02omfn^P?o00000ooI_Kh0
1?l0003ofKblomVl_?oI_;`3o`000005omRl__l0003oekZmomNj_Ol000000ooE^[h01Ol0003oe;[0
omBj`?oD^/3o000000?odkVo00Go0000om>h_ol0003od;W3o`000003om2h`P07o`000?o@]l7od;O1
om2g`Ol0003od;K0o`000003omc9aP;o000000?oglJoo`000?oNaKl00_oNaKl01?l0003ogL>oo`00
0?l00003om_1_`03o`000?oJ_koof[no00?o000000?og;fio`000?oK^kX00_oK^kX00ol0003ofKZj
omVj^P02o`0000;oe[Nj00Wo0000omRe]OoH]KGof;Feo`000?oG];Ko0000omJc]Ol000000ooC/;H0
2Ol0003oeJncomF_/ooE[k?o0000omB_/ol0003odjfbo`000004olnZ/`09oljY/ol0003odJV`om6Y
/?l0003od:Vao`000?o?Yk3o000000?objBa00?o0000olbT[oo<Y:l00oo<Y:l00ol0003obj:_ol^R
[`05o`000003olVO[_l0003oa9^^00Coa9^^00?o0000olFK[Oo5Vjd00_o5Vjd01?l0003o`9N]ol2G
[Oo0Ujd9o`000005okjDZol0003o_I>[okfCZol000001OnjT:/5o`0000;o^I2/0_l00005okJ=[004
o`000?neS:_o]Hb[o`0000Co/XZ[00Co0000ok:9ZonbRJ_o00001On_Qj/01?l0003o[hN[ojn7Zol0
0005oj^5[0;o00000onYPj`8o`0000?oYX:^00?o0000oj9o[_nROjh01OnROjh00ol0003oWWb]oiil
[@05o`0000GoVgb`00?o0000oiMi/?nGNK000onGNK03o`0000GoU7Ra00?o0000oi5f/OnAM[400onA
M[43o`0000GoSGFc00?o0000ohYd]?l000000_l000000on;M[Ko0000ohMd]P04ohMd]P;o00001?n5
M;T00ol0003oOg:kogmb^`02o`0000;oPWBk1?l00002ogib_003o`000?mlM;ooO7Bo00CoO7Bo0_l0
0003ogYf`P;o00000omfML@2ogAgb0GoMWS80_l00005og=ibP03o`000?mcOLooLgg?00?o00000_mb
Om401Ol0003oK87Fofb1e_m/PMKo000000;oKh;F1?l00004og>9fP;o00001?mhT=h8o`000004ogJD
h_l0003oPIkVo`0000CoNi_V00?o0000ohRXj_n8Z>X01On8Z>X00ol0003oSk;^ohnbkP02ohnbkPGo
00001onKb_P00ol0003o[]ohojkOn002o`000004okCMm?l0003o0000o`0000;o`?3b1?l000001?oE
omGo0000o`000?l0000moookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX01OoonfX0
00Oooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003oiL6aonG1/@02o`000009on?1]?l0003oh[nd
on:o]?l0003ohKneo`000?oO`;So000000;ogknh00Co0000omjn^?oN_[So00000ooM_[X00ol0003o
g;fiombm^@02o`0000;ofKfn00Go0000omVl_?oI_;cofKblo`000002omRk_004o`000?oG^[goekZm
omNj_@;o000000KoeKZno`000?oE^Kko0000omBj`?l00003om>i_`04o`000?oC^;oodkRoom>h_`?o
000000?od;S2o`000?o@]l400_o@]l400ol0003od;K0o`000003omc9aP04o`000?oKalGoflO5o`00
00?og/Fo00So0000omg3_ooM`koo0000omc2_ol0003ofl6oo`0000?of[no0_l000000ooL_K[o0000
om^k^P02om^k^P09o`000?oI^[[ofKZjomVj^_l0003of;Rjo`000?oF]k[o000000;of;Fe00Co0000
omNd]_oG];KoekBf0ol000001_oC/;Ko0000om6_]ol0003oeJnco`0000?oe:nc0ol00002olnZ/`05
o`000?o>ZK?o0000om6Y/?l000000oo@ZK43o`0000;objBa00?o0000olbT[oo<Y:l00_o<Y:l00ol0
003obj:_ol^R[`02ol^R[`;o00000_o9X:l4o`0000;oa9^^00?o0000olBK[_l000000_o5Vjd00ol0
003o`9N]ol2G[@02ol2G[@;o00001?o1V:d00ol0003o_9B]okbD[@0>o`0000;o^I2/00Co0000okR>
ZonhSZ_o00000onfSJ`00ol0003o]Hb[okF<Z`02okF<Z`04o`000?nbRZ_o/XZ[o`0000Co/XV[00Ko
0000ojn7Zon_Qj_o[hN[o`000?n_Qj/=o`0000?oZ8>]00?o0000ojF0[?l000001OnVPZh00ol0003o
XWn^oj9o[P03oj9o[PKo00000_nOO[000ol0003oVgb`oi]l/005oi]l/003o`000?nGNK3o000000;o
000000?oV7Z`o`000?nDN;401OnDN;401?l0003oTGJaoi5f/OnAM[4;o`000006ohYd]?l0003o0000
o`000?n;M[Ko00001?n7M;H2o`0000KoQGBi0_l00004oh9d^`04o`000?mmLkkoOG>nogec_PCo0000
1OmlM;l00ol0003oNWK2ogYf`P03ogYf`P;o000000GoMWG4o`000?mdMlSoM7O8o`000003ogIhb005
o`000?maM/SoMWc<ogIlc?l000000_mcNLX2o`0000GoLgg?1Ol00002ofb1eP;o00000omcQMH8o`00
00CoN93N00?o0000og2>h?l000001?mmVN<?o`000003ohRXj_l0003o000000?o00001?n?_?@00ol0
003oVl[hoi_:n003o`0000CoWloh00Co0000okCMm?ndgOCo00000oo0l?82o`000003olWYkOo5m>ko
cOgP00Go0000?_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00Gooo]Z0007oook
JP03o`000?oonf[ooo]Z00oooo]Z00Go0000onG1/OoU`K7o0000onFo/@02o`0000;oh[nd0_l00000
1OoQ_kGo0000o`000?oO_kSo000000?og[jh0_l000000ooM_[[o0000ombm^@02ombm^@04o`000?oK
^kWo0000o`0000?ofKbl00Co0000omRk_?oH^kcof;^l0_l000001OoG^[go0000omJj_OoF^[go0000
00?oeKVn0ol000000ooC^Koo0000om>h_`03om>h_`03o`000?oA]koodKNo00?o000000Cod;O1o`00
0?o@]/3o00000ooLbLH01?l0003oflO5om_7aOoKalD2o`000005omk5_ol0003ogL>oomg3_ol00000
0ooL`[l01Ol0003of[noomZo_ooJ_koo000000;of;jo00Go0000om^l^_l0003ofk^jo`000003omVj
^P04o`000?oH^;[of;RjomRh^P?o000000?of;Feo`000?oG];H00_oG];H00ol0003oe[>fomJc]P03
o`000003om6_]ol0003oe:nc00?oe:nc00?o0000om:]/ooB[K<01Ol000000ooAZK3o0000om2Y/@02
om2Y/@03o`000?o>Yk7ocZNa00Go000000?oc:B_o`000?o;XZl00oo;XZl00ol0003oaYn`o`000002
olVP[`04o`000?o7Wjooain_olNO[`Go000000?oaI^]o`000?o0Ujd00oo0Ujd00ol0003o`IR]o`00
0003ol6H[@03o`000?nlU:go_9B]00?o_9B]00?o0000okbD[Ol000000ol000000onlU:go0000o`00
0003okVA[Aco00000_n^RJh01?l0003oZhF/oj^5[?l00003ojb7[P03o`000?nXPjgoZ8>]00CoZ8>]
0_l00007ojJ2[P03o`000?nROjko000000;o000000?oXWn^o`000?l000001OnOO[000ol0003oVgb`
oi]l/003oi]l/0Co00001OnHN[000ol0003oU7RaoiAh/@08o`0000;oTGRd00?o0000ohig]On>MkD0
0on>MkD2o`0000CoRWJg2?l00005ohEd^@;o00001On2M;/01?l0003oOG>nogec__l00003oh1f_P03
o`000?mkML7o000000;oO7Bo0_l00005ogYf`P04o`000?miN<KoNGS6ogUhaP?o00000_mfN<P01?l0
003oLGK8og5fb?maM/P3ogIlc0Ko00000_mcOLl00ol0003oMH?CogF3d`02ogF3d`?o00001OmcQMH0
0ol0003oLhWJo`000003ogN<f`Wo00001OmmVN<00ol0003oPJ7Woh6Qi`04oh6Qi`03o`000?n<[>_o
S:c[00CoS:c[0_l00004ohnlm004o`000?n?_?CoSkcdohnlm0;o00000onOcoP3o`000003ojCDnOl0
003o]=gd00;o00000_o0l?801?l0003obNW]o`000?o5m>h3o`000003omWlf_l0003o0000043ooo]Z
00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP05oookJP001ooonfX00ol0003ooo]Zoook
JP0>oookJP;o000000KoiL6ao`000?oU_k7oiKnao`000?oT_[42o`0000;oh[jd00?o0000on2n]OoP
_[D00_l00002omjn^003o`000?oN_KOog[fg00?o000000?og;fio`000?oK^kT00_oK^kT2o`000003
omVl_?l0003of;^l00;of;^l00?o0000omRj_?oH^[`00ol000000ooF^[go0000omFi_P02omFi_P03
o`000?oD^;koe;Rn00;o00000ooC^;l01Ol0003od[Nno`000?oA]koo000000;odKJo0_l000001Oo@
]/3o0000o`000?oLbLKo000000?oflO500?o0000om[6aOoJa/D00ol000000ooM`koo0000omc2_`02
omc2_`;o000000?of[noo`000?oH_[l00_oH_[l00ol0003ofkbjom^l^P03o`000003omVj^_l0003o
f;Rj00?of;Rj00?o0000omJg^_oF]kX00ol000000ooG];Ko0000omJc]P02omJc]P03o`000?oD/KOo
e;6g00;o00000ooD[k<00ol0003odZfcom:]/`02om:]/`03o`000?o@ZkCod:^d00Co000000?od:Va
o`000?o>Yk400oo>Yk401?l0003obJBbo`000?o<YK03o`0000;obj:_00Co0000olJO/?o6Wk3oaYn`
0_l00005olNO[`03o`000?o3Vjoo`i^_00Wo000000Go`IR]o`000?o1V:go`IR]o`000004okbD[@?o
00001?nlU:d01?l0003o^i:/ok^B[?l00003okVA[@05o`000?nfSZco]Xj/okJ>[?l000000_nfSZ`0
0ol0003o]Hj]okF>[@03okF>[@;o00001_nbRjd2o`0000Ko[XV^00?o0000oj^5[?l000001?n/Qjh0
0ol0003oZ8>]ojR3[@03ojR3[@03o`000?nXQ:go000000?oYX:^1_l000001_nROjko0000o`000?l0
003oXX6`o`0000KoWgj`00?o0000oi]l/?l000000_l00002oi]l/004o`000?nHN[3oV7Z`oiQj/0So
00000_nEN[<00ol0003oTGRdoi5h]004oi5h]003o`000?n>MkGo000000;o000000?oSgReo`000?n:
M[L01?n:M[L00ol0003oQgFho`000004ohUg^@Oo00001_n2M;/2o`0000CoP7Jn00?o0000og]e`Omk
ML401_l00002ogYf`P;o00001_miN<H4o`0000;oLGK80omfO<`01?l0003oLWk@og9nd?l00002og9n
d0Co00001OmePm<00ol0003oMhWHogN9f004og>5eP03o`000?mgS=_oMhcK00?oMhcK00Co0000ogNA
gomgTMoo00000omhT]l8o`0000KoPJ7W00?o0000ohb/jon<[>/02Ol00004oi?0mP03o`000?nOcoSo
000000;o00001OnTe?T00ol0003o^N3co`000003o`0000?oaOC^0_l000001?oIo=[o0000olcj]?l0
0011oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX01OoonfX000Oooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003oikn^o`000002onFo/@05o`000?oT_[7oi;jaonBn/Ol000000_oR
_[@2o`000006on2n]Ol0003ogkfeo`000?oN_[So00000_oN_KL01?l0003ogKbgomfl]ol00003om^k
^@03o`000?oK^kWo000000?o000000?of;^lo`000?oH^[`00_oH^[`00ol0003oekVkomNi^`03o`00
0003omFi__l0003oe;Rn00;oe;Rn00Go0000om>g_Ol0003odkRoo`000003om:g_P07o`000?oA][oo
dKJoom6f_ol0003od;K0o`000002omg9a@?o000000?oflO5o`000?oJa/D00_oJa/D2o`000003omg3
_ol0003og<:o00;og<:o00?o0000om_0_ooK`;l00ol000001_oH_[oo0000omNl_ol0003ofkbjo`00
00;ofKZj0_l00003omRh^P05o`000?oF]k[oe[NjomJg^_l000000_oG]KL2o`0000;oe[>f00?o0000
omBa]ooD/KL00_oD/KL3o`000003omB_/ol0003odZfc00;odZfc00Co0000om2[]?o@ZkCod:^d0_l0
0002olnY/P?o00000_o>Yk401?l0003obJBbolVT/_o9Y;82o`0000;objBa1Ol000000oo6Wk3o0000
olNO[`04olNO[`05o`000?o3Vjoo`i^_ol>K[ol000001Oo4W:l00ol0003o_iN_oknG[`0:o`000003
okfD[Ol0003o_9B]00;o_9B]00Go0000ok^B[?nkTZco^i:/o`000002okVA[@03o`000?nfSZco]Xj/
00?o]Xj/0_l00006okF>[@03o`000?nbRjgo/X^]00Go/X^]00?o0000ojj9[_n^RJh01On^RJh2o`00
00Ko[8N^00?o0000ojR3[Ol000002?l00004ojF2[`?o00001OnRPK000ol0003oWgj`oimn/005o`00
00CoVgb`1Ol00002oiQl/P?o00001OnEN[<00ol0003oTGRdoi5h]003oi5h]0?o00001?n?N;D00ol0
003oRWJgohYf]`03ohYf]`;o00001On9MkT00ol0003oQ7Fko`000004ohIg^`?o00000_n2M;/2o`00
00KoP7Jn0_l00003ogig`@05o`000?miMlCoNGO4o`000?mjM/800ol00005ogUhaP04o`000?miO<[o
NGc:ogUlbP;o00000_mfO<`01Ol0003oLWk@og9nd?mbO]3o000000;oLWk@00Co0000ogN1d?mgPM3o
Mh7@0_l00002ogF3d`03o`000?m^PMGo000000CoMhWH00CoLhGFo`000?l0003o00001?mgS=/2o`00
00GoN9;O00?o0000oh6Li?n1W>@00_n1W>@00ol0003oNi[Uo`000008o`0000;oTK3/00Go0000oh^^
kOn;[^goRjk]o`000007oi?0mP03o`000?nTe?WoY=Ci00;oY=Ci0_l00004ojSKn@03o`000?o9jNgo
000000?oaOC^00?ob_O[o`000?oIo=X00ol00012oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000
oookJ_oonfX01OoonfX000Oooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003oikn^onNo[P02o`00
0003onFo/Ol0003oi;ja00;oi;ja0ol00002on6m]005o`000?oO_KGogkfeomnm]Ol000000_oN_KL0
1?l0003ogKbgomfl]ooM_;L2o`000003om^k^Ol0003ofk^i00;ofk^i00?o0000omVj^_oI^[X00_l0
0002omRj_006o`000?oG^K_oekVkomNi^ol0003oekRk0_l00003omBh_P04o`000?oC]kgodkNmom>g
_@?o000000Sod[Nno`000?oB][ko0000om6f_ol0003od;K0o`0000?ogLW500Co0000omc7aOoLalGo
00000ooJa/D02?l0003ofLC5omW4aOl0003og<:oo`000?oL`[oo00000ooK`;l00ol0003of[noomZo
_`02o`0000;oekbo00Wo0000omVj^_oI^[[ofKZjo`000?oI^K[o0000omRh^_l000000ooF]kX02Ol0
003odkBko`000?oG]KOo0000omJc]ol0003oe[>fo`000003omBa]`04o`000?o@[[Oo0000om>_]0?o
000000?odZfco`000?o@Zk@00_o@Zk@01_l0003oc:ReolbX]Ol0003ocjVbo`0000;ocZRc0ol00003
olVT/P03o`000?o;Y;7objBa00;objBa00Co0000olVR/?o9X[3obJ:`1Ol000000oo7Wjoo0000ol>K
[`03ol>K[`03o`000?o4W:ooa9b_00;oa9b_00?o0000oknG[onoUjl00_noUjl4o`0000;o_iR_2ol0
00001?nkTZco0000okVA[Ol00006okJ>[003o`000?neSZgo]Hj]00Co]Hj]0_l00007ok:;[@03o`00
0?n^RJko[XV^00;o[XV^3Ol000000onXQ:ko0000ojV6[`02ojV6[`03o`000?nUPZooYH:_00CoYH:_
0_l00005oj:1/0;o000000?oWgj`o`000?l000000onOOk000ol0003oVgb`oi]l/003o`000004oian
/_l0003oV7bboiQl/P?o000000?oV7bbo`000?nEN[<01_nEN[<00ol0003oTGRdoi5h]002o`000003
oi9i]?l0003oSgRe00GoSgRe0_n:M[L3o`000003oh]g]ol0003oRGNi00CoRGNi0_l00005ohIg^`03
o`000?n2M[goPWJm00Go00001?n0M[h2o`0000GoOWO100?o0000ogUga?l000000ommNL@2o`0000?o
NGS600?oMg_:o`000?miO<X01OmiO<X4o`0000;oLWk@0_l00004ogN1d003o`000?mdPmCoM8?D00Co
00001?mgRMP00ol0003oL8OIo`000004ogZ@g004o`000?mgS=_o0000ogRBg`?o00000_mhT]l01?l0
003oPIcToh6Li?l00002og^Ji@03o`000?n0Z>goP:S]00GoP:S]00?o0000oi6`k?l000000_n;[^d7
o`0000GoUlGg0_l00003ojSKn@Ko00000_o5m>h01?l0003ob_O[o`000?oIo=X4o`0004?ooo]Z00?o
0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP05oookJP001ooonfX00ol0003ooo]ZoookJP0<
oookJP;o00000_oW_jh01?l0003oi[j]o`000?l00002onBn/@03o`000?oS_K3ohkf`00;o000000?o
hKfdo`000?oO_KD00_oO_KD2o`000005omjm]ol0003ogKbgomfl]ol000000_oL^kL3o`00000:om^k
^Ol0003of[Zio`000?oI^[[o0000omVi^Ol0003of;Zlo`0000;oekVk00Co0000omNh^ooG^;_oekRk
0_l000000ooD^;ko0000om>g_@02om>g_@04o`000?oC][godkJmom>f_@?o000000Cod[Jno`000?o@
]/3o00000ooMbLD01?l0003og<O5omc7aOoLalD2o`000003om[6aOl0003ofLC500;ofLC500Co0000
omc2_ooL`[oo00000ooK`;l02Ol0003of[noomZo_ooJ_koo0000omVm_ol0003oekboo`000002omVj
^P04o`000?oI^K[ofKVjomVi^P?o000000?oe[Njo`000?oC];/00_oC];/01?l0003oe[>gomJc]ooF
/kL3o`000003omBa]ol0003od:jg00;od:jg00Co0000om:]]?oB[KCodZfd0ol00002om2[]003o`00
0?o<Z;Goc:Re00;o00001?o>Z;<01_l0003ocJNbo`000?l0003obJBbo`0000?objBa00?o0000olVR
/?o9X[000oo9X[02o`0000;oaj2`1?l000001?o3Vjoo0000ol>K[ol00003olBL[`03o`000?noUjoo
000000?o00001_noV:l01?l0003o_9B^okbD[_l00002okbE[P04o`000?nlUJoo_9F_okbE[aoo0000
0_n^RJh00ol0003o[XV^o`000006oj^7[`03o`000?nXQ:ko000000CoZHJ_00?o0000ojF2[onUPZl0
0onUPZl00ol0003oYH>_o`000002oj:1/0?o00000_nRPK000ol0003oWgn`oimo/003oimo/0?o0000
0onLO[84o`0000CoV7bb00?o0000oiEj/onEN[<01OnEN[<00onAN;Co0000o`000003oi9i]003o`00
0?n?N;GoSgRe00?oSgRe00?o0000ohYf]ol000001?n;MkL00ol0003oRGNiohUg^@02ohUg^@03o`00
0?n9NK_o000000KoQWNk0_l00003ohAh_@04o`000?moMl3oOgO0ogmg`0Co00001_mnMl400ol0003o
OGW4ogeia002ogeia004o`000?mhNLOoN7W7ogUhaP;o000000?oMg_:o`000?miO<X00omiO<X00ol0
003oNH3>ogV0cP02ogV0cP?o00001_mgPM02o`0000?oN8KD1ol000000om`QmWo0000ogZ@g004ogZ@
g003o`000?mnUn7oOYOQ00;oOYOQ4?l000000on0Z>go0000o`000002o`0000CoT;;^00?o0000oiO5
monGaOL00ol00003oi_;n004o`000?nXfoWo0000o`0000;o[N7i0_l00002ok_/m0;o000000Gob_O[
o`000?l0003o0000olood002o`0004Gooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Zoook
JP05oookJP001ooonfX00ol0003ooo]ZoookJP0<oookJP04o`000?oX_JWo0000o`0000;oi[j]00Go
0000onFm[Ol0003oi;jao`000002on>m/003o`000?oR_;3o000000;o000000Cogkfeo`000?oO_;Co
gkbd0ol000001OoM_;Oo0000ombk]ooL^kOo000000;og;Zf0_l00002omZj^@04o`000?oI^KWofKVi
omVi^@;o000000?oekVko`000?oG^;/00_oG^;/00ol0003oe[NjomJg^P03o`000003om>g_Ol0003o
dkJm00?odkJm00?o0000om>e_?oC]K`01Ol000000ooMbLGo0000omc7a@02omc7a@04o`000?oKa/Co
flK4o`0000?ofLC500Co0000omS3a?l0003og<:o0_l000000ooK`;oo0000omZo_`02omZo_`04o`00
0?oI_KoofKfoomVm_`?o000000?ofKZjo`000?oI^KX00_oI^KX00ol0003oekRjomNh^P03o`000003
om>d^ol0003o000000?oe[>g00?o0000omBc]ooD/kL00ol000000oo@[[Oo0000o`000003om:]]003
o`000?oA[KGodJfe00Co00000_o<Z;D01Ol0003ocZRcoljX/oo>Z;?o000000CocJNb1?l000000oo;
Y;7o0000olVR/003olVR/003o`000?o5Wk7o000000;oaj2`00Co0000olJO/Oo6Wk7oaYna2_l00002
oknG[`03o`000?noV:oo_iR_00?o_iR_00?o0000okbD[_nlU:h00_nlU:h2o`0000Ko_9F_00?o0000
okRB[onhTZl00onhTZl00ol0003o]i2^o`000004okF?[P05o`000?ndSJgo]8f]okB=[Ol000000onb
S:h01Ol0003o/H^^ok6;[_naRjko000000Co[XV^00Co0000ojj9[_n^RJko00001_n[Qjl2o`0000Ko
ZHJ_00?o0000ojF2[ol000001ol00005oj:1/003o`000?nOOk3oWgn`00?o000000?oWh6bo`000?nL
O[800ol00002oiao/P03o`000?nHO;;oV7bb00CoV7bb00?o0000oiEj/onEN[<00_nEN[<3o`0000Ko
TWVd00Oo0000ohmh]On?N;GoSgReo`000?n?N[Oo000000KoRgNg00?o0000ohUg^On9MkT01?n9NK/0
0ol0003oQWNkohIg^`02ohIg^`;o00001On4N;d01?l0003oOgO0ogmg`?l00002oh9i`0Co00000_mn
Ml42o`0000GoOGW40_l00003ogalb0?o00000_miO<X00ol0003oMWk>o`000004ogV0cP04o`000?md
O/ooNXCBogZ4dPCoMh7@00?o0000ogR6e?mhQ]@00omhQ]@01?l0003oMhWIogN9fOl00002ogN:f@Co
00000_mjT=`00ol0003oLhkOo`000005ogjGh@03o`000?n1WNGo000000CoPIkU00?o0000oh^YjOn;
ZNT01On;ZNT00ol0003oT;;^oi2bkP02oi2bkPKo00001onKboP01ol0003o[N7iojgQnOl0003o]=ke
o`000?nkk?@00_l00002ol?Vk`?o000000?ocoo@o`000?o0n;<0AooonfX00ol0003ooo]ZoookJP0L
oookJP03o`000?oonf[ooo]Z00Gooo]Z0006oookJP03o`000?oonf[ooo]Z00gooo]Z00Co0000onRm
ZOoX_JWo00000_oV_Zd00ol0003oiKf]onFm[@02o`000006on>m/?l0003oh[b`on:l/?l0003oh[^`
0_l00003omnl]004o`000?oN^kKog[^fo`0000;og;^g00Wo0000ombj]_oL^[Kog;Zfo`000?oK^KKo
0000omZj^Ol000000ooI^KT00ol0003of;Rjo`000002o`000003omNh^ol0003oe[Nj00;oe[Nj00?o
0000omBf^ooD][/00_l00003om>f_@04o`000?oC]KcodkFlom>e_0;o00000_oIb//4o`000003omc7
aOl0003oflK400;oflK40_l000000ooIa<Go0000omS3a002omS3a003o`000?oK`;oofl2o00?o0000
00?of[noo`000?oI_Kl00ooI_Kl01?l0003oekboomNl_ol00003omVi^P05o`000?oG^;[oekRjomNh
^_l000000_oF]k/2o`000004om:c^ol0003oe[>go`0000?oe;>g00?o0000om>a]ooC/KL00_l00000
1?o?[KSo0000om:]]?l00004om6]]@03o`000?o?ZkGocj^e00?o00000_o>Z;<00ol0003ocJNbolfW
/P02olfW/P05o`000?o8Xk?ob:>co`000?o;YK800ol00002olVR/004o`000?o5Wk7oaInaolFO/@;o
00001?o6Wk400ol0003o`Y^ao`000004o`0000?o`Yba1_l000000onoV:oo0000okbD[P04okbD[P03
o`000?nlUJoo_9F_00Co_9F_0_l00004okRB[`04o`000?ngT:ko]i2^o`0000?o]Hn^00?o0000okB=
[OndSJd00_ndSJd01?l0003o/Xb^ok:<[_l00004ok6;[P05o`000?n^RJko[XV^ojj9[_l000001?n^
RJh00ol0003oZhN_oj^7[`02oj^7[`03o`000?n[Qjoo000000?oZHJ_1_l00005ojJ5/@03o`000?nR
PK3oXX6`00CoXX6`0ol00003oin1/P?o00001OnLOk800ol0003oV7bboiQl/P04oiQl/P03o`000?nE
N[?o000001Wo000000?oRGNio`000?l000001Ol000001On6Mk_o0000o`000?n6NKgo000000GoQ7Rm
00?o0000ogmg`?l000000on2NL001?l0003oOGS3ogeh`ommN<<6o`0000;oOGW40_l00005ogalb003
o`000?mhOL_o000000?o000000GoMWk>o`000?miP<koNH3>o`000002ogAnc`03o`000?mjQ=;oNXCB
00;oNXCB00CoMh7@o`000?l0003o00001?mhQ]@2o`0000CoMh[I0omoTmd9o`0000;oOYOQ00?o0000
oh6NiOn1W^D01?n1W^D01?l0003oRjWYoh^YjOn;ZNT2o`000003oh^YjOl0003o000000?o00001?nA
_O@00ol0003oVl_hoi_;n004o`0000?oX=3i00?o0000okCNmOndg_D00ol00003ol?Vk`;o^OO_00?o
0000olcngoo<o]l00_o0n;=8oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX01?oo
nfX000Kooo]Z00?o0000oookJ_oonfX03?oonfX01?l0003oj;fYonRmZOoX_JT3o`0000?oiKf]00?o
0000onBl[Ol000000_oR_;001?l0003oh[^`on:k/?oR^k02o`000003omnl]?l0003og[^f00;og[^f
0_l000001OoL^kOo0000ombj]_oL^[Ko000000?ofkVf0ol000001OoI^KWo0000omRh^_oH^;[o0000
00;oekNi0_l00003omJg^P08omJf^_l0003oe;Jko`000?oD]K_o0000om>f_Ol00003om>e_0;o0000
1?oIb//2o`000003omc7aOl0003oflK400;oflK400?o0000om_5a?oKaL@00ol000001_oH`lCo0000
omO1a?l0003ofl2oo`0000;of[nn0_l00003omVm_`04o`000?oG_;ooekboomNl_`;o000000?ofKVj
o`000?oG^;X00_oG^;X02Ol0003oe[NkomJg^ooF]k_o0000omBe^ol0003od[>ko`000003omBc]`06
o`000?oC/KOodk6gom>a]ol0003odJnh0ol00004om6]]@03o`000?o?ZkGocj^e00;ocj^e00?o0000
ol^X]_l000000ol00002olfW/P03o`000?o8Xk?ob:>c00;ob:>c00Co0000olVT/_o9Y;;obJBb1Ol0
00000oo5Wk7o0000olJO/@03olJO/@?o00000_o2Vk42o`0000Go`Yba00?o0000okjH/?l000000_no
VK0;o`0000;o_9F_00Co0000okZC[_njTjko00000_nhTZl00ol0003o]i2^okN@[P02okN@[P03o`00
0?neSjko000000Ko]8f]0_l00006ok6;[P03o`000?n^RJko000000Go[XV^00?o0000oj^7[ol00000
2?l00003ojR6/0;o00001_nVQK400ol0003oXX6`oj:1/003oj:1/0;o00000_nOPK83o`000003oin1
/_l0003oW7nb00KoW7nb00?o0000oiQl/_nHO;800_nHO;85o`0000?oUWff00?o0000oi9k]_nBNkH0
0onBNkH3o`0000CoSgZh00Co0000ohai^On<NKWoS7Vi0_l000000on>N[Wo0000ohUi^`05ohUi^`;o
000000?oQWNko`000?l000001?l00003ohAh_@;o00001On2NL000ol0003oOGS3o`000003oh5j``03
o`000?mlN/KoO7[600Co00001_mlO<P00ol0003oO7o<ogaoc002ogaoc0Oo000000?oM7k?o`000?mj
Q=800_mjQ=800ol0003oM8;Co`000003og^:eP03o`000?mhQ]Co000000Go000000CoMh[IognCgOmo
Tmgo00001?miT=d01?l0003oPi_Roh>Kh_n3Vn8=o`0000?oT:gZ00?o0000ohV]kOl000001onA_O@2
o`0000?oX=3i0ol00002ojCGn@03o`000?ndg_Go000000?o`nK_0onimnl01Ol0003oc?kOolcngol0
003o`?Rc04Wooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP04oookJP001_oonfX0
0ol0003ooo]ZoookJP0<oookJP;o000000Coj;fYo`000?oW_:WoikbY0_l000001?oU_Jgo0000onBl
[OoT_:d2o`000003on:l/?l0003oh[^`00;oh[^`00Co0000on6j/?l0003o00000_oN^kH00ol0003o
gKVdomfi]003o`000003ombj]_l0003ofkVf00;ofkVf00Co0000om^h]_l0003o00000_oH^;X02Ol0
003oekNiomNg^OoG]kWo0000omNf^?l0003oe[Njo`000002omJf^P04o`000?oD]K_oe;FkomBe^`?o
000000CodkFlo`000?l0003o00000ooIb//02?l0003of<W;omS9bol0003oflK4o`000?oKa/Co0000
0ooKaL@01?l0003of/C4om[4a?l00003omO1a009o`000?oJ_kkof[nnomZo__l0003ofKfno`000?oI
_Koo000000?oekbo00?o0000omBj_ooD^[l00ol000000ooG^;[o0000omJg^`02omJg^`04o`000?oD
]K_oe;FkomBe^`?o000000?oe;>go`000?oC/KL00_oC/KL00ol0003odJnhom6_^002om6_^0?o0000
00?odJfeo`000?o?ZkD00oo?ZkD00ol0003objRfol^X]P02o`0000;ocJRd0ol00004olRS/`03o`00
0?o9Y;;obJBb00;obJBb00Co0000olRR/_o8X[;ob::b2Ol00002ol:K/@03o`000?o2W;7o`Yba00?o
`Yba00Co0000okjH/?nnV;3o_YR`0_l00006okjI/@;o00000onkUK0Yo`0000Co[8Va00?o0000ojR6
/?nXQ[000onXQ[000ol0003oZ8J`o`000007ojJ5/@03o`000?nRPK3o000000Ko00001?nOPK800ol0
003oW7nboiao/P05oiao/P03o`000?nHO;;o000000;o00000_nIOkD00ol0003oUWffoiIm]P04oiIm
]P03o`000?nBNkKo000000;o000000?oTgbgo`000?n?N[P01On?N[P3o`0000CoSWZi1On9NK/2o`00
00GoR7Zm00?o0000ohAi_on4NKl01_l00004oh9i`0;o00001On1N/<2o`0000CoOgg60ol00002ogal
b0;o00001_mlOl`00ol0003oO8??ogb3c`02ogb3c`;o00000_mjQ=801Ol0003oM8;CogB2domdP]?o
000000CoNh[F0_l00004ogj@fP?o000000CoNI3Mo`000?l0003o00000_miT=d00ol0003oPi_Roh>K
hP02oh>KhP03o`000?mlVNCo000000KoPJK/00Ko0000oi2]j_n@[N[oT:gZo`000?n9[Nd6o`0000Co
UL;f00Co0000oj3@nOl0003o00001_nTeoT2o`0000;o`nK_00Co^OO_o`000?l0003o00000_o<o]l0
0ol0003o`?RcoookJP1:oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX01?oonfX0
00Kooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003oj[bTo`000003onNlZ@04o`000?oV^jWo0000
o`0000;oi;b]00?o0000onBk[Ol000000_l000002OoR^k3o0000on6j/?oQ^[3o0000on2i[ol0003o
g[^fo`000002omfi]004o`000?oM^;CogKRdo`0000?ofkVf00So0000om^h]_oK^;Ko0000omZg]Ol0
003of;Rjo`0000;oekNi00Co0000omNf^?oG][SoekJh0ol000000ooF][[o0000omBe^`02omBe^`03
o`000?oC];_odkBk00?o000000Cof/[:o`000?oIb/_o00000ooHbL/2o`000003om_6a?l0003oflG4
00;oflG400Co0000om[4a?oJa<Cof/C40_l000001_oG`LCo0000omK0a?l0003of[nno`0000?ofKfn
0ol000000ooG_;oo0000omBj_`02omBj_`03o`000?oG^;_oekRk00?o000000?oe[Nko`000?oD]K/0
0ooD]K/00ol0003odK:lo`000003o`0000;odk6g00?o0000om6_^?oA[kP00_oA[kP00ol0003odJjf
om6^]P03o`0000;ocj^e00Go0000ol^X]_o;Z;KobjRfo`000004olfX]008o`000?o<YkCo0000o`00
0?o8Xk?o0000olRS/ol00002olVT/P04o`000?o8X[;ob::bolRR/P?o00000oo6X;801?l0003oaJ2b
olFP/_o5X;83o`0000Co`Yba00?o0000okjH/?nnV;000_nnV;000ol0003o_YVaokjI/@04okjI/@03
o`000?nlU[3o000000Co^iF`00Co0000okRB[onhTZoo^9:_0_l00007okRC/003o`000?ndT;3o]92`
00Go]92`00?o0000ok6=/?naSK001?naSK02o`0000Oo[X^`0_l00005ojb9/@04o`000?nXQ[3oZ8J`
ojR6/0;o00000onXQ[001?l0003oYXFaojJ5/OnVQK46o`0000CoXhBc00?o0000oin1/_nOPK801?nO
PK801?l0003oW7nboiao/_nLOk85o`0000GoVGne00?o0000oiIm]_nFOKH00onFOKH3o`0000CoTgbg
00?o0000ohmj^?n?N[P00on?N[P2o`0000KoSWZi00Ko0000ohUi^on9NK_oRGVko`000?n:N[/7ohQj
_@;o00001?n6Nkl01?l0003oPW[2oh9j`_n2N/84o`0000GoPG[300?o0000ogmma_moOLH00omoOLH0
0ol0003oNgg9og]mb@07o`0000;oO7o<0_l00005ogb3c`03o`000?miQM?o000000?o000000?oM8;C
o`000?mkR]H00_mkR]H01?l0003oMXSHogJ8f?l00005ogj@fP03o`000?n1UmooPIOO00;oPIOO4?l0
00000on1Y^co0000o`000003o`0000?oSjo/00?o0000oiG2m_nE`_H01OnE`_H00ol0003oY=OiojCG
n@02ojCGn@;o00000onYgOX2o`000003okWgkol0003oa?O]00;o000000Coc?kOo`000?l0003o0000
C?oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00Cooo]Z0006oookJP03o`000?oo
nf[ooo]Z00_ooo]Z00?o0000onZlY?oZ_:@00_l000001_oW_:Wo0000onJkZOoV^jWo0000onJjZ@;o
00000_oT^jd01?l0003ohkZ]on>j[Ol00002on6j/003o`000?oP^Jooh;V_00?o000000?ogKVdo`00
0?oM^;@00_oM^;@2o`000005om^i]_l0003ofkRfom^h]_l000000ooJ]kD3o`000003omNg^Ol0003o
ekJh00;oekJh00?o0000omJe^?oF]KP00ol000000ooD]K_o0000om>d^`02om>d^`;o00000ooJb/X0
1Ol0003of<W;omS9booHbL_o000000;oelO:00Go0000om_5a?l0003oflG4o`000003om[4a003o`00
0?oI`/CofL;400?o000000?oe/34o`000?oI_Kh00_oI_Kh01Ol0003of;fnomRm__oH_Kko000000?o
e;Zo00Go0000om>i_ol0003oekRko`000002omJg^`;o00000ooD]K/01Ol0003odK:lom6b_?oA/[co
000000;odk6h0ol00003om6_^005o`000?o=[KWo0000om6^]_l000000_o@[KH4o`0000;objRf00Go
0000olfX]?o=Z;CocJRdo`000004olbW]0Co000000?obJBbo`000?l000001?l00002olBO/`03o`00
0?o6X;;o000000GoaJ2b00?o0000ol6K/_l000001_l00002okjH/003o`000?nnVK7o_YVa00?o_YVa
00Go0000okbF/?nlU[3o_9J`o`000002ok^E/003o`000?nhTZoo^9:_00;o^9:_00?o0000okRC/?nh
Tk001OnhTk02o`0000Ko]92`0_l00005ok6=/003o`000?naSK3o000000Oo[X^`00?o0000ojb9/On/
RK401On/RK400ol0003oZ8J`o`000002ojR6/0Oo00000_nUQK42o`0000KoXhBc00?o0000oin1/_nO
PK800onOPK87o`000003oif1]Ol0003oVGne00KoVGne00?o0000oiIm]_l000000_l000000onFOKKo
0000oi=l]`05oi=l]`03o`000?n?N[So000000;o000000?oT7^ho`000?n>N[T01On>N[T00ol0003o
RGVkohUi^`03ohYj^`03o`000?n8N[goR7Zm00?oR7Zm0_l00006ohIk_`?o00000on4O<84o`0000;o
PG[300?o0000ogmma_moOLH01?moOLH2o`0000CoOWo:00?o0000og^0cOmkP<d01Ol00005ogb3c`03
o`000?mmR=?oOHSC00;oOHSC2Ol00005ogj@fP;o00001_n1Uml00ol0003oPYcSo`000004oh:Lh`03
o`000?n<YnOoS:OW00CoS:OW00?o0000ohn_k?l000000_n?[n`8o`0000CoVLOg0_l00003ojWMnP;o
000000?o/=kgo`000?ngjOH00_l000001?o4mngo0000o`000?o<o]l3o`0004kooo]Z00?o0000oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP04oookJP001_oonfX00ol0003ooo]ZoookJP0;oookJP05
o`000?oZ_:Coj[bTo`000?oY^Z@00_l00002onJkZ@03o`000?oV^ZWoi[ZY00?o00000ooS^Zd2o`00
0005on6j/?l0003oh;V_on2i[ol000000_oO^;02o`0000;ogKRd00?o0000ombg/ooL]k<00ol00000
0ooK^;Ko0000omZg]@02omZg]@04o`000?oI][KofKJfo`0000?oekJh00Ko0000omJe^?oF]KSoe[Fh
o`000?oF];L2o`0000?odkBk0_l00003om[:bP05o`000?oIbLWo0000omS9bol000000_oGalX01?l0
003oe/K:o`000?oKaL@3o`000003om[4a?l0003ofL;400;ofL;400?o0000omO1a?oG`L@00ol00000
0ooI_Kko0000omRm_P03omRm_P;o000000?oe;Zoo`000?oC^Kl00_oC^Kl02Ol0003oe[NkomJg^ooF
]k_o0000omFg^ol0003oe;Fko`000004om6b_009o`000?oC/KSodk6hom>a^?l0003od[6io`000?oA
[kSo000000?ocJfi00?o0000om2]]_o@[KH00_o@[KH00ol0003ocZbfolj/]P04o`0000;ocJRd00Go
0000olbW]?o<YkCoc:Ndo`000003olNS]@Wo000000Coa9nco`000?o6X;;o00001?o5X;801?l0003o
`I^bol6K/_l00002ol:L/@04o`000?o1W;;o`Ibbol6L/P_o000000Co_9J`o`000?nkUK3o00001Onh
TZl00ol0003o^9>`okRC/004okRC/003o`000?ngTK3o000000Go]92`00?o0000okB?/?l000001?na
SK001Ol0003o/Hf`ok6=/?naSK3o000000Go[X^`0_l00004ojb9/@So00000onXQk801?l0003oYHFa
ojF5/OnUQK42o`000003ojJ6/ol0003oXhBc00KoXhBc00?o0000oin1/_l000001_l00004oif1]@03
o`000?nIOkGoVGne00?oVGne1?l00005oiIm]P03o`000?nCO;OoTgbg00;oTgbg0ol00002oi1k^0Oo
00000_n>N[T00ol0003oRGVkohYj^`04ohYj^`03o`000?n8N[goR7Zm00;o000000?oR7boo`000?n6
Nkl01On6Nkl00ol0003oQ7c2ohAl`P03ohAl`P04o`000?n0O<GoP7c5oh1la@Ko00000omoOLH00ol0
003oOWo:ogiobP04ogiobP04o`000?mkP<goNh3=o`0000;oOX?=1ol00006ogf8d`03o`000?mkRmSo
000000?oOXgH3?l00003oh6Gg`03o`000?n2W>?oPYcS00CoPYcS00Co0000ohbWion<YnOoS:OW0_l0
00000on<YnOo0000o`000002o`0000CoT;[c00?o0000oiW7monIaoL00ol00003oig>n@04o`000?nY
gO[o0000o`0000;o/=kg0ol000001?njlO?o0000o`000?o8nNT4o`00053ooo]Z00?o0000oookJ_oo
nfX06?oonfX00ol0003ooo]ZoookJP04oookJP001_oonfX00ol0003ooo]ZoookJP0;oookJP?o0000
0_oY^Z@01?l0003oj;VTo`000?l00003onJjZ@03o`000?oU^JWo000000;ohkZ]00?o0000on:i[?oR
^J`00ol000002OoP^JoogkR_o`000?oO^;3o0000omjg/?l0003ogKRdo`000002ombg/`03o`000?oK
]k?ofkNc00;o00000_oJ]kD01?l0003ofKJeo`000?oI][H2o`000003omNf^?l0003oe[Fh00;oe[Fh
00Go0000omJd]ooF];Ooe[Bgo`000003om>d^`;o00000_oJb/X01?l0003ofLW9omW9bOoIbLT2o`00
0003omO7b_l0003oe/K:00;oe/K:00Go0000om[4a?oJa<Cof/C4o`000003omW2a006o`000?oG`LCo
el74omO1a?l0003oe/340_l00004omRm_P04o`000?oG_;ooekboomBj_`;o000000?odkVoo`000?l0
00000_oF]k/01?l0003oeKNkomFg^ooE]k/3o`0000;odK:l0_l00002om>a^004o`000?oB/KWod[6i
om:a^@?o00000_o=[KT01Ol0003od:ffom2]]_o@[KKo000000CocZbf00?o0000olVX]oo9Z;L01?l0
00000oo<YkCo0000o`000003o`000003olNS]Ol0003ob:Bd00?ob:Bd00?o0000olNR/oo7X[<01Ol0
0002olFP/P03o`000?o1Vk;o`I^b00;o`I^b0_l00005ol6L/P03o`000?nmV;;o000000?o_YVa00Co
0000okfI/_nmVK;o_IVb4_l000000ongTK3o0000okB@/002okB@/006o`000?ndSk3o]8n`okB?/?l0
003o/Hf`4_l000001?n[RK7o0000oj^9/Ol00007ojR7/P04o`000?nUQK7oYHFao`0000CoYXJc00Co
0000oj>4/onSQ;?oXhBc2?l00002oj23]@03o`000?nMPKGoWH6e00CoWH6e00?o0000oiUo]Ol00000
0_l00002oiUo]@03o`000?nFOKKoUWff00;oUWff3?l00003oi5m^P03o`000?n=O;_oSGbk00co0000
00KoR7Zmo`000?l0003o0000ohQl_ol00004ohIk_`;o00001_n4O<83o`0000?oPgk500Co0000ogin
b?mnO/SoOWk81Ol00004ogiobP03o`000?mkP<go000000?oOX?=00Go0000og^4dOmkQ=7oNhCAo`00
0002og^5d@Co00000ommR=<00ol0003oOXgHogj=f003ogj=f004o`000?mmTMcoOI7Lo`0000?oOY7L
00?o0000ohFJh?n5V^000_n5V^0=o`0000?oT:_Y00?o0000oi2jlon@^_<01_n@^_<2o`0000OoWLki
00?o0000ok3Nmon`g_L00_n`g_L4o`0000;oaNc_00?o]_[Yo`000?o@omD00_l0001@oookJP03o`00
0?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX01?oonfX000Kooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ok;RMo`000002onVjY003o`000?oX^JCoj;VT00;o000000Coi[ZYo`000?oU^JWoiKVY
0_l000001OoS^Zgo0000on:i[?oR^Jco000000;oh[R/00Co0000omnh[ooO^:oo00000ooN]k02o`00
0003ombg/ol0003ofkNc00;ofkNc00Go0000om^f/_l0003of[Neo`000002omVf]@03o`000?oH]KKo
f;Ff00?o000000?oe[Fho`000?oF];L00_oF];L00ol0003oeK>go`000004o`000003om[:b_l0003o
fLW900;ofLW900?o0000omS8bOoHb<T00_l00003omK6bP;o000000Kof/C4o`000?oI`/?o0000omW2
a?l00003omO1a004o`000?oF`<Coe/34omK0a0?o000000?of;fno`000?oG_;l00_oG_;l00ol0003o
e[^oomJk_`04o`000003omJg^ol0003oeKNk00;oeKNk00?o0000om>e^ooC]K/01_l00004om:a^@03
o`000?o@/;Wod;2i00Co000000?od:ffo`000?o>[;H00oo>[;H01Ol0003obJRgolVX]oo9Z;Oo0000
00;oc:Nd1Ol00002olNS]@;o00000oo8Y;@00ol0003oaj:colNR/`02olNR/`;o00000_o5X;<5o`00
00;o`I^b00?o0000ol6L/_o1W;800oo1W;801?l0003o_IRbokfH/_l00002okjI/@03o`000?nmVK;o
_IVb00?o_IVb00?o0000ok^F/_nkU[800onkU[801?l0003o^9>aokRC/Ol00003okRC/@04o`000?ng
Tk;o]i>bokNC/P_o000000?o/Hjao`000?naS[800onaS[801?l0003o[X^aojj;/Ol00004ojn=/P05
o`000?n[RK7oZhVaoj^9/Ol000000_n[RK400ol0003oZ8NbojR7/P05ojR7/P?o00000_nVQ[<7o`00
00;oXXBc0ol00005oj23]@03o`000?nMPKGoWH6e00?oWH6e0ol00005oiUo]@03o`000?nFOKKo0000
00;o000000CoUgnho`000?l0003o00001OnCO[T00ol0003oTGfjoi5m^P03oi5m^P?o00001?n?OK/0
0ol0003oRgbmoh]l_@03oh]l_@;o00001?n:OKl;o`0000?oQ7c200?o0000oh=naOn3O/D00on3O/D0
1?l0003oOWk8oginb?l00003ogmnb0CoPH?;00Co0000ogiob_l0003o00001OmnPld00ol0003oNhCA
o`000003og^5d@CoP8_E1_l00004ogj=f0;o00001OmnTM`00ol0003oQI[PohFJh002ohFJh0;o0000
1on3YNX00ol0003oT:_Yoi2[j@02oi2[j@03o`000?n9[>co000000;oT;[c0ol00003oiC0m@03o`00
0?nMc_WoWLki00?o00001?nRe?X4o`0000?oaNc_0_nfn^T01?l0003od?oEo`000?l0001BoookJP03
o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX01?oonfX000Gooo]Z00?o0000oookJ_oonfX0
2ooonfX00ol0003ok;RMonbhW@03o`0000?oj;VT00?o0000onNhY?l000000_oU^JT00ol0003oi;RX
onBhZ004o`0000?oh[R/0_l000001OoO^:oo0000o`000?oN]k3o000000;ogKJa0_l00002om^g/`04
o`000?oK][;ofkJbom^f/P;o000000?ofKJeo`000?l000000_oH]KH00ol0003oekBgomNd]`03o`00
0003omJd]ol0003oeK>g00;oeK>g00?o0000omG;d?oEbm000_l00003omW9b@09o`000?oHb<Wof<S9
omS8bOl0003of<K9o`000?oFa/[o000000;oe/C900Co0000omW2`ooI`/?ofL;30ol000000ooG`LCo
0000omK0a002omK0a005o`000?oD_LCo0000omRm_ol000000ooG_;l01Ol0003oe[^oomJk_ooF^koo
000000;oe;Vo0_l00003omFg^`03o`000?oC]K_odkFk00;odkFk00Co0000om:d_?oB];co00001?oB
/KT00ol0003od;2iom2`^@02om2`^@03o`000?o<[;[o000000?o00000_o>[;H01?l0003obJRgolVX
]oo9Z;L4o`000003olbW]?l0003obZRf00;obZRf1Ol000000oo8Y;Co0000olNR/`03olNR/`04o`00
0?o3WkCo`indo`0000;oaJ2c00Co0000olBP]?o4X;Coa:2d1Ol00002ol6L/P03o`000?nmV;;o_IRb
00;o_IRb0_l00005okfI/P;o00001?nkU[801Ol0003o^9>aokRC/OnhTk7o000000;o^9>a00?o0000
okNC/_ngTk800ongTk82o`0000Ko]96b00?o0000ok6>/Ol000001_naS[82o`0000Go[hfb00Co0000
oj^9/On[RK7o00001?n[RK400ol0003oZ8NbojR7/P09o`0000?oYHJd00Co0000oj:4/onRQ;?oXXBc
0_l000000onSQ[Go0000oj23]@06oj23]@03o`000?nMPKGo000000;o000000?oW86eo`000?nIOkD0
0_nIOkD5o`0000;oUgnh0_l000000onGP;So0000oi=n^@05oi=n^@04o`000?nAOK[oTGfjoi5m^P;o
000000?oTGjjo`000?n?OK/01On?OK/00ol0003oRgbmo`000002o`000003oh]l_On:OKooRWfo00Co
RWfo00?o0000ohIl`_l000001?n8O/801?l0003oQ7g4ohAma?n4OL@5o`0000CoPgk50_l00005ogmn
b0?oPH?;00?o0000ogj1c?mnPL`01?n1Q/l2ogj3c@;o00001OmkQM44oh2;e@03o`000?mkRMKo0000
00CoPY7I00?o0000ogj=f?l000003_l00004oh>UjP;o000000?oPjGZo`000?l000001ol00007oiC0
m@;o00000onRe?X3o`000003ojKLn_l0003o000000;oaNc_0_l00002okKjj@04o`000?o@omGo0000
o`0005Cooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP04oookJP001OoonfX00ol0
003ooo]ZoookJP0;oookJP?o00000_o[]id4o`0000;oikRT0_l000001OoU^JWo0000onBhZ?oT^:So
000000;ohkNX00Co0000on:h[?oR^:co00000_oQ]j`4o`0000?ogKJa00Go0000ombe/?l0003ofkNc
o`000003om^f/P03o`000?oJ];;o000000Co00000ooG];L00ol0003oek>eomNc]@02o`0000;oeK>g
00?o0000omG;d?oEbm000_oEbm02o`000003omW9bOl0003of<S900;of<S900Co0000omS6bOoHa/Wo
f<K90_l000001_oFa<Wo0000omC3bOl0003ofL;3o`0000?of<7300Go0000omK0a?oF`<Coe/34o`00
0003omBma005o`000?oG_;oo0000omNl_ol000000ooF^kl02Ol0003oe;VoomBi_ooD^Koo0000om6g
`?l0003oeKNko`000004om>e^`04o`000?oB];cod[Blom:d_0?o000000?od[6io`000?o@/;T00oo@
/;T01Ol0003oc:bjolb/^_o<[;[o000000;ocZbg1ol000001?o8YkSo0000olbW]?l00005olZX]P03
o`000?o6XkKoaZ>f00Co00000_o7X[<01ol0003o`indol>O]?o3WkCo0000olFP/ol000001Oo4X;@2
o`0000;o`Ifc2ol00002okfI/P04o`000?nkUk7o^iNao`0000;o^iJb00?o0000okRC/OnhTk400onh
Tk42o`0000Ko]i>b00?o0000okBA/_ndTK801OndTK82o`0000Oo/Hjb00?o0000ojn=/_n_SK801On_
SK82o`0000;oZhVa1_l000000onXR;;o0000ojV:]002ojV:]003o`000?nUQ[CoYHJd00GoYHJd0ol0
0004oj>6]@04o`000?nPPkGoX8>eoj23]@Go00000onLPKD5o`0000?oVX6g00Co0000oiMo^?l0003o
00001?nGP;P00ol0003oTgjioi=n^@04oi=n^@?o00000onAO[X00ol0003oSgfkohmm^`03ohmm^`?o
00001?n;O;d00ol0003oRWfoohYm_`03ohYm_`;o00001_n8O/83o`0000?oQWo400Ko0000oh9oaon2
OlOoPWo7o`000?n3O/D6o`000004ogmnb?n1Pl_oPH?;o`0000CoOX7<1On1Q/l6o`000005og^5dOl0
003oP8_Eoh2;eOl000000omkRMH00ol0003oPY7Ioh:Af@03oh:Af@03o`000?n4UmkoQ9ON00GoQ9ON
00Co0000ohBLh_n4W>;o00000_n5W>85o`0000?oSJKV00Go0000ohn]jon?[N_oSjg[o`000003ohn^
j`03o`000?nD`?GoU<3e00?o00000_nHa_L00ol0003oX]Cjo`000002o`0000GoY]cj0ol00002okKj
j@;o000000?od?oEo`000?l00000E_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z
00?ooo]Z0005oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000onfeU_l000000_o[]id2o`000006
onVfW_l0003oikRTonNhY?l0003oi[NT1?l00003on>gZ0;o000000Goh[R/o`000?oQ]jcohKN/o`00
0002on2f[005o`000?oM][7ogKJaomff/Ol000000_oL]K03o`000005om^f/_l0003of[BbomZd/_l0
00000_oJ];82o`0000;oekBg00Ko0000omNc]OoG/kGoek>eo`000?oF/[D2o`0000CoeL_@00?o0000
omC:cooDb/l00_l00002omS8b@05o`000?oHa/Wof<K9omS6bOl000000_oGaLT2o`0000;oe<?900?o
0000omS1`ooH`L<00_oH`L<2o`000003omK0a?l0003oe;g400;oe;g400Co0000om>la?l0003oekbo
0ol000000ooF^koo0000omBi_`02omBi_`03o`000?oA]l3odKO000Co00000_oC]K/02?l0003od[Bl
om:d_?oB];co0000olja_Ol0003odK:j0ol00002om2`^@04o`000?o<[;[oc:bjolb/^P;o000000?o
cZbgo`000?l000000_l000000oo=[;So0000o`000003o`000003olbW]?l0003obZRf00?obZRf00Go
0000olJS]_o6XkKoaZ>fo`000003olNT]@Go000000Co`indo`000?o5X;?o00001?o4X;@01?l0003o
_ibdoknL]?l00002ol6M/`03o`000?o0WKCo`9fd00;o`9fd0_l00003okfI/`co00000_nhTk400ol0
003o]i>bokNC/P05okNC/P03o`000?ndTK;o]96b00Co]96b00?o0000ok>@/Ol000001_naS[82o`00
00?o[hfb2?l00003oj^;/`04o`000?nXR;;oZ8Rbo`0000CoZHZd00?o0000ojF6]?nUQ[@01?nUQ[@2
o`0000CoXhJe1_l00003oj24]@03o`000?nLPKGo000000;o00000_nMPkL01?l0003oVX6goiZ1]onJ
PKL4o`0000KoUh2h00?o0000oi=n^OnCO[T00onCO[T2o`0000KoTGjj00?o0000ohmm^on?OK/00_l0
00000on?Okgo0000oh]l_@05oh]l_@?oRWfo0_l000000on:Ol;o0000ohQn`P04ohQn`P;o00001On6
Ol@00ol0003oPWo7oh9oa`02o`0000;oPWo71On4PlX7o`000003ogj1c?l0003oPHK?00;oPHK?00?o
0000ogf4d?l000001?n2R]<;o`0000;oPY7I00?o0000ogb@fol000001on4Umh2o`0000CoQIcR00?o
0000ohfVi_n=Y^H01On=Y^H00ol0003oSjg[o`000002ohn^j`Go00001_nHa_L00ol0003oY]cjojKL
nP02ojKLnP;o000000CoZ^?jo`000?l0003o]o3e0_l000000oo3n^[o0000om3oe@02o`0005Sooo]Z
00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP03oookJP001OoonfX00ol0003ooo]Zoook
JP0:oookJP03o`000?o]]IKokKFF00?o00000_oZ]Yd01?l0003ojKFNo`000?l00002onJgY004o`00
0?oU]ZCoiKJTo`0000;ohkNX00?o0000on>fZ?oS]ZP01?l00003on2f[0;o000000?ogKJao`000?oL
]K000_oL]K000ol0003og;B`ombd/002o`0000;of[Bb00?o0000omZd/_oJ];800ol000001OoG];Oo
0000omNc]OoG/kGo000000;oe[:e0_l00003omG;d005o`000?oDb/ooe<[?o`000?oDb<l00_l00000
1OoHb<Wo0000omS6bOoHa/Wo000000?oelG900Go0000omK4bOl0003oe<?9o`000003omS1``03o`00
0?oG_l?oeko300?o000000?oe;g4o`000?oC_<@00_oC_<@01?l0003oe[ZoomJj_ooF^[l3o`000003
omBi_ol0003odKO000?odKO000?o0000om>e_?oC]K`01?l000000ooB];co0000olja_@02olja_@04
o`000?o@/;Wod;2iom2`^@Co000000?oc:bjo`000?l000000_l000000oo>[;Oo0000olf/^003olf/
^003o`000?o;Z[SobjZh00;o00001?o:Z;H00ol0003oaZ>folJS]P02olJS]P03o`000?o7Y;GoajBe
00;oajBe00Co0000olJS]Oo6XkGoaZ>e1Ol00002olBP]007o`000?noW;Co_ibdoknL]?l0003o`Ifc
o`000004ol2M]004o`000?nlVK?o_9Vco`0000?o_IVc00Oo0000okfJ]?nmV[Co_IZdo`000?nkUk;o
000000Co^YNc7ol00002ojj=/`03o`000?n^SK?o000000OoZh^c0_l00006ojV:]003o`000?nUQ[Co
YHJd00;oYHJd00Co0000ojJ7]?l0003oXhJe0ol00002oj:6]@03o`000?nPQ;GoX8Be00?oX8Be0ol0
0004oif3]`Go00000onJP[P00ol0003oUh2hoiN0^004oiN0^003o`000?nCO[WoTgji00go000000?o
Sgfko`000?l000002Ol000001?n:OKoo0000o`000?l00002ohYo`P07o`000?n8O/;oR7k2ohQn`_l0
003oR834o`000006ohIoa0;o00001?n2OlL00ol0003oQ8?:ohB3bP03ohB3bP03oh>6c_n4Q/koQ8K>
00?oQ8K>0_l00002oh66c`05o`000?mmQ=3oOHC@ogf4d?l000001On2R]<00ol0003oPhoGoh>?e`04
oh>?e`03o`000?n1T]_o000000co000000?oQIcRo`000?l000002_l000000on=Y^Ko0000o`000002
o`0000?oT;Wb00?o0000oiS6monHa_L00ol00004oic<n0;o00000onZhoX01?l0003o]o3eokO`mOl0
0003ol;/l@?o0000FOoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z00?ooo]Z0005
oookJP03o`000?oonf[ooo]Z00[ooo]Z00Go0000onfeU_o]]IKo0000onbdUP02o`000004onZfWOl0
003ojKFNonVeWP?o00000ooU]Z@2o`000005on>gZ?l0003ohkJXon>fZ?l000000_oR]:P01?l0003o
h;J/on2f[?l00002omndZ`?o000000?og;F`o`000?oL];000_oL];001?l0003ofk>_o`000?l00002
omZd/P04o`000?oI/[7o0000omRb/P?o000000Woek>eo`000?oF/[Goe[:eo`000?oFbloo0000omG;
d?l000000_oDb/l01?l0003oe<S?omC8cooDb<l3o`000003omS6bOl0003oelG900;oelG900Wo0000
omK4bOoFa<Woe/C9o`000?oC`/Wo0000omS1`ol000000ooG_l<01Ol0003oe[o3omJo`ooD_LCo0000
00?odkc400Go0000omJj_ooF^[ooe[Zoo`000002omBi_`;o00000ooA]l02o`0000?odkFl00?o0000
om:e_?oB]K`00_l00003olja_@06o`000?o@/;Wod;2iom2`^Ol0003ock2j1Ol00002ol^/^P03o`00
0?o=[;SocJbh00;ocJbh00?o0000ol^Z^?o;Z[P00_o;Z[P7o`0000;oaZ>f00?o0000olJS]_l00000
0_o7Y;D00ol0003oaZ>eolJS]@03olJS]@;o00000_o4X;D5o`0000;o_ibd00?o0000ol2M]?o0WK@0
0_o0WK@01Ol0003o_9VcokbI/onlVK?o000000;o_IVc00?o0000okfJ]?nmV[@00onmV[@00ol0003o
^YNcokZG/`04okZG/`;o00001?ngU;<01Ol0003o]96bokBA/_ndTK;o000000?o]96c00Go0000ok>B
]?ncT[Co/i:do`000003ok6?/P05o`000?nbT;Co/Y2dok:@]?l000001?n^SK<01?l0003o[Xfcojj=
/ol00006oj^;/`;o00001onYR[@00ol0003oYHJdo`000006o`0000GoXXJe00Co0000oj24]OnPQ;Go
X8Be0_l000001?nPQ[Oo0000oif3]onMPkL3o`0000;oWHBg00?o0000oiZ2^?nJP[P01?nJP[P00ol0
003oUh2hoiN0^003oiN0^0Co00000onEPK/00ol0003oTX2loi:0_003oi:0_0;o00001_n@P;h00ol0
003oS7noohao_`02ohao_`03oheo`?n<P<;oS83200?oS8323?l00003ohIoa003o`000?n2OlOoPWo7
00CoPWo71?n4PlX2oh>6cP03o`000?n4Q/koQ8K>00CoQ8K>2Ol00002oh::d`03o`000?n0SMOo0000
00KoPhoG00?o0000oh6Cfon1Tm/00on1Tm/00ol0003oR9_OohRKg`03ohRKg`;o00001_n5YNT00ol0
003oTJ_Woi6[i`04oi6[i`;o00001on@^O82o`0000?oW<ch0_l00003oj3CnP04o`000?nZho[o0000
ok;Qm`?o00000oo2k?401?l0003obOoCo`000?l0001JoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX00ooonfX000Gooo]Z00?o0000oookJ_oonfX02_oonfX3o`0000;ok;BF00?o0000
onbcU_l000000_l000000ooY]Iko0000onRdWP02o`0000;oiKJT00?o0000onFdY?l000000ol00003
on:dZ0;o000000Goh;J/o`000?oO]:_ogkB[o`000002omjc[0;o00000_oL];001?l0003ofk>_om^c
[ooK/jl2o`000005omZd/_l0003ofK:aomVb/Ol000000ooH/K84o`0000?oe/_?0_l000000ooDb/oo
0000omC8c`02omC8c`05o`000?oCaloo0000omS6bOl000000ooGaLT02Ol0003oe/C9omK4bOoFa<Wo
0000omG3bOl0003odl;9o`000003omNo``0=o`000?oF_l?oe[o3omJo`ol0003oeKk4o`000?oC_<Co
0000om6ka?l0003oe[Zoo`000003omBi_`05o`000?oD^L3o0000om6g`?l000000_o@]/000ol0003o
dkFlo`000003om:e_008o`000?oA];go0000olja_Ol0003ocK2mo`000?o@/;T3o`0000;ock2j00?o
0000olj^^_o>[[X00ol00003olf/^003o`000?o;Z[SobjZh00;objZh0_l00003olZX]`03o`000?o9
YkSobJNh00Go000000?oajBeo`000?o6XkD01?o6XkD00ol0003o`Ynfo`000002olBP]@03o`000?o3
X;Ko`j2f00;o`j2f2_l000001?nlVK?o0000okfI/ol00005okfJ]0;o00001OnjUk<01?l0003o^9Fb
okRE/_l00002okND/`03o`000?ndTK;o]96b00;o]96b00Co0000okBA/ondTK?o00001?ncT[@01?l0
003o/Hnbok6?/_l00004ok:@]005o`000?n^SK?o[Xfcojj=/ol000001?n^SK<00ol0003oZh^coj^;
/`02oj^;/`03o`000?n[Rk?o000000CoZHZd1_l00004ojJ9]P03o`000?nRQ[GoXXJe00GoXXJe0ol0
0002oj26]`Co00001OnMQ;L00ol0003oVX:hoiZ2^003oiZ2^0Oo000000?oV8:jo`000?nEPK/01OnE
PK/00ol0003oTX2loi:0_002o`000003oi:0_On@P;koT82n00KoT82n00?o0000ohao_on=Ol000on=
Ol06ohb0`P;o00001On:PL@01?l0003oQX76ohJ1a_n6PLH7o`0000;oPWo70on4PlX4oh>6cP03o`00
0?n4Q/koQ8K>00;oQ8K>0_l00006ohB:d@03o`000?n1S=Go000000_o00001_n1Tm/01Ol0003oR9_O
ohRKgon8Vmoo000000;oPY[Q00?o0000ohFUjOn5YNT01?n5YNT00ol0003oTJ_Woi6[i`09o`0000Go
U;od0_l00007oj3CnP04o`000?nbhOOo0000o`0000;o`^ca00Co0000ok3ijOl0003obOoC0_l0001L
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX00ooonfX000Gooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003okk6=onnaS@03o`0000?ok;>F0ol00002onRdWP04o`000?oW/ioo0000
o`0000;oiKBT00Co0000onBcY?oT/jCo00000_oR]:P00ol0003ohK>Xon6cZ003o`000009omndZooN
/j_o0000omjc[?l0003ogK:/o`000?oL];3o000000?ofk>_00?o0000om^b[ol000000_l000000ooI
/[7o0000omRa/P02omRa/P03o`000?oG/K?o000000?oe/_?00Co0000omK:c_oFb/ko00000ooDb<l0
2Ol0003odlO?om?7cooCaloo0000omO5b?l0003oelG9o`000003omK4b@04o`000?oE`lWoeL?9omG3
b@?o000000?oeko3o`000?oF_l<00_oF_l<01?l0003oeKk4omFna?oE_/@3o`000003om6ka?l0003o
e;Vo00;oe;Vo00Go0000omBi`?oD^L3oe;W0om6g`002o`000003om2f`?l0003o000000?od[Fl00Co
0000om6d_OoA];godKBm1Ol00004oln`^P03o`000?o>[[[ocZjj00;ocZjj1ol00002ol^Z^006o`00
0?o7YkWoajNio`000?o:Z;Oo00001?o9YkP00ol0003oa:>golBS]`05o`0000;oaZ>e00Co0000ol:O
]_o2WkKo`Ynf0_l00005ol>P]P03o`000?nnW;Go000000?o`9fd00Co0000oknM]_noWKKo_iff1_l0
0002okfJ]004o`000?nkUk?o^iNco`0000?o^YNc00Oo0000okRE/_nhUK;o^9Fbo`000?ngU;?o0000
00Ko]96b0_l00006ok>B]0;o00001_nbT;@00ol0003o[Xfco`000002ojj=/`oo00000_nXRK@2o`00
00KoYXVf00?o0000oj:6]OnRQ[D00onRQ[D3o`000004oj26]ol0003o0000o`0000;oX8Jg00?o0000
oif4]onMQ;L01OnMQ;L00ol0003oVX:ho`000005o`0000GoV8:j00?o0000oiF1^onEPK/00onEPK/3
o`0000GoTX2m1_n@P;h2o`0000GoSGo01?n<P<82o`000003ohb2a?l0003oRX7400GoRX740ol00003
ohJ1a`CoQhC90ol000000on4Pl[o0000o`000005o`0000;oQ8K>00Co0000oh:9dOn2RM7o00001_n4
R]400ol0003oPHcEoh6<e@03oh6<e@CoQY;H00?o0000oh:AfOn2TMT05ol00002oi2]jP05o`000?n@
[^[oT:kZoi2^j_l000000_nD_o@3o`0000?oV<Gf00?o0000oj3Cn_nPdoX00ol00003ojCKn`;o0000
00Ko`^cao`000?l0003o/?WYo`000?o9om<2o`0005kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0
003ooo]ZoookJP03oookJP001OoonfX00ol0003ooo]ZoookJP09oookJP;o000000?okk6=o`000?o^
/8d00_l00002onbcUP03o`000?o[/YKo000000;oj;BN00?o0000onNcWooW/il00ol00003onBcY0;o
000000Goh[BXo`000?oQ/jSohK>Xo`000002on6cY`;o000000?og[>[o`000?oM/Z`00_oM/Z`3o`00
0005om^c[ol0003ofk:_om^b[ol000000_oJ/Jl3o`000008omRa/_l0003oek6co`000?o@c=Go0000
omK;col00002omK:cP05o`000?oEbLko0000omC8col000001?oCall2o`000006omO5b?l0003o0000
o`000?oFa<Wo00000ooE`lT01?l0003oe<;9omC2bOoD`/T2o`0000;oe[o300Go0000omFna?oE_/Co
eKk4o`000003omBma0?o000000?oe;Voo`000?oD^L000ooD^L000ol0003od[S0om:h`004o`000004
om:e_?l0003odKBmom6d_@?o00000_o?/kd4o`000003oln`^_l0003ocZjj00?ocZjj00Ko0000olV[
^oo9Zk_o0000olf/^Ol00002ol^Z^0Co00000_o7YkT00ol0003obJNholVW^002olVW^003o`000?o4
XkOoa:>g00;oa:>g00Co0000olJS]Oo6XkGoaZ>e1Ol000000oo2WkKo0000ol>P]P04ol>P]P04o`00
0?nnW;Go_Ybeo`0000;o`9fd00?o0000oknM]_noWKH00onoWKH2o`0000?o_9Ze:ol00003ojj>]@03
o`000?n[RkCo000000GoZhbf00?o0000ojR9]?nXRK@00_nXRK@00ol0003oZHbfo`000007ojJ9]P03
o`000?nRQ[Go000000Ko00001OnPQ[L00ol0003oWHBgoif4]`03oif4]`Oo000000?oVhBjo`000?nH
P[X01_nHP[X00ol0003oUH6koiF1^`02o`000003oiF2^ol0003oTX2m00GoTX2m00Co0000oi20__n@
P;koT82n0_l000000onAP[oo0000oheo`004oheo`0?oS83200?o0000ohb2a?n<P/@00_n<P/@00ol0
003oRX74ohZ1a003ohZ1a003o`000?n6PLOoQX7700?oQX7700?o0000ohN4bOn7Q<T00_n7Q<T00ol0
003oQhO<o`000005ohJ7c003o`000?n3R=3o000000So00000_n4R]42o`0000KoPHcE0_n6T]P01Ol0
003oPY7Ioh:AfOn2TMWo000000KoR9SM00?o0000ohNMhOl000001?n7WN800ol0003oSjKUohnVi@05
ohnVi@03o`000?n@[N[o000000;oT:kZ1Ol00007oiS5mP;o00000_nTfo/3o`000005ojSSnol0003o
0000o`000?n`nNT00_l000000oo9om?o0000ojGUT@1PoookJP03o`000?oonf[ooo]Z017ooo]Z00?o
0000oookJ_oonfX00ooonfX000Gooo]Z00?o0000oookJ_oonfX02OoonfX01ol0003ol:b2o`000?l0
003ok[2=o`000?o][hd00_l00002on^bUP?o00000ooW/il01?l0003oi[:No`000?l00002onBcY003
o`000?oS/Z?o000000?o00000ooQ/jL01?l0003oh;:Wo`000?l00003omfb[003o`000?oL/Zgog;:]
00;o00000_oK/Zl01Ol0003of[6_omZa[ol0003ofK2^00Go000000Kod<cEo`000?l0003o0000omK:
c_l00003omG9cP;o00000ooCall01?l0003od/K>om;6c_l00003omK4b005o`000?oE`lWoeL?9omG3
bOl000000ooD`/T01_l0003odL39o`000?l0003oe[o3o`0000;oeKk400Go0000omBma?oD_LCoe;g4
o`000002om:la0;o00001?oD^L001Ol0003od[S0om:h`?oB^<3o000000;oc[G11Ol000000ooA];go
0000olnc_@02olnc_@04o`000?o</;ko0000oln`^`?o00000_o>[[X01?l0003obJ^kolV[^oo9Zk/2
o`0000?objZh00Co0000ol^[^_o;Zk[obj^j0ol00003olVW^003o`000?o4XkOoa:>g00?oa:>g00?o
0000olJS]Oo6XkD00_o6XkD01?l0003oaJBholFT^?o5Y;P5o`000003ol>P]_l0003o_Ybe00?o_Ybe
0_l00005oknM]P03o`000?nmV[Co000000Co_9Ze00Oo0000okVG]?niUkCo^INdo`000?njUkCo0000
00Ko^IRe00?o0000okJE]OnfUKD01?nfUKD2o`0000Ko/i:d0_l00006ok2@]@;o00001on^S[D2o`00
00KoZhbf00?o0000ojR9]?nXRK@00_l00003ojV<]P04o`000?nVRKKoYXVfojJ9]PGo00001OnSR;P0
0ol0003oX8Jgoj26]`05oj26]`03o`000?nMQ;Oo000000Ko00001OnKQ;X00ol0003oV8:joiR2^P04
oiR2^P03o`000?nEPK_o000000CoUH:k00Co0000oi:0_OnBP;goTX2m1?l000000on@P;ko0000o`00
0009o`000003ohb0`_l0003o000000Oo00000_n:PL@2o`0000KoQX770on7Q<T3ohN7c003o`000?n6
QlcoQXO<00CoQXO<00?o0000ohJ9d?n6RM000on6RM001?l0003oPh_Coh>;don3Rm<?o`0000;oPY7I
00?o0000ohRHgOn8V=d01?n8V=d00ol0003oQigRohNMhP04ohNMhP03o`000?n?Y^GoSjKU00;oSjKU
0_l000000on?Y^Go0000o`000002o`0000?oTKWb00?o0000oiS5m_nHaOH01?l00002oic<n004o`00
0?nTfo_o0000o`0000?oZ>?k0_l000000ondl?Go0000o`000004o`00067ooo]Z00?o0000oookJ_oo
nfX04OoonfX00ol0003ooo]ZoookJP03oookJP001?oonfX00ol0003ooo]ZoookJP0:oookJP06o`00
0?o`[8;ol:b2o`000?o^/8go00000_o][hd3o`0000;oj[6F1?l00002onJbWP04o`000?oU/Iko0000
o`0000;ohk:S00?o0000on:aXooR/J<00_l00002on6cY`03o`000?oP/ZOoh;:W00;o000000?ogK:/
o`000?oL/Zd00_oL/Zd01?l0003ofk2/o`000?l00002omZa[`05o`000?oI/:kofK2^omV`[_l00000
0ooAc=@01Ol0003od<_Eom3;eOo@bmGo000000?oeLW>00Ko0000omC7c_oDalko0000om?7col00002
om;6cP09o`000?oAaLko0000omK4b?l0003oeL?8o`000?oE`lWo000000?oe<;900Co0000om70bOoA
`<WodL390ol000000ooE_/Co0000omBma002omBma003o`000?oB_<Cod[c400;od[c40ol000000ooD
^L3o0000om:h`002om:h`003o`000?o>]L7o000000?o000000CodKBmo`000?oA];go00000oo?/kd0
1Ol0003oc;2nolb`__o</;ko000000?ocZnj1?l000001?o9Zk_o0000olR[_?l00002ol^Z^003o`00
0?o;Zk[obj^j00?obj^j00?o0000olJW^_l000001?l00003olBS]`;o`j>h00Co0000olJS]Oo6XkGo
00001?o5Y;P00ol0003o`J2go`000002ol>Q]PCo00000_nnW;D00ol0003o_iffoknM]P03oknM]P05
o`000?nmV[Co_IZdokfJ]?l000000_nlV[D00ol0003o^INdokVG]003okVG]003o`000?niV;Go^IRe
00Go^IRe00?o0000okJE]OnfUKD00onfUKD01?l0003o]I>dokFC]?l00004ok>B]004o`000?ncTKCo
/i6do`0000Co/92e00Co0000ok2@]?n`T;Co00001On^S[D00ol0003o[Xjeo`000007oj^<]P;o0000
0_nYS;H7o`000004ojF9]_l0003oYX^ho`0000OoXhRh00?o0000oj26]onPQ[L00_nPQ[L7o`0000;o
WXJj00?o0000oi^4^_nKQ;X01?nKQ;X00ol0003oV8:joiR2^P03oiR2^P;o00000onEP[/7o`0000;o
Th>o0_l00005oi:3`003o`000?n>P/;oSX;200CoSX;21on=Q<@00ol0003oRH?6ohV3aP0;o`000004
ohN4bOl0003o0000o`0000;oQhO<00?o0000ohJ7c?n6Ql`00_n6Ql`2o`0000KoQXW@00?o0000oh>;
dol000000on3S=<00ol0003oQi7GohNAe`04ohNAe`;o00000on5UM/Eo`0000?oTj_W00?o0000oi6i
l_nA^O801OnA^O82o`0000OoW<ch00?o0000ojSSnonXho/00_l000001?nahOOo0000o`000?l00002
ol3]lP03o`000?nioMgoYNFA06?ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP02
oookJP001?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?o`[8;ol:b200?o00000_o][hd01_l0
003ok:j>o`000?l0003oj[6Fo`0000;oj;2G00Co0000onJbW_oV/Yko00000_oU/Ih3o`0000?oh[6S
00Co0000on:`Xol0003o00000ooP/ZL01?l0003ogk6Wo`000?l00002ombb[@04o`000?oK/:cofk2/
om^`[0;o000000Gof[6_o`000?oI/:kofK2^o`000003om7<e009o`000?oAbmCo0000om3;eOl0003o
clWDo`000?oEbLko000000Coe<O>0_l000000ooBa/ko0000om75cP02om75cP04o`000?oE`lSoeL?8
omG3b0?o000000?oe<;9o`000?oA`<T00ooA`<T2o`000006omFna?l0003o0000o`000?oD_LCo0000
1?oB_<@01?l0003ockW5o`000?oC^/47o`0000?oc[G100?ocKC1o`000?oA];d00ol000000oo?/kgo
0000olb`_P03olb`_P03o`000?o>[k[ocZnj00;ocZnj00?o0000olf__?o=[k`00ol000000oo8Zkco
0000o`000005ol^[^P06o`000?o6Yk[oaZNjo`000?o9Z;So00000_o8YkT6o`000003olJS]Ol0003o
aJBh00?oaJBh00Co0000ol6P]oo1X;Oo00000_o3XKH01?l0003o`Z6gol:Q]oo2XKL;o`000004okfJ
]?l0003o_9Zeo`0000Go^INd0_l00006okVH]@03okRF]?l0003o]YFe00?o]YFe00Go0000okFC]?ne
TkCo]I>do`000003ok>B]005o`000?ncTKCo/i6dok>A]?l000000on`T;D01Ol0003o/92dok2@]?n`
T;Co000000Co[Xje00Co0000ojj>]On^S[Go00000on[S;H8o`0000?oZ8^g00?o0000ojF9]_nURKH0
0_l00003ojJ;^003o`000?nSR;SoXhRh00CoXhRh00?o0000oj26]ol000001_l00005oij6^P03o`00
0?nKQ;[oVhBj00CoVhBj00?o0000oiR2^_nHP[X02?l00003oiJ4_P04o`000?nCPkooTh>ooi>3_`;o
000000?oTh>ooi:3`?nBPl001OnBPl000ol0003oSX;2ohj2`P04ohj2`POoSHC40_l00004ohb4aP03
o`000?n8Q<SoR8C800?oR8C800?o0000ohV8bon9R</00_n9R</=o`0000?oQXW@00?o0000oh><don3
S=<00on3S=<00ol0003oQi7GohNAe`02ohNAe`03o`000?n6UM_o000000GoQIGK00?o0000oh^Lg_n;
W=h00_n;W=h01?l0003oQi[OohNJgol00006ohRVj003o`000?nCZnOoTj_W00?oTj_W1_l00004oiFo
m003o`000?nLc?SoW<ch00?o00001?nOe?X00ol0003o/N7gok7Qm`02o`000006ol3]l_l0003oZOSW
o`000?nioMgoYNFAIOoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z00;ooo]Z0004
oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol00002onn[PP?o00000_o/[Xh00ol0003ojjf>o`000002
o`000004onR`Uol0003o0000o`0000?oiK6N00Co0000onB`W_l0003o00000_oR/J<00ol0003oh[2S
on:`X`02o`000004on2bYol0003ogk6WomnaY`?o000000?og;:]o`000?oK/:`00_oK/:`00ol0003o
fjn[o`000003o`0000?odLcD00Co0000om7;e?oAbmCodL_D0_l00002olo9e005o`000?oDalkoe<O>
omC7c_l000000ooCa/d2o`0000?odLG>0_l000000ooE`lSo0000omC2b002omC2b0;o00000ooA`<T0
1?l0003od;o9om2obOl00003omBma0;o00000ooB_<@01?l0003ockW5olniaOo?^LD6o`0000Coc[G1
0oo=]<401?l0003ock>molnc_Oo?/kd3o`0000;oc;2n00?o0000olZ___l000000_o>[kX01Ol0003o
cJnlolf__?o=[kco000000;objfl0ol00004ol^[^P03o`000?o6Yk[oaZNj00;oaZNj00?o0000olRW
^Oo8YkT00_o8YkT01?l0003oajJiolNV^Oo7Y[T4o`0000;oaJBh00?o0000ol6P]oo1X;L00_o1X;L2
o`0000Go`Z6g00?o0000okjM]ol000000_noWKH00ol0003o_YjgokjN]`02okjN]`ko00000_niV;D3
okRF]004o`000?nfUKGo]YFeo`0000Co]I>d00Co0000ok>B]?ncT[Co00001?ncTK@01?l0003o/92e
ok2@]Ol00002ok2@]0ko000000GoZhffo`000?n/SkOo[8ngo`000007ojR;]`;o00001OnVRkP00ol0
003oXhRhoj>8^002oj>8^0Co00001OnQR;X00ol0003oWXJjoij6^P05oij6^P04o`000?nKQ;[oVhBj
oi^4^PKo00000onIQKd00ol0003oUXBnoiJ4_P04oiJ4_P?o00001?nCPkl00ol0003oTX?0oi:3`003
oi:3`0;o00001_n>P/800ol0003oSHC4ohf4a003ohf4a0;o00001On<Q<H01?l0003oR8C8ohR4b?n8
Q<P2o`000003ohR5bOl0003oRHS;00CoRHS;00?o0000ohJ8c_l000001?n6RLl4ohR=dA3o000000?o
QYGKo`000?n5UM/01?n5UM/01Ol0003oRicNoh^Lg_l0003oQi[O00Wo000000?oR:KXo`000?l00000
1?l00002oi:^jP03o`000?nE_oCoUKod00GoUKod0_l00003oioDnP;o00000onSg?/2o`000005ol3]
l_l0003o0000ojWhionjn^T00_l0001WoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oo
nfX00_oonfX000Cooo]Z00?o0000oookJ_oonfX02_oonfX01ol0003ol:Edo`000?l0003okj^2o`00
0?o^ZX<00_l000001oo/[Xko0000on^]S_o[[Hko0000onR`U_l000000_oW[iP4o`0000;oi;2N00Co
0000on>_W_l0003o00000ooR/:<01?l0003ohJnSo`000?l00002omnaY`;o000000KogJnXo`000?l0
003o0000om^`[?l00002om^_Z`?o00000ooAc=@01?l0003odL_Dom7;e?oAbm@3om39d`06o`000?o?
bMCo0000o`000?oDalko00001?oCa/d01Ol0003od/G=o`000?oAaLko000000;od<C>0_l00003omC2
b005o`000?oC`LSo0000om70bOl000000oo@_lT02_l0003oe;g4omBma?oD_LCo0000om:la?l0003o
d[c4o`000?o?^LD4o`0000?od[S000?o0000om6g`?l000000_o>]L43olfd`@;o00000oo?/kd00ol0
003ock>oolnc_`05o`000003olj_^_l0003ocJnl00;ocJnl00?o0000ol^]_?o;[K`00_o;[K`3o`00
00;obj^j00?o0000olJW^_o6YkX00_o6YkX2o`0000?ob:Ni00?o0000olNV^Oo7Y[T00oo7Y[T00ol0
003oaJBholFT^005o`0000;o`J2g00?o0000ol:Q]oo2XKL00oo2XKL01?l0003o_YfgokjM]onnWKL2
o`0000Ko_Yjg00?o0000okbK]_nlVkH01?nlVkH01Ol0003o^IRfokVH]_l0003o^IRf01co00000on`
TKL2o`0000Go[I2g00?o0000oj^=]_n[SKH00_l00003ojb?]`03o`000?nXRkOoZ8^g00CoZ8^g0_l0
0005ojJ;^0So000000?oY8Zjo`000?nQR;X01OnQR;X00ol0003oWXJjoij6^P03oij6^PKo00000_nK
Qk`00ol0003oVHFmoiV5_@04oiV5_@03o`000?nFQ;koUXBn00?o000000?oUXBno`000?nCPkl01OnC
Pkl3oi:3`0;o000000?oTXG2o`000?n>P/801On>P/801?l0003oSHC4ohf4a?n=Q<@2o`000003ohj5
a_l0003oS8C600GoS8C600?o0000ohR4b?l000001?n8QLT00ol0003oRHS;ohV8b`02ohV8b`;o0000
1_n6RLl3ohR=d@04o`000?n5Rm;oQH_Bo`0000KoRI7E00?o0000ohJCfOl000000on6U=T<o`0000?o
RioQ00?o0000oi6XiOnAZ>D01?nAZ>D00ol0003oTZkZo`000003oi:^jPOo00001OnIa_L2o`0000;o
Xmck0ol000001onWi?_o0000o`000?l0003oZOSWo`000?njn^T00_l0001YoookJP03o`000?oonf[o
oo]Z00kooo]Z00?o0000oookJ_oonfX00_oonfX000Cooo]Z00?o0000oookJ_oonfX02_oonfX01?l0
003ol:Edo`000?o_Y7D2o`000003onjZPol0003okJV300;o00000_o[[Hh3o`0000;oijnH00Co0000
onJ^UooV[YOo00000_oT/9h00ol0003ohjnNon>_WP02o`000006on:`Xol0003ohJnSon6_Xol0003o
h:jS0_l00002omj_Y`;o00000_oL[jP5o`0000;oc<cJ00?o0000om7<e?l000000_oAbm@00ol0003o
d<WCom39d`03om39d`;o000000?oclSDo`000?l000000ooCa/d01?l0003od/G=om;5cOoBaLd2o`00
0007om34c_l0003ocl?>olo3c_l0003oe<;8o`000003om?1b0?o000000Kod;o9o`000?o?_LWo0000
omBma?l00003om:la0?o000000OockW5o`000?o>^<Goc[S5o`000?oB^<3o000000?odKO00ol00000
1oo=]<7o0000olbc`_o</l;o0000olnc_Ol000000oo?/kl01?l0003ocK:oolfb_oo=/[l2o`0000?o
cJnl00?o0000ol^]_?o;[K`00_o;[K`2o`0000;obZbk1?l00002olJW^P06o`000?o6Yk[oaZNjo`00
0?o8YkWo00001Oo7Y[T00ol0003o`Z>jo`000002olFT^004o`000?o4Y;Woa:BiolBT^@Ko000000?o
`Z6go`000?nnWKL00onnWKL00ol0003o_YjgokjN]`05okjN]`03okbK]_l0003o_9^f00?o_9^f00Co
0000okVH]_niV;Ko^IRf0_l00006okRH]`;o00001onfU[L7ok>C]`03ok:C]_l0003o/96g00Go/96g
0_l00007ojf@]`;o00001_n/SkL01?l0003oZ8^gojR;]onXRkL2o`000004ojR<]ol0003oYX^hojJ;
^0?o00000_nVRkP3o`0000CoY8Zj00?o0000oj68^_nQR;X01?nQR;X00ol0003oWXJjoij6^P06o`00
00GoVhNl00?o0000oiV5_OnIQKd00onIQKd4o`0000GoUXBn00?o0000oi>3_onCPkl01?l000000onB
Pl3o0000o`00000;o`000003ohf4a?l0003o000001;o00000_n9R</00ol0003oRH[>o`000006ohJ9
c`;oR8gA00?o0000ohF;d_n5Rm800_n5Rm800ol0003oRI7EohVAe@03ohVAe@;o00001On6U=T00ol0
003oS9[LohbJg004ohbJg0;o00001_n;Wn401?l0003oTJSUoi6XiOnAZ>D2o`000003oi6XiOl0003o
000000?o00001?nC^_800ol0003oVLKgoiW6m`03o`0000;oW<gi00Co0000oj?Lnol0003o00000onW
i?/2o`0000;o^^Od00Co0000ok[jjOl0003o0000J_oonfX00ol0003ooo]ZoookJP0>oookJP03o`00
0?oonf[ooo]Z00;ooo]Z0004oookJP03o`000?oonf[ooo]Z00[ooo]Z0ol00002onnTM@?o00000_o]
ZH<3o`0000;ojZb>0ol00003onJ^U`?o00000ooS[ih01?l0003ohjjNo`000?l00002on6_X`03o`00
0?oP[Z?oh:jS00;o000000?ogZnWo`000?oL[jP00_oL[jP01?l0003og:jXo`000?l00004olc<fP;o
000000?odL_Do`000?o@bM<00oo@bM<01Ol0003odLWBom79d_oAbM;o000000;oc/OD00?o0000om?6
cOl000000ooBaLd00ol0003od/C=om;4c@02o`0000?ocl?>00Go0000om?1b?oC`LSodl78o`000003
om:ob004o`000?o?_LWockg9olnmb@Go00000ooB_<D2o`0000?oc[S500Go0000om6g`?oA]l3odKO0
o`000003om2g`P?o00000_o</l801Ol0003ock>oolnc_oo?/koo000000CocK:o00Ko0000olV__ol0
003o0000olf__?l00003ol^]_006o`000?o7Zkgoaj^mo`000?o:[;_o00000oo9Zk/00ol0003oaZNj
o`000003o`000003olRW^Ol0003oajJi00?oajJi00Ko0000ol:S^_o2Xk[o0000olFT^?l00004olBT
^@04o`000?noX;Wo_j2io`0000;o`J6h1ol00006okjN]`;o_9^f00Go0000okbK]_nlVkKo_9^fo`00
0004okVH]P03o`000?nhV;Oo^9Rg00Go^9Rg00?o]iNfo`000?nfU[L01OnfU[L00oneU;Ko0000ok>C
]`04ok>C]`;o/Y>f00?o0000ok2A]on`TKL00on`TKL00ol0003o/96fo`000007ojf@]`03o`000?n/
SkOo[8ng00Go[8ng00?o0000ojR;]ol000001ol00004ojJ;^0;o00001onTR[X00ol0003oXHRjoj68
^P02oj68^PGo00000onNR;`00ol0003oVhNloi^7_005oi^7_003o`000?nIQKgo000000;o00000_nI
QKd01?l0003oUXBnoiJ4__nFQ;h6o`0000;oU8K10_l00006oi>6`P03o`000?n?QLCoShG400?oShG4
00?oT8G4o`000?n?QlH01On?QlH01?l0003oRhK8oh^6b?l00002ohb6b003o`000?n<RL_oS8W;00Co
S8W;00?o0000ohV9c_l000006Ol00006ohJDf@03o`000?n<V]coS9[L00?oS9[L3?l00002oiF]i`03
o`000?n@[>Wo000000SoTk[b0_l00006oic=n@03o`000?nWi?_oYnCk00;oYnCk00Co0000ok[Wm?nj
ioCo^^Od0_nUmNh2o`0006cooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP02oook
JP001?oonfX00ol0003ooo]ZoookJP0:oookJP08o`000?o_Vf;o0000o`000?o_Y7Go0000onjSM_l0
0002onfYP`03o`000?o/Z8Co000000;ojZb>1?l00002onJ^U`03o`000?oU[IOo000000?o00000_oS
[Yh01?l0003ohZfMo`000?l00003on2^X`03o`000?oO[Z;ogjjR00;o00000_oL[jP2o`0000Goc<cJ
0_o;bmX00oo:c=_o0000om39d`03om39d`05o`000?oAbM;odLWBom79d_l000000_o?b=<2olk7e005
o`000?oBaLgod/G=om;5cOl000000ooBa<d02Ol0003od/C=o`000?o?`lko0000olk2c_l0003odl78
o`000004om:ob0Ko000000?od[c4o`000?oB_<D00ooB_<D02Ol0003odK_5o`000?o>^<Go0000olfg
aOl0003odKO0o`000004om2g`P03o`000?o?]/;ockK200?o00000_o?/kl00ol0003ocK:oolfb_`02
olfb_`05o`000?o9[koobJnoo`000?o=/;d00ol00002ol^]_005o`000?o7Zkgoaj^molN[_Ol00000
1Oo9Zk/01?l0003oaJNkolFW^oo5Yk/4o`0000;oajJi00?o0000ol:S^_o2XkX00_o2XkX00ol0003o
a:BiolBT^@02olBT^@03o`000?noX;Wo_j2i00;o_j2i0_l00005ol6Q^@03o`000?nmWKSo000000So
00000_nlVkH00ol0003o^IRfokVH]P03okVH]P03o`000?nhV;Oo^9Rg00Co^9Rg0ongUkH00ol0003o
]YJgokJF]`02okJF]`?o]IBf00Co0000ok>C]oncTkOo/i>g1?nbTkH01Ol0003o/96gok2A]on`TKOo
000000?o/96f00?o0000ojf@]on]T;L00on]T;L;o`0000KoZ8fi00Co0000ojJ;^?nVRkSoYX^h0_l0
00000onVSK[o0000ojB:^P06ojB:^P03o`000?nQR;[o000000;o000000?oX8Rjoj6:_?l000001_nN
R;`00ol0003oVhNloi^7_003oi^7_0?o00000_nIQKd7o`0000?oUhK000?o0000oiB6`OnDQ/400_l0
00000onDQ/7oThK2oi>6`P06oi>6`P03o`000?n?QLCoShG400CoT8G400?o0000ohn7a_n?QlH01?n?
QlH2o`0000CoS8K800?o0000ohb9bon<RL/00on<RL/2o`0000GoRH[>1_n;SM000on:TMCo0000oh^A
e005oh^Ae004o`000?n8TmOoR9?Go`0000?oR9?H2_l000001On<V]co0000oh^Mgon;WMoo000000Ko
RjSX00Go0000oiF]ionE[NOoUJgWo`000003oi2/j@03o`000?nC^_;oTk[b00?o00000_nG`O@00ol0
003oW<gioic=n@03o`0000CoX=Kk0ol000001OnjioCoYOG^ojGek_l0003oXoOQ00;o0000K_oonfX0
0ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00;ooo]Z0004oookJP03o`000?oonf[ooo]Z
00_ooo]Z0_l000001?o^VV?o0000o`000?o^XgH3o`0000;ok:R40ol000001?oYZhoo0000o`000?oW
ZHl2o`0000;oiJfG00?o0000onF/UooU[9L00_l000001?oS[Yko0000on:]WOoR[Id4o`0000?ogjjR
00?o0000omj/X_l000000_l00004olc<fP03o`000?o;bm[obl_J00;obl_J00Go0000ol[;f_l0003o
d<WCo`000003om79dP04o`000?o?b=?oclSColo8d`;o000000CocLKDo`000?oBaLgo00000ooBa<d0
0ol0003od/C=om;4c@04o`000003olk2c_l0003od[o800;od[o81ol000000oo>_<Wo0000om:la@03
om:la@04o`000?oA^lGodK_5om6ka@?o000000?ocKO5o`000?o@]l800oo@]l801_l0003ockK2olnf
`_o?]/;o0000ol^c``Co00000oo=/[l00ol0003obJnoolV__`02olV__`04o`000?o;[Kcobjflol^]
_0Co00000_o7Zkd2o`0000?obJ^k00?o0000olFW^oo5Yk/00oo5Yk/00ol0003oajNiolNW^@08o`00
00?oa:Bi00?o0000oknP^OnoX;T00onoX;T00ol0003o`J6iol6Q^@03ol6Q^@04o`000?nmWKSo_Ifh
o`0000;o_Yjh00?o0000okfN^OnmW[T00_nmW[TEo`0000;o]YJg1?neU;H2o`000003ok>C]ol0003o
000001;o000000?o[I6io`000?n[S[P01?n[S[P00ol0003o[92jo`000007ojR=^@?o00001?nVSKX0
1?l0003oY8ZjojB:^_nTR[X5o`000003oj28^_nQR[coXHZl00;oXHZl00?o0000oij8_?nNR;`01?nN
R;`00ol0003oVhNloi^7_008o`0000?oVHRo00?o0000oiN6`?nGQ/000onGQ/03o`0000GoU8K11_nC
Q/82o`0000KoT8G400?o0000ohn7a_n?QlH00_n?QlH3o`0000GoS8K800Co0000ohb9bon<RL_oS8W;
0_l000000on<S<ko0000ohV:cP05ohV:cPCoRhg@0on:TM@00ol0003oRi7Doh^Ae004oh^Ae0;o0000
1?n8TmP00ol0003oS9WKohbIf`05ohbIf`03o`000?n;WMooRigO00CoRigO00?o0000oh^Xj?n;Z>P0
1?n;Z>P:o`0000KoUl7d0_l00003oj3Fn`?o00000_nSg_`00ol0003oYOG^ojGekP02o`000003oj?g
hOl0003o0000073ooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP02oookJP000ooo
nfX00ol0003ooo]ZoookJP0<oookJP?o000000GokYYSo`000?l0003o0000onfRMP04o`000003on^W
Q?l0003o000000;o00000_oWZHl4o`0000;oiJbG00Co0000onB[Uol0003o00000_oR[Id00ol0003o
hJbMon6/W@02o`0000;ogjjR00Co0000omj/X_l0003o00001?o<c=X00ol0003obl_Jol_;fP02ol_;
fP?obl_I0_l00003om79dP05o`000?o?b=?oclSColo8dol000000oo?b=<2o`0000?od/C=00Co0000
om;4cOoBa<go00001?o@a<h6o`0000;od/3800Co0000om2obOo@_lWod;o90ol00002om:la@03o`00
0?oA^lGodK_500;odK_500?o0000olnjaOo?^/D01?l000000oo@]l;o0000olnf`P02olnf`P03o`00
0?o;/l?obk?300;obk?300Ko0000olfb__l0003o0000olfb_ol00004olV__`05o`000?o;[Kcobjfl
ol^]_?l000000oo:[kh5o`000003olV[^ol0003oaJNk00CoaJNk00Goa:Nlo`000?o7YkWoajNio`00
0005olFW^`03o`000?o1Xk_o000000Go00000_noX;T2o`0000Co`J6i00?o0000okfM^?nmWKP00_nm
WKP2o`0000Ko_Iji00?o0000ok^K^?nkVkP00_nkVkP01Ol0003o^9VhokRI^?nhVKSo000000;o^9Vg
00?o0000okRI^OnhVKT00onhVKT9o`000003ok>D]ol0003o/YFh00Co/YFh00?o0000ok2B]ol00000
1On`TkT01?l0003o[I2go`000?l00004ojfA^@03o`000?n[S[SoZhjh00;oZhjh0on/T;X00ol0003o
Z8fiojR=^@04ojR=^@;o00000onVSKX7o`0000;oXhZj0_l00007oj6:_003o`000?nNR;coWXRl00;o
WXRl1?l000000onLQkco0000o`000002oib9_P03o`000?nIR;ooVHRo00CoVHRo00?o0000oiN6`?l0
00000_l000000onGQl3o0000oiB6`@05oiB6`@04o`000?nCQ/;oThK2oi>6`P;o000000?oThO4o`00
0?n@QL@00on@QL@Lo`000004ohV:c_n;SM3oRhg@oh^=d0CoRY7D00?o0000oh^Ae?n;TM@01?n;TM@0
0ol0003oR9?HohRCf004ohRCf003o`000?n<VM_oS9WK00?oS9WK4Ol00006oiB`jP03o`000?nG`OCo
Ul7d00?o00000onJb?L01?l0003oX=Kko`000?l00003oj?No0;o000000Co[ncho`000?l0003oXoOQ
0ol0001boookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX00OoonfX000?ooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ojH@lo`000002o`000004onfIIOl0003okJ9fo`0000;ok:5g
00?o0000on^WQ?l000000_oZYXD01?l0003oijV?onNYSol00002onJXS`04o`000?oU[9OoiJbGo`00
00;oi:^G0ol00003on6/W@04o`000?oPZigo0000o`0000;ogZbR0_l000001?o3cN7o0000olc<f_l0
0003ol_;fP04o`000?o;bmWobl_Iol_;f@?oc<[H00?o0000om79d_l000000_o?b=<2o`0000?oclSC
00Ko0000olk7doo>am?o0000om;4cOl00002om;4c@04o`000?o@a<kod<C>om34cPGo000000God[o8
o`000?oB`<Sod/38o`000004om2ob@03o`000?o=_<[ocKc:00?o00000ooA^lD02?l0003ock[5olnj
aOo?^/Go0000olbga_l0003od;S20ol000000oo?]/;o0000ol^c``04ol^c``04o`000?o=/[kocK:n
olfb_P?o00000_o9[kl01Ol0003ob:k0o`000?o;[Kco000000CobZnn00Co0000olJ[__o6ZkkoaZ^n
1?l00003olFW^`?oa:Nl0_l00005olFW^`06o`000?o1Xk_o`J>ko`000?o3Y;[o00000oo2Y;/6o`00
0003ol6Q^Ol0003o_Ifh00Co_Ifh00?o0000okfN^OnmW[T01?nmW[T2ok^L^004o`000?nkVkSo^i^h
o`0000Go^9Vh0_l00006okRI^@03o`000?neUkWo]INi00Go]INi0_l00006ok:E^0;o00001_n`TkT2
o`0000Oo[I6i00?o0000oj^>^?l000001On/T;X00ol0003oZ8fio`000008o`0000?oYXfj00Co0000
oj>:^_nSR[[oXhZj0_l000000onTS;co0000oj6:_006oj6:_003o`000?nNR;co000000;o000000Co
WXRlo`000?l0003o00001OnLRKh00ol0003oVHRooiV8_`03oiV8_`?o00001OnGQl001?l0003oU8K1
oiB6`OnDQ/44o`000003oi>6`_l0003o000000Oo00000onAR<H2o`0000CoT8[800?o0000ohf:bon=
R//00on=R//2o`0000KoSXg=00?o0000oh^=d?n;SM000_n;SM02o`000003oh^=d?l0003o000001Oo
000000?oS9cNo`000?n<Y^H01On<Y^H00ol0003oU:[UoiBZi@04oiBZi@;o00001?nD/>X5o`0000Oo
V/Sg00Co0000oj?No?l0003o00000_n[h?T3o`000005okW[mOnOm>So0000o`000?nbn//0LooonfX0
0ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z007ooo]Z0003oookJP03o`000?oonf[ooo]Z
00cooo]Z00?o0000onV4??l000001_l00002onbQM`?o00000_oZYXD3o`0000?oiZR?0ol00003onB[
U`04o`000?oSZIOo0000o`0000;ohJbM00?o0000on2[WOoPZid00ol00003olC=h@;o00000oo;bmX0
1?l0003obl_Iol_;fOl00004olc:f0?o000000?oclSCo`000?o?b=<00oo?b=<01?l0003oc/OColk7
doo>am<3o`000003om;4cOl0003od<C>00Co00000oo?`lh3o`000003om;0b?l0003od;o900?od;o9
00Go0000olflb_o=_<[ocKc:o`000002om6ka@03o`000?oA^lGo000000?ock[500Go0000olbga_o<
]lKoc;O6o`000003olnf`P;o00001?o;/l<01?l0003obK;3o`000?l00004olbb`0Co000000?ob:k0
o`000?o:[kh00oo:[kh00ol0003oaZ^nolJ[_P02olJ[_P04o`000?o8Z[_ob:ZkolRZ^`Co00000_o4
Yk`00ol0003oaJNkolFW^`03olFW^`04o`000?o1Xk_o`J>kol6S^`;o00001?o2Y;/01_l0003o_j6j
oknQ^_noXK[o0000ol2Q^@So00001OnmW[T3ok^L^003o`000?nkVkSo000000Ko^9Vh00?o0000okRI
^OnhVKT01?nhVKT2o`0000Ko]INi00?o0000okBF^?l000001OnbUKP00ol0003o/YBho`000005ok2C
^@03o`000?n`T[So000000Oo[I6i00Co0000ojb@^_n/T;[o[92j1ol00004ojR?^`03o`000?nVSK[o
YXfj00CoYXfj0ol00005ojB<_004o`000?nQR[coXHZloj6:_0Go00000_nNR;`2o`000003oin;__l0
003oW8Vn00KoW8Vn00?o0000oiV8_ol000000_l000000onJR;oo0000oiN7`003oiN7`0Ko00000_nE
R<<00onERLCo0000oiB9a@05oiB9a@03o`000?nAR<KoTHS600?oTHS60_l00006oi2:b007o`000?n=
R/_oSH[;ohf:bol0003oSX[;o`000006ohj=c@03o`000?n;SM3oRhg@00CoRhg@00?o0000ohfAdon=
TM<01?n=TM<01?l0003oRY?Fo`000?l00003ohZCeP03o`000?n>VM[oSYWJ00CoSYWJ00?o0000ohbK
gOl000001?n<W=h00ol0003oS:KVohbViP04ohbViP03o`000?nDZ^GoU:[U00;o000000?oU:[Uo`00
0?l000001?l00005oiFml`Co00001?nMd?X01Ol0003oZn3ioj_PnOn[h?Wo000000;o^N_e0_nOm>P3
o`0007Gooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP01oookJP000ooonfX00ol0
003ooo]ZoookJP0<oookJPGo000000?ok9AMo`000?l000000_l000000oo/XGOo0000onbPN004o`00
0003onRTQOl0003o000000;o00000_oVYhl4o`0000;ohjVG00Co0000on:XUol0003o00000ooPZid2
o`0000?oa<gQ0oo4c>000ol0003obl_Jo`000002ol_;f@03o`000?o<b]Soc<[H00;oc<[H00?o0000
olW9fOo9bMT00ol00003olo8d`05o`000?o>am?oc/OColk7dol000000_o<aM<4o`0000;od<C>00Go
0000olo3c_o?`lkocl?>o`000002olg0cP?o00000oo@_lT00ol0003ocKc:olflbP02olflbP04olbk
b_l0003odK_5om6ka@?o000000?ock[5o`000?o<]lH00_o<]lH2o`0000?ockK200Ko0000olfd`_l0
003o0000ol^c`ol00002olVb``03o`000?o<//3oc;;000?oc;;000Co0000ol^a`Oo;/L7obk711?l0
00000oo:[kko0000olJ[_P03olJ[_P;o00000oo8Z[/01?l0003oaj^nolN[__o7Zkh6o`000003olFW
^ol0003o`J>k00;o`J>k00?o0000ol:T^ol000000oo2Y;/00ol0003o_j6joknQ^P03oknQ^P03o`00
0?noXK[o_j6j00?o_j6j00?o0000okbN^_nlW[X03Ol00003okRI^0;o00001OnhVKT01?l0003o]iRh
okNH^?l00004okFG^@Co]9Jh00Co0000ok:E^?nbUKSo/YFh1?nbU;P01Ol0003o/9>iok2C^On`TkWo
000000?o/9:h00?o0000ojfA^On]TKT00_l000000on]TKWo0000o`000003o`0000CoZi2j0_l00005
ojR?^`04o`000?nVSK[oYXfjojJ=^P?o000000?oYXnlo`000?nTS;`01?nTS;`5o`0000;oXHZl1?l0
0005oin;_P03o`000?nLRKkoW8Vn00?oW8Vn0ol00002oiZ8_`Oo00000onHRL800ol0003oUHS3oiF8
``04oiF9a003o`000?nDRLGoU8W500CoU8W500?o0000oi68a_l000000_l000000onARLOo0000oi2:
b005oi2:b003o`000?n=R/_oSH[;00CoSX[;00?o0000ohj=cOn>SLd01?n>SLd00ol0003oRhg@oh^=
d004oh^=d003o`000?n=TM?oSI7C00CoSI7C00?o0000ohZCe_n:TmH01?n:TmH00ol0003oSYWJohjI
fP04ohjIfP04o`000?n<W=koS9cNohbLgPgo00001OnC[^P00ol0003oUKgcoiFml`03o`0000;oVLCf
00?o0000oig@n_nMd?X00ol00004oj3In`05o`000?n_iOWo0000okW[mOnOm>P00_l000000onbn/_o
0000oookJP1foookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX00OoonfX000?ooo]Z
00?o0000oookJ_oonfX03OoonfX00ol0003offH@o`000003o`0000;ojiAO0ol000000oo/X7So0000
o`000002o`000004onRTQOl0003oij>5onNSQ@;o000000CoiZN?o`000?oUYY3oiJJ@0ol00003on:X
U`Co00000_o4cN42o`0000Goa<cP0_l000000oo;bmWo0000olc:f003olc:f004o`000?o9bMWobLWI
olW9f@;o000000CoclSCo`000?o?b=?o00000oo>am<6o`000004om74c_l0003od<C>o`0000?ocl?>
00Co0000olg0c_o=`<kocL3>0_l000001?oA_lWo0000om2obOl00004olflbP?oc;_:00?o0000olnj
aOo?^/D00_o?^/D3o`000007olbga_l0003obkK6ol^fa_l0003ockK2o`000004olfd`P?o000000?o
bK;3o`000?o<//000oo<//001ol0003obk71ol^a`Oo;/L7o0000olN^`Ol000000_o:[kl3o`0000;o
aZ^n00Ko0000olFZ_oo5Z[oo0000olRZ^ol00004olN[_P05o`000?o3Ykgo`jNmo`000?o5Z;`01Ol0
00001oo1Xk_o0000o`000?o2Y;_o0000ol:T^ol000001OnoXKX2o`0000Co_j6j00Oo0000okbN^_nl
W[[o_9jjo`000?nmW[Wo000000Ko_9nk00Co0000okZK^?njVkSo^Y^h6?l000000onbUKSo0000o`00
0006o`000003ok2C^Ol0003o000000Oo00000_n]Tk/00ol0003oZi2joj^@^P04oj^@^P;o00001onX
Sk/00ol0003oYXfjo`000005ojJ?_003o`000?nTS;co000000;o00000_nSS;`00ol0003oXHZloj6:
_002o`0000;oXHfn00?o0000oin;__nORkh01?nORkh00ol0003oW8Vnoib9_P08o`0000?oVX[100?o
0000oiR9`_nHRL800onHRL82o`0000KoUHW400?o0000oiB9aOnDRLD00onDRLD3o`0000GoTHW700?o
0000oi2:b?n@R/P00_l000000on@R/So0000o`00000/o`0000?oSJGU00?o0000oiBXi?nDZ>@01OnD
Z>@00ol0003oTjkXoi>^j002oi>^j0Go00001_nIa?H2o`0000?oX=Wk0ol00002oj?Ro0;o000000Go
WoCXo`000?l0003o/_[;o`00001ioookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
0OoonfX000?ooo]Z00?o0000oookJ_oonfX03_oonfX8o`000004on^CHOl0003o0000o`0000;ojYef
0ol00002onNSQ@04o`000?oVXXGo0000o`0000;oiJJ@00Co0000onBUT?l0003o00000_oRZ9L4o`00
0003olC=hOl0003oa<cP00Coa<cP00Go0000olC;h?o4bn3oa<_Po`000004olc:f0CobLWI00Oo0000
olS8fOo8b=Wo0000olo8dol0003oc/OC00Co00000_o<aM<01Ol0003oblCCol_4dol0003odLC>00?o
000000?ocl?>o`000?o=`<h00_o=`<h01Ol0003oc;o?olbocol0003odKo900?o00000_o=_<X3olbk
bP;o00000oo?^/D01_l0003oc[W5oljiaOo>^LGoc;O6o`0000?obkK600?o0000olfd`_o=]<800_o=
]<801?l0003ocKK4olffa?o=]/@3o`0000;oc;;000Go0000ol^a`Oo;/L7obk71o`000003olN^`@03
o`000?o:[koo000000;obJfn00Co0000olJ[__l0003o00000_o5Z[l00ol0003oaj^nolN[_P02olN[
_P03o`000?o3Ykgo`jNm00;o`jNm00?o0000olBX_Oo4Z;d00oo4Z;d00ol0003o`:Blol2T_006o`00
00;o_j6j00?o0000oknQ^ol000000onoXKX00ol0003o_9jjokbN^P03okbN^P03o`000?nlWk_o_9nk
00Go_9nk00?o0000okZK^?njVkP00_njVkP01Ol0003o^IfkokVM^oniWK_o000000;o^9Zi00?o0000
okNJ^ongV[/00ongV[/2o`0000Ko]9Rj0_l00006ok:F^P03o`000?n`TkWo000000Go[iBk00?o0000
ojfA^Ol000001On]Tk/01?l0003oZi2joj^@^_n[T;X2o`000003ojbB_?l0003oZ8nk00KoZ8nk00?o
0000ojJ?_?nVSk`00_nVSk`5o`0000CoXhbl0ol00006oj6=_P04o`000?nORkkoWh^noin;_PGo0000
00GoW8Voo`000?l0003oWHc1o`000007oiZ:`@03o`000?nHRL;o000000;o000000?oV8W2o`000?nE
RL@01OnERL@00ol0003oU8W5oiB9a@0@o`0000;oT8c;00?o0000oi6>cOnAS/d01?nAS/d00ol0003o
SXo@ohj?d002o`0000;oSXo@00?o0000ohnBd_n?T]800on?T]801Ol0003oS9?EohbCeOn<TmGo0000
00;oS9CF00?o0000ohnIfOn?VMT01?n?VMT01Ol0003oSI_LohfKg?n=Vmco000000?oSI_L00?o0000
ohfUiOn=YND01?n=YND01?l0003oU:SToiBXi?nDZ>@2o`000003oiBXi?l0003o000000?o00000onE
^_400ol0003oVLCfoiW4mP03o`0000?oW<ch00Co0000oj3Inol0003o00000onSh_`00ol0003o[?3g
ojc`m`05o`0007_ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP01oookJP000ooo
nfX00ol0003ooo]ZoookJP0>oookJPGo00000_oWPd<01?l0003oji=Qo`000?oZTf82o`000003onZM
M_l0003ojIag00;o000000Coij>5o`000?oVXXGoiZ:50ol00002onBUT003o`000?oSYI3o000000;o
00000_njc>P2o`0000Coa<cP00?o0000olC;h?o4bn000_o4bn02ol?:h003o`000?o<b]Soc<[H00Co
bLWI00Co0000olS8fOo8b=Wob<SI1?l000000oo>am?o0000olc5d`02olc5d`04o`000?o;a=?oblCC
ol_4d`;o00000oo@`lh01Ol0003ocL3>olg0c_o=`<ko000000?oc;o?0_l00003olnnb@05olflb_l0
003o0000olbkb_l000000_o;^//00ol0003ock[5o`000003oljia@05o`000?o>^/Ooc[[7o`000?o;
]/H00_l00003olfd`P05o`000?o=]/CocKK4olffa?l000000oo8//@4o`000003ol^a`Ol0003oajk1
00?oajk10_l00004olV]_P03o`000?o8[/3ob:k000Go000000?oaj^no`000?o3Ykd01?o3Ykd00ol0
003oa:RmolBX_@02olBX_@03o`000?o0Y;co`:Bl00;o`:Bl00?o0000ol6S^_o1XkX00_o1XkX02?l0
003o_j6jo`000?l0003o_j6ko`000?noXK[o00001OnlW[X2o`0000Ko_9nk0_niW;X01?l0003o^Y^h
okZK^?l00005okVM^`;o00001_ngV[/00ol0003o]9RjokBH^P05okBH^P03o`000?nbU[[o/YJj00Go
/YJj0_l00006ojnD^`;o00001_n]Tk/01?l0003oZi2joj^@^_l00004ojbB_004o`000?nXSk_oZ8nk
ojR?^`;o000000?oZ8nko`000?l000000ol00003ojJ?_004o`000?nSS;coXhbloj><_0;o000000?o
Y8nno`000?nQSKh01?nQSKh6o`0000;oWh^n0ol00005oif<`@03o`000?nJR/7oVX[100?oVX[10ol0
0005oiR9`P04o`000?nERLCoUHW4oiF9a0Go00001OnDRlL6oi><b@03o`000?n@S<_o000000GoT8c;
00?o0000oi6>cOnAS/d01?nAS/d2o`0000CoSXo@00?o0000ohnBd_n?T]801?n?T]800ol0003oS9?E
o`000004ohbDeP03o`000?n?VMWoSiWI00CoSiWI00?o0000ohfKg?l000000_n=Vm`9o`000006ohfU
iOl0003o0000o`000?nG[NKo00000_nC[>L00ol0003oUK[aoiFjl@05oiFjl@;o00001onLc?P00ol0
003oXn;loj?Ro006o`000003okW`m?nFl]go000007gooo]Z00?o0000oookJ_oonfX01ooonfX00ol0
003ooo]ZoookJP01oookJP000ooonfX00ol0003ooo]ZoookJP0?oookJP?o000000?offLFo`000?l0
00000ol000000ooZTf;o0000onVBH`02o`000003onVLMol0003oj9ah00;o00000_oVXXD01Ol0003o
iZ66o`000?l0003oi:F@00Co000000?o^/cXo`000?l000000_njc>P01?l0003oa<cPo`000?l00002
olC;h0;o00001?o3b^02o`0000?obLWI00?o0000olS8fOl000000ol000000oo8amWo0000olk7d`03
o`000003olc5dol0003oblCC00;oblCC00[o0000ol[3e?o:`mCo0000om33c_l0003ocl;>o`000?o=
`<ko00000oo<_ll01_l0003ob[k?olZncol0003ockk9o`0000?oc[c90_l00003ol^jb`05o`000?o>
^LGoc[W5oljiaOl000001?o>^/L4o`000003olfd`_l0003ocKK400;ocKK400?o0000olRba?o8//@0
0_o8//@01?l0003obk71ol^a`Oo;/L43o`0000;oajk100?o0000olF]`_l000000oo9[Kh01Ol0003o
b:k0olR^`?o8[/3o000000;oa:[000?o0000olN[__l000000ol00002ol>W_@03o`000?o3Ykgo0000
00;oa:Rm00?o0000ol2T_?o0Y;`00oo0Y;`00ol0003o`J>jol6S^P02ol6S^P04o`000?o0YKgo`:Fm
ol2U_@co00001?nlWk/3okVL^P03o`000?njVkSo000000Ko^Ifk00?o0000okNJ^ongV[/01?ngV[/2
o`0000Ko]9Rj00?o]9Njo`000?nbU[X01OnbU[X00ol0003o/IFjo`000005ojnD^`03o`000?n_U;[o
000000Oo[I>k00Co0000ojbB_?n/T[co[9:l2Ol00002ojRA_@03o`000?nVSkcoYXnl00GoYXnl00?o
0000oj><_?l000001?nTSkh00ol0003oXHfno`000002o`0000;oXHfn00?o0000oin;__nORkh00_l0
0002oin=`@03o`000?nMS<7oWHc100CoWHc100?o0000oiZ:`OnJR/400ol000000onJRl;o0000oiR9
`P02oiR9`POo00000_nFRlH2o`0000KoU8_700?o0000oi><bOnCS<T00onCS<T2o`0000KoT8c;00?o
0000oi6>cOnAS/d00onAS/d2o`0000KoSXo@00?o0000ohnBd_n?T]801?n?T]801?l0003oS9CFohbD
e_n<U=H>o`0000?oSjCS00?o0000oi2Yion@ZNL01?n@ZNL01Ol0003oUjgVoiN]i_l0003oTjcW00Oo
00001?nH`O@00ol0003oW<choic<n003o`0000?oW]Ck00?o0000ojcRnOn/h_T00_l000001Onil?Co
0000o`000?l0003o[o[A07oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP01oook
JP000ooonfX00ol0003ooo]ZoookJP0@oookJPCo000000?offLIo`000?l000001?l000001?oYTV?o
0000o`000?l00002onRLN0?o00000_oVXHH4o`0000?o^lcW0_l00003ok[<j0;o00000oo4bn000ol0
003o`l[Pol?:h005ol?:h0;o000000?obLWIo`000?l000000ol00003olS7f@;o00000oo>a]<01Ol0
003oblCCol_4doo;a=?o000000?ob/?D0_l00003olo2cP?o000000?oc;o?o`000?o:_/l00_o:_/l2
o`0000Coc[c900Wo0000olfkbOl0003obk[;o`000?o9^/_o0000oljiaOl000001?o>^/L01?l0003o
c;W7olbiaoo<^LL4o`000003olffa?l0003ob;;400Cob;;400Coak75o`000?o;/L7o00000oo9/<44
o`000004olF]`_l0003obJfno`0000?ob:k000?o0000olBZ`?o4Z/000_o4Z/02o`0000?oaJVm1Ol0
00000oo4Z;go0000ol2T_004ol2T_003o`000?noY;go000000;o`J>j00?o0000ol2U_Oo0YKd00oo0
YKd2o`0000Co_Z2j00Co0000okfR_OnmX[go_J:m3Ol00003okVM^`;o00001OngV[/01?l0003o]YVj
okJI^_l00004okBH^P?o]9Nj00?o0000ok:F^_nbU[X00_nbU[X4ok6E^P05o`000?n_U;_o0000o`00
0?n_U;/02?l000000on]Tk_o0000o`000003o`0000?oZi:l00Co0000ojR?^ol0003o00001?nXTKd0
0ol0003oYXnlojJ?_003ojJ?_0?o00000onTSkh5o`0000CoXHfn0ol00005oin=`@03o`000?nMS<7o
WHc100?oWHc11?l00002oiZ;`PKo00000onIS<D01?l0003oUX_6oiJ;a_nFRlH2o`000003oiN<a_l0
003oU8_700KoU8_70onCS<T2o`000003oiB>bol0003oT8c;00?oT8c;6ol00003ohjKf`CoTYgK0_l0
00000on?Vm_o0000ohnTh`06ohnTh`04o`000?n@ZNOoT:WWoi2Yi`;o000000?oT:WWo`000?l00000
0_l00004oiNbjP03o`000?nH`OCoV<7d00GoV<7d0_l00002oikDn`?o00000onQg_`2o`000003okW`
m?l0003oU_;M00;o0000POoonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z007ooo]Z
0002oookJP03o`000?oonf[ooo]Z01;ooo]Z1?l000000ooKIaWo0000o`000002onJ2A`04o`000?oY
TV?o0000onRBI@;o000000?oj9aho`000?oWVgP01?l00003oj_:l003o`000?nkc>Oo000000;o^lcW
00?o0000ok[<j?l000000_nibnL00ol0003oa<_Po`000003ol?:h0;o00000_o3b^05o`000003olS8
fOl0003ob<OI00?ob<OI00?o0000olO6fOo7a]T00_l00002olg5d`03o`000?o;a=?o000000?ob/?D
00Ko0000olW2e?o9`]Co0000olo2c_l00003olg0cP?o000000Cob[k?o`000?o9_Loo00000oo>_<T0
1?l0003ocK_9olfkbOo=^lT3o`000003olVjbol0003oc[[700?oc[[700Go0000olbiaoo<^LOoc;W7
o`000002olRfb003o`000?o<]/Go000000;o00000oo8//@3olNaa@03o`000?o9/<7obK3100?obK31
00?o0000olVb`oo9//<01Ol000000oo8[/3o0000olBZ`003olBZ`0;o00001?o5ZKd01?l0003oaJ_0
olF[`?o5Zl05o`0000;o`:Bl00Ko0000oknT_OnoY;go0000ol6S^_l00006ol2U_@03okfQ_Ol0003o
_Z2j00;o_Z2j00?o0000okfR_OnmX[d00_nmX[d00ol0003o_9nko`000004ok^O_003o`000?nhWKco
000000?o^Ifl4?l000000ondV;[o0000o`000005o`000003ok:F^_l0003o000000Ko00001?n_U[d0
1?l0003o[I>kojfC^on]Tk/2o`0000;o[IBm00?o0000oj^B_?n[T[`01?n[T[`2o`0000OoZ96m00?o
0000ojJ?_?l000002?l00003ojB>_P03o`000?nQSKkoXHfn00?o000000?oXXo0o`000?nOSL401_nO
SL400ol0003oWHc1o`000002o`000003oif<`Ol0003o000000?o00000onKSL@00ol0003oVHc5oiV<
a@03oiV<a@?o00001OnGS<H01?l0003oU8_7oiB;aonDRlL4o`000003oi><bOl0003o000000Oo0000
0onBSld3o`0000CoTI7@00?o0000oi:Cd_nBTm800onBTm800ol0003oSiCEo`000002o`0000;oSiGE
00?o0000ohjKfon>Vm/01On>Vm/2oi:Mf`03o`000?n?Vm_oSi_K00;oSi_K00?o0000ohnThon?Y><0
0_n?Y><2o`000004ohnThol0003o0000o`0000?oV:cU00?oU[;Zo`000?nG/^X01?nG/^X6o`0000Go
VlSg0_l00002oj7No0?o00000_nZk?T4o`0008Cooo]Z00?o0000oookJ_oonfX01OoonfX1o`00007o
oo]Z0OoonfX000;ooo]Z00?o0000oookJ_oonfX04ooonfX7o`000007onJ2Aol0003o0000o`000?oX
TVGo0000onNAIP04o`0000OoZl[`00?o0000ok_<ionkc>L00_nkc>L01?l0003o^L_WokW;ionibnL2
o`000005ol?:h?l0003o`l[Po`000?o3b^001?l00002ol;9g`04o`000?o:bMWo0000o`0000?ob<OI
00Co0000olO6fOo7a]Wo00000_o6a]X00ol0003ocLGColg5d`03o`000003ol[3e?l0003obL;D00;o
bL;D0_l00003olg0cP04o`000?o<_lkoc;o>olbocP;o00000_o9_Ll00ol0003oc[c9o`000003olfk
b@04o`000?o=_L_ocKg;olfmb`?o00000_o>^/L01Ol0003oc;W7olbiaoo<^LOo000000Cob;K800Ko
0000ol^da?o;]<CobkC4o`000?o8//@2o`000003olNaaOl0003o000000CobK3100?o0000olVb`oo9
//<00_o9//<2o`0000;ob:o10ol00002olBZ`003o`000?o3Z/7o000000?oaJVm00?o0000olF[`?o5
Zl000oo5Zl001?l0003o`jNlol>W_?o3Yk`:o`0000?o`:Fm0_nmXKd01?l0003o_Z2jokjP^_l00005
okfR_@;o00001?nkWk`01Ol0003o^9flokRM_?nhWKco000000?o^Ifl00Oo0000okRN_OnhW[go^9jm
o`000?ngVk_o000000Go]Y^m00?o0000okBH^ol000001_ndVK`2o`0000Ko/INl0_l00006ojnF_@?o
00001On]U;d01?l0003oZi:loj^B_?n[T[`2o`000003oj^D__l0003oZ96m00KoZ96m1?l00003ojJA
_`03o`000?nTS[koY8jn00?oY8jn1?l00005oj:?`004o`000?nOSL7oWhg1oin=`@Go00000_nMS<42
o`000003oif>`ol0003oVhg400KoVhg400?o0000oiV<aOl000000_l000000onIS<Go0000oiN<aP03
oiN<aPKo00000_nES/X00onFS/[o0000oiF@c005oiF@c003o`000?nBSlgoTXo=00?oTXo=0_l00006
oi6Ad003o`000?nBTm;oTY?B00?oTY?B0_l00006ohnEe@03o`000?n>Vm_oSY_K00;oSY_K0_l00000
0on>Vm_o0000o`000009o`0000?oTJWV00?o0000oiR/iOnH[>D00_nH[>D3oiJbjP03o`000?nG/^[o
000000;o00000onH__800ol0003oVlSgoi_8m`03o`0000;oWM7j00Go0000oj7No?l0003o0000oj;V
n`04o`000003okG]m_nBl>;o000008Kooo]Z00?o0000oookJ_oonfX01?oonfX1o`00007ooo]Z0Ooo
nfX000;ooo]Z00?o0000oookJ_oonfX05OoonfX=o`0000;oT/?h00?o0000oj_:l?n[b_000ol00004
oj_9l0;o00000_njbnL00ol0003o^L_Wo`000003okW:i`Co000000?o`l[Po`000?l000001?o2bMl0
1_l0003obLSIolW8fOl0003ob<OIo`0000;oalKI00?o0000olK6f_o6a]X00_o6a]X00ol0003oc<CC
olc4d`02olc4d`?o000000OobL;Do`000?o8`MCob<7Do`000?o=`<ko000000?oc;o>00Go0000ol^n
c_o;_/ko0000olVmc`02o`0000?ocK_900Go0000olfmboo=_L_ocKg;o`000003olVic0Co000000?o
c;W7o`000?o8]/P01?o8]/P01Ol0003obkC4ol^da?o;]<Co000000?ob[G60_l000001Oo6/LGo0000
olV``Oo9/<7o000000CobK;300Ko0000olF^`oo5[/?o0000olR_`Ol00002olJ/`003o`000?o4Z/3o
000000?o000000?oaJVmo`000?o5Zl001?o5Zl02ol6W`004o`000?o3Ykco`jNlo`0000Co`ZRo0_l0
0003ol2U_PGo000000?o_J6mo`000?l000001OnmX[d00ol0003o_:2lo`000003ok^O_003o`000?nh
WKco^9fl00;o^9fl00Co0000okVM_?niWKco00001OnhW[d00ol0003o]Y^mokJK_@04okJK_@;o0000
1ondVK`00ol0003o/INlok6G_004ok6G_0;o00001_n_U[d2o`0000Oo[IBm00Co0000oj^B_?n[T[co
00001?n[U;h01?l0003oZ96mojRA_OnXTKd2o`000003ojRA_Ol0003oYY6o00KoYY6o00?o0000ojB>
__l000000_l00002ojBA`@03o`000?nRSl3oXXo000?oXXo01Ol00002oin=`@Co00001OnMS/<00ol0
003oVhg4oi^=a003oi^=a0?o00000_nIS<D7o`0000?oUhk800?o0000oiF>b_nES/X01?nFS/X00ol0
003oUI3<oiF@c004oiF@c003o`000?nBSlgoTXo=00;o00000_nCT<d00ol0003oTI7@oi6Ad004oi6A
d003o`000?nBTm;o000000oo00000_nAW=X00onAW=_o0000oi6PgP05oi6PgP03o`000?nAZNKoTJWV
00GoTJWV0_l000000onH[>Go0000o`000004o`0000OoV;kb0_l00006oigAnP03o`000?nRi__oX^Kk
00;o000000?o]Ngfoi;`h_nBl>800_l00027oookJP03o`000?oonf[ooo]Z00Cooo]Z0Ol00001oook
JP7ooo]Z0002oookJP03o`000?oonf[ooo]Z01Kooo]Z0ol000000omEZ_Wo0000o`000003o`0000Ko
T/?h0_l00004oj_9l0;o00000_n[bNl01?l0003o^/_Wok[;ionjbnL5o`0000;o^<[W00?o0000ol?:
h?l000001?o2bMl00ol0003o`/SOol;8g`02ol;8g`05olW8fOl0003o0000olO6fOl000001?o6a]X0
1Ol0003oaLGJo`000?o<a=?o000000Cobl?C0_l00003olS1e005o`000?o<_lkoc;o>olboc_l00000
1?o;_/h4o`000003olfkbOl0003ocKg;00;ocKg;00?o0000olVic?o9^L`00_o9^L`01?l0003oc;W7
olbiaoo<^LL2o`0000Cob;K800Go0000olNeb?l0003obkC4o`000004olZeaP06o`000?o9]LKo0000
o`000?o9/<7o00001?o9//<00ol0003oaJk3olF^``02olF^``05o`000?o6[<3oaZc0olJ/`?l00000
1?o6[/<4o`0000?oaJ_00oo1Yl000ol0003o`jNlo`000004ol:X_`04o`000?nnY;oo_ZBoo`0000;o
`:Fn00?o0000oknU_onoYKl00_noYKl:o`000004okbP_?l0003o^inlo`0000Go^9fl00?o0000okVM
_?l000001OnhW[d2o`0000Go]Y^m00?o0000okFJ_?l000001_ndVK`00oncV;co0000ok6G_004ok6G
_003o`000?naUkco000000Go[iJm00?o0000ojnF_Ol000001on]U;d>o`0000;oZ9>o00?o0000ojJA
_onVTKl00onVTKl3o`0000KoY97100?o0000oj:?`?l000000_l000001?nRSl7o0000o`000?nOSL42
o`0000?oX8o300?o0000oif>`onMS/<01?nMS/<00ol0003oVhg4oi^=a008o`0000?oVXo700?o0000
oiN>b?nGS/P00onGS/P2o`0000KoUXk:00?o0000oiF@c?nET<`01OnET<`01?l0003oTi3=oi>@cOnC
T<d<o`0000CoTIOE00?o0000oi>JeonCV]L01?nCV]L00ol0003oTIcJoi6LfP02oi6LfP?oTIcK00Co
0000oi6Pg_nAX=koTJ3N2Ol000000onAZNKo0000o`000006oiN`j@03o`000?nH__;oV;kb00?o0000
0_nJa_H00ol0003oWM7joigAnP03o`0000CoWm_l0_l00002oi;`hP?o0000ROoonfX00ol0003ooo]Z
oookJP03oookJP7o00000OoonfX1oookJP000_oonfX00ol0003ooo]ZoookJP0HoookJP03o`0kZOl0
003o000000Oo00001OnA`oP01?l0003oZlW`o`000?l00005oj_9k`Oo00000onhb^L2o`0000?o`/WO
0_l00004ol;8g`;o`LSO00Co0000olW8fOl0003o00000oo6a]X01Ol0003oaLGJolG5f_o5aM[o0000
00Cobl?C00[o0000olW2doo9`]?o0000olS1e?l0003oa/7Eo`000?o<_lko00000oo;_/h00ol0003o
bl3@ol_0d002ol_0d0Co000000?ocKg;o`000?o9^L`00oo9^L`01Ol0003oakW<o`000?o<^LOo0000
00;obkO70_l000000oo8]/So0000olNeb002olNeb003o`000?o:]LKob[G600;ob[G600Co0000olVe
a_o9]LKobKG61?l00002olVb``03o`000?o5[/?oaJk300;oaJk30_l00002olJ/`003o`000?o6[/?o
aZk300?oaZk30_l00002olB/`@Go00000_o1Yl000ol0003o`ZRool:X_`02ol:X_`07o`000?nnY;oo
_ZBookjT_ol0003o`:Fno`000004oknU_`03o`000?nlX[oo000000Co_J>n00Co0000okbS_onlXkoo
_:>o3_l00002okRN_@04o`000?ngW;co]iblo`0000?o]Y^m00Go0000okFJ_?neV[co]IZlo`000004
okBI_0?o/iRl00Go0000ok6G_?naUkco/INlo`000003ok6G_005o`000?n_U[go0000o`000?n_U[d0
1ol000001On]U;go0000ojbF_on/U[oo000000KoZiBn0ol00005ojRC_`04o`000?nVTKooYY6oojJA
_`;o000000?oYi?1o`000?nTTL400onTTL45o`0000?oXXo100?o0000oj:A`ol000001_nPSl<00ol0
003oWHk3oif>``03oif>``Go00000onLT<H00ol0003oVXo7oiZ?a`05oiZ?a`03o`000?nGS/So0000
00;o000000?oV8o8o`000?nFS/X00onFS/X>o`0000?oTiGB1_nDUM82o`0000KoTIOE00?o0000oi>J
eonCV]L01?nCV]L01?l0003oTIcJoi6LfonAW=/7o`0000?oTZWU00?o0000oiR[i?nHZn@01?nHZn@0
0onG/NWo0000oiN`j@03oiN`j@Go00001_nJa_H2o`0000?oWm_l0_l000000onPi?co0000ok7[n002
ok7[n0;o0000S?oonfX00ol0003ooo]ZoookJP02oookJP7o00000OoonfX1oookJP000_oonfX00ol0
003ooo]ZoookJP0IoookJP;o000000Ko06kFoe:YnOmBZOWo0000ofFbnol00007oi73n004o`000?n[
bNooZlW_oj_9k`Ko000000?o^/_Wo`000?nibnL00_nibnL00ol0003o^<[Wo`000002okO9j003o`00
0?o2bMoo000000?o`/SO0_l00004ol78g`06o`000?o8amWob<OIo`000?o6a][o00000oo5aMX01_l0
003oa<CJolC4f_l0003obl?Co`0000CobL;C0ol000000oo6`MGo0000ol^ncP02ol^ncP03o`000?o;
`=3obl3@00;obl3@00Go0000olNmd?o7_M3o0000olbmc002o`0000?obKW<00Go0000olNic?o7^Lco
akW<o`000005ol^ga`?o000000?oakG8o`000?l000000oo:]LH01Ol0003obKG6olVea_o9]LKo0000
00;oaK7700?o0000olRba?l000000ol00002olF^``03o`000?o3[LCo`jg400;o00001Oo6[/<01?l0
003o`Z_3ol:[`ol00002olB/`@04o`000?o3Zl;o`j_2ol>[`PGo000000?o`ZRoo`000?nnY;l01?nn
Y;l00ol0003o_jFooknU_`02oknU_`05o`000?nlX[oo_::ookbR_ol000000_nmXkh00ol0003o_:>o
okbS_`03okbS_`03o`000?njW[co^Yjl00?o^Yjl00Co0000okZQ`?njXL3o00000onhW[d@o`000003
okBI_?l0003o000000go00001On_Ukl00ol0003o[IBmojfD_@02o`0000?o[9Jo00?o0000oj^D__n[
U;h00_n[U;h2o`000003oj^F`?l0003oZ9>o00GoZ9>o00Go0000ojJA_onVTKoo0000ojNC`@07o`00
00?oY97100Co0000oj:?`OnRSl7o00001?nRTL<00ol0003oX8o3oj2?``04oj2?``03o`000?nMS/?o
000000;o00000_nNTLH00ol0003oW936oib@aP04oib@aP03o`000?nJSlOoVXo700?oVXo70ol00002
oiR?b0Oo00000onGTL`00ol0003oUI;>o`000002o`0000;oUI;>00?o0000oi>Ed_nCUM801?nCUM80
0ol0003oU9GBoiBEdP02oiBEdP03o`000?nDV=Co000000CoTIOE3Ol00003oi:Th@03o`000?nBZNGo
TZWU00GoTZWU00?o0000oiR[i?nHZn@00_nHZn@00onG/NWo0000o`000004o`0000CoV;ga1?l00005
oic?n@;o00000onPi?`01_l0003o/N_hok7[n?najoSoSnoUo`0008kooo]Z00Go0000oookJ_oonf[o
oo]Zo`000002oookJP000_oonfX00ol0003ooo]ZoookJP0JoookJPCo000000?oD:Wio`000?l00000
1?l00005oi73n0Co00001?n[bNl00ol0003o^L_WokW;i`03okW;i`;o00000_ngbNP2o`0000?o`/SO
00?o0000ol78goo1b=l00oo1b=l2ol37h003o`000?o8amWob<OI00?o000000?oaLGJo`000?o4a=X0
0_o4a=X2o`0000?obL;C00?o0000olS1doo8`M<00_o8`M<01Ol0003oaL3Eo`000?o;_/ko000000Co
bl3@00Co0000olNmd?o7_M3oakg@0_l00002olblb`03o`000?o9^Lco000000?oakW<0_l00003ol^g
a`03o`000?o9]/OobKK700;obKK71?l000000oo:]LKo0000olVeaP02olVeaP03o`000?o5/LOoaK77
00;oaK7700?o0000olN``oo7/<<00_o7/<<4o`000003ol>]a?l0003oaZk300CoaZk300Oo0000ol:[
`oo2Zl?o`Z_3o`000?o4[<7o000000Co`j_200Go0000oknW`OnoYl7o0000ol:X`004o`0000;o_ZBo
0_l00003oknU_`03o`000?nlX[oo_::o00;o_::o00?o0000okfS__l000001_nlXkl00ol0003o^Yjl
okZN_002okZN_005o`000?njXL3o^Z70okZQ`?l000000_nhW[d00ol0003o^9nookRO_`03okRO_`03
o`000?nfW;go000000Go]Ybn0_l00006ok>J_P;o00001_naVKh2o`0000Oo[iNo0_l00006ojbF_`04
o`000?n[U;koZiBno`0000CoZiK000?o0000ojRC_onXTkl01?nXTkl4o`0000?oYY?100?o0000ojBA
`OnTTL400onTTL43o`0000KoXY7300Co0000oj2?`onPSl?oX8o31Ol00006oijAaP03o`000?nLT<Ko
W93600?oW93600?o0000oiZ?aonJSlL02?l00003oiVBb`03o`000?nGTLcoUi7<00CoUi7<0_l00006
oiFBcP03o`000?nCUM;oTiGB00CoTiGB0onDUM800onDV=Co0000o`000005o`0000?oUI_G00?o0000
oi>Mf_nCWMX00_l00002oi>MfP03o`000?nBY>7oTZCQ00CoTZCQ00?o0000oi:YiOnBZND00_nBZND2
o`000004oi:YiOl0003o0000oiR[i0;o00000_nG/>P00ol0003oV;gaoiRml@03o`0000?oV/Ge00?o
0000oic?nOnLcoT00ol00003oikHo0?o00000_najoP00on?knGoWOCUo`00002AoookJP04o`000?oo
nf[ooo]Zo`0000;ooo]Z0002oookJP03o`000?oonf[ooo]Z01cooo]Z3_l000001?n@`oSo0000oj_9
kon[bNl3o`0000?oZ/S`0_l00004okW:i`;o00000_ngbNP00ol0003o`/SOo`000003ol78g`03o`00
0?o0an3o`<OP00?o`<OP00?o0000olO6fOo7a]T00_o7a]T01Ol0003oa<CJolC4f_o4a=[o000000;o
`lCK00?o0000olW2dol000000oo8`M<01_l0003oal3DolO0e?o7`=CoaL3Eo`0000Cobl3@00Oo0000
olNmd?o7_M3oakg@o`000?o6_=7o000000?oc;c;0ol000001oo7^Lco0000olJhcOo6^<go0000ol^g
aol000000oo9]/L00ol0003obKW;olVib`02olVib`Co000000?obKG6o`000?o5/LL00oo5/LL2o`00
00?oak3300?o0000olJba_o6//H00_o6//H5o`000003olJ^`ol0003o`Z_300?o`Z_30_l00004ol>[
`P04o`000?noYl7o_jO1oknW`@;o00001?o1Y[h:o`0000?o_::o00?o0000okbS_onlXkl01?nlXkl2
okVP_`04o`000?njW[co^Yjlo`0000Go^Z700_l00006okRO_`;o00001_nfW;h00oneVkko/iZnok>J
_P04ok>J_P03o`000?ncV[ko/IVn00Ko/IVn00?o/IRno`000?n_Ukl01On_Ukl2o`0000Oo[9Jo00?o
0000oj^D__l000000_n[U/0;o`0000OoYY?100?o0000ojBA`Ol000000_l00002ojBC``03o`000?nR
TL?oXY7300?oXY731Ol00002oj2?``03oj2BaOl0003oWY7600KoWY7600?o0000oib@a_nLT<H01?nL
T<H4o`0000?oVi?;00?o0000oiVBbonIT//01?nIT//00ol0003oUi7<oiNAc003o`000003oiNBc?l0
003oUI;>00?oUI;>2_l000000onDUM;o0000o`000003oiBIe@03o`000?nEVmOoUI_G00GoUI_G0_l0
0005oi>MfP04o`000?nBY>7oTZCQoi:Th@;o000000?oTZCQo`000?l000000_l00003oiV[h`;o0000
0onG/>P5o`0000OoV/Ge0_l00002oikHo0?o00000_nOh_d3o`0000;oWOCU00?o0000oookJ_oonfX0
T?oonfX01?l0003ooo]ZoookJ_l00002oookJP0000?ooo]Zo`000?oonfX08?oonfX2o`0000?oC:Sh
1?l00005oi33n0;o00000onZb?02o`0000?oZLS`00?o0000okW:iol000000onhbNL01?l0003o]lWX
o`000?l00002ol78g`;o00001?o0an001_l0003o_lOPoko7h?l0003oalKIo`0000;oa/GI00?o0000
olC4f_l000000oo3a=/2o`0000?ob<7C00?o0000olO0e?o7`=@00oo7`=@3o`000003ol_0d?l0003o
akg@00;oakg@00Oo0000olJldOo6_=7oa[cAo`000?o<_<_o000000?ob[_<0ol00002olJhc@05o`00
0?o9]/OobKK7olVfaol000001_o9^L/00ol0003obKG6olVeaP03o`0000;oaK7700Ko0000ol>ab?o3
/LSo0000olN``ol00004olJbaP05o`000?o2[/Ko`Zk6o`000?o5[l<01?l00002ol:[``03o`000?o2
Zl?o000000?o`j_200Oo0000oknW`OnoYl7o_jO1o`000?nnYl?o000000Co`JJn00Oo0000ol2Y`oo0
ZL?o`:W3o`000?noY[oo000000?o_Z>n1ol00002okbS_`?o^J2o00?o0000okZN_?l000001OnjXL02
o`0000Ko^9no00?o0000okNM__l000001OnfW;h2okFK_P04o`000?ncV[ko/iZnok>J_P;o00000_nc
V[h00ol0003o/IVnok6I_P03ok6I_P;o/IRn00?o0000ojnG_on_Ukl00_n_Ukl2o`000003ojnG_ol0
003o[9Jo00;o[9Jo00?o0000ojbF_on/U[l01_l00003oj^F`@03o`000?nXTl3o000000;o00000onX
UL800ol0003oYY?1ojJC`@03ojJC`@?o00001_nTTl<00ol0003oXY73o`000002o`000004oj:A`ol0
003o0000oj2?``GoX9;500?o0000oijAa_nNTLH01?nNTLH01?l0003oW936oib@a_nLT<H4o`0000Oo
Vi?;00?o0000oiVBbonIT//00onIT//3o`0000;oUi;<1ol00003oiRFd003o`000?nEUm?oUIOC00?o
UIOC00?o0000oiBIeOnDVMD01OnDVMD00ol0003oUI_GoiFKe`03oiFKe`co00001?nDZN@00ol0003o
VJ_SoiV[h`02oiV[h`03oiR`j?l0003o000000?o00001?nH_?400ol0003oV/Geoi[5m@03o`0000;o
W<gi00Co0000oikHo?l0003o00000onOh_d2o`000005ojoYnOn<kNOoS>gWohc]iol00000U?oonfX0
1?l0003ooo]ZoookJ_l00001oookJP0000?ooo]Zo`000?oonfX08_oonfX9o`0000CoSl?h00Co0000
oj[8l?l0003o00001_nYb?000ol0003o^<WWokS9i`03okS9i`;o000000?o]/SXo`000?l000001?o0
an000ol0003o_lOPoko7h003oko7h003o`000?o6aMWoa/GI00;oa/GI0ol000001oo3a=_o0000ol73
foo1`m_o0000olS1dol000001?o7`=@01Ol0003oal?FolO3e_l0003obl7A00?o000000?oakg@o`00
0?o6_=400oo6_=42o`0000?ob[_<00Co0000olRic?o8^Lcob;W<1?l000000oo9]/Oo0000olVib`05
olVib`;oaKG;00?o0000olVea_l000000_o7/lH4o`0000;o`k7800?o0000olJba_o6//H00_o6//H0
0ol0003o`Zk6ol:^aP02ol:^aP03o`000?o4[<;oa:c200;oa:c21_l000000oo3Zl;o0000oknW`@02
oknW`@05o`000?nnYl?o_ZO3okjW`ol000000_o1Y[h00ol0003o`:W3ol2Y``02ol2Y``;o00001?nn
Xkh01Ol0003o_JO3okfW`onmYl?o000000;o_:?03ol00005okRO_`05o`000?ngWKko]ifnokNM__l0
00000onfW;h4okFK_P;o/iZn00?o0000ok>J__ncV[h00oncV[h01?l0003o/IVnok6I__naVKh4ok6H
_P04o`000?n_Ukoo0000ojnG_`Wo00000on/V<800ol0003oZiK1oj^F`@04oj^F`@;o00001_nXUL80
1?l0003oYY?1ojJC`OnVTl42o`000003ojNE`ol0003oY9?300?oY9?31Ol000000onRTL?o0000o`00
0002oj:Ca@03o`000?nPT/GoX9;500CoX9;500?o0000oijAa_nNTLH00_nNTLH6o`0000CoW9?900?o
0000oi^CbonKTl/01?nKTl/00ol0003oVI;;oiVBb`08o`0000?oV9K@00?o0000oiRFd?nHU]001?nH
U]02o`0000GoUIOC00?o0000oiBIeOnDVMD00_nDVMD8o`000003oiFOfol0003oU:GQ00KoU:GQ00?o
0000oiBYi?nDZN@01OnDZN@2o`000003oiV[hol0003o000000;oV;3X00?o0000oiRllOnH_?401OnH
_?42o`0000KoW<gi00?o0000oioRoOnOh_d00_l000000on_jOWo0000o`000003ohc]iiOooo]Z00?o
0000oookJ_l000000OoonfX00003oookJ_l0003ooo]Z01kooo]Z1?l00002oookJP04o`000?m7Y_Oo
AjKgodNVm`;o00001_n?`oP00ol0003oZLS`ojW8l002ojW8l0;o00000onXb?001?l0003o^<WWo`00
0?l00003okO9j0;o000000?o]<SYo`000?o0an000_l00004oko7h006o`000?nob>;o_lSRo`000?o6
aMWo00001?o5a=X3o`000003ol73fol0003o000000?oal3D0_l00003olO3eP;o00000oo:_m02o`00
00?oa[cA00Ko0000olFld_o5_=;o0000olZkc?l00003olRic004o`000?o8_<oob;c?olRlc`?o0000
1Oo9^L/3olFeb`;o00000oo7/lH01?l0003oakG9olNebOo7]LT3o`0000?oa[;600?o0000ol:^a_o2
[/H00_o2[/H2o`0000Coa:c200?o0000ol>_a_o3[lH00_o3[lH9o`000004okjW`ol0003o`JJno`00
00Co`:W300?o0000okbU`_l000000onnXkh00ol0003o_JO3okfW``03okfW``;o00001?nlY<400ol0
003o^J71o`000004okZR`004o`000?niX/;o^J;2okVR`Q_o000000?o/IVno`000?l000001_l00005
ojjI`@03o`000?n/U/3o000000Go[9S200Co0000oj^F`On[U/7oZiK10ol000000on[V<?o0000ojRE
`P05ojRE`P05o`000?nVTl7oYY?1o`000?nWUL<01ol00002ojBC``?o00001_nRTlD00ol0003oX9;5
oj2Ba@04oj2Ba@Co000000CoWY?8oinDb?nOU<So00001_nLTlT00ol0003oVi?;oi^Cb`02oi^Cb`Go
00001?nIULh00ol0003oV9K@oiRFd005oiRFd004o`000?nHU]3oV9K@oiRFd0;o000000?oV9SBo`00
0?nEUm<00_nEUm<7o`0000?oUigH00?o0000oiFOfol000001?nEWm/00ol0003oU:GQoiBUh@02oiBU
h@;o000000?oU:GQo`000?l000000_l00003oiZ/h`03o`000?nH/>SoV;3X00?oV;3X1_l00005oi_4
m0?o00001OnMeo`2o`000004ojoYnOl0003oS>gWohc]i`;o0000VOoonfX2o`00007ooo]Z00000ooo
nf[o0000oookJP0KoookJP?o00001ooonfX2o`000003od:Tm_m7Y_Oo000000?o00001On>`_T2o`00
00OoZ<S`00?o0000okO9j?ngbNP00_l00003okK8j003o`000?ndb>Wo000000Co_lOP0_l00003oko8
hP;o00000oo5a=X00ol0003o`lCJol?4fP02ol?4fP;o000000Co`<;Lo`000?o7`=Co00001?o7`mH0
1_l0003o`koFol>oe_l0003ob[o@o`0000;ob;k@00?o0000olJldOl000001?o5_=801Ol0003ob;W<
olRic?o8^Lco000000?ob;c?00Co0000olBhcol0003ob;W;0_l00002olVib`?oaKG;00Ko0000ol>d
c?o3]<co0000olNca_l00004olNeb@03o`000?o3/LWo`k7900Go00000_o2[/H01?l0003o`Jk7ol6^
aol00002olB/`P03o`000?o3[lKo`jo600?o`jo600Go0000ol>Z`Oo3Z/7o`j[1o`000004ol6/a@Go
00000_o0ZL<01ol0003o_:G2okbU`_nlYL;o0000okjS__l000001OnmYl<2o`0000Co_:C100Go0000
okVQ`OniXL7o^J71o`000002okZR`003o`000?niX/;o^J;200;o^J;200?o0000okRO_ol000001_ng
X<400ol0003o]I^nokFK_P05okFK_P03o`000?ncV[ko/iZn00Co/iZn00?o0000ok:M`ol000001ona
VKh00ol0003o[YW1ojjI`@04ojjI`@;o00001on/V<800ol0003oZiK1o`000005oj^H``03o`000?nX
UL;oZ9G200?oZ9G21Ol00003ojJEa004o`000?nTTl?oY9?3ojBC``;o000000?oYIG5oj:CaOnRTlD0
1_nRTlD00ol0003oX9;5oj2Ba@05o`000003oijCb?nOU<SoWiC800?oWiC800?o0000oibCbOnLTlT0
0onLTlT6o`0000;oViG=0_l00006oiVEcP03o`000?nHU]3oV9K@00CoV9K@00?o0000oiRFd?nHU]00
2?l00003oiJMf003o`000?nGWMSoUigH00CoUigH0_l00003oiFOf`Oo00000onFZ^@00ol0003oVZcS
oiZ/h`03oiZ/h`04oiZaj?l0003oV;3XoiR`j0?o00000onI_?000ol0003oVlCdoi_4m003o`0000;o
W<gh00?o0000oigGo?nMeo`00ol00002oigQo@Co000000?oONK=o`000?oonfX0VOoonfX3o`00007o
oo]Z00000ooonf[o0000oookJP0GoookJPCo00003?oonfX01?l0003o>j;eoc^RmOm2Y?H4o`0000Go
S<;i00?o0000ojS8l?nXb?000ol00003ojO7l003o`000?nfb>So]/SX00Co]/SX0_l000001?ncanWo
0000oko7h?l00003oko8hP;o00000_nlaN800ol0003oaLCJo`000003ol?4fP07o`000?o2`m[o`/?J
ol;3f_l0003o`<;Lo`000004olO3eP04o`000?o3_mKo`koFol>oeP;o00001?o8_]03o`0000;oaKcB
00Go0000ol>kd_l0003ob;W<o`000003olRlc`06o`000?o4^<ooa;S?olBhcol0003ob;W;1?l00000
0oo5]L_o0000ol>dc003ol>dc003o`000?o7]LWoakG900;oakG900?o0000ol>abOo3/LT00_o3/LT0
1?l0003oaK35olF`aOo5/<D4o`000004ol6^aol0003oa:c2o`0000Go`jo60_noZlD00ol0003o`j[1
o`000005ol6/a@03o`000?nmZ<Co000000;o`:W31Ol00002okbU`P03o`000?nmYl?o_JO300?o_JO3
00?o0000okbT`Ol000000onlY<400ol0003o^J71okVQ`@02okVQ`@03o`000?njX/3o000000Go^J;2
0_l00006okNP`@03okBM`Ol0003o]I^n00Co]I^n00?o0000okBO`ol000001?ncV[h2o`0000;o/Yg3
00?o0000ok6I__naVKh00_naVKh2o`000003ok6L`_n^VL7o[YW100Co[YW100?o0000ojjI`Ol00000
1_n/V<82o`0000CoZiS32Ol000000onXUlCo0000ojJEa005ojJEa0?o00001OnUULD7oj:Ca@?o0000
00GoXIG8o`000?l0003oXIG8o`000007oinDb003o`000?nLTlWo000000;o00000_nMU/`01?l0003o
ViG=oi^EcOnKULd2o`000003oi^EcOl0003oVIG>00GoVIG>00?o0000oiRFd?nHU]000_nHU]04o`00
00GoV9[D00?o0000oiJMf?nFWMP01OnFWMP01?l0003oUigHoiNMf?nGWMP7o`0000?oUZOQ00?o0000
oiJZi?nFZ^@01OnFZ^@01Ol0003oVZcSoiZ/honJ[>?oV[7X00Co00001onI_?02o`0000KoW<gh0_l0
0002oigQo@;o00000on/j?T2ohW/iiSooo]Z1?l00004oookJP0000?ooo]Zo`000?oonfX05?oonfX3
o`0001;ooo]Z0_l000000olkX_Go0000o`000007ohc2n@;o00000_nWao03o`0000;oYLOa00?o0000
okK8j?l000000_l00004okG7j0;o00000onob>800ol0003o_<GRokc5hP02okc5hP;o00000oo3a=X0
0ol0003o`/?Jol;3fP03ol;3fP?o00000_o7`mH3ol>oeP;o00000_o2_mL00ol0003ob;k@o`000004
olNmd@Co000000?o`k_Bo`000?o8_<l00_o8_<l00ol0003oa;S?olBhc`02olBhc`;o00001?o7]lX3
o`0000;o`kC<0_l00003olNeb@03o`000?o3/LWo`k7900;o`k790_l00003olF`a@04o`000?o4//So
a;;8olBbb0Ko00000_o3[lH4okn[a@03o`000?o1[<Go`Jc500?o`Jc500Co0000okfXa?nmZ<Co_JS4
0_l00005oknYa0[o000000Co_:C1o`000?nlY<7o00001OniXL42o`0000Go^J;200?o0000okRP`Ol0
00001OngX<43okBM`@03o`000?neVkko]I^n00;o00000ondWl<01?l0003o/iZnok>J__l00005ok:M
``04o`000?naVKko/IVno`0000?o/Ic200?o0000ojjI`On^VL400_n^VL401Ol0003o[YW1ojjI`On^
VL7o000000Co[9S21ol00002ojZH``?o00001OnXUl@01?l0003oYYG4ojJEa?nVUL@3o`000003ojNG
a_l0003oYIG500GoYIG500Co0000oj:CaOnRTlGoXY?51_l00005oj6Eb004o`000?nOU<SoWiC8oinD
b0Go00001?nMU/`4o`0000GoViG=00Co0000oiVEc_nIULkoVIG>1ol00003oiVIdP03o`000?nHV]Co
V9[D00CoV9[D00?o0000oiJMf?nFWMP00_nFWMP2o`000003oiJMf?l0003oUigH00;o00000_nGXM/0
0ol0003oUZOQoiJWh@05oiJWh@03o`000?nFZ^CoUZ[T00;oUZ[T0_l000000onFZ^Co0000oiZ/h`02
o`0000?oVK7X00?o0000oiVll?nI_?000ol00002oi_4m003o`000?nLcOSoW<gh00?o00001?nMeo`0
1?l0003oY>?ko`000?n/j?T2ohW/i`03ogORbol0003ooo]Z09Cooo]Z1?l00008oookJP0000?ooo]Z
o`000?oonfX04?oonfX4o`0001Kooo]Z2?l00005oh[1n@;o00001_nUao400ol0003o]LOXokG7j002
okG7j0;o00000_ncanT4o`0000?o_<GR0_l00002ok[5hP03o`000?o3a=[o000000Co`/?J00?o0000
ol32foo0`]/00_o0`]/3o`000003ol>oe_l0003o`[oG00?o`[oG0_l00003olNmd@;o00001?o5_=42
o`0000;ob;c?00?o0000olBhcoo4^<l00_o4^<l01_l0003o`kS@ol>hd?l0003oakO:o`0000CoaKG:
1Ol000000oo7]LWo0000ol>ab@03ol>ab@06o`000?o1/L[o`K7:o`000?o5/<Go00001?o4//P01?l0
003o`:k8ol2^b?l00002ol>_aP?o00000_noZlD2o`0000Co`Jc500?o0000okfXa?nmZ<@00_nmZ<@0
0ol0003o_jW4oknYa003oknYa004o`000?nkY/Co^jK4o`0000?o_JO300Co0000okbWa?nlYlCo_:O4
3_l000000oniX/;o0000okRP`@02okRP`@04o`000?ngX<7o]j31okNP`@Co]9g100?o0000okFK__l0
00001OndWl<00ol0003o/iZno`000006ok:M``?o00001OnaW<85ojjI`@Wo00000_n/V/@00ol0003o
ZYS3ojZH``02ojZH``03o`000?nZVLGo000000OoZ9O400?o0000ojJEa?l000001OnWUlH01?l0003o
YIG5ojFEaOnUULD7o`0000?oXiO800?o0000oj6Eb?nQULP00onQULP5o`0000?oWiO;00?o0000oifF
c?nMU/`00ol00002oifFc004o`000?nKULgoViG=oi^Ec@Oo00000onJV=02o`0000KoVIWB00Co0000
oiRJe?nHV]CoV9[D1ol00003oiROf@03o`000?nGXM_oUj7K00CoUj7K00?o0000oiJWhOnFYn400_nF
Yn42o`000003oiJWhOl0003o000000;o00000_nI[>@00onI[NCo0000oiVaj003oiVaj0Go00001_nK
a?@2o`0000?oWMOl0_l00003oicQo@03o`000?n9k>Oo000000;oMn;;00?o0000oookJ_oonfX0T?oo
nfX4o`0000cooo]Z00000ooonf[o0000oookJP0=oookJP?o00007?oonfX01?l0003o:Y[_obZJkolc
W_84o`0000CoQl3j00?o0000ojG7lOnUao400ol00002ojC7lP04o`000?neanSo0000o`0000Ko/lOY
00Go0000okk8h_l0003o_<GRo`000004ok[5hP;o00000_o2`mX2o`0000Co`<;K00Go0000oko2g?no
`]co0000olK2eP02o`0000?o`[oG00Ko0000ol6nf?o1_]So0000olNmdOl00004olFld@04o`000?o5
_mCoaKoDolFoe0Co00000_o4^<l00ol0003o`kS@ol>hd002ol>hd003o`000?o5]L[oaKG:00;oaKG:
00?o0000olFic_o5^Lh00_o5^Lh4o`0000;o`k7900?o0000ol6ab_o1/LX00_o1/LX00ol0003oa;;8
olBbb002olBbb003o`000?o0[/So`:k800;o`:k80_l00003ol:]a@Go00000_o1[<D00ol0003o_JS4
okfXa003okfXa003o`000?noZLCo_jW400;o_jW400?o0000ok^Va?nkY/@00_nkY/@00ol0003o_JO3
o`000005okbWa003okVTa?l0003o^j?100?o^j?100Go0000okZVaOnjY/Go^ZK5o`000002okVS`QOo
00001onbWL<9o`000004ojjI`Ol0003o0000o`0000?o[YW200?o0000ojbH`_l000001_n/V/@00ol0
003oZYS3o`000004ojZIa@03o`000?nXUlCoZ9O400CoZ9O400?o0000ojNGa_nWUlH00onWUlH6o`00
00;oY9G600?oYIO8o`000?nSUlP01_nSUlP00ol0003oXIG8o`000002o`0000;oXIS;00Co0000oinG
bonOUl_oWiO;1Ol00003oifFc0Ko00001?nLV<l00ol0003oVYS@oiZHd003o`000003oi^Id?l0003o
VIWB00;oVIWB1ol00003oiZNeP03o`000?nHWmWoV9oI00GoV9oI00Co0000oiNQfonGXM_oUj7K1ol0
0003oi^Yh@05o`000?nI[>CoVJcToiV/i?nI[N@01ol00004oiZml003o`000?nKa?CoVlCd00?o0000
0onLcOT2o`0000;oW>7m0_l00003ojWYnP03oh?Yi?m^g/Ko000008oooo]Z1Ol0000@oookJP0000?o
oo]Zo`000?oonfX02OoonfX4o`00023ooo]Z0ol000000olZV^oo0000o`000006ohO0nP;o00001_nT
ao800ol0003o/lOYok?7j@02ok?7j@;o00001?nbanT3o`000004ok[5h_l0003o0000o`0000;o^LGS
0_l00004ol32f`03o`000?no`]co_l;L00?o_l;L00Ko0000olG1eoo5`MOo0000ol:oeol00004ol6n
f004o`000?o5_=7oaKcAolFld@;o00001?o5_m@2o`0000;oak_?0ol00003ol>hd0;o00000oo5]LX0
0ol0003oaKW>olFicP03olFicP04ol6dc_l0003oa[C9olJdb@Co00000_o1/LX2o`0000?oa;;800?o
0000ol2^b?o0[/P00_o0[/P2o`0000Co`Zg500Co0000ol6`bOo1/<Wo`K391_l00002okfXa003o`00
0?nnZLGo000000;o_jW400?o0000ok^Va?nkY/@00onkY/@2o`0000Go_:O40oniY<@01?l0003o^j?1
ok^S`Ol00005okZVa@;o00001OnhXl@2o`0000Go]Yk000?o0000okJRaOl000001OndWl<00ol0003o
/j75o`000005ok:M``04o`000?naWlGo/Io5o`0000Go/9c300?o0000ojnMaOl000001on^VL800ol0
003o[9[4ojbJa004ojbJa0;o00001_nZVLD01?l0003oZ9O4ojRGa?nXUl@2o`000004ojVJaol0003o
YiO6ojNGaP?o00000_nVUlH2o`000003ojBEa_nUUlSoYIO800?oYIO800?o0000oj>Gb?nSUlP01?nS
UlP2o`0000CoXIS;1Ol00003oinGb`Go00000onNVLh00ol0003oW9S?oibHc`03oibHc`Co00000_nK
VM06o`0000?oVYkF00?o0000oiZNe_nJW]H01?nJW]H2o`0000?oV9oI1ol00004oiRXh@03o`000?nK
ZN7oVjWQ00?oVjWQ1Ol00004oiZgk@03o`000?nJ_O3oV[g`00GoV[g`0_l00002oic=n@;o00001?nM
eo`01Ol0003oX^Clo`000?nYjO[oPnWT00?o0000SOoonfX4o`0001Gooo]Z00000ol0003ooo]Zoook
JP06oookJP?o00009_oonfX00ol0003o7iG[o`000004o`0000GoQ;oj0ol00005oj;6lP;o00001?nb
anT2o`0000;o/<KZ00Co0000okg8hol0003o00000oniaN<01Ol0003o]lCTokO4i?l0003o`<;K00;o
00001?no`]`01?l0003o_/;Mokk2gOl00002olG1e`?o00000_o1_]P01Ol0003o_kkIo`000?o5_=7o
000000GoaKoD00Ko0000ol6ke?o1^mCo0000olNkcol00002olFjc`03o`000?o3^=3o000000;o`KOA
00?o0000olFeb_l000001Oo5^Lh3ol6dcP;o00001?o4//T5o`000003olBbb?l0003o`:k800?o`:k8
00?o0000okn^bOl000000oo2[LD00ol0003o`K39ol6`b@03ol6`b@03o`000?o0ZlCo`:_400;o`:_4
2_l00002ok^Va003o`000?nlYlGo000000Co_:O41?niY<@00ol0003o^j?1o`000005okZVa@;o0000
1OnhXl@00ol0003o]Z74o`000004okJN`005o`000?nfX/Go]Z;5okJRaOl000000_ndWl<2o`0000?o
/j7500?o0000ok:M`onbWL<00_l00003ok6Oa@03o`000?n`W<?o/9c300;o/9c30on_WLD01?l0003o
[YW2ojjI`_n^VL83o`000003ojnMaOn/V/Co[9[400?o[9[40_l000000on/V/Go0000ojZIa@05ojZI
a@05o`000?nXUlCo0000o`000?nYV/L01Ol00003ojJGaP;o000000?oYYW9o`000?nUUlP01OnUUlP0
0ol0003oXiO8oj>Gb003o`000004oj>Ibol0003oXIS;oj6Hb`?o00000_nQV</00ol0003oWiO;oinG
b`03o`000003oj2Jc_l0003oWYW>00KoWYW>00?o0000oibHcol000000_l000000onMVLoo0000o`00
0003o`0000?oW9gE00?o0000oiZNe_nJW]H01?nJW]H01?l0003oVYkFoiZNe_nJW]H7o`0000?oVJKO
00?o0000oiRXhOnHZ>401_nHZ>44o`0000?oVZoU00?o0000oiZgkOnJ]nd01OnJ]nd4o`0000CoW<Ge
0_l00003oigGo0?o00000_nKhOd2o`000004oh?Yi?l0003oK]k6o`0008[ooo]Z1?l0000IoookJP00
00?o0000oookJ_oonfX00_oonfX4o`0002_ooo]Z00Co0000obNFk_l0003o7iG[0ol00004ogBno@03
o`000?nRa_;oX/Kb00?o00000onOa_<01?l0003o//OYo`000?l00005ok36jP06o`000?nkan?o^lOS
o`000?niaN?o00000onga>@2o`0000Co_l;L00?o0000okk2gOnn`]d00onn`]d00ol0003o`l3Gol?0
e`02ol?0e`Co000000?o_kkIo`000?o5_m@01?o5_m@01?l0003o`K_Dol6ke?o1^m@2o`0000CoaK[?
0ol00002ol6gd@03o`000?o5^LkoaKW>00?oaKW>1?o1]<h00ol0003oa;;9olBbb@02olBbb@03o`00
0?o3]/go`kK=00;o`kK=1?l00002ol2^b007o`000?no[/Wo_jk9okn^bOl0003o`Zg5o`000005ol6`
b@;o_Jc800Co0000ol2[a?o0ZlCo00001Ono[LP00ol0003o_ZS4okjXa002okjXa0Ko00000_nlYl@5
okVTa0;o00001OnjY/D00ol0003o^J?4o`000004okRSa005o`000?nfXLCo]Z74okJQa?l000000_nf
W/000ol0003o]Z;5okJRa@02okJRa@03o`000?ndWl?o000000Go/j7500?o0000ok:M`ol000001_na
WlD00ol0003o/9c3o`000005ojnMa@?o00001On_WLD3ojbJa003o`000?n/V/Go[9[500;o[9[500Co
0000ojZIaOnZVLGoZYW50_l000000onZVLGo0000o`000002o`0000?oZ9[700Co0000ojJGa_nVUlKo
00001?nVVLT00ol0003oYIO8ojFGb003ojFGb004o`000?nUUlSo0000o`0000;oXiW;1Ol00004oj6H
b`Co00001OnPV/h00ol0003oWYW>oijIcP04oijIcP;o000000?oWIW?o`000?l000000_nMWM<00ol0
003oW9gEoibMe@05oibMe@04o`000?nJW]KoVYkFoiZNeP;o000000?oVYkFo`000?l000000ol00002
oiZRfP03o`000?nIY]ooVJKO00CoVJKO00?o0000oiRXhOnHZ>400ol00002oib/hP03o`000?nJ[^Go
000000?oVZoU1_l00003oi^ol@03o`000?nLaOGoW<Ge00?o00000onMcoT01?l0003oWMOlo`000?l0
0003oi_Qo@06o`000?nVj_[oY^[jojKZn_l0003oO>C4R?oonfX4o`0001gooo]Z00000ol0003ooo]Z
o`000002o`00037ooo]Z0_l0MM45o`0000?oM;km0_l00007oio6l`03o`000?n`a^[o/<KZ00;o/<KZ
0_l00002ojo6j`03o`000?nkan?o^lOS00?o000000Ko]lCTo`000?nea>Go]LCUo`000?no`]`2o`00
00Co_/;M00Go0000okg5hOnmaN7o0000ol?0e`02o`0000Co`KoH0ol00003olFoe0Co`K_D00Ko0000
oknke_no^mKo0000olFjcol00004ol>hc`Go00000_o5^Lh4ol6dcP;o00000oo4//T00ol0003o`kK=
ol>fc@03ol>fc@04oknbcOl0003o`k78ol>ab0Go00000_no[/T00ol0003o`K39ol6`b@03ol6`b@?o
_Jc800?o0000ol2[a?l000001Ono[LP00onkZ/So0000okjXa002okjXa003o`000?nmZlSo_J_800?o
_J_83?l00002okZVa@05o`000?niXlCo^J?4okVSa?l000000_nhXl@5okJQa003o`000?nfW/3o0000
00Go]Z;50_l00006ok>Qa@;o00001_naWlD2o`0000Ko[ig50_l00004ojnMa@Co000000?o[9[4o`00
0?l000002_l000000onZVlSo0000ojRJa`05ojRJa`;o00001onVVLT00ol0003oYIO8o`000002o`00
0003ojFKbol0003o000000?o00000onSVL/00ol0003oXIS;oj6Hb`03o`0000;oXY[=00?o0000oj2J
c_nPV/h01?nPV/h01?l0003oWYW>oijIc_nNVLh5o`0000KoWIgC00Co0000oibMeOnLWMGoW9gE0_l0
00000onLWMGo0000o`000002o`0000;oVj7H00?oVj7Io`000?nJX]X01_nJX]X01?l0003oVJKOoiVV
gonIY]l2o`000003oiVVgol0003o000000GoW:cR0_l000001?nJ[nGo0000o`000?l00003oi^ik@03
o`000?nK_o7oVkoa00CoVkoa0_l00007oig?n@03o`000?nKhOgoVn7m00;o00000onVj_X00omli<Co
oo]ZoookJP25oookJPCo00008OoonfX000;o0000=ooonfX2o`1ed@03o`000?mX^_go000000?oNKom
00?o0000oio6lonOa_<00ol00003oig5m004o`000?n`a^[o0000o`0000Go[lK[00?o0000ok[6i?nj
a^@00_nja^@3o`000003okG4iOl0003o000000Co_/;M0_l00003okg5h@;o00000oo1_mP2o`0000Co
_kkH0ol00003ol6ke004o`000?no^mKo_k_FoknkeP;o00001?o3^<l01?l0003o`kcDol>le?o3_=@5
o`0000;o`KC>00Ko0000okndcono]<oo0000olBbbOl00005ol>fc@?o_k;=00?o0000ol>ab?l00000
1?o1[lP5o`0000;o`K391?nm[<P2o`0000Go_jg80onkZ/P00ol0003o_ZS4o`000006okf[b003o`00
0?nkY/Co^jK400;o^jK400Go0000okZYb?njZLSo^ZW8o`000002okZVaA?o00000_nfX/D00ol0003o
]J74o`000005ok>Qa@03o`000?ncWlCo000000;o/Io500?o0000ok6OaOnaWlD01_l00002ojnMa@Oo
00000_n^WLH2o`0000So[9_50_l00005ojZKb003o`000?nXV/OoZ9[700?o000000?oZIc9o`000?nV
VLT01OnVVLT3o`0000;oYI_;0_l00002ojFKb`03o`000?nSVL_oXiW;00?oXiW;0ol00005oj:Jc@03
o`000?nPV/koX9[>00?oX9[>00?o0000oj2Jc_l000000_l00003oijMdP03o`000?nMWM?oWIgC00Ko
WIgC0ol00003oibPe`04o`000?nKXMSoVj7Hoi^Qf0CoVj7I00Co0000oiZRf_nJX][oVZ;J1ol00004
oiZ[hP03o`000?nL[>;oW:cR00;oW:cR1?l00007oi^ik@?o00001OnLaoH4o`0000CoW=Wl0_l00000
1?nVj_[o0000o`000?l00025oookJPCo00009OoonfX000;ooo]Z00?o0000oookJ_oonfX0=OoonfX0
0ol0003o1hKOo`000007o`0000OoWLGd00Co0000ojo6jon_a^_o[lK[0ol00002ojg6k003o`000?nj
a^Co000000Co^<KU0_l00002ok?4iP03o`000?nn`]go000000Co_LGQ00Ko0000okW1h?ni`N3o0000
ol6of?l00004oknnf008o`000?nn_m[o_[oJo`000?o4_mGo0000ol6ke?l00003oknkeP03o`000?nn
^mOo000000?o`kS?00?o0000ol>le?o3_=@00_o3_=@00ono^=?o0000olBgcP02olBgcPCo00000_no
]<l00ol0003o`kK=ol>fc@03ol>fc@Co_k;=0_l00004ol6_b006o`000?o0/lgo`;?=ol2ccOl0003o
`K392?l00004okn]b0Co^j[80_l00006okf[b0;o^JS700Co0000ok^Va?nkY/Co00001OnjZLP2o`00
00Go^J?300?o0000okRXbOl000000onhX/<01Ol0003o]ZK8okJVb?nfY/So000000?o]J?64?l00005
ok6Na@04o`000?n_W/Go[ik5o`0000Co[io700?o0000ojjMa_n^WLH00_n^WLH00ol0003o[Ik8o`00
0004ojbKa@?o000000?o[Ik9ojZKb?nZVlP01OnZVlP3o`0000GoZIc900?o0000ojJIbOnVVLT01ol0
0006ojFKb`03o`000?nSVL_o000000;o000000?oXic=o`000?nRV/d01_nRV/d00ol0003oX9[>o`00
0002o`0000;oX9gA00?o0000oijMd_nNWM801?nNWM800ol0003oWIgCoifMd`03o`0000;oWZ3F00?o
0000oibPeonLX=L00onLX=L2o`0000CoVj7I1_l00004oi^Yh003o`000?nJZn;oVZ_R00GoVZ_R0_l0
00000onL[>;o0000oibai`02oibai`03o`000?nK^NgoVkW]00?o00000_nL`O800ol0003oW<Ofoic7
mP03o`0000?oWM7j00?o0000oicIo?nLfO`01Ol00002oj;[nP;o0000P_oonfX4o`0002Wooo]Z0003
oookJP;o0000>?oonfX3o`000003oengo?l0003o000000Go00001OnJaOD2o`0000Ko[LK/00?o0000
okS6iOnha^D00_l00003okK5i@04o`000?nca>Ko/lCVo`0000?o_LGQ0_l00003okW1h0;o00000ono
_]P2o`0000Co_[oJ1Ol000000ono^mKo0000okjke`02okjke`03o`000?o3^<oo000000Co`kcD0ono
^=<00ol0003oa;O>o`000004ol:fcPCo00000oo3]/d4oknbc@03o`000?nm//ko000000;o`Jo80_l0
0004ol2cc@;o00001?o0[/P01?l0003o_k7<oknac?no/L`5o`0000;o^j[800Co0000okb[b?nlZlSo
00001?nmZlP3okVXa`03o`000?nkY/Co000000Go^ZW80_l00004okVS``;o00000_nhZ<T01?l0003o
^:;3okRR`ol00005okJVb0?o00001OneY<L00ol0003o/j75o`000006ok>Pa003o`000?naW/Go/Ik5
00Go/Ik50_l00006ojnOa`03o`000?n^WLKo000000Co[Ik800Co0000ojbKaOl0003o00001?n]W/T0
0ol0003oZY_8ojZKb002ojZKb0;o000000?oZYg9o`000?nYW<T00onYW<T5o`0000GoYic;00?o0000
ojFKbonUVl/00onUVl/4o`0000GoXic=00Co0000oj:JcOnRV/goXY[=0_l000000onRV/go0000o`00
0006oj2Md@04o`000?nNWM;oWYgBoijMdPGo00001_nNX=H00ol0003oW:3Go`000008o`0000?oW:ON
00?o0000oi^Yh?nKZN001OnKZN04o`0000;oW:kT0_l00004oibai`Go00001_nL`O82o`0000OoWM7j
0_l00002oiWRo@03o`000?nRjo[oX^_j00;o0000P?oonfX4o`0002gooo]Z0005oookJP03o`000?oo
nf[ooo]Z03Oooo]Z0_l00002oeFcn`03o`000?m__?goKkcm00Co00001?nFa?L00ol0003o[LK/ojg6
k003o`0000?oZ/K^00?o0000okK5iOnfaND01OnfaND3o`0000;o_LGQ0oni`N02o`0000;o]l7R00?o
0000oknnf?l000001?nn_mX00ol0003o_KoKo`000004ol:neP?o00000_nn^mL2o`0000Co`kcD1?no
^=<2o`0000?o`[K>0_l00004ol2dc`Co00000_no//d01?l0003o_K;>okfbc_nm//h2o`0000Go`;?=
00?o0000okb_cOl000000oo0[/P00ol0003o_k7<oknac002oknac0;o00000onn[<L7o`0000;o_J_8
1?niZ<L2o`0000Go^ZW800Co0000okNVb?ngY/So00000_niXl<00ol0003o^:S9okRXb@03okRXb@;o
00001OnfY/P2o`0000Oo]JC70_l00004ok>Pa0;o000000?o/ZC:o`000?naW/D01_naW/D00ol0003o
[io7ojnOa`04ojnOa`;o00001_n]W/P2o`0000Oo[Ik90onZVlP00ol0003oZYg9o`000006o`0000;o
Z9c:0_l00007ojNLb`03o`000?nUVl_o000000;o00000_nUWLh00ol0003oXic=oj>Lc@04oj>Lc@Co
00001?nRW]400ol0003oX9gAoj2Md@03oj2Md@Go00000onOX=@00ol0003oWZ3FoijPeP04oijPeP?o
000000?oWJ3Go`000?l000000_nMY]`00ol0003oW:ONoibWgP05oibWgP03o`000?nKZN3o000000;o
00000_nN[>401?l0003oW:kToib^i?nL[^@2o`000003oib^i?l0003o000000?o00001?nL_>l00ol0
003oW<7boic1lP03o`0000;oWL[g00?o0000oigAn_nMdOX00ol00003oi_Ko@;o000000CoX^_jo`00
0?l0003o0000O_oonfX4o`00037ooo]Z0006oookJP03o`000?oonf[ooo]Z03Oooo]Z0ol000001_m9
[oWo0000o`000?l0003oJ;Wmo`0000KoU/Cg0_l00002oj[6kP?o00000_nXa^l00ol0003o]/GUokK5
i@03o`0000Co]<CV0ol000000oni`N3o0000okO1hP03okO1hP;o00000onn_mX2o`0000?o_KoK00?o
0000ol:ne_l000001?o0_=H5o`0000;o`kcD0ono^=<2o`0000;o_KSE00?o0000ol:fc_l000001?o0
]<l00ol0003o`;[Do`000003ol:ec@Co00000_nm//h2o`0000Co`;?=00Oo0000okb_cOnl[lgo_:o=
o`000?o0[/So000000Co_k7<00?o0000ok^]c?l000000onn[<L00ol0003o_:_8okb[b003okb[b0Wo
00001?njZLP01ol0003o]jK8okNVb?ngY/So0000okVS`ol000001_nhZ<T00ol0003o]ZK8okJVb003
okJVb003o`000?nfY<Oo000000Go]JC70_l000000onbX/Oo0000ok>Pa002ok>Pa003o`000?nbY<[o
/ZC:00;o/ZC:00Co0000ok6NaOnaW/Go/Ik50_l000000onbXlWo[io7ojnOa`03ojnOa`;o000000?o
[io7o`000?n]W/P01?n]W/P00ol0003o[Io8o`000004ojfNb@Co000000CoZY_8o`000?l0003o0000
0onZWLT01?l0003oZ9c:ojRLb_nXW<X2o`000003ojRMbol0003oYic;00KoYic;0_l00006ojFMcP03
o`000?nSW<goXic=00Go00001onRW]400ol0003oX9gAo`000002o`0000;oXJ7D00?o0000oinPe?nO
X=@01?nOX=@00ol0003oWZ3FoijPeP06o`0000KoWJKL00Co0000oibWg_nLYmkoW:ON0_l000000onL
Ymko0000o`000005oij/h@?o000000CoW:kTo`000?l0003o00000_nM^>`00ol0003oW;c_oiblk`05
oiblk`;o00001_nMb_L2o`0000;oVm_m1Ol000000onLkOOoI=W:o`00001koookJPGo0000=OoonfX0
00Oooo]Z0_l0000joookJPWo00001OnBa?P2o`0000KoZ<K_0_l00003okC4iP?o00000_naa>P00ol0
003o_LGQo`000002o`000003okO1h_l0003o000000;o]L7S00?o0000okjof_l000001_nm_m/01?l0
003o`;cFol2le_o0_=H2o`0000Co_[_G1?l000000ono^=?o0000okfhe@03okfhe@;o00001?o0]<l0
1ol0003o`;[Dol2je?o0^]Co0000ol:ecOl000001?o0/ld5o`0000;o`;?=1Onl[ld2o`0000Co_k7<
00Oo0000ok^]c?nk[Lco^jg<o`000?nn[<Oo000000Co_:_800?o0000okb`c_l000000onlZ/L00ol0
003o^jg<ok^]c002ok^]c0go00000onhZ<T2o`0000Co]ZK800Go0000okJTaonfY<Oo]ZC7o`000003
okFTa`03o`000?nbX/Oo/Z;700;o/Z;70ol00005ok:TbP04o`000?naW/Go0000o`0000Co/Z?90on_
WlL00ol0003o[io7o`00000@o`000003ojbOb_l0003oZYg900OoZYg90_l00005ojRMb`03o`000?nW
W<_oYic;00?o000000?oYio>o`000?nUWLh01?nUWLh4o`000003oj>LcOl0003o000000;oY:3A00?o
0000oj:NdOnRW]401?nRW]43o`0000KoXJ7D00?o0000oinPe?nOX=@00onOX=@4o`0000CoWjGJ00?o
0000oifVg?nMY]`01OnMY]`3o`0000CoWJcR00Co0000oij/hOnN[>7oWZcQ1_l00006oifhk0Co0000
1?nMa?<4o`0000GoW=Ck1?l000001?nLkOOo0000ofCIb_l0001ioookJPCo0000>_oonfX000Wooo]Z
00?o0000oookJ_oonfX0>OoonfX2o`0000;o>jSe1Ol00004ohg3n@03o`000?nXa^ooZ<K_00?o0000
0_nUaO001?l0003o]<CVo`000?l00006ok74j004o`000?nka>;o^lCRok_4hP;o00000one`N<2o`00
00Co_KoK0_l00002ok_3h003o`000?o0_=Ko000000Go_[_G00Go0000okflfOnm_=Wo0000ol:le003
o`0000;o_KSE00?o0000ok^heol000000oo0]<l00ol0003o`;[Dol2je002ol2je0;o00000oo0/ld2
o`0000Co_[;>2_l00003oknac0Go^jg<0_l00004okb[b007o`000?nl/<ko_;3>okb`c_l0003o_:[7
o`000005ok^]c0;o00001?niYlL01?l0003o^:c=okR/cOl00003okRXbAOo00001onbY<X9o`000004
ojnOaol0003o0000o`0000Co[j380_l00005ojfOb@04o`000?n[W/Wo0000o`0000Co[9o:00Co0000
ojZMbOnZWLWoZYg90ol000000onYXLko0000ojRMb`06ojRMb`;o00001OnWWlh00ol0003oYIg>o`00
0002o`000003ojFMc_nUX=3o000000OoY:3A00?o0000oj:NdOnRW]400ol000000onRXMCo0000oj6Q
e006oj6Qe0Ko000000?oX:GIo`000?nOYMX01_nOYMX4o`0000?oWZ_O00?o0000oif/h_nM[>801OnM
[>801?l0003oWZcQo`000?l00003oifbi`03o`000?nM^>coWKS/00?o00000onM`?000ol0003oWLCc
oig4l`03o`0000;oWLki00?o0000oicDnonLe?/00ol00003oiWNoP?o000000?oI=W:o`000?oonfX0
M_oonfX4o`0003kooo]Z000:oookJP;o0000>ooonfX01?l0003o:Z3^obZPk_lZX>h2o`0000KoSL?i
0_l00006ojG5l003o`000?naa>So/LCX00;o/LCX0_l00003ojo4j@03o`000?nka>;o000000;o^<CS
00?o0000okG1hol000000_nc`ND01?l0003o_KoKo`000?l00004ok_3h0;o00001?nn^mL00ol0003o
_KcIokflf@03okflf@04o`000?o0^mCo`;_Dol2ke0Co000000Co^kSGo`000?o0]<oo00000oo0^]@2
o`0000;o^kKD00?o0000ol2ccOl000001?nn//h00ol0003o_KSEo`000003oknbc@03o`000?nm/<go
_K3=00;o_K3=1Ol00002ok^]c0;o000000?o^Jk>o`000?nlZlP00_nlZlP00ol0003o_;3>okb`cP02
okb`cP;o00001Onk[L`00ol0003o]j[<o`000003okVWa`03o`000?nh[<go^:c=00;o^:c=00Co0000
okRXbOl0003o00001OngY/P00ol0003o]ZC7okJTa`05okJTa`03o`000?ndXlOo]:?700?o]:?700?o
0000ok>Wc?l000001OnbY<X01?l0003o/JK<ok6Vc?l00006ok2SbP03ok2Tc?l0003o[j3800?o[j38
0_l000000on^Y<go0000ojfOb@06ojfOb@03o`000?n/Wl[o[9o:00Co[9o:00Co0000ojZMbOl0003o
00001?nYXLh01?l0003oZ9g;ojRMbonXWL/3o`000003ojVRcol0003oYio>00;oYio>1Ol000000onU
WLkoYJ3@ojFPd003ojFPd003o`000?nTX=7oY:3A00?oY:3A00Co0000ojBPdOl0003o00001OnRXM@0
0ol0003oXJ7Doj6Qe006o`0000KoX:GI00?o0000oinUf_nOYMX00ol000000onOZ]ko0000oij[g`06
oij[g`03o`000?nM[>;o000000;o00000onN/>@01?l0003oWK;WoifbionM/^L5o`0000OoWL3`0_l0
0006oig>n@;o00000_nIg_h3o`000004oigWnol0003oL^7PofcNd7Gooo]Z1?l00012oookJP003?oo
nfX00ol0003ooo]ZoookJP0joookJP03o`000?lFUNGo:Z3^00Co00001On7`_X3o`0000GoXLGb0_l0
0007ojo4j@03o`000?nha>?o^<CS00;o^<CS0ol00002ok?1i@03o`000?nk`n3o^l?P00;o^l?P0_l0
0002okNnh004o`000?nn^mOo0000o`0000Co_KcI00Ko0000ok^lf_nk_=[o0000ol2ke?l00004okji
e@Go000000?o`;[Do`000?nk]]@00onk]]@2o`0000Co_[;>00Oo0000okfheOnm^=Go_KSEo`000?no
//go000000Go_K3=00?o0000okbfdol000000_nn/<`5o`000004okV^c_l0003o_:_8o`0000?o_;3>
0_l000000onj[Lco0000ok^]c003ok^]c007o`000?ngZ/co]j[<okNZc?l0003o^JO7o`000005okR/
c@;o00001OngY/P00ol0003o]Z_>o`000004okJTa`;o000000?o]JW=o`000?ndXlL00_ndXlL2o`00
00?o/jO<00?o0000ok:Tb_nbY<X00_l00004ok6Vc003o`000?n`Xl[o/:?:00Co/:C<00Go0000ojnP
b?n_X<So[j38o`000004ojjTc@04o`000?n]WlWo[Io9ojfOb@;o000000?o[:?>o`000?n/WlX01_n/
WlX00ol0003oZJ7>ojVQcP05ojVQcP?o000000?oZJ;?o`000?l000001Ol00002ojJOc`03o`000?nW
X]7o000000KoYJ3@00?o0000ojBPdOnTX=400ol00002ojBRe003o`000?nRXMCoXZ7D00GoXZ7D0ol0
0004oj6Uf003o`000?nPYMWoX:GI00;oX:GI1Ol00005oinZgP04o`000?nNZmooWZ_Ooij[g`;o0000
00?oWZ_Oo`000?l000001OnN/>@5o`0000CoW[c^00?o0000oig0l?nM`?000ol00002oig8mP03o`00
0?nMc_WoWLki00?o00000onKf?d5o`000003og;Qh?l0003o000007?ooo]Z1?l00016oookJP003Ooo
nfX2o`0003cooo]Z00Co0000obBIkOl0003o5YGU0ol00004ofjooP03o`000?nQaO;oXLGb00?o0000
0onMaO@00ol0003o[lCYojo4j@03o`0000?o[<C[0_l00004okK2i0Go000000?o^l?Po`000?ng_^00
0ong_^02o`0000Co_KcI00?o0000ok^lf_nk_=X00onk_=X01?l0003o_[WEokjieOnn^MD2o`0000?o
_;WG00?o0000oknjeOl000000_l00002ok^fe003o`000?nj]]Ko000000?o_[;>00?o0000okfheOnm
^=D00_nm^=D2o`0000Co_K3=0_l00003okbfd`;o00001Onl[/`:o`000004okZ]c?l0003o^jg<ok^]
c0Go]j[<0_l00004okR/c@;o000000?o]JW<o`000?ngY/P00_ngY/P2o`0000?o]Z_>00Co0000okJT
aol0003o00001?neZLd00ol0003o]:?7o`000005ok>Wc003o`000?nbY<[o000000Go/JK<0_l00007
ok2Tc0?o00001On^Y<d01?l0003o[Io9o`000?l00004ojbScP03o`000?n/Wl[o[9o:00?o000000?o
[:C?o`000?nYXLh00_nYXLh00ol0003oZJ7>ojVQcP05o`0000CoZ:;@00?o0000ojJOconVWll01OnW
X]400ol0003oYJ3@ojFPd004ojFPd0;o00001_nTX]@00ol0003oXZ7Do`000002o`0000;oXjKH00?o
0000oj6Uf?nQYMP00onQYMP6o`0000?oXJWM00?o0000oinZg_nOZ]h01OnOZ]h3o`0000?oWjoS0_l0
0002oij`i0?o00000_nO^N/00ol0003oW[c^oijlkP05oijlkP;o00001_nMb?H2o`0000;oVmSm2_l0
001aoookJPCo0000B_oonfX000oooo]Z00?o0000oookJ_oonfX0??oonfX00om<003o0000o`000003
o`0000?oK[on0_l00007oig5m0;o00000_n/a>/3o`0000;oZLC]00?o0000okK2i?l000000_l00004
ok?2i@Co000000?o]kkPo`000?l000000_nd_n801?l0003o_KcIo`000?l00004ok^lfP06o`000?ni
`^7o^L;Qo`000?nn^MGo00001_nl^ML01?l0003o_kSDoknhe?no^=@6o`000003okjbc_l0003o_KSE
00?o_KSE00?o0000okVde?l000000onm/<d00ol0003o_;KCokbfd`02okbfd`;o00001Onl[/`01_l0
003o^kCCok^ddol0003o^k3?o`0000Go^Zg<1_l00002okNZc003o`000?nh[<go000000?o^:c=00?o
0000okFYc?neZL`00_neZL`00ol0003o]jK8o`000005okJ[cP;o00001_neZLd2o`0000Ko/jO<0_l0
0004ok6Vc0;o000000?o/JG<o`000?n`Y<`01On`Y<`2o`0000Oo[ZC=0_l00007ojbScP;o00000_n/
Y<l8o`0000;oZZ?@00?o0000ojRRd?nXX]001?nXX]02o`0000OoYj;A00?o0000ojFPd?nUX=000ol0
00000onUY=Co0000ojBRe004ojBRe0Co00001_nSY]P00ol0003oXJGHo`000002o`0000;oXZWL00?o
0000oj6YgOnQZMd01OnQZMd4o`0000?oX:kQ00?o0000oin_honO[n<01ol00006oinij`Co00001OnN
a?<3o`0000GoW=;k0_l000001?nEhOgo0000o`000?l00002oiGZn@03oekFc?oonf[ooo]Z06kooo]Z
1?l0001>oookJP004?oonfX00ol0003ooo]ZoookJP0noookJP03of@00?l0003o000000Wo00001OnH
aOH2o`0000KoZLC]00?o0000ok?2iOnc`^D00_nc`^D2o`0000;o/<?W00?o0000ok_3h?nk`n000ol0
0002okBohP;o00001?nk_=X00ol0003o^L;QokW2h@02okW2h@;o00001Onl^ML01_l0003o^[[IokZj
fOl0003o_kSDo`0000Go_;OD1?l00002okfhe@07o`000?ni]=Co^KCDokVde?l0003o_K3=o`000004
okbfd`03o`000?nh/]?o000000?o_:k<0_l00003ok^dd`;o00001Onj[L`2o`000003okVbdol0003o
^Zg<00;o^Zg<2ol00003okFYc003o`000?nfZlko]Z_>00?o]Z_>00?o0000okFYcOl000001?neZLd2
o`000003okBWc?l0003o/jO<00;o/jO<0ol00002ok>Vc004o`000?naY/co/JK<ok6Vc0Co/JG<00Co
0000ok2Tc?n`Y<co/:C<0_l00002ok2Tc003o`000?n^Y<go[ZC=00;o[ZC=2?l00002ojbScPGo0000
0on[Y<l2o`0000KoZZ?@00?o0000ojRRd?nXX]000ol000000onXXm7o0000ojNRd@07ojNRd@;o0000
1OnUY=@01Ol0003oY:;Do`000?nTX]Co000000;oY:OH00?o0000oj>Vf?nSY]P01?nSY]P3o`0000Ko
XZWL00?o0000oj6YgOnQZMd00ol000000onQ[^7o0000oj2^h@05oj2^h@Go00001?nO]nT00ol0003o
WkW[oinij`03o`0000;oWl7a00?o0000oik4lonNa?<00ol00002oig>n@03o`000?nLd__oW=;k00?o
00000onHgOh2o`000003oiGZnOl0003o000006oooo]Z1?l0001BoookJP004OoonfX2o`00047ooo]Z
0_l00002odRbn003o`000?m/_Oko000000;oV<Gf0ol00003oi;4n003o`000?nYa>goZLC]00?o0000
0_nVaNl01?l0003o/l;Uo`000?l00005ok33i`03o`000?nh`^;o^<;R00;o^<;R0ol000000onb_nCo
0000ok^lfP02o`0000?o^L;Q0_l000000one_N3o0000okbie`02okbie`;o00001?nj^]T00ol0003o
_;ODokbge002okbge0;o00000_nj]mH00ol0003o_KWEo`000003o`0000;o^KCD0_l00004okbfd`07
o`000?nh/]?o^;;CokRbdol0003o_:k<o`000004ok^dd`03o`000?ng/=;o000000Co^Zg<00?o0000
okVbdoni/]<00_ni/]<3o`0000Ko^:c=00?o0000okRZc?nhZ/`00_nhZ/`No`000003ok6Vc?l0003o
000000Ko000000?o/:C<o`000?l000002?l00002ojjTcP03o`000?n/Xlko[:?>00?o00000_n]YLl0
0ol0003oZjC?oj^Tc`02oj^Tc`;o000000?oZjC@o`000?nZXm001_nZXm02o`0000GoZ:?A00?o0000
ojNRdOnWX]400ol00002ojNVe@03o`000?nUY=CoYJCD00;oYJCD1?l00006ojBWf003o`000?nSY]So
XjKH00?o000000?oXj[Ko`000?nRZM`01onRZM`2o`0000GoXJkQ00?o0000oj2^hOnP[^400ol00002
oj2fj003o`000?nO]nWoWkOY00GoWkOY0_l00006oio1l@;o00001_nMc_T2o`0000;oV=gn1?l00002
ofcNh003o`000?oonf[ooo]Z06_ooo]Z1?l0001FoookJP004ooonfX00ol0003ooo]ZoookJP0ooook
JPSo00001onBa?P2o`0000KoY/G_00Co0000ok33ion``nOo/<?W0ol00002ojk3j@03o`000?nh`^;o
000000Co]L7S0ol00004okW2h@03o`000?ne_N3o]KgP00;o]KgP00?o0000okbieol000001?nj^]T0
1Ol0003o^<3PokS0h?l0003o_;OD00;o00001Onj]mH00ol0003o_;KCokbfd`02okbfd`Ko000000?o
_;KCo`000?nh/]<00onh/]<2o`0000Co^kCC00Ko0000okN`d_ng/=;o]k3Bo`000?nj[L`2o`0000Co
^K;C0_l00005okR/c@;o000000?o]k7Co`000?nhZ/`00_nhZ/`2o`0000?o]Z_>00?o0000okJ[c_l0
00001OneZLd00ol0003o]:W=o`000006okBWc003o`000?ncY/co/jK<00Go/jK<00?o0000ok6Uc?na
YL`01OnaYL`00ol0003o/:G=ok2Uc@05ok2Uc@;o00001_n^Y<h2o`0000Ko[JG?00?o0000oj^Tcol0
00001On[Y=000ol0003oZZ?@ojZSd003o`000003ojVVe?l0003oZ:?A00KoZ:?A0_l00003ojNVe@Oo
000000GoYJCDojFWf?nUYmSoYJOHo`000006ojBWf0;o00001OnSZ]/00ol0003oXZWLoj:Yg003o`00
00;oXZkP00?o0000oj6^hOnQ[^400_nQ[^45o`0000KoX;KX1?l00003oinnk`03o`000?nO`O7oWl7a
00?o00000onNb_H00ol0003oWLkioig>n@03o`0000?oV]Sm0ol000000om/g^3o0000o`00001[oook
JPGo0000F_oonfX001Cooo]Z0_l00012oookJPWo00001On;`oX3o`0000GoX/Gb0_l00006ojk3j@04
o`000?ne`N?o]L7SokG1h`;o00000onb`>@5o`0000?o]KgP0ol00003okZjf@;o00000onh`>02o`00
00Go^[OF00Go0000okVifOni^MWo0000okbfd`02o`0000Go^[GD2_l00003ok^dd`Co]k3B0_l00004
okVbd`;o000000?o]ZoBo`000?nh[<d00onh[<d00ol0003o]k7CokNad`02okNad`?o00001_nfZlh0
0ol0003o]JW=okFYc@05okFYc@03o`000?ndYlco]:O<00;o]:O<0_l000000onc[M;o0000ok>Vc003
ok>Vc0;o000000?o/J_Bo`000?naYL`00onaYL`2o`000003ok2Xcol0003o/:G=00?o/:G=0_l00000
0on^ZM;o0000ojjTcP03ojjTcP;o000000?o[JWCo`000?n]YLl01_n]YLl00ol0003oZjC@oj^Td006
oj^Td0;o00001OnYY]@00ol0003oZ:?AojRSd@09o`0000;oYZKE0_l000000onUY=CoYJOHojFWf005
ojFWf0?o00001?nTZ]/00ol0003oXj[Koj>Zf`04oj>Zf`;o00001_nR[^04o`0000CoXKGV00?o0000
oj2fj?nP]^P00ol00002oj2mk@03o`000?nO_^ooWkk_00CoWkk_0_l00007oik:mP;o00000_nJf?d2
o`000003oi;Qo_l0003oR^Of00;oR^Of00?o0000oookJ_oonfX0IooonfX4o`0005oooo]Z000Foook
JP03o`000?oonf[ooo]Z04;ooo]Z0_l000000ol[X>oo6Y_Vo`000003o`0000CoK/;n00?o0000oj;5
l_nRaO800ol00002oic5m003o`000?n^`nWo[/?Y00?o00000_nZ`n`00ol0003o]L7So`000006ok;0
i004o`000?ni`N3o^L7PokW1h0Co00000_nb_N800ol0003o^[[Io`000003okS0h0;o000000?o];_O
o`000?nj]mH00_nj]mH2o`0000Co^KWI00?o0000okZee?nj]M@00onj]M@01_l0003o^;OHokRgf?l0
003o_;GCo`0000Go^K?C1Ol00002okN`dP04o`000?nh/]?o^;;Co`0000?o^K;C1?nf[m801?l0003o
^:c=o`000?l00004okNad`;o00001OnfZlh2o`000003okFaeOl0003o]JW=00;o]JW=0ol00002okB_
d`04o`000?ndYlco0000o`0000Co/jgB00Co0000ok>Vc?l0003o00001?naZm801?l0003o/JG<o`00
0?l00004ok2Xc`04o`000?n`YLgo0000o`0000Co[ZWB00Co0000ojjTc_l0003o00001?n]ZM<00ol0
003o[JG?ojfUc`03o`000003oj^Ye?l0003oZjC@00?oZjC@0ol000000on[Z]Ko0000ojVVe004ojVV
e0Ko00000onXZ=L01?l0003oYZKEojJVeOnVY]D2o`0000;oYjWH00?o0000ojFWf?nUYmP00ol00002
ojF[f`03o`000?nTZ]_oY:[K00GoY:[K0ol00004oj>^h003o`000?nR[^3oXZkP00?oXZkP0_l00008
oj6eiP;o00001_nP_Nd3o`0000GoW/Od1?l00004oi_Do0Co00000_n:ioH2o`0006Sooo]Z1?l0001S
oookJP005ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?l[X>oo000000Co00000om^`_h2o`00
00KoW<Gd0_l00006oj[3k004o`000?nb`>Co//3Tok;0i0?o00000_n_`^L00ol0003o^L7Po`000004
okJoh@Co00000onh`>000ol0003o];_OokBkg`02okBkg`03o`000?nj]mKo000000Co^KWI00?o0000
okJohOl000000onj]M@2o`0000Co^;OH00?o0000okVcdoni/m<00oni/m<00ol0003o^;GGo`000003
okZcdP_o00000_nf[m82o`0000Go]k7C00?o0000ok>^dol000001?nfZlh00ol0003o]K7EokFae@02
okFae@?o00001Ond[m<2o`0000Ko/jgB0_l00006ok6[dP;o00001on`Z<l00ol0003o[ZWBojjYdP04
ojjYdP;o00001_n]ZM<3o`0000GoZjWD00Go0000oj^Td?l0003o0000oj^ZeP08o`0000?oZJWG00?o
0000ojRXeonXZ=L01?nXZ=L3o`0000KoYjWH0_l00006ojF[f`03o`000?nTZ]_o000000;o00000_nT
/>000ol0003oXjkPoj>^h003oj>^h0Go00001?nR]>D00ol0003oXKGVoj6eiP03o`0000;oXK_/00?o
0000oj2mkOnP_Nd00ol00002oio5l`03o`000?nNaoCoW/Od00?o00001?nLdOX3o`000004oiCNo_l0
003o0000o`0000;oS>Gi0ol0001VoookJPCo0000IooonfX001Sooo]Z0_l00018oookJP04o`000?l0
IK7o0000oeBin`Oo00001OnFaOL3o`0000GoY/C_0_l00006ojo2i`04o`000?nf_n7o][oQokJoh@;o
00001?nb_n<4o`0000?o];_O0ol00003okVif@;o00000onf_n400ol0003o^[GDo`000004okRgf003
o`000?nf_Moo000000?o^K?C0_l00003okRee`03o`000?nj/m;o000000Ko^;;C00?o0000okVad_ni
/M800_ni/M87o`000003okNadol0003o/jkC00;o/jkC00Co0000okJ[c_l0003o00001?ne/MD2o`00
00Go]:oC0_l000000onc[M;o0000ok>]dP03ok>]dP;o000000?o/ZcBok6[d_naZm800_naZm83o`00
0003ojnZd_l0003o/:S?00?o/:S?0_l000000ona[]Go[ZWBojjYdP03ojjYdP;o000000?o[jWBo`00
0?n]ZM<00on]ZM<2o`000003ojfYe?l0003oZjWD00;oZjWD00?o0000oj^Ye?n[ZM@01Ol00003ojZZ
eP;o00001onYZML00ol0003oZ:SGojRXe`03o`0000;oZ:_I00?o0000ojNYf?nWZMP00ol000000onV
[Mco0000ojF[f`06ojF[f`;o00001_nT/>02o`000003oj>^h?l0003o000000?oXkGV00Co0000oj:d
iOnR]>GoX[CU1Ol00006oj6kk0;o00001_nOaO<2o`0000?oW=7j0_l00003oiKKoPCo00000_n<iOT0
0ol0003oF]CCo`00001ToookJPCo0000JooonfX001[ooo]Z00?o0000oookJ_oonfX0BOoonfX2o`00
0003ocb_m?l0003o000000Co00001?n>a?X00ol0003oY/C_ojK4k`03o`0000;oX/Ga00?o0000ojo2
ion_`^L00ol00003ojc2jP03o`000?nb_n?o/[oS00Go/[oS00Co0000okRoh?nh_n3o^;oP1?l00002
ok6lhP03o`000?ni^MWo000000Go][oQ0_l00003okRgf0;o00000onf_Ml00ol0003o^K?Co`000006
okRee`03o`000?nh/]?o^;;C00;o^;;C0_l00002okJde`04o`000?ni/M;o0000o`0000Go][7D4Ol0
0004okB_d`03o`000?nc[M;o/jgB00;o/jgB00Co0000ok>]d_nc[M;o00001?nb[=82ok6[dP03o`00
0?n_Z];o[j[B00?o[j[B00Co0000ok2Xcol0003o00001?na[]D3ojjYdP03o`000?n_ZM;o000000Go
000000?o[JWCo`000?l000001ol00003ojb[eP04o`000?nZZ]KoZZ[FojZZeP;o000000?oZZ_Ho`00
0?nYZML01onYZML2o`0000KoZ:_I0_l00005ojJ]g003o`000?nUZm_oYJ_K00?o00000_nU/N401?l0
003oY;3PojB`h?nT/>04o`0000SoXkGV0ol00004oj:kj`03o`000?nQ^ncoXK_/00?o00000_nP`o80
0ol0003oWlGcoio5l`03o`0000?oWLki0_l00002oiKKoP?o00000_n?hOd00ol0003oS>Gio`000002
o`0006?ooo]Z1?l0001_oookJP006ooonfX2o`0004_ooo]Z00Co0000ob2QiolPXNOo8:7W0_l00006
ohk4nP;o00001_nRaO42o`0000;o[<;Z0ol00002ojS3k@03o`000?nb_n?o/[oS00?o00000on``>H2
o`0000Co];kQ1_l000001?nf_n7o0000o`000?l00002ok:jg`03o`000?nh]mSo000000Go][gO0_l0
0004okRee`;o00000_ne_=h01?l0003o^;;Co`000?l00005okJde`03o`000?nf/MCo][7D00?o][7D
00?o0000okFceol000001?nf[m82o`0000;o];7E00Co0000okFaeOl0003o00001?nd[m<Ao`000003
ok6[d_l0003o000000ko000000Co[ZWBo`000?l0003o00001?n^Z]<00ol0003o[J[DojfZe005ojfZ
e003o`000?n/ZmKo[:_F00Go[:_F0_l00005ojZ[f003o`000?nYZMOoZJWG00?o00000_nY[=X00ol0
003oZ:_IojR[f@03o`0000;oYjkM00?o0000ojJ]g?nV[M`01OnV[M`2o`0000CoYK7Q1Ol00002ojB`
h0;oY;GU00?o0000oj>ei_nS]NH00ol00002oj:kj`03o`000?nR^n_oX[_[00GoX[_[0_l00006oj33
lP;o00000_nMc_T3o`0000?oUmSm0_l00002ohoQo@;o000000?oHmWOo`000?l00000H_oonfX4o`00
07?ooo]Z000MoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oc6VlOlPXNL01?l00005ofk3oP?o
00001OnLaOD2o`0000KoZ<?]0_l00003ok30iP;o00000_n/`NT00ol0003o];kQo`000002o`0000Co
/KkS00?o0000okJohOl000000_l00003ok:jg`;o00001?nf_Ml2o`0000;o/[SN00Co0000okReeol0
003o00001?ne_=h2o`0000Co][CG0_l000000ond^]ko0000okJae002okJae0;o00000one/mL01?l0
003o]ZoBo`000?l00005okBae@03o`000?nd[m?o]:oC00Go]:oC00?o0000ok>]d_nc[M800_nc[M82
o`000003ok:`e_l0003o/ZcB00?o/ZcB0_l000000ona[mKo0000ok6[dP03ok6[dP;o00000_n`[]H0
0ol0003o[jgFojn]eP05ojn]eP03o`000?n^Z]?o[Z[C00?o00000_n^[ML00ol0003o[J[DojfZe002
ojfZe0;o000000?o[:gHo`000?n/ZmH00on/ZmH2o`000003oj^^fOl0003oZZ_H00KoZZ_H0_l00006
ojV/fP;o00001_nW[]d00ol0003oYZgLo`000002o`0000;oY[?R00?o0000ojFahOnU/N400ol00000
1?nU/N7o0000o`000?nT/>06ojBei@;o00001_nR^n/4o`0000CoXL?a1?l00005oig=n0;o00000_nG
f?d2o`0000?oT=on1Ol0001QoookJPCo0000MooonfX001kooo]Z0_l0001=oookJP03oc<00?l0003o
000000Co00000omca?l00ol0003oW<Geoic5m@03o`0000;oU<Gh00?o0000ojS3kOnX`nd00ol00002
oj?4l004o`000?n``>Ko0000o`0000Go[<7Y00?o0000ok6nhona_^<01_na_^<01?l0003o][gPokJm
h?nf_N06o`0000;o][gO00Co0000ok:hg_nb^=ko/[SN0ol00004okFlgP;o00000_na]mh01?l0003o
][CGo`000?l00004okBjgP03o`000?nf/MCo000000Ko]K?G00?o0000okBaeOnd/MD00_nd/MD2o`00
0003ok>cf?l0003o]:oC00?o]:oC0_l00002ok>ae`04o`000?nc[M;o0000o`0000Co/[3F00Co0000
ok:/d_l0003o00001?na[mH01?l0003o/J_Bo`000?l00005ok2^eP03o`000?n_[MKo[jgF00Go[jgF
0_l00006ojj]e`04o`000?n]Z]Co0000o`0000Co[:gH00Co0000ojb[e_l0003o00001?n[[]T00ol0
003oZZ_HojZ[f003o`0000;oZJoK00?o0000ojV/f_nY[=X00ol000000onW/^7o0000ojN^g@06ojN^
g@;o00000onV/n85o`000003ojFahOl0003oYKKU00?oYKKU00?o0000ojBeiOnT]ND00ol00002oj>k
j`03o`000?nR^n_oX[_[00?o00000_nQ`_000ol0003oXL?aoj73l@03o`0000;oW/cg00?o0000oig=
n?nMcOP00ol00003oiSFo@;o00000_n@goh3o`000003ofWKiom3a;ko0000063ooo]Z1?l0001koook
JP008?oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?lc003o000000Oo00001_nDaOP2o`0000Ko
XlC`00Co0000ojc1jOn/`NWo[<7Y0ol00002ojS3k@03o`000?na_^?o/KkS00?o00000on^`>L2o`00
00Oo/[cQ2?l000001Onb^n3o0000okFlg_ne_=ko000000Co/KON0_l00006okBjgP;o00001?ne/mL2
o`0000;o/[[O00Co0000okBaeOl0003o00001?nc/mP01?l0003o]:oCo`000?l00005ok>ae`03o`00
0?nb/=Ko/[3F00Go/[3F00?o0000ok6_e_na[mH01Ona[mH00ol0003o/:kFok2^eP02ok2^eP;o0000
00?o[k3Io`000?n_[MH00on_[MH2o`000003ojj`fOl0003o[ZgG00Oo[ZgG00?o0000ojb]f?n/[MP0
1On/[MP00ol0003oZjkIoj^^f@05oj^^f@;o00001_nY[m/2o`0000GoYk;Q00?o0000ojN^gOnW[]d0
2Ol00002ojFchP;oYKSV00?o0000ojFfiOnU]^D01OnU]^D2o`0000KoXk_[0_l00006oj72l0;o0000
1_nNc?L2o`0000;oV=Km1?l00002oh_Po@Go0000G_oonfX5o`0007oooo]Z000QoookJP03o`000?oo
nf[ooo]Z053ooo]Z0_l00002oc>]k`Go00001On;aO/3o`0000GoWLGd0_l00006ojS3k@;o00000on^
`>L2o`0000;oZl7Z00?o0000ok:lhOnb_>400ol00002ojnni@03o`000?nf_Moo000000Go/[_P1Ol0
0002ok6ggP;o00000_na^^000ol0003o];[NokBjgP03o`0000;o/;ON00Co0000okFceol0003o0000
1?nb^]l2o`0000Oo/k?H00?o0000ok>aeonc/ML00_nc/ML2o`000003ok2hgol0003o/[3F00?o/[3F
0_l00002ok6bf@03o`000?na[mKo/JoF00?o00000_n`/MT01?l0003o/:kFo`000?l00004ojn`f@04
o`000?n_[MKo0000o`0000Co[[3I00?o0000ojj]eon^[ML00ol00002ojf`fP03o`000?n/[MSo[:gH
00?o00000_nZ/ml00ol0003oZjkIoj^^f@03o`0000;oZ;CQ00?o0000ojV_fonY[m/00ol00002ojVf
h`05o`000?nW/^7oYk;QojNbhOl000000_nW/^45o`0000?oY[KT0_l000000onU/n;oYKSVojFhiP04
ojFhiPCo00000onS_>/00ol0003oXk_[oj>kj`03o`0000;oXL?a00?o0000oj72l?nQ`_000ol00004
oik;m`?o00001OnHeOd3o`0000;oRn3m0ol000000om1`l7ooo]ZoookJP1LoookJPCo0000Q?oonfX0
02;ooo]Z0_l0001DoookJP03o`000?lTXN[o000000Co00001?mR`_d00ol0003oWLGdoig5m003o`00
00;oU/Kh00?o0000ojS3kOnX`nd00ol00002oj?4l004o`000?n^`>Oo0000o`0000GoZl7Z0_l00006
ojnni@03o`000?nb^n3o/[_P00;o/[_P0ol000001?n__NCo0000okFlgone_=l;o`0000?o/;ON0_l0
0004ok:jg`;o000000?o[[KOo`000?nc/mP00onc/mP2o`0000;o/;[Q00Co0000ok>aeol0003o0000
1?n`^=l01?l0003o/[3Fo`000?l00005ok6bf@;o00001_n`/MT00ol0003o[k3Iojn`f@05ojn`f@03
o`000?n^/=Wo[[3I00Go[[3I0_l00006ojf`fP;o00001OnZ/ml3o`0000KoZ;CQ0_l00003ojVfh`So
00000onW]^@00ol0003oY[KTojJfi003o`0000;oYKWW00?o0000ojFhi_nU^>H00ol00002ojBnk003
o`000?nS_>_oXkc[00CoXkc[0_l00006oj73l@;o00000onNboL2o`0000?oV=Cm1ol00003ofgKkP;o
0000G_oonfX4o`0008Sooo]Z000ToookJP03o`000?oonf[ooo]Z05Cooo]Z1_l00003of;2o@;o0000
1_nFa_P2o`0000KoXlC`00Co0000oj_1j_n[`N[oZl7Z0ol00002ojK3kP03o`000?n__^Go[kkU00?o
00000_n/`>T01?l0003o/[_Po`000?l00005ojnmi0;o00000ona^]l3o`000004ojnmi?l0003o/k[N
ok>jgPSo000000?o/[[Oo`000?n^]]l00on^]]l01?l0003o/k?Ho`000?l00003ok2jh@?o00001_n`
^=l2o`0000Co/K;I0_l000000on]^^?o0000ok2af@03ok2af@;o00000_n/^N800ol0003o[k3Iojn`
f@03o`0000;o[;SR00?o0000ojj`fOn^/=T00ol00002oj^ghP03o`000?n]/=[o[K3J00?o00000_n/
^>801?l0003oZ[?OojZcgonZ/ml2o`000003ojZdh?l0003oZ;CQ00;oZ;CQ00?o0000ojRdhOnX]>40
1_l00002ojRfh`?o00001onW]^@2o`0000KoYKWW0_l00006ojBnk0?o00001OnQa?43o`0000GoW/cg
0_l00002oiSDo@?o00000on;g?h2o`0000;oKM_^00?o0000oookJ_oonfX0GOoonfX4o`0008cooo]Z
000UoookJP;o0000F?oonfX3o`000003ocVal?l0003o000000Co00001On<a_/3o`0000GoW<Gd0_l0
0006ojK3kP;o00001_n/`>T01?l0003o[kgTojnmi?n__N@3o`0000;o[;oX00Co0000ok6jgol0003o
00001On__N@2o`0000Oo/;[P4Ol00003ok2hg`?o00000_n/]Ml01?l0003o/K;Io`000?l00004ojfj
h`04o`000?n`/MWo0000o`0000Co[;WR0ol00005ojbhhP?o00001_n[]n82o`0000;o[;SR1Ol00000
0onZ/moo0000o`000007o`0000CoZKOS00Co0000ojRfhonX]^?oZ;KS0_l00002ojNiiP03o`000?nW
]^CoYkKT00?o00000_nU_>T00ol0003oYKWWojFii`03o`0000?oY<3]00?o0000ojBnk?nT_^`00ol0
0002oj75lP03o`000?nQa?7oXLCa00?o00000onMc?P3o`0000GoUmGm0_l00002oh_LoP;o00000_m[
f^h00olc^[[o3P00oookJP1MoookJPCo0000T?oonfX002Oooo]Z00?o0000oookJ_oonfX0FOoonfX2
o`0000;o4YcK1?l00005oeo2o@?o00001?nDa_T00ol0003oY/?^ojK3kP03o`0000;oX<Gb00?o0000
ojc0jOn/`>T00ol00003ojO2k@;o00001_n/_nP00ol0003o[kgTojnmi002ojnmi0;o00000_n[_nP0
0ol0003o/;[Pok2jh003o`0000;o[KgU00?o0000ok6ig_l000000_l00004ojnjhP03o`000?n`^n;o
000000Co[kSO7_l00002ojbhhPOo00000_n[]n85o`0000?oZ[SS0_nY^N@00ol0003oZ[GQojZeh@03
o`000003ojRji_l0003oZKOS00KoZKOS0_l00006ojNiiP;o00001_nU_>T2o`0000OoY<3]0_l00006
oj75lP;o00000_nMc?P2o`0000;oU]Gm00?o0000oiOEoOnGeOd00ol00003ohOLoPGo000000?o3P00
oookJ_oonfX0FooonfX4o`0009Cooo]Z000XoookJP;o0000G_oonfX=o`0000?oU<Ki0_l00006oj35
lP;o00000_nW`^d3o`0000;oX/Ca00?o0000ojboj?n/_nP00ol00002ojS2k004o`000?n__NCo0000
o`0000GoZkoX0_l00006ojfmi@03o`000?n_^^;o[k[R00Ko[k[R00Co0000ojnhgon_^=oo[kSO0ol0
00001?n]_>Go0000ojngg_n_]mh3o`0000;o[K[S00?o0000ojfjhol000000_l00004ojfihP04o`00
0?n/^N;o0000o`0000Co[;SR00Co0000ojbhh_l0003o00001?n/^>800ol0003oZkORo`000002o`00
00CoZkSS00?o0000ojZhhonY^N@01OnY^N@2o`0000GoZ;[V00?o0000ojVghonY]n<00ol00002ojNl
j003o`000?nW^NKoYkWV00?o00000_nU_^`00ol0003oYKcYojFlj@03o`0000;oXl;_00?o0000ojC0
kOnT`>d00ol00003oj37m0Co00001?nLc_T2o`0000KoU]Gm0_l00002ohOLoP05o`000?mVf>co0000
obRa/_l00000G_oonfX4o`0009Sooo]Z000ZoookJP03o`000?oonf[ooo]Z067ooo]Z00?o0000od6c
mOm1/oD00_m1/oD4o`0000?oKLOo0ol00005oiS7m`;o00001_nRa?42o`0000KoZ<;/00Co0000oj^o
j?n[_nSoZkoX0ol00002ojO2k@03o`000?n]_NGo[KgU00?o00000_nZ_nT00ol0003o[k[RojnjhP03
o`0000;o[;gW00Co0000ojnhgol0003o00001On]_>D2o`0000Ko[K[S00?o0000ojfih_n]^N801_n]
^N800ol0003o[;SRojbhhP05ojbhhP03o`000?n/^>;o[;SR00Go[;SR00Co0000oj^hhon[^>?oZkSS
0_l00003ojRlj003o`000?nY^NCoZKWT00?o00000_nW_NT00ol0003oZ;[VojRjiP04ojRjiP;o0000
1_nW_>P2o`0000KoYKk/0_l00006oj?2k`;o00000_nPao@3o`0000;oV]3k00?o0000oic>nOnLc_T0
0ol00003oi?GoP?o000000KoP]cmo`000?l0003o0000oegDj?l0001PoookJPCo0000W?oonfX002_o
oo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP02oookJP?o<`000_l000000om5^OCo
0000o`000004o`0000GoSLSk0ol00005oi[7mP?o00001OnRa?42o`0000KoYl;]0_l00006ojZoj@;o
00001_n/_NL01?l0003o[KcUojfliOn]_>D3o`0000;oZKoY00?o0000ojfjhon]^^<00ol00002ojZn
j003o`000?n]^N;o[KWR00?o00000_nZ_NL00ol0003o[;SRojbhhP03o`0000;oZ[cW00?o0000ojbh
h_n/^>800ol00003ojVli`;o00001onX_>P2o`0000KoYkgY0ol00005ojJok0?o00001OnT`^l3o`00
00GoX/Gb0ol00005oik:mP;o00001_nJd?/2o`0000;oTmOn00?o0000og_Ko?l000000om_f?L3o`00
063ooo]Z1?l0002PoookJP00;?oonfX2o`00063ooo]Z00?o0000oookJ_oonfX01ooonfX3o`0000;o
6j?M1?l00005oeg4o0?o00001?n@b?/00ol0003oX/Caoj;4l@03o`0000;oV/Of00?o0000ojO2kOnW
`^d00ol00002oj75lP03o`000?nZ_nWoZ[oY00?o00000onU`nl3o`0000GoZ<7/0_l00006ojVoj@;o
00001_nZ_^P2o`0000KoZ[gW0_l00006ojZli`;o00000_nY_>L3o`0000;oY/7]00?o0000ojRlj?nX
_>P00ol00002ojG2kP03o`000?nW_NWoYkgY00?o00000_nS`o000ol0003oY[o/ojJok003o`0000;o
X/Kb00?o0000ojC2konT`^l00ol00002oio9m@03o`000?nRaO;oX/Gb00?o00000onLcOT4o`0000Go
U];l0ol000000on>f?oo0000o`000002og7In0;o00000_m_f?L2o`00063ooo]Z1Ol0002ToookJP00
;_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z00gooo]Z3Ol00003oi38n`;o0000
1_nJaoH2o`0000KoXLGb0_l00002ojG3k`?o00000_nNa_@00ol0003oZ<7/ojS1k003o`0000;oX/Ga
00?o0000ojVojOnY_nT00ol00002ojC3k`03o`000?nZ_^SoZ[kX00?o00000_nV`^h00ol0003oZ[gW
ojZmi`03o`0000?oY/7]0ol00005ojK1k@;o00001_nV`Nd2o`0000KoYL;^0_l00006oj?3l0;o0000
1_nRa_82o`0000KoWlWe0_l00002oic=n@?o00000onAeOh4o`0000CoO=Sn0_l00002og7In004o`00
0?ln`];o0000o`X0067ooo]Z1?l0002YoookJP00;ooonfX2o`0005gooo]Z00?o0000oookJ_oonfX0
5OoonfX2ocJakPGo00000omPa_`3o`0000GoSlWk0ol00005oiW8n0;o00001_nNa_@2o`0000KoX/Ga
0_l00006ojC3k`;o00001_nV`^h2o`0000;oY/7]0ol00002oj76l`03o`000?nV`NgoY/7]00?o0000
0_nQa_<00ol0003oY/7]ojK1k@03o`0000;oX<Oc00?o0000ojG2k_nU`^h00ol00002oio8m@03o`00
0?nS`o3oXl?`00?o00000onMb_L3o`0000GoVlgi0ol00005oiOAo0;o00000_nAeOh3o`0000;oL=Oj
1?l000001?mTe?;o0000o`000?lZ001ToookJPCo0000[OoonfX0037ooo]Z00?o0000oookJ_oonfX0
F_oonfX00ol0003ooo]ZoookJP0JoookJP05od<00?l0003o0000o`000?lX[N<01Ol00005oek6n`?o
00001Ombc?l3o`0000GoUL[j0ol00005oi[9m`?o00001OnNaoD3o`0000GoWlOd0_l00006oj76l`;o
00001_nQa_<2o`0000KoX<Oc0_l00006oio8m@;o00000_nMb_L3o`0000?oTm7m0ol00005ohkDoP?o
00001Omie_h2o`0000;oL=Oj00Co0000odW8h?l0003o0000IooonfX4o`000;7ooo]Z000boookJP;o
0000F_oonfX00ol0003ooo]ZoookJP0RoookJP?o@`000ol00002oeW3nPco00001OmYbod3o`0000Go
S/cm0ol00005oi?<n`?o00001OnFc?X3o`0000GoV<cj0ol00005oiS<nP?o00001OnHcOX3o`0000Go
U/ok0_l00002oi?Ao@?o00000om]d_/3o`000003ofSCn?mEc>ooELc_00;oELc_0_l00002ofCCm003
o`000?l^003o;P0006[ooo]Z1?l0002eoookJP00=?oonfX00ol0003ooo]ZoookJP1GoookJP03o`00
0?oonf[ooo]Z02cooo]Z0om900000ol0003oC/3fodk0mP02odk0mPco00001OmJaoP3o`0000GoI/cl
0ol00005ofk>o@?o00001Omcd?h3o`0000GoMM7n0ol00005ogCBoP?o00001Ombd_d2o`0000;oKM;k
0_mGcO07o`00073ooo]Z1?l0002ioookJP00=OoonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oo
nf[ooo]Z03cooo]Z1Ol00004odk3m2_o00000omQcoL00ol8003ooo]ZoookJP1hoookJPCo0000_Ooo
nfX003Kooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z0>[ooo]Z1?l00031oookJP00>?oonfX00ol0
003ooo]ZoookJP1CoookJP03o`000?oonf[ooo]Z0>Kooo]Z1?l00035oookJP00>OoonfX2o`0005?o
oo]Z00?o0000oookJ_oonfX0hOoonfX5o`000<Wooo]Z000koookJP03o`000?oonf[ooo]Z04oooo]Z
00?o0000oookJ_oonfX0g_oonfX4o`000<kooo]Z000loookJP03o`000?oonf[ooo]Z04kooo]Z00?o
0000oookJ_oonfX0f_oonfX4o`000=;ooo]Z000moookJP;o0000C_oonfX00ol0003ooo]ZoookJP3F
oookJPCo0000e_oonfX003oooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]ZoookJP3Boook
JPCo0000f_oonfX0043ooo]Z0_l0001;oookJP03o`000?oonf[ooo]Z0<kooo]Z1?l0003NoookJP00
@_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z0<[ooo]Z1?l0003RoookJP00@ooo
nfX2o`0004Sooo]Z00?o0000oookJ_oonfX0a_oonfX4o`000>Kooo]Z0015oookJP03o`000?oonf[o
oo]Z04Gooo]Z00?o0000oookJ_oonfX0`OoonfX5o`000>[ooo]Z0016oookJP03o`000?oonf[ooo]Z
04Cooo]Z00?o0000oookJ_oonfX0_OoonfX4o`000>oooo]Z0017oookJP;o0000A?oonfX00ol0003o
oo]ZoookJP2ioookJPCo0000looonfX004Wooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Z
oookJP2eoookJPCo0000mooonfX004[ooo]Z0_l00011oookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0
003koookJP00C?oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z0:gooo]Z1?l0003o
oookJP00COoonfX2o`0003kooo]Z00?o0000oookJ_oonfX0ZOoonfX4o`000?oooo]Z1?oonfX004oo
oo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP2UoookJPCo0000oooonfX8oookJP00
D?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z0:7ooo]Z1?l0003ooookJPcooo]Z
001AoookJP;o0000>OoonfX00ol0003ooo]ZoookJP2MoookJPGo0000oooonfX@oookJP00DooonfX0
0ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z09Wooo]Z1?l0003ooookJQGooo]Z001Doook
JP;o0000=_oonfX00ol0003ooo]ZoookJP2EoookJPCo0000oooonfXIoookJP00E_oonfX00ol0003o
oo]ZoookJP0coookJP03o`000?oonf[ooo]Z097ooo]Z1?l0003ooookJQgooo]Z001GoookJP03o`00
0?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0SOoonfX4o`000?oooo]Z8OoonfX005Sooo]Z0_l0
000boookJP03o`000?oonf[ooo]Z08Wooo]Z1?l0003ooookJRGooo]Z001JoookJP03o`000?oonf[o
oo]Z02oooo]Z00?o0000oookJ_oonfX0QOoonfX4o`000?oooo]Z:OoonfX005_ooo]Z0_l0000_oook
JP03o`000?oonf[ooo]Z087ooo]Z1?l0003ooookJRgooo]Z001MoookJP03o`000?oonf[ooo]Z02co
oo]Z00?o0000oookJ_oonfX0OOoonfX4o`000?oooo]Z<OoonfX005kooo]Z0_l0000/oookJP03o`00
0?oonf[ooo]Z07Sooo]Z1Ol0003ooookJSGooo]Z001PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX0M?oonfX4o`000?oooo]Z>_oonfX0067ooo]Z00?o0000oookJ_oonfX0:?oonfX0
0ol0003ooo]ZoookJP1`oookJPCo0000oooonfXnoookJP00H_oonfX2o`0002Sooo]Z00?o0000oook
J_oonfX0K?oonfX4o`000?oooo]Z@_oonfX006Cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003o
oo]ZoookJP1XoookJPCo0000oooonfY6oookJP00IOoonfX2o`0002Gooo]Z00?o0000oookJ_oonfX0
I?oonfX4o`000?oooo]ZB_oonfX006Oooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Zoook
JP1PoookJPCo0000oooonfY>oookJP00J?oonfX2o`00027ooo]Z00?o0000oookJ_oonfX0GOoonfX4
o`000?oooo]ZD_oonfX006[ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP1Ioook
JPCo0000oooonfYFoookJP00JooonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z05Co
oo]Z1Ol0003ooookJU[ooo]Z001/oookJP;o00007OoonfX00ol0003ooo]ZoookJP1@oookJPCo0000
oooonfYOoookJP00K_oonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z04cooo]Z1?l0
003ooookJV?ooo]Z001_oookJP;o00006_oonfX00ol0003ooo]ZoookJP18oookJPCo0000oooonfYW
oookJP00LOoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0003ooook
JV_ooo]Z001boookJP;o00005ooonfX00ol0003ooo]ZoookJP10oookJPCo0000oooonfY_oookJP00
M?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z03cooo]Z1?l0003ooookJW?ooo]Z
001eoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0>?oonfX4o`000?oooo]ZMooo
nfX007Kooo]Z0_l0000CoookJP03o`000?oonf[ooo]Z03Cooo]Z1?l0003ooookJW_ooo]Z001hoook
JP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0;ooonfX5o`000?oooo]ZOooonfX007Wo
oo]Z0_l0000@oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003ooookJXCooo]Z001koookJP03o`00
0?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX09ooonfX4o`000?oooo]ZR?oonfX007cooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0SoookJPCo0000oooonfZ<oookJP00OOoonfX2
o`0000cooo]Z00?o0000oookJ_oonfX07ooonfX4o`000?oooo]ZT?oonfX007oooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP0KoookJPCo0000oooonfZDoookJP00P?oonfX2o`0000So
oo]Z00?o0000oookJ_oonfX06?oonfX4o`000?oooo]ZV?oonfX008;ooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP0DoookJPCo0000oooonfZLoookJP00PooonfX2o`0000Gooo]Z00?o
0000oookJ_oonfX04?oonfX4o`000?oooo]ZX?oonfX008Gooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP0;oookJPGo0000oooonfZToookJP00Q_oonfX01Ol0003ooo]ZoookJ_oonf[o
000000Wooo]Z1?l0003ooookJZWooo]Z0027oookJP;o000000?ooo]Zo`000?oonfX01?oonfX4o`00
0?oooo]Z[OoonfX008Wooo]Z0_l000000ooonf[o0000o`000002o`000?oooo]Z/OoonfX008[ooo]Z
0_l0003ooookJ[Gooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {633.5, 0}} -> {0.0579154, -8.00217*^-5, \
0.00154506, 0.00154506}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Write a function to place all the octants on one graph", "Text"],

Cell[BoxData[
    \(HAtomShow[n_\ , \ L_, \ m_, \ pfrac_]\  := \ 
      Module[{nu, nd, su, sd, pmax, plevel, whole, 
          half}, \[IndentingNewLine]pmax = \ 
          NMaximize[
            Abs[HAtom[n, L, m, SphericalCoords[x, y, z]]], {x, y, 
              z}]; \[IndentingNewLine]plevel\ \  = \ 
          pfrac\ \((pmax[\([1]\)])\); \[IndentingNewLine]nu\  = \ 
          ContourPlot3D[
            Abs[HAtom[n, L, m, SphericalCoords[x, y, z]]], {x, \(-10\), 
              10}, {y, epsilon, 10}, {z, epsilon, 10}, 
            MaxRecursion \[Rule] 2, PlotPoints -> {5, 5}, 
            Contours -> {plevel}, 
            DisplayFunction \[Rule] Identity]; \[IndentingNewLine]nd\  = \ 
          ContourPlot3D[
            Abs[HAtom[3, 2, 1, SphericalCoords[x, y, z]]], {x, \(-10\), 
              10}, {y, epsilon, 10}, {z, \(-epsilon\), \(-10\)}, 
            MaxRecursion \[Rule] 2, PlotPoints -> {5, 5}, 
            Contours -> {plevel}, 
            DisplayFunction \[Rule] Identity]; \[IndentingNewLine]su\  = \ 
          ContourPlot3D[
            Abs[HAtom[n, L, m, SphericalCoords[x, y, z]]], {x, \(-10\), 
              10}, {y, \(-epsilon\), \(-10\)}, {z, epsilon, 10}, 
            MaxRecursion \[Rule] 2, PlotPoints -> {5, 5}, 
            Contours -> {plevel}, 
            DisplayFunction \[Rule] Identity]; \[IndentingNewLine]sd\  = \ 
          ContourPlot3D[
            Abs[HAtom[3, 2, 1, SphericalCoords[x, y, z]]], {x, \(-10\), 
              10}, {y, \(-epsilon\), \(-10\)}, {z, \(-epsilon\), \(-10\)}, 
            MaxRecursion \[Rule] 2, PlotPoints -> {5, 5}, 
            Contours -> {plevel}, 
            DisplayFunction \[Rule] Identity]; \[IndentingNewLine]whole\  = \ 
          Show[nu, nd, su, sd, 
            DisplayFunction \[Rule] 
              Identity]; \[IndentingNewLine]half\  = \ \ Show[nu, nd, 
            DisplayFunction \[Rule] Identity]; \[IndentingNewLine]Show[
          GraphicsArray[{whole, half}], 
          DisplayFunction \[Rule] $DisplayFunction]]\)], "Input"],

Cell["\<\
It takes about a minute to compute and display one probability \
density contour\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(H210\  = \ HAtomShow[2, 1, 0, 0.8]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .50166 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0119442 0.47619 [
[ 0 0 0 0 ]
[ 1 .50166 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .50166 L
0 .50166 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0119442 0.477324 0.489714 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0431315 1.1386 -1.11022e-16 1.1386 [
[ 0 0 0 0 ]
[ 1 1.05348 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08224 .2468 m
0 .76615 L
s
0 .76615 m
.40035 1.05348 L
s
.40035 1.05348 m
.4167 .58443 L
s
.4167 .58443 m
.08224 .2468 L
s
.67411 0 m
.93226 .41737 L
s
.93226 .41737 m
1 .91353 L
s
1 .91353 m
.70561 .5445 L
s
.70561 .5445 m
.67411 0 L
s
.08224 .2468 m
0 .76615 L
s
0 .76615 m
.70561 .5445 L
s
.70561 .5445 m
.67411 0 L
s
.67411 0 m
.08224 .2468 L
s
.4167 .58443 m
.93226 .41737 L
s
.93226 .41737 m
1 .91353 L
s
1 .91353 m
.40035 1.05348 L
s
.40035 1.05348 m
.4167 .58443 L
s
0 0 m
1 0 L
1 1.05348 L
0 1.05348 L
closepath
clip
newpath
.5 Mabswid
.697 .571 .709 r
.5206 .61894 m .55962 .58651 L .51089 .58837 L closepath p F P
0 g
s
.698 .591 .732 r
.55962 .58651 m .51089 .58837 L .50611 .57562 L p F P
0 g
s
.722 .585 .701 r
.51089 .58837 m .49442 .58692 L p .5146 .62543 L F P
0 g
s
.722 .585 .701 r
.5146 .62543 m .5206 .61894 L .51089 .58837 L p F P
0 g
s
.728 .606 .721 r
.51089 .58837 m .50611 .57562 L .49442 .58692 L closepath p F P
0 g
s
.695 .567 .707 r
.52274 .62582 m .5206 .61894 L .55962 .58651 L p F P
0 g
s
.72 .581 .699 r
.52274 .62582 m .5206 .61894 L .5146 .62543 L closepath p F P
0 g
s
.687 .542 .683 r
.52274 .62582 m .58791 .62145 L p .55293 .65841 L F P
0 g
s
.687 .542 .683 r
.55293 .65841 m .53127 .65985 L .52274 .62582 L p F P
0 g
s
.695 .567 .707 r
.57731 .58534 m .58791 .62145 L .52274 .62582 L p F P
0 g
s
.695 .567 .707 r
.55962 .58651 m .57731 .58534 L p .52274 .62582 L F P
0 g
s
.721 .562 .674 r
.5146 .62543 m .52274 .62582 L .53127 .65985 L p F P
0 g
s
.721 .562 .674 r
.53127 .65985 m .4906 .65789 L .5146 .62543 L p F P
0 g
s
.733 .582 .685 r
.46493 .62098 m .5146 .62543 L .4906 .65789 L p F P
0 g
s
.722 .585 .701 r
.49442 .58692 m .46493 .62098 L .5146 .62543 L p F P
0 g
s
.698 .591 .732 r
.50611 .57562 m .54456 .5463 L p .55962 .58651 L F P
0 g
s
.707 .6 .735 r
.50611 .57562 m .54456 .5463 L .49465 .54617 L closepath p F P
0 g
s
.731 .612 .725 r
.49442 .58692 m .50611 .57562 L .49465 .54617 L p F P
0 g
s
.744 .612 .712 r
.45015 .5806 m .49442 .58692 L .46493 .62098 L p F P
0 g
s
.731 .612 .725 r
.48503 .54485 m .45015 .5806 L .49442 .58692 L p F P
0 g
s
.731 .612 .725 r
.49465 .54617 m .48503 .54485 L p .49442 .58692 L F P
0 g
s
.691 .577 .723 r
.57731 .58534 m .57415 .57616 L .55962 .58651 L closepath p F P
0 g
s
.698 .591 .732 r
.56347 .54559 m .57415 .57616 L .55962 .58651 L p F P
0 g
s
.698 .591 .732 r
.54456 .5463 m .56347 .54559 L p .55962 .58651 L F P
0 g
s
.649 .534 .709 r
.57731 .58534 m .63563 .5725 L p .60026 .61874 L F P
0 g
s
.649 .534 .709 r
.60026 .61874 m .58791 .62145 L .57731 .58534 L p F P
0 g
s
.656 .558 .732 r
.62851 .55137 m .63563 .5725 L .57731 .58534 L p F P
0 g
s
.656 .558 .732 r
.57731 .58534 m .57415 .57616 L .62851 .55137 L p F P
0 g
s
.658 .561 .734 r
.62229 .53308 m .62851 .55137 L .57415 .57616 L p F P
0 g
s
.658 .561 .734 r
.57415 .57616 m .56347 .54559 L .62229 .53308 L p F P
0 g
s
.684 .518 .655 r
.53512 .68013 m .55293 .65841 L .53127 .65985 L closepath p F P
0 g
s
.712 .536 .65 r
.53127 .65985 m .4906 .65789 L p .52851 .69122 L F P
0 g
s
.712 .536 .65 r
.52851 .69122 m .53512 .68013 L .53127 .65985 L p F P
0 g
s
.698 .601 .744 r
.56347 .54559 m .5597 .53617 L .54456 .5463 L closepath p F P
0 g
s
.706 .618 .756 r
.54523 .50087 m .5597 .53617 L .54456 .5463 L p F P
0 g
s
.706 .618 .756 r
.49153 .53912 m .54523 .50087 L p .54456 .5463 L F P
0 g
s
.706 .618 .756 r
.54456 .5463 m .49465 .54617 L .49153 .53912 L p F P
0 g
s
.734 .631 .744 r
.49465 .54617 m .49153 .53912 L .48503 .54485 L closepath p F P
0 g
s
.643 .508 .683 r
.58873 .62486 m .60026 .61874 L .58791 .62145 L closepath p F P
0 g
s
.687 .542 .683 r
.58791 .62145 m .58873 .62486 L .55293 .65841 L p F P
0 g
s
.664 .584 .755 r
.61407 .51183 m .62229 .53308 L .56347 .54559 L p F P
0 g
s
.664 .584 .755 r
.56347 .54559 m .5597 .53617 L .61407 .51183 L p F P
0 g
s
.733 .582 .685 r
.45229 .63905 m .46493 .62098 L p .4906 .65789 L F P
0 g
s
.747 .594 .686 r
.45229 .63905 m .46493 .62098 L .446 .61818 L closepath p F P
0 g
s
.744 .612 .712 r
.43767 .59582 m .45015 .5806 L p .46493 .62098 L F P
0 g
s
.744 .612 .712 r
.46493 .62098 m .446 .61818 L .43767 .59582 L p F P
0 g
s
.642 .507 .683 r
.59583 .65471 m .58873 .62486 L .60026 .61874 L p F P
0 g
s
.68 .531 .676 r
.59583 .65471 m .58873 .62486 L .55293 .65841 L closepath p F P
0 g
s
.683 .516 .654 r
.55293 .65841 m .59583 .65471 L p .53723 .69138 L F P
0 g
s
.683 .516 .654 r
.53723 .69138 m .53512 .68013 L .55293 .65841 L p F P
0 g
s
.753 .643 .739 r
.44539 .53676 m .48503 .54485 L .45015 .5806 L p F P
0 g
s
.74 .641 .75 r
.47677 .50766 m .44539 .53676 L .48503 .54485 L p F P
0 g
s
.74 .641 .75 r
.48503 .54485 m .49153 .53912 L .47677 .50766 L p F P
0 g
s
.716 .621 .75 r
.54523 .50087 m .49153 .53912 L .47677 .50766 L p F P
0 g
s
.712 .536 .65 r
.4906 .65789 m .47346 .68846 L .52851 .69122 L p F P
0 g
s
.734 .561 .657 r
.45676 .65469 m .4906 .65789 L .47346 .68846 L p F P
0 g
s
.733 .582 .685 r
.4906 .65789 m .45676 .65469 L .45229 .63905 L p F P
0 g
s
.666 .584 .754 r
.61407 .51183 m .5597 .53617 L .54523 .50087 L p F P
0 g
s
.642 .507 .683 r
.60026 .61874 m .64604 .6085 L p .59583 .65471 L F P
0 g
s
.647 .53 .706 r
.64604 .6085 m .6432 .59864 L .60026 .61874 L closepath p F P
0 g
s
.649 .534 .709 r
.63563 .5725 m .6432 .59864 L .60026 .61874 L p F P
0 g
s
.758 .627 .714 r
.43767 .59582 m .45015 .5806 L .42981 .57615 L closepath p F P
0 g
s
.753 .643 .739 r
.42276 .56106 m .44539 .53676 L p .45015 .5806 L F P
0 g
s
.753 .643 .739 r
.45015 .5806 m .42981 .57615 L .42276 .56106 L p F P
0 g
s
.762 .602 .68 r
.446 .61818 m .42499 .61332 L p .44414 .65245 L F P
0 g
s
.762 .602 .68 r
.44414 .65245 m .45229 .63905 L .446 .61818 L p F P
0 g
s
.765 .623 .702 r
.446 .61818 m .43767 .59582 L .42499 .61332 L closepath p F P
0 g
s
.711 .535 .649 r
.53723 .69138 m .53512 .68013 L .52851 .69122 L closepath p F P
0 g
s
.757 .595 .676 r
.45676 .65469 m .45229 .63905 L .44414 .65245 L closepath p F P
0 g
s
.632 .478 .656 r
.59583 .65471 m .65402 .64179 L p .63976 .67744 L F P
0 g
s
.632 .478 .656 r
.63976 .67744 m .60159 .6858 L .59583 .65471 L p F P
0 g
s
.683 .516 .654 r
.59583 .65471 m .60159 .6858 L .53723 .69138 L p F P
0 g
s
.642 .507 .683 r
.64604 .6085 m .65402 .64179 L .59583 .65471 L p F P
0 g
s
.734 .561 .657 r
.47346 .68846 m .46374 .68756 L .45676 .65469 L p F P
0 g
s
.76 .576 .649 r
.44414 .65245 m .45676 .65469 L .46374 .68756 L p F P
0 g
s
.772 .633 .707 r
.42499 .61332 m .43767 .59582 L .42981 .57615 L p F P
0 g
s
.671 .484 .624 r
.53723 .69138 m .60159 .6858 L p .59796 .71572 L F P
0 g
s
.671 .484 .624 r
.59796 .71572 m .54078 .72069 L .53723 .69138 L p F P
0 g
s
.709 .511 .62 r
.52851 .69122 m .53723 .69138 L .54078 .72069 L p F P
0 g
s
.709 .511 .62 r
.54078 .72069 m .51753 .72028 L .52851 .69122 L p F P
0 g
s
.721 .526 .626 r
.47346 .68846 m .52851 .69122 L .51753 .72028 L p F P
0 g
s
.666 .584 .754 r
.60498 .48884 m .61407 .51183 L p .54523 .50087 L F P
0 g
s
.666 .584 .754 r
.54523 .50087 m .54612 .50045 L .60498 .48884 L p F P
0 g
s
.671 .599 .765 r
.54523 .50087 m .54612 .50045 L .54513 .50063 L closepath p F P
0 g
s
.716 .621 .75 r
.54513 .50063 m .54523 .50087 L p .47677 .50766 L F P
0 g
s
.76 .576 .649 r
.46374 .68756 m .43091 .68183 L .44414 .65245 L p F P
0 g
s
.777 .595 .653 r
.4073 .64387 m .44414 .65245 L .43091 .68183 L p F P
0 g
s
.762 .602 .68 r
.42499 .61332 m .4073 .64387 L .44414 .65245 L p F P
0 g
s
.716 .621 .75 r
.47677 .50766 m .48994 .49773 L .54513 .50063 L p F P
0 g
s
.673 .617 .784 r
.54612 .50045 m .54513 .50063 L .53068 .47035 L p F P
0 g
s
.713 .636 .769 r
.54513 .50063 m .53068 .47035 L .48994 .49773 L closepath p F P
0 g
s
.669 .605 .774 r
.60498 .48884 m .59968 .47678 L .54612 .50045 L closepath p F P
0 g
s
.673 .617 .784 r
.58526 .4451 m .59968 .47678 L .54612 .50045 L p F P
0 g
s
.673 .617 .784 r
.53068 .47035 m .58526 .4451 L p .54612 .50045 L F P
0 g
s
.772 .633 .707 r
.42981 .57615 m .41405 .57144 L p .42499 .61332 L F P
0 g
s
.772 .65 .728 r
.42981 .57615 m .42276 .56106 L .41405 .57144 L closepath p F P
0 g
s
.79 .63 .684 r
.39193 .60326 m .42499 .61332 L .4073 .64387 L p F P
0 g
s
.772 .633 .707 r
.41405 .57144 m .39193 .60326 L .42499 .61332 L p F P
0 g
s
.729 .647 .767 r
.47677 .50766 m .48994 .49773 L .47037 .49499 L closepath p F P
0 g
s
.753 .656 .755 r
.44539 .53676 m .47677 .50766 L .47037 .49499 L p F P
0 g
s
.77 .655 .736 r
.44539 .53676 m .42276 .56106 L .40753 .53132 L p F P
0 g
s
.77 .655 .736 r
.40753 .53132 m .41192 .5264 L .44539 .53676 L p F P
0 g
s
.753 .656 .755 r
.45037 .48928 m .41192 .5264 L .44539 .53676 L p F P
0 g
s
.753 .656 .755 r
.47037 .49499 m .45037 .48928 L p .44539 .53676 L F P
0 g
s
.721 .526 .626 r
.46641 .7078 m .47346 .68846 L p .51753 .72028 L F P
0 g
s
.734 .537 .626 r
.46641 .7078 m .47346 .68846 L .46374 .68756 L closepath p F P
0 g
s
.724 .66 .786 r
.51794 .44515 m .53068 .47035 L .48994 .49773 L p F P
0 g
s
.724 .66 .786 r
.5116 .44434 m .51794 .44515 L p .48994 .49773 L F P
0 g
s
.724 .66 .786 r
.46181 .4796 m .5116 .44434 L p .48994 .49773 L F P
0 g
s
.724 .66 .786 r
.48994 .49773 m .47037 .49499 L .46181 .4796 L p F P
0 g
s
.752 .55 .622 r
.46374 .68756 m .43091 .68183 L p .46353 .71714 L F P
0 g
s
.752 .55 .622 r
.46353 .71714 m .46641 .7078 L .46374 .68756 L p F P
0 g
s
.781 .665 .735 r
.41405 .57144 m .42276 .56106 L .40753 .53132 L p F P
0 g
s
.603 .503 .714 r
.63563 .5725 m .68771 .55067 L p .68735 .59206 L F P
0 g
s
.603 .503 .714 r
.68735 .59206 m .6432 .59864 L .63563 .5725 L p F P
0 g
s
.61 .529 .738 r
.68451 .54129 m .68771 .55067 L .63563 .5725 L p F P
0 g
s
.61 .529 .738 r
.63563 .5725 m .62851 .55137 L .68451 .54129 L p F P
0 g
s
.608 .53 .741 r
.67371 .51005 m .68451 .54129 L .62851 .55137 L p F P
0 g
s
.608 .53 .741 r
.62851 .55137 m .62229 .53308 L .67371 .51005 L p F P
0 g
s
.623 .448 .624 r
.60409 .70535 m .63976 .67744 L .60159 .6858 L closepath p F P
0 g
s
.671 .484 .624 r
.60159 .6858 m .60409 .70535 L .59796 .71572 L p F P
0 g
s
.798 .662 .713 r
.38441 .55992 m .41405 .57144 L .39193 .60326 L p F P
0 g
s
.781 .665 .735 r
.40753 .53132 m .38441 .55992 L .41405 .57144 L p F P
0 g
s
.617 .555 .763 r
.66996 .5004 m .67371 .51005 L .62229 .53308 L p F P
0 g
s
.617 .555 .763 r
.62229 .53308 m .61407 .51183 L .66996 .5004 L p F P
0 g
s
.751 .67 .772 r
.47037 .49499 m .46181 .4796 L .45037 .48928 L closepath p F P
0 g
s
.603 .503 .713 r
.64604 .6085 m .6432 .59864 L .68735 .59206 L closepath p F P
0 g
s
.591 .473 .686 r
.65402 .64179 m .64604 .6085 L .68735 .59206 L p F P
0 g
s
.614 .558 .768 r
.65556 .46424 m .66996 .5004 L .61407 .51183 L p F P
0 g
s
.614 .558 .768 r
.65463 .46442 m .65556 .46424 L p .61407 .51183 L F P
0 g
s
.614 .558 .768 r
.61407 .51183 m .60498 .48884 L .65463 .46442 L p F P
0 g
s
.681 .631 .792 r
.58105 .43635 m .58526 .4451 L .53068 .47035 L p F P
0 g
s
.681 .631 .792 r
.53068 .47035 m .51794 .44515 L .58105 .43635 L p F P
0 g
s
.664 .454 .589 r
.54078 .72069 m .59796 .71572 L .59171 .74392 L p F P
0 g
s
.664 .454 .589 r
.59171 .74392 m .54215 .74815 L .54078 .72069 L p F P
0 g
s
.705 .485 .588 r
.51753 .72028 m .54078 .72069 L .54215 .74815 L p F P
0 g
s
.721 .526 .626 r
.51753 .72028 m .46767 .71769 L .46641 .7078 L p F P
0 g
s
.748 .545 .621 r
.46767 .71769 m .46641 .7078 L .46353 .71714 L closepath p F P
0 g
s
.705 .485 .588 r
.54215 .74815 m .51348 .74765 L .51753 .72028 L p F P
0 g
s
.718 .498 .59 r
.46767 .71769 m .51753 .72028 L .51348 .74765 L p F P
0 g
s
.777 .595 .653 r
.43091 .68183 m .39443 .67316 L .4073 .64387 L p F P
0 g
s
.795 .619 .662 r
.37475 .6337 m .4073 .64387 L .39443 .67316 L p F P
0 g
s
.79 .63 .684 r
.4073 .64387 m .37475 .6337 L .39193 .60326 L p F P
0 g
s
.752 .55 .622 r
.43091 .68183 m .42255 .71003 L .46353 .71714 L p F P
0 g
s
.782 .577 .623 r
.39443 .67316 m .43091 .68183 L .42255 .71003 L p F P
0 g
s
.774 .692 .773 r
.42097 .47712 m .45037 .48928 L .41192 .5264 L p F P
0 g
s
.76 .688 .782 r
.44658 .45469 m .42097 .47712 L .45037 .48928 L p F P
0 g
s
.76 .688 .782 r
.45037 .48928 m .46181 .4796 L .44658 .45469 L p F P
0 g
s
.582 .443 .657 r
.65402 .64179 m .70705 .62135 L p .67828 .66615 L F P
0 g
s
.582 .443 .657 r
.67828 .66615 m .65874 .66654 L .65402 .64179 L p F P
0 g
s
.591 .473 .686 r
.69951 .59097 m .70705 .62135 L .65402 .64179 L p F P
0 g
s
.591 .473 .686 r
.68735 .59206 m .69951 .59097 L p .65402 .64179 L F P
0 g
s
.632 .478 .656 r
.65402 .64179 m .65874 .66654 L .63976 .67744 L p F P
0 g
s
.623 .582 .787 r
.60498 .48884 m .59968 .47678 L .65463 .46442 L closepath p F P
0 g
s
.738 .672 .786 r
.5116 .44434 m .46181 .4796 L .44658 .45469 L p F P
0 g
s
.624 .448 .625 r
.60532 .71497 m .60409 .70535 L .63976 .67744 L p F P
0 g
s
.665 .478 .622 r
.60532 .71497 m .60409 .70535 L .59796 .71572 L closepath p F P
0 g
s
.806 .655 .695 r
.3629 .59163 m .39193 .60326 L .37475 .6337 L p F P
0 g
s
.798 .662 .713 r
.39193 .60326 m .3629 .59163 L .38441 .55992 L p F P
0 g
s
.718 .498 .59 r
.51348 .74765 m .46872 .74537 L .46767 .71769 L p F P
0 g
s
.748 .521 .587 r
.46353 .71714 m .46767 .71769 L .46872 .74537 L p F P
0 g
s
.785 .682 .75 r
.40753 .53132 m .41192 .5264 L .40226 .52221 L closepath p F P
0 g
s
.774 .692 .773 r
.39194 .506 m .42097 .47712 L p .41192 .5264 L F P
0 g
s
.774 .692 .773 r
.41192 .5264 m .40226 .52221 L .39194 .506 L p F P
0 g
s
.748 .521 .587 r
.46872 .74537 m .4601 .74425 L .46353 .71714 L p F P
0 g
s
.763 .534 .587 r
.42255 .71003 m .46353 .71714 L .4601 .74425 L p F P
0 g
s
.797 .685 .741 r
.38441 .55992 m .40753 .53132 L .40226 .52221 L p F P
0 g
s
.658 .448 .588 r
.59796 .71572 m .60532 .71497 L .60706 .7424 L p F P
0 g
s
.658 .448 .588 r
.60706 .7424 m .59171 .74392 L .59796 .71572 L p F P
0 g
s
.624 .448 .625 r
.63976 .67744 m .65996 .67295 L p .60532 .71497 L F P
0 g
s
.631 .477 .655 r
.65996 .67295 m .65874 .66654 L .63976 .67744 L closepath p F P
0 g
s
.624 .589 .793 r
.65463 .46442 m .59968 .47678 L .58526 .4451 L p F P
0 g
s
.611 .412 .588 r
.60706 .7424 m .60532 .71497 L .66394 .70215 L p F P
0 g
s
.624 .448 .625 r
.65996 .67295 m .66394 .70215 L .60532 .71497 L p F P
0 g
s
.797 .685 .741 r
.40226 .52221 m .38492 .51357 L p .38441 .55992 L F P
0 g
s
.79 .696 .761 r
.40226 .52221 m .39194 .506 L .38492 .51357 L closepath p F P
0 g
s
.683 .646 .807 r
.57075 .41659 m .58105 .43635 L .51794 .44515 L p F P
0 g
s
.683 .646 .807 r
.51794 .44515 m .51597 .44155 L .57075 .41659 L p F P
0 g
s
.72 .661 .791 r
.51794 .44515 m .51597 .44155 L .5116 .44434 L closepath p F P
0 g
s
.816 .686 .721 r
.35866 .54679 m .38441 .55992 L .3629 .59163 L p F P
0 g
s
.797 .685 .741 r
.38492 .51357 m .35866 .54679 L .38441 .55992 L p F P
0 g
s
.582 .444 .658 r
.65996 .67295 m .65874 .66654 L .67828 .66615 L closepath p F P
0 g
s
.738 .672 .786 r
.44658 .45469 m .47318 .43508 L .5116 .44434 L p F P
0 g
s
.726 .678 .803 r
.50105 .41649 m .47318 .43508 L .5116 .44434 L p F P
0 g
s
.726 .678 .803 r
.5116 .44434 m .51597 .44155 L .50105 .41649 L p F P
0 g
s
.689 .659 .815 r
.57075 .41659 m .51597 .44155 L .50105 .41649 L p F P
0 g
s
.782 .577 .623 r
.42255 .71003 m .38612 .70136 L .39443 .67316 L p F P
0 g
s
.801 .598 .628 r
.37063 .66575 m .39443 .67316 L .38612 .70136 L p F P
0 g
s
.795 .619 .662 r
.36672 .65247 m .37475 .6337 L p .39443 .67316 L F P
0 g
s
.795 .619 .662 r
.39443 .67316 m .37063 .66575 L .36672 .65247 L p F P
0 g
s
.567 .407 .623 r
.66394 .70215 m .65996 .67295 L .67828 .66615 L p F P
0 g
s
.815 .638 .663 r
.36672 .65247 m .37475 .6337 L .35811 .62703 L closepath p F P
0 g
s
.806 .655 .695 r
.35158 .61219 m .3629 .59163 L p .37475 .6337 L F P
0 g
s
.806 .655 .695 r
.37475 .6337 m .35811 .62703 L .35158 .61219 L p F P
0 g
s
.763 .534 .587 r
.4601 .74425 m .41898 .73716 L .42255 .71003 L p F P
0 g
s
.784 .554 .587 r
.38612 .70136 m .42255 .71003 L .41898 .73716 L p F P
0 g
s
.655 .418 .548 r
.54215 .74815 m .59171 .74392 L .59743 .76916 L p F P
0 g
s
.655 .418 .548 r
.59743 .76916 m .54132 .77386 L .54215 .74815 L p F P
0 g
s
.7 .455 .55 r
.51348 .74765 m .54215 .74815 L .54132 .77386 L p F P
0 g
s
.7 .455 .55 r
.54132 .77386 m .51644 .77343 L .51348 .74765 L p F P
0 g
s
.714 .465 .548 r
.46872 .74537 m .51348 .74765 L .51644 .77343 L p F P
0 g
s
.624 .589 .793 r
.58526 .4451 m .64125 .43289 L p .65463 .46442 L F P
0 g
s
.619 .596 .806 r
.6288 .40697 m .64125 .43289 L .58526 .4451 L p F P
0 g
s
.619 .596 .806 r
.58526 .4451 m .58105 .43635 L .6288 .40697 L p F P
0 g
s
.792 .712 .776 r
.42097 .47712 m .39194 .506 L .37596 .4841 L p F P
0 g
s
.792 .712 .776 r
.37596 .4841 m .39699 .46275 L .42097 .47712 L p F P
0 g
s
.775 .712 .793 r
.43104 .43228 m .39699 .46275 L .42097 .47712 L p F P
0 g
s
.775 .712 .793 r
.42097 .47712 m .44658 .45469 L .43104 .43228 L p F P
0 g
s
.591 .475 .689 r
.69951 .59097 m .68735 .59206 L .69864 .58749 L closepath p F P
0 g
s
.603 .503 .714 r
.68771 .55067 m .69864 .58749 L .68735 .59206 L p F P
0 g
s
.754 .703 .803 r
.47318 .43508 m .44658 .45469 L .43104 .43228 L p F P
0 g
s
.828 .674 .692 r
.3629 .59163 m .35158 .61219 L .33579 .58161 L p F P
0 g
s
.828 .674 .692 r
.33579 .58161 m .33746 .5785 L .3629 .59163 L p F P
0 g
s
.816 .686 .721 r
.3629 .59163 m .33746 .5785 L .35866 .54679 L p F P
0 g
s
.714 .465 .548 r
.51644 .77343 m .4671 .77097 L .46872 .74537 L p F P
0 g
s
.746 .493 .549 r
.4601 .74425 m .46872 .74537 L .4671 .77097 L p F P
0 g
s
.802 .718 .772 r
.38492 .51357 m .39194 .506 L .37596 .4841 L p F P
0 g
s
.82 .717 .751 r
.36249 .49884 m .38492 .51357 L .35866 .54679 L p F P
0 g
s
.802 .718 .772 r
.37596 .4841 m .36249 .49884 L .38492 .51357 L p F P
0 g
s
.627 .617 .821 r
.62688 .40326 m .6288 .40697 L .58105 .43635 L p F P
0 g
s
.627 .617 .821 r
.58105 .43635 m .57075 .41659 L .62688 .40326 L p F P
0 g
s
.746 .493 .549 r
.4671 .77097 m .4618 .77029 L .4601 .74425 L p F P
0 g
s
.761 .506 .547 r
.41898 .73716 m .4601 .74425 L .4618 .77029 L p F P
0 g
s
.649 .414 .549 r
.59171 .74392 m .60706 .7424 L .60687 .76824 L p F P
0 g
s
.649 .414 .549 r
.60687 .76824 m .59743 .76916 L .59171 .74392 L p F P
0 g
s
.754 .703 .803 r
.43104 .43228 m .44436 .42219 L .47318 .43508 L p F P
0 g
s
.74 .703 .816 r
.48589 .39371 m .44436 .42219 L .47318 .43508 L p F P
0 g
s
.74 .703 .816 r
.47318 .43508 m .50105 .41649 L .48589 .39371 L p F P
0 g
s
.544 .47 .723 r
.69864 .58749 m .68771 .55067 L .70013 .54226 L p F P
0 g
s
.561 .504 .748 r
.68771 .55067 m .68451 .54129 L .70013 .54226 L closepath p F P
0 g
s
.808 .626 .655 r
.37063 .66575 m .36672 .65247 L .3625 .66284 L closepath p F P
0 g
s
.821 .641 .659 r
.3625 .66284 m .36672 .65247 L .35811 .62703 L p F P
0 g
s
.567 .407 .623 r
.67828 .66615 m .71643 .67279 L p .66394 .70215 L F P
0 g
s
.567 .408 .626 r
.71643 .67279 m .67828 .66615 L .71344 .65295 L closepath p F P
0 g
s
.582 .443 .657 r
.70705 .62135 m .71344 .65295 L .67828 .66615 L p F P
0 g
s
.561 .506 .751 r
.70013 .54226 m .68451 .54129 L .67371 .51005 L p F P
0 g
s
.801 .598 .628 r
.38612 .70136 m .37661 .69847 L .37063 .66575 L p F P
0 g
s
.815 .607 .621 r
.3625 .66284 m .37063 .66575 L .37661 .69847 L p F P
0 g
s
.821 .641 .659 r
.35811 .62703 m .34646 .6219 L p .3625 .66284 L F P
0 g
s
.817 .659 .687 r
.35811 .62703 m .35158 .61219 L .34646 .6219 L closepath p F P
0 g
s
.596 .371 .545 r
.60687 .76824 m .60706 .7424 L .66611 .72969 L p F P
0 g
s
.611 .412 .588 r
.66394 .70215 m .66611 .72969 L .60706 .7424 L p F P
0 g
s
.536 .44 .693 r
.69864 .58749 m .74552 .55686 L p .73908 .60226 L F P
0 g
s
.536 .44 .693 r
.73908 .60226 m .69951 .59097 L .69864 .58749 L p F P
0 g
s
.544 .47 .723 r
.74328 .54968 m .74552 .55686 L .69864 .58749 L p F P
0 g
s
.544 .47 .723 r
.70013 .54226 m .74328 .54968 L p .69864 .58749 L F P
0 g
s
.561 .506 .751 r
.67371 .51005 m .68613 .50052 L p .70013 .54226 L F P
0 g
s
.568 .532 .774 r
.67371 .51005 m .66996 .5004 L .68613 .50052 L closepath p F P
0 g
s
.536 .439 .692 r
.70705 .62135 m .69951 .59097 L .73908 .60226 L closepath p F P
0 g
s
.551 .367 .585 r
.66611 .72969 m .66394 .70215 L .7179 .68255 L p F P
0 g
s
.567 .407 .623 r
.71643 .67279 m .7179 .68255 L .66394 .70215 L p F P
0 g
s
.831 .678 .693 r
.34646 .6219 m .35158 .61219 L .33579 .58161 L p F P
0 g
s
.567 .536 .779 r
.68613 .50052 m .66996 .5004 L .65556 .46424 L p F P
0 g
s
.815 .607 .621 r
.37661 .69847 m .35496 .69084 L .3625 .66284 L p F P
0 g
s
.835 .628 .623 r
.335 .65086 m .3625 .66284 L .35496 .69084 L p F P
0 g
s
.821 .641 .659 r
.34646 .6219 m .335 .65086 L .3625 .66284 L p F P
0 g
s
.784 .554 .587 r
.41898 .73716 m .38234 .72855 L .38612 .70136 L p F P
0 g
s
.804 .573 .588 r
.37661 .69847 m .38612 .70136 L .38234 .72855 L p F P
0 g
s
.832 .713 .734 r
.33646 .53212 m .35866 .54679 L .33746 .5785 L p F P
0 g
s
.82 .717 .751 r
.35866 .54679 m .33646 .53212 L .36249 .49884 L p F P
0 g
s
.689 .659 .815 r
.50105 .41649 m .5561 .39048 L .57075 .41659 L p F P
0 g
s
.698 .684 .833 r
.5561 .39048 m .50105 .41649 L .48589 .39371 L p F P
0 g
s
.847 .668 .66 r
.32185 .6086 m .34646 .6219 L .335 .65086 L p F P
0 g
s
.831 .678 .693 r
.33579 .58161 m .32185 .6086 L .34646 .6219 L p F P
0 g
s
.625 .637 .842 r
.62688 .40326 m .57075 .41659 L .5561 .39048 L p F P
0 g
s
.517 .401 .661 r
.71344 .65295 m .70705 .62135 L .73908 .60226 L p F P
0 g
s
.804 .573 .588 r
.38234 .72855 m .37803 .72727 L .37661 .69847 L p F P
0 g
s
.819 .585 .584 r
.35496 .69084 m .37661 .69847 L .37803 .72727 L p F P
0 g
s
.761 .506 .547 r
.4618 .77029 m .42027 .76328 L .41898 .73716 L p F P
0 g
s
.784 .524 .544 r
.38234 .72855 m .41898 .73716 L .42027 .76328 L p F P
0 g
s
.54 .479 .736 r
.74328 .54968 m .70013 .54226 L .73314 .51782 L closepath p F P
0 g
s
.561 .506 .751 r
.72832 .50448 m .73314 .51782 L .70013 .54226 L p F P
0 g
s
.561 .506 .751 r
.68613 .50052 m .72832 .50448 L p .70013 .54226 L F P
0 g
s
.615 .57 .78 r
.65556 .46424 m .65463 .46442 L .65545 .46399 L closepath p F P
0 g
s
.624 .589 .793 r
.64125 .43289 m .65545 .46399 L .65463 .46442 L p F P
0 g
s
.567 .536 .779 r
.65556 .46424 m .71377 .46621 L p .68613 .50052 L F P
0 g
s
.544 .531 .79 r
.69944 .43305 m .71377 .46621 L .65556 .46424 L p F P
0 g
s
.544 .531 .79 r
.68497 .43217 m .69944 .43305 L p .65556 .46424 L F P
0 g
s
.544 .531 .79 r
.65556 .46424 m .65545 .46399 L .68497 .43217 L p F P
0 g
s
.564 .562 .809 r
.65545 .46399 m .64125 .43289 L .68497 .43217 L closepath p F P
0 g
s
.642 .373 .497 r
.53818 .79784 m .54132 .77386 L .59743 .76916 L p F P
0 g
s
.692 .419 .505 r
.51644 .77343 m .54132 .77386 L .53818 .79784 L p F P
0 g
s
.692 .419 .505 r
.53818 .79784 m .52673 .79765 L .51644 .77343 L p F P
0 g
s
.705 .426 .499 r
.4671 .77097 m .51644 .77343 L .52673 .79765 L p F P
0 g
s
.809 .743 .791 r
.39699 .46275 m .37596 .4841 L .35953 .46514 L p F P
0 g
s
.809 .743 .791 r
.35953 .46514 m .37805 .44623 L .39699 .46275 L p F P
0 g
s
.792 .742 .807 r
.41513 .41279 m .37805 .44623 L .39699 .46275 L p F P
0 g
s
.792 .742 .807 r
.39699 .46275 m .43104 .43228 L .41513 .41279 L p F P
0 g
s
.77 .738 .823 r
.44436 .42219 m .43104 .43228 L .41513 .41279 L p F P
0 g
s
.847 .702 .701 r
.33579 .58161 m .33746 .5785 L .33116 .57438 L closepath p F P
0 g
s
.832 .713 .734 r
.31936 .55797 m .33646 .53212 L p .33746 .5785 L F P
0 g
s
.832 .713 .734 r
.33746 .5785 m .33116 .57438 L .31936 .55797 L p F P
0 g
s
.547 .513 .769 r
.72832 .50448 m .68613 .50052 L .71683 .47362 L closepath p F P
0 g
s
.567 .536 .779 r
.71377 .46621 m .71683 .47362 L .68613 .50052 L p F P
0 g
s
.818 .745 .783 r
.36249 .49884 m .37596 .4841 L .35953 .46514 L p F P
0 g
s
.851 .702 .697 r
.32185 .6086 m .33579 .58161 L .33116 .57438 L p F P
0 g
s
.77 .738 .823 r
.41513 .41279 m .42416 .40588 L .44436 .42219 L p F P
0 g
s
.755 .735 .834 r
.47042 .37377 m .42416 .40588 L .44436 .42219 L p F P
0 g
s
.755 .735 .834 r
.44436 .42219 m .48589 .39371 L .47042 .37377 L p F P
0 g
s
.705 .426 .499 r
.46505 .78222 m .4671 .77097 L p .52673 .79765 L F P
0 g
s
.741 .461 .505 r
.46505 .78222 m .4618 .77029 L .4671 .77097 L closepath p F P
0 g
s
.836 .744 .762 r
.3438 .48241 m .36249 .49884 L .33646 .53212 L p F P
0 g
s
.818 .745 .783 r
.35953 .46514 m .3438 .48241 L .36249 .49884 L p F P
0 g
s
.757 .471 .499 r
.4618 .77029 m .46505 .78222 L .46248 .79432 L p F P
0 g
s
.757 .471 .499 r
.42027 .76328 m .4618 .77029 L p .46248 .79432 L F P
0 g
s
.507 .366 .624 r
.71344 .65295 m .76212 .62476 L p .72356 .67951 L F P
0 g
s
.507 .366 .624 r
.72356 .67951 m .71643 .67279 L .71344 .65295 L p F P
0 g
s
.517 .401 .661 r
.75958 .61313 m .76212 .62476 L .71344 .65295 L p F P
0 g
s
.517 .401 .661 r
.73908 .60226 m .75958 .61313 L p .71344 .65295 L F P
0 g
s
.637 .375 .505 r
.60587 .77984 m .59743 .76916 L .60687 .76824 L closepath p F P
0 g
s
.642 .373 .497 r
.59743 .76916 m .60587 .77984 L p .53818 .79784 L F P
0 g
s
.851 .702 .697 r
.33116 .57438 m .31559 .56384 L p .32185 .6086 L F P
0 g
s
.839 .714 .726 r
.33116 .57438 m .31936 .55797 L .31559 .56384 L closepath p F P
0 g
s
.819 .585 .584 r
.37803 .72727 m .35134 .71801 L .35496 .69084 L p F P
0 g
s
.842 .607 .583 r
.32743 .67892 m .35496 .69084 L .35134 .71801 L p F P
0 g
s
.835 .628 .623 r
.35496 .69084 m .32743 .67892 L .335 .65086 L p F P
0 g
s
.53 .319 .539 r
.66644 .75565 m .66611 .72969 L .72052 .71031 L p F P
0 g
s
.551 .367 .585 r
.7179 .68255 m .72052 .71031 L .66611 .72969 L p F P
0 g
s
.596 .371 .545 r
.66611 .72969 m .66644 .75565 L .60687 .76824 L p F P
0 g
s
.578 .322 .492 r
.60687 .76824 m .66644 .75565 L .66487 .78006 L p F P
0 g
s
.578 .322 .492 r
.60587 .77984 m .60687 .76824 L p .66487 .78006 L F P
0 g
s
.858 .652 .624 r
.3104 .63763 m .335 .65086 L .32743 .67892 L p F P
0 g
s
.847 .668 .66 r
.335 .65086 m .3104 .63763 L .32185 .6086 L p F P
0 g
s
.784 .524 .544 r
.42027 .76328 m .3832 .75479 L .38234 .72855 L p F P
0 g
s
.806 .542 .54 r
.37803 .72727 m .38234 .72855 L .3832 .75479 L p F P
0 g
s
.698 .684 .833 r
.48589 .39371 m .54125 .36677 L .5561 .39048 L p F P
0 g
s
.708 .721 .859 r
.54125 .36677 m .48589 .39371 L .47042 .37377 L p F P
0 g
s
.563 .572 .821 r
.68497 .43217 m .64125 .43289 L .6288 .40697 L p F P
0 g
s
.625 .637 .842 r
.5561 .39048 m .61245 .3774 L .62688 .40326 L p F P
0 g
s
.623 .659 .864 r
.61245 .3774 m .5561 .39048 L .54125 .36677 L p F P
0 g
s
.806 .542 .54 r
.3832 .75479 m .37482 .75234 L .37803 .72727 L p F P
0 g
s
.822 .558 .54 r
.35134 .71801 m .37803 .72727 L .37482 .75234 L p F P
0 g
s
.853 .739 .737 r
.33646 .53212 m .31936 .55797 L .30232 .53906 L p F P
0 g
s
.853 .739 .737 r
.30232 .53906 m .31764 .5159 L .33646 .53212 L p F P
0 g
s
.836 .744 .762 r
.33646 .53212 m .31764 .5159 L .3438 .48241 L p F P
0 g
s
.868 .694 .664 r
.30008 .59401 m .32185 .6086 L .3104 .63763 L p F P
0 g
s
.851 .702 .697 r
.31559 .56384 m .30008 .59401 L .32185 .6086 L p F P
0 g
s
.506 .366 .625 r
.7179 .68255 m .71643 .67279 L .72356 .67951 L closepath p F P
0 g
s
.705 .426 .499 r
.52673 .79765 m .47 .79496 L .46505 .78222 L p F P
0 g
s
.721 .434 .49 r
.47 .79496 m .46248 .79432 L .46505 .78222 L closepath p F P
0 g
s
.757 .471 .499 r
.46248 .79432 m .42664 .78842 L .42027 .76328 L p F P
0 g
s
.779 .487 .491 r
.3832 .75479 m .42027 .76328 L .42664 .78842 L p F P
0 g
s
.578 .322 .492 r
.66487 .78006 m .63388 .78649 L .60587 .77984 L p F P
0 g
s
.578 .318 .487 r
.63388 .78649 m .6046 .79245 L .60587 .77984 L closepath p F P
0 g
s
.642 .373 .497 r
.60587 .77984 m .6046 .79245 L .53818 .79784 L p F P
0 g
s
.48 .316 .58 r
.72356 .67951 m .7179 .68255 L .72052 .71031 L p F P
0 g
s
.856 .74 .735 r
.31559 .56384 m .31936 .55797 L .30232 .53906 L p F P
0 g
s
.874 .733 .703 r
.29671 .54777 m .31559 .56384 L .30008 .59401 L p F P
0 g
s
.856 .74 .735 r
.30232 .53906 m .29671 .54777 L .31559 .56384 L p F P
0 g
s
.825 .777 .807 r
.35953 .46514 m .37805 .44623 L .36406 .4275 L p F P
0 g
s
.807 .776 .825 r
.41513 .41279 m .37805 .44623 L .36406 .4275 L p F P
0 g
s
.563 .572 .821 r
.6288 .40697 m .63147 .40299 L p .68497 .43217 L F P
0 g
s
.571 .593 .837 r
.6288 .40697 m .62688 .40326 L .63147 .40299 L closepath p F P
0 g
s
.784 .776 .845 r
.41234 .3861 m .39877 .39642 L .41513 .41279 L p F P
0 g
s
.784 .776 .845 r
.41513 .41279 m .42416 .40588 L .41234 .3861 L p F P
0 g
s
.807 .776 .825 r
.36406 .4275 m .39877 .39642 L .41513 .41279 L p F P
0 g
s
.51 .403 .669 r
.75958 .61313 m .73908 .60226 L .75496 .59217 L closepath p F P
0 g
s
.536 .44 .693 r
.74552 .55686 m .75496 .59217 L .73908 .60226 L p F P
0 g
s
.626 .321 .435 r
.53818 .79784 m .6046 .79245 L .59998 .81492 L p F P
0 g
s
.626 .321 .435 r
.53548 .80897 m .53818 .79784 L p .59998 .81492 L F P
0 g
s
.681 .377 .453 r
.53548 .80897 m .52673 .79765 L .53818 .79784 L closepath p F P
0 g
s
.692 .38 .442 r
.52673 .79765 m .53548 .80897 L .53235 .81988 L p F P
0 g
s
.692 .38 .442 r
.47 .79496 m .52673 .79765 L p .53235 .81988 L F P
0 g
s
.768 .774 .857 r
.47042 .37377 m .42416 .40588 L .41234 .3861 L p F P
0 g
s
.825 .777 .807 r
.36406 .4275 m .34258 .44925 L .35953 .46514 L p F P
0 g
s
.833 .775 .797 r
.35953 .46514 m .3438 .48241 L .32882 .46424 L p F P
0 g
s
.833 .775 .797 r
.32882 .46424 m .34258 .44925 L .35953 .46514 L p F P
0 g
s
.568 .609 .854 r
.63147 .40299 m .62688 .40326 L .61245 .3774 L p F P
0 g
s
.48 .316 .58 r
.72052 .71031 m .73235 .70408 L .72356 .67951 L p F P
0 g
s
.471 .31 .581 r
.76715 .65494 m .72356 .67951 L .73235 .70408 L p F P
0 g
s
.507 .366 .624 r
.76212 .62476 m .76715 .65494 L .72356 .67951 L p F P
0 g
s
.842 .607 .583 r
.35134 .71801 m .32364 .70619 L .32743 .67892 L p F P
0 g
s
.866 .631 .58 r
.30273 .66579 m .32743 .67892 L .32364 .70619 L p F P
0 g
s
.858 .652 .624 r
.32743 .67892 m .30273 .66579 L .3104 .63763 L p F P
0 g
s
.822 .558 .54 r
.37482 .75234 m .35165 .74442 L .35134 .71801 L p F P
0 g
s
.846 .579 .534 r
.32364 .70619 m .35134 .71801 L .35165 .74442 L p F P
0 g
s
.853 .773 .773 r
.3438 .48241 m .32882 .46424 L .30217 .49807 L p F P
0 g
s
.853 .773 .773 r
.30217 .49807 m .31764 .5159 L .3438 .48241 L p F P
0 g
s
.563 .572 .821 r
.63147 .40299 m .68518 .40333 L p .68497 .43217 L F P
0 g
s
.537 .58 .846 r
.63147 .40299 m .68518 .40333 L .67091 .37678 L p F P
0 g
s
.537 .58 .846 r
.67091 .37678 m .64203 .3761 L .63147 .40299 L p F P
0 g
s
.568 .609 .854 r
.61245 .3774 m .64203 .3761 L .63147 .40299 L p F P
0 g
s
.692 .38 .442 r
.53235 .81988 m .48665 .81785 L .47 .79496 L p F P
0 g
s
.708 .381 .423 r
.46248 .79432 m .47 .79496 L .48665 .81785 L p F P
0 g
s
.502 .259 .479 r
.72133 .73642 m .66644 .75565 L .66487 .78006 L p F P
0 g
s
.53 .319 .539 r
.72052 .71031 m .72133 .73642 L .66644 .75565 L p F P
0 g
s
.881 .679 .625 r
.28853 .62316 m .3104 .63763 L .30273 .66579 L p F P
0 g
s
.868 .694 .664 r
.3104 .63763 m .28853 .62316 L .30008 .59401 L p F P
0 g
s
.708 .381 .423 r
.48665 .81785 m .45435 .81515 L .46248 .79432 L p F P
0 g
s
.749 .427 .439 r
.42664 .78842 m .46248 .79432 L .45435 .81515 L p F P
0 g
s
.779 .487 .491 r
.42664 .78842 m .38895 .78007 L .3832 .75479 L p F P
0 g
s
.804 .502 .479 r
.37482 .75234 m .3832 .75479 L .38895 .78007 L p F P
0 g
s
.623 .659 .864 r
.54125 .36677 m .59788 .3538 L .61245 .3774 L p F P
0 g
s
.621 .691 .894 r
.59788 .3538 m .54125 .36677 L .52617 .3462 L p F P
0 g
s
.708 .721 .859 r
.47042 .37377 m .52617 .3462 L .54125 .36677 L p F P
0 g
s
.487 .447 .738 r
.73314 .51782 m .74154 .50816 L p .75014 .55238 L F P
0 g
s
.487 .447 .738 r
.75014 .55238 m .74328 .54968 L .73314 .51782 L p F P
0 g
s
.498 .478 .766 r
.73314 .51782 m .72832 .50448 L .74154 .50816 L closepath p F P
0 g
s
.49 .445 .734 r
.74552 .55686 m .74328 .54968 L .75014 .55238 L closepath p F P
0 g
s
.46 .399 .702 r
.75014 .55238 m .74552 .55686 L .75496 .59217 L p F P
0 g
s
.551 .255 .419 r
.59998 .81492 m .6046 .79245 L .63388 .78649 L p F P
0 g
s
.718 .766 .891 r
.51079 .32914 m .45458 .35693 L .47042 .37377 L p F P
0 g
s
.718 .766 .891 r
.47042 .37377 m .52617 .3462 L .51079 .32914 L p F P
0 g
s
.768 .774 .857 r
.41234 .3861 m .45458 .35693 L .47042 .37377 L p F P
0 g
s
.494 .482 .772 r
.74154 .50816 m .72832 .50448 L .71683 .47362 L p F P
0 g
s
.804 .502 .479 r
.38895 .78007 m .36673 .7737 L .37482 .75234 L p F P
0 g
s
.822 .524 .485 r
.35165 .74442 m .37482 .75234 L .36673 .7737 L p F P
0 g
s
.872 .771 .748 r
.30232 .53906 m .31764 .5159 L .30217 .49807 L p F P
0 g
s
.89 .722 .668 r
.28103 .57811 m .30008 .59401 L .28853 .62316 L p F P
0 g
s
.874 .733 .703 r
.30008 .59401 m .28103 .57811 L .29671 .54777 L p F P
0 g
s
.626 .321 .435 r
.59998 .81492 m .55031 .81881 L .53548 .80897 L p F P
0 g
s
.631 .316 .419 r
.55031 .81881 m .53235 .81988 L .53548 .80897 L closepath p F P
0 g
s
.45 .363 .666 r
.75496 .59217 m .77837 .57003 L p .7675 .6203 L F P
0 g
s
.45 .363 .666 r
.7675 .6203 m .75958 .61313 L .75496 .59217 L p F P
0 g
s
.46 .399 .702 r
.75496 .59217 m .77837 .57003 L .75014 .55238 L p F P
0 g
s
.449 .258 .528 r
.73235 .70408 m .72052 .71031 L .72133 .73642 L p F P
0 g
s
.494 .482 .772 r
.71683 .47362 m .72103 .46758 L p .74154 .50816 L F P
0 g
s
.507 .512 .797 r
.71683 .47362 m .71377 .46621 L .72103 .46758 L closepath p F P
0 g
s
.444 .406 .722 r
.7758 .52337 m .75014 .55238 L .77837 .57003 L p F P
0 g
s
.487 .447 .738 r
.74154 .50816 m .7758 .52337 L .75014 .55238 L p F P
0 g
s
.769 .438 .426 r
.38895 .78007 m .42664 .78842 L .43844 .81256 L p F P
0 g
s
.749 .427 .439 r
.45435 .81515 m .43844 .81256 L .42664 .78842 L p F P
0 g
s
.502 .519 .807 r
.72103 .46758 m .71377 .46621 L .69944 .43305 L p F P
0 g
s
.538 .554 .819 r
.69944 .43305 m .68497 .43217 L .69329 .41966 L closepath p F P
0 g
s
.563 .572 .821 r
.68518 .40333 m .69329 .41966 L .68497 .43217 L p F P
0 g
s
.872 .771 .748 r
.30217 .49807 m .2846 .52431 L .30232 .53906 L p F P
0 g
s
.873 .769 .744 r
.30232 .53906 m .29671 .54777 L .28073 .53027 L p F P
0 g
s
.873 .769 .744 r
.28073 .53027 m .2846 .52431 L .30232 .53906 L p F P
0 g
s
.554 .627 .879 r
.64203 .3761 m .61245 .3774 L .59788 .3538 L p F P
0 g
s
.556 .27 .436 r
.66372 .78779 m .63388 .78649 L .66487 .78006 L closepath p F P
0 g
s
.551 .255 .419 r
.63388 .78649 m .66372 .78779 L p .59998 .81492 L F P
0 g
s
.451 .363 .665 r
.76212 .62476 m .75958 .61313 L .7675 .6203 L closepath p F P
0 g
s
.846 .579 .534 r
.35165 .74442 m .3237 .73271 L .32364 .70619 L p F P
0 g
s
.872 .602 .526 r
.29876 .69317 m .32364 .70619 L .3237 .73271 L p F P
0 g
s
.866 .631 .58 r
.32364 .70619 m .29876 .69317 L .30273 .66579 L p F P
0 g
s
.894 .763 .709 r
.29671 .54777 m .28073 .53027 L .26471 .56086 L p F P
0 g
s
.894 .763 .709 r
.26471 .56086 m .28103 .57811 L .29671 .54777 L p F P
0 g
s
.452 .448 .763 r
.76096 .48031 m .74154 .50816 L .7758 .52337 L p F P
0 g
s
.494 .482 .772 r
.72103 .46758 m .76096 .48031 L .74154 .50816 L p F P
0 g
s
.892 .657 .577 r
.28071 .65145 m .30273 .66579 L .29876 .69317 L p F P
0 g
s
.881 .679 .625 r
.30273 .66579 m .28071 .65145 L .28853 .62316 L p F P
0 g
s
.822 .524 .485 r
.36673 .7737 m .35605 .7701 L .35165 .74442 L p F P
0 g
s
.846 .542 .473 r
.3237 .73271 m .35165 .74442 L .35605 .7701 L p F P
0 g
s
.461 .491 .803 r
.73479 .44083 m .72103 .46758 L .76096 .48031 L p F P
0 g
s
.502 .519 .807 r
.69944 .43305 m .73479 .44083 L .72103 .46758 L p F P
0 g
s
.841 .815 .825 r
.34258 .44925 m .36406 .4275 L .3553 .40637 L p F P
0 g
s
.818 .813 .845 r
.39877 .39642 m .36406 .4275 L .3553 .40637 L p F P
0 g
s
.449 .258 .528 r
.72133 .73642 m .72861 .73266 L .73235 .70408 L p F P
0 g
s
.435 .246 .523 r
.77027 .6831 m .73235 .70408 L .72861 .73266 L p F P
0 g
s
.471 .31 .581 r
.73235 .70408 m .77027 .6831 L .76715 .65494 L p F P
0 g
s
.797 .82 .87 r
.40946 .3625 m .38191 .38302 L .39877 .39642 L p F P
0 g
s
.797 .82 .87 r
.39877 .39642 m .41234 .3861 L .40946 .3625 L p F P
0 g
s
.818 .813 .845 r
.3553 .40637 m .38191 .38302 L .39877 .39642 L p F P
0 g
s
.416 .307 .621 r
.7675 .6203 m .76212 .62476 L .76715 .65494 L p F P
0 g
s
.841 .815 .825 r
.3553 .40637 m .32506 .43634 L .34258 .44925 L p F P
0 g
s
.846 .807 .812 r
.34258 .44925 m .32882 .46424 L .31773 .44419 L p F P
0 g
s
.846 .807 .812 r
.31773 .44419 m .32506 .43634 L .34258 .44925 L p F P
0 g
s
.775 .813 .882 r
.45458 .35693 m .41234 .3861 L .40946 .3625 L p F P
0 g
s
.905 .708 .625 r
.26929 .60743 m .28853 .62316 L .28071 .65145 L p F P
0 g
s
.89 .722 .668 r
.28853 .62316 m .26929 .60743 L .28103 .57811 L p F P
0 g
s
.869 .805 .785 r
.32882 .46424 m .31773 .44419 L .2902 .47852 L p F P
0 g
s
.869 .805 .785 r
.2902 .47852 m .30217 .49807 L .32882 .46424 L p F P
0 g
s
.478 .52 .823 r
.73479 .44083 m .69944 .43305 L .69329 .41966 L p F P
0 g
s
.621 .691 .894 r
.52617 .3462 m .58313 .33305 L .59788 .3538 L p F P
0 g
s
.617 .732 .928 r
.56815 .31541 m .51079 .32914 L .52617 .3462 L p F P
0 g
s
.617 .732 .928 r
.52617 .3462 m .58313 .33305 L .56815 .31541 L p F P
0 g
s
.603 .244 .333 r
.52337 .8397 m .53235 .81988 L .55031 .81881 L p F P
0 g
s
.673 .32 .366 r
.48665 .81785 m .53235 .81988 L .52337 .8397 L p F P
0 g
s
.769 .438 .426 r
.43844 .81256 m .39997 .80439 L .38895 .78007 L p F P
0 g
s
.794 .448 .401 r
.36673 .7737 m .38895 .78007 L .39997 .80439 L p F P
0 g
s
.47 .196 .414 r
.66372 .78779 m .69312 .77031 L .66487 .78006 L closepath p F P
0 g
s
.502 .259 .479 r
.72087 .74812 m .72133 .73642 L p .66487 .78006 L F P
0 g
s
.502 .259 .479 r
.66487 .78006 m .69312 .77031 L .72087 .74812 L p F P
0 g
s
.601 .259 .362 r
.59287 .83562 m .55031 .81881 L .59998 .81492 L closepath p F P
0 g
s
.603 .244 .333 r
.55031 .81881 m .59287 .83562 L p .52337 .8397 L F P
0 g
s
.416 .307 .621 r
.76715 .65494 m .7816 .64321 L .7675 .6203 L p F P
0 g
s
.393 .3 .631 r
.79939 .59054 m .7675 .6203 L .7816 .64321 L p F P
0 g
s
.45 .363 .666 r
.77837 .57003 m .79939 .59054 L .7675 .6203 L p F P
0 g
s
.673 .32 .366 r
.52337 .8397 m .51147 .83918 L .48665 .81785 L p F P
0 g
s
.685 .313 .337 r
.45435 .81515 m .48665 .81785 L .51147 .83918 L p F P
0 g
s
.478 .52 .823 r
.69329 .41966 m .69786 .40505 L p .73479 .44083 L F P
0 g
s
.498 .551 .841 r
.69329 .41966 m .68518 .40333 L .69786 .40505 L closepath p F P
0 g
s
.723 .813 .921 r
.49503 .31529 m .4383 .34299 L .45458 .35693 L p F P
0 g
s
.723 .813 .921 r
.45458 .35693 m .51079 .32914 L .49503 .31529 L p F P
0 g
s
.775 .813 .882 r
.40946 .3625 m .4383 .34299 L .45458 .35693 L p F P
0 g
s
.913 .753 .671 r
.28103 .57811 m .26471 .56086 L .2527 .59039 L p F P
0 g
s
.913 .753 .671 r
.2527 .59039 m .26929 .60743 L .28103 .57811 L p F P
0 g
s
.885 .805 .764 r
.30217 .49807 m .2902 .47852 L .26784 .51121 L p F P
0 g
s
.885 .805 .764 r
.2846 .52431 m .30217 .49807 L p .26784 .51121 L F P
0 g
s
.412 .19 .464 r
.72087 .74812 m .72861 .73266 L .72133 .73642 L closepath p F P
0 g
s
.685 .313 .337 r
.44798 .82546 m .45435 .81515 L p .51147 .83918 L F P
0 g
s
.736 .376 .37 r
.44798 .82546 m .43844 .81256 L .45435 .81515 L closepath p F P
0 g
s
.508 .159 .311 r
.59998 .81492 m .66109 .80273 L .65484 .82354 L p F P
0 g
s
.508 .159 .311 r
.59287 .83562 m .59998 .81492 L p .65484 .82354 L F P
0 g
s
.551 .255 .419 r
.66372 .78779 m .66109 .80273 L .59998 .81492 L p F P
0 g
s
.554 .627 .879 r
.59788 .3538 m .64207 .35225 L .64203 .3761 L p F P
0 g
s
.535 .653 .911 r
.64207 .35225 m .59788 .3538 L .58313 .33305 L p F P
0 g
s
.453 .169 .391 r
.66109 .80273 m .66372 .78779 L .69312 .77031 L p F P
0 g
s
.376 .243 .569 r
.7816 .64321 m .76715 .65494 L .77027 .6831 L p F P
0 g
s
.517 .603 .878 r
.64203 .3761 m .67091 .37678 L .65657 .35274 L p F P
0 g
s
.517 .603 .878 r
.65657 .35274 m .64207 .35225 L .64203 .3761 L p F P
0 g
s
.794 .448 .401 r
.36025 .78255 m .36673 .7737 L p .39997 .80439 L F P
0 g
s
.818 .483 .421 r
.36025 .78255 m .35605 .7701 L .36673 .7737 L closepath p F P
0 g
s
.872 .602 .526 r
.3237 .73271 m .29857 .71981 L .29876 .69317 L p F P
0 g
s
.9 .627 .516 r
.27655 .67895 m .29876 .69317 L .29857 .71981 L p F P
0 g
s
.892 .657 .577 r
.29876 .69317 m .27655 .67895 L .28071 .65145 L p F P
0 g
s
.752 .377 .342 r
.43844 .81256 m .44798 .82546 L .44181 .83288 L p F P
0 g
s
.752 .377 .342 r
.39997 .80439 m .43844 .81256 L p .44181 .83288 L F P
0 g
s
.846 .542 .473 r
.35605 .7701 m .32775 .75851 L .3237 .73271 L p F P
0 g
s
.873 .562 .458 r
.29857 .71981 m .3237 .73271 L .32775 .75851 L p F P
0 g
s
.388 .165 .449 r
.72861 .73266 m .77147 .70934 L p .7202 .76084 L F P
0 g
s
.388 .165 .449 r
.7202 .76084 m .72087 .74812 L .72861 .73266 L p F P
0 g
s
.435 .246 .523 r
.72861 .73266 m .77147 .70934 L .77027 .6831 L p F P
0 g
s
.487 .565 .86 r
.69786 .40505 m .68518 .40333 L .67091 .37678 L p F P
0 g
s
.918 .686 .571 r
.26128 .63587 m .28071 .65145 L .27655 .67895 L p F P
0 g
s
.905 .708 .625 r
.28071 .65145 m .26128 .63587 L .26929 .60743 L p F P
0 g
s
.885 .805 .764 r
.26784 .51121 m .27145 .51672 L .2846 .52431 L p F P
0 g
s
.891 .8 .752 r
.27145 .51672 m .2846 .52431 L .28073 .53027 L closepath p F P
0 g
s
.453 .169 .391 r
.69312 .77031 m .7202 .76084 L p .66109 .80273 L F P
0 g
s
.496 .25 .472 r
.69312 .77031 m .7202 .76084 L .72087 .74812 L closepath p F P
0 g
s
.84 .493 .397 r
.35605 .7701 m .36025 .78255 L .35174 .7899 L p F P
0 g
s
.84 .493 .397 r
.32775 .75851 m .35605 .7701 L p .35174 .7899 L F P
0 g
s
.916 .801 .718 r
.28073 .53027 m .26471 .56086 L .25122 .54215 L p F P
0 g
s
.916 .801 .718 r
.27145 .51672 m .28073 .53027 L p .25122 .54215 L F P
0 g
s
.403 .347 .68 r
.7959 .55025 m .77837 .57003 L .79939 .59054 L p F P
0 g
s
.444 .406 .722 r
.79096 .53364 m .7758 .52337 L p .77837 .57003 L F P
0 g
s
.444 .406 .722 r
.77837 .57003 m .7959 .55025 L .79096 .53364 L p F P
0 g
s
.93 .739 .623 r
.26929 .60743 m .2527 .59039 L .24446 .61901 L p F P
0 g
s
.93 .739 .623 r
.24446 .61901 m .26128 .63587 L .26929 .60743 L p F P
0 g
s
.841 .844 .846 r
.3553 .40637 m .35238 .38251 L .31152 .42181 L p F P
0 g
s
.841 .844 .846 r
.32506 .43634 m .3553 .40637 L p .31152 .42181 L F P
0 g
s
.824 .848 .866 r
.38191 .38302 m .3553 .40637 L .35238 .38251 L p F P
0 g
s
.804 .868 .895 r
.41695 .33441 m .36448 .37221 L .38191 .38302 L p F P
0 g
s
.804 .868 .895 r
.38191 .38302 m .40946 .3625 L .41695 .33441 L p F P
0 g
s
.824 .848 .866 r
.35238 .38251 m .36448 .37221 L .38191 .38302 L p F P
0 g
s
.478 .52 .823 r
.69786 .40505 m .74153 .41576 L .73479 .44083 L p F P
0 g
s
.44 .539 .861 r
.69938 .38117 m .69786 .40505 L .74153 .41576 L p F P
0 g
s
.487 .565 .86 r
.67091 .37678 m .69938 .38117 L .69786 .40505 L p F P
0 g
s
.841 .844 .846 r
.31152 .42181 m .31314 .42969 L .32506 .43634 L p F P
0 g
s
.859 .838 .824 r
.31314 .42969 m .32506 .43634 L .31773 .44419 L closepath p F P
0 g
s
.609 .773 .959 r
.55287 .30065 m .49503 .31529 L .51079 .32914 L p F P
0 g
s
.609 .773 .959 r
.51079 .32914 m .56815 .31541 L .55287 .30065 L p F P
0 g
s
.884 .852 .806 r
.31773 .44419 m .2902 .47852 L .28204 .45707 L p F P
0 g
s
.884 .852 .806 r
.31314 .42969 m .31773 .44419 L p .28204 .45707 L F P
0 g
s
.752 .377 .342 r
.44181 .83288 m .41673 .82772 L .39997 .80439 L p F P
0 g
s
.774 .382 .311 r
.36563 .79482 m .39997 .80439 L .41673 .82772 L p F P
0 g
s
.794 .448 .401 r
.39997 .80439 m .36563 .79482 L .36025 .78255 L p F P
0 g
s
.41 .391 .728 r
.79096 .53364 m .7758 .52337 L .78413 .51144 L closepath p F P
0 g
s
.452 .448 .763 r
.77564 .4875 m .76096 .48031 L p .7758 .52337 L F P
0 g
s
.452 .448 .763 r
.7758 .52337 m .78413 .51144 L .77564 .4875 L p F P
0 g
s
.376 .243 .569 r
.77027 .6831 m .78814 .66887 L .7816 .64321 L p F P
0 g
s
.341 .221 .568 r
.81058 .61648 m .7816 .64321 L .78814 .66887 L p F P
0 g
s
.393 .3 .631 r
.80861 .60613 m .79939 .59054 L p .7816 .64321 L F P
0 g
s
.393 .3 .631 r
.7816 .64321 m .81058 .61648 L .80861 .60613 L p F P
0 g
s
.776 .848 .905 r
.4383 .34299 m .40946 .3625 L .41695 .33441 L p F P
0 g
s
.325 .164 .503 r
.78814 .66887 m .77027 .6831 L .77147 .70934 L p F P
0 g
s
.698 .302 .293 r
.4587 .835 m .44181 .83288 L .44798 .82546 L closepath p F P
0 g
s
.685 .313 .337 r
.51147 .83918 m .4587 .835 L .44798 .82546 L p F P
0 g
s
.387 .049 .264 r
.71689 .78341 m .66109 .80273 L .65484 .82354 L p F P
0 g
s
.453 .169 .391 r
.7202 .76084 m .71689 .78341 L .66109 .80273 L p F P
0 g
s
.82 .458 .37 r
.36563 .79482 m .35174 .7899 L .36025 .78255 L closepath p F P
0 g
s
.461 .491 .803 r
.76098 .45006 m .73479 .44083 L p .76096 .48031 L F P
0 g
s
.411 .47 .811 r
.73479 .44083 m .76098 .45006 L .74662 .41773 L p F P
0 g
s
.411 .47 .811 r
.74662 .41773 m .74153 .41576 L .73479 .44083 L p F P
0 g
s
.935 .788 .673 r
.26471 .56086 m .25122 .54215 L .23884 .57194 L p F P
0 g
s
.935 .788 .673 r
.23884 .57194 m .2527 .59039 L .26471 .56086 L p F P
0 g
s
.416 .437 .774 r
.77564 .4875 m .76096 .48031 L .76777 .46638 L closepath p F P
0 g
s
.461 .491 .803 r
.76096 .48031 m .76777 .46638 L .76098 .45006 L p F P
0 g
s
.457 .576 .886 r
.69938 .38117 m .67091 .37678 L .65657 .35274 L p F P
0 g
s
.326 .061 .349 r
.77067 .73369 m .7202 .76084 L .71689 .78341 L p F P
0 g
s
.388 .165 .449 r
.77147 .70934 m .77067 .73369 L .7202 .76084 L p F P
0 g
s
.535 .653 .911 r
.58313 .33305 m .63231 .3313 L .64207 .35225 L p F P
0 g
s
.514 .688 .946 r
.58313 .33305 m .63231 .3313 L .61285 .31331 L p F P
0 g
s
.514 .688 .946 r
.61285 .31331 m .56815 .31541 L .58313 .33305 L p F P
0 g
s
.873 .562 .458 r
.32775 .75851 m .30233 .74574 L .29857 .71981 L p F P
0 g
s
.901 .584 .437 r
.27615 .70572 m .29857 .71981 L .30233 .74574 L p F P
0 g
s
.9 .627 .516 r
.29857 .71981 m .27615 .70572 L .27655 .67895 L p F P
0 g
s
.907 .842 .769 r
.2902 .47852 m .28204 .45707 L .25877 .49028 L p F P
0 g
s
.907 .842 .769 r
.25877 .49028 m .26784 .51121 L .2902 .47852 L p F P
0 g
s
.719 .851 .945 r
.47885 .30392 m .42154 .3314 L .4383 .34299 L p F P
0 g
s
.719 .851 .945 r
.4383 .34299 m .49503 .31529 L .47885 .30392 L p F P
0 g
s
.776 .848 .905 r
.41695 .33441 m .42154 .3314 L .4383 .34299 L p F P
0 g
s
.928 .654 .501 r
.25694 .66352 m .27655 .67895 L .27615 .70572 L p F P
0 g
s
.918 .686 .571 r
.27655 .67895 m .25694 .66352 L .26128 .63587 L p F P
0 g
s
.562 .154 .225 r
.52337 .8397 m .59286 .83563 L .58208 .85366 L p F P
0 g
s
.562 .154 .225 r
.52021 .84459 m .52337 .8397 L p .58208 .85366 L F P
0 g
s
.603 .244 .333 r
.59287 .83562 m .59286 .83563 L .52337 .8397 L p F P
0 g
s
.649 .257 .288 r
.52021 .84459 m .51147 .83918 L .52337 .8397 L closepath p F P
0 g
s
.653 .235 .239 r
.51147 .83918 m .52021 .84459 L .51008 .85647 L p F P
0 g
s
.653 .235 .239 r
.4587 .835 m .51147 .83918 L p .51008 .85647 L F P
0 g
s
.84 .493 .397 r
.35174 .7899 m .33606 .7836 L .32775 .75851 L p F P
0 g
s
.866 .508 .369 r
.30233 .74574 m .32775 .75851 L .33606 .7836 L p F P
0 g
s
.913 .804 .725 r
.26607 .5144 m .26784 .51121 L .27145 .51672 L closepath p F P
0 g
s
.916 .801 .718 r
.25122 .54215 m .26607 .5144 L .27145 .51672 L p F P
0 g
s
.945 .717 .562 r
.26128 .63587 m .24446 .61901 L .23993 .64682 L p F P
0 g
s
.945 .717 .562 r
.23993 .64682 m .25694 .66352 L .26128 .63587 L p F P
0 g
s
.495 .632 .914 r
.64207 .35225 m .65657 .35274 L .64212 .33162 L p F P
0 g
s
.495 .632 .914 r
.64212 .33162 m .63231 .3313 L .64207 .35225 L p F P
0 g
s
.508 .159 .311 r
.65484 .82354 m .59297 .83561 L .59287 .83562 L p F P
0 g
s
.498 .134 .28 r
.59297 .83561 m .59286 .83563 L .59287 .83562 L closepath p F P
0 g
s
.444 .034 .166 r
.58208 .85366 m .59286 .83563 L .59297 .83561 L p F P
0 g
s
.473 .092 .235 r
.65179 .83047 m .59297 .83561 L .65484 .82354 L closepath p F P
0 g
s
.444 .034 .166 r
.59297 .83561 m .65179 .83047 L p .58208 .85366 L F P
0 g
s
.774 .382 .311 r
.41673 .82772 m .38158 .81832 L .36563 .79482 L p F P
0 g
s
.796 .378 .257 r
.35174 .7899 m .36563 .79482 L .38158 .81832 L p F P
0 g
s
.653 .235 .239 r
.51008 .85647 m .49069 .85499 L .4587 .835 L p F P
0 g
s
.655 .205 .169 r
.44181 .83288 m .4587 .835 L .49069 .85499 L p F P
0 g
s
.353 .355 .722 r
.78413 .51144 m .79084 .49702 L p .80092 .54216 L F P
0 g
s
.353 .355 .722 r
.80092 .54216 m .79096 .53364 L .78413 .51144 L p F P
0 g
s
.379 .402 .759 r
.78413 .51144 m .77564 .4875 L .79084 .49702 L closepath p F P
0 g
s
.936 .845 .729 r
.26607 .5144 m .26784 .51121 L .25877 .49028 L p F P
0 g
s
.366 .356 .716 r
.7959 .55025 m .79096 .53364 L .80092 .54216 L closepath p F P
0 g
s
.562 .154 .225 r
.58208 .85366 m .56044 .85488 L .52021 .84459 L p F P
0 g
s
.553 .115 .162 r
.56044 .85488 m .51008 .85647 L .52021 .84459 L closepath p F P
0 g
s
.873 .86 .825 r
.30684 .427 m .31152 .42181 L .31314 .42969 L closepath p F P
0 g
s
.884 .852 .806 r
.28204 .45707 m .30684 .427 L .31314 .42969 L p F P
0 g
s
.936 .845 .729 r
.25877 .49028 m .24639 .51174 L .26607 .5144 L p F P
0 g
s
.933 .839 .728 r
.26607 .5144 m .25122 .54215 L .24076 .52187 L p F P
0 g
s
.933 .839 .728 r
.24076 .52187 m .24639 .51174 L .26607 .5144 L p F P
0 g
s
.309 .284 .668 r
.80092 .54216 m .7959 .55025 L .8045 .58493 L p F P
0 g
s
.403 .347 .68 r
.79939 .59054 m .8045 .58493 L .7959 .55025 L p F P
0 g
s
.655 .205 .169 r
.43077 .8417 m .44181 .83288 L p .49069 .85499 L F P
0 g
s
.727 .304 .244 r
.43077 .8417 m .41673 .82772 L .44181 .83288 L closepath p F P
0 g
s
.354 .276 .629 r
.80861 .60613 m .79939 .59054 L .8045 .58493 L closepath p F P
0 g
s
.955 .774 .619 r
.2527 .59039 m .23884 .57194 L .23033 .60078 L p F P
0 g
s
.955 .774 .619 r
.23033 .60078 m .24446 .61901 L .2527 .59039 L p F P
0 g
s
.362 .404 .77 r
.79084 .49702 m .77564 .4875 L .76777 .46638 L p F P
0 g
s
.261 .066 .416 r
.78697 .69721 m .77147 .70934 L .77067 .73369 L p F P
0 g
s
.325 .164 .503 r
.77147 .70934 m .78697 .69721 L .78814 .66887 L p F P
0 g
s
.276 .125 .488 r
.81428 .64525 m .78814 .66887 L .78697 .69721 L p F P
0 g
s
.341 .221 .568 r
.78814 .66887 m .81428 .64525 L .81058 .61648 L p F P
0 g
s
.362 .404 .77 r
.76777 .46638 m .77123 .45474 L p .79084 .49702 L F P
0 g
s
.395 .451 .801 r
.76777 .46638 m .76098 .45006 L .77123 .45474 L closepath p F P
0 g
s
.796 .378 .257 r
.34154 .79439 m .35174 .7899 L p .38158 .81832 L F P
0 g
s
.827 .435 .309 r
.34154 .79439 m .33606 .7836 L .35174 .7899 L closepath p F P
0 g
s
.457 .576 .886 r
.65657 .35274 m .69439 .35894 L .69938 .38117 L p F P
0 g
s
.418 .592 .915 r
.69439 .35894 m .65657 .35274 L .64212 .33162 L p F P
0 g
s
.853 .905 .87 r
.35238 .38251 m .31152 .42181 L .3124 .39621 L p F P
0 g
s
.853 .905 .87 r
.35426 .36731 m .35238 .38251 L p .3124 .39621 L F P
0 g
s
.831 .877 .877 r
.35426 .36731 m .36448 .37221 L .35238 .38251 L closepath p F P
0 g
s
.284 .229 .617 r
.8045 .58493 m .81773 .56415 L p .8125 .61403 L F P
0 g
s
.284 .229 .617 r
.8125 .61403 m .80861 .60613 L .8045 .58493 L p F P
0 g
s
.309 .284 .668 r
.8045 .58493 m .81773 .56415 L .80092 .54216 L p F P
0 g
s
.599 .809 .98 r
.53724 .28824 m .47885 .30392 L .49503 .31529 L p F P
0 g
s
.599 .809 .98 r
.49503 .31529 m .55287 .30065 L .53724 .28824 L p F P
0 g
s
.789 .883 .914 r
.36448 .37221 m .41695 .33441 L p .36052 .35388 L F P
0 g
s
.789 .883 .914 r
.36052 .35388 m .35426 .36731 L .36448 .37221 L p F P
0 g
s
.738 .29 .188 r
.41673 .82772 m .43077 .8417 L .42235 .8456 L p F P
0 g
s
.738 .29 .188 r
.38158 .81832 m .41673 .82772 L p .42235 .8456 L F P
0 g
s
.375 .456 .816 r
.77123 .45474 m .76098 .45006 L .74662 .41773 L p F P
0 g
s
.901 .584 .437 r
.30233 .74574 m .27966 .73177 L .27615 .70572 L p F P
0 g
s
.929 .606 .408 r
.25635 .69042 m .27615 .70572 L .27966 .73177 L p F P
0 g
s
.928 .654 .501 r
.27615 .70572 m .25635 .69042 L .25694 .66352 L p F P
0 g
s
.887 .908 .836 r
.30684 .427 m .31152 .42181 L .3124 .39621 L p F P
0 g
s
.44 .539 .861 r
.73244 .38991 m .69938 .38117 L p .74153 .41576 L F P
0 g
s
.387 .531 .879 r
.69938 .38117 m .73244 .38991 L .7183 .36554 L p F P
0 g
s
.387 .531 .879 r
.7183 .36554 m .69439 .35894 L .69938 .38117 L p F P
0 g
s
.866 .508 .369 r
.33606 .7836 m .3103 .77095 L .30233 .74574 L p F P
0 g
s
.892 .523 .332 r
.27966 .73177 m .30233 .74574 L .3103 .77095 L p F P
0 g
s
.887 .908 .836 r
.3124 .39621 m .28773 .42233 L .30684 .427 L p F P
0 g
s
.891 .889 .822 r
.30684 .427 m .28204 .45707 L .27819 .43345 L p F P
0 g
s
.891 .889 .822 r
.27819 .43345 m .28773 .42233 L .30684 .427 L p F P
0 g
s
.242 .254 .673 r
.81262 .51699 m .80092 .54216 L .81773 .56415 L p F P
0 g
s
.353 .355 .722 r
.79084 .49702 m .81262 .51699 L .80092 .54216 L p F P
0 g
s
.957 .825 .673 r
.25122 .54215 m .24076 .52187 L .22791 .55197 L p F P
0 g
s
.957 .825 .673 r
.22791 .55197 m .23884 .57194 L .25122 .54215 L p F P
0 g
s
.955 .683 .48 r
.25694 .66352 m .23993 .64682 L .23918 .67385 L p F P
0 g
s
.955 .683 .48 r
.23918 .67385 m .25635 .69042 L .25694 .66352 L p F P
0 g
s
.496 .726 .975 r
.56815 .31541 m .61285 .31331 L .58315 .29862 L p F P
0 g
s
.496 .726 .975 r
.58315 .29862 m .55287 .30065 L .56815 .31541 L p F P
0 g
s
.846 .433 .253 r
.33606 .7836 m .34154 .79439 L .32282 .79541 L p F P
0 g
s
.846 .433 .253 r
.32282 .79541 m .3103 .77095 L .33606 .7836 L p F P
0 g
s
.251 0 .23 r
.71125 .80413 m .75427 .76348 L .71689 .78341 L closepath p F P
0 g
s
.326 .061 .349 r
.76928 .74492 m .77067 .73369 L p .71689 .78341 L F P
0 g
s
.326 .061 .349 r
.71689 .78341 m .75427 .76348 L .76928 .74492 L p F P
0 g
s
.387 .049 .264 r
.71125 .80413 m .71689 .78341 L p .65484 .82354 L F P
0 g
s
.337 0 .174 r
.65179 .83047 m .71115 .80418 L .65484 .82354 L closepath p F P
0 g
s
.387 .049 .264 r
.65484 .82354 m .71115 .80418 L .71125 .80413 L p F P
0 g
s
.921 .884 .779 r
.28204 .45707 m .27819 .43345 L .25369 .46732 L p F P
0 g
s
.921 .884 .779 r
.25369 .46732 m .25877 .49028 L .28204 .45707 L p F P
0 g
s
.297 .235 .617 r
.81058 .61648 m .80861 .60613 L .8125 .61403 L closepath p F P
0 g
s
.789 .883 .914 r
.41695 .33441 m .41926 .33011 L p .36052 .35388 L F P
0 g
s
.78 .877 .918 r
.41926 .33011 m .42154 .3314 L .41695 .33441 L closepath p F P
0 g
s
.378 .483 .84 r
.74662 .41773 m .74153 .41576 L .74177 .40776 L closepath p F P
0 g
s
.44 .539 .861 r
.74153 .41576 m .74177 .40776 L .73244 .38991 L p F P
0 g
s
.25 .312 .733 r
.79785 .47259 m .79084 .49702 L .81262 .51699 L p F P
0 g
s
.362 .404 .77 r
.77123 .45474 m .79785 .47259 L .79084 .49702 L p F P
0 g
s
.971 .751 .547 r
.24446 .61901 m .23033 .60078 L .22561 .62875 L p F P
0 g
s
.971 .751 .547 r
.22561 .62875 m .23993 .64682 L .24446 .61901 L p F P
0 g
s
.711 .871 .957 r
.41926 .33011 m .42154 .3314 L .47885 .30392 L p F P
0 g
s
.266 .374 .787 r
.77384 .43106 m .77123 .45474 L .79785 .47259 L p F P
0 g
s
.375 .456 .816 r
.74662 .41773 m .77384 .43106 L .77123 .45474 L p F P
0 g
s
.465 .664 .949 r
.64212 .33162 m .63231 .3313 L .61285 .31331 L p F P
0 g
s
.227 .141 .545 r
.8125 .61403 m .81058 .61648 L .81428 .64525 L p F P
0 g
s
.321 .448 .834 r
.77384 .43106 m .74662 .41773 L .74177 .40776 L p F P
0 g
s
.261 .066 .416 r
.77067 .73369 m .77778 .72822 L .78697 .69721 L p F P
0 g
s
.198 .01 .386 r
.8158 .67163 m .78697 .69721 L .77778 .72822 L p F P
0 g
s
.276 .125 .488 r
.78697 .69721 m .8158 .67163 L .81428 .64525 L p F P
0 g
s
.709 .903 .965 r
.40416 .32373 m .41926 .33011 L .46707 .29715 L p F P
0 g
s
.711 .871 .957 r
.47885 .30392 m .46707 .29715 L .41926 .33011 L p F P
0 g
s
.789 .883 .914 r
.41926 .33011 m .40416 .32373 L .36052 .35388 L p F P
0 g
s
.738 .29 .188 r
.42235 .8456 m .40377 .84079 L .38158 .81832 L p F P
0 g
s
.752 .279 .123 r
.35037 .80756 m .38158 .81832 L .40377 .84079 L p F P
0 g
s
.796 .378 .257 r
.38158 .81832 m .35037 .80756 L .34154 .79439 L p F P
0 g
s
.227 .141 .545 r
.81428 .64525 m .8183 .64022 L .8125 .61403 L p F P
0 g
s
.154 .093 .53 r
.82905 .58839 m .8125 .61403 L .8183 .64022 L p F P
0 g
s
.284 .229 .617 r
.81773 .56415 m .82905 .58839 L .8125 .61403 L p F P
0 g
s
.815 .372 .188 r
.35037 .80756 m .34154 .79439 L .32282 .79541 L p F P
0 g
s
.942 .886 .748 r
.25877 .49028 m .25369 .46732 L .23436 .49958 L p F P
0 g
s
.942 .886 .748 r
.24639 .51174 m .25877 .49028 L p .23436 .49958 L F P
0 g
s
.978 .811 .609 r
.23884 .57194 m .22791 .55197 L .21907 .58105 L p F P
0 g
s
.978 .811 .609 r
.21907 .58105 m .23033 .60078 L .23884 .57194 L p F P
0 g
s
.814 .915 .907 r
.34638 .36474 m .36052 .35388 L .35426 .36731 L closepath p F P
0 g
s
.853 .905 .87 r
.3124 .39621 m .34638 .36474 L .35426 .36731 L p F P
0 g
s
.321 .448 .834 r
.74177 .40776 m .74056 .39267 L p .77384 .43106 L F P
0 g
s
.377 .502 .858 r
.74177 .40776 m .73244 .38991 L .74056 .39267 L closepath p F P
0 g
s
.655 .205 .169 r
.49069 .85499 m .44271 .84921 L .43077 .8417 L p F P
0 g
s
.654 .165 .078 r
.44271 .84921 m .42235 .8456 L .43077 .8417 L closepath p F P
0 g
s
.418 .592 .915 r
.64212 .33162 m .68316 .33834 L .69439 .35894 L p F P
0 g
s
.375 .615 .944 r
.64212 .33162 m .68316 .33834 L .66572 .31942 L p F P
0 g
s
.375 .615 .944 r
.66572 .31942 m .62752 .31363 L .64212 .33162 L p F P
0 g
s
.465 .664 .949 r
.61285 .31331 m .62752 .31363 L .64212 .33162 L p F P
0 g
s
.27 0 .074 r
.64539 .84193 m .65179 .83047 L .71115 .80418 L p F P
0 g
s
.444 .034 .166 r
.65179 .83047 m .64539 .84193 L .58208 .85366 L p F P
0 g
s
.479 0 .005 r
.51008 .85647 m .56044 .85488 L p .56657 .86825 L F P
0 g
s
.479 0 .005 r
.50428 .86135 m .51008 .85647 L p .56657 .86825 L F P
0 g
s
.611 .148 .128 r
.50428 .86135 m .49069 .85499 L .51008 .85647 L closepath p F P
0 g
s
.183 0 .31 r
.76928 .74492 m .77778 .72822 L .77067 .73369 L closepath p F P
0 g
s
.597 .095 .032 r
.49069 .85499 m .50428 .86135 L .49044 .86868 L p F P
0 g
s
.597 .095 .032 r
.44271 .84921 m .49069 .85499 L p .49044 .86868 L F P
0 g
s
.518 .069 .123 r
.57847 .85802 m .56044 .85488 L .58208 .85366 L closepath p F P
0 g
s
.479 0 .005 r
.56044 .85488 m .57847 .85802 L .56657 .86825 L p F P
0 g
s
.892 .523 .332 r
.3103 .77095 m .28737 .7571 L .27966 .73177 L p F P
0 g
s
.915 .535 .282 r
.25968 .71659 m .27966 .73177 L .28737 .7571 L p F P
0 g
s
.929 .606 .408 r
.27966 .73177 m .25968 .71659 L .25635 .69042 L p F P
0 g
s
.953 .628 .367 r
.25635 .69042 m .23918 .67385 L .24241 .70013 L p F P
0 g
s
.953 .628 .367 r
.24241 .70013 m .25968 .71659 L .25635 .69042 L p F P
0 g
s
.376 0 .033 r
.57847 .85802 m .58208 .85366 L .64539 .84193 L p F P
0 g
s
.863 .435 .195 r
.3103 .77095 m .32282 .79541 L .32278 .7954 L p F P
0 g
s
.863 .435 .195 r
.28737 .7571 m .3103 .77095 L p .32278 .7954 L F P
0 g
s
.942 .886 .748 r
.23436 .49958 m .23768 .51264 L .24639 .51174 L p F P
0 g
s
.947 .87 .728 r
.23768 .51264 m .24639 .51174 L .24076 .52187 L closepath p F P
0 g
s
.979 .711 .448 r
.23993 .64682 m .22561 .62875 L .22475 .65593 L p F P
0 g
s
.979 .711 .448 r
.22475 .65593 m .23918 .67385 L .23993 .64682 L p F P
0 g
s
.149 .149 .603 r
.82906 .53925 m .81773 .56415 L .82905 .58839 L p F P
0 g
s
.242 .254 .673 r
.81773 .56415 m .82906 .53925 L .81262 .51699 L p F P
0 g
s
.093 0 .247 r
.77778 .72822 m .81087 .69948 L p .76753 .7559 L F P
0 g
s
.093 0 .247 r
.76753 .7559 m .76928 .74492 L .77778 .72822 L p F P
0 g
s
.198 .01 .386 r
.81549 .68311 m .8158 .67163 L p .77778 .72822 L F P
0 g
s
.198 .01 .386 r
.77778 .72822 m .81087 .69948 L .81549 .68311 L p F P
0 g
s
.337 .545 .907 r
.69439 .35894 m .7183 .36554 L .70412 .34412 L p F P
0 g
s
.337 .545 .907 r
.70412 .34412 m .68316 .33834 L .69439 .35894 L p F P
0 g
s
.141 .028 .454 r
.8183 .64022 m .81428 .64525 L .8158 .67163 L p F P
0 g
s
.975 .876 .674 r
.24076 .52187 m .22791 .55197 L .22019 .53031 L p F P
0 g
s
.975 .876 .674 r
.23768 .51264 m .24076 .52187 L p .22019 .53031 L F P
0 g
s
.345 .513 .88 r
.74056 .39267 m .73244 .38991 L .7183 .36554 L p F P
0 g
s
.583 .844 .994 r
.46707 .29715 m .47885 .30392 L .53724 .28824 L p F P
0 g
s
.48 .76 .992 r
.55287 .30065 m .58315 .29862 L .542 .2878 L p F P
0 g
s
.48 .76 .992 r
.542 .2878 m .53724 .28824 L .55287 .30065 L p F P
0 g
s
.597 .095 .032 r
.49044 .86868 m .48273 .86778 L .44271 .84921 L p F P
0 g
s
.575 .035 0 r
.42235 .8456 m .44271 .84921 L .48273 .86778 L p F P
0 g
s
.752 .279 .123 r
.40377 .84079 m .37183 .83019 L .35037 .80756 L p F P
0 g
s
.757 .258 .033 r
.32283 .79543 m .35037 .80756 L .37183 .83019 L p F P
0 g
s
.815 .372 .188 r
.32282 .79541 m .32283 .79543 L .35037 .80756 L p F P
0 g
s
.804 .965 .91 r
.38617 .31795 m .32749 .36092 L .34638 .36474 L p F P
0 g
s
.804 .965 .91 r
.3863 .31797 m .38617 .31795 L p .34638 .36474 L F P
0 g
s
.804 .965 .91 r
.34638 .36474 m .36052 .35388 L .3863 .31797 L p F P
0 g
s
.846 .935 .885 r
.34638 .36474 m .3124 .39621 L .32032 .36725 L p F P
0 g
s
.846 .935 .885 r
.32032 .36725 m .32749 .36092 L .34638 .36474 L p F P
0 g
s
.872 .933 .859 r
.3124 .39621 m .32032 .36725 L .28158 .4065 L p F P
0 g
s
.872 .933 .859 r
.28773 .42233 m .3124 .39621 L p .28158 .4065 L F P
0 g
s
.424 .699 .978 r
.62752 .31363 m .61285 .31331 L .58315 .29862 L p F P
0 g
s
.279 .007 .309 r
.75427 .76348 m .76753 .7559 L .76928 .74492 L closepath p F P
0 g
s
.992 .784 .522 r
.23033 .60078 m .21907 .58105 L .21415 .60922 L p F P
0 g
s
.992 .784 .522 r
.21415 .60922 m .22561 .62875 L .23033 .60078 L p F P
0 g
s
.788 .93 .927 r
.3863 .31797 m .40416 .32373 L .36052 .35388 L closepath p F P
0 g
s
.435 0 0 r
.54967 .86878 m .49044 .86868 L .50428 .86135 L closepath p F P
0 g
s
.479 0 .005 r
.56657 .86825 m .54967 .86878 L .50428 .86135 L p F P
0 g
s
.376 0 .033 r
.64539 .84193 m .63838 .85093 L .57847 .85802 L p F P
0 g
s
.299 0 0 r
.56657 .86825 m .57847 .85802 L .63838 .85093 L p F P
0 g
s
.872 .933 .859 r
.28158 .4065 m .27846 .42138 L .28773 .42233 L p F P
0 g
s
.898 .916 .826 r
.27846 .42138 m .28773 .42233 L .27819 .43345 L closepath p F P
0 g
s
.173 .234 .686 r
.81911 .49283 m .81262 .51699 L .82906 .53925 L p F P
0 g
s
.25 .312 .733 r
.81262 .51699 m .81911 .49283 L .79785 .47259 L p F P
0 g
s
.141 .028 .454 r
.8158 .67163 m .81827 .66858 L .8183 .64022 L p F P
0 g
s
.049 0 .422 r
.83488 .61482 m .8183 .64022 L .81827 .66858 L p F P
0 g
s
.154 .093 .53 r
.8183 .64022 m .83488 .61482 L .82905 .58839 L p F P
0 g
s
.166 0 .144 r
.75427 .76348 m .76753 .7559 L p .71124 .80414 L F P
0 g
s
.166 0 .144 r
.71124 .80414 m .71125 .80413 L .75427 .76348 L p F P
0 g
s
.321 .448 .834 r
.74056 .39267 m .77149 .40843 L .77384 .43106 L p F P
0 g
s
.225 .432 .854 r
.73383 .37097 m .74056 .39267 L .77149 .40843 L p F P
0 g
s
.345 .513 .88 r
.7183 .36554 m .73383 .37097 L .74056 .39267 L p F P
0 g
s
.575 .035 0 r
.41323 .84816 m .42235 .8456 L p .48273 .86778 L F P
0 g
s
.692 .196 .061 r
.41323 .84816 m .40377 .84079 L .42235 .8456 L closepath p F P
0 g
s
.923 .942 .794 r
.27819 .43345 m .25369 .46732 L .25319 .44205 L p F P
0 g
s
.923 .942 .794 r
.27846 .42138 m .27819 .43345 L p .25319 .44205 L F P
0 g
s
.27 0 .074 r
.71115 .80418 m .71124 .80414 L p .64539 .84193 L F P
0 g
s
.359 .005 .221 r
.71115 .80418 m .71124 .80414 L .71125 .80413 L closepath p F P
0 g
s
.056 0 0 r
.76164 .77567 m .71124 .80414 L .70218 .82206 L p F P
0 g
s
.166 0 .144 r
.76753 .7559 m .76164 .77567 L .71124 .80414 L p F P
0 g
s
.27 0 .074 r
.71124 .80414 m .70218 .82206 L .64539 .84193 L p F P
0 g
s
.19 .306 .753 r
.79982 .44917 m .79785 .47259 L .81911 .49283 L p F P
0 g
s
.266 .374 .787 r
.79785 .47259 m .79982 .44917 L .77384 .43106 L p F P
0 g
s
.188 .356 .801 r
.77149 .40843 m .77384 .43106 L .79982 .44917 L p F P
0 g
s
.973 .886 .682 r
.22508 .51937 m .23436 .49958 L .23768 .51264 L closepath p F P
0 g
s
.975 .876 .674 r
.22019 .53031 m .22508 .51937 L .23768 .51264 L p F P
0 g
s
.688 .921 .971 r
.40416 .32373 m .46216 .29508 L p .38712 .31747 L F P
0 g
s
.688 .921 .971 r
.38712 .31747 m .3863 .31797 L .40416 .32373 L p F P
0 g
s
.709 .903 .965 r
.46707 .29715 m .46216 .29508 L .40416 .32373 L p F P
0 g
s
.177 0 0 r
.63838 .85093 m .64539 .84193 L .70218 .82206 L p F P
0 g
s
.333 .641 .965 r
.62752 .31363 m .66572 .31942 L .64176 .30236 L p F P
0 g
s
.333 .641 .965 r
.64176 .30236 m .61269 .29861 L .62752 .31363 L p F P
0 g
s
.424 .699 .978 r
.58315 .29862 m .61269 .29861 L .62752 .31363 L p F P
0 g
s
.993 .848 .59 r
.22791 .55197 m .22019 .53031 L .21095 .55968 L p F P
0 g
s
.993 .848 .59 r
.21095 .55968 m .21907 .58105 L .22791 .55197 L p F P
0 g
s
.675 .143 0 r
.40377 .84079 m .41323 .84816 L .39535 .84833 L p F P
0 g
s
.675 .143 0 r
.39535 .84833 m .37183 .83019 L .40377 .84079 L p F P
0 g
s
.915 .535 .282 r
.28737 .7571 m .26723 .74202 L .25968 .71659 L p F P
0 g
s
.927 .541 .213 r
.25968 .71659 m .24241 .70013 L .24988 .72565 L p F P
0 g
s
.927 .541 .213 r
.24988 .72565 m .26723 .74202 L .25968 .71659 L p F P
0 g
s
.863 .435 .195 r
.32278 .7954 m .29964 .78169 L .28737 .7571 L p F P
0 g
s
.871 .428 .115 r
.26723 .74202 m .28737 .7571 L .29964 .78169 L p F P
0 g
s
.955 .928 .734 r
.25369 .46732 m .25319 .44205 L .23276 .47492 L p F P
0 g
s
.955 .928 .734 r
.23276 .47492 m .23436 .49958 L .25369 .46732 L p F P
0 g
s
.967 .644 .31 r
.23918 .67385 m .22475 .65593 L .22792 .68231 L p F P
0 g
s
.967 .644 .31 r
.22792 .68231 m .24241 .70013 L .23918 .67385 L p F P
0 g
s
0 0 .079 r
.79405 .73337 m .76753 .7559 L .76164 .77567 L p F P
0 g
s
.093 0 .247 r
.81087 .69948 m .79405 .73337 L .76753 .7559 L p F P
0 g
s
.285 .515 .901 r
.73383 .37097 m .7183 .36554 L .70412 .34412 L p F P
0 g
s
.038 0 .336 r
.81549 .68311 m .81827 .66858 L .8158 .67163 L closepath p F P
0 g
s
.37 .729 .989 r
.61269 .29861 m .58315 .29862 L .542 .2878 L p F P
0 g
s
.032 .015 .502 r
.84028 .56372 m .82905 .58839 L .83488 .61482 L p F P
0 g
s
.149 .149 .603 r
.82905 .58839 m .84028 .56372 L .82906 .53925 L p F P
0 g
s
.82 .349 .086 r
.32283 .79543 m .32278 .7954 L .32282 .79541 L closepath p F P
0 g
s
.757 .258 .033 r
.37183 .83019 m .34375 .81819 L .32283 .79543 L p F P
0 g
s
.736 .21 0 r
.32278 .7954 m .32283 .79543 L .34375 .81819 L p F P
0 g
s
.736 .21 0 r
.30407 .78819 m .32278 .7954 L p .34375 .81819 L F P
0 g
s
.816 .337 .052 r
.30407 .78819 m .29964 .78169 L .32278 .7954 L closepath p F P
0 g
s
.527 .858 .996 r
.46216 .29508 m .46707 .29715 L .53512 .28685 L p F P
0 g
s
.583 .844 .994 r
.53724 .28824 m .53512 .28685 L .46707 .29715 L p F P
0 g
s
.991 .734 .4 r
.22561 .62875 m .21415 .60922 L .2132 .63653 L p F P
0 g
s
.991 .734 .4 r
.2132 .63653 m .22475 .65593 L .22561 .62875 L p F P
0 g
s
.903 .96 .818 r
.26757 .42307 m .28158 .4065 L .27846 .42138 L closepath p F P
0 g
s
.923 .942 .794 r
.25319 .44205 m .26757 .42307 L .27846 .42138 L p F P
0 g
s
.274 .557 .93 r
.70412 .34412 m .68316 .33834 L .66572 .31942 L p F P
0 g
s
0 0 .268 r
.81827 .66858 m .83507 .64341 L p .81487 .69543 L F P
0 g
s
0 0 .268 r
.81487 .69543 m .81549 .68311 L .81827 .66858 L p F P
0 g
s
.049 0 .422 r
.81827 .66858 m .83507 .64341 L .83488 .61482 L p F P
0 g
s
.575 .035 0 r
.48273 .86778 m .43927 .86044 L .41323 .84816 L p F P
0 g
s
.526 0 0 r
.43927 .86044 m .41323 .84816 L .39535 .84833 L p F P
0 g
s
.972 .924 .676 r
.23436 .49958 m .23276 .47492 L .21743 .50626 L p F P
0 g
s
.972 .924 .676 r
.22508 .51937 m .23436 .49958 L p .21743 .50626 L F P
0 g
s
.446 .776 .998 r
.53512 .28685 m .53724 .28824 L .542 .2878 L closepath p F P
0 g
s
1 .812 .481 r
.21907 .58105 m .21095 .55968 L .20581 .58806 L p F P
0 g
s
1 .812 .481 r
.20581 .58806 m .21415 .60922 L .21907 .58105 L p F P
0 g
s
.048 .098 .593 r
.83378 .52172 m .82906 .53925 L .84028 .56372 L p F P
0 g
s
.173 .234 .686 r
.82937 .50727 m .81911 .49283 L p .82906 .53925 L F P
0 g
s
.173 .234 .686 r
.82906 .53925 m .83378 .52172 L .82937 .50727 L p F P
0 g
s
.648 .09 0 r
.37183 .83019 m .39535 .84833 L .38707 .8463 L p F P
0 g
s
.648 .09 0 r
.34375 .81819 m .37183 .83019 L p .38707 .8463 L F P
0 g
s
.517 .875 .985 r
.46216 .29508 m .52118 .27976 L p .50363 .2734 L F P
0 g
s
.517 .875 .985 r
.50363 .2734 m .44489 .28963 L .46216 .29508 L p F P
0 g
s
.527 .858 .996 r
.53512 .28685 m .52118 .27976 L .46216 .29508 L p F P
0 g
s
.688 .921 .971 r
.46216 .29508 m .44489 .28963 L .38712 .31747 L p F P
0 g
s
.103 0 .335 r
.81087 .69948 m .81487 .69543 L .81549 .68311 L closepath p F P
0 g
s
.36 .766 .983 r
.542 .2878 m .59757 .28617 L p .56698 .27687 L F P
0 g
s
.36 .766 .983 r
.53512 .28685 m .542 .2878 L p .56698 .27687 L F P
0 g
s
.37 .729 .989 r
.542 .2878 m .59757 .28617 L .61269 .29861 L p F P
0 g
s
.225 .432 .854 r
.77149 .40843 m .76442 .38682 L .73383 .37097 L p F P
0 g
s
.146 .424 .864 r
.72218 .35041 m .73383 .37097 L .76442 .38682 L p F P
0 g
s
.285 .515 .901 r
.70412 .34412 m .72218 .35041 L .73383 .37097 L p F P
0 g
s
.36 .766 .983 r
.56698 .27687 m .52118 .27976 L .53512 .28685 L p F P
0 g
s
.177 0 0 r
.70218 .82206 m .69908 .82636 L .63838 .85093 L p F P
0 g
s
.035 0 0 r
.63162 .85703 m .63838 .85093 L .69908 .82636 L p F P
0 g
s
.299 0 0 r
.63838 .85093 m .63162 .85703 L .56657 .86825 L p F P
0 g
s
.351 0 0 r
.54967 .86878 m .56333 .87032 L p .48783 .86964 L F P
0 g
s
.351 0 0 r
.48783 .86964 m .49044 .86868 L .54967 .86878 L p F P
0 g
s
.413 0 0 r
.56333 .87032 m .54967 .86878 L .56657 .86825 L closepath p F P
0 g
s
.53 0 0 r
.48783 .86964 m .48273 .86778 L .49044 .86868 L closepath p F P
0 g
s
.054 .172 .671 r
.82937 .50727 m .81911 .49283 L .82017 .47946 L closepath p F P
0 g
s
.19 .306 .753 r
.8138 .46303 m .79982 .44917 L p .81911 .49283 L F P
0 g
s
.19 .306 .753 r
.81911 .49283 m .82017 .47946 L .8138 .46303 L p F P
0 g
s
.848 .986 .857 r
.32032 .36725 m .28158 .4065 L .29435 .37526 L p F P
0 g
s
.848 .986 .857 r
.32335 .36047 m .32032 .36725 L p .29435 .37526 L F P
0 g
s
.844 .953 .886 r
.32335 .36047 m .32749 .36092 L .32032 .36725 L closepath p F P
0 g
s
.972 .924 .676 r
.21743 .50626 m .21898 .52411 L .22508 .51937 L p F P
0 g
s
.98 .9 .661 r
.21898 .52411 m .22508 .51937 L .22019 .53031 L closepath p F P
0 g
s
.204 0 0 r
.56333 .87032 m .56657 .86825 L .63162 .85703 L p F P
0 g
s
.776 .962 .926 r
.32749 .36092 m .38617 .31795 L p .3505 .32905 L F P
0 g
s
.776 .962 .926 r
.3505 .32905 m .32335 .36047 L .32749 .36092 L p F P
0 g
s
.188 .356 .801 r
.79982 .44917 m .79707 .4267 L .77149 .40843 L p F P
0 g
s
.121 .355 .818 r
.76442 .38682 m .77149 .40843 L .79707 .4267 L p F P
0 g
s
.472 0 0 r
.48273 .86778 m .48783 .86964 L .47091 .87179 L p F P
0 g
s
.472 0 0 r
.47091 .87179 m .43927 .86044 L .48273 .86778 L p F P
0 g
s
.871 .428 .115 r
.29964 .78169 m .27934 .7667 L .26723 .74202 L p F P
0 g
s
.856 .409 .011 r
.26723 .74202 m .24988 .72565 L .26196 .75039 L p F P
0 g
s
.856 .409 .011 r
.26196 .75039 m .27934 .7667 L .26723 .74202 L p F P
0 g
s
.916 .533 .121 r
.24241 .70013 m .22792 .68231 L .23542 .70791 L p F P
0 g
s
.916 .533 .121 r
.23542 .70791 m .24988 .72565 L .24241 .70013 L p F P
0 g
s
.049 .233 .732 r
.79982 .44917 m .8138 .46303 L .79911 .42881 L p F P
0 g
s
.049 .233 .732 r
.79911 .42881 m .79707 .4267 L .79982 .44917 L p F P
0 g
s
0 0 .159 r
.81487 .69543 m .81087 .69948 L .79405 .73337 L p F P
0 g
s
.88 .986 .82 r
.28158 .4065 m .29435 .37526 L .26057 .41313 L p F P
0 g
s
.88 .986 .82 r
.26757 .42307 m .28158 .4065 L p .26057 .41313 L F P
0 g
s
.219 .52 .916 r
.70412 .34412 m .72217 .35041 L .70555 .33107 L p F P
0 g
s
.219 .52 .916 r
.70555 .33107 m .68987 .32578 L .70412 .34412 L p F P
0 g
s
.274 .557 .93 r
.66572 .31942 m .68987 .32578 L .70412 .34412 L p F P
0 g
s
.296 .665 .973 r
.61269 .29861 m .64176 .30236 L .61066 .28747 L p F P
0 g
s
.296 .665 .973 r
.61066 .28747 m .59757 .28617 L .61269 .29861 L p F P
0 g
s
0 0 .359 r
.8462 .59034 m .83488 .61482 L .83507 .64341 L p F P
0 g
s
.032 .015 .502 r
.83488 .61482 m .8462 .59034 L .84028 .56372 L p F P
0 g
s
.798 .306 0 r
.29964 .78169 m .30407 .78819 L .28523 .77536 L p F P
0 g
s
.798 .306 0 r
.28523 .77536 m .27934 .7667 L .29964 .78169 L p F P
0 g
s
.957 .645 .228 r
.22475 .65593 m .2132 .63653 L .21639 .66302 L p F P
0 g
s
.957 .645 .228 r
.21639 .66302 m .22792 .68231 L .22475 .65593 L p F P
0 g
s
.992 .877 .558 r
.22019 .53031 m .21898 .52411 L .20759 .54331 L p F P
0 g
s
.992 .877 .558 r
.20759 .54331 m .21095 .55968 L .22019 .53031 L p F P
0 g
s
.351 0 0 r
.56333 .87032 m .54757 .87598 L .48783 .86964 L p F P
0 g
s
.199 0 0 r
.48783 .86964 m .54757 .87598 L .54269 .87644 L p F P
0 g
s
.199 0 0 r
.47091 .87179 m .48783 .86964 L p .54269 .87644 L F P
0 g
s
.88 .986 .82 r
.26057 .41313 m .25559 .42645 L .26757 .42307 L p F P
0 g
s
.921 .961 .788 r
.25559 .42645 m .26757 .42307 L .25319 .44205 L closepath p F P
0 g
s
.194 .564 .936 r
.68987 .32578 m .66572 .31942 L .64176 .30236 L p F P
0 g
s
0 0 0 r
.69908 .82636 m .71754 .81341 L .70218 .82206 L closepath p F P
0 g
s
.056 0 0 r
.75941 .7805 m .76164 .77567 L p .70218 .82206 L F P
0 g
s
.056 0 0 r
.70218 .82206 m .71754 .81341 L .75941 .7805 L p F P
0 g
s
.773 .991 .885 r
.30757 .36257 m .3505 .32905 L .32335 .36047 L closepath p F P
0 g
s
.848 .986 .857 r
.29435 .37526 m .30757 .36257 L .32335 .36047 L p F P
0 g
s
.009 0 0 r
.56333 .87032 m .6241 .86201 L .61089 .86662 L p F P
0 g
s
.009 0 0 r
.54757 .87598 m .56333 .87032 L p .61089 .86662 L F P
0 g
s
.204 0 0 r
.63162 .85703 m .6241 .86201 L .56333 .87032 L p F P
0 g
s
0 0 .078 r
.82937 .67415 m .81487 .69543 L .81109 .71632 L p F P
0 g
s
0 0 .268 r
.83507 .64341 m .82937 .67415 L .81487 .69543 L p F P
0 g
s
0 0 .159 r
.79405 .73337 m .81109 .71632 L .81487 .69543 L p F P
0 g
s
.662 .951 .953 r
.38617 .31795 m .38712 .31747 L .3863 .31797 L closepath p F P
0 g
s
.61 .951 .918 r
.42693 .28783 m .36732 .31732 L .38617 .31795 L p F P
0 g
s
.61 .951 .918 r
.43836 .28802 m .42693 .28783 L p .38617 .31795 L F P
0 g
s
.61 .951 .918 r
.38617 .31795 m .38712 .31747 L .43836 .28802 L p F P
0 g
s
.776 .962 .926 r
.38617 .31795 m .36732 .31732 L .3505 .32905 L p F P
0 g
s
.665 .938 .966 r
.43836 .28802 m .44489 .28963 L .38712 .31747 L closepath p F P
0 g
s
.924 .975 .715 r
.25319 .44205 m .23276 .47492 L .2362 .44771 L p F P
0 g
s
.924 .975 .715 r
.25559 .42645 m .25319 .44205 L p .2362 .44771 L F P
0 g
s
.978 .742 .327 r
.21415 .60922 m .20581 .58806 L .2048 .61553 L p F P
0 g
s
.978 .742 .327 r
.2048 .61553 m .2132 .63653 L .21415 .60922 L p F P
0 g
s
.736 .21 0 r
.34375 .81819 m .31939 .80479 L .30407 .78819 L p F P
0 g
s
.681 .149 0 r
.31939 .80479 m .30407 .78819 L .28523 .77536 L p F P
0 g
s
.389 0 0 r
.43927 .86044 m .47091 .87179 L .4567 .87005 L p F P
0 g
s
.389 0 0 r
.40172 .85128 m .43927 .86044 L p .4567 .87005 L F P
0 g
s
.526 0 0 r
.39535 .84833 m .40172 .85128 L .43927 .86044 L p F P
0 g
s
.648 .09 0 r
.38707 .8463 m .37151 .83983 L .34375 .81819 L p F P
0 g
s
.591 .024 0 r
.31939 .80479 m .34375 .81819 L .37151 .83983 L p F P
0 g
s
.979 .898 .553 r
.21898 .52411 m .21743 .50626 L .20694 .53625 L p F P
0 g
s
.979 .898 .553 r
.20694 .53625 m .20759 .54331 L .21898 .52411 L p F P
0 g
s
0 0 0 r
.75941 .7805 m .76845 .76994 L .76164 .77567 L closepath p F P
0 g
s
0 0 .079 r
.76164 .77567 m .76845 .76994 L .79405 .73337 L p F P
0 g
s
0 0 0 r
.81109 .71632 m .79405 .73337 L .76845 .76994 L p F P
0 g
s
.076 .168 .658 r
.83378 .52172 m .82937 .50727 L .8348 .51546 L closepath p F P
0 g
s
.003 .137 .653 r
.8348 .51546 m .82937 .50727 L .82017 .47946 L p F P
0 g
s
0 .014 .549 r
.8348 .51546 m .83378 .52172 L .84222 .55683 L p F P
0 g
s
.048 .098 .593 r
.84028 .56372 m .84222 .55683 L .83378 .52172 L p F P
0 g
s
0 0 .461 r
.84222 .55683 m .84028 .56372 L .8462 .59034 L p F P
0 g
s
.003 .137 .653 r
.82017 .47946 m .82019 .46977 L p .8348 .51546 L F P
0 g
s
.106 .25 .729 r
.82017 .47946 m .8138 .46303 L .82019 .46977 L closepath p F P
0 g
s
0 0 0 r
.68871 .83636 m .69908 .82636 L .71754 .81341 L p F P
0 g
s
.035 0 0 r
.69908 .82636 m .68871 .83636 L .63162 .85703 L p F P
0 g
s
0 0 0 r
.6241 .86201 m .63162 .85703 L .68871 .83636 L p F P
0 g
s
.146 .424 .864 r
.76442 .38682 m .75273 .36622 L .72218 .35041 L p F P
0 g
s
.051 .408 .86 r
.72217 .35041 m .70555 .33107 L .73638 .34669 L p F P
0 g
s
.051 .408 .86 r
.73638 .34669 m .75273 .36622 L .72217 .35041 L p F P
0 g
s
.027 .224 .729 r
.82019 .46977 m .8138 .46303 L .79911 .42881 L p F P
0 g
s
0 0 0 r
.71754 .81341 m .752 .79207 L p .68871 .83636 L F P
0 g
s
0 0 0 r
.71754 .81341 m .752 .79207 L .75941 .7805 L closepath p F P
0 g
s
.424 0 0 r
.40172 .85128 m .38707 .8463 L .39535 .84833 L closepath p F P
0 g
s
.978 .824 .418 r
.21095 .55968 m .20759 .54331 L .20154 .56814 L p F P
0 g
s
.978 .824 .418 r
.20154 .56814 m .20581 .58806 L .21095 .55968 L p F P
0 g
s
.946 .943 .617 r
.23276 .47492 m .2362 .44771 L .21997 .47961 L p F P
0 g
s
.946 .943 .617 r
.21997 .47961 m .21743 .50626 L .23276 .47492 L p F P
0 g
s
0 0 .169 r
.84663 .61911 m .83507 .64341 L .82937 .67415 L p F P
0 g
s
0 0 .359 r
.83507 .64341 m .84663 .61911 L .8462 .59034 L p F P
0 g
s
0 0 0 r
.76845 .76994 m .79605 .74291 L p .752 .79207 L F P
0 g
s
0 0 0 r
.752 .79207 m .75941 .7805 L .76845 .76994 L p F P
0 g
s
0 0 0 r
.80748 .72645 m .81109 .71632 L p .76845 .76994 L F P
0 g
s
0 0 0 r
.76845 .76994 m .79605 .74291 L .80748 .72645 L p F P
0 g
s
0 .014 .549 r
.84222 .55683 m .84499 .54041 L .8348 .51546 L p F P
0 g
s
0 0 .493 r
.83483 .49285 m .8348 .51546 L .84499 .54041 L p F P
0 g
s
.003 .137 .653 r
.82019 .46977 m .83483 .49285 L .8348 .51546 L p F P
0 g
s
.311 .759 .96 r
.50474 .27318 m .52118 .27976 L .56698 .27687 L closepath p F P
0 g
s
.517 .875 .985 r
.52118 .27976 m .50474 .27318 L .50363 .2734 L p F P
0 g
s
0 0 .398 r
.84499 .54041 m .84222 .55683 L .8471 .58727 L p F P
0 g
s
0 0 .461 r
.8462 .59034 m .8471 .58727 L .84222 .55683 L p F P
0 g
s
.802 .368 0 r
.24988 .72565 m .23542 .70791 L p .24763 .73273 L F P
0 g
s
.802 .368 0 r
.24763 .73273 m .26196 .75039 L .24988 .72565 L p F P
0 g
s
.193 .6 .945 r
.64176 .30236 m .61066 .28747 L .65565 .29684 L p F P
0 g
s
.193 .6 .945 r
.67547 .31044 m .64176 .30236 L p .65565 .29684 L F P
0 g
s
.194 .564 .936 r
.64176 .30236 m .67547 .31044 L .68987 .32578 L p F P
0 g
s
.121 .355 .818 r
.78491 .40175 m .76442 .38682 L p .79707 .4267 L F P
0 g
s
0 .298 .795 r
.76442 .38682 m .78491 .40175 L .77093 .37952 L p F P
0 g
s
0 .298 .795 r
.77093 .37952 m .75273 .36622 L .76442 .38682 L p F P
0 g
s
.863 .5 .001 r
.22792 .68231 m .21639 .66302 L .224 .68867 L p F P
0 g
s
.863 .5 .001 r
.224 .68867 m .23542 .70791 L .22792 .68231 L p F P
0 g
s
.389 0 0 r
.4567 .87005 m .44973 .86842 L .40172 .85128 L p F P
0 g
s
.273 0 0 r
.38707 .8463 m .40172 .85128 L .44973 .86842 L p F P
0 g
s
.749 .261 0 r
.28523 .77536 m .27934 .7667 L .26196 .75039 L p F P
0 g
s
.154 .527 .92 r
.68987 .32578 m .70555 .33107 L .68375 .31306 L p F P
0 g
s
.154 .527 .92 r
.68375 .31306 m .67547 .31044 L .68987 .32578 L p F P
0 g
s
0 .018 .588 r
.81634 .44772 m .82019 .46977 L .83483 .49285 L p F P
0 g
s
.027 .224 .729 r
.79911 .42881 m .81634 .44772 L .82019 .46977 L p F P
0 g
s
.49 .875 .971 r
.43836 .28802 m .44489 .28963 L .50363 .2734 L closepath p F P
0 g
s
0 .188 .718 r
.79911 .42881 m .79707 .4267 L .79504 .4206 L closepath p F P
0 g
s
.121 .355 .818 r
.79707 .4267 m .79504 .4206 L .78491 .40175 L p F P
0 g
s
.882 .987 .724 r
.24584 .43303 m .26057 .41313 L .25559 .42645 L closepath p F P
0 g
s
.924 .975 .715 r
.2362 .44771 m .24584 .43303 L .25559 .42645 L p F P
0 g
s
.901 .618 .116 r
.2132 .63653 m .2048 .61553 L .20807 .6421 L p F P
0 g
s
.901 .618 .116 r
.20807 .6421 m .21639 .66302 L .2132 .63653 L p F P
0 g
s
0 .155 .696 r
.81634 .44772 m .79911 .42881 L .79504 .4206 L p F P
0 g
s
.232 .662 .958 r
.5888 .28033 m .59757 .28617 L .61066 .28747 L closepath p F P
0 g
s
.36 .766 .983 r
.59757 .28617 m .5888 .28033 L .56698 .27687 L p F P
0 g
s
.591 .024 0 r
.37151 .83983 m .34681 .82651 L .31939 .80479 L p F P
0 g
s
.49 0 0 r
.29867 .78994 m .31939 .80479 L .34681 .82651 L p F P
0 g
s
.681 .149 0 r
.28523 .77536 m .29867 .78994 L .31939 .80479 L p F P
0 g
s
.273 0 0 r
.37716 .84337 m .38707 .8463 L p .44973 .86842 L F P
0 g
s
.538 0 0 r
.37716 .84337 m .37151 .83983 L .38707 .8463 L closepath p F P
0 g
s
.918 .886 .467 r
.21743 .50626 m .21997 .47961 L .20897 .50999 L p F P
0 g
s
.918 .886 .467 r
.20897 .50999 m .20694 .53625 L .21743 .50626 L p F P
0 g
s
0 .155 .696 r
.79504 .4206 m .78948 .40526 L p .81634 .44772 L F P
0 g
s
.053 .308 .794 r
.79504 .4206 m .78491 .40175 L .78948 .40526 L closepath p F P
0 g
s
0 0 .267 r
.8471 .58727 m .8462 .59034 L .84663 .61911 L p F P
0 g
s
.574 .068 0 r
.28523 .77536 m .29867 .78994 L .28163 .77357 L p F P
0 g
s
.574 .068 0 r
.28163 .77357 m .26637 .75692 L .28523 .77536 L p F P
0 g
s
.749 .261 0 r
.26196 .75039 m .26637 .75692 L .28523 .77536 L p F P
0 g
s
0 0 0 r
.68871 .83636 m .68585 .83836 L .6241 .86201 L p F P
0 g
s
.277 .766 .687 r
.61089 .86662 m .6241 .86201 L .68585 .83836 L p F P
0 g
s
0 0 0 r
.84128 .65004 m .82937 .67415 L .81745 .70704 L p F P
0 g
s
0 0 .169 r
.82937 .67415 m .84128 .65004 L .84663 .61911 L p F P
0 g
s
0 0 .078 r
.81109 .71632 m .81745 .70704 L .82937 .67415 L p F P
0 g
s
0 0 0 r
.80748 .72645 m .81745 .70704 L .81109 .71632 L closepath p F P
0 g
s
.199 0 0 r
.54269 .87644 m .49933 .87456 L .47091 .87179 L p F P
0 g
s
0 .533 .726 r
.49933 .87456 m .4567 .87005 L .47091 .87179 L closepath p F P
0 g
s
.728 .989 .871 r
.30757 .36257 m .3505 .32905 L p .33097 .33408 L F P
0 g
s
.728 .989 .871 r
.33097 .33408 m .30079 .36395 L .30757 .36257 L p F P
0 g
s
.838 .994 .848 r
.30079 .36395 m .30757 .36257 L .29435 .37526 L closepath p F P
0 g
s
.918 .72 .226 r
.20581 .58806 m .20154 .56814 L .20105 .59854 L p F P
0 g
s
.918 .72 .226 r
.20105 .59854 m .2048 .61553 L .20581 .58806 L p F P
0 g
s
.793 .992 .758 r
.29435 .37526 m .26057 .41313 L .27931 .37912 L p F P
0 g
s
.793 .992 .758 r
.30079 .36395 m .29435 .37526 L p .27931 .37912 L F P
0 g
s
0 0 .192 r
.85053 .56733 m .8471 .58727 L .84839 .61324 L p F P
0 g
s
0 0 .398 r
.8471 .58727 m .85053 .56733 L .84499 .54041 L p F P
0 g
s
0 0 .267 r
.84663 .61911 m .84839 .61324 L .8471 .58727 L p F P
0 g
s
0 .381 .829 r
.70555 .33107 m .68375 .31306 L .71519 .32834 L p F P
0 g
s
0 .381 .829 r
.71519 .32834 m .73638 .34669 L .70555 .33107 L p F P
0 g
s
.344 .821 .873 r
.42693 .28783 m .43836 .28802 L .50363 .2734 L p F P
0 g
s
.941 .821 .373 r
.20759 .54331 m .20694 .53625 L .20124 .56499 L p F P
0 g
s
.941 .821 .373 r
.20124 .56499 m .20154 .56814 L .20759 .54331 L p F P
0 g
s
.054 .574 .872 r
.61066 .28747 m .65565 .29684 L .61891 .28336 L p F P
0 g
s
.054 .574 .872 r
.5888 .28033 m .61066 .28747 L p .61891 .28336 L F P
0 g
s
.728 .989 .871 r
.3505 .32905 m .36227 .31742 L p .33097 .33408 L F P
0 g
s
.747 .983 .909 r
.36227 .31742 m .36732 .31732 L .3505 .32905 L closepath p F P
0 g
s
.009 0 0 r
.61089 .86662 m .58967 .86995 L .54757 .87598 L p F P
0 g
s
.137 .683 .743 r
.58967 .86995 m .54269 .87644 L .54757 .87598 L closepath p F P
0 g
s
.438 0 0 r
.37151 .83983 m .37716 .84337 L .35868 .83391 L p F P
0 g
s
.438 0 0 r
.35868 .83391 m .34681 .82651 L .37151 .83983 L p F P
0 g
s
.816 .979 .689 r
.26057 .41313 m .27931 .37912 L .25076 .4156 L p F P
0 g
s
.816 .979 .689 r
.24584 .43303 m .26057 .41313 L p .25076 .4156 L F P
0 g
s
0 0 .292 r
.84489 .51797 m .84499 .54041 L .85053 .56733 L p F P
0 g
s
0 0 .493 r
.84499 .54041 m .84489 .51797 L .83483 .49285 L p F P
0 g
s
.6 .946 .92 r
.36227 .31742 m .36732 .31732 L .42693 .28783 L p F P
0 g
s
0 .277 .781 r
.78948 .40526 m .78491 .40175 L .77093 .37952 L p F P
0 g
s
0 0 0 r
.68585 .83836 m .69992 .82943 L .68871 .83636 L closepath p F P
0 g
s
0 0 0 r
.74761 .79673 m .69992 .82943 L .68871 .83636 L p F P
0 g
s
0 0 0 r
.752 .79207 m .74761 .79673 L p .68871 .83636 L F P
0 g
s
0 .25 .752 r
.77092 .37952 m .75273 .36622 L .73638 .34669 L p F P
0 g
s
.816 .979 .689 r
.25076 .4156 m .2387 .43861 L .24584 .43303 L p F P
0 g
s
.906 .977 .693 r
.2387 .43861 m .24584 .43303 L .2362 .44771 L closepath p F P
0 g
s
.701 .302 0 r
.24759 .73267 m .23542 .70791 L .224 .68867 L p F P
0 g
s
.802 .368 0 r
.23542 .70791 m .24759 .73267 L .24763 .73273 L p F P
0 g
s
.273 0 0 r
.44973 .86842 m .41681 .85758 L .37716 .84337 L p F P
0 g
s
0 .417 .777 r
.41681 .85758 m .37716 .84337 L .35868 .83391 L p F P
0 g
s
.054 .574 .872 r
.61891 .28336 m .58211 .27706 L .5888 .28033 L p F P
0 g
s
.25 .71 .95 r
.58211 .27706 m .56698 .27687 L .5888 .28033 L closepath p F P
0 g
s
.66 .2 0 r
.26637 .75692 m .26196 .75039 L .24763 .73273 L closepath p F P
0 g
s
.827 .763 .25 r
.20694 .53625 m .20897 .50999 L .20312 .53898 L p F P
0 g
s
.827 .763 .25 r
.20312 .53898 m .20124 .56499 L .20694 .53625 L p F P
0 g
s
0 0 0 r
.81745 .70704 m .82978 .68314 L .84128 .65004 L p F P
0 g
s
0 0 0 r
.79605 .74291 m .80371 .73361 L .80748 .72645 L closepath p F P
0 g
s
.641 .786 .334 r
.81745 .70704 m .82978 .68314 L p .80371 .73361 L F P
0 g
s
.641 .786 .334 r
.80371 .73361 m .80748 .72645 L .81745 .70704 L p F P
0 g
s
0 0 .398 r
.83081 .47094 m .83483 .49285 L .84489 .51797 L p F P
0 g
s
0 .018 .588 r
.83483 .49285 m .83081 .47094 L .81634 .44772 L p F P
0 g
s
0 0 0 r
.74761 .79673 m .76197 .78243 L .752 .79207 L closepath p F P
0 g
s
0 0 0 r
.79605 .74291 m .76197 .78243 L .752 .79207 L p F P
0 g
s
.654 .954 .739 r
.28631 .37173 m .33097 .33408 L .30079 .36395 L closepath p F P
0 g
s
.793 .992 .758 r
.27931 .37912 m .28631 .37173 L .30079 .36395 L p F P
0 g
s
.754 .433 0 r
.21639 .66302 m .20807 .6421 L p .21954 .67736 L F P
0 g
s
.754 .433 0 r
.21954 .67736 m .224 .68867 L .21639 .66302 L p F P
0 g
s
.102 0 0 r
.53128 .87664 m .49933 .87456 L .54269 .87644 L closepath p F P
0 g
s
.207 .733 .811 r
.53128 .87664 m .54269 .87644 L .58967 .86995 L p F P
0 g
s
.088 .639 .821 r
.56698 .27687 m .58211 .27706 L p .50462 .27316 L F P
0 g
s
.088 .639 .821 r
.50462 .27316 m .50474 .27318 L .56698 .27687 L p F P
0 g
s
0 .155 .696 r
.78948 .40526 m .80847 .42641 L .81634 .44772 L p F P
0 g
s
0 .064 .62 r
.77764 .38469 m .78948 .40526 L .80847 .42641 L p F P
0 g
s
0 .277 .781 r
.77093 .37952 m .77764 .38469 L .78948 .40526 L p F P
0 g
s
.064 .511 .896 r
.66588 .30219 m .67547 .31044 L .68375 .31306 L closepath p F P
0 g
s
.193 .6 .945 r
.65565 .29684 m .66588 .30219 L .67547 .31044 L p F P
0 g
s
0 0 .008 r
.84839 .61324 m .84663 .61911 L .84128 .65004 L p F P
0 g
s
0 0 .509 r
.80847 .42641 m .81634 .44772 L .83081 .47094 L p F P
0 g
s
.87 .928 .542 r
.2362 .44771 m .2387 .43861 L .22627 .4561 L p F P
0 g
s
.87 .928 .542 r
.22627 .4561 m .21997 .47961 L .2362 .44771 L p F P
0 g
s
.49 0 0 r
.34681 .82651 m .32598 .81169 L .29867 .78994 L p F P
0 g
s
0 .144 .636 r
.29867 .78994 m .28163 .77357 L .30908 .79529 L p F P
0 g
s
0 .144 .636 r
.30908 .79529 m .32598 .81169 L .29867 .78994 L p F P
0 g
s
.47 .887 .785 r
.34747 .32188 m .36227 .31742 L .41632 .28818 L p F P
0 g
s
.6 .946 .92 r
.42693 .28783 m .41632 .28818 L .36227 .31742 L p F P
0 g
s
.728 .989 .871 r
.36227 .31742 m .34747 .32188 L .33097 .33408 L p F P
0 g
s
.266 0 0 r
.45354 .8695 m .44973 .86842 L .4567 .87005 L closepath p F P
0 g
s
.026 .59 .792 r
.49933 .87456 m .53128 .87664 L p .45354 .8695 L F P
0 g
s
.026 .59 .792 r
.45354 .8695 m .4567 .87005 L .49933 .87456 L p F P
0 g
s
.499 .89 .728 r
.69992 .82943 m .68585 .83836 L .6718 .84361 L p F P
0 g
s
.277 .766 .687 r
.68585 .83836 m .6718 .84361 L p .61089 .86662 L F P
0 g
s
0 .017 .558 r
.26637 .75692 m .24763 .73273 L p .26839 .75558 L F P
0 g
s
0 .017 .558 r
.26839 .75558 m .28163 .77357 L .26637 .75692 L p F P
0 g
s
.344 .821 .873 r
.50363 .2734 m .50462 .27316 L p .42693 .28783 L F P
0 g
s
.42 .852 .939 r
.50462 .27316 m .50363 .2734 L .50474 .27318 L closepath p F P
0 g
s
.131 .677 .809 r
.50462 .27316 m .56624 .27161 L p .50479 .27062 L F P
0 g
s
.131 .677 .809 r
.50479 .27062 m .48745 .2717 L .50462 .27316 L p F P
0 g
s
.088 .639 .821 r
.58211 .27706 m .56624 .27161 L .50462 .27316 L p F P
0 g
s
.344 .821 .873 r
.50462 .27316 m .48745 .2717 L .42693 .28783 L p F P
0 g
s
.792 .556 0 r
.2048 .61553 m .20105 .59854 L .20635 .63445 L p F P
0 g
s
.792 .556 0 r
.20635 .63445 m .20807 .6421 L .2048 .61553 L p F P
0 g
s
.499 .89 .728 r
.73681 .80342 m .69992 .82943 L p .6718 .84361 L F P
0 g
s
.436 .832 .621 r
.69992 .82943 m .73681 .80342 L .74761 .79673 L closepath p F P
0 g
s
.565 .838 .492 r
.80371 .73361 m .79605 .74291 L .76197 .78243 L p F P
0 g
s
0 .356 .761 r
.68375 .31306 m .71519 .32834 L .6888 .31135 L p F P
0 g
s
0 .356 .761 r
.66588 .30219 m .68375 .31306 L p .6888 .31135 L F P
0 g
s
0 0 0 r
.85134 .5962 m .84839 .61324 L .84593 .63474 L p F P
0 g
s
0 0 .008 r
.84128 .65004 m .84593 .63474 L .84839 .61324 L p F P
0 g
s
0 0 .192 r
.84839 .61324 m .85134 .5962 L .85053 .56733 L p F P
0 g
s
0 0 0 r
.60914 .86703 m .58967 .86995 L .61089 .86662 L closepath p F P
0 g
s
.207 .733 .811 r
.58967 .86995 m .60914 .86703 L p .53128 .87664 L F P
0 g
s
0 .223 .663 r
.34681 .82651 m .35868 .83391 L .33994 .82036 L p F P
0 g
s
0 .223 .663 r
.33994 .82036 m .32598 .81169 L .34681 .82651 L p F P
0 g
s
.027 .576 .831 r
.58211 .27706 m .61891 .28336 L .57389 .27259 L p F P
0 g
s
.027 .576 .831 r
.57389 .27259 m .56624 .27161 L .58211 .27706 L p F P
0 g
s
.826 .665 .12 r
.20154 .56814 m .20124 .56499 L .20047 .59252 L p F P
0 g
s
.826 .665 .12 r
.20047 .59252 m .20105 .59854 L .20154 .56814 L p F P
0 g
s
.716 .877 .476 r
.2387 .43861 m .25076 .4156 L .2297 .44954 L p F P
0 g
s
.716 .877 .476 r
.2297 .44954 m .22627 .4561 L .2387 .43861 L p F P
0 g
s
0 0 .044 r
.85041 .54507 m .85053 .56733 L .85134 .5962 L p F P
0 g
s
0 0 .292 r
.85053 .56733 m .85041 .54507 L .84489 .51797 L p F P
0 g
s
.673 .942 .672 r
.76197 .78243 m .78342 .75685 L p .73681 .80342 L F P
0 g
s
.673 .942 .672 r
.73681 .80342 m .74761 .79673 L .76197 .78243 L p F P
0 g
s
.565 .838 .492 r
.79648 .7418 m .80371 .73361 L p .76197 .78243 L F P
0 g
s
.565 .838 .492 r
.76197 .78243 m .78342 .75685 L .79648 .7418 L p F P
0 g
s
.332 .815 .851 r
.41632 .28818 m .42693 .28783 L .48745 .2717 L p F P
0 g
s
0 .441 .749 r
.44973 .86842 m .45354 .8695 L .43579 .86293 L p F P
0 g
s
0 .441 .749 r
.43579 .86293 m .41681 .85758 L .44973 .86842 L p F P
0 g
s
.703 .776 .289 r
.21997 .47961 m .20897 .50999 L .21652 .48096 L p F P
0 g
s
.703 .776 .289 r
.22627 .4561 m .21997 .47961 L p .21652 .48096 L F P
0 g
s
0 0 .022 r
.20124 .56499 m .20312 .53898 L .20249 .56664 L p F P
0 g
s
0 0 .022 r
.20249 .56664 m .20047 .59252 L .20124 .56499 L p F P
0 g
s
.339 .815 .767 r
.60914 .86703 m .62864 .85983 L .61089 .86662 L closepath p F P
0 g
s
.277 .766 .687 r
.6718 .84361 m .62864 .85983 L .61089 .86662 L p F P
0 g
s
.026 .59 .792 r
.53128 .87664 m .5145 .87317 L .45354 .8695 L p F P
0 g
s
.216 .69 .938 r
.5145 .87317 m .45354 .8695 L .43579 .86293 L p F P
0 g
s
0 .23 .737 r
.77092 .37952 m .77764 .38469 L .76162 .36499 L p F P
0 g
s
0 .23 .737 r
.76162 .36499 m .75702 .36151 L .77092 .37952 L p F P
0 g
s
0 .25 .752 r
.73638 .34669 m .75702 .36151 L .77092 .37952 L p F P
0 g
s
.707 .762 .265 r
.84593 .63474 m .84128 .65004 L .82978 .68314 L p F P
0 g
s
0 .239 .714 r
.73638 .34669 m .71519 .32834 L .74113 .34632 L p F P
0 g
s
0 .239 .714 r
.75702 .36151 m .73638 .34669 L p .74113 .34632 L F P
0 g
s
.476 .894 .899 r
.62864 .85983 m .60914 .86703 L .59356 .86702 L p F P
0 g
s
.207 .733 .811 r
.60914 .86703 m .59356 .86702 L .53128 .87664 L p F P
0 g
s
0 .356 .761 r
.6888 .31135 m .66089 .29867 L .66588 .30219 L p F P
0 g
s
0 .452 .832 r
.66089 .29867 m .65565 .29684 L .66588 .30219 L closepath p F P
0 g
s
0 0 .148 r
.84079 .4962 m .84489 .51797 L .85041 .54507 L p F P
0 g
s
0 0 .398 r
.84489 .51797 m .84079 .4962 L .83081 .47094 L p F P
0 g
s
.641 .786 .334 r
.82978 .68314 m .81172 .71845 L .80371 .73361 L p F P
0 g
s
.723 .894 .509 r
.79648 .7418 m .81172 .71845 L .80371 .73361 L closepath p F P
0 g
s
.64 .193 0 r
.2476 .73269 m .24763 .73273 L .24759 .73267 L closepath p F P
0 g
s
0 .017 .558 r
.24763 .73273 m .2476 .73269 L .26839 .75558 L p F P
0 g
s
0 0 .459 r
.24759 .73267 m .2476 .73269 L .23786 .71302 L p F P
0 g
s
.701 .302 0 r
.224 .68867 m .22925 .69966 L .24759 .73267 L p F P
0 g
s
0 0 .459 r
.23786 .71302 m .22925 .69966 L .24759 .73267 L p F P
0 g
s
0 .088 .644 r
.2476 .73269 m .23786 .71302 L .25916 .73583 L p F P
0 g
s
0 .088 .644 r
.25916 .73583 m .26839 .75558 L .2476 .73269 L p F P
0 g
s
.374 .817 .95 r
.59356 .86702 m .53128 .87664 L .5145 .87317 L p F P
0 g
s
0 0 .353 r
.22925 .69966 m .224 .68867 L .21954 .67736 L closepath p F P
0 g
s
0 .417 .777 r
.35868 .83391 m .38962 .84487 L .41681 .85758 L p F P
0 g
s
.021 .483 .876 r
.38962 .84487 m .35868 .83391 L .33994 .82036 L p F P
0 g
s
0 .064 .62 r
.80847 .42641 m .7966 .40586 L .77764 .38469 L p F P
0 g
s
0 0 .518 r
.77764 .38469 m .76162 .36499 L .78069 .38612 L p F P
0 g
s
0 0 .518 r
.78069 .38612 m .7966 .40586 L .77764 .38469 L p F P
0 g
s
0 0 .265 r
.82285 .44972 m .83081 .47094 L .84079 .4962 L p F P
0 g
s
0 0 .509 r
.83081 .47094 m .82285 .44972 L .80847 .42641 L p F P
0 g
s
0 .215 .728 r
.28163 .77357 m .26839 .75558 L .29623 .77722 L p F P
0 g
s
0 .215 .728 r
.29623 .77722 m .30908 .79529 L .28163 .77357 L p F P
0 g
s
0 .367 .691 r
.66089 .29867 m .65565 .29684 L .61891 .28336 L p F P
0 g
s
.476 .894 .899 r
.6674 .84392 m .62864 .85983 L p .59356 .86702 L F P
0 g
s
.44 .878 .86 r
.62864 .85983 m .6674 .84392 L .6718 .84361 L closepath p F P
0 g
s
0 0 .391 r
.7966 .40586 m .80847 .42641 L .82285 .44972 L p F P
0 g
s
.754 .433 0 r
.20807 .6421 m .21181 .65492 L .21954 .67736 L p F P
0 g
s
0 0 .243 r
.21181 .65492 m .20807 .6421 L .20635 .63445 L closepath p F P
0 g
s
0 0 .171 r
.20105 .59854 m .20047 .59252 L .20491 .61885 L p F P
0 g
s
0 0 .171 r
.20491 .61885 m .20635 .63445 L .20105 .59854 L p F P
0 g
s
.01 .515 .865 r
.41681 .85758 m .43579 .86293 L .41766 .85265 L p F P
0 g
s
.01 .515 .865 r
.41766 .85265 m .38962 .84487 L .41681 .85758 L p F P
0 g
s
.625 .937 .71 r
.28305 .37365 m .28631 .37173 L .33097 .33408 L p F P
0 g
s
.775 .986 .74 r
.28305 .37365 m .28631 .37173 L .27931 .37912 L closepath p F P
0 g
s
0 0 0 r
.20897 .50999 m .21652 .48096 L .21042 .51026 L p F P
0 g
s
0 0 0 r
.21042 .51026 m .20312 .53898 L .20897 .50999 L p F P
0 g
s
0 .336 .69 r
.66089 .29867 m .6888 .31135 L .65671 .29595 L p F P
0 g
s
0 .336 .69 r
.65671 .29595 m .6461 .29161 L .66089 .29867 L p F P
0 g
s
0 .367 .691 r
.61891 .28336 m .6461 .29161 L .66089 .29867 L p F P
0 g
s
.801 .89 .471 r
.83701 .66005 m .82978 .68314 L .81172 .71845 L p F P
0 g
s
.707 .762 .265 r
.84282 .64327 m .84593 .63474 L p .82978 .68314 L F P
0 g
s
.707 .762 .265 r
.82978 .68314 m .83701 .66005 L .84282 .64327 L p F P
0 g
s
.678 .899 .549 r
.27931 .37912 m .28305 .37365 L .26923 .38844 L p F P
0 g
s
.678 .899 .549 r
.26923 .38844 m .25076 .4156 L .27931 .37912 L p F P
0 g
s
0 0 0 r
.84593 .63474 m .84726 .62701 L .85134 .5962 L p F P
0 g
s
0 0 .044 r
.85134 .5962 m .85126 .57412 L .85041 .54507 L p F P
0 g
s
.835 .733 .209 r
.85126 .57412 m .85134 .5962 L .84726 .62701 L p F P
0 g
s
.625 .937 .71 r
.33097 .33408 m .34299 .32339 L p .28305 .37365 L F P
0 g
s
.663 .97 .813 r
.34299 .32339 m .34747 .32188 L .33097 .33408 L closepath p F P
0 g
s
0 .29 .762 r
.33994 .82036 m .32598 .81169 L .30908 .79529 L p F P
0 g
s
0 0 .553 r
.22925 .69966 m .21954 .67736 L p .23223 .69146 L F P
0 g
s
0 0 .553 r
.23223 .69146 m .23786 .71302 L .22925 .69966 L p F P
0 g
s
.44 .869 .76 r
.34299 .32339 m .34747 .32188 L .40811 .29097 L p F P
0 g
s
.47 .887 .785 r
.41632 .28818 m .40811 .29097 L .34747 .32188 L p F P
0 g
s
.332 .815 .851 r
.48745 .2717 m .48287 .27158 L .41632 .28818 L p F P
0 g
s
0 0 0 r
.40811 .29097 m .41632 .28818 L .48287 .27158 L p F P
0 g
s
0 0 .288 r
.20047 .59252 m .20249 .56664 L .20733 .593 L p F P
0 g
s
0 0 .288 r
.20733 .593 m .20491 .61885 L .20047 .59252 L p F P
0 g
s
.625 .937 .71 r
.34299 .32339 m .32742 .33452 L .28305 .37365 L p F P
0 g
s
0 0 0 r
.28305 .37365 m .32742 .33452 L p .28392 .37554 L F P
0 g
s
0 0 0 r
.28392 .37554 m .26923 .38844 L .28305 .37365 L p F P
0 g
s
.795 .785 .285 r
.84282 .64327 m .84726 .62701 L .84593 .63474 L closepath p F P
0 g
s
0 0 .43 r
.20635 .63445 m .20491 .61885 L .21496 .64395 L p F P
0 g
s
0 0 .43 r
.21181 .65492 m .20635 .63445 L p .21496 .64395 L F P
0 g
s
0 0 .553 r
.21954 .67736 m .21679 .66751 L .23223 .69146 L p F P
0 g
s
0 0 .329 r
.21679 .66751 m .21954 .67736 L .21181 .65492 L closepath p F P
0 g
s
0 0 0 r
.25076 .4156 m .2297 .44954 L .25412 .41314 L p F P
0 g
s
0 0 0 r
.26923 .38844 m .25076 .4156 L p .25412 .41314 L F P
0 g
s
.418 0 0 r
.71519 .32834 m .6888 .31135 L .71533 .329 L p F P
0 g
s
.418 0 0 r
.71533 .329 m .74113 .34632 L .71519 .32834 L p F P
0 g
s
0 0 .43 r
.21496 .64395 m .21679 .66751 L .21181 .65492 L p F P
0 g
s
.499 .89 .728 r
.6718 .84361 m .73474 .80426 L .73681 .80342 L p F P
0 g
s
.668 .974 .885 r
.6674 .84392 m .6718 .84361 L .73474 .80426 L p F P
0 g
s
0 0 .148 r
.85041 .54507 m .84628 .52345 L .84079 .4962 L p F P
0 g
s
.858 .654 .118 r
.84628 .52345 m .85041 .54507 L .85126 .57412 L p F P
0 g
s
0 .439 .714 r
.61891 .28336 m .57389 .27259 L .61574 .28339 L p F P
0 g
s
0 .439 .714 r
.6461 .29161 m .61891 .28336 L p .61574 .28339 L F P
0 g
s
0 .168 .655 r
.74713 .35164 m .75702 .36151 L .76162 .36499 L closepath p F P
0 g
s
0 .239 .714 r
.74113 .34632 m .74713 .35164 L .75702 .36151 L p F P
0 g
s
.869 .972 .657 r
.81172 .71845 m .81933 .69559 L p .79065 .7451 L F P
0 g
s
.869 .972 .657 r
.79065 .7451 m .79648 .7418 L .81172 .71845 L p F P
0 g
s
.801 .89 .471 r
.81172 .71845 m .81933 .69559 L .83701 .66005 L p F P
0 g
s
.703 .776 .289 r
.21652 .48096 m .22043 .47075 L .22627 .4561 L p F P
0 g
s
0 0 0 r
.22043 .47075 m .2297 .44954 L .22627 .4561 L closepath p F P
0 g
s
.096 .653 .77 r
.48287 .27158 m .48745 .2717 L .50479 .27062 L closepath p F P
0 g
s
.216 .69 .938 r
.43579 .86293 m .49726 .86599 L .5145 .87317 L p F P
0 g
s
.315 .708 .979 r
.43579 .86293 m .49726 .86599 L .49306 .86345 L p F P
0 g
s
.315 .708 .979 r
.41766 .85265 m .43579 .86293 L p .49306 .86345 L F P
0 g
s
.44 .869 .76 r
.40811 .29097 m .39855 .29452 L .34299 .32339 L p F P
0 g
s
0 0 0 r
.34299 .32339 m .39855 .29452 L p .33933 .32842 L F P
0 g
s
0 0 0 r
.33933 .32842 m .32742 .33452 L .34299 .32339 L p F P
0 g
s
.695 .97 .754 r
.73474 .80426 m .74018 .79945 L .73681 .80342 L closepath p F P
0 g
s
.673 .942 .672 r
.78342 .75685 m .74018 .79945 L .73681 .80342 L p F P
0 g
s
0 .54 .768 r
.56278 .27081 m .56624 .27161 L .57389 .27259 L closepath p F P
0 g
s
.131 .677 .809 r
.56624 .27161 m .56278 .27081 L .50479 .27062 L p F P
0 g
s
.602 .085 0 r
.76162 .36499 m .78069 .38612 L .76056 .36727 L p F P
0 g
s
.602 .085 0 r
.74713 .35164 m .76162 .36499 L p .76056 .36727 L F P
0 g
s
0 0 .265 r
.84079 .4962 m .83277 .4751 L .82285 .44972 L p F P
0 g
s
.845 .545 .008 r
.83277 .4751 m .84079 .4962 L .84628 .52345 L p F P
0 g
s
.934 .863 .434 r
.84726 .62701 m .84726 .60513 L p .83815 .64998 L F P
0 g
s
.934 .863 .434 r
.83815 .64998 m .84282 .64327 L .84726 .62701 L p F P
0 g
s
.835 .733 .209 r
.84726 .62701 m .84726 .60513 L .85126 .57412 L p F P
0 g
s
.021 .483 .876 r
.33994 .82036 m .36805 .8302 L .38962 .84487 L p F P
0 g
s
.14 .51 .912 r
.33994 .82036 m .36805 .8302 L .35216 .81349 L p F P
0 g
s
.14 .51 .912 r
.35216 .81349 m .321 .80268 L .33994 .82036 L p F P
0 g
s
0 .29 .762 r
.30908 .79529 m .321 .80268 L .33994 .82036 L p F P
0 g
s
.755 .966 .678 r
.78342 .75685 m .79065 .7451 L .79648 .7418 L closepath p F P
0 g
s
0 0 .166 r
.20312 .53898 m .21042 .51026 L .20993 .53808 L p F P
0 g
s
0 0 .166 r
.20993 .53808 m .20249 .56664 L .20312 .53898 L p F P
0 g
s
.128 .551 .921 r
.38962 .84487 m .41766 .85265 L .3992 .83873 L p F P
0 g
s
.128 .551 .921 r
.3992 .83873 m .36805 .8302 L .38962 .84487 L p F P
0 g
s
.777 .993 .778 r
.79065 .7451 m .78342 .75685 L .74018 .79945 L p F P
0 g
s
0 .158 .696 r
.23786 .71302 m .23223 .69146 L .25427 .71412 L p F P
0 g
s
0 .158 .696 r
.25427 .71412 m .25916 .73583 L .23786 .71302 L p F P
0 g
s
0 0 .391 r
.82285 .44972 m .81095 .42922 L .7966 .40586 L p F P
0 g
s
.796 .411 0 r
.81095 .42922 m .82285 .44972 L .83277 .4751 L p F P
0 g
s
.714 .259 0 r
.7966 .40586 m .78069 .38612 L .79507 .40949 L p F P
0 g
s
.714 .259 0 r
.79507 .40949 m .81095 .42922 L .7966 .40586 L p F P
0 g
s
.668 .97 .91 r
.65707 .84378 m .69056 .82421 L .6674 .84392 L closepath p F P
0 g
s
.668 .974 .885 r
.72102 .80545 m .69056 .82421 L .6674 .84392 L p F P
0 g
s
.668 .974 .885 r
.73474 .80426 m .72102 .80545 L p .6674 .84392 L F P
0 g
s
.476 .894 .899 r
.59356 .86702 m .65707 .84378 L .6674 .84392 L p F P
0 g
s
0 0 0 r
.2297 .44954 m .25412 .41314 L .23927 .44551 L p F P
0 g
s
0 0 0 r
.22043 .47075 m .2297 .44954 L p .23927 .44551 L F P
0 g
s
.788 .998 .845 r
.74018 .79945 m .73474 .80426 L .72102 .80545 L p F P
0 g
s
.788 .998 .845 r
.72102 .80545 m .75537 .77538 L .74018 .79945 L p F P
0 g
s
.777 .993 .778 r
.78417 .74696 m .79065 .7451 L p .74018 .79945 L F P
0 g
s
.777 .993 .778 r
.74018 .79945 m .75537 .77538 L .78417 .74696 L p F P
0 g
s
0 .267 .774 r
.26839 .75558 m .25916 .73583 L p .29158 .76651 L F P
0 g
s
0 .267 .774 r
.29158 .76651 m .29623 .77722 L .26839 .75558 L p F P
0 g
s
0 .043 .601 r
.21679 .66751 m .21496 .64395 L .23115 .66778 L p F P
0 g
s
0 .043 .601 r
.23115 .66778 m .23223 .69146 L .21679 .66751 L p F P
0 g
s
.58 .914 .972 r
.65707 .84378 m .59356 .86702 L .57744 .86311 L p F P
0 g
s
.374 .817 .95 r
.5145 .87317 m .57744 .86311 L .59356 .86702 L p F P
0 g
s
.262 0 0 r
.57389 .27259 m .61574 .28339 L .56389 .27454 L p F P
0 g
s
.262 0 0 r
.56278 .27081 m .57389 .27259 L p .56389 .27454 L F P
0 g
s
.471 .827 .996 r
.5145 .87317 m .57744 .86311 L .57179 .86057 L p F P
0 g
s
.471 .827 .996 r
.49726 .86599 m .5145 .87317 L p .57179 .86057 L F P
0 g
s
.126 0 0 r
.48287 .27158 m .50479 .27062 L p .48645 .27513 L F P
0 g
s
.126 0 0 r
.48645 .27513 m .46955 .27545 L .48287 .27158 L p F P
0 g
s
0 0 0 r
.48287 .27158 m .46955 .27545 L .40811 .29097 L p F P
0 g
s
.262 0 0 r
.56389 .27454 m .54987 .27165 L .56278 .27081 L p F P
0 g
s
.061 0 0 r
.54987 .27165 m .50479 .27062 L .56278 .27081 L closepath p F P
0 g
s
0 0 0 r
.39855 .29452 m .40811 .29097 L .46955 .27545 L p F P
0 g
s
.126 0 0 r
.50479 .27062 m .54987 .27165 L p .48645 .27513 L F P
0 g
s
.889 .876 .441 r
.83701 .66005 m .83815 .64998 L .84282 .64327 L closepath p F P
0 g
s
0 .333 .813 r
.321 .80268 m .30908 .79529 L .29623 .77722 L p F P
0 g
s
.506 0 0 r
.6888 .31135 m .65671 .29595 L .68409 .31314 L p F P
0 g
s
.506 0 0 r
.68409 .31314 m .71533 .329 L .6888 .31135 L p F P
0 g
s
0 0 .494 r
.20491 .61885 m .20733 .593 L .21806 .61804 L p F P
0 g
s
0 0 .494 r
.21806 .61804 m .21496 .64395 L .20491 .61885 L p F P
0 g
s
.954 .795 .347 r
.84714 .55267 m .85126 .57412 L .84726 .60513 L p F P
0 g
s
.858 .654 .118 r
.85126 .57412 m .84714 .55267 L .84628 .52345 L p F P
0 g
s
0 0 0 r
.23927 .44551 m .21763 .47808 L .22043 .47075 L p F P
0 g
s
0 0 0 r
.21763 .47808 m .22043 .47075 L .21652 .48096 L closepath p F P
0 g
s
.927 .948 .611 r
.83815 .64998 m .83701 .66005 L .81933 .69559 L p F P
0 g
s
.602 .085 0 r
.76056 .36727 m .74319 .34842 L .74713 .35164 L p F P
0 g
s
.571 .05 0 r
.74319 .34842 m .74113 .34632 L .74713 .35164 L closepath p F P
0 g
s
0 .439 .714 r
.61574 .28339 m .63905 .28953 L .6461 .29161 L p F P
0 g
s
.316 0 0 r
.63905 .28953 m .6461 .29161 L .65671 .29595 L closepath p F P
0 g
s
0 0 .017 r
.21652 .48096 m .21763 .47808 L .21272 .50434 L p F P
0 g
s
0 0 .017 r
.21272 .50434 m .21042 .51026 L .21652 .48096 L p F P
0 g
s
.868 .991 .737 r
.78417 .74696 m .79465 .73338 L .79065 .7451 L closepath p F P
0 g
s
.869 .972 .657 r
.81933 .69559 m .79465 .73338 L .79065 .7451 L p F P
0 g
s
.956 .705 .254 r
.83822 .50248 m .84628 .52345 L .84714 .55267 L p F P
0 g
s
.845 .545 .008 r
.84628 .52345 m .83822 .50248 L .83277 .4751 L p F P
0 g
s
.672 .129 0 r
.74319 .34842 m .74113 .34632 L .71533 .329 L p F P
0 g
s
0 0 .379 r
.20249 .56664 m .20993 .53808 L p .21391 .5688 L F P
0 g
s
0 0 .379 r
.21391 .5688 m .20733 .593 L .20249 .56664 L p F P
0 g
s
0 0 .179 r
.21763 .47808 m .23927 .44551 L .23211 .47549 L p F P
0 g
s
0 0 .179 r
.23211 .47549 m .21272 .50434 L .21763 .47808 L p F P
0 g
s
.227 .512 .91 r
.321 .80268 m .35216 .81349 L .34215 .79459 L p F P
0 g
s
.227 .512 .91 r
.34215 .79459 m .30192 .78074 L .321 .80268 L p F P
0 g
s
0 .333 .813 r
.29623 .77722 m .30192 .78074 L .321 .80268 L p F P
0 g
s
0 0 0 r
.26241 .40058 m .28392 .37554 L .26923 .38844 L closepath p F P
0 g
s
0 0 0 r
.25412 .41314 m .26241 .40058 L .26923 .38844 L p F P
0 g
s
.315 .708 .979 r
.49306 .86345 m .46751 .85489 L .41766 .85265 L p F P
0 g
s
.388 .7 .983 r
.46751 .85489 m .41766 .85265 L .3992 .83873 L p F P
0 g
s
.665 .125 0 r
.74319 .34842 m .76056 .36727 L .73599 .34945 L p F P
0 g
s
.665 .125 0 r
.73599 .34945 m .72952 .34274 L .74319 .34842 L p F P
0 g
s
.672 .129 0 r
.71533 .329 m .72952 .34274 L .74319 .34842 L p F P
0 g
s
.219 .561 .936 r
.3992 .83873 m .36805 .8302 L .35216 .81349 L p F P
0 g
s
.929 .593 .145 r
.82083 .45468 m .83277 .4751 L .83822 .50248 L p F P
0 g
s
.796 .411 0 r
.83277 .4751 m .82083 .45468 L .81095 .42922 L p F P
0 g
s
.794 .315 0 r
.78069 .38612 m .76056 .36727 L .77504 .39061 L p F P
0 g
s
.794 .315 0 r
.77504 .39061 m .79507 .40949 L .78069 .38612 L p F P
0 g
s
.722 .959 .945 r
.69056 .82421 m .65707 .84378 L .64173 .83973 L p F P
0 g
s
.58 .914 .972 r
.57744 .86311 m .64173 .83973 L .65707 .84378 L p F P
0 g
s
.924 .974 .715 r
.8219 .67353 m .81933 .69559 L .79465 .73338 L p F P
0 g
s
.927 .948 .611 r
.83194 .65348 m .83815 .64998 L p .81933 .69559 L F P
0 g
s
.927 .948 .611 r
.81933 .69559 m .8219 .67353 L .83194 .65348 L p F P
0 g
s
.875 .463 .023 r
.81095 .42922 m .79507 .40949 L .80492 .435 L p F P
0 g
s
.875 .463 .023 r
.80492 .435 m .82083 .45468 L .81095 .42922 L p F P
0 g
s
.533 0 0 r
.65671 .29595 m .68409 .31314 L .64681 .29903 L p F P
0 g
s
.533 0 0 r
.63905 .28953 m .65671 .29595 L p .64681 .29903 L F P
0 g
s
.956 .922 .571 r
.83194 .65348 m .83813 .6381 L .83815 .64998 L closepath p F P
0 g
s
.934 .863 .434 r
.84726 .60513 m .83813 .6381 L .83815 .64998 L p F P
0 g
s
.986 .873 .517 r
.84317 .58388 m .84726 .60513 L .83813 .6381 L p F P
0 g
s
.954 .795 .347 r
.84726 .60513 m .84317 .58388 L .84714 .55267 L p F P
0 g
s
.125 0 0 r
.39855 .29452 m .46553 .27678 L p .43718 .29127 L F P
0 g
s
.125 0 0 r
.43718 .29127 m .38814 .30268 L .39855 .29452 L p F P
0 g
s
0 0 0 r
.46955 .27545 m .46553 .27678 L .39855 .29452 L p F P
0 g
s
0 0 0 r
.39855 .29452 m .38814 .30268 L .33933 .32842 L p F P
0 g
s
.022 .208 .715 r
.23223 .69146 m .23115 .66778 L p .25408 .70192 L F P
0 g
s
.022 .208 .715 r
.25408 .70192 m .25427 .71412 L .23223 .69146 L p F P
0 g
s
.046 .294 .785 r
.2828 .75396 m .25916 .73583 L .25427 .71412 L p F P
0 g
s
0 .267 .774 r
.25916 .73583 m .2828 .75396 L .29158 .76651 L p F P
0 g
s
.722 .959 .945 r
.70923 .8028 m .69056 .82421 L p .64173 .83973 L F P
0 g
s
.73 .969 .934 r
.69056 .82421 m .70923 .8028 L .72102 .80545 L closepath p F P
0 g
s
.03 0 0 r
.32616 .3361 m .33933 .32842 L .32742 .33452 L closepath p F P
0 g
s
0 0 0 r
.32742 .33452 m .32616 .3361 L .28392 .37554 L p F P
0 g
s
.533 0 0 r
.64681 .29903 m .63105 .29 L .63905 .28953 L p F P
0 g
s
.443 0 0 r
.63105 .29 m .61574 .28339 L .63905 .28953 L closepath p F P
0 g
s
.471 .827 .996 r
.57179 .86057 m .50856 .86414 L .49726 .86599 L p F P
0 g
s
.527 .807 .997 r
.50856 .86414 m .49306 .86345 L .49726 .86599 L closepath p F P
0 g
s
.638 .89 .986 r
.57179 .86057 m .57744 .86311 L .64173 .83973 L p F P
0 g
s
.908 .976 .792 r
.79465 .73338 m .78417 .74696 L .77091 .74551 L p F P
0 g
s
.908 .976 .792 r
.77091 .74551 m .79746 .71161 L .79465 .73338 L p F P
0 g
s
.924 .974 .715 r
.79465 .73338 m .79746 .71161 L .8219 .67353 L p F P
0 g
s
0 .11 .63 r
.21496 .64395 m .21806 .61804 L p .23353 .65126 L F P
0 g
s
0 .11 .63 r
.23353 .65126 m .23115 .66778 L .21496 .64395 L p F P
0 g
s
0 0 .246 r
.21042 .51026 m .21272 .50434 L .21134 .5345 L p F P
0 g
s
0 0 .246 r
.21134 .5345 m .20993 .53808 L .21042 .51026 L p F P
0 g
s
.052 .356 .829 r
.30192 .78074 m .29623 .77722 L .29158 .76651 L closepath p F P
0 g
s
.036 0 0 r
.31513 .3502 m .32616 .3361 L .33933 .32842 L p F P
0 g
s
0 0 0 r
.31513 .3502 m .32616 .3361 L .28392 .37554 L closepath p F P
0 g
s
0 0 0 r
.28392 .37554 m .31513 .3502 L p .25863 .40744 L F P
0 g
s
0 0 0 r
.25863 .40744 m .26241 .40058 L .28392 .37554 L p F P
0 g
s
.848 .992 .846 r
.75537 .77538 m .78417 .74696 L .77091 .74551 L p F P
0 g
s
.834 .974 .883 r
.70923 .8028 m .72102 .80545 L .75537 .77538 L p F P
0 g
s
.143 0 0 r
.46553 .27678 m .46955 .27545 L .48645 .27513 L closepath p F P
0 g
s
.293 0 0 r
.54436 .2725 m .54987 .27165 L .56389 .27454 L closepath p F P
0 g
s
.126 0 0 r
.54987 .27165 m .54436 .2725 L .48645 .27513 L p F P
0 g
s
.996 .8 .441 r
.83904 .53187 m .84714 .55267 L .84317 .58388 L p F P
0 g
s
.956 .705 .254 r
.84714 .55267 m .83904 .53187 L .83822 .50248 L p F P
0 g
s
.834 .974 .883 r
.75537 .77538 m .76375 .7525 L p .70923 .8028 L F P
0 g
s
.848 .992 .846 r
.77091 .74551 m .76375 .7525 L .75537 .77538 L p F P
0 g
s
.481 .828 .997 r
.56082 .85541 m .50856 .86414 L .57179 .86057 L closepath p F P
0 g
s
.532 .807 .996 r
.50856 .86414 m .56082 .85541 L p .47959 .85517 L F P
0 g
s
.532 .807 .996 r
.47959 .85517 m .49306 .86345 L .50856 .86414 L p F P
0 g
s
.656 .1 0 r
.71533 .329 m .68409 .31314 L .70578 .33311 L p F P
0 g
s
.656 .1 0 r
.72952 .34274 m .71533 .329 L p .70578 .33311 L F P
0 g
s
.036 0 0 r
.33933 .32842 m .38416 .30584 L p .31513 .3502 L F P
0 g
s
0 0 0 r
.38416 .30584 m .38814 .30268 L .33933 .32842 L closepath p F P
0 g
s
.348 .721 .986 r
.47959 .85517 m .46751 .85489 L .49306 .86345 L closepath p F P
0 g
s
.431 0 0 r
.61574 .28339 m .56389 .27454 L .59995 .28803 L p F P
0 g
s
.431 0 0 r
.63105 .29 m .61574 .28339 L p .59995 .28803 L F P
0 g
s
0 0 0 r
.25863 .40744 m .26241 .40058 L .25412 .41314 L closepath p F P
0 g
s
.29 .505 .891 r
.30192 .78074 m .29158 .76651 L p .33837 .77328 L F P
0 g
s
.29 .505 .891 r
.33837 .77328 m .34215 .79459 L .30192 .78074 L p F P
0 g
s
.016 0 .378 r
.21272 .50434 m .23211 .47549 L .23273 .50321 L p F P
0 g
s
.016 0 .378 r
.23273 .50321 m .21134 .5345 L .21272 .50434 L p F P
0 g
s
.982 .909 .638 r
.83813 .6381 m .83194 .65348 L .81954 .65226 L p F P
0 g
s
.982 .909 .638 r
.81954 .65226 m .83407 .61707 L .83813 .6381 L p F P
0 g
s
.986 .873 .517 r
.83813 .6381 m .83407 .61707 L .84317 .58388 L p F P
0 g
s
0 .008 .533 r
.20733 .593 m .21391 .5688 L .22101 .60753 L p F P
0 g
s
0 .008 .533 r
.22101 .60753 m .21806 .61804 L .20733 .593 L p F P
0 g
s
.638 .886 .986 r
.56082 .85541 m .61402 .83622 L .57179 .86057 L closepath p F P
0 g
s
.638 .89 .986 r
.62581 .83192 m .61402 .83622 L .57179 .86057 L p F P
0 g
s
.638 .89 .986 r
.64173 .83973 m .62581 .83192 L p .57179 .86057 L F P
0 g
s
0 0 .035 r
.25412 .41314 m .25863 .40744 L .25124 .43048 L p F P
0 g
s
0 0 .035 r
.25124 .43048 m .23927 .44551 L .25412 .41314 L p F P
0 g
s
.985 .709 .35 r
.82622 .48218 m .83822 .50248 L .83904 .53187 L p F P
0 g
s
.929 .593 .145 r
.83822 .50248 m .82622 .48218 L .82083 .45468 L p F P
0 g
s
.823 .344 .01 r
.76056 .36727 m .73599 .34945 L .75064 .37269 L p F P
0 g
s
.823 .344 .01 r
.75064 .37269 m .77504 .39061 L .76056 .36727 L p F P
0 g
s
.388 .7 .983 r
.3992 .83873 m .44409 .84055 L .46751 .85489 L p F P
0 g
s
.437 .678 .965 r
.3992 .83873 m .44409 .84055 L .4309 .82295 L p F P
0 g
s
.437 .678 .965 r
.4309 .82295 m .38045 .82112 L .3992 .83873 L p F P
0 g
s
.219 .561 .936 r
.35216 .81349 m .38045 .82112 L .3992 .83873 L p F P
0 g
s
.359 0 0 r
.45175 .28735 m .46553 .27678 L .48645 .27513 L p F P
0 g
s
.125 0 0 r
.46553 .27678 m .45175 .28735 L .43718 .29127 L p F P
0 g
s
.287 .556 .927 r
.38045 .82112 m .35216 .81349 L .34215 .79459 L p F P
0 g
s
.953 .603 .248 r
.82083 .45468 m .80492 .435 L .81021 .46261 L p F P
0 g
s
.953 .603 .248 r
.81021 .46261 m .82622 .48218 L .82083 .45468 L p F P
0 g
s
.967 .934 .681 r
.8219 .67353 m .83194 .65348 L .81954 .65226 L p F P
0 g
s
.359 0 0 r
.48645 .27513 m .5329 .27926 L p .45175 .28735 L F P
0 g
s
.312 0 0 r
.5329 .27926 m .48645 .27513 L .54436 .2725 L closepath p F P
0 g
s
.9 .482 .135 r
.79507 .40949 m .77504 .39061 L .78487 .41615 L p F P
0 g
s
.9 .482 .135 r
.78487 .41615 m .80492 .435 L .79507 .40949 L p F P
0 g
s
.461 0 0 r
.56389 .27454 m .59995 .28803 L .54019 .28154 L p F P
0 g
s
.461 0 0 r
.54436 .2725 m .56389 .27454 L p .54019 .28154 L F P
0 g
s
.29 .505 .891 r
.29158 .76651 m .28928 .75684 L .33837 .77328 L p F P
0 g
s
.22 .451 .87 r
.28928 .75684 m .29158 .76651 L .2828 .75396 L closepath p F P
0 g
s
.093 0 .18 r
.25863 .40744 m .30565 .36979 L p .29327 .3974 L F P
0 g
s
.093 0 .18 r
.29327 .3974 m .25124 .43048 L .25863 .40744 L p F P
0 g
s
0 0 0 r
.31513 .3502 m .30565 .36979 L .25863 .40744 L p F P
0 g
s
.461 0 0 r
.54019 .28154 m .5329 .27926 L .54436 .2725 L p F P
0 g
s
.411 .709 .984 r
.46751 .85489 m .47959 .85517 L .46154 .84089 L p F P
0 g
s
.411 .709 .984 r
.46154 .84089 m .44409 .84055 L .46751 .85489 L p F P
0 g
s
.129 0 0 r
.38416 .30584 m .38814 .30268 L .43718 .29127 L closepath p F P
0 g
s
.558 0 0 r
.62239 .29208 m .63105 .29 L .64681 .29903 L closepath p F P
0 g
s
.431 0 0 r
.59995 .28803 m .62239 .29208 L .63105 .29 L p F P
0 g
s
.996 .85 .573 r
.83503 .56326 m .84317 .58388 L .83407 .61707 L p F P
0 g
s
.996 .8 .441 r
.84317 .58388 m .83503 .56326 L .83904 .53187 L p F P
0 g
s
.945 .942 .751 r
.81953 .65228 m .8219 .67353 L .79746 .71161 L p F P
0 g
s
.967 .934 .681 r
.81954 .65226 m .81953 .65228 L .8219 .67353 L p F P
0 g
s
.722 .959 .945 r
.64173 .83973 m .70659 .80205 L .70923 .8028 L p F P
0 g
s
.746 .922 .95 r
.70659 .80205 m .64173 .83973 L .62581 .83192 L p F P
0 g
s
0 0 .419 r
.21236 .55067 m .20993 .53808 L .21134 .5345 L closepath p F P
0 g
s
0 0 .379 r
.20993 .53808 m .21236 .55067 L .21391 .5688 L p F P
0 g
s
.699 .171 0 r
.68409 .31314 m .64681 .29903 L .66914 .31861 L p F P
0 g
s
.699 .171 0 r
.66914 .31861 m .70578 .33311 L .68409 .31314 L p F P
0 g
s
.707 .17 0 r
.72374 .34241 m .72952 .34274 L .73599 .34945 L closepath p F P
0 g
s
.656 .1 0 r
.70578 .33311 m .72374 .34241 L .72952 .34274 L p F P
0 g
s
.277 .441 .844 r
.2828 .75396 m .28928 .75684 L .29043 .73337 L p F P
0 g
s
.277 .441 .844 r
.29043 .73337 m .26379 .72149 L .2828 .75396 L p F P
0 g
s
.046 .294 .785 r
.25427 .71412 m .26379 .72149 L .2828 .75396 L p F P
0 g
s
0 0 .248 r
.23927 .44551 m .25124 .43048 L .24683 .45722 L p F P
0 g
s
0 0 .248 r
.24683 .45722 m .23211 .47549 L .23927 .44551 L p F P
0 g
s
.532 .807 .996 r
.56082 .85541 m .54371 .84419 L .47959 .85517 L p F P
0 g
s
.565 .776 .977 r
.54371 .84419 m .47959 .85517 L .46154 .84089 L p F P
0 g
s
.147 .076 .513 r
.21134 .5345 m .23273 .50321 L .24152 .52868 L p F P
0 g
s
.147 .076 .513 r
.21236 .55067 m .21134 .5345 L p .24152 .52868 L F P
0 g
s
.121 .303 .774 r
.26379 .72149 m .25427 .71412 L .25408 .70192 L closepath p F P
0 g
s
.66 .85 .973 r
.61402 .83622 m .56082 .85541 L .54371 .84419 L p F P
0 g
s
.102 .23 .711 r
.24511 .68189 m .23115 .66778 L .23353 .65126 L closepath p F P
0 g
s
.022 .208 .715 r
.23115 .66778 m .24511 .68189 L .25408 .70192 L p F P
0 g
s
.816 .967 .902 r
.70659 .80205 m .71073 .79873 L .70923 .8028 L closepath p F P
0 g
s
.834 .974 .883 r
.76375 .7525 m .71073 .79873 L .70923 .8028 L p F P
0 g
s
.994 .775 .498 r
.82695 .51173 m .83904 .53187 L .83503 .56326 L p F P
0 g
s
.985 .709 .35 r
.83904 .53187 m .82695 .51173 L .82622 .48218 L p F P
0 g
s
.311 0 .016 r
.37283 .3216 m .38416 .30584 L .43718 .29127 L p F P
0 g
s
.036 0 0 r
.38416 .30584 m .37283 .3216 L .31513 .3502 L p F P
0 g
s
.336 .493 .867 r
.28928 .75684 m .29043 .73337 L p .33884 .76905 L F P
0 g
s
.336 .493 .867 r
.33884 .76905 m .33837 .77328 L .28928 .75684 L p F P
0 g
s
.914 .933 .808 r
.79746 .71161 m .79516 .69066 L p .76454 .74265 L F P
0 g
s
.914 .933 .808 r
.76454 .74265 m .77091 .74551 L .79746 .71161 L p F P
0 g
s
.945 .942 .751 r
.79746 .71161 m .79516 .69066 L .81953 .65228 L p F P
0 g
s
.218 0 .112 r
.31513 .3502 m .37283 .3216 L p .34376 .35116 L F P
0 g
s
.218 0 .112 r
.34376 .35116 m .30565 .36979 L .31513 .3502 L p F P
0 g
s
.81 .337 .095 r
.73599 .34945 m .75064 .37269 L .72154 .35589 L p F P
0 g
s
.81 .337 .095 r
.72374 .34241 m .73599 .34945 L p .72154 .35589 L F P
0 g
s
.147 .076 .513 r
.24152 .52868 m .21656 .56403 L .21236 .55067 L p F P
0 g
s
.07 .033 .504 r
.21656 .56403 m .21391 .5688 L .21236 .55067 L closepath p F P
0 g
s
.071 .143 .633 r
.22725 .63124 m .21806 .61804 L .22101 .60753 L closepath p F P
0 g
s
0 .11 .63 r
.21806 .61804 m .22725 .63124 L .23353 .65126 L p F P
0 g
s
.824 .927 .901 r
.71073 .79873 m .70659 .80205 L .69151 .79419 L p F P
0 g
s
.746 .922 .95 r
.62581 .83192 m .69151 .79419 L .70659 .80205 L p F P
0 g
s
.976 .69 .413 r
.82622 .48218 m .81021 .46261 L .8108 .49231 L p F P
0 g
s
.976 .69 .413 r
.8108 .49231 m .82695 .51173 L .82622 .48218 L p F P
0 g
s
.824 .927 .901 r
.69151 .79419 m .71234 .77755 L .71073 .79873 L p F P
0 g
s
.843 .939 .887 r
.76454 .74265 m .76375 .7525 L .71073 .79873 L p F P
0 g
s
.843 .939 .887 r
.75685 .73868 m .76454 .74265 L p .71073 .79873 L F P
0 g
s
.843 .939 .887 r
.71073 .79873 m .71234 .77755 L .75685 .73868 L p F P
0 g
s
.47 .652 .939 r
.38045 .82112 m .36146 .79972 L p .42893 .80695 L F P
0 g
s
.47 .652 .939 r
.42893 .80695 m .4309 .82295 L .38045 .82112 L p F P
0 g
s
.287 .556 .927 r
.34215 .79459 m .36146 .79972 L .38045 .82112 L p F P
0 g
s
.976 .87 .667 r
.83407 .61707 m .82587 .59668 L p .81951 .65224 L F P
0 g
s
.976 .87 .667 r
.81951 .65224 m .81954 .65226 L .83407 .61707 L p F P
0 g
s
.996 .85 .573 r
.83407 .61707 m .82587 .59668 L .83503 .56326 L p F P
0 g
s
.866 .949 .866 r
.76375 .7525 m .76454 .74265 L .77091 .74551 L closepath p F P
0 g
s
.892 .482 .217 r
.77504 .39061 m .75064 .37269 L .76047 .39822 L p F P
0 g
s
.892 .482 .217 r
.76047 .39822 m .78487 .41615 L .77504 .39061 L p F P
0 g
s
.942 .592 .32 r
.80492 .435 m .78487 .41615 L .79005 .44385 L p F P
0 g
s
.942 .592 .32 r
.79005 .44385 m .81021 .46261 L .80492 .435 L p F P
0 g
s
.666 .16 .032 r
.64681 .29903 m .66914 .31861 L .62601 .30604 L p F P
0 g
s
.666 .16 .032 r
.62239 .29208 m .64681 .29903 L p .62601 .30604 L F P
0 g
s
.323 .431 .817 r
.26379 .72149 m .25408 .70192 L p .2985 .70704 L F P
0 g
s
.323 .431 .817 r
.2985 .70704 m .29043 .73337 L .26379 .72149 L p F P
0 g
s
.81 .337 .095 r
.72154 .35589 m .71609 .34764 L .72374 .34241 L p F P
0 g
s
.796 .316 .08 r
.71609 .34764 m .70578 .33311 L .72374 .34241 L closepath p F P
0 g
s
.186 .176 .613 r
.21391 .5688 m .21656 .56403 L .23249 .5875 L p F P
0 g
s
.186 .176 .613 r
.23249 .5875 m .22101 .60753 L .21391 .5688 L p F P
0 g
s
.453 .687 .966 r
.46154 .84089 m .44409 .84055 L .4309 .82295 L p F P
0 g
s
.336 .542 .906 r
.36146 .79972 m .34215 .79459 L .33837 .77328 L p F P
0 g
s
.22 0 .352 r
.25124 .43048 m .29327 .3974 L .28324 .42892 L p F P
0 g
s
.22 0 .352 r
.28324 .42892 m .24683 .45722 L .25124 .43048 L p F P
0 g
s
.101 0 .405 r
.23211 .47549 m .24683 .45722 L .24551 .4876 L p F P
0 g
s
.101 0 .405 r
.24551 .4876 m .23273 .50321 L .23211 .47549 L p F P
0 g
s
.323 .431 .817 r
.25408 .70192 m .25725 .68928 L .2985 .70704 L p F P
0 g
s
.257 .367 .784 r
.25725 .68928 m .25408 .70192 L .24511 .68189 L closepath p F P
0 g
s
.666 .16 .032 r
.62601 .30604 m .61572 .29776 L .62239 .29208 L p F P
0 g
s
.609 .09 0 r
.61572 .29776 m .59995 .28803 L .62239 .29208 L closepath p F P
0 g
s
.311 0 .016 r
.43718 .29127 m .45066 .2889 L p .37283 .3216 L F P
0 g
s
.303 0 0 r
.45066 .2889 m .43718 .29127 L .45175 .28735 L closepath p F P
0 g
s
.24 .195 .604 r
.21656 .56403 m .24152 .52868 L p .25304 .55955 L F P
0 g
s
.24 .195 .604 r
.25304 .55955 m .23249 .5875 L .21656 .56403 L p F P
0 g
s
.66 .85 .973 r
.6219 .82921 m .61402 .83622 L p .54371 .84419 L F P
0 g
s
.662 .853 .973 r
.61402 .83622 m .6219 .82921 L .62581 .83192 L closepath p F P
0 g
s
.98 .811 .602 r
.82281 .54332 m .83503 .56326 L .82587 .59668 L p F P
0 g
s
.994 .775 .498 r
.83503 .56326 m .82281 .54332 L .82695 .51173 L p F P
0 g
s
.303 .363 .759 r
.24511 .68189 m .23353 .65126 L p .27071 .66031 L F P
0 g
s
.303 .363 .759 r
.27071 .66031 m .25725 .68928 L .24511 .68189 L p F P
0 g
s
.276 .284 .688 r
.22101 .60753 m .23249 .5875 L .25746 .60878 L p F P
0 g
s
.276 .284 .688 r
.22725 .63124 m .22101 .60753 L p .25746 .60878 L F P
0 g
s
.58 .071 .007 r
.59995 .28803 m .54019 .28154 L .56979 .29792 L p F P
0 g
s
.58 .071 .007 r
.61572 .29776 m .59995 .28803 L p .56979 .29792 L F P
0 g
s
.962 .891 .713 r
.81953 .65228 m .81951 .65224 L .81954 .65226 L closepath p F P
0 g
s
.935 .894 .764 r
.81951 .65224 m .81953 .65228 L .79516 .69066 L p F P
0 g
s
.956 .88 .718 r
.80595 .64229 m .81124 .63217 L .81951 .65224 L closepath p F P
0 g
s
.976 .87 .667 r
.82587 .59668 m .81124 .63217 L .81951 .65224 L p F P
0 g
s
.935 .894 .764 r
.80595 .64229 m .81951 .65224 L p .79516 .69066 L F P
0 g
s
.468 0 0 r
.53033 .28095 m .5329 .27926 L .54019 .28154 L closepath p F P
0 g
s
.359 0 0 r
.5329 .27926 m .53033 .28095 L .45175 .28735 L p F P
0 g
s
.77 .3 .124 r
.70578 .33311 m .66914 .31861 L .6857 .34098 L p F P
0 g
s
.77 .3 .124 r
.71609 .34764 m .70578 .33311 L p .6857 .34098 L F P
0 g
s
.471 .015 .087 r
.45175 .28735 m .53033 .28095 L p .49333 .29714 L F P
0 g
s
.471 .015 .087 r
.49333 .29714 m .45066 .2889 L .45175 .28735 L p F P
0 g
s
.894 .932 .835 r
.75685 .73868 m .76326 .73143 L .76454 .74265 L closepath p F P
0 g
s
.914 .933 .808 r
.79516 .69066 m .76326 .73143 L .76454 .74265 L p F P
0 g
s
.227 .277 .707 r
.23798 .64079 m .23353 .65126 L .22725 .63124 L closepath p F P
0 g
s
.276 .284 .688 r
.25746 .60878 m .23798 .64079 L .22725 .63124 L p F P
0 g
s
.565 .776 .977 r
.46154 .84089 m .52617 .82954 L .54371 .84419 L p F P
0 g
s
.583 .742 .952 r
.50821 .81143 m .44313 .82313 L .46154 .84089 L p F P
0 g
s
.583 .742 .952 r
.46154 .84089 m .52617 .82954 L .50821 .81143 L p F P
0 g
s
.453 .687 .966 r
.4309 .82295 m .44313 .82313 L .46154 .84089 L p F P
0 g
s
.755 .872 .933 r
.6219 .82921 m .62581 .83192 L .69151 .79419 L p F P
0 g
s
.303 .363 .759 r
.23353 .65126 m .23798 .64079 L .27071 .66031 L p F P
0 g
s
.471 .017 .091 r
.44111 .30269 m .45066 .2889 L .49333 .29714 L closepath p F P
0 g
s
.311 0 .016 r
.45066 .2889 m .44111 .30269 L .37283 .3216 L p F P
0 g
s
.971 .74 .531 r
.82695 .51173 m .8108 .49231 L .80645 .5241 L p F P
0 g
s
.971 .74 .531 r
.80645 .5241 m .82281 .54332 L .82695 .51173 L p F P
0 g
s
.66 .85 .973 r
.54371 .84419 m .60937 .82039 L .6219 .82921 L p F P
0 g
s
.671 .811 .95 r
.60937 .82039 m .54371 .84419 L .52617 .82954 L p F P
0 g
s
.488 .627 .912 r
.40542 .77642 m .34228 .77431 L .36146 .79972 L p F P
0 g
s
.488 .627 .912 r
.36146 .79972 m .4244 .80175 L .40542 .77642 L p F P
0 g
s
.47 .652 .939 r
.36146 .79972 m .4244 .80175 L .42893 .80695 L p F P
0 g
s
.336 .542 .906 r
.33837 .77328 m .34228 .77431 L .36146 .79972 L p F P
0 g
s
.589 .121 .109 r
.54019 .28154 m .53033 .28095 L .5199 .29496 L p F P
0 g
s
.589 .121 .109 r
.5199 .29496 m .56979 .29792 L .54019 .28154 L p F P
0 g
s
.869 .47 .275 r
.75064 .37269 m .72154 .35589 L .73141 .38138 L p F P
0 g
s
.869 .47 .275 r
.73141 .38138 m .76047 .39822 L .75064 .37269 L p F P
0 g
s
.471 .015 .087 r
.53033 .28095 m .5199 .29496 L .49333 .29714 L p F P
0 g
s
.747 .869 .936 r
.60937 .82039 m .62208 .81336 L .6219 .82921 L closepath p F P
0 g
s
.755 .872 .933 r
.67583 .7825 m .62208 .81336 L .6219 .82921 L p F P
0 g
s
.755 .872 .933 r
.69151 .79419 m .67583 .7825 L p .6219 .82921 L F P
0 g
s
.95 .661 .454 r
.81021 .46261 m .79005 .44385 L .79043 .47369 L p F P
0 g
s
.95 .661 .454 r
.79043 .47369 m .8108 .49231 L .81021 .46261 L p F P
0 g
s
.906 .893 .805 r
.78779 .67058 m .79516 .69066 L .76326 .73143 L p F P
0 g
s
.935 .894 .764 r
.79516 .69066 m .78779 .67058 L .80595 .64229 L p F P
0 g
s
.917 .572 .369 r
.78487 .41615 m .76047 .39822 L .76551 .42599 L p F P
0 g
s
.917 .572 .369 r
.76551 .42599 m .79005 .44385 L .78487 .41615 L p F P
0 g
s
.332 .029 .292 r
.3012 .38543 m .34376 .35116 L .30565 .36979 L closepath p F P
0 g
s
.093 0 .18 r
.30565 .36979 m .3012 .38543 L .29327 .3974 L p F P
0 g
s
.355 .422 .793 r
.25725 .68928 m .27071 .66031 L p .30081 .70252 L F P
0 g
s
.355 .422 .793 r
.30081 .70252 m .2985 .70704 L .25725 .68928 L p F P
0 g
s
.958 .83 .675 r
.8135 .57698 m .82587 .59668 L .81124 .63217 L p F P
0 g
s
.98 .811 .602 r
.82587 .59668 m .8135 .57698 L .82281 .54332 L p F P
0 g
s
.412 .034 .209 r
.37283 .3216 m .44111 .30269 L p .38778 .33467 L F P
0 g
s
.412 .034 .209 r
.38778 .33467 m .36599 .33723 L .37283 .3216 L p F P
0 g
s
.218 0 .112 r
.37283 .3216 m .36599 .33723 L .34376 .35116 L p F P
0 g
s
.366 .478 .842 r
.32303 .7441 m .29043 .73337 L .2985 .70704 L p F P
0 g
s
.336 .493 .867 r
.29043 .73337 m .32303 .7441 L .33884 .76905 L p F P
0 g
s
.821 .882 .889 r
.71234 .77755 m .69151 .79419 L .67583 .7825 L p F P
0 g
s
.204 .11 .52 r
.23273 .50321 m .24551 .4876 L .24742 .52161 L p F P
0 g
s
.204 .11 .52 r
.24742 .52161 m .24152 .52868 L .23273 .50321 L p F P
0 g
s
.334 .357 .735 r
.23798 .64079 m .25746 .60878 L p .27812 .64884 L F P
0 g
s
.334 .357 .735 r
.27812 .64884 m .27071 .66031 L .23798 .64079 L p F P
0 g
s
.311 .135 .474 r
.24683 .45722 m .28324 .42892 L .28677 .45604 L p F P
0 g
s
.311 .135 .474 r
.28677 .45604 m .24551 .4876 L .24683 .45722 L p F P
0 g
s
.821 .882 .889 r
.67583 .7825 m .70695 .75768 L .71234 .77755 L p F P
0 g
s
.84 .892 .877 r
.74207 .72711 m .70695 .75768 L .71234 .77755 L p F P
0 g
s
.84 .892 .877 r
.71234 .77755 m .75685 .73868 L .74207 .72711 L p F P
0 g
s
.756 .318 .212 r
.66914 .31861 m .62601 .30604 L .64295 .32811 L p F P
0 g
s
.756 .318 .212 r
.64295 .32811 m .6857 .34098 L .66914 .31861 L p F P
0 g
s
.883 .887 .83 r
.76326 .73143 m .75685 .73868 L .74207 .72711 L p F P
0 g
s
.883 .887 .83 r
.74207 .72711 m .75575 .71172 L .76326 .73143 L p F P
0 g
s
.906 .893 .805 r
.76326 .73143 m .75575 .71172 L .78779 .67058 L p F P
0 g
s
.802 .344 .149 r
.71258 .35173 m .71609 .34764 L .72154 .35589 L closepath p F P
0 g
s
.77 .3 .124 r
.6857 .34098 m .71258 .35173 L .71609 .34764 L p F P
0 g
s
.481 .661 .941 r
.44313 .82313 m .4309 .82295 L .42893 .80695 L closepath p F P
0 g
s
.665 .171 .066 r
.61092 .30271 m .61572 .29776 L .62601 .30604 L closepath p F P
0 g
s
.58 .071 .007 r
.56979 .29792 m .61092 .30271 L .61572 .29776 L p F P
0 g
s
.954 .77 .616 r
.82281 .54332 m .80645 .5241 L .79686 .55801 L p F P
0 g
s
.954 .77 .616 r
.79686 .55801 m .8135 .57698 L .82281 .54332 L p F P
0 g
s
.37 .526 .881 r
.34228 .77431 m .33837 .77328 L .33884 .76905 L closepath p F P
0 g
s
.592 .709 .925 r
.48989 .78973 m .50821 .81143 L .44313 .82313 L p F P
0 g
s
.592 .709 .925 r
.43604 .79965 m .48989 .78973 L p .44313 .82313 L F P
0 g
s
.592 .709 .925 r
.44313 .82313 m .42893 .80695 L .43604 .79965 L p F P
0 g
s
.31 .288 .672 r
.23249 .5875 m .25304 .55955 L .26287 .60167 L p F P
0 g
s
.31 .288 .672 r
.26287 .60167 m .25746 .60878 L .23249 .5875 L p F P
0 g
s
.496 .592 .88 r
.38624 .74692 m .40542 .77642 L .34228 .77431 L p F P
0 g
s
.496 .592 .88 r
.35274 .74593 m .38624 .74692 L p .34228 .77431 L F P
0 g
s
.496 .592 .88 r
.34228 .77431 m .33884 .76905 L .35274 .74593 L p F P
0 g
s
.842 .454 .314 r
.72154 .35589 m .71258 .35173 L .7074 .3703 L p F P
0 g
s
.842 .454 .314 r
.7074 .3703 m .73141 .38138 L .72154 .35589 L p F P
0 g
s
.936 .837 .722 r
.81124 .63217 m .80595 .64229 L .7915 .62632 L p F P
0 g
s
.936 .837 .722 r
.7915 .62632 m .79866 .61274 L .81124 .63217 L p F P
0 g
s
.958 .83 .675 r
.81124 .63217 m .79866 .61274 L .8135 .57698 L p F P
0 g
s
.331 .027 .291 r
.29898 .39316 m .3012 .38543 L .34376 .35116 L p F P
0 g
s
.137 0 .211 r
.29898 .39316 m .3012 .38543 L .29327 .3974 L closepath p F P
0 g
s
.941 .704 .551 r
.8108 .49231 m .79043 .47369 L .78578 .50569 L p F P
0 g
s
.941 .704 .551 r
.78578 .50569 m .80645 .5241 L .8108 .49231 L p F P
0 g
s
.745 .829 .916 r
.62208 .81336 m .60937 .82039 L .59244 .80532 L p F P
0 g
s
.671 .811 .95 r
.52617 .82954 m .59244 .80532 L .60937 .82039 L p F P
0 g
s
.486 .579 .874 r
.35274 .74593 m .33884 .76905 L .32303 .7441 L closepath p F P
0 g
s
.915 .845 .761 r
.78779 .67058 m .80595 .64229 L .7915 .62632 L p F P
0 g
s
.728 .307 .248 r
.62601 .30604 m .61092 .30271 L .60334 .31942 L p F P
0 g
s
.728 .307 .248 r
.60334 .31942 m .64295 .32811 L .62601 .30604 L p F P
0 g
s
.886 .548 .403 r
.76047 .39822 m .73141 .38138 L .7363 .40919 L p F P
0 g
s
.886 .548 .403 r
.7363 .40919 m .76551 .42599 L .76047 .39822 L p F P
0 g
s
.817 .424 .307 r
.71258 .35173 m .6857 .34098 L .69659 .36604 L p F P
0 g
s
.817 .424 .307 r
.69659 .36604 m .7074 .3703 L .71258 .35173 L p F P
0 g
s
.919 .63 .48 r
.79005 .44385 m .76551 .42599 L .76563 .45598 L p F P
0 g
s
.919 .63 .48 r
.76563 .45598 m .79043 .47369 L .79005 .44385 L p F P
0 g
s
.745 .829 .916 r
.59244 .80532 m .6109 .79506 L .62208 .81336 L p F P
0 g
s
.752 .832 .913 r
.6596 .767 m .6109 .79506 L .62208 .81336 L p F P
0 g
s
.752 .832 .913 r
.62208 .81336 m .67583 .7825 L .6596 .767 L p F P
0 g
s
.674 .773 .925 r
.57504 .78671 m .50821 .81143 L .52617 .82954 L p F P
0 g
s
.674 .773 .925 r
.52617 .82954 m .59243 .80532 L .57504 .78671 L p F P
0 g
s
.252 .028 .368 r
.29327 .3974 m .29898 .39316 L .29514 .4202 L p F P
0 g
s
.252 .028 .368 r
.29514 .4202 m .28324 .42892 L .29327 .3974 L p F P
0 g
s
.331 .027 .291 r
.34376 .35116 m .3642 .34129 L p .29898 .39316 L F P
0 g
s
.23 0 .123 r
.3642 .34129 m .36599 .33723 L .34376 .35116 L closepath p F P
0 g
s
.665 .236 .22 r
.61092 .30271 m .56979 .29792 L .59139 .31805 L p F P
0 g
s
.665 .236 .22 r
.59139 .31805 m .60334 .31942 L .61092 .30271 L p F P
0 g
s
.548 .161 .259 r
.43318 .32211 m .44111 .30269 L .49333 .29714 L p F P
0 g
s
.412 .034 .209 r
.44111 .30269 m .43318 .32211 L .38778 .33467 L p F P
0 g
s
.376 .238 .563 r
.24742 .52161 m .24551 .4876 L .28677 .45604 L p F P
0 g
s
.412 .16 .419 r
.29514 .4202 m .29898 .39316 L .35833 .36486 L p F P
0 g
s
.331 .027 .291 r
.3642 .34129 m .35833 .36486 L .29898 .39316 L p F P
0 g
s
.411 .032 .206 r
.3642 .34129 m .36599 .33723 L .38778 .33467 L closepath p F P
0 g
s
.889 .846 .796 r
.77529 .6514 m .78779 .67058 L .75575 .71172 L p F P
0 g
s
.915 .845 .761 r
.7915 .62632 m .77529 .6514 L .78779 .67058 L p F P
0 g
s
.932 .787 .678 r
.8135 .57698 m .79686 .55801 L .78169 .59408 L p F P
0 g
s
.932 .787 .678 r
.78169 .59408 m .79866 .61274 L .8135 .57698 L p F P
0 g
s
.629 .228 .263 r
.56979 .29792 m .59139 .31805 L .52326 .3138 L p F P
0 g
s
.629 .228 .263 r
.5199 .29496 m .56979 .29792 L p .52326 .3138 L F P
0 g
s
.548 .161 .259 r
.49333 .29714 m .51508 .30684 L p .43318 .32211 L F P
0 g
s
.552 .149 .232 r
.51508 .30684 m .49333 .29714 L .5199 .29496 L closepath p F P
0 g
s
.277 .21 .598 r
.24995 .54027 m .24152 .52868 L .24742 .52161 L closepath p F P
0 g
s
.24 .195 .604 r
.24152 .52868 m .24995 .54027 L .25304 .55955 L p F P
0 g
s
.59 .707 .924 r
.43604 .79965 m .42893 .80695 L .4244 .80175 L closepath p F P
0 g
s
.498 .556 .845 r
.32303 .7441 m .3038 .70877 L p .37281 .72335 L F P
0 g
s
.498 .556 .845 r
.37281 .72335 m .35274 .74593 L .32303 .7441 L p F P
0 g
s
.366 .478 .842 r
.2985 .70704 m .3038 .70877 L .32303 .7441 L p F P
0 g
s
.629 .228 .263 r
.52326 .3138 m .51508 .30684 L .5199 .29496 L p F P
0 g
s
.485 .167 .352 r
.35833 .36486 m .3642 .34129 L .38778 .33467 L p F P
0 g
s
.811 .84 .872 r
.70695 .75768 m .67583 .7825 L .6596 .767 L p F P
0 g
s
.789 .414 .345 r
.6857 .34098 m .64295 .32811 L .65384 .35303 L p F P
0 g
s
.789 .414 .345 r
.65384 .35303 m .69659 .36604 L .6857 .34098 L p F P
0 g
s
.868 .844 .819 r
.75575 .71172 m .74207 .72711 L .72664 .71119 L p F P
0 g
s
.868 .844 .819 r
.72664 .71119 m .74291 .69295 L .75575 .71172 L p F P
0 g
s
.889 .846 .796 r
.75575 .71172 m .74291 .69295 L .77529 .6514 L p F P
0 g
s
.811 .84 .872 r
.6596 .767 m .69444 .73921 L .70695 .75768 L p F P
0 g
s
.827 .844 .86 r
.72664 .71119 m .69444 .73921 L .70695 .75768 L p F P
0 g
s
.827 .844 .86 r
.70695 .75768 m .74207 .72711 L .72664 .71119 L p F P
0 g
s
.596 .676 .896 r
.4244 .80175 m .40542 .77642 L p .47767 .77309 L F P
0 g
s
.596 .676 .896 r
.47767 .77309 m .43604 .79965 L .4244 .80175 L p F P
0 g
s
.925 .731 .622 r
.80645 .5241 m .78578 .50569 L .77582 .53986 L p F P
0 g
s
.925 .731 .622 r
.77582 .53986 m .79686 .55801 L .80645 .5241 L p F P
0 g
s
.33 .148 .476 r
.28324 .42892 m .29514 .4202 L .29411 .45075 L p F P
0 g
s
.33 .148 .476 r
.29411 .45075 m .28677 .45604 L .28324 .42892 L p F P
0 g
s
.42 .313 .627 r
.24742 .52161 m .29613 .48493 L .30152 .52288 L p F P
0 g
s
.42 .313 .627 r
.24995 .54027 m .24742 .52161 L p .30152 .52288 L F P
0 g
s
.376 .238 .563 r
.29497 .46693 m .29613 .48493 L .24742 .52161 L p F P
0 g
s
.376 .238 .563 r
.28677 .45604 m .29497 .46693 L p .24742 .52161 L F P
0 g
s
.855 .524 .425 r
.73141 .38138 m .7074 .3703 L .70662 .39564 L p F P
0 g
s
.855 .524 .425 r
.70662 .39564 m .7363 .40919 L .73141 .38138 L p F P
0 g
s
.485 .167 .352 r
.38778 .33467 m .42968 .33775 L p .35833 .36486 L F P
0 g
s
.485 .163 .346 r
.42968 .33775 m .38778 .33467 L .43318 .32211 L closepath p F P
0 g
s
.387 .462 .815 r
.3038 .70877 m .2985 .70704 L .30081 .70252 L closepath p F P
0 g
s
.374 .409 .769 r
.28482 .66632 m .27071 .66031 L .27812 .64884 L closepath p F P
0 g
s
.355 .422 .793 r
.27071 .66031 m .28482 .66632 L .30081 .70252 L p F P
0 g
s
.91 .669 .562 r
.79043 .47369 m .76563 .45598 L .76061 .48818 L p F P
0 g
s
.91 .669 .562 r
.76061 .48818 m .78578 .50569 L .79043 .47369 L p F P
0 g
s
.597 .679 .898 r
.48989 .78973 m .43604 .79965 L .47767 .77309 L closepath p F P
0 g
s
.913 .797 .718 r
.7915 .62632 m .79866 .61274 L .78169 .59408 L p F P
0 g
s
.887 .6 .497 r
.76551 .42599 m .7363 .40919 L .73611 .43931 L p F P
0 g
s
.887 .6 .497 r
.73611 .43931 m .76563 .45598 L .76551 .42599 L p F P
0 g
s
.74 .791 .894 r
.588 .77946 m .57504 .78671 L .59243 .80532 L p F P
0 g
s
.74 .791 .894 r
.59243 .80532 m .6109 .79506 L .588 .77946 L p F P
0 g
s
.42 .313 .627 r
.30152 .52288 m .26522 .54975 L .24995 .54027 L p F P
0 g
s
.409 .317 .639 r
.26522 .54975 m .25304 .55955 L .24995 .54027 L closepath p F P
0 g
s
.673 .739 .9 r
.54499 .76903 m .48989 .78973 L .50821 .81143 L p F P
0 g
s
.673 .739 .9 r
.56152 .76983 m .54499 .76903 L p .50821 .81143 L F P
0 g
s
.673 .739 .9 r
.50821 .81143 m .57504 .78671 L .56152 .76983 L p F P
0 g
s
.5 .526 .815 r
.34769 .67244 m .36695 .71263 L .3038 .70877 L p F P
0 g
s
.5 .526 .815 r
.33308 .6716 m .34769 .67244 L p .3038 .70877 L F P
0 g
s
.5 .526 .815 r
.3038 .70877 m .30081 .70252 L .33308 .6716 L p F P
0 g
s
.498 .556 .845 r
.3038 .70877 m .36695 .71263 L .37281 .72335 L p F P
0 g
s
.913 .797 .718 r
.78169 .59408 m .77624 .60438 L .7915 .62632 L p F P
0 g
s
.891 .799 .751 r
.7915 .62632 m .77529 .6514 L .75754 .63321 L p F P
0 g
s
.891 .799 .751 r
.75754 .63321 m .77624 .60438 L .7915 .62632 L p F P
0 g
s
.486 .502 .799 r
.33308 .6716 m .30081 .70252 L .28482 .66632 L closepath p F P
0 g
s
.355 .349 .715 r
.26646 .61402 m .25746 .60878 L .26287 .60167 L closepath p F P
0 g
s
.334 .357 .735 r
.25746 .60878 m .26646 .61402 L .27812 .64884 L p F P
0 g
s
.74 .379 .367 r
.64295 .32811 m .65384 .35303 L .60415 .34212 L p F P
0 g
s
.74 .379 .367 r
.60334 .31942 m .64295 .32811 L p .60415 .34212 L F P
0 g
s
.746 .791 .889 r
.6596 .767 m .6109 .79506 L .588 .77946 L p F P
0 g
s
.463 .253 .508 r
.29411 .45075 m .29514 .4202 L .3551 .39204 L p F P
0 g
s
.412 .16 .419 r
.35833 .36486 m .3551 .39204 L .29514 .4202 L p F P
0 g
s
.447 .38 .689 r
.26287 .60167 m .25304 .55955 L .26522 .54975 L p F P
0 g
s
.509 .572 .855 r
.38624 .74692 m .35274 .74593 L .37281 .72335 L closepath p F P
0 g
s
.907 .751 .677 r
.79686 .55801 m .78169 .59408 L .76024 .57628 L p F P
0 g
s
.907 .751 .677 r
.77582 .53986 m .79686 .55801 L p .76024 .57628 L F P
0 g
s
.628 .228 .267 r
.51242 .31356 m .51508 .30684 L .52326 .3138 L closepath p F P
0 g
s
.548 .161 .259 r
.51508 .30684 m .51242 .31356 L .43318 .32211 L p F P
0 g
s
.833 .502 .429 r
.7074 .3703 m .69659 .36604 L .7017 .39374 L p F P
0 g
s
.833 .502 .429 r
.7017 .39374 m .70662 .39564 L .7074 .3703 L p F P
0 g
s
.869 .803 .783 r
.77529 .6514 m .75754 .63321 L .72463 .67519 L p F P
0 g
s
.869 .803 .783 r
.72463 .67519 m .74291 .69295 L .77529 .6514 L p F P
0 g
s
.58 .25 .374 r
.43318 .32211 m .51242 .31356 L p .43698 .34432 L F P
0 g
s
.58 .25 .374 r
.43698 .34432 m .42968 .33775 L .43318 .32211 L p F P
0 g
s
.493 .485 .776 r
.28482 .66632 m .27812 .64884 L p .34366 .66295 L F P
0 g
s
.493 .485 .776 r
.34366 .66295 m .33308 .6716 L .28482 .66632 L p F P
0 g
s
.597 .646 .869 r
.4523 .73441 m .38624 .74692 L .40542 .77642 L p F P
0 g
s
.597 .646 .869 r
.40542 .77642 m .47123 .76421 L .4523 .73441 L p F P
0 g
s
.596 .676 .896 r
.40542 .77642 m .47123 .76421 L .47767 .77309 L p F P
0 g
s
.493 .485 .776 r
.27812 .64884 m .3093 .62228 L p .34366 .66295 L F P
0 g
s
.469 .443 .747 r
.3093 .62228 m .27812 .64884 L .26646 .61402 L closepath p F P
0 g
s
.476 .43 .727 r
.26287 .60167 m .31038 .56454 L .3241 .61103 L p F P
0 g
s
.476 .43 .727 r
.26646 .61402 m .26287 .60167 L p .3241 .61103 L F P
0 g
s
.447 .38 .689 r
.31037 .56451 m .31038 .56454 L .26287 .60167 L p F P
0 g
s
.447 .38 .689 r
.26522 .54975 m .31037 .56451 L p .26287 .60167 L F P
0 g
s
.74 .379 .367 r
.60415 .34212 m .60043 .33398 L .60334 .31942 L p F P
0 g
s
.706 .345 .361 r
.60043 .33398 m .59139 .31805 L .60334 .31942 L closepath p F P
0 g
s
.476 .43 .727 r
.3241 .61103 m .3093 .62228 L .26646 .61402 L p F P
0 g
s
.803 .482 .445 r
.69659 .36604 m .65384 .35303 L .65865 .38075 L p F P
0 g
s
.803 .482 .445 r
.65865 .38075 m .7017 .39374 L .69659 .36604 L p F P
0 g
s
.682 .325 .363 r
.59139 .31805 m .52326 .3138 L .53698 .33724 L p F P
0 g
s
.682 .325 .363 r
.60043 .33398 m .59139 .31805 L p .53698 .33724 L F P
0 g
s
.529 .259 .45 r
.3551 .39204 m .35833 .36486 L .42794 .34547 L p F P
0 g
s
.485 .167 .352 r
.42968 .33775 m .42794 .34547 L .35833 .36486 L p F P
0 g
s
.799 .802 .854 r
.67466 .72224 m .64284 .74768 L .6596 .767 L p F P
0 g
s
.799 .802 .854 r
.6596 .767 m .69444 .73921 L .67466 .72224 L p F P
0 g
s
.746 .791 .889 r
.588 .77946 m .64284 .74768 L .6596 .767 L p F P
0 g
s
.895 .695 .624 r
.78578 .50569 m .76061 .48818 L .75017 .52263 L p F P
0 g
s
.895 .695 .624 r
.75017 .52263 m .77582 .53986 L .78578 .50569 L p F P
0 g
s
.851 .805 .805 r
.72664 .71119 m .74291 .69295 L .72463 .67519 L p F P
0 g
s
.813 .801 .841 r
.72664 .71119 m .69444 .73921 L .67466 .72224 L p F P
0 g
s
.856 .573 .508 r
.7363 .40919 m .70662 .39564 L .71037 .42772 L p F P
0 g
s
.856 .573 .508 r
.71037 .42772 m .73611 .43931 L .7363 .40919 L p F P
0 g
s
.386 .237 .554 r
.29497 .46693 m .28677 .45604 L .29411 .45075 L closepath p F P
0 g
s
.879 .637 .568 r
.76563 .45598 m .73611 .43931 L .73064 .47172 L p F P
0 g
s
.879 .637 .568 r
.73064 .47172 m .76061 .48818 L .76563 .45598 L p F P
0 g
s
.851 .805 .805 r
.72463 .67519 m .7106 .69092 L .72664 .71119 L p F P
0 g
s
.813 .801 .841 r
.67466 .72224 m .7106 .69092 L .72664 .71119 L p F P
0 g
s
.454 .372 .674 r
.31037 .56451 m .26522 .54975 L .30152 .52288 L closepath p F P
0 g
s
.666 .324 .385 r
.52326 .3138 m .51242 .31356 L .50788 .3366 L p F P
0 g
s
.666 .324 .385 r
.50788 .3366 m .53698 .33724 L .52326 .3138 L p F P
0 g
s
.58 .25 .374 r
.51242 .31356 m .50788 .3366 L .43698 .34432 L p F P
0 g
s
.89 .759 .711 r
.77624 .60438 m .78169 .59408 L .76024 .57628 L closepath p F P
0 g
s
.67 .708 .876 r
.48989 .78973 m .54499 .76903 L .47767 .77309 L closepath p F P
0 g
s
.733 .757 .872 r
.57504 .78671 m .588 .77946 L .56152 .76983 L closepath p F P
0 g
s
.499 .325 .575 r
.29411 .45075 m .3546 .4228 L .35694 .45712 L p F P
0 g
s
.499 .325 .575 r
.29497 .46693 m .29411 .45075 L p .35694 .45712 L F P
0 g
s
.463 .253 .508 r
.3551 .39204 m .3546 .4228 L .29411 .45075 L p F P
0 g
s
.867 .758 .74 r
.77624 .60438 m .76024 .57628 L p .73438 .61609 L F P
0 g
s
.867 .758 .74 r
.73438 .61609 m .75754 .63321 L .77624 .60438 L p F P
0 g
s
.738 .757 .868 r
.64284 .74768 m .588 .77946 L .56152 .76983 L p F P
0 g
s
.58 .25 .373 r
.42794 .34547 m .42968 .33775 L .43698 .34432 L closepath p F P
0 g
s
.772 .459 .457 r
.65384 .35303 m .60415 .34212 L .60869 .36981 L p F P
0 g
s
.772 .459 .457 r
.60869 .36981 m .65865 .38075 L .65384 .35303 L p F P
0 g
s
.595 .615 .841 r
.43317 .70007 m .4523 .73441 L .38624 .74692 L p F P
0 g
s
.595 .615 .841 r
.4122 .70414 m .43317 .70007 L p .38624 .74692 L F P
0 g
s
.595 .615 .841 r
.38624 .74692 m .37281 .72335 L .4122 .70414 L p F P
0 g
s
.881 .715 .672 r
.76021 .57621 m .77582 .53986 L .75017 .52263 L p F P
0 g
s
.907 .751 .677 r
.76024 .57628 m .76021 .57621 L .77582 .53986 L p F P
0 g
s
.734 .376 .373 r
.59906 .34128 m .60043 .33398 L .60415 .34212 L closepath p F P
0 g
s
.682 .325 .363 r
.53698 .33724 m .59906 .34128 L .60043 .33398 L p F P
0 g
s
.499 .325 .575 r
.35694 .45712 m .32544 .47142 L .29497 .46693 L p F P
0 g
s
.499 .328 .58 r
.32544 .47142 m .29613 .48493 L .29497 .46693 L closepath p F P
0 g
s
.848 .764 .77 r
.75754 .63321 m .73438 .61609 L .70074 .65855 L p F P
0 g
s
.848 .764 .77 r
.70074 .65855 m .72463 .67519 L .75754 .63321 L p F P
0 g
s
.835 .557 .517 r
.70662 .39564 m .7017 .39374 L .70081 .42408 L p F P
0 g
s
.835 .557 .517 r
.70081 .42408 m .71037 .42772 L .70662 .39564 L p F P
0 g
s
.807 .531 .522 r
.7017 .39374 m .65865 .38075 L .65718 .41124 L p F P
0 g
s
.807 .531 .522 r
.65718 .41124 m .70081 .42408 L .7017 .39374 L p F P
0 g
s
.871 .666 .622 r
.76061 .48818 m .75017 .52263 L .73363 .5138 L p F P
0 g
s
.871 .666 .622 r
.73064 .47172 m .76061 .48818 L p .73363 .5138 L F P
0 g
s
.612 .329 .463 r
.43698 .34432 m .42794 .34547 L .42541 .37269 L p F P
0 g
s
.529 .259 .45 r
.42794 .34547 m .42541 .37269 L .3551 .39204 L p F P
0 g
s
.671 .705 .873 r
.55721 .7644 m .54499 .76903 L .47767 .77309 L p F P
0 g
s
.671 .705 .873 r
.53899 .73805 m .55721 .7644 L p .47767 .77309 L F P
0 g
s
.671 .705 .873 r
.47767 .77309 m .47123 .76421 L .53899 .73805 L p F P
0 g
s
.56 .33 .523 r
.3546 .4228 m .3551 .39204 L .42541 .37269 L p F P
0 g
s
.612 .329 .463 r
.42541 .37269 m .44434 .37031 L .43698 .34432 L p F P
0 g
s
.621 .334 .461 r
.50788 .3366 m .43698 .34432 L .44434 .37031 L p F P
0 g
s
.852 .609 .571 r
.73611 .43931 m .71037 .42772 L .71884 .46649 L p F P
0 g
s
.852 .609 .571 r
.71884 .46649 m .73064 .47172 L .73611 .43931 L p F P
0 g
s
.787 .767 .835 r
.64738 .70691 m .62559 .7244 L .64284 .74768 L p F P
0 g
s
.787 .767 .835 r
.64284 .74768 m .67466 .72224 L .64738 .70691 L p F P
0 g
s
.738 .757 .868 r
.62559 .7244 m .64284 .74768 L p .56152 .76983 L F P
0 g
s
.592 .604 .833 r
.4122 .70414 m .37281 .72335 L .36695 .71263 L closepath p F P
0 g
s
.526 .385 .633 r
.30152 .52288 m .29613 .48493 L .32544 .47142 L p F P
0 g
s
.75 .442 .462 r
.60415 .34212 m .59906 .34128 L .59805 .36805 L p F P
0 g
s
.75 .442 .462 r
.59805 .36805 m .60869 .36981 L .60415 .34212 L p F P
0 g
s
.834 .77 .79 r
.7106 .69092 m .72463 .67519 L .70074 .65855 L p F P
0 g
s
.797 .762 .821 r
.7106 .69092 m .67466 .72224 L .64738 .70691 L p F P
0 g
s
.705 .402 .462 r
.59906 .34128 m .53698 .33724 L .5421 .36447 L p F P
0 g
s
.705 .402 .462 r
.5421 .36447 m .59805 .36805 L .59906 .34128 L p F P
0 g
s
.738 .757 .868 r
.56152 .76983 m .55721 .7644 L .62559 .7244 L p F P
0 g
s
.675 .737 .898 r
.54499 .76903 m .56152 .76983 L .55721 .7644 L closepath p F P
0 g
s
.834 .77 .79 r
.70074 .65855 m .69399 .66613 L .7106 .69092 L p F P
0 g
s
.797 .762 .821 r
.64738 .70691 m .69399 .66613 L .7106 .69092 L p F P
0 g
s
.665 .673 .847 r
.52042 .70745 m .4523 .73441 L .47123 .76421 L p F P
0 g
s
.665 .673 .847 r
.47123 .76421 m .53899 .73805 L .52042 .70745 L p F P
0 g
s
.591 .583 .813 r
.36695 .71263 m .34769 .67244 L p .43097 .69565 L F P
0 g
s
.591 .583 .813 r
.43097 .69565 m .4122 .70414 L .36695 .71263 L p F P
0 g
s
.867 .758 .74 r
.76024 .57628 m .76019 .57624 L .73438 .61609 L p F P
0 g
s
.885 .75 .707 r
.76019 .57624 m .76024 .57628 L .76021 .57621 L closepath p F P
0 g
s
.881 .715 .672 r
.75017 .52263 m .74327 .53877 L .76021 .57621 L p F P
0 g
s
.86 .71 .695 r
.76021 .57621 m .76019 .57624 L .7322 .55988 L p F P
0 g
s
.86 .71 .695 r
.7322 .55988 m .74327 .53877 L .76021 .57621 L p F P
0 g
s
.845 .721 .727 r
.76019 .57624 m .7322 .55988 L .70556 .60018 L p F P
0 g
s
.845 .721 .727 r
.70556 .60018 m .73438 .61609 L .76019 .57624 L p F P
0 g
s
.506 .508 .793 r
.34769 .67244 m .33308 .6716 L .34366 .66295 L closepath p F P
0 g
s
.686 .39 .467 r
.53698 .33724 m .50788 .3366 L .50609 .36369 L p F P
0 g
s
.686 .39 .467 r
.50609 .36369 m .5421 .36447 L .53698 .33724 L p F P
0 g
s
.621 .334 .461 r
.44434 .37031 m .50609 .36369 L .50788 .3366 L p F P
0 g
s
.728 .72 .843 r
.60789 .69695 m .53899 .73805 L .55721 .7644 L p F P
0 g
s
.728 .72 .843 r
.55721 .7644 m .62559 .7244 L .60789 .69695 L p F P
0 g
s
.494 .463 .752 r
.32869 .6244 m .3093 .62228 L .3241 .61103 L closepath p F P
0 g
s
.493 .485 .776 r
.3093 .62228 m .32869 .6244 L .34366 .66295 L p F P
0 g
s
.778 .506 .525 r
.65865 .38075 m .60869 .36981 L .60665 .4004 L p F P
0 g
s
.778 .506 .525 r
.60665 .4004 m .65718 .41124 L .65865 .38075 L p F P
0 g
s
.831 .596 .584 r
.71037 .42772 m .70081 .42408 L .69358 .45711 L p F P
0 g
s
.831 .596 .584 r
.69358 .45711 m .71884 .46649 L .71037 .42772 L p F P
0 g
s
.549 .44 .682 r
.30152 .52288 m .36254 .49529 L .37164 .53739 L p F P
0 g
s
.549 .44 .682 r
.31037 .56451 m .30152 .52288 L p .37164 .53739 L F P
0 g
s
.526 .385 .633 r
.35865 .4698 m .36254 .49529 L .30152 .52288 L p F P
0 g
s
.526 .385 .633 r
.32544 .47142 m .35865 .4698 L p .30152 .52288 L F P
0 g
s
.858 .683 .663 r
.74327 .53877 m .75017 .52263 L .73363 .5138 L closepath p F P
0 g
s
.585 .552 .784 r
.40397 .63606 m .41395 .65981 L .34769 .67244 L p F P
0 g
s
.585 .552 .784 r
.34769 .67244 m .34366 .66295 L .40397 .63606 L p F P
0 g
s
.591 .583 .813 r
.34769 .67244 m .41395 .65981 L .43097 .69565 L p F P
0 g
s
.83 .735 .759 r
.73438 .61609 m .70074 .65855 L .68473 .65023 L p F P
0 g
s
.83 .735 .759 r
.70556 .60018 m .73438 .61609 L p .68473 .65023 L F P
0 g
s
.804 .568 .581 r
.70081 .42408 m .65718 .41124 L .64915 .44452 L p F P
0 g
s
.804 .568 .581 r
.64915 .44452 m .69358 .45711 L .70081 .42408 L p F P
0 g
s
.845 .635 .618 r
.72533 .48895 m .73064 .47172 L .71884 .46649 L closepath p F P
0 g
s
.871 .666 .622 r
.73363 .5138 m .72533 .48895 L .73064 .47172 L p F P
0 g
s
.523 .375 .621 r
.35865 .4698 m .32544 .47142 L .35694 .45712 L closepath p F P
0 g
s
.578 .533 .768 r
.39479 .61232 m .40397 .63606 L .34366 .66295 L p F P
0 g
s
.578 .533 .768 r
.34366 .66295 m .32869 .6244 L .39479 .61232 L p F P
0 g
s
.583 .387 .582 r
.42558 .40361 m .3546 .4228 L .35694 .45712 L p F P
0 g
s
.56 .33 .523 r
.42541 .37269 m .42558 .40361 L .3546 .4228 L p F P
0 g
s
.836 .676 .684 r
.74327 .53877 m .73363 .5138 L p .69842 .54485 L F P
0 g
s
.836 .676 .684 r
.69842 .54485 m .7322 .55988 L .74327 .53877 L p F P
0 g
s
.632 .387 .528 r
.44434 .37031 m .42541 .37269 L .42558 .40361 L p F P
0 g
s
.549 .44 .682 r
.37164 .53739 m .31047 .5645 L .31037 .56451 L p F P
0 g
s
.551 .45 .693 r
.31047 .5645 m .31038 .56454 L .31037 .56451 L closepath p F P
0 g
s
.564 .483 .722 r
.3241 .61103 m .31038 .56454 L .31047 .5645 L p F P
0 g
s
.56 .466 .705 r
.37602 .55378 m .31047 .5645 L .37164 .53739 L closepath p F P
0 g
s
.564 .483 .722 r
.31047 .5645 m .37602 .55378 L p .3241 .61103 L F P
0 g
s
.774 .735 .817 r
.6123 .69338 m .60789 .69695 L .62559 .7244 L p F P
0 g
s
.774 .735 .817 r
.62559 .7244 m .64738 .70691 L .6123 .69338 L p F P
0 g
s
.66 .644 .823 r
.45444 .69143 m .43317 .70007 L .4523 .73441 L p F P
0 g
s
.66 .644 .823 r
.50732 .68306 m .45444 .69143 L p .4523 .73441 L F P
0 g
s
.66 .644 .823 r
.4523 .73441 m .52042 .70745 L .50732 .68306 L p F P
0 g
s
.574 .511 .746 r
.38507 .58403 m .39479 .61232 L .32869 .6244 L p F P
0 g
s
.574 .511 .746 r
.32869 .6244 m .3241 .61103 L .38507 .58403 L p F P
0 g
s
.564 .483 .722 r
.37602 .55378 m .38507 .58403 L .3241 .61103 L p F P
0 g
s
.632 .387 .528 r
.42558 .40361 m .43723 .40216 L .44434 .37031 L p F P
0 g
s
.641 .396 .531 r
.50609 .36369 m .44434 .37031 L .43723 .40216 L p F P
0 g
s
.823 .625 .635 r
.71884 .46649 m .69358 .45711 L .67961 .49284 L p F P
0 g
s
.823 .625 .635 r
.72533 .48895 m .71884 .46649 L p .67961 .49284 L F P
0 g
s
.783 .729 .803 r
.6123 .69338 m .64738 .70691 L .69399 .66613 L p F P
0 g
s
.818 .738 .776 r
.69399 .66613 m .70074 .65855 L .68473 .65023 L closepath p F P
0 g
s
.758 .489 .527 r
.60869 .36981 m .59805 .36805 L .6001 .39934 L p F P
0 g
s
.758 .489 .527 r
.6001 .39934 m .60665 .4004 L .60869 .36981 L p F P
0 g
s
.836 .676 .684 r
.73363 .5138 m .71854 .50679 L .69842 .54485 L p F P
0 g
s
.848 .656 .643 r
.71854 .50679 m .73363 .5138 L .72533 .48895 L closepath p F P
0 g
s
.783 .729 .803 r
.69399 .66613 m .68473 .65023 L p .6123 .69338 L F P
0 g
s
.823 .625 .635 r
.67961 .49284 m .71854 .50679 L .72533 .48895 L p F P
0 g
s
.717 .457 .532 r
.59805 .36805 m .5421 .36447 L .53839 .39547 L p F P
0 g
s
.717 .457 .532 r
.53839 .39547 m .6001 .39934 L .59805 .36805 L p F P
0 g
s
.822 .688 .716 r
.7322 .55988 m .69842 .54485 L .67076 .58562 L p F P
0 g
s
.822 .688 .716 r
.67076 .58562 m .70556 .60018 L .7322 .55988 L p F P
0 g
s
.593 .591 .819 r
.43317 .70007 m .4122 .70414 L .43097 .69565 L closepath p F P
0 g
s
.719 .691 .822 r
.5567 .68551 m .52042 .70745 L .53899 .73805 L p F P
0 g
s
.719 .691 .822 r
.60465 .6913 m .5567 .68551 L p .53899 .73805 L F P
0 g
s
.719 .691 .822 r
.53899 .73805 m .60789 .69695 L .60465 .6913 L p F P
0 g
s
.699 .441 .53 r
.5421 .36447 m .50609 .36369 L .50713 .3948 L p F P
0 g
s
.699 .441 .53 r
.50713 .3948 m .53839 .39547 L .5421 .36447 L p F P
0 g
s
.641 .396 .531 r
.43723 .40216 m .50713 .3948 L .50609 .36369 L p F P
0 g
s
.779 .545 .581 r
.65718 .41124 m .64915 .44452 L .60559 .43542 L p F P
0 g
s
.779 .545 .581 r
.60665 .4004 m .65718 .41124 L p .60559 .43542 L F P
0 g
s
.812 .643 .673 r
.71854 .50679 m .67961 .49284 L .65846 .53132 L p F P
0 g
s
.812 .643 .673 r
.65846 .53132 m .69842 .54485 L .71854 .50679 L p F P
0 g
s
.598 .428 .622 r
.35865 .4698 m .39346 .44745 L .35694 .45712 L closepath p F P
0 g
s
.583 .387 .582 r
.42694 .42004 m .42558 .40361 L p .35694 .45712 L F P
0 g
s
.583 .387 .582 r
.35694 .45712 m .39346 .44745 L .42694 .42004 L p F P
0 g
s
.798 .595 .628 r
.69358 .45711 m .64915 .44452 L .63419 .4806 L p F P
0 g
s
.798 .595 .628 r
.63419 .4806 m .67961 .49284 L .69358 .45711 L p F P
0 g
s
.83 .735 .759 r
.68473 .65023 m .67681 .63622 L .70556 .60018 L p F P
0 g
s
.783 .729 .803 r
.68473 .65023 m .66911 .64371 L .6123 .69338 L p F P
0 g
s
.794 .725 .787 r
.66911 .64371 m .68473 .65023 L .67681 .63622 L closepath p F P
0 g
s
.811 .702 .745 r
.67681 .63622 m .70556 .60018 L .67076 .58562 L p F P
0 g
s
.655 .621 .804 r
.43317 .70007 m .45444 .69143 L .43097 .69565 L closepath p F P
0 g
s
.655 .612 .794 r
.50158 .67197 m .45444 .69143 L .43097 .69565 L p F P
0 g
s
.655 .612 .794 r
.48254 .63049 m .50158 .67197 L p .43097 .69565 L F P
0 g
s
.655 .612 .794 r
.43097 .69565 m .41395 .65981 L .48254 .63049 L p F P
0 g
s
.605 .441 .633 r
.36254 .49529 m .35865 .4698 L .39346 .44745 L p F P
0 g
s
.645 .431 .579 r
.42694 .42004 m .43723 .40216 L .42558 .40361 L closepath p F P
0 g
s
.762 .707 .8 r
.60789 .69695 m .6123 .69338 L .60465 .6913 L closepath p F P
0 g
s
.771 .704 .788 r
.66911 .64371 m .6123 .69338 L .60465 .6913 L p F P
0 g
s
.656 .444 .585 r
.43723 .40216 m .50713 .3948 L p .42865 .43832 L F P
0 g
s
.656 .444 .585 r
.42865 .43832 m .42694 .42004 L .43723 .40216 L p F P
0 g
s
.811 .702 .745 r
.67076 .58562 m .6591 .60034 L .67681 .63622 L p F P
0 g
s
.778 .691 .768 r
.67681 .63622 m .66911 .64371 L .62741 .63145 L p F P
0 g
s
.778 .691 .768 r
.62741 .63145 m .6591 .60034 L .67681 .63622 L p F P
0 g
s
.771 .704 .788 r
.62741 .63145 m .66911 .64371 L p .60465 .6913 L F P
0 g
s
.76 .525 .576 r
.60255 .41633 m .60665 .4004 L .6001 .39934 L closepath p F P
0 g
s
.779 .545 .581 r
.60559 .43542 m .60255 .41633 L .60665 .4004 L p F P
0 g
s
.66 .637 .815 r
.45444 .69143 m .50732 .68306 L .50158 .67197 L closepath p F P
0 g
s
.771 .704 .788 r
.60465 .6913 m .58976 .66452 L .62741 .63145 L p F P
0 g
s
.724 .687 .813 r
.5567 .68551 m .60465 .6913 L .58976 .66452 L closepath p F P
0 g
s
.722 .498 .585 r
.6001 .39934 m .53839 .39547 L .52547 .43022 L p F P
0 g
s
.722 .498 .585 r
.60255 .41633 m .6001 .39934 L p .52547 .43022 L F P
0 g
s
.711 .666 .804 r
.52042 .70745 m .5567 .68551 L .50732 .68306 L closepath p F P
0 g
s
.805 .665 .709 r
.69842 .54485 m .67076 .58562 L .64974 .57887 L p F P
0 g
s
.805 .665 .709 r
.65846 .53132 m .69842 .54485 L p .64974 .57887 L F P
0 g
s
.605 .441 .633 r
.39346 .44745 m .42865 .43832 L p .36254 .49529 L F P
0 g
s
.587 .394 .586 r
.39346 .44745 m .42865 .43832 L .42694 .42004 L closepath p F P
0 g
s
.618 .485 .677 r
.43495 .47702 m .36254 .49529 L .37164 .53739 L p F P
0 g
s
.605 .441 .633 r
.42865 .43832 m .43495 .47702 L .36254 .49529 L p F P
0 g
s
.647 .585 .772 r
.47852 .62071 m .48254 .63049 L .41395 .65981 L p F P
0 g
s
.647 .585 .772 r
.41395 .65981 m .40397 .63606 L .47852 .62071 L p F P
0 g
s
.777 .573 .624 r
.64915 .44452 m .60559 .43542 L .61496 .47666 L p F P
0 g
s
.777 .573 .624 r
.61496 .47666 m .63419 .4806 L .64915 .44452 L p F P
0 g
s
.706 .481 .581 r
.53839 .39547 m .50713 .3948 L .51111 .42992 L p F P
0 g
s
.706 .481 .581 r
.51111 .42992 m .52547 .43022 L .53839 .39547 L p F P
0 g
s
.793 .622 .668 r
.67961 .49284 m .65846 .53132 L .62896 .52372 L p F P
0 g
s
.793 .622 .668 r
.63419 .4806 m .67961 .49284 L p .62896 .52372 L F P
0 g
s
.656 .444 .585 r
.50713 .3948 m .51111 .42992 L .42865 .43832 L p F P
0 g
s
.722 .498 .585 r
.52547 .43022 m .59627 .43442 L .60255 .41633 L p F P
0 g
s
.741 .518 .592 r
.59627 .43442 m .60559 .43542 L .60255 .41633 L closepath p F P
0 g
s
.716 .661 .794 r
.58976 .66452 m .5567 .68551 L .50732 .68306 L p F P
0 g
s
.645 .571 .757 r
.46345 .58104 m .47852 .62071 L .40397 .63606 L p F P
0 g
s
.645 .571 .757 r
.40397 .63606 m .39479 .61232 L .46345 .58104 L p F P
0 g
s
.624 .506 .698 r
.37602 .55378 m .44443 .51965 L .37164 .53739 L closepath p F P
0 g
s
.618 .485 .677 r
.44454 .51959 m .43495 .47702 L p .37164 .53739 L F P
0 g
s
.618 .485 .677 r
.37164 .53739 m .44443 .51965 L .44454 .51959 L p F P
0 g
s
.795 .674 .73 r
.6591 .60034 m .67076 .58562 L .64974 .57887 L closepath p F P
0 g
s
.716 .661 .794 r
.57127 .62678 m .58976 .66452 L p .50732 .68306 L F P
0 g
s
.716 .661 .794 r
.50732 .68306 m .50158 .67197 L .57127 .62678 L p F P
0 g
s
.636 .547 .737 r
.45877 .5673 m .46345 .58104 L .39479 .61232 L p F P
0 g
s
.636 .547 .737 r
.39479 .61232 m .38507 .58403 L .45877 .5673 L p F P
0 g
s
.633 .526 .715 r
.38507 .58403 m .37602 .55378 L .44443 .51965 L p F P
0 g
s
.665 .484 .63 r
.51111 .42992 m .42865 .43832 L .43495 .47702 L p F P
0 g
s
.633 .526 .715 r
.44455 .51962 m .45877 .5673 L .38507 .58403 L p F P
0 g
s
.633 .526 .715 r
.44443 .51965 m .44455 .51962 L p .38507 .58403 L F P
0 g
s
.761 .661 .751 r
.6591 .60034 m .64974 .57887 L p .57736 .62137 L F P
0 g
s
.761 .661 .751 r
.57736 .62137 m .62741 .63145 L .6591 .60034 L p F P
0 g
s
.756 .673 .77 r
.57736 .62137 m .57127 .62678 L .58976 .66452 L p F P
0 g
s
.756 .673 .77 r
.58976 .66452 m .62741 .63145 L .57736 .62137 L p F P
0 g
s
.742 .552 .636 r
.60559 .43542 m .59627 .43442 L .57523 .47252 L p F P
0 g
s
.742 .552 .636 r
.57523 .47252 m .61496 .47666 L .60559 .43542 L p F P
0 g
s
.702 .629 .772 r
.49843 .61998 m .48254 .63049 L .50158 .67197 L p F P
0 g
s
.702 .629 .772 r
.56834 .62013 m .49843 .61998 L p .50158 .67197 L F P
0 g
s
.702 .629 .772 r
.50158 .67197 m .57127 .62678 L .56834 .62013 L p F P
0 g
s
.725 .531 .628 r
.59627 .43442 m .57523 .47252 L .51847 .46939 L p F P
0 g
s
.725 .531 .628 r
.52547 .43022 m .59627 .43442 L p .51847 .46939 L F P
0 g
s
.786 .636 .696 r
.64088 .55699 m .65846 .53132 L .62896 .52372 L closepath p F P
0 g
s
.805 .665 .709 r
.64974 .57887 m .64088 .55699 L .65846 .53132 L p F P
0 g
s
.761 .661 .751 r
.64974 .57887 m .62607 .57371 L .57736 .62137 L p F P
0 g
s
.769 .649 .73 r
.62607 .57371 m .64974 .57887 L .64088 .55699 L closepath p F P
0 g
s
.774 .596 .658 r
.62213 .50212 m .63419 .4806 L .61496 .47666 L closepath p F P
0 g
s
.793 .622 .668 r
.62896 .52372 m .62213 .50212 L .63419 .4806 L p F P
0 g
s
.71 .513 .62 r
.51453 .44931 m .52547 .43022 L .51111 .42992 L closepath p F P
0 g
s
.725 .531 .628 r
.51847 .46939 m .51453 .44931 L .52547 .43022 L p F P
0 g
s
.665 .484 .63 r
.51453 .44931 m .51111 .42992 L p .43495 .47702 L F P
0 g
s
.752 .622 .715 r
.64088 .55699 m .62896 .52372 L p .56903 .56535 L F P
0 g
s
.752 .622 .715 r
.56903 .56535 m .62607 .57371 L .64088 .55699 L p F P
0 g
s
.671 .514 .664 r
.44454 .51959 m .49615 .47104 L .43495 .47702 L closepath p F P
0 g
s
.665 .484 .63 r
.43495 .47702 m .49615 .47104 L .51453 .44931 L p F P
0 g
s
.74 .577 .673 r
.61496 .47666 m .57523 .47252 L .54426 .51428 L p F P
0 g
s
.74 .577 .673 r
.62213 .50212 m .61496 .47666 L p .54426 .51428 L F P
0 g
s
.75 .64 .738 r
.62607 .57371 m .57736 .62137 L .56834 .62013 L p F P
0 g
s
.75 .64 .738 r
.56903 .56535 m .62607 .57371 L p .56834 .62013 L F P
0 g
s
.757 .603 .686 r
.60865 .52057 m .62896 .52372 L .62213 .50212 L closepath p F P
0 g
s
.74 .577 .673 r
.54426 .51428 m .60865 .52057 L .62213 .50212 L p F P
0 g
s
.752 .622 .715 r
.62896 .52372 m .60865 .52057 L .56903 .56535 L p F P
0 g
s
.695 .609 .757 r
.48254 .63049 m .49843 .61998 L .47852 .62071 L closepath p F P
0 g
s
.676 .499 .639 r
.49615 .47104 m .51847 .46939 L .51453 .44931 L closepath p F P
0 g
s
.744 .648 .755 r
.57127 .62678 m .57736 .62137 L .56834 .62013 L closepath p F P
0 g
s
.697 .597 .741 r
.55247 .58169 m .49843 .61998 L .47852 .62071 L p F P
0 g
s
.697 .597 .741 r
.54565 .56319 m .55247 .58169 L p .47852 .62071 L F P
0 g
s
.697 .597 .741 r
.48478 .56553 m .54565 .56319 L p .47852 .62071 L F P
0 g
s
.697 .597 .741 r
.47852 .62071 m .46345 .58104 L .48478 .56553 L p F P
0 g
s
.725 .557 .663 r
.57523 .47252 m .51847 .46939 L .52962 .51349 L p F P
0 g
s
.725 .557 .663 r
.52962 .51349 m .54426 .51428 L .57523 .47252 L p F P
0 g
s
.75 .64 .738 r
.56834 .62013 m .55247 .58169 L .56903 .56535 L p F P
0 g
s
.706 .619 .757 r
.49843 .61998 m .56834 .62013 L .55247 .58169 L closepath p F P
0 g
s
.74 .6 .702 r
.60865 .52057 m .56903 .56535 L .54565 .56319 L p F P
0 g
s
.74 .6 .702 r
.54426 .51428 m .60865 .52057 L p .54565 .56319 L F P
0 g
s
.683 .533 .677 r
.49615 .47104 m .51847 .46939 L p .44455 .51962 L F P
0 g
s
.683 .533 .677 r
.44455 .51962 m .44454 .51959 L .49615 .47104 L p F P
0 g
s
.624 .497 .687 r
.44443 .51965 m .44455 .51962 L .44454 .51959 L closepath p F P
0 g
s
.684 .556 .704 r
.52962 .51349 m .44455 .51962 L .45877 .5673 L p F P
0 g
s
.683 .533 .677 r
.51847 .46939 m .52962 .51349 L .44455 .51962 L p F P
0 g
s
.685 .574 .724 r
.46345 .58104 m .48478 .56553 L .45877 .5673 L closepath p F P
0 g
s
.684 .556 .704 r
.53349 .52647 m .52962 .51349 L p .45877 .5673 L F P
0 g
s
.684 .556 .704 r
.45877 .5673 m .48478 .56553 L .53349 .52647 L p F P
0 g
s
.695 .576 .717 r
.48478 .56553 m .54565 .56319 L .53349 .52647 L closepath p F P
0 g
s
.735 .614 .723 r
.55247 .58169 m .56903 .56535 L .54565 .56319 L closepath p F P
0 g
s
.725 .577 .689 r
.53349 .52647 m .54426 .51428 L .52962 .51349 L closepath p F P
0 g
s
.74 .6 .702 r
.54565 .56319 m .53349 .52647 L .54426 .51428 L p F P
0 g
s
.25 Mabswid
.67411 0 m
.93226 .41737 L
s
.93226 .41737 m
1 .91353 L
s
1 .91353 m
.70561 .5445 L
s
.70561 .5445 m
.67411 0 L
s
.08224 .2468 m
0 .76615 L
s
0 .76615 m
.70561 .5445 L
s
.70561 .5445 m
.67411 0 L
s
.67411 0 m
.08224 .2468 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0119442 0.97619 0.489714 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0474435 1.09022 0 1.09022 [
[ 0 0 0 0 ]
[ 1 1.06007 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07412 .27037 m
0 .88688 L
s
0 .88688 m
.24147 1.06007 L
s
.24147 1.06007 m
.27626 .47442 L
s
.27626 .47442 m
.07412 .27037 L
s
.76886 0 m
.92458 .25192 L
s
.92458 .25192 m
1 .87095 L
s
1 .87095 m
.82297 .64898 L
s
.82297 .64898 m
.76886 0 L
s
.07412 .27037 m
0 .88688 L
s
0 .88688 m
.82297 .64898 L
s
.82297 .64898 m
.76886 0 L
s
.76886 0 m
.07412 .27037 L
s
.27626 .47442 m
.92458 .25192 L
s
.92458 .25192 m
1 .87095 L
s
1 .87095 m
.24147 1.06007 L
s
.24147 1.06007 m
.27626 .47442 L
s
0 0 m
1 0 L
1 1.06007 L
0 1.06007 L
closepath
clip
newpath
.5 Mabswid
.697 .571 .709 r
.4043 .51412 m .45386 .47275 L .39195 .47523 L closepath p F P
0 g
s
.697 .591 .733 r
.45386 .47275 m .39195 .47523 L .38581 .45895 L p F P
0 g
s
.723 .585 .701 r
.39195 .47523 m .37092 .47331 L p .39664 .52235 L F P
0 g
s
.723 .585 .701 r
.39664 .52235 m .4043 .51412 L .39195 .47523 L p F P
0 g
s
.728 .607 .722 r
.39195 .47523 m .38581 .45895 L .37092 .47331 L closepath p F P
0 g
s
.695 .567 .707 r
.40702 .52288 m .4043 .51412 L .45386 .47275 L p F P
0 g
s
.721 .581 .698 r
.40702 .52288 m .4043 .51412 L .39664 .52235 L closepath p F P
0 g
s
.686 .54 .681 r
.40702 .52288 m .48971 .51705 L p .44515 .56405 L F P
0 g
s
.686 .54 .681 r
.44515 .56405 m .41766 .56597 L .40702 .52288 L p F P
0 g
s
.695 .567 .707 r
.47631 .4712 m .48971 .51705 L .40702 .52288 L p F P
0 g
s
.695 .567 .707 r
.45386 .47275 m .47631 .4712 L p .40702 .52288 L F P
0 g
s
.721 .561 .672 r
.39664 .52235 m .40702 .52288 L .41766 .56597 L p F P
0 g
s
.721 .561 .672 r
.41766 .56597 m .36579 .56335 L .39664 .52235 L p F P
0 g
s
.735 .582 .684 r
.33317 .51643 m .39664 .52235 L .36579 .56335 L p F P
0 g
s
.723 .585 .701 r
.37092 .47331 m .33317 .51643 L .39664 .52235 L p F P
0 g
s
.697 .591 .733 r
.38581 .45895 m .43457 .42145 L p .45386 .47275 L F P
0 g
s
.707 .601 .736 r
.38581 .45895 m .43457 .42145 L .37105 .42127 L closepath p F P
0 g
s
.732 .614 .726 r
.37092 .47331 m .38581 .45895 L .37105 .42127 L p F P
0 g
s
.745 .614 .712 r
.31422 .46489 m .37092 .47331 L .33317 .51643 L p F P
0 g
s
.732 .614 .726 r
.35872 .41951 m .31422 .46489 L .37092 .47331 L p F P
0 g
s
.732 .614 .726 r
.37105 .42127 m .35872 .41951 L p .37092 .47331 L F P
0 g
s
.69 .577 .724 r
.47631 .4712 m .47227 .4595 L .45386 .47275 L closepath p F P
0 g
s
.697 .591 .733 r
.45859 .4205 m .47227 .4595 L .45386 .47275 L p F P
0 g
s
.697 .591 .733 r
.43457 .42145 m .45859 .4205 L p .45386 .47275 L F P
0 g
s
.646 .531 .709 r
.47631 .4712 m .54987 .4541 L p .50529 .51345 L F P
0 g
s
.646 .531 .709 r
.50529 .51345 m .48971 .51705 L .47631 .4712 L p F P
0 g
s
.654 .557 .733 r
.54079 .42716 m .54987 .4541 L .47631 .4712 L p F P
0 g
s
.654 .557 .733 r
.47631 .4712 m .47227 .4595 L .54079 .42716 L p F P
0 g
s
.656 .561 .735 r
.53283 .40384 m .54079 .42716 L .47227 .4595 L p F P
0 g
s
.656 .561 .735 r
.47227 .4595 m .45859 .4205 L .53283 .40384 L p F P
0 g
s
.683 .514 .652 r
.42233 .59154 m .44515 .56405 L .41766 .56597 L closepath p F P
0 g
s
.712 .534 .647 r
.41766 .56597 m .36579 .56335 L p .41377 .60551 L F P
0 g
s
.712 .534 .647 r
.41377 .60551 m .42233 .59154 L .41766 .56597 L p F P
0 g
s
.698 .602 .746 r
.45859 .4205 m .45373 .40843 L .43457 .42145 L closepath p F P
0 g
s
.706 .619 .758 r
.43502 .36316 m .45373 .40843 L .43457 .42145 L p F P
0 g
s
.706 .619 .758 r
.36699 .41222 m .43502 .36316 L p .43457 .42145 L F P
0 g
s
.706 .619 .758 r
.43457 .42145 m .37105 .42127 L .36699 .41222 L p F P
0 g
s
.735 .633 .745 r
.37105 .42127 m .36699 .41222 L .35872 .41951 L closepath p F P
0 g
s
.639 .503 .681 r
.49072 .52138 m .50529 .51345 L .48971 .51705 L closepath p F P
0 g
s
.686 .54 .681 r
.48971 .51705 m .49072 .52138 L .44515 .56405 L p F P
0 g
s
.662 .584 .757 r
.52222 .37662 m .53283 .40384 L .45859 .4205 L p F P
0 g
s
.662 .584 .757 r
.45859 .4205 m .45373 .40843 L .52222 .37662 L p F P
0 g
s
.735 .582 .684 r
.31689 .53923 m .33317 .51643 L p .36579 .56335 L F P
0 g
s
.749 .595 .685 r
.31689 .53923 m .33317 .51643 L .30891 .5127 L closepath p F P
0 g
s
.745 .614 .712 r
.29822 .48414 m .31422 .46489 L p .33317 .51643 L F P
0 g
s
.745 .614 .712 r
.33317 .51643 m .30891 .5127 L .29822 .48414 L p F P
0 g
s
.638 .503 .681 r
.49954 .55911 m .49072 .52138 L .50529 .51345 L p F P
0 g
s
.679 .528 .674 r
.49954 .55911 m .49072 .52138 L .44515 .56405 L closepath p F P
0 g
s
.681 .513 .651 r
.44515 .56405 m .49954 .55911 L p .42489 .60572 L F P
0 g
s
.681 .513 .651 r
.42489 .60572 m .42233 .59154 L .44515 .56405 L p F P
0 g
s
.754 .645 .74 r
.30782 .40874 m .35872 .41951 L .31422 .46489 L p F P
0 g
s
.74 .642 .751 r
.34778 .3717 m .30782 .40874 L .35872 .41951 L p F P
0 g
s
.74 .642 .751 r
.35872 .41951 m .36699 .41222 L .34778 .3717 L p F P
0 g
s
.716 .622 .751 r
.43502 .36316 m .36699 .41222 L .34778 .3717 L p F P
0 g
s
.712 .534 .647 r
.36579 .56335 m .34354 .60183 L .41377 .60551 L p F P
0 g
s
.736 .56 .654 r
.32253 .55909 m .36579 .56335 L .34354 .60183 L p F P
0 g
s
.735 .582 .684 r
.36579 .56335 m .32253 .55909 L .31689 .53923 L p F P
0 g
s
.664 .584 .756 r
.52222 .37662 m .45373 .40843 L .43502 .36316 L p F P
0 g
s
.638 .503 .681 r
.50529 .51345 m .56303 .49981 L p .49954 .55911 L F P
0 g
s
.644 .527 .706 r
.56303 .49981 m .55943 .4873 L .50529 .51345 L closepath p F P
0 g
s
.646 .531 .709 r
.54987 .4541 m .55943 .4873 L .50529 .51345 L p F P
0 g
s
.76 .629 .715 r
.29822 .48414 m .31422 .46489 L .28807 .45897 L closepath p F P
0 g
s
.754 .645 .74 r
.2789 .43956 m .30782 .40874 L p .31422 .46489 L F P
0 g
s
.754 .645 .74 r
.31422 .46489 m .28807 .45897 L .2789 .43956 L p F P
0 g
s
.764 .603 .678 r
.30891 .5127 m .28188 .50624 L p .30634 .55611 L F P
0 g
s
.764 .603 .678 r
.30634 .55611 m .31689 .53923 L .30891 .5127 L p F P
0 g
s
.767 .624 .702 r
.30891 .5127 m .29822 .48414 L .28188 .50624 L closepath p F P
0 g
s
.711 .532 .646 r
.42489 .60572 m .42233 .59154 L .41377 .60551 L closepath p F P
0 g
s
.759 .595 .675 r
.32253 .55909 m .31689 .53923 L .30634 .55611 L closepath p F P
0 g
s
.627 .472 .652 r
.49954 .55911 m .57293 .5419 L p .55464 .58714 L F P
0 g
s
.627 .472 .652 r
.55464 .58714 m .5065 .59829 L .49954 .55911 L p F P
0 g
s
.681 .513 .651 r
.49954 .55911 m .5065 .59829 L .42489 .60572 L p F P
0 g
s
.638 .503 .681 r
.56303 .49981 m .57293 .5419 L .49954 .55911 L p F P
0 g
s
.736 .56 .654 r
.34354 .60183 m .3311 .60063 L .32253 .55909 L p F P
0 g
s
.762 .576 .646 r
.30634 .55611 m .32253 .55909 L .3311 .60063 L p F P
0 g
s
.774 .635 .707 r
.28188 .50624 m .29822 .48414 L .28807 .45897 L p F P
0 g
s
.668 .478 .618 r
.42489 .60572 m .5065 .59829 L p .50141 .63589 L F P
0 g
s
.668 .478 .618 r
.50141 .63589 m .42889 .64251 L .42489 .60572 L p F P
0 g
s
.708 .507 .614 r
.41377 .60551 m .42489 .60572 L .42889 .64251 L p F P
0 g
s
.708 .507 .614 r
.42889 .64251 m .39926 .64197 L .41377 .60551 L p F P
0 g
s
.722 .523 .621 r
.34354 .60183 m .41377 .60551 L .39926 .64197 L p F P
0 g
s
.664 .584 .756 r
.51049 .34715 m .52222 .37662 L p .43502 .36316 L F P
0 g
s
.664 .584 .756 r
.43502 .36316 m .43613 .36262 L .51049 .34715 L p F P
0 g
s
.67 .599 .767 r
.43502 .36316 m .43613 .36262 L .43489 .36285 L closepath p F P
0 g
s
.716 .622 .751 r
.43489 .36285 m .43502 .36316 L p .34778 .3717 L F P
0 g
s
.78 .596 .65 r
.25891 .54467 m .30634 .55611 L .28896 .593 L p F P
0 g
s
.764 .603 .678 r
.28188 .50624 m .25891 .54467 L .30634 .55611 L p F P
0 g
s
.762 .576 .646 r
.3311 .60063 m .28896 .593 L .30634 .55611 L p F P
0 g
s
.716 .622 .751 r
.34778 .3717 m .36447 .35899 L .43489 .36285 L p F P
0 g
s
.672 .619 .787 r
.43613 .36262 m .43489 .36285 L .41604 .32379 L p F P
0 g
s
.713 .637 .771 r
.43489 .36285 m .41604 .32379 L .36447 .35899 L closepath p F P
0 g
s
.667 .606 .777 r
.51049 .34715 m .50359 .33162 L .43613 .36262 L closepath p F P
0 g
s
.672 .619 .787 r
.48481 .29076 m .50359 .33162 L .43613 .36262 L p F P
0 g
s
.672 .619 .787 r
.41604 .32379 m .48481 .29076 L p .43613 .36262 L F P
0 g
s
.774 .635 .707 r
.28807 .45897 m .26774 .45269 L p .28188 .50624 L F P
0 g
s
.773 .652 .729 r
.28807 .45897 m .2789 .43956 L .26774 .45269 L closepath p F P
0 g
s
.792 .632 .683 r
.2392 .49282 m .28188 .50624 L .25891 .54467 L p F P
0 g
s
.774 .635 .707 r
.26774 .45269 m .2392 .49282 L .28188 .50624 L p F P
0 g
s
.729 .649 .769 r
.34778 .3717 m .36447 .35899 L .33942 .35534 L closepath p F P
0 g
s
.754 .658 .756 r
.30782 .40874 m .34778 .3717 L .33942 .35534 L p F P
0 g
s
.771 .657 .737 r
.30782 .40874 m .2789 .43956 L .25901 .40117 L p F P
0 g
s
.771 .657 .737 r
.25901 .40117 m .26462 .39493 L .30782 .40874 L p F P
0 g
s
.754 .658 .756 r
.31365 .34774 m .26462 .39493 L .30782 .40874 L p F P
0 g
s
.754 .658 .756 r
.33942 .35534 m .31365 .34774 L p .30782 .40874 L F P
0 g
s
.722 .523 .621 r
.33419 .62609 m .34354 .60183 L p .39926 .64197 L F P
0 g
s
.736 .535 .621 r
.33419 .62609 m .34354 .60183 L .3311 .60063 L closepath p F P
0 g
s
.724 .662 .788 r
.39938 .29118 m .41604 .32379 L .36447 .35899 L p F P
0 g
s
.724 .662 .788 r
.39126 .29011 m .39938 .29118 L p .36447 .35899 L F P
0 g
s
.724 .662 .788 r
.32818 .33538 m .39126 .29011 L p .36447 .35899 L F P
0 g
s
.724 .662 .788 r
.36447 .35899 m .33942 .35534 L .32818 .33538 L p F P
0 g
s
.754 .548 .617 r
.3311 .60063 m .28896 .593 L p .33032 .63779 L F P
0 g
s
.754 .548 .617 r
.33032 .63779 m .33419 .62609 L .3311 .60063 L p F P
0 g
s
.782 .667 .736 r
.26774 .45269 m .2789 .43956 L .25901 .40117 L p F P
0 g
s
.596 .499 .714 r
.54987 .4541 m .61512 .42499 L p .61479 .47789 L F P
0 g
s
.596 .499 .714 r
.61479 .47789 m .55943 .4873 L .54987 .4541 L p F P
0 g
s
.604 .526 .74 r
.61102 .41302 m .61512 .42499 L .54987 .4541 L p F P
0 g
s
.604 .526 .74 r
.54987 .4541 m .54079 .42716 L .61102 .41302 L p F P
0 g
s
.602 .527 .742 r
.59718 .37313 m .61102 .41302 L .54079 .42716 L p F P
0 g
s
.602 .527 .742 r
.54079 .42716 m .53283 .40384 L .59718 .37313 L p F P
0 g
s
.617 .438 .618 r
.50934 .62282 m .55464 .58714 L .5065 .59829 L closepath p F P
0 g
s
.668 .478 .618 r
.5065 .59829 m .50934 .62282 L .50141 .63589 L p F P
0 g
s
.801 .664 .713 r
.22932 .43733 m .26774 .45269 L .2392 .49282 L p F P
0 g
s
.782 .667 .736 r
.25901 .40117 m .22932 .43733 L .26774 .45269 L p F P
0 g
s
.612 .554 .765 r
.59233 .36075 m .59718 .37313 L .53283 .40384 L p F P
0 g
s
.612 .554 .765 r
.53283 .40384 m .52222 .37662 L .59233 .36075 L p F P
0 g
s
.752 .672 .773 r
.33942 .35534 m .32818 .33538 L .31365 .34774 L closepath p F P
0 g
s
.596 .498 .713 r
.56303 .49981 m .55943 .4873 L .61479 .47789 L closepath p F P
0 g
s
.583 .465 .685 r
.57293 .5419 m .56303 .49981 L .61479 .47789 L p F P
0 g
s
.609 .556 .77 r
.5737 .31432 m .59233 .36075 L .52222 .37662 L p F P
0 g
s
.609 .556 .77 r
.57254 .31457 m .5737 .31432 L p .52222 .37662 L F P
0 g
s
.609 .556 .77 r
.52222 .37662 m .51049 .34715 L .57254 .31457 L p F P
0 g
s
.68 .632 .795 r
.47931 .27945 m .48481 .29076 L .41604 .32379 L p F P
0 g
s
.68 .632 .795 r
.41604 .32379 m .39938 .29118 L .47931 .27945 L p F P
0 g
s
.661 .445 .58 r
.42889 .64251 m .50141 .63589 L .49286 .6712 L p F P
0 g
s
.661 .445 .58 r
.49286 .6712 m .42998 .67684 L .42889 .64251 L p F P
0 g
s
.704 .479 .579 r
.39926 .64197 m .42889 .64251 L .42998 .67684 L p F P
0 g
s
.722 .523 .621 r
.39926 .64197 m .33562 .63852 L .33419 .62609 L p F P
0 g
s
.75 .544 .616 r
.33562 .63852 m .33419 .62609 L .33032 .63779 L closepath p F P
0 g
s
.704 .479 .579 r
.42998 .67684 m .39344 .67617 L .39926 .64197 L p F P
0 g
s
.718 .492 .582 r
.33562 .63852 m .39926 .64197 L .39344 .67617 L p F P
0 g
s
.78 .596 .65 r
.28896 .593 m .24196 .58144 L .25891 .54467 L p F P
0 g
s
.798 .62 .66 r
.21683 .53112 m .25891 .54467 L .24196 .58144 L p F P
0 g
s
.792 .632 .683 r
.25891 .54467 m .21683 .53112 L .2392 .49282 L p F P
0 g
s
.754 .548 .617 r
.28896 .593 m .27768 .62831 L .33032 .63779 L p F P
0 g
s
.785 .577 .619 r
.24196 .58144 m .28896 .593 L .27768 .62831 L p F P
0 g
s
.775 .694 .774 r
.27552 .33152 m .31365 .34774 L .26462 .39493 L p F P
0 g
s
.761 .69 .784 r
.30811 .30291 m .27552 .33152 L .31365 .34774 L p F P
0 g
s
.761 .69 .784 r
.31365 .34774 m .32818 .33538 L .30811 .30291 L p F P
0 g
s
.573 .433 .653 r
.57293 .5419 m .63944 .51465 L p .6031 .57209 L F P
0 g
s
.573 .433 .653 r
.6031 .57209 m .57864 .57309 L .57293 .5419 L p F P
0 g
s
.583 .465 .685 r
.63004 .4762 m .63944 .51465 L .57293 .5419 L p F P
0 g
s
.583 .465 .685 r
.61479 .47789 m .63004 .4762 L p .57293 .5419 L F P
0 g
s
.627 .472 .652 r
.57293 .5419 m .57864 .57309 L .55464 .58714 L p F P
0 g
s
.619 .581 .789 r
.51049 .34715 m .50359 .33162 L .57254 .31457 L closepath p F P
0 g
s
.738 .674 .788 r
.39126 .29011 m .32818 .33538 L .30811 .30291 L p F P
0 g
s
.617 .439 .618 r
.51074 .6349 m .50934 .62282 L .55464 .58714 L p F P
0 g
s
.662 .471 .616 r
.51074 .6349 m .50934 .62282 L .50141 .63589 L closepath p F P
0 g
s
.809 .657 .694 r
.20151 .47731 m .2392 .49282 L .21683 .53112 L p F P
0 g
s
.801 .664 .713 r
.2392 .49282 m .20151 .47731 L .22932 .43733 L p F P
0 g
s
.718 .492 .582 r
.39344 .67617 m .33629 .67314 L .33562 .63852 L p F P
0 g
s
.749 .517 .58 r
.33032 .63779 m .33562 .63852 L .33629 .67314 L p F P
0 g
s
.787 .684 .751 r
.25901 .40117 m .26462 .39493 L .25208 .38935 L closepath p F P
0 g
s
.775 .694 .774 r
.23848 .36822 m .27552 .33152 L p .26462 .39493 L F P
0 g
s
.775 .694 .774 r
.26462 .39493 m .25208 .38935 L .23848 .36822 L p F P
0 g
s
.749 .517 .58 r
.33629 .67314 m .32524 .67164 L .33032 .63779 L p F P
0 g
s
.765 .531 .58 r
.27768 .62831 m .33032 .63779 L .32524 .67164 L p F P
0 g
s
.799 .687 .742 r
.22932 .43733 m .25901 .40117 L .25208 .38935 L p F P
0 g
s
.654 .438 .578 r
.50141 .63589 m .51074 .6349 L .51232 .66916 L p F P
0 g
s
.654 .438 .578 r
.51232 .66916 m .49286 .6712 L .50141 .63589 L p F P
0 g
s
.617 .439 .618 r
.55464 .58714 m .58013 .58115 L p .51074 .6349 L F P
0 g
s
.626 .47 .651 r
.58013 .58115 m .57864 .57309 L .55464 .58714 L closepath p F P
0 g
s
.621 .589 .796 r
.57254 .31457 m .50359 .33162 L .48481 .29076 L p F P
0 g
s
.602 .398 .577 r
.51232 .66916 m .51074 .6349 L .58469 .6178 L p F P
0 g
s
.617 .439 .618 r
.58013 .58115 m .58469 .6178 L .51074 .6349 L p F P
0 g
s
.799 .687 .742 r
.25208 .38935 m .22949 .37782 L p .22932 .43733 L F P
0 g
s
.791 .698 .762 r
.25208 .38935 m .23848 .36822 L .22949 .37782 L closepath p F P
0 g
s
.682 .648 .81 r
.4658 .2538 m .47931 .27945 L .39938 .29118 L p F P
0 g
s
.682 .648 .81 r
.39938 .29118 m .39678 .2865 L .4658 .2538 L p F P
0 g
s
.72 .663 .793 r
.39938 .29118 m .39678 .2865 L .39126 .29011 L closepath p F P
0 g
s
.818 .688 .721 r
.19572 .41983 m .22932 .43733 L .20151 .47731 L p F P
0 g
s
.799 .687 .742 r
.22949 .37782 m .19572 .41983 L .22932 .43733 L p F P
0 g
s
.573 .434 .654 r
.58013 .58115 m .57864 .57309 L .6031 .57209 L closepath p F P
0 g
s
.738 .674 .788 r
.30811 .30291 m .34184 .27776 L .39126 .29011 L p F P
0 g
s
.727 .68 .805 r
.37713 .25382 m .34184 .27776 L .39126 .29011 L p F P
0 g
s
.727 .68 .805 r
.39126 .29011 m .39678 .2865 L .37713 .25382 L p F P
0 g
s
.688 .661 .818 r
.4658 .2538 m .39678 .2865 L .37713 .25382 L p F P
0 g
s
.785 .577 .619 r
.27768 .62831 m .23071 .61674 L .24196 .58144 L p F P
0 g
s
.804 .598 .624 r
.21117 .57156 m .24196 .58144 L .23071 .61674 L p F P
0 g
s
.798 .62 .66 r
.20622 .55467 m .21683 .53112 L p .24196 .58144 L F P
0 g
s
.798 .62 .66 r
.24196 .58144 m .21117 .57156 L .20622 .55467 L p F P
0 g
s
.555 .393 .616 r
.58469 .6178 m .58013 .58115 L .6031 .57209 L p F P
0 g
s
.818 .639 .661 r
.20622 .55467 m .21683 .53112 L .19521 .52223 L closepath p F P
0 g
s
.809 .657 .694 r
.18674 .50318 m .20151 .47731 L p .21683 .53112 L F P
0 g
s
.809 .657 .694 r
.21683 .53112 m .19521 .52223 L .18674 .50318 L p F P
0 g
s
.765 .531 .58 r
.32524 .67164 m .27239 .66218 L .27768 .62831 L p F P
0 g
s
.787 .552 .581 r
.23071 .61674 m .27768 .62831 L .27239 .66218 L p F P
0 g
s
.65 .404 .534 r
.42998 .67684 m .49286 .6712 L .49934 .70255 L p F P
0 g
s
.65 .404 .534 r
.49934 .70255 m .42813 .70881 L .42998 .67684 L p F P
0 g
s
.698 .446 .538 r
.39344 .67617 m .42998 .67684 L .42813 .70881 L p F P
0 g
s
.698 .446 .538 r
.42813 .70881 m .39641 .70824 L .39344 .67617 L p F P
0 g
s
.713 .457 .536 r
.33629 .67314 m .39344 .67617 L .39641 .70824 L p F P
0 g
s
.621 .589 .796 r
.48481 .29076 m .55504 .27382 L p .57254 .31457 L F P
0 g
s
.615 .597 .809 r
.53873 .24023 m .55504 .27382 L .48481 .29076 L p F P
0 g
s
.615 .597 .809 r
.48481 .29076 m .47931 .27945 L .53873 .24023 L p F P
0 g
s
.793 .713 .777 r
.27552 .33152 m .23848 .36822 L .21729 .33948 L p F P
0 g
s
.793 .713 .777 r
.21729 .33948 m .24417 .31235 L .27552 .33152 L p F P
0 g
s
.776 .714 .794 r
.28753 .27349 m .24417 .31235 L .27552 .33152 L p F P
0 g
s
.776 .714 .794 r
.27552 .33152 m .30811 .30291 L .28753 .27349 L p F P
0 g
s
.583 .468 .688 r
.63004 .4762 m .61479 .47789 L .62896 .4718 L closepath p F P
0 g
s
.596 .499 .714 r
.61512 .42499 m .62896 .4718 L .61479 .47789 L p F P
0 g
s
.755 .705 .805 r
.34184 .27776 m .30811 .30291 L .28753 .27349 L p F P
0 g
s
.83 .676 .692 r
.20151 .47731 m .18674 .50318 L .1661 .4637 L p F P
0 g
s
.83 .676 .692 r
.1661 .4637 m .16828 .4598 L .20151 .47731 L p F P
0 g
s
.818 .688 .721 r
.20151 .47731 m .16828 .4598 L .19572 .41983 L p F P
0 g
s
.713 .457 .536 r
.39641 .70824 m .33338 .70496 L .33629 .67314 L p F P
0 g
s
.747 .487 .539 r
.32524 .67164 m .33629 .67314 L .33338 .70496 L p F P
0 g
s
.803 .72 .773 r
.22949 .37782 m .23848 .36822 L .21729 .33948 L p F P
0 g
s
.821 .718 .751 r
.20005 .35816 m .22949 .37782 L .19572 .41983 L p F P
0 g
s
.803 .72 .773 r
.21729 .33948 m .20005 .35816 L .22949 .37782 L p F P
0 g
s
.624 .618 .824 r
.53621 .2354 m .53873 .24023 L .47931 .27945 L p F P
0 g
s
.624 .618 .824 r
.47931 .27945 m .4658 .2538 L .53621 .2354 L p F P
0 g
s
.747 .487 .539 r
.33338 .70496 m .32658 .70405 L .32524 .67164 L p F P
0 g
s
.763 .501 .537 r
.27239 .66218 m .32524 .67164 L .32658 .70405 L p F P
0 g
s
.643 .4 .536 r
.49286 .6712 m .51232 .66916 L .51132 .70131 L p F P
0 g
s
.643 .4 .536 r
.51132 .70131 m .49934 .70255 L .49286 .6712 L p F P
0 g
s
.755 .705 .805 r
.28753 .27349 m .30444 .26055 L .34184 .27776 L p F P
0 g
s
.74 .704 .818 r
.35704 .22389 m .30444 .26055 L .34184 .27776 L p F P
0 g
s
.74 .704 .818 r
.34184 .27776 m .37713 .25382 L .35704 .22389 L p F P
0 g
s
.533 .463 .723 r
.62896 .4718 m .61512 .42499 L .63053 .41378 L p F P
0 g
s
.552 .499 .749 r
.61512 .42499 m .61102 .41302 L .63053 .41378 L closepath p F P
0 g
s
.811 .627 .653 r
.21117 .57156 m .20622 .55467 L .20063 .56768 L closepath p F P
0 g
s
.823 .642 .657 r
.20063 .56768 m .20622 .55467 L .19521 .52223 L p F P
0 g
s
.555 .393 .616 r
.6031 .57209 m .65069 .57937 L p .58469 .6178 L F P
0 g
s
.555 .394 .618 r
.65069 .57937 m .6031 .57209 L .6472 .55448 L closepath p F P
0 g
s
.573 .433 .653 r
.63944 .51465 m .6472 .55448 L .6031 .57209 L p F P
0 g
s
.552 .501 .752 r
.63053 .41378 m .61102 .41302 L .59718 .37313 L p F P
0 g
s
.804 .598 .624 r
.23071 .61674 m .21841 .61288 L .21117 .57156 L p F P
0 g
s
.818 .608 .618 r
.20063 .56768 m .21117 .57156 L .21841 .61288 L p F P
0 g
s
.823 .642 .657 r
.19521 .52223 m .18004 .51538 L p .20063 .56768 L F P
0 g
s
.819 .661 .686 r
.19521 .52223 m .18674 .50318 L .18004 .51538 L closepath p F P
0 g
s
.585 .352 .53 r
.51132 .70131 m .51232 .66916 L .58683 .65221 L p F P
0 g
s
.602 .398 .577 r
.58469 .6178 m .58683 .65221 L .51232 .66916 L p F P
0 g
s
.523 .429 .69 r
.62896 .4718 m .68722 .43089 L p .6793 .48916 L F P
0 g
s
.523 .429 .69 r
.6793 .48916 m .63004 .4762 L .62896 .4718 L p F P
0 g
s
.533 .463 .723 r
.68436 .42174 m .68722 .43089 L .62896 .4718 L p F P
0 g
s
.533 .463 .723 r
.63053 .41378 m .68436 .42174 L p .62896 .4718 L F P
0 g
s
.552 .501 .752 r
.59718 .37313 m .61255 .3604 L p .63053 .41378 L F P
0 g
s
.561 .529 .777 r
.59718 .37313 m .59233 .36075 L .61255 .3604 L closepath p F P
0 g
s
.523 .429 .69 r
.63944 .51465 m .63004 .4762 L .6793 .48916 L closepath p F P
0 g
s
.536 .348 .573 r
.58683 .65221 m .58469 .6178 L .65241 .59163 L p F P
0 g
s
.555 .393 .616 r
.65069 .57937 m .65241 .59163 L .58469 .6178 L p F P
0 g
s
.833 .68 .692 r
.18004 .51538 m .18674 .50318 L .1661 .4637 L p F P
0 g
s
.56 .533 .782 r
.61255 .3604 m .59233 .36075 L .5737 .31432 L p F P
0 g
s
.818 .608 .618 r
.21841 .61288 m .19031 .6027 L .20063 .56768 L p F P
0 g
s
.838 .629 .62 r
.1648 .55168 m .20063 .56768 L .19031 .6027 L p F P
0 g
s
.823 .642 .657 r
.18004 .51538 m .1648 .55168 L .20063 .56768 L p F P
0 g
s
.787 .552 .581 r
.27239 .66218 m .22512 .65069 L .23071 .61674 L p F P
0 g
s
.808 .573 .583 r
.21841 .61288 m .23071 .61674 L .22512 .65069 L p F P
0 g
s
.833 .715 .734 r
.16654 .40024 m .19572 .41983 L .16828 .4598 L p F P
0 g
s
.821 .718 .751 r
.19572 .41983 m .16654 .40024 L .20005 .35816 L p F P
0 g
s
.688 .661 .818 r
.37713 .25382 m .44649 .21975 L .4658 .2538 L p F P
0 g
s
.698 .686 .835 r
.44649 .21975 m .37713 .25382 L .35704 .22389 L p F P
0 g
s
.85 .67 .658 r
.14783 .49762 m .18004 .51538 L .1648 .55168 L p F P
0 g
s
.833 .68 .692 r
.1661 .4637 m .14783 .49762 L .18004 .51538 L p F P
0 g
s
.623 .638 .844 r
.53621 .2354 m .4658 .2538 L .44649 .21975 L p F P
0 g
s
.501 .387 .656 r
.6472 .55448 m .63944 .51465 L .6793 .48916 L p F P
0 g
s
.808 .573 .583 r
.22512 .65069 m .21955 .64898 L .21841 .61288 L p F P
0 g
s
.823 .585 .579 r
.19031 .6027 m .21841 .61288 L .21955 .64898 L p F P
0 g
s
.763 .501 .537 r
.32658 .70405 m .27318 .6947 L .27239 .66218 L p F P
0 g
s
.787 .521 .535 r
.22512 .65069 m .27239 .66218 L .27318 .6947 L p F P
0 g
s
.529 .472 .737 r
.68436 .42174 m .63053 .41378 L .67144 .38112 L closepath p F P
0 g
s
.552 .501 .752 r
.66523 .36404 m .67144 .38112 L .63053 .41378 L p F P
0 g
s
.552 .501 .752 r
.61255 .3604 m .66523 .36404 L p .63053 .41378 L F P
0 g
s
.611 .569 .782 r
.5737 .31432 m .57254 .31457 L .57357 .314 L closepath p F P
0 g
s
.621 .589 .796 r
.55504 .27382 m .57357 .314 L .57254 .31457 L p F P
0 g
s
.56 .533 .782 r
.5737 .31432 m .64643 .31493 L p .61255 .3604 L F P
0 g
s
.536 .528 .793 r
.62776 .2721 m .64643 .31493 L .5737 .31432 L p F P
0 g
s
.536 .528 .793 r
.60969 .27149 m .62776 .2721 L p .5737 .31432 L F P
0 g
s
.536 .528 .793 r
.5737 .31432 m .57357 .314 L .60969 .27149 L p F P
0 g
s
.558 .561 .813 r
.57357 .314 m .55504 .27382 L .60969 .27149 L closepath p F P
0 g
s
.635 .355 .477 r
.42318 .73848 m .42813 .70881 L .49934 .70255 L p F P
0 g
s
.689 .406 .488 r
.39641 .70824 m .42813 .70881 L .42318 .73848 L p F P
0 g
s
.689 .406 .488 r
.42318 .73848 m .40857 .73822 L .39641 .70824 L p F P
0 g
s
.703 .414 .483 r
.33338 .70496 m .39641 .70824 L .40857 .73822 L p F P
0 g
s
.809 .744 .791 r
.24417 .31235 m .21729 .33948 L .1954 .31431 L p F P
0 g
s
.809 .744 .791 r
.1954 .31431 m .21908 .29028 L .24417 .31235 L p F P
0 g
s
.792 .743 .807 r
.26634 .24763 m .21908 .29028 L .24417 .31235 L p F P
0 g
s
.792 .743 .807 r
.24417 .31235 m .28753 .27349 L .26634 .24763 L p F P
0 g
s
.77 .738 .824 r
.30444 .26055 m .28753 .27349 L .26634 .24763 L p F P
0 g
s
.849 .703 .701 r
.1661 .4637 m .16828 .4598 L .16 .4543 L closepath p F P
0 g
s
.833 .715 .734 r
.14437 .43282 m .16654 .40024 L p .16828 .4598 L F P
0 g
s
.833 .715 .734 r
.16828 .4598 m .16 .4543 L .14437 .43282 L p F P
0 g
s
.538 .509 .771 r
.66523 .36404 m .61255 .3604 L .65041 .32447 L closepath p F P
0 g
s
.56 .533 .782 r
.64643 .31493 m .65041 .32447 L .61255 .3604 L p F P
0 g
s
.818 .745 .783 r
.20005 .35816 m .21729 .33948 L .1954 .31431 L p F P
0 g
s
.853 .704 .697 r
.14783 .49762 m .1661 .4637 L .16 .4543 L p F P
0 g
s
.77 .738 .824 r
.26634 .24763 m .2778 .23876 L .30444 .26055 L p F P
0 g
s
.755 .736 .835 r
.33643 .19742 m .2778 .23876 L .30444 .26055 L p F P
0 g
s
.755 .736 .835 r
.30444 .26055 m .35704 .22389 L .33643 .19742 L p F P
0 g
s
.703 .414 .483 r
.33028 .71886 m .33338 .70496 L p .40857 .73822 L F P
0 g
s
.742 .452 .491 r
.33028 .71886 m .32658 .70405 L .33338 .70496 L closepath p F P
0 g
s
.837 .744 .762 r
.17525 .33623 m .20005 .35816 L .16654 .40024 L p F P
0 g
s
.818 .745 .783 r
.1954 .31431 m .17525 .33623 L .20005 .35816 L p F P
0 g
s
.758 .463 .485 r
.32658 .70405 m .33028 .71886 L .32644 .73378 L p F P
0 g
s
.758 .463 .485 r
.27318 .6947 m .32658 .70405 L p .32644 .73378 L F P
0 g
s
.488 .347 .615 r
.6472 .55448 m .70785 .51681 L p .65946 .58757 L F P
0 g
s
.488 .347 .615 r
.65946 .58757 m .65069 .57937 L .6472 .55448 L p F P
0 g
s
.501 .387 .656 r
.70473 .50213 m .70785 .51681 L .6472 .55448 L p F P
0 g
s
.501 .387 .656 r
.6793 .48916 m .70473 .50213 L p .6472 .55448 L F P
0 g
s
.629 .357 .486 r
.50962 .71567 m .49934 .70255 L .51132 .70131 L closepath p F P
0 g
s
.635 .355 .477 r
.49934 .70255 m .50962 .71567 L p .42318 .73848 L F P
0 g
s
.853 .704 .697 r
.16 .4543 m .13947 .44022 L p .14783 .49762 L F P
0 g
s
.84 .715 .726 r
.16 .4543 m .14437 .43282 L .13947 .44022 L closepath p F P
0 g
s
.823 .585 .579 r
.21955 .64898 m .18489 .63662 L .19031 .6027 L p F P
0 g
s
.845 .607 .578 r
.15441 .58678 m .19031 .6027 L .18489 .63662 L p F P
0 g
s
.838 .629 .62 r
.19031 .6027 m .15441 .58678 L .1648 .55168 L p F P
0 g
s
.511 .293 .52 r
.58652 .6845 m .58683 .65221 L .65514 .62632 L p F P
0 g
s
.536 .348 .573 r
.65241 .59163 m .65514 .62632 L .58683 .65221 L p F P
0 g
s
.585 .352 .53 r
.58683 .65221 m .58652 .6845 L .51132 .70131 L p F P
0 g
s
.563 .296 .47 r
.51132 .70131 m .58652 .6845 L .58365 .7147 L p F P
0 g
s
.563 .296 .47 r
.50962 .71567 m .51132 .70131 L p .58365 .7147 L F P
0 g
s
.86 .653 .622 r
.13256 .53401 m .1648 .55168 L .15441 .58678 L p F P
0 g
s
.85 .67 .658 r
.1648 .55168 m .13256 .53401 L .14783 .49762 L p F P
0 g
s
.787 .521 .535 r
.27318 .6947 m .22534 .68335 L .22512 .65069 L p F P
0 g
s
.809 .54 .531 r
.21955 .64898 m .22512 .65069 L .22534 .68335 L p F P
0 g
s
.698 .686 .835 r
.35704 .22389 m .42684 .18861 L .44649 .21975 L p F P
0 g
s
.708 .721 .86 r
.42684 .18861 m .35704 .22389 L .33643 .19742 L p F P
0 g
s
.556 .571 .824 r
.60969 .27149 m .55504 .27382 L .53873 .24023 L p F P
0 g
s
.623 .638 .844 r
.44649 .21975 m .51717 .20159 L .53621 .2354 L p F P
0 g
s
.621 .66 .866 r
.51717 .20159 m .44649 .21975 L .42684 .18861 L p F P
0 g
s
.809 .54 .531 r
.22534 .68335 m .21448 .68008 L .21955 .64898 L p F P
0 g
s
.826 .556 .532 r
.18489 .63662 m .21955 .64898 L .21448 .68008 L p F P
0 g
s
.853 .739 .737 r
.16654 .40024 m .14437 .43282 L .12166 .40777 L p F P
0 g
s
.853 .739 .737 r
.12166 .40777 m .14154 .37856 L .16654 .40024 L p F P
0 g
s
.837 .744 .762 r
.16654 .40024 m .14154 .37856 L .17525 .33623 L p F P
0 g
s
.87 .695 .663 r
.11911 .47812 m .14783 .49762 L .13256 .53401 L p F P
0 g
s
.853 .704 .697 r
.13947 .44022 m .11911 .47812 L .14783 .49762 L p F P
0 g
s
.487 .347 .616 r
.65241 .59163 m .65069 .57937 L .65946 .58757 L closepath p F P
0 g
s
.703 .414 .483 r
.40857 .73822 m .33608 .73463 L .33028 .71886 L p F P
0 g
s
.72 .422 .473 r
.33608 .73463 m .32644 .73378 L .33028 .71886 L closepath p F P
0 g
s
.781 .48 .478 r
.22534 .68335 m .27318 .6947 L .28033 .72588 L p F P
0 g
s
.758 .463 .485 r
.32644 .73378 m .28033 .72588 L .27318 .6947 L p F P
0 g
s
.563 .296 .47 r
.58365 .7147 m .5445 .72331 L .50962 .71567 L p F P
0 g
s
.563 .292 .464 r
.5445 .72331 m .50753 .73128 L .50962 .71567 L closepath p F P
0 g
s
.635 .355 .477 r
.50962 .71567 m .50753 .73128 L .42318 .73848 L p F P
0 g
s
.457 .29 .566 r
.65946 .58757 m .65241 .59163 L .65514 .62632 L p F P
0 g
s
.856 .74 .735 r
.13947 .44022 m .14437 .43282 L .12166 .40777 L p F P
0 g
s
.875 .733 .702 r
.11438 .41874 m .13947 .44022 L .11911 .47812 L p F P
0 g
s
.856 .74 .735 r
.12166 .40777 m .11438 .41874 L .13947 .44022 L p F P
0 g
s
.556 .571 .824 r
.53873 .24023 m .54195 .23491 L p .60969 .27149 L F P
0 g
s
.566 .593 .84 r
.53873 .24023 m .53621 .2354 L .54195 .23491 L closepath p F P
0 g
s
.494 .389 .664 r
.70473 .50213 m .6793 .48916 L .69905 .47567 L closepath p F P
0 g
s
.523 .429 .69 r
.68722 .43089 m .69905 .47567 L .6793 .48916 L p F P
0 g
s
.614 .296 .407 r
.42318 .73848 m .50753 .73128 L .50057 .75888 L p F P
0 g
s
.614 .296 .407 r
.41919 .75214 m .42318 .73848 L p .50057 .75888 L F P
0 g
s
.676 .359 .43 r
.41919 .75214 m .40857 .73822 L .42318 .73848 L closepath p F P
0 g
s
.688 .362 .419 r
.40857 .73822 m .41919 .75214 L .41462 .76551 L p F P
0 g
s
.688 .362 .419 r
.33608 .73463 m .40857 .73822 L p .41462 .76551 L F P
0 g
s
.564 .609 .857 r
.54195 .23491 m .53621 .2354 L .51717 .20159 L p F P
0 g
s
.457 .29 .566 r
.65514 .62632 m .66989 .61799 L .65946 .58757 L p F P
0 g
s
.446 .284 .567 r
.71379 .55471 m .65946 .58757 L .66989 .61799 L p F P
0 g
s
.488 .347 .615 r
.70785 .51681 m .71379 .55471 L .65946 .58757 L p F P
0 g
s
.845 .607 .578 r
.18489 .63662 m .14875 .62081 L .15441 .58678 L p F P
0 g
s
.869 .632 .577 r
.12201 .56923 m .15441 .58678 L .14875 .62081 L p F P
0 g
s
.86 .653 .622 r
.15441 .58678 m .12201 .56923 L .13256 .53401 L p F P
0 g
s
.826 .556 .532 r
.21448 .68008 m .18438 .6695 L .18489 .63662 L p F P
0 g
s
.849 .578 .527 r
.14875 .62081 m .18489 .63662 L .18438 .6695 L p F P
0 g
s
.556 .571 .824 r
.54195 .23491 m .60905 .23349 L p .60969 .27149 L F P
0 g
s
.531 .579 .848 r
.54195 .23491 m .60905 .23349 L .59022 .19877 L p F P
0 g
s
.531 .579 .848 r
.59022 .19877 m .55415 .19895 L .54195 .23491 L p F P
0 g
s
.564 .609 .857 r
.51717 .20159 m .55415 .19895 L .54195 .23491 L p F P
0 g
s
.688 .362 .419 r
.41462 .76551 m .35618 .7628 L .33608 .73463 L p F P
0 g
s
.704 .364 .398 r
.32644 .73378 m .33608 .73463 L .35618 .7628 L p F P
0 g
s
.476 .224 .451 r
.65544 .6588 m .58652 .6845 L .58365 .7147 L p F P
0 g
s
.511 .293 .52 r
.65514 .62632 m .65544 .6588 L .58652 .6845 L p F P
0 g
s
.883 .68 .623 r
.10369 .51467 m .13256 .53401 L .12201 .56923 L p F P
0 g
s
.87 .695 .663 r
.13256 .53401 m .10369 .51467 L .11911 .47812 L p F P
0 g
s
.704 .364 .398 r
.35618 .7628 m .31478 .75919 L .32644 .73378 L p F P
0 g
s
.749 .415 .419 r
.28033 .72588 m .32644 .73378 L .31478 .75919 L p F P
0 g
s
.781 .48 .478 r
.28033 .72588 m .23168 .71472 L .22534 .68335 L p F P
0 g
s
.806 .497 .466 r
.21448 .68008 m .22534 .68335 L .23168 .71472 L p F P
0 g
s
.621 .66 .866 r
.42684 .18861 m .49784 .17053 L .51717 .20159 L p F P
0 g
s
.621 .692 .895 r
.49784 .17053 m .42684 .18861 L .40673 .16131 L p F P
0 g
s
.708 .721 .86 r
.33643 .19742 m .40673 .16131 L .42684 .18861 L p F P
0 g
s
.472 .437 .738 r
.67144 .38112 m .68169 .36822 L p .69289 .4249 L F P
0 g
s
.472 .437 .738 r
.69289 .4249 m .68436 .42174 L .67144 .38112 L p F P
0 g
s
.485 .471 .767 r
.67144 .38112 m .66523 .36404 L .68169 .36822 L closepath p F P
0 g
s
.474 .435 .734 r
.68722 .43089 m .68436 .42174 L .69289 .4249 L closepath p F P
0 g
s
.44 .384 .699 r
.69289 .4249 m .68722 .43089 L .69905 .47567 L p F P
0 g
s
.531 .22 .385 r
.50057 .75888 m .50753 .73128 L .5445 .72331 L p F P
0 g
s
.482 .476 .774 r
.68169 .36822 m .66523 .36404 L .65041 .32447 L p F P
0 g
s
.806 .497 .466 r
.23168 .71472 m .20288 .7062 L .21448 .68008 L p F P
0 g
s
.825 .52 .473 r
.18438 .6695 m .21448 .68008 L .20288 .7062 L p F P
0 g
s
.891 .723 .667 r
.09376 .45687 m .11911 .47812 L .10369 .51467 L p F P
0 g
s
.875 .733 .702 r
.11911 .47812 m .09376 .45687 L .11438 .41874 L p F P
0 g
s
.614 .296 .407 r
.50057 .75888 m .43745 .76408 L .41919 .75214 L p F P
0 g
s
.62 .29 .389 r
.43745 .76408 m .41462 .76551 L .41919 .75214 L closepath p F P
0 g
s
.427 .344 .66 r
.69905 .47567 m .72785 .44605 L p .71449 .51084 L F P
0 g
s
.427 .344 .66 r
.71449 .51084 m .70473 .50213 L .69905 .47567 L p F P
0 g
s
.44 .384 .699 r
.69905 .47567 m .72785 .44605 L .69289 .4249 L p F P
0 g
s
.42 .223 .505 r
.66989 .61799 m .65514 .62632 L .65544 .6588 L p F P
0 g
s
.482 .476 .774 r
.65041 .32447 m .65549 .31639 L p .68169 .36822 L F P
0 g
s
.496 .508 .799 r
.65041 .32447 m .64643 .31493 L .65549 .31639 L closepath p F P
0 g
s
.424 .392 .72 r
.72426 .38609 m .69289 .4249 L .72785 .44605 L p F P
0 g
s
.472 .437 .738 r
.68169 .36822 m .72426 .38609 L .69289 .4249 L p F P
0 g
s
.749 .415 .419 r
.31478 .75919 m .2943 .75573 L .28033 .72588 L p F P
0 g
s
.77 .428 .406 r
.23168 .71472 m .28033 .72588 L .2943 .75573 L p F P
0 g
s
.492 .516 .81 r
.65549 .31639 m .64643 .31493 L .62776 .2721 L p F P
0 g
s
.53 .552 .822 r
.62776 .2721 m .60969 .27149 L .61972 .25475 L closepath p F P
0 g
s
.556 .571 .824 r
.60905 .23349 m .61972 .25475 L .60969 .27149 L p F P
0 g
s
.55 .627 .881 r
.55415 .19895 m .51717 .20159 L .49784 .17053 L p F P
0 g
s
.537 .236 .405 r
.58184 .72421 m .5445 .72331 L .58365 .7147 L closepath p F P
0 g
s
.531 .22 .385 r
.5445 .72331 m .58184 .72421 L p .50057 .75888 L F P
0 g
s
.429 .344 .659 r
.70785 .51681 m .70473 .50213 L .71449 .51084 L closepath p F P
0 g
s
.849 .578 .527 r
.18438 .6695 m .14789 .65382 L .14875 .62081 L p F P
0 g
s
.875 .602 .52 r
.1161 .60339 m .14875 .62081 L .14789 .65382 L p F P
0 g
s
.869 .632 .577 r
.14875 .62081 m .1161 .60339 L .12201 .56923 L p F P
0 g
s
.436 .439 .764 r
.70517 .33094 m .68169 .36822 L .72426 .38609 L p F P
0 g
s
.482 .476 .774 r
.65549 .31639 m .70517 .33094 L .68169 .36822 L p F P
0 g
s
.894 .658 .574 r
.09292 .55004 m .12201 .56923 L .1161 .60339 L p F P
0 g
s
.883 .68 .623 r
.12201 .56923 m .09292 .55004 L .10369 .51467 L p F P
0 g
s
.825 .52 .473 r
.20288 .7062 m .18899 .70139 L .18438 .6695 L p F P
0 g
s
.849 .539 .463 r
.14789 .65382 m .18438 .6695 L .18899 .70139 L p F P
0 g
s
.448 .485 .805 r
.6718 .28059 m .65549 .31639 L .70517 .33094 L p F P
0 g
s
.492 .516 .81 r
.62776 .2721 m .6718 .28059 L .65549 .31639 L p F P
0 g
s
.42 .223 .505 r
.65544 .6588 m .66451 .65376 L .66989 .61799 L p F P
0 g
s
.403 .209 .5 r
.71717 .58991 m .66989 .61799 L .66451 .65376 L p F P
0 g
s
.446 .284 .567 r
.66989 .61799 m .71717 .58991 L .71379 .55471 L p F P
0 g
s
.387 .28 .61 r
.71449 .51084 m .70785 .51681 L .71379 .55471 L p F P
0 g
s
.906 .708 .624 r
.07807 .49362 m .10369 .51467 L .09292 .55004 L p F P
0 g
s
.891 .723 .667 r
.10369 .51467 m .07807 .49362 L .09376 .45687 L p F P
0 g
s
.467 .516 .825 r
.6718 .28059 m .62776 .2721 L .61972 .25475 L p F P
0 g
s
.621 .692 .895 r
.40673 .16131 m .47815 .14293 L .49784 .17053 L p F P
0 g
s
.586 .208 .292 r
.40179 .78955 m .41462 .76551 L .43745 .76408 L p F P
0 g
s
.665 .295 .334 r
.35618 .7628 m .41462 .76551 L .40179 .78955 L p F P
0 g
s
.77 .428 .406 r
.2943 .75573 m .24462 .74479 L .23168 .71472 L p F P
0 g
s
.795 .438 .381 r
.20288 .7062 m .23168 .71472 L .24462 .74479 L p F P
0 g
s
.438 .15 .377 r
.58184 .72421 m .61912 .70167 L .58365 .7147 L closepath p F P
0 g
s
.476 .224 .451 r
.65444 .67327 m .65544 .6588 L p .58365 .7147 L F P
0 g
s
.476 .224 .451 r
.58365 .7147 m .61912 .70167 L .65444 .67327 L p F P
0 g
s
.585 .225 .324 r
.49024 .78409 m .43745 .76408 L .50057 .75888 L closepath p F P
0 g
s
.586 .208 .292 r
.43745 .76408 m .49024 .78409 L p .40179 .78955 L F P
0 g
s
.387 .28 .61 r
.71379 .55471 m .73164 .53902 L .71449 .51084 L p F P
0 g
s
.362 .273 .619 r
.75374 .47099 m .71449 .51084 L .73164 .53902 L p F P
0 g
s
.427 .344 .66 r
.72785 .44605 m .75374 .47099 L .71449 .51084 L p F P
0 g
s
.665 .295 .334 r
.40179 .78955 m .38657 .78885 L .35618 .7628 L p F P
0 g
s
.677 .288 .302 r
.31478 .75919 m .35618 .7628 L .38657 .78885 L p F P
0 g
s
.467 .516 .825 r
.61972 .25475 m .62487 .2352 L p .6718 .28059 L F P
0 g
s
.489 .549 .844 r
.61972 .25475 m .60905 .23349 L .62487 .2352 L closepath p F P
0 g
s
.374 .144 .432 r
.65444 .67327 m .66451 .65376 L .65544 .6588 L closepath p F P
0 g
s
.677 .288 .302 r
.30581 .7716 m .31478 .75919 L p .38657 .78885 L F P
0 g
s
.733 .359 .343 r
.30581 .7716 m .2943 .75573 L .31478 .75919 L closepath p F P
0 g
s
.477 .109 .261 r
.50057 .75888 m .57779 .74256 L .5686 .7679 L p F P
0 g
s
.477 .109 .261 r
.49024 .78409 m .50057 .75888 L p .5686 .7679 L F P
0 g
s
.531 .22 .385 r
.58184 .72421 m .57779 .74256 L .50057 .75888 L p F P
0 g
s
.55 .627 .881 r
.49784 .17053 m .55307 .167 L .55415 .19895 L p F P
0 g
s
.533 .653 .912 r
.55307 .167 m .49784 .17053 L .47815 .14293 L p F P
0 g
s
.418 .119 .349 r
.57779 .74256 m .58184 .72421 L .61912 .70167 L p F P
0 g
s
.339 .207 .55 r
.73164 .53902 m .71379 .55471 L .71717 .58991 L p F P
0 g
s
.512 .603 .88 r
.55415 .19895 m .59022 .19877 L .57117 .16707 L p F P
0 g
s
.512 .603 .88 r
.57117 .16707 m .55307 .167 L .55415 .19895 L p F P
0 g
s
.795 .438 .381 r
.1938 .7168 m .20288 .7062 L p .24462 .74479 L F P
0 g
s
.82 .476 .405 r
.1938 .7168 m .18899 .70139 L .20288 .7062 L closepath p F P
0 g
s
.875 .602 .52 r
.14789 .65382 m .11489 .63656 L .1161 .60339 L p F P
0 g
s
.902 .627 .512 r
.08673 .58436 m .1161 .60339 L .11489 .63656 L p F P
0 g
s
.894 .658 .574 r
.1161 .60339 m .08673 .58436 L .09292 .55004 L p F P
0 g
s
.75 .36 .314 r
.2943 .75573 m .30581 .7716 L .29719 .78042 L p F P
0 g
s
.75 .36 .314 r
.24462 .74479 m .2943 .75573 L p .29719 .78042 L F P
0 g
s
.849 .539 .463 r
.18899 .70139 m .15202 .68586 L .14789 .65382 L p F P
0 g
s
.876 .56 .449 r
.11489 .63656 m .14789 .65382 L .15202 .68586 L p F P
0 g
s
.346 .114 .413 r
.66451 .65376 m .71797 .62253 L p .65313 .68898 L F P
0 g
s
.346 .114 .413 r
.65313 .68898 m .65444 .67327 L .66451 .65376 L p F P
0 g
s
.403 .209 .5 r
.66451 .65376 m .71797 .62253 L .71717 .58991 L p F P
0 g
s
.48 .563 .863 r
.62487 .2352 m .60905 .23349 L .59022 .19877 L p F P
0 g
s
.919 .686 .57 r
.06703 .52919 m .09292 .55004 L .08673 .58436 L p F P
0 g
s
.906 .708 .624 r
.09292 .55004 m .06703 .52919 L .07807 .49362 L p F P
0 g
s
.418 .119 .349 r
.61912 .70167 m .65313 .68898 L p .57779 .74256 L F P
0 g
s
.47 .214 .443 r
.61912 .70167 m .65313 .68898 L .65444 .67327 L closepath p F P
0 g
s
.842 .487 .382 r
.18899 .70139 m .1938 .7168 L .18199 .72537 L p F P
0 g
s
.842 .487 .382 r
.15202 .68586 m .18899 .70139 L p .18199 .72537 L F P
0 g
s
.377 .326 .674 r
.74929 .41956 m .72785 .44605 L .75374 .47099 L p F P
0 g
s
.424 .392 .72 r
.74302 .39841 m .72426 .38609 L p .72785 .44605 L F P
0 g
s
.424 .392 .72 r
.72785 .44605 m .74929 .41956 L .74302 .39841 L p F P
0 g
s
.467 .516 .825 r
.62487 .2352 m .67925 .24699 L .6718 .28059 L p F P
0 g
s
.431 .536 .863 r
.62571 .20319 m .62487 .2352 L .67925 .24699 L p F P
0 g
s
.48 .563 .863 r
.59022 .19877 m .62571 .20319 L .62487 .2352 L p F P
0 g
s
.75 .36 .314 r
.29719 .78042 m .26478 .7735 L .24462 .74479 L p F P
0 g
s
.772 .367 .284 r
.20009 .73196 m .24462 .74479 L .26478 .7735 L p F P
0 g
s
.795 .438 .381 r
.24462 .74479 m .20009 .73196 L .1938 .7168 L p F P
0 g
s
.387 .376 .725 r
.74302 .39841 m .72426 .38609 L .73433 .37011 L closepath p F P
0 g
s
.436 .439 .764 r
.7234 .33941 m .70517 .33094 L p .72426 .38609 L F P
0 g
s
.436 .439 .764 r
.72426 .38609 m .73433 .37011 L .7234 .33941 L p F P
0 g
s
.339 .207 .55 r
.71717 .58991 m .73926 .57085 L .73164 .53902 L p F P
0 g
s
.3 .183 .548 r
.76733 .50319 m .73164 .53902 L .73926 .57085 L p F P
0 g
s
.362 .273 .619 r
.76496 .49016 m .75374 .47099 L p .73164 .53902 L F P
0 g
s
.362 .273 .619 r
.73164 .53902 m .76733 .50319 L .76496 .49016 L p F P
0 g
s
.278 .115 .473 r
.73926 .57085 m .71717 .58991 L .71797 .62253 L p F P
0 g
s
.69 .276 .256 r
.3189 .78325 m .29719 .78042 L .30581 .7716 L closepath p F P
0 g
s
.677 .288 .302 r
.38657 .78885 m .3189 .78325 L .30581 .7716 L p F P
0 g
s
.336 0 .2 r
.64788 .71668 m .57779 .74256 L .5686 .7679 L p F P
0 g
s
.418 .119 .349 r
.65313 .68898 m .64788 .71668 L .57779 .74256 L p F P
0 g
s
.821 .449 .351 r
.20009 .73196 m .18199 .72537 L .1938 .7168 L closepath p F P
0 g
s
.448 .485 .805 r
.70439 .29118 m .6718 .28059 L p .70517 .33094 L F P
0 g
s
.396 .463 .812 r
.6718 .28059 m .70439 .29118 L .68558 .24926 L p F P
0 g
s
.396 .463 .812 r
.68558 .24926 m .67925 .24699 L .6718 .28059 L p F P
0 g
s
.398 .427 .774 r
.7234 .33941 m .70517 .33094 L .71324 .31227 L closepath p F P
0 g
s
.448 .485 .805 r
.70517 .33094 m .71324 .31227 L .70439 .29118 L p F P
0 g
s
.451 .575 .887 r
.62571 .20319 m .59022 .19877 L .57117 .16707 L p F P
0 g
s
.269 0 .295 r
.71607 .6526 m .65313 .68898 L .64788 .71668 L p F P
0 g
s
.346 .114 .413 r
.71797 .62253 m .71607 .6526 L .65313 .68898 L p F P
0 g
s
.533 .653 .912 r
.47815 .14293 m .5396 .1389 L .55307 .167 L p F P
0 g
s
.876 .56 .449 r
.15202 .68586 m .11862 .66875 L .11489 .63656 L p F P
0 g
s
.903 .583 .43 r
.08522 .61768 m .11489 .63656 L .11862 .66875 L p F P
0 g
s
.902 .627 .512 r
.11489 .63656 m .08522 .61768 L .08673 .58436 L p F P
0 g
s
.928 .654 .499 r
.06057 .56368 m .08673 .58436 L .08522 .61768 L p F P
0 g
s
.919 .686 .57 r
.08673 .58436 m .06057 .56368 L .06703 .52919 L p F P
0 g
s
.536 .104 .168 r
.40179 .78955 m .49023 .7841 L .47494 .80569 L p F P
0 g
s
.536 .104 .168 r
.39733 .79542 m .40179 .78955 L p .47494 .80569 L F P
0 g
s
.586 .208 .292 r
.49024 .78409 m .49023 .7841 L .40179 .78955 L p F P
0 g
s
.636 .224 .246 r
.39733 .79542 m .38657 .78885 L .40179 .78955 L closepath p F P
0 g
s
.638 .2 .192 r
.38657 .78885 m .39733 .79542 L .38314 .80947 L p F P
0 g
s
.638 .2 .192 r
.3189 .78325 m .38657 .78885 L p .38314 .80947 L F P
0 g
s
.842 .487 .382 r
.18199 .72537 m .16149 .71693 L .15202 .68586 L p F P
0 g
s
.868 .503 .356 r
.11862 .66875 m .15202 .68586 L .16149 .71693 L p F P
0 g
s
.493 .632 .914 r
.55307 .167 m .57117 .16707 L .55186 .13894 L p F P
0 g
s
.493 .632 .914 r
.55186 .13894 m .5396 .1389 L .55307 .167 L p F P
0 g
s
.477 .109 .261 r
.5686 .7679 m .49036 .78408 L .49024 .78409 L p F P
0 g
s
.464 .079 .224 r
.49036 .78408 m .49023 .7841 L .49024 .78409 L closepath p F P
0 g
s
.398 0 .093 r
.47494 .80569 m .49023 .7841 L .49036 .78408 L p F P
0 g
s
.434 .03 .172 r
.5642 .77626 m .49036 .78408 L .5686 .7679 L closepath p F P
0 g
s
.398 0 .093 r
.49036 .78408 m .5642 .77626 L p .47494 .80569 L F P
0 g
s
.772 .367 .284 r
.26478 .7735 m .21919 .76091 L .20009 .73196 L p F P
0 g
s
.793 .364 .23 r
.18199 .72537 m .20009 .73196 L .21919 .76091 L p F P
0 g
s
.638 .2 .192 r
.38314 .80947 m .35826 .80749 L .3189 .78325 L p F P
0 g
s
.638 .167 .118 r
.29719 .78042 m .3189 .78325 L .35826 .80749 L p F P
0 g
s
.325 .337 .718 r
.73433 .37011 m .74223 .35078 L p .75532 .40871 L F P
0 g
s
.325 .337 .718 r
.75532 .40871 m .74302 .39841 L .73433 .37011 L p F P
0 g
s
.357 .389 .758 r
.73433 .37011 m .7234 .33941 L .74223 .35078 L closepath p F P
0 g
s
.339 .338 .712 r
.74929 .41956 m .74302 .39841 L .75532 .40871 L closepath p F P
0 g
s
.536 .104 .168 r
.47494 .80569 m .44737 .80733 L .39733 .79542 L p F P
0 g
s
.523 .061 .098 r
.44737 .80733 m .38314 .80947 L .39733 .79542 L closepath p F P
0 g
s
.273 .257 .659 r
.75532 .40871 m .74929 .41956 L .76 .46347 L p F P
0 g
s
.377 .326 .674 r
.75374 .47099 m .76 .46347 L .74929 .41956 L p F P
0 g
s
.638 .167 .118 r
.28186 .79063 m .29719 .78042 L p .35826 .80749 L F P
0 g
s
.72 .28 .207 r
.28186 .79063 m .26478 .7735 L .29719 .78042 L closepath p F P
0 g
s
.319 .247 .616 r
.76496 .49016 m .75374 .47099 L .76 .46347 L closepath p F P
0 g
s
.34 .391 .769 r
.74223 .35078 m .7234 .33941 L .71324 .31227 L p F P
0 g
s
.199 .001 .371 r
.73713 .60627 m .71797 .62253 L .71607 .6526 L p F P
0 g
s
.278 .115 .473 r
.71797 .62253 m .73713 .60627 L .73926 .57085 L p F P
0 g
s
.221 .071 .454 r
.77146 .53917 m .73926 .57085 L .73713 .60627 L p F P
0 g
s
.3 .183 .548 r
.73926 .57085 m .77146 .53917 L .76733 .50319 L p F P
0 g
s
.34 .391 .769 r
.71324 .31227 m .71712 .29667 L p .74223 .35078 L F P
0 g
s
.377 .443 .802 r
.71324 .31227 m .70439 .29118 L .71712 .29667 L closepath p F P
0 g
s
.793 .364 .23 r
.16794 .73025 m .18199 .72537 L p .21919 .76091 L F P
0 g
s
.827 .426 .288 r
.16794 .73025 m .16149 .71693 L .18199 .72537 L closepath p F P
0 g
s
.451 .575 .887 r
.57117 .16707 m .61829 .17337 L .62571 .20319 L p F P
0 g
s
.416 .592 .916 r
.61829 .17337 m .57117 .16707 L .55186 .13894 L p F P
0 g
s
.241 .193 .601 r
.76 .46347 m .77591 .4356 L p .76966 .4999 L F P
0 g
s
.241 .193 .601 r
.76966 .4999 m .76496 .49016 L .76 .46347 L p F P
0 g
s
.273 .257 .659 r
.76 .46347 m .77591 .4356 L .75532 .40871 L p F P
0 g
s
.73 .266 .149 r
.26478 .7735 m .28186 .79063 L .27023 .79487 L p F P
0 g
s
.73 .266 .149 r
.21919 .76091 m .26478 .7735 L p .27023 .79487 L F P
0 g
s
.358 .449 .817 r
.71712 .29667 m .70439 .29118 L .68558 .24926 L p F P
0 g
s
.903 .583 .43 r
.11862 .66875 m .0886 .65002 L .08522 .61768 L p F P
0 g
s
.93 .606 .405 r
.05878 .59716 m .08522 .61768 L .0886 .65002 L p F P
0 g
s
.928 .654 .499 r
.08522 .61768 m .05878 .59716 L .06057 .56368 L p F P
0 g
s
.431 .536 .863 r
.66685 .21285 m .62571 .20319 L p .67925 .24699 L F P
0 g
s
.379 .528 .88 r
.62571 .20319 m .66685 .21285 L .64804 .18067 L p F P
0 g
s
.379 .528 .88 r
.64804 .18067 m .61829 .17337 L .62571 .20319 L p F P
0 g
s
.868 .503 .356 r
.16149 .71693 m .12761 .69996 L .11862 .66875 L p F P
0 g
s
.893 .519 .323 r
.0886 .65002 m .11862 .66875 L .12761 .69996 L p F P
0 g
s
.201 .224 .661 r
.76909 .37494 m .75532 .40871 L .77591 .4356 L p F P
0 g
s
.325 .337 .718 r
.74223 .35078 m .76909 .37494 L .75532 .40871 L p F P
0 g
s
.845 .425 .234 r
.16149 .71693 m .16794 .73025 L .14232 .73015 L p F P
0 g
s
.845 .425 .234 r
.14232 .73015 m .12761 .69996 L .16149 .71693 L p F P
0 g
s
.177 0 .154 r
.63947 .74186 m .69449 .68993 L .64788 .71668 L closepath p F P
0 g
s
.269 0 .295 r
.71378 .66635 m .71607 .6526 L p .64788 .71668 L F P
0 g
s
.269 0 .295 r
.64788 .71668 m .69449 .68993 L .71378 .66635 L p F P
0 g
s
.336 0 .2 r
.63947 .74186 m .64788 .71668 L p .5686 .7679 L F P
0 g
s
.275 0 .094 r
.5642 .77626 m .63934 .74192 L .5686 .7679 L closepath p F P
0 g
s
.336 0 .2 r
.5686 .7679 m .63934 .74192 L .63947 .74186 L p F P
0 g
s
.255 .2 .601 r
.76733 .50319 m .76496 .49016 L .76966 .4999 L closepath p F P
0 g
s
.364 .477 .841 r
.68558 .24926 m .67925 .24699 L .67919 .23626 L closepath p F P
0 g
s
.431 .536 .863 r
.67925 .24699 m .67919 .23626 L .66685 .21285 L p F P
0 g
s
.217 .292 .726 r
.75006 .31798 m .74223 .35078 L .76909 .37494 L p F P
0 g
s
.34 .391 .769 r
.71712 .29667 m .75006 .31798 L .74223 .35078 L p F P
0 g
s
.242 .361 .785 r
.71937 .26488 m .71712 .29667 L .75006 .31798 L p F P
0 g
s
.358 .449 .817 r
.68558 .24926 m .71937 .26488 L .71712 .29667 L p F P
0 g
s
.171 .092 .518 r
.76966 .4999 m .76733 .50319 L .77146 .53917 L p F P
0 g
s
.305 .441 .834 r
.71937 .26488 m .68558 .24926 L .67919 .23626 L p F P
0 g
s
.199 .001 .371 r
.71607 .6526 m .72485 .64525 L .73713 .60627 L p F P
0 g
s
.126 0 .334 r
.77264 .57192 m .73713 .60627 L .72485 .64525 L p F P
0 g
s
.221 .071 .454 r
.73713 .60627 m .77264 .57192 L .77146 .53917 L p F P
0 g
s
.73 .266 .149 r
.27023 .79487 m .24612 .78842 L .21919 .76091 L p F P
0 g
s
.742 .256 .085 r
.17848 .74646 m .21919 .76091 L .24612 .78842 L p F P
0 g
s
.793 .364 .23 r
.21919 .76091 m .17848 .74646 L .16794 .73025 L p F P
0 g
s
.171 .092 .518 r
.77146 .53917 m .77633 .53241 L .76966 .4999 L p F P
0 g
s
.091 .039 .499 r
.78957 .46549 m .76966 .4999 L .77633 .53241 L p F P
0 g
s
.241 .193 .601 r
.77591 .4356 m .78957 .46549 L .76966 .4999 L p F P
0 g
s
.811 .359 .163 r
.17848 .74646 m .16794 .73025 L .14232 .73015 L p F P
0 g
s
.305 .441 .834 r
.67919 .23626 m .67696 .216 L p .71937 .26488 L F P
0 g
s
.366 .498 .859 r
.67919 .23626 m .66685 .21285 L .67696 .216 L closepath p F P
0 g
s
.638 .167 .118 r
.35826 .80749 m .29653 .79973 L .28186 .79063 L p F P
0 g
s
.634 .126 .022 r
.29653 .79973 m .27023 .79487 L .28186 .79063 L closepath p F P
0 g
s
.416 .592 .916 r
.55186 .13894 m .60298 .14569 L .61829 .17337 L p F P
0 g
s
.194 0 0 r
.55507 .78996 m .5642 .77626 L .63934 .74192 L p F P
0 g
s
.398 0 .093 r
.5642 .77626 m .55507 .78996 L .47494 .80569 L p F P
0 g
s
.434 0 0 r
.38314 .80947 m .44737 .80733 L p .45325 .82262 L F P
0 g
s
.434 0 0 r
.37507 .81511 m .38314 .80947 L p .45325 .82262 L F P
0 g
s
.588 .102 .069 r
.37507 .81511 m .35826 .80749 L .38314 .80947 L closepath p F P
0 g
s
.105 0 .245 r
.71378 .66635 m .72485 .64525 L .71607 .6526 L closepath p F P
0 g
s
.569 .046 0 r
.35826 .80749 m .37507 .81511 L .3559 .82319 L p F P
0 g
s
.569 .046 0 r
.29653 .79973 m .35826 .80749 L p .3559 .82319 L F P
0 g
s
.482 .008 .052 r
.46987 .81083 m .44737 .80733 L .47494 .80569 L closepath p F P
0 g
s
.434 0 0 r
.44737 .80733 m .46987 .81083 L .45325 .82262 L p F P
0 g
s
.893 .519 .323 r
.12761 .69996 m .09724 .68138 L .0886 .65002 L p F P
0 g
s
.915 .533 .278 r
.06191 .62964 m .0886 .65002 L .09724 .68138 L p F P
0 g
s
.93 .606 .405 r
.0886 .65002 m .06191 .62964 L .05878 .59716 L p F P
0 g
s
.315 0 0 r
.46987 .81083 m .47494 .80569 L .55507 .78996 L p F P
0 g
s
.862 .428 .181 r
.12761 .69996 m .14232 .73015 L .14227 .73013 L p F P
0 g
s
.862 .428 .181 r
.09724 .68138 m .12761 .69996 L p .14227 .73013 L F P
0 g
s
.094 .107 .581 r
.78922 .40215 m .77591 .4356 L .78957 .46549 L p F P
0 g
s
.201 .224 .661 r
.77591 .4356 m .78922 .40215 L .76909 .37494 L p F P
0 g
s
0 0 .169 r
.72485 .64525 m .76562 .60665 L p .711 .67976 L F P
0 g
s
0 0 .169 r
.711 .67976 m .71378 .66635 L .72485 .64525 L p F P
0 g
s
.126 0 .334 r
.77181 .58606 m .77264 .57192 L p .72485 .64525 L F P
0 g
s
.126 0 .334 r
.72485 .64525 m .76562 .60665 L .77181 .58606 L p F P
0 g
s
.334 .544 .908 r
.61829 .17337 m .64804 .18067 L .62905 .15206 L p F P
0 g
s
.334 .544 .908 r
.62905 .15206 m .60298 .14569 L .61829 .17337 L p F P
0 g
s
.069 0 .411 r
.77633 .53241 m .77146 .53917 L .77264 .57192 L p F P
0 g
s
.336 .51 .881 r
.67696 .216 m .66685 .21285 L .64804 .18067 L p F P
0 g
s
.569 .046 0 r
.3559 .82319 m .34598 .82199 L .29653 .79973 L p F P
0 g
s
.542 0 0 r
.27023 .79487 m .29653 .79973 L .34598 .82199 L p F P
0 g
s
.742 .256 .085 r
.24612 .78842 m .20445 .77418 L .17848 .74646 L p F P
0 g
s
.747 .238 0 r
.14234 .73017 m .17848 .74646 L .20445 .77418 L p F P
0 g
s
.811 .359 .163 r
.14232 .73015 m .14234 .73017 L .17848 .74646 L p F P
0 g
s
.214 0 .247 r
.69449 .68993 m .711 .67976 L .71378 .66635 L closepath p F P
0 g
s
.382 0 0 r
.43167 .82333 m .3559 .82319 L .37507 .81511 L closepath p F P
0 g
s
.434 0 0 r
.45325 .82262 m .43167 .82333 L .37507 .81511 L p F P
0 g
s
.315 0 0 r
.55507 .78996 m .54516 .80053 L .46987 .81083 L p F P
0 g
s
.224 0 0 r
.45325 .82262 m .46987 .81083 L .54516 .80053 L p F P
0 g
s
.131 .205 .674 r
.77627 .34246 m .76909 .37494 L .78922 .40215 L p F P
0 g
s
.217 .292 .726 r
.76909 .37494 m .77627 .34246 L .75006 .31798 L p F P
0 g
s
.069 0 .411 r
.77264 .57192 m .77564 .56783 L .77633 .53241 L p F P
0 g
s
0 0 .372 r
.79628 .49829 m .77633 .53241 L .77564 .56783 L p F P
0 g
s
.091 .039 .499 r
.77633 .53241 m .79628 .49829 L .78957 .46549 L p F P
0 g
s
.077 0 .052 r
.69449 .68993 m .711 .67976 L p .63946 .74188 L F P
0 g
s
.077 0 .052 r
.63946 .74188 m .63947 .74186 L .69449 .68993 L p F P
0 g
s
.305 .441 .834 r
.67696 .216 m .71532 .23447 L .71937 .26488 L p F P
0 g
s
.212 .426 .853 r
.66736 .18683 m .67696 .216 L .71532 .23447 L p F P
0 g
s
.336 .51 .881 r
.64804 .18067 m .66736 .18683 L .67696 .216 L p F P
0 g
s
.542 0 0 r
.25769 .79741 m .27023 .79487 L p .34598 .82199 L F P
0 g
s
.676 .163 .012 r
.25769 .79741 m .24612 .78842 L .27023 .79487 L closepath p F P
0 g
s
.194 0 0 r
.63934 .74192 m .63946 .74188 L p .55507 .78996 L F P
0 g
s
.301 0 .149 r
.63934 .74192 m .63946 .74188 L .63947 .74186 L closepath p F P
0 g
s
0 0 0 r
.70222 .70361 m .63946 .74188 L .62642 .76324 L p F P
0 g
s
.077 0 .052 r
.711 .67976 m .70222 .70361 L .63946 .74188 L p F P
0 g
s
.194 0 0 r
.63946 .74188 m .62642 .76324 L .55507 .78996 L p F P
0 g
s
.158 .287 .746 r
.75151 .2865 m .75006 .31798 L .77627 .34246 L p F P
0 g
s
.242 .361 .785 r
.75006 .31798 m .75151 .2865 L .71937 .26488 L p F P
0 g
s
.165 .344 .797 r
.71532 .23447 m .71937 .26488 L .75151 .2865 L p F P
0 g
s
.085 0 0 r
.54516 .80053 m .55507 .78996 L .62642 .76324 L p F P
0 g
s
.656 .111 0 r
.24612 .78842 m .25769 .79741 L .2332 .79626 L p F P
0 g
s
.656 .111 0 r
.2332 .79626 m .20445 .77418 L .24612 .78842 L p F P
0 g
s
.915 .533 .278 r
.09724 .68138 m .0703 .66111 L .06191 .62964 L p F P
0 g
s
.862 .428 .181 r
.14227 .73013 m .11159 .71171 L .09724 .68138 L p F P
0 g
s
.869 .426 .109 r
.0703 .66111 m .09724 .68138 L .11159 .71171 L p F P
0 g
s
0 0 0 r
.74366 .64947 m .711 .67976 L .70222 .70361 L p F P
0 g
s
0 0 .169 r
.76562 .60665 m .74366 .64947 L .711 .67976 L p F P
0 g
s
.281 .514 .901 r
.66736 .18683 m .64804 .18067 L .62905 .15206 L p F P
0 g
s
0 0 .273 r
.77181 .58606 m .77564 .56783 L .77264 .57192 L closepath p F P
0 g
s
0 0 .464 r
.80274 .4323 m .78957 .46549 L .79628 .49829 L p F P
0 g
s
.094 .107 .581 r
.78957 .46549 m .80274 .4323 L .78922 .40215 L p F P
0 g
s
.815 .339 .067 r
.14234 .73017 m .14227 .73013 L .14232 .73015 L closepath p F P
0 g
s
.747 .238 0 r
.20445 .77418 m .16759 .75805 L .14234 .73017 L p F P
0 g
s
.725 .194 0 r
.14227 .73013 m .14234 .73017 L .16759 .75805 L p F P
0 g
s
.725 .194 0 r
.11687 .7197 m .14227 .73013 L p .16759 .75805 L F P
0 g
s
.811 .327 .034 r
.11687 .7197 m .11159 .71171 L .14227 .73013 L closepath p F P
0 g
s
0 0 .193 r
.77564 .56783 m .79585 .53397 L p .77053 .60119 L F P
0 g
s
0 0 .193 r
.77053 .60119 m .77181 .58606 L .77564 .56783 L p F P
0 g
s
0 0 .372 r
.77564 .56783 m .79585 .53397 L .79628 .49829 L p F P
0 g
s
.542 0 0 r
.34598 .82199 m .28982 .81211 L .25769 .79741 L p F P
0 g
s
.489 0 0 r
.28982 .81211 m .25769 .79741 L .2332 .79626 L p F P
0 g
s
0 .053 .568 r
.79443 .37857 m .78922 .40215 L .80274 .4323 L p F P
0 g
s
.131 .205 .674 r
.78881 .36012 m .77627 .34246 L p .78922 .40215 L F P
0 g
s
.131 .205 .674 r
.78922 .40215 m .79443 .37857 L .78881 .36012 L p F P
0 g
s
.627 .062 0 r
.20445 .77418 m .2332 .79626 L .2219 .79308 L p F P
0 g
s
.627 .062 0 r
.16759 .75805 m .20445 .77418 L p .2219 .79308 L F P
0 g
s
.017 0 .272 r
.76562 .60665 m .77053 .60119 L .77181 .58606 L closepath p F P
0 g
s
.212 .426 .853 r
.71532 .23447 m .70527 .20537 L .66736 .18683 L p F P
0 g
s
.141 .421 .864 r
.65148 .15917 m .66736 .18683 L .70527 .20537 L p F P
0 g
s
.281 .514 .901 r
.62905 .15206 m .65148 .15917 L .66736 .18683 L p F P
0 g
s
.085 0 0 r
.62642 .76324 m .62201 .76829 L .54516 .80053 L p F P
0 g
s
0 0 0 r
.53568 .80752 m .54516 .80053 L .62201 .76829 L p F P
0 g
s
.224 0 0 r
.54516 .80053 m .53568 .80752 L .45325 .82262 L p F P
0 g
s
.357 0 0 r
.44873 .82493 m .43167 .82333 L .45325 .82262 L closepath p F P
0 g
s
.286 0 0 r
.43167 .82333 m .44873 .82493 L p .3523 .82419 L F P
0 g
s
.286 0 0 r
.3523 .82419 m .3559 .82319 L .43167 .82333 L p F P
0 g
s
.491 0 0 r
.3523 .82419 m .34598 .82199 L .3559 .82319 L closepath p F P
0 g
s
.007 .141 .655 r
.78881 .36012 m .77627 .34246 L .77701 .32448 L closepath p F P
0 g
s
.158 .287 .746 r
.76872 .30326 m .75151 .2865 L p .77627 .34246 L F P
0 g
s
.158 .287 .746 r
.77627 .34246 m .77701 .32448 L .76872 .30326 L p F P
0 g
s
.117 0 0 r
.44873 .82493 m .45325 .82262 L .53568 .80752 L p F P
0 g
s
.165 .344 .797 r
.75151 .2865 m .74695 .25626 L .71532 .23447 L p F P
0 g
s
.104 .346 .815 r
.70527 .20537 m .71532 .23447 L .74695 .25626 L p F P
0 g
s
.426 0 0 r
.34598 .82199 m .3523 .82419 L .32902 .82554 L p F P
0 g
s
.426 0 0 r
.32902 .82554 m .28982 .81211 L .34598 .82199 L p F P
0 g
s
.869 .426 .109 r
.11159 .71171 m .08442 .69153 L .0703 .66111 L p F P
0 g
s
.015 .212 .722 r
.75151 .2865 m .76872 .30326 L .74946 .25881 L p F P
0 g
s
.015 .212 .722 r
.74946 .25881 m .74695 .25626 L .75151 .2865 L p F P
0 g
s
0 0 .067 r
.77053 .60119 m .76562 .60665 L .74366 .64947 L p F P
0 g
s
0 0 .299 r
.80957 .46533 m .79628 .49829 L .79585 .53397 L p F P
0 g
s
0 0 .464 r
.79628 .49829 m .80957 .46533 L .80274 .4323 L p F P
0 g
s
.795 .302 0 r
.11159 .71171 m .11687 .7197 L .09141 .70217 L p F P
0 g
s
.795 .302 0 r
.09141 .70217 m .08442 .69153 L .11159 .71171 L p F P
0 g
s
.286 0 0 r
.44873 .82493 m .42692 .83068 L .3523 .82419 L p F P
0 g
s
.127 0 0 r
.3523 .82419 m .42692 .83068 L .42019 .83084 L p F P
0 g
s
.127 0 0 r
.32902 .82554 m .3523 .82419 L p .42019 .83084 L F P
0 g
s
0 0 0 r
.62201 .76829 m .64553 .75161 L .62642 .76324 L closepath p F P
0 g
s
0 0 0 r
.69898 .70934 m .70222 .70361 L p .62642 .76324 L F P
0 g
s
0 0 0 r
.62642 .76324 m .64553 .75161 L .69898 .70934 L p F P
0 g
s
0 0 0 r
.44873 .82493 m .52518 .81305 L .50683 .8176 L p F P
0 g
s
0 0 0 r
.42692 .83068 m .44873 .82493 L p .50683 .8176 L F P
0 g
s
.117 0 0 r
.53568 .80752 m .52518 .81305 L .44873 .82493 L p F P
0 g
s
0 0 0 r
.78796 .57254 m .77053 .60119 L .76454 .62651 L p F P
0 g
s
0 0 .193 r
.79585 .53397 m .78796 .57254 L .77053 .60119 L p F P
0 g
s
0 0 .067 r
.74366 .64947 m .76454 .62651 L .77053 .60119 L p F P
0 g
s
.725 .194 0 r
.16759 .75805 m .13533 .74001 L .11687 .7197 L p F P
0 g
s
.676 .142 0 r
.13533 .74001 m .11687 .7197 L .09141 .70217 L p F P
0 g
s
.341 0 0 r
.28982 .81211 m .32902 .82554 L .30955 .82223 L p F P
0 g
s
.341 0 0 r
.24105 .79979 m .24446 .80065 L p .25843 .80548 L F P
0 g
s
.489 0 0 r
.2332 .79626 m .24105 .79979 L .28982 .81211 L p F P
0 g
s
.385 0 0 r
.24105 .79979 m .2219 .79308 L .2332 .79626 L closepath p F P
0 g
s
.341 0 0 r
.30955 .82223 m .3005 .82002 L .24105 .79979 L p F P
0 g
s
.231 0 0 r
.2219 .79308 m .24105 .79979 L .3005 .82002 L p F P
0 g
s
.231 0 0 r
.20838 .78865 m .2219 .79308 L p .29744 .81898 L F P
0 g
s
.231 0 0 r
.3005 .82002 m .29869 .81941 L .29744 .81898 L F
.29869 .81941 m .20838 .78865 L .29744 .81898 L F
.341 0 0 r
.30955 .82223 m .25843 .80548 L .28982 .81211 L F
.24446 .80065 m .28982 .81211 L p .25843 .80548 L F P
0 g
s
.627 .062 0 r
.2219 .79308 m .20146 .78437 L .16759 .75805 L p F P
0 g
s
.573 .004 0 r
.13533 .74001 m .16759 .75805 L .20146 .78437 L p F P
0 g
s
0 0 0 r
.69898 .70934 m .7106 .69589 L .70222 .70361 L closepath p F P
0 g
s
0 0 0 r
.70222 .70361 m .7106 .69589 L .74366 .64947 L p F P
0 g
s
0 0 0 r
.76454 .62651 m .74366 .64947 L .7106 .69589 L p F P
0 g
s
.027 .134 .641 r
.79443 .37857 m .78881 .36012 L .79544 .37014 L closepath p F P
0 g
s
0 .103 .634 r
.79544 .37014 m .78881 .36012 L .77701 .32448 L p F P
0 g
s
0 0 .517 r
.79544 .37014 m .79443 .37857 L .8049 .42303 L p F P
0 g
s
0 .053 .568 r
.80274 .4323 m .8049 .42303 L .79443 .37857 L p F P
0 g
s
0 0 .416 r
.8049 .42303 m .80274 .4323 L .80957 .46533 L p F P
0 g
s
0 .103 .634 r
.77701 .32448 m .77658 .31144 L p .79544 .37014 L F P
0 g
s
.071 .227 .72 r
.77701 .32448 m .76872 .30326 L .77658 .31144 L closepath p F P
0 g
s
0 0 0 r
.60738 .7797 m .62201 .76829 L .64553 .75161 L p F P
0 g
s
0 0 0 r
.62201 .76829 m .60738 .7797 L .53568 .80752 L p F P
0 g
s
0 0 0 r
.52518 .81305 m .53568 .80752 L .60738 .7797 L p F P
0 g
s
.141 .421 .864 r
.70527 .20537 m .68935 .17762 L .65148 .15917 L p F P
0 g
s
0 .203 .718 r
.77658 .31144 m .76872 .30326 L .74946 .25881 L p F P
0 g
s
0 0 0 r
.64553 .75161 m .68833 .72287 L p .60738 .7797 L F P
0 g
s
0 0 0 r
.64553 .75161 m .68833 .72287 L .69898 .70934 L closepath p F P
0 g
s
0 0 .083 r
.80943 .50124 m .79585 .53397 L .78796 .57254 L p F P
0 g
s
0 0 .299 r
.79585 .53397 m .80943 .50124 L .80957 .46533 L p F P
0 g
s
0 0 0 r
.7106 .69589 m .74438 .65947 L p .68833 .72287 L F P
0 g
s
0 0 0 r
.68833 .72287 m .69898 .70934 L .7106 .69589 L p F P
0 g
s
0 0 0 r
.75916 .63857 m .76454 .62651 L p .7106 .69589 L F P
0 g
s
0 0 0 r
.7106 .69589 m .74438 .65947 L .75916 .63857 L p F P
0 g
s
0 0 .517 r
.8049 .42303 m .80765 .4009 L .79544 .37014 L p F P
0 g
s
0 0 .456 r
.79442 .33968 m .79544 .37014 L .80765 .4009 L p F P
0 g
s
0 .103 .634 r
.77658 .31144 m .79442 .33968 L .79544 .37014 L p F P
0 g
s
0 0 .346 r
.80765 .4009 m .8049 .42303 L .81057 .4612 L p F P
0 g
s
0 0 .416 r
.80957 .46533 m .81057 .4612 L .8049 .42303 L p F P
0 g
s
.104 .346 .815 r
.7306 .22317 m .70527 .20537 L p .74695 .25626 L F P
0 g
s
0 .294 .792 r
.70527 .20537 m .7306 .22317 L .71182 .19344 L p F P
0 g
s
0 .294 .792 r
.71182 .19344 m .68935 .17762 L .70527 .20537 L p F P
0 g
s
0 0 .565 r
.77063 .28172 m .77658 .31144 L .79442 .33968 L p F P
0 g
s
0 .203 .718 r
.74946 .25881 m .77063 .28172 L .77658 .31144 L p F P
0 g
s
0 .172 .708 r
.74946 .25881 m .74695 .25626 L .74407 .24804 L closepath p F P
0 g
s
.104 .346 .815 r
.74695 .25626 m .74407 .24804 L .7306 .22317 L p F P
0 g
s
0 .138 .684 r
.77063 .28172 m .74946 .25881 L .74407 .24804 L p F P
0 g
s
.573 .004 0 r
.20146 .78437 m .16872 .76641 L .13533 .74001 L p F P
0 g
s
.482 0 0 r
.10759 .72 m .13533 .74001 L .16872 .76641 L p F P
0 g
s
.676 .142 0 r
.09141 .70217 m .10759 .72 L .13533 .74001 L p F P
0 g
s
.509 0 0 r
.20838 .78865 m .20146 .78437 L .2219 .79308 L closepath p F P
0 g
s
0 .138 .684 r
.74407 .24804 m .73624 .22736 L p .77063 .28172 L F P
0 g
s
.035 .298 .789 r
.74407 .24804 m .7306 .22317 L .73624 .22736 L closepath p F P
0 g
s
0 0 .197 r
.81057 .4612 m .80957 .46533 L .80943 .50124 L p F P
0 g
s
0 0 0 r
.60738 .7797 m .60337 .78189 L .52518 .81305 L p F P
0 g
s
.364 .83 .769 r
.50683 .8176 m .52518 .81305 L .60337 .78189 L p F P
0 g
s
0 0 0 r
.76454 .62651 m .77218 .61401 L .78796 .57254 L p F P
0 g
s
0 0 0 r
.80196 .54004 m .78796 .57254 L .77218 .61401 L p F P
0 g
s
0 0 .083 r
.78796 .57254 m .80196 .54004 L .80943 .50124 L p F P
0 g
s
0 0 0 r
.75916 .63857 m .77218 .61401 L .76454 .62651 L closepath p F P
0 g
s
.127 0 0 r
.42019 .83084 m .36451 .8283 L .32902 .82554 L p F P
0 g
s
.011 .579 .782 r
.36451 .8283 m .30955 .82223 L .32902 .82554 L closepath p F P
0 g
s
0 0 .121 r
.81398 .43431 m .81057 .4612 L .81139 .49332 L p F P
0 g
s
0 0 .346 r
.81057 .4612 m .81398 .43431 L .80765 .4009 L p F P
0 g
s
0 0 .197 r
.80943 .50124 m .81139 .49332 L .81057 .4612 L p F P
0 g
s
0 0 0 r
.50683 .8176 m .47988 .82209 L .42692 .83068 L p F P
0 g
s
.213 .738 .811 r
.47988 .82209 m .42019 .83084 L .42692 .83068 L closepath p F P
0 g
s
.417 0 0 r
.20146 .78437 m .20838 .78865 L .18327 .77535 L p F P
0 g
s
.417 0 0 r
.18327 .77535 m .16872 .76641 L .20146 .78437 L p F P
0 g
s
0 0 .238 r
.80646 .37064 m .80765 .4009 L .81398 .43431 L p F P
0 g
s
0 0 .456 r
.80765 .4009 m .80646 .37064 L .79442 .33968 L p F P
0 g
s
0 .273 .778 r
.73624 .22736 m .7306 .22317 L .71182 .19344 L p F P
0 g
s
0 0 0 r
.6821 .72816 m .62128 .77035 L .60738 .7797 L p F P
0 g
s
0 0 0 r
.68833 .72287 m .6821 .72816 L p .60738 .7797 L F P
0 g
s
.441 .845 .656 r
.60337 .78189 m .62128 .77035 L .60738 .7797 L closepath p F P
0 g
s
.231 0 0 r
.3005 .82002 m .25744 .80541 L .20838 .78865 L p F P
0 g
s
0 .435 .797 r
.25744 .80541 m .20838 .78865 L .18327 .77535 L p F P
0 g
s
0 0 0 r
.77218 .61401 m .78668 .58176 L .80196 .54004 L p F P
0 g
s
0 0 0 r
.74438 .65947 m .75367 .64694 L .75916 .63857 L closepath p F P
0 g
s
.727 .854 .423 r
.77218 .61401 m .78668 .58176 L p .75367 .64694 L F P
0 g
s
.727 .854 .423 r
.75367 .64694 m .75916 .63857 L .77218 .61401 L p F P
0 g
s
0 0 .361 r
.78824 .31012 m .79442 .33968 L .80646 .37064 L p F P
0 g
s
0 0 .565 r
.79442 .33968 m .78824 .31012 L .77063 .28172 L p F P
0 g
s
0 0 0 r
.74438 .65947 m .70052 .70988 L .68833 .72287 L p F P
0 g
s
.568 .871 .57 r
.6821 .72816 m .70052 .70988 L .68833 .72287 L closepath p F P
0 g
s
.274 .776 .865 r
.40448 .83012 m .42019 .83084 L .47988 .82209 L p F P
0 g
s
0 .551 .707 r
.40448 .83012 m .36451 .8283 L .42019 .83084 L closepath p F P
0 g
s
0 .138 .684 r
.73624 .22736 m .75955 .25296 L .77063 .28172 L p F P
0 g
s
0 .058 .614 r
.72011 .1996 m .73624 .22736 L .75955 .25296 L p F P
0 g
s
0 .273 .778 r
.71182 .19344 m .72011 .1996 L .73624 .22736 L p F P
0 g
s
0 0 0 r
.81139 .49332 m .80943 .50124 L .80196 .54004 L p F P
0 g
s
0 0 .488 r
.75955 .25296 m .77063 .28172 L .78824 .31012 L p F P
0 g
s
.482 0 0 r
.16872 .76641 m .14081 .74641 L .10759 .72 L p F P
0 g
s
.215 0 0 r
.30523 .82129 m .3005 .82002 L .30955 .82223 L closepath p F P
0 g
s
.082 .629 .838 r
.36451 .8283 m .40448 .83012 L p .30523 .82129 L F P
0 g
s
.082 .629 .838 r
.30523 .82129 m .30955 .82223 L .36451 .8283 L p F P
0 g
s
.571 .934 .794 r
.62128 .77035 m .60337 .78189 L .58378 .78701 L p F P
0 g
s
.364 .83 .769 r
.60337 .78189 m .58378 .78701 L p .50683 .8176 L F P
0 g
s
.571 .934 .794 r
.6669 .73525 m .62128 .77035 L p .58378 .78701 L F P
0 g
s
.526 .898 .708 r
.62128 .77035 m .6669 .73525 L .6821 .72816 L closepath p F P
0 g
s
.654 .905 .583 r
.75367 .64694 m .74438 .65947 L .70052 .70988 L p F P
0 g
s
0 0 0 r
.80196 .54004 m .80713 .51939 L .81139 .49332 L p F P
0 g
s
0 0 .121 r
.81139 .49332 m .81432 .47033 L .81398 .43431 L p F P
0 g
s
.73 .679 .132 r
.81432 .47033 m .81139 .49332 L .80713 .51939 L p F P
0 g
s
.135 .68 .718 r
.5044 .81795 m .47988 .82209 L .50683 .8176 L closepath p F P
0 g
s
.274 .776 .865 r
.47988 .82209 m .5044 .81795 L p .40448 .83012 L F P
0 g
s
0 .229 .67 r
.16872 .76641 m .18327 .77535 L .1579 .75686 L p F P
0 g
s
0 .229 .67 r
.1579 .75686 m .14081 .74641 L .16872 .76641 L p F P
0 g
s
0 0 .238 r
.81398 .43431 m .81274 .40426 L .80646 .37064 L p F P
0 g
s
.74 .592 .019 r
.81274 .40426 m .81398 .43431 L .81432 .47033 L p F P
0 g
s
.732 .975 .731 r
.70052 .70988 m .72649 .67534 L p .6669 .73525 L F P
0 g
s
.732 .975 .731 r
.6669 .73525 m .6821 .72816 L .70052 .70988 L p F P
0 g
s
.654 .905 .583 r
.74331 .65612 m .75367 .64694 L p .70052 .70988 L F P
0 g
s
.654 .905 .583 r
.70052 .70988 m .72649 .67534 L .74331 .65612 L p F P
0 g
s
0 .47 .782 r
.3005 .82002 m .30523 .82129 L .28099 .8116 L p F P
0 g
s
0 .47 .782 r
.28099 .8116 m .25744 .80541 L .3005 .82002 L p F P
0 g
s
.415 .864 .832 r
.5044 .81795 m .52909 .80844 L .50683 .8176 L closepath p F P
0 g
s
.364 .83 .769 r
.58378 .78701 m .52909 .80844 L .50683 .8176 L p F P
0 g
s
.082 .629 .838 r
.40448 .83012 m .38145 .82433 L .30523 .82129 L p F P
0 g
s
.247 .703 .952 r
.38145 .82433 m .30523 .82129 L .28099 .8116 L p F P
0 g
s
.781 .82 .345 r
.80713 .51939 m .80196 .54004 L .78668 .58176 L p F P
0 g
s
.523 .912 .929 r
.52909 .80844 m .5044 .81795 L .4829 .8165 L p F P
0 g
s
.274 .776 .865 r
.5044 .81795 m .4829 .8165 L .40448 .83012 L p F P
0 g
s
0 0 .361 r
.80646 .37064 m .80016 .34124 L .78824 .31012 L p F P
0 g
s
.727 .482 0 r
.80016 .34124 m .80646 .37064 L .81274 .40426 L p F P
0 g
s
.787 .936 .579 r
.74331 .65612 m .76309 .62646 L .75367 .64694 L closepath p F P
0 g
s
.727 .854 .423 r
.78668 .58176 m .76309 .62646 L .75367 .64694 L p F P
0 g
s
.412 .83 .968 r
.4829 .8165 m .40448 .83012 L .38145 .82433 L p F P
0 g
s
0 .435 .797 r
.18327 .77535 m .22152 .78823 L .25744 .80541 L p F P
0 g
s
.029 .487 .88 r
.22152 .78823 m .18327 .77535 L .1579 .75686 L p F P
0 g
s
0 .058 .614 r
.75955 .25296 m .74336 .2252 L .72011 .1996 L p F P
0 g
s
0 0 .488 r
.78824 .31012 m .77702 .28145 L .75955 .25296 L p F P
0 g
s
.676 .344 0 r
.77702 .28145 m .78824 .31012 L .80016 .34124 L p F P
0 g
s
.523 .912 .929 r
.57767 .78696 m .52909 .80844 L p .4829 .8165 L F P
0 g
s
.497 .904 .901 r
.52909 .80844 m .57767 .78696 L .58378 .78701 L closepath p F P
0 g
s
0 0 .383 r
.74336 .2252 m .75955 .25296 L .77702 .28145 L p F P
0 g
s
.032 .527 .877 r
.25744 .80541 m .28099 .8116 L .25632 .79723 L p F P
0 g
s
.032 .527 .877 r
.25632 .79723 m .22152 .78823 L .25744 .80541 L p F P
0 g
s
.852 .923 .532 r
.79472 .55056 m .78668 .58176 L .76309 .62646 L p F P
0 g
s
.781 .82 .345 r
.80245 .52941 m .80713 .51939 L p .78668 .58176 L F P
0 g
s
.781 .82 .345 r
.78668 .58176 m .79472 .55056 L .80245 .52941 L p F P
0 g
s
.73 .679 .132 r
.80713 .51939 m .80843 .50894 L .81432 .47033 L p F P
0 g
s
.878 .767 .265 r
.81311 .44049 m .81432 .47033 L .80843 .50894 L p F P
0 g
s
.74 .592 .019 r
.81432 .47033 m .81311 .44049 L .81274 .40426 L p F P
0 g
s
.85 .827 .351 r
.80245 .52941 m .80843 .50894 L .80713 .51939 L closepath p F P
0 g
s
.571 .934 .794 r
.58378 .78701 m .66399 .73605 L .6669 .73525 L p F P
0 g
s
.699 .978 .906 r
.57767 .78696 m .58378 .78701 L .66399 .73605 L p F P
0 g
s
.887 .678 .16 r
.80639 .37503 m .81274 .40426 L .81311 .44049 L p F P
0 g
s
.727 .482 0 r
.81274 .40426 m .80639 .37503 L .80016 .34124 L p F P
0 g
s
.893 .979 .691 r
.76309 .62646 m .77156 .59555 L p .73507 .65945 L F P
0 g
s
.893 .979 .691 r
.73507 .65945 m .74331 .65612 L .76309 .62646 L p F P
0 g
s
.852 .923 .532 r
.76309 .62646 m .77156 .59555 L .79472 .55056 L p F P
0 g
s
.247 .703 .952 r
.28099 .8116 m .35787 .81384 L .38145 .82433 L p F P
0 g
s
.33 .712 .983 r
.28099 .8116 m .35787 .81384 L .35214 .81028 L p F P
0 g
s
.33 .712 .983 r
.25632 .79723 m .28099 .8116 L p .35214 .81028 L F P
0 g
s
.741 .989 .797 r
.66399 .73605 m .67096 .72988 L .6669 .73525 L closepath p F P
0 g
s
.732 .975 .731 r
.72649 .67534 m .67096 .72988 L .6669 .73525 L p F P
0 g
s
.862 .56 .035 r
.78885 .31269 m .80016 .34124 L .80639 .37503 L p F P
0 g
s
.676 .344 0 r
.80016 .34124 m .78885 .31269 L .77702 .28145 L p F P
0 g
s
.954 .876 .471 r
.80843 .50894 m .8073 .47935 L p .79564 .53694 L F P
0 g
s
.954 .876 .471 r
.79564 .53694 m .80245 .52941 L .80843 .50894 L p F P
0 g
s
.878 .767 .265 r
.80843 .50894 m .8073 .47935 L .81311 .44049 L p F P
0 g
s
.029 .487 .88 r
.1579 .75686 m .19264 .7684 L .22152 .78823 L p F P
0 g
s
.8 .986 .726 r
.72649 .67534 m .73507 .65945 L .74331 .65612 L closepath p F P
0 g
s
.134 .554 .923 r
.22152 .78823 m .25632 .79723 L .23127 .77822 L p F P
0 g
s
.134 .554 .923 r
.23127 .77822 m .19264 .7684 L .22152 .78823 L p F P
0 g
s
.807 1 .808 r
.73507 .65945 m .72649 .67534 L .67096 .72988 L p F P
0 g
s
0 0 .383 r
.77702 .28145 m .76078 .25372 L .74336 .2252 L p F P
0 g
s
.802 .417 0 r
.76078 .25372 m .77702 .28145 L .78885 .31269 L p F P
0 g
s
.695 .971 .925 r
.56337 .78571 m .60604 .76029 L .57767 .78696 L closepath p F P
0 g
s
.699 .978 .906 r
.64488 .73595 m .60604 .76029 L .57767 .78696 L p F P
0 g
s
.699 .978 .906 r
.66399 .73605 m .64488 .73595 L p .57767 .78696 L F P
0 g
s
.523 .912 .929 r
.4829 .8165 m .56337 .78571 L .57767 .78696 L p F P
0 g
s
.807 .996 .861 r
.67096 .72988 m .66399 .73605 L .64488 .73595 L p F P
0 g
s
.807 .996 .861 r
.64488 .73595 m .68894 .69732 L .67096 .72988 L p F P
0 g
s
.807 1 .808 r
.72596 .6609 m .73507 .65945 L p .67096 .72988 L F P
0 g
s
.807 1 .808 r
.67096 .72988 m .68894 .69732 L .72596 .6609 L p F P
0 g
s
.602 .914 .978 r
.56337 .78571 m .4829 .8165 L .46074 .8101 L p F P
0 g
s
.412 .83 .968 r
.38145 .82433 m .46074 .8101 L .4829 .8165 L p F P
0 g
s
.49 .829 .998 r
.38145 .82433 m .46074 .8101 L .453 .80639 L p F P
0 g
s
.49 .829 .998 r
.35787 .81384 m .38145 .82433 L p .453 .80639 L F P
0 g
s
.92 .896 .488 r
.79472 .55056 m .79564 .53694 L .80245 .52941 L closepath p F P
0 g
s
.968 .806 .378 r
.80674 .41146 m .81311 .44049 L .8073 .47935 L p F P
0 g
s
.887 .678 .16 r
.81311 .44049 m .80674 .41146 L .80639 .37503 L p F P
0 g
s
.942 .952 .639 r
.79564 .53694 m .79472 .55056 L .77156 .59555 L p F P
0 g
s
.885 .991 .76 r
.72596 .6609 m .73951 .64359 L .73507 .65945 L closepath p F P
0 g
s
.893 .979 .691 r
.77156 .59555 m .73951 .64359 L .73507 .65945 L p F P
0 g
s
.964 .713 .274 r
.79501 .34663 m .80639 .37503 L .80674 .41146 L p F P
0 g
s
.862 .56 .035 r
.80639 .37503 m .79501 .34663 L .78885 .31269 L p F P
0 g
s
.33 .712 .983 r
.35214 .81028 m .31866 .79869 L .25632 .79723 L p F P
0 g
s
.392 .7 .983 r
.31866 .79869 m .25632 .79723 L .23127 .77822 L p F P
0 g
s
.932 .596 .152 r
.77254 .28505 m .78885 .31269 L .79501 .34663 L p F P
0 g
s
.802 .417 0 r
.78885 .31269 m .77254 .28505 L .76078 .25372 L p F P
0 g
s
.734 .952 .947 r
.60604 .76029 m .56337 .78571 L .54221 .77908 L p F P
0 g
s
.602 .914 .978 r
.46074 .8101 m .54221 .77908 L .56337 .78571 L p F P
0 g
s
.931 .97 .732 r
.77362 .56568 m .77156 .59555 L .73951 .64359 L p F P
0 g
s
.942 .952 .639 r
.78679 .54028 m .79564 .53694 L p .77156 .59555 L F P
0 g
s
.942 .952 .639 r
.77156 .59555 m .77362 .56568 L .78679 .54028 L p F P
0 g
s
.966 .925 .596 r
.78679 .54028 m .79498 .52085 L .79564 .53694 L closepath p F P
0 g
s
.954 .876 .471 r
.8073 .47935 m .79498 .52085 L .79564 .53694 L p F P
0 g
s
.99 .875 .536 r
.80095 .45056 m .8073 .47935 L .79498 .52085 L p F P
0 g
s
.968 .806 .378 r
.8073 .47935 m .80095 .45056 L .80674 .41146 L p F P
0 g
s
.734 .952 .947 r
.62856 .73129 m .60604 .76029 L p .54221 .77908 L F P
0 g
s
.743 .963 .938 r
.60604 .76029 m .62856 .73129 L .64488 .73595 L closepath p F P
0 g
s
.49 .829 .998 r
.453 .80639 m .3721 .81123 L .35787 .81384 L p F P
0 g
s
.535 .806 .996 r
.3721 .81123 m .35214 .81028 L .35787 .81384 L closepath p F P
0 g
s
.647 .886 .984 r
.453 .80639 m .46074 .8101 L .54221 .77908 L p F P
0 g
s
.911 .968 .799 r
.73951 .64359 m .72596 .6609 L .70748 .65735 L p F P
0 g
s
.911 .968 .799 r
.70748 .65735 m .74183 .61409 L .73951 .64359 L p F P
0 g
s
.931 .97 .732 r
.73951 .64359 m .74183 .61409 L .77362 .56568 L p F P
0 g
s
.856 .984 .854 r
.68894 .69732 m .72596 .6609 L .70748 .65735 L p F P
0 g
s
.839 .966 .886 r
.62856 .73129 m .64488 .73595 L .68894 .69732 L p F P
0 g
s
.998 .802 .454 r
.79529 .38326 m .80674 .41146 L .80095 .45056 L p F P
0 g
s
.964 .713 .274 r
.80674 .41146 m .79529 .38326 L .79501 .34663 L p F P
0 g
s
.839 .966 .886 r
.68894 .69732 m .69827 .66631 L p .62856 .73129 L F P
0 g
s
.856 .984 .854 r
.70748 .65735 m .69827 .66631 L .68894 .69732 L p F P
0 g
s
.498 .829 .999 r
.43796 .79889 m .3721 .81123 L .453 .80639 L closepath p F P
0 g
s
.539 .806 .995 r
.3721 .81123 m .43796 .79889 L p .33379 .79872 L F P
0 g
s
.539 .806 .995 r
.33379 .79872 m .35214 .81028 L .3721 .81123 L p F P
0 g
s
.361 .724 .988 r
.33379 .79872 m .31866 .79869 L .35214 .81028 L closepath p F P
0 g
s
.982 .905 .648 r
.79498 .52085 m .78679 .54028 L .7694 .53682 L p F P
0 g
s
.982 .905 .648 r
.7694 .53682 m .78864 .49234 L .79498 .52085 L p F P
0 g
s
.99 .875 .536 r
.79498 .52085 m .78864 .49234 L .80095 .45056 L p F P
0 g
s
.646 .882 .984 r
.43796 .79889 m .50541 .77337 L .453 .80639 L closepath p F P
0 g
s
.647 .886 .984 r
.52037 .76766 m .50541 .77337 L .453 .80639 L p F P
0 g
s
.647 .886 .984 r
.54221 .77908 m .52037 .76766 L p .453 .80639 L F P
0 g
s
.986 .71 .355 r
.77858 .31912 m .79501 .34663 L .79529 .38326 L p F P
0 g
s
.932 .596 .152 r
.79501 .34663 m .77858 .31912 L .77254 .28505 L p F P
0 g
s
.392 .7 .983 r
.23127 .77822 m .28739 .77925 L .31866 .79869 L p F P
0 g
s
.968 .929 .691 r
.77362 .56568 m .78679 .54028 L .7694 .53682 L p F P
0 g
s
.414 .71 .984 r
.31866 .79869 m .33379 .79872 L .30924 .77919 L p F P
0 g
s
.414 .71 .984 r
.30924 .77919 m .28739 .77925 L .31866 .79869 L p F P
0 g
s
.995 .848 .58 r
.78941 .42259 m .80095 .45056 L .78864 .49234 L p F P
0 g
s
.998 .802 .454 r
.80095 .45056 m .78941 .42259 L .79529 .38326 L p F P
0 g
s
.944 .935 .756 r
.76938 .53686 m .77362 .56568 L .74183 .61409 L p F P
0 g
s
.968 .929 .691 r
.7694 .53682 m .76938 .53686 L .77362 .56568 L p F P
0 g
s
.734 .952 .947 r
.54221 .77908 m .62492 .73005 L .62856 .73129 L p F P
0 g
s
.75 .915 .947 r
.62492 .73005 m .54221 .77908 L .52037 .76766 L p F P
0 g
s
.539 .806 .995 r
.43796 .79889 m .4146 .7832 L .33379 .79872 L p F P
0 g
s
.567 .775 .977 r
.4146 .7832 m .33379 .79872 L .30924 .77919 L p F P
0 g
s
.664 .847 .97 r
.50541 .77337 m .43796 .79889 L .4146 .7832 L p F P
0 g
s
.82 .958 .902 r
.62492 .73005 m .63021 .72578 L .62856 .73129 L closepath p F P
0 g
s
.839 .966 .886 r
.69827 .66631 m .63021 .72578 L .62856 .73129 L p F P
0 g
s
.993 .775 .501 r
.77873 .35593 m .79529 .38326 L .78941 .42259 L p F P
0 g
s
.986 .71 .355 r
.79529 .38326 m .77873 .35593 L .77858 .31912 L p F P
0 g
s
.912 .926 .81 r
.74183 .61409 m .73765 .58566 L p .69867 .65294 L F P
0 g
s
.912 .926 .81 r
.69867 .65294 m .70748 .65735 L .74183 .61409 L p F P
0 g
s
.944 .935 .756 r
.74183 .61409 m .73765 .58566 L .76938 .53686 L p F P
0 g
s
.825 .92 .9 r
.63021 .72578 m .62492 .73005 L .60416 .7185 L p F P
0 g
s
.75 .915 .947 r
.52037 .76766 m .60416 .7185 L .62492 .73005 L p F P
0 g
s
.825 .92 .9 r
.60416 .7185 m .63087 .69702 L .63021 .72578 L p F P
0 g
s
.843 .932 .886 r
.69867 .65294 m .69827 .66631 L .63021 .72578 L p F P
0 g
s
.843 .932 .886 r
.68805 .64699 m .69867 .65294 L p .63021 .72578 L F P
0 g
s
.843 .932 .886 r
.63021 .72578 m .63087 .69702 L .68805 .64699 L p F P
0 g
s
.974 .867 .671 r
.78864 .49234 m .77699 .46467 L p .76936 .5368 L F P
0 g
s
.974 .867 .671 r
.76936 .5368 m .7694 .53682 L .78864 .49234 L p F P
0 g
s
.995 .848 .58 r
.78864 .49234 m .77699 .46467 L .78941 .42259 L p F P
0 g
s
.866 .941 .866 r
.69827 .66631 m .69867 .65294 L .70748 .65735 L closepath p F P
0 g
s
.664 .847 .97 r
.51502 .76386 m .50541 .77337 L p .4146 .7832 L F P
0 g
s
.665 .85 .97 r
.50541 .77337 m .51502 .76386 L .52037 .76766 L closepath p F P
0 g
s
.979 .81 .603 r
.77266 .3955 m .78941 .42259 L .77699 .46467 L p F P
0 g
s
.993 .775 .501 r
.78941 .42259 m .77266 .3955 L .77873 .35593 L p F P
0 g
s
.959 .887 .716 r
.76938 .53686 m .76936 .5368 L .7694 .53682 L closepath p F P
0 g
s
.933 .89 .765 r
.76936 .5368 m .76938 .53686 L .73765 .58566 L p F P
0 g
s
.954 .877 .72 r
.75065 .52236 m .75759 .50953 L .76936 .5368 L closepath p F P
0 g
s
.974 .867 .671 r
.77699 .46467 m .75759 .50953 L .76936 .5368 L p F P
0 g
s
.933 .89 .765 r
.75065 .52236 m .76936 .5368 L p .73765 .58566 L F P
0 g
s
.892 .925 .835 r
.68805 .64699 m .69633 .6377 L .69867 .65294 L closepath p F P
0 g
s
.912 .926 .81 r
.73765 .58566 m .69633 .6377 L .69867 .65294 L p F P
0 g
s
.567 .775 .977 r
.30924 .77919 m .3907 .76314 L .4146 .7832 L p F P
0 g
s
.756 .869 .93 r
.51502 .76386 m .52037 .76766 L .60416 .7185 L p F P
0 g
s
.664 .847 .97 r
.4146 .7832 m .49787 .75151 L .51502 .76386 L p F P
0 g
s
.671 .81 .949 r
.49787 .75151 m .4146 .7832 L .3907 .76314 L p F P
0 g
s
.748 .866 .934 r
.49787 .75151 m .51408 .74232 L .51502 .76386 L closepath p F P
0 g
s
.756 .869 .93 r
.58267 .70206 m .51408 .74232 L .51502 .76386 L p F P
0 g
s
.756 .869 .93 r
.60416 .7185 m .58267 .70206 L p .51502 .76386 L F P
0 g
s
.904 .888 .805 r
.72698 .55836 m .73765 .58566 L .69633 .6377 L p F P
0 g
s
.933 .89 .765 r
.73765 .58566 m .72698 .55836 L .75065 .52236 L p F P
0 g
s
.957 .829 .676 r
.76 .43788 m .77699 .46467 L .75759 .50953 L p F P
0 g
s
.979 .81 .603 r
.77699 .46467 m .76 .43788 L .77266 .3955 L p F P
0 g
s
.82 .878 .887 r
.63087 .69702 m .60416 .7185 L .58267 .70206 L p F P
0 g
s
.82 .878 .887 r
.58267 .70206 m .6226 .67001 L .63087 .69702 L p F P
0 g
s
.839 .887 .876 r
.66775 .63061 m .6226 .67001 L .63087 .69702 L p F P
0 g
s
.839 .887 .876 r
.63087 .69702 m .68805 .64699 L .66775 .63061 L p F P
0 g
s
.882 .883 .83 r
.69633 .6377 m .68805 .64699 L .66775 .63061 L p F P
0 g
s
.882 .883 .83 r
.66775 .63061 m .68543 .6109 L .69633 .6377 L p F P
0 g
s
.904 .888 .805 r
.69633 .6377 m .68543 .6109 L .72698 .55836 L p F P
0 g
s
.935 .836 .722 r
.75759 .50953 m .75065 .52236 L .73089 .50034 L p F P
0 g
s
.935 .836 .722 r
.73089 .50034 m .7403 .48311 L .75759 .50953 L p F P
0 g
s
.957 .829 .676 r
.75759 .50953 m .7403 .48311 L .76 .43788 L p F P
0 g
s
.746 .828 .915 r
.51408 .74232 m .49787 .75151 L .47477 .73085 L p F P
0 g
s
.671 .81 .949 r
.3907 .76314 m .47477 .73085 L .49787 .75151 L p F P
0 g
s
.914 .844 .761 r
.72698 .55836 m .75065 .52236 L .73089 .50034 L p F P
0 g
s
.746 .828 .915 r
.47477 .73085 m .49833 .71743 L .51408 .74232 L p F P
0 g
s
.752 .831 .912 r
.56051 .68078 m .49833 .71743 L .51408 .74232 L p F P
0 g
s
.752 .831 .912 r
.51408 .74232 m .58267 .70206 L .56051 .68078 L p F P
0 g
s
.888 .845 .796 r
.70974 .53226 m .72698 .55836 L .68543 .6109 L p F P
0 g
s
.914 .844 .761 r
.73089 .50034 m .70974 .53226 L .72698 .55836 L p F P
0 g
s
.811 .839 .871 r
.6226 .67001 m .58267 .70206 L .56051 .68078 L p F P
0 g
s
.868 .843 .819 r
.68543 .6109 m .66775 .63061 L .64668 .60873 L p F P
0 g
s
.868 .843 .819 r
.64668 .60873 m .66772 .58535 L .68543 .6109 L p F P
0 g
s
.888 .845 .796 r
.68543 .6109 m .66772 .58535 L .70974 .53226 L p F P
0 g
s
.811 .839 .871 r
.56051 .68078 m .60525 .64485 L .6226 .67001 L p F P
0 g
s
.827 .843 .86 r
.64668 .60873 m .60525 .64485 L .6226 .67001 L p F P
0 g
s
.827 .843 .86 r
.6226 .67001 m .66775 .63061 L .64668 .60873 L p F P
0 g
s
.25 Mabswid
.76886 0 m
.92458 .25192 L
s
.92458 .25192 m
1 .87095 L
s
1 .87095 m
.82297 .64898 L
s
.82297 .64898 m
.76886 0 L
s
.07412 .27037 m
0 .88688 L
s
0 .88688 m
.82297 .64898 L
s
.82297 .64898 m
.76886 0 L
s
.76886 0 m
.07412 .27037 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{916.062, 459.5},
  ImageMargins->{{7, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>D0001bb000`400?l00000o`00003ooooonf[o
oookJ_oooo]ZUooonfX00?oooo]Zoooonf[ooookJYOooo]Z003ooookJ_oooo]ZoooonfZGoookJP00
oooonf[ooookJ_oooo]ZUooonfX00?oooo]Zoooonf[ooookJYOooo]Z003ooookJ_oooo]ZoooonfZG
oookJP00oooonf[ooookJ_oooo]ZUooonfX00?oooo]Zoooonf[ooookJYOooo]Z003ooookJ_oooo]Z
oooonfZGoookJP00oooonf[ooookJ_oooo]ZUooonfX00?oooo]Zoooonf[ooookJYOooo]Z003ooook
JRgooo]Z0_l0003ooookJ^kooo]Z0_l0001goookJP00oooonfXZoookJP?o000000?ooo]Zo`000?oo
nfX0oooonf[ZoookJP?o000000?ooo]Zo`000?oonfX0M_oonfX00?oooo]Z:?oonfX2o`0000Cooo]Z
0_l0003ooookJ^Sooo]Z0_l00004oookJP;o0000M_oonfX00?oooo]Z9_oonfX2o`0000Kooo]Z00?o
0000oookJ_l00000oooonf[ToookJP?o00001_oonfX00ol0003ooo]Zo`00001eoookJP00oooonfXS
oookJP?o00002?oonfX00ol0003ooo]Zo`00003ooookJ^7ooo]Z0ol00009oookJP03o`000?oonf[o
000007Gooo]Z003ooookJR7ooo]Z0_l0000;oookJP04o`000?oonf[ooo]Zo`000?oooo]Zg_oonfX2
o`0000cooo]Z00Co0000oookJ_oonf[o0000M?oonfX00?oooo]Z7_oonfX3o`0000gooo]Z00Co0000
oookJ_oonf[o0000oooonf[KoookJP?o00003_oonfX01?l0003ooo]ZoookJ_l0001doookJP00oooo
nfXLoookJP;o00004?oonfX01Ol0003ooo]ZoookJ_oonf[o00000?oooo]Zf?oonfX2o`0001;ooo]Z
00Co0000oookJ_oonf[o0000LooonfX00?oooo]Z6_oonfX2o`0001;ooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP3ooookJ];ooo]Z0ol0000DoookJP05o`000?oonf[ooo]ZoookJ_l0
0000L_oonfX00?oooo]Z5ooonfX3o`0001Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Z
oookJP3ooookJ]3ooo]Z0_l0000GoookJP05o`000?oonf[ooo]ZoookJ_l00000L_oonfX00?oooo]Z
5OoonfX2o`0001Sooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP3ooookJ/cooo]Z
0ol0000IoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0KooonfX00?oooo]Z4_oo
nfX3o`0001[ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP3ooookJ/Wooo]Z0ol0
000LoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0KooonfX00?oooo]Z4?oonfX2
o`0001gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP3ooookJ/Kooo]Z0_l0000O
oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0K_oonfX00?oooo]Z3_oonfX2o`00
01oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP3ooookJ/;ooo]Z0ol0000Qoook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0KOoonfX00?oooo]Z2ooonfX3o`00027o
oo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP3ooookJ/3ooo]Z0_l0000ToookJP03
o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0KOoonfX00?oooo]Z2OoonfX2o`0002Cooo]Z
00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP3ooookJ[cooo]Z0ol0000VoookJP03o`00
0?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0K?oonfX00?oooo]Z1_oonfX3o`0002Kooo]Z00?o
0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP3ooookJ[Sooo]Z0ol0000YoookJP03o`000?oo
nf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0JooonfX00?oooo]Z1?oonfX2o`0002Wooo]Z00?o0000
oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP3ooookJ[Kooo]Z0_l0000/oookJP03o`000?oonf[o
oo]Z00Kooo]Z00?o0000oookJ_oonfX0JooonfX00?oooo]Z0_oonfX2o`0002_ooo]Z00?o0000oook
J_oonfX01ooonfX00ol0003ooo]ZoookJP3ooookJ[;ooo]Z0ol0000^oookJP03o`000?oonf[ooo]Z
00Oooo]Z00?o0000oookJ_oonfX0J_oonfX00?kooo]Z0ol0000]oookJP03o`000?oonf[ooo]Z00Oo
oo]Z00?o0000oookJ_oonfX0oooonfZ`oookJP;o0000<_oonfX00ol0003ooo]ZoookJP06oookJP03
o`000?oonf[ooo]Z06[ooo]Z003loookJP;o0000<?oonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oonf[ooo]Z0?oooo]Z[?oonfX3o`0003Cooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Z
oookJP1YoookJP00nOoonfX3o`0003;ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]Zoook
JP3ooookJZWooo]Z0_l0000goookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0J?oo
nfX00?Oooo]Z0_l0000eoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0oooonfZV
oookJP?o0000>OoonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z06Sooo]Z003eoook
JP;o0000=ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z0?oooo]ZX_oonfX3o`00
03cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP1WoookJP00l_oonfX3o`0003Wo
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP3ooookJYoooo]Z0_l0000ooookJP03
o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0IooonfX00?3ooo]Z0_l0000loookJP03o`00
0?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0oooonfZLoookJP?o0000@OoonfX00ol0003ooo]Z
oookJP0:oookJP03o`000?oonf[ooo]Z06Kooo]Z003]oookJP?o0000?_oonfX00ol0003ooo]Zoook
JP0<oookJP03o`000?oonf[ooo]Z0?oooo]ZVOoonfX2o`0004Cooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP1UoookJP00jooonfX2o`0004;ooo]Z00?o0000oookJ_oonfX02ooonfX0
0ol0003ooo]ZoookJP3ooookJYKooo]Z0ol00016oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000
oookJ_oonfX0IOoonfX00>Wooo]Z0_l00014oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0oooonfZCoookJP;o0000BOoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z
06Cooo]Z003VoookJP?o0000A_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z0?oo
oo]ZSooonfX3o`0004_ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP1SoookJP00
i?oonfX2o`0004Wooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP3ooookJXcooo]Z
0ol0001>oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0HooonfX00>7ooo]Z0ol0
001;oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0oooonfZ9oookJP;o0000D_oo
nfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z06;ooo]Z003OoookJP;o0000C_oonfX0
0ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z0?oooo]ZQ_oonfX3o`0005Cooo]Z00?o0000
oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP1RoookJP00gOoonfX2o`00053ooo]Z00?o0000oook
J_oonfX03ooonfX00ol0003ooo]ZoookJP3ooookJX?ooo]Z0_l0001GoookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX0HOoonfX00=[ooo]Z0ol0001BoookJP03o`000?oonf[ooo]Z013o
oo]Z00?o0000oookJ_oonfX0oooonfYooookJP?o0000FOoonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oonf[ooo]Z063ooo]Z003HoookJP;o0000EOoonfX00ol0003ooo]ZoookJP0@oookJP03o`00
0?oonf[ooo]Z0?oooo]ZOOoonfX2o`0005cooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Z
oookJP1PoookJP00eOoonfX3o`0005Oooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Zoook
JP3ooookJWWooo]Z0ol0001NoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0Gooo
nfX00=?ooo]Z0_l0001JoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0oooonfYe
oookJP?o0000HOoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z05oooo]Z003Aoook
JP;o0000G?oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z0?oooo]ZLooonfX2o`00
06Cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP1NoookJP00c_oonfX3o`0005ko
oo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP3ooookJVoooo]Z0ol0001VoookJP03
o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0GOoonfX00<cooo]Z0_l0001QoookJP03o`00
0?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0oooonfY]oookJP;o0000JOoonfX00ol0003ooo]Z
oookJP0BoookJP03o`000?oonf[ooo]Z05gooo]Z0039oookJP?o0000HooonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z0?oooo]ZJOoonfX3o`0006_ooo]Z00?o0000oookJ_oonfX04ooo
nfX00ol0003ooo]ZoookJP1LoookJP00aooonfX2o`0006Kooo]Z00?o0000oookJ_oonfX05OoonfX0
0ol0003ooo]ZoookJP3ooookJVGooo]Z0ol0001^oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX0FooonfX00<Gooo]Z0_l0001XoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oook
J_oonfX0oooonfYSoookJP;o0000L_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
05_ooo]Z0032oookJP?o0000JooonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z0?oo
oo]ZGooonfX3o`0007Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP1JoookJP00
`?oonfX2o`0006kooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP3ooookJUcooo]Z
0_l0001goookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0F_oonfX00;gooo]Z0ol0
001`oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0oooonfYIoookJP?o0000NOoo
nfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z05Wooo]Z002koookJP;o0000LooonfX0
0ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z0?oooo]ZE_oonfX2o`0007cooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP1HoookJP00^OoonfX2o`0007Gooo]Z00?o0000oook
J_oonfX05ooonfX00ol0003ooo]ZoookJP3ooookJU?ooo]Z0ol0001noookJP03o`000?oonf[ooo]Z
01Kooo]Z00?o0000oookJ_oonfX0F?oonfX00;Kooo]Z0ol0001goookJP03o`000?oonf[ooo]Z01So
oo]Z00?o0000oookJ_oonfX0oooonfY?oookJP?o0000POoonfX00ol0003ooo]ZoookJP0GoookJP03
o`000?oonf[ooo]Z05Oooo]Z002doookJP;o0000N_oonfX00ol0003ooo]ZoookJP0IoookJP03o`00
0?oonf[ooo]Z0?oooo]ZC?oonfX2o`0008Cooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Z
oookJP1GoookJP00/OoonfX3o`0007cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Zoook
JP3ooookJTWooo]Z0ol00026oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0E_oo
nfX00:oooo]Z0_l0001ooookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0oooonfY6
oookJP;o0000ROoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z05Gooo]Z002/oook
JP?o0000POoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z0?oooo]Z@ooonfX3o`00
08_ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP1EoookJP00Z_oonfX2o`0008Co
oo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP3ooookJT3ooo]Z0_l0002>oookJP03
o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0E?oonfX00:Sooo]Z0_l00026oookJP03o`00
0?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0oooonfXloookJP?o0000T?oonfX00ol0003ooo]Z
oookJP0KoookJP03o`000?oonf[ooo]Z05?ooo]Z002UoookJP?o0000R?oonfX00ol0003ooo]Zoook
JP0LoookJP03o`000?oonf[ooo]Z0?oooo]Z>OoonfX3o`0009Cooo]Z00?o0000oookJ_oonfX06_oo
nfX00ol0003ooo]ZoookJP1CoookJP00XooonfX2o`0008_ooo]Z00?o0000oookJ_oonfX07OoonfX0
0ol0003ooo]ZoookJP3ooookJSKooo]Z0_l0000]oookJQ3o0000F_oonfX00ol0003ooo]ZoookJP0K
oookJP03o`000?oonf[ooo]Z05;ooo]Z002PoookJP?o0000SOoonfX00ol0003ooo]ZoookJP0Noook
JP03o`000?oonf[ooo]Z0?oooo]Z<_oonfX3o`0002;ooo]Z3Ol00006ohRWj@03o`000?mnXNWoOZ7Y
00;oOZ7Y00?o0000ofZGj_mZUnX00_mZUnX7o`0005?ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0
003ooo]ZoookJP1BoookJP00W_oonfX2o`00093ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003o
oo]ZoookJP3ooookJS3ooo]Z0_l0000MoookJPSo00005?n8YnT00ol0003oOZ7YogjQj@02ogjQj@03
o`000?mZUn[oJYOZ00SoJYOZ1ol0001<oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oo
nfX0DOoonfX009cooo]Z0_l0002BoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
oooonfX/oookJP?o00006ooonfX4o`0000;oW[7U00?o0000ohRWjOn8YnT05on8YnT00ol0003oOZ7Y
ogjQj@03ogjQj@03o`000?mZUn[oJYOZ00koJYOZ1Ol00017oookJP03o`000?oonf[ooo]Z01gooo]Z
00?o0000oookJ_oonfX0D?oonfX009Wooo]Z0ol0002DoookJP03o`000?oonf[ooo]Z01oooo]Z00?o
0000oookJ_oonfX0oooonfXZoookJP;o00006_oonfX4o`0000OoW[7U00?o0000ohRWjOn8YnT05on8
YnT00ol0003oOZ7YogjQj@02ogjQj@03o`000?mZUn[oJYOZ013oJYOZ00?o0000oeF;j?mERnP01?l0
0013oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0D?oonfX009Oooo]Z0_l0002H
oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0oooonfXVoookJP?o00005ooonfX5
o`0000coW[7U00?o0000ohRWjOn8YnT05_n8YnT00ol0003oOZ7YogjQj@03ogjQj@03o`000?mZUn[o
JYOZ013oJYOZ00?o0000oeF;j?mERnP00omERnP3o`00043ooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP1?oookJP00U?oonfX3o`0009[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP3ooookJR;ooo]Z0ol0000FoookJPCo00004_nN/ND00ol0003oR:OYohRWj@0FohRW
j@03o`000?mnXNWoOZ7Y00?oOZ7Y00?o0000ofZGj_mZUnX04?mZUnX00ol0003oEH_XoeF;j005oeF;
j0Co0000??oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z04oooo]Z002BoookJP;o
0000WOoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z0?oooo]Z8?oonfX2o`0001Go
oo]Z1?l0000Foijai@03o`000?n8YnWoR:OY01KoR:OY00?o0000ogjQjOmnXNT00omnXNT00ol0003o
JYOZofZGjP0@ofZGjP03o`000?mERnSoEH_X00KoEH_X00?o0000odN3i_m7PnH00ol0000ioookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0C_oonfX0093ooo]Z0_l0002OoookJP03o`00
0?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0oooonfXLoookJP?o00004ooonfX4o`0001_oW[7U
00?o0000ohRWjOn8YnT05_n8YnT00ol0003oOZ7YogjQj@03ogjQj@03o`000?mZUn[oJYOZ013oJYOZ
00?o0000oeF;j?mERnP01_mERnP00ol0003oAh?VodN3iP02odN3iP?o0000=_oonfX00ol0003ooo]Z
oookJP0PoookJP03o`000?oonf[ooo]Z04gooo]Z002=oookJP?o0000XOoonfX00ol0003ooo]Zoook
JP0RoookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX2o`0001?ooo]Z0ol0000Poijai@03o`000?n8
YnWoR:OY01GoR:OY00?o0000ogjQjOmnXNT01?mnXNT00ol0003oJYOZofZGjP0@ofZGjP03o`000?mE
RnSoEH_X00KoEH_X00?o0000odN3i_m7PnH01?m7PnH2o`0003Cooo]Z00?o0000oookJ_oonfX08?oo
nfX00ol0003ooo]ZoookJP1=oookJP00RooonfX2o`000:Cooo]Z00?o0000oookJ_oonfX08_oonfX0
0ol0003ooo]ZoookJP3ooookJQKooo]Z0ol0000CoookJP;o000000?o]KSLo`000?nN/ND08?nN/ND0
0ol0003oR:OYohRWj@0FohRWj@03o`000?mnXNWoOZ7Y00?oOZ7Y00?o0000ofZGj_mZUnX04?mZUnX0
0ol0003oEH_XoeF;j007oeF;j003o`000?m7PnKoAh?V00?oAh?V00Co0000obA[gOl0003o0000<_oo
nfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z04cooo]Z0028oookJP?o0000Y_oonfX0
0ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z0?oooo]Z4ooonfX2o`0001Cooo]Z0_l00004
okFhg003o`000?nN/NGoW[7U01ooW[7U00?o0000ohRWjOn8YnT05On8YnT00ol0003oOZ7YogjQj@04
ogjQj@03o`000?mZUn[oJYOZ013oJYOZ00?o0000oeF;j?mERnP01_mERnP00ol0003oAh?VodN3iP04
odN3iP03o`000?lTJmgo96_M00?o0000<?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[o
oo]Z04_ooo]Z0026oookJP;o0000ZOoonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z
0?oooo]Z4?oonfX3o`0001Cooo]Z0_l00007okFhg003o`000?nN/NGoW[7U01ooW[7U00?o0000ohRW
jOn8YnT02_n8YnT:o`000003ohRWjOl0003o000000_o00003?mZUnX00ol0003oEH_XoeF;j007oeF;
j003o`000?m7PnKoAh?V00CoAh?V00?o0000obA[gOlTJmd00_lTJmd2o`0002kooo]Z00?o0000oook
J_oonfX08OoonfX00ol0003ooo]ZoookJP1;oookJP00Q?oonfX2o`000:_ooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z0ol0000EoookJP;o00002One^=`00ol0003o
W[7Uoijai@0Poijai@co00002on<X>400ol0003oPi[Qoh>Jh@04oh>Jh@03o`000?mcTn?oLi?S00?o
Li?S2_l00003ofZGjP03o`000?mERnSoEH_X00OoEH_X00?o0000odN3i_m7PnH00om7PnH00ol0003o
96_MobA[g@04obA[g@;o0000;?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z04[o
oo]Z0021oookJP?o0000[OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z0?oooo]Z
2OoonfX2o`0001Kooo]Z0_l0000<okFhg003o`000?nN/NGoW[7U01[oW[7U0ol00002oijXg@03o`00
0?n<X>7oS:3Q01CoS:3Q00?o0000oh>JhOn3V^401On3V^400ol0003oLi?Sog>Ch`0<og>Ch`Oo0000
1_mERnP00ol0003oAh?VodN3iP04odN3iP03o`000?lTJmgo96_M00Go96_M0ol0000YoookJP03o`00
0?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0B_oonfX007oooo]Z0_l0002`oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP?o00005_oonfX2o`0000oo]KSL00?o
0000oijaiOnN/ND05OnN/ND4o`0000KoWZSM00?o0000ohbPhOn<X>404on<X>400ol0003oPi[Qoh>J
h@06oh>Jh@03o`000?mcTn?oLi?S00ooLi?S00?o0000of67hOmQQn401?l00003oeF;j003o`000?m7
PnKoAh?V00CoAh?V00?o0000obA[gOlTJmd01olTJmd2o`0002Oooo]Z00?o0000oookJ_oonfX08ooo
nfX00ol0003ooo]ZoookJP19oookJP00O?oonfX3o`000;;ooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ooo]ZoookJP3ooookJP?ooo]Z0_l0000GoookJP;o00004One^=`00ol0003oW[7Uoijai@0A
oijai@Co00002onNZ=d00ol0003oS:3QohbPh@0BohbPh@03o`000?n3V^7oPi[Q00KoPi[Q00?o0000
og>ChomcTn<03omcTn<00ol0003oHHOQof67h@04of67h@Go00001Om7PnH00ol0003o96_MobA[g@09
obA[g@;o00009OoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z04Sooo]Z001joook
JP;o0000]OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z0?oooo]Z0ol0000Hoook
JP03o`000?ne^=co]KSL01;o]KSL00?o0000oijaiOnN/ND03OnN/ND3o`0000ooWZSM00?o0000ohbP
hOn<X>404_n<X>400ol0003oPi[Qoh>Jh@07oh>Jh@03o`000?mcTn?oLi?S00ooLi?S00?o0000of67
hOmQQn401omQQn43o`0000CoAh?V00?o0000obA[gOlTJmd02?lTJmd00ol0003o04_:o`00000Toook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0B?oonfX007Sooo]Z0_l0002goookJP03
o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0nooonfX3o`0001Wooo]Z0_l0000FokFhg003
o`000?nN/NGoW[7U00SoW[7U1?l0000CoijXg@03o`000?n<X>7oS:3Q017oS:3Q00?o0000oh>JhOn3
V^401on3V^400ol0003oLi?Sog>Ch`0?og>Ch`03o`000?mQQn7oHHOQ00SoHHOQ0_mFP^43o`000003
odN3i_l0003o96_M00[o96_M00?o0000o`1;b_l000008ooonfX00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z04Oooo]Z001eoookJP?o0000^OoonfX00ol0003ooo]ZoookJP0XoookJP03o`00
0?oonf[ooo]Z0?Sooo]Z0_l0000JoookJP;o00006?ne^=`00ol0003oW[7Uoijai@04oijai@Co0000
5onNZ=d00ol0003oS:3QohbPh@0AohbPh@03o`000?n3V^7oPi[Q00SoPi[Q00?o0000og>ChomcTn<0
3_mcTn<00ol0003oHHOQof67h@09of67h@CoEX;Q0ol0000:obA[g@03o`000?l0Bl[o04_:00;o0000
8OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z04Oooo]Z001coookJP;o0000_?oo
nfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z0?Gooo]Z0ol0000JoookJP;o00006one
^=`00ol0003oW[7Uoijai@03o`0001coWZSM00?o0000ohbPhOn<X>404?n<X>400ol0003oPi[Qoh>J
h@09oh>Jh@03o`000?mcTn?oLi?S00goLi?S00?o0000of67hOmQQn402OmQQn400ol0003oEX;QoeJ2
h@04oeJ2h@;o00002OlTJmd01Ol0003o04_:o`1;b_l0Bl[o0000023ooo]Z00?o0000oookJ_oonfX0
9_oonfX00ol0003ooo]ZoookJP16oookJP00L?oonfX3o`000;kooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP3boookJP;o00006ooonfX2o`0001ko]KSL0_l0000PoijXg@03o`000?n<
X>7oS:3Q00ooS:3Q00?o0000oh>JhOn3V^402On3V^400ol0003oLi?Sog>Ch`0>og>Ch`03o`000?mQ
Qn7oHHOQ00WoHHOQ00?o0000oeJ2hOmFP^400omFP^401?l0003o=VgJo`000?l00008obA[g@05o`00
0?l0Bl[o04_:o`1;b_l000007ooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z04Go
oo]Z001^oookJP;o0000`_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z0>kooo]Z
0ol0000KoookJP;o00007One^=`2o`000003ok:_eOl0003oWZSM023oWZSM00?o0000ohbPhOn<X>40
3on<X>400ol0003oPi[Qoh>Jh@0:oh>Jh@03o`000?mcTn?oLi?S00goLi?S00?o0000of67hOmQQn40
2_mQQn400ol0003oEX;QoeJ2h@03oeJ2h@03o`000?lfKM[o=VgJ00;o00001_lTJmd00ol0003o04_:
o`1;bP02o`1;bP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP15oookJP00K?oonfX2o`000<Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP3/oookJP;o00007?oonfX2o`0001go]KSL0_l00004ok:_e@03o`000?nNZ=goWZSM01ooWZSM00?o
0000ohbPhOn<X>403_n<X>400ol0003oPi[Qoh>Jh@0:oh>Jh@03o`000?mcTn?oLi?S00goLi?S00?o
0000of67hOmQQn402_mQQn400ol0003oEX;QoeJ2h@03oeJ2h@03o`000?lfKM[o=VgJ00;o=VgJ0_l0
0005obA[g@03o`000?l0Bl[o04_:00;o04_:0_l0000MoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX0A?oonfX006Wooo]Z0ol00036oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000
oookJ_oonfX0j?oonfX3o`0001cooo]Z0_l0000MokFhg0;o00001onb[mD00ol0003oWZSMoijXg@0N
oijXg@03o`000?n<X>7oS:3Q00koS:3Q00?o0000oh>JhOn3V^402on3V^400ol0003oLi?Sog>Ch`0<
og>Ch`03o`000?mQQn7oHHOQ00_oHHOQ00?o0000oeJ2hOmFP^400_mFP^400ol0003o=VgJocI]fP04
ocI]fP;o00000olTJmd00ol0003o04_:o`1;bP02o`1;bP;o04G70_l0000KoookJP03o`000?oonf[o
oo]Z02Sooo]Z00?o0000oookJ_oonfX0@ooonfX006Oooo]Z0_l00039oookJP03o`000?oonf[ooo]Z
02[ooo]Z00?o0000oookJ_oonfX0iOoonfX3o`0001kooo]Z00?o0000ol6leOl000006one^=`2o`00
00Wo/ZoE00?o0000oijXgOnNZ=d07onNZ=d00ol0003oS:3QohbPh@06ohbPhA_o00002OmcTn<00ol0
003oHHOQof67h@0;of67h@03o`000?mFP^7oEX;Q00?oEX;Q00?o0000ocI]f_lfKMX01OlfKMX2o`00
00;o96_M00?o0000o`1;b_l0BlX00_l0BlX3o`15a`03o`000?oonf[ooo]Z01Sooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP13oookJP00I?oonfX3o`000<_ooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP3RoookJP;o00007ooonfX2o`0000?o`KcE00?o0000okFhg?ne
^=`05_ne^=`2o`0000co/ZoE00?o0000oijXgOnNZ=d07onNZ=d8o`0000OoT9_K00?o0000ohNDfOn7
U=T03?n7U=T5ogZ@g0Oo00000omcTn<00ol0003oHHOQof67h@0;of67h@03o`000?mFP^7oEX;Q00;o
EX;Q00?o0000ocI]f_lfKMX01olfKMX2o`000003obA[gOl0003o04_:00?o04_:0_l0ALL00ol0003o
oo]ZoookJP0HoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0@_oonfX006;ooo]Z
0_l0003>oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0g_oonfX3o`00023ooo]Z
00?o0000ol6leOo1_=D01?o1_=D00ol0003o]KSLokFhg00CokFhg0;o00003onb[mD00ol0003oWZSM
oijXg@0HoijXg@Co00000_nOXmP>oi2Kf`03o`000?n7U=WoQiCI00koQiCI2omjT=`6o`0000_oHHOQ
00?o0000oeJ2hOmFP^400_mFP^400ol0003o=VgJocI]fP09ocI]fP;o00001?l0BlX01?l0003o04G7
o`15aol0000IoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0@_oonfX0063ooo]Z
0_l0003@oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0g?oonfX2o`00027ooo]Z
0_l00008ol6le@03o`000?ne^=co]KSL00oo]KSL0ol0000Aok:_e@03o`000?nNZ=goWZSM01CoWZSM
1?l00007oinSf0goT9_K00?o0000ohNDfOn7U=T03_n7U=T00ol0003oNY3LogZ@g00;ogZ@g003o`00
0?m^RMcoKXWL00Co00002?mQQn400ol0003oEX;QoeJ2h@02oeJ2h@03o`000?lfKM[o=VgJ00[o=VgJ
0_l00003o`1;bP;o04G70_l0000HoookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0
@OoonfX005gooo]Z0ol0003BoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0f?oo
nfX3o`0002;ooo]Z00?o0000ol6leOo1_=D02?o1_=D00ol0003o]KSLokFhg00=okFhg0;o00005Onb
[mD00ol0003oWZSMoijXg@0>oijXg@Go00002onOXmP00ol0003oT9_Koi2Kf`0:oi2Kf`03o`000?n7
U=WoQiCI00ooQiCI00?o0000ogZ@g?mjT=`02_mjT=`00ol0003oKXWLofj9g004ofj9g0Go00001?mQ
Qn401Ol0003oEX;QoeJ2hOmFP^7o000000co=VgJ0_lJF=001?l0003o04_:o`1;b_l0BlX2o`15a`;o
00005ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z043ooo]Z001KoookJP;o0000
eOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z0=Gooo]Z0_l0000SoookJP;o0000
3?o1_=D00ol0003o]KSLokFhg00:okFhg0;o00006?nb[mD00ol0003oWZSMoijXg@09oijXg@Co0000
4OnOXmP00ol0003oT9_Koi2Kf`08oi2Kf`03o`000?n7U=WoQiCI017oQiCI00?o0000ogZ@g?mjT=`0
2OmjT=`00ol0003oKXWLofj9g009ofj9g0Go00000omFP^400ol0003o=VgJocI]fP0;ocI]fP;o6US@
0_l000001_l0Bl[o0000o`15aol0003o00jMo`0001Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP10oookJP00F?oonfX3o`000=Oooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003o
oo]ZoookJP3BoookJP?o00009?oonfX00ol0003o`KcEol6le@0=ol6le@03o`000?ne^=co]KSL00Oo
]KSL0_l0000Jok:_e@03o`000?nNZ=goWZSM00GoWZSM1?l0000FoinSf0[oT9_K00?o0000ohNDfOn7
U=T04On7U=T00ol0003oNY3LogZ@g009ogZ@g003o`000?m^RMcoKXWL00goKXWL1?l000000omFP^7o
0000ocI]fP0;ocI]fP06o`000?lJF=3o6US@oaYHd?l0003o04_:0_l0ALL00ol0003o00jMo`00000E
oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0?ooonfX005Kooo]Z0_l0003Joook
JP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0c_oonfX3o`0002Gooo]Z0_l0000@ol6l
e@03o`000?ne^=co]KSL00Go]KSL0_l0000Mok:_e@03o`000?nNZ=goWZSM00Co00006_nOXmP00ol0
003oT9_Koi2Kf`07oi2Kf`03o`000?n7U=WoQiCI01;oQiCI00?o0000ogZ@g?mjT=`02?mjT=`00ol0
003oKXWLofj9g00>ofj9g003o`000?mMOm_oGGoK00?o00002olfKMX00ol0003o6US@oaYHd002oaYH
d006o`000?l0Bl[o04G7o`000?l03Ygo00005OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z03oooo]Z001DoookJP;o0000g?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z0<cooo]Z0_l0000WoookJP03o`000?o1_=Go`KcE017o`KcE00?o0000okFhg?ne^=`00_ne^=`2
o`00023o/ZoE0_l0000OoinSf003o`000?n@Vm_oT9_K00GoT9_K00?o0000ohNDfOn7U=T04on7U=T0
0ol0003oNY3LogZ@g008ogZ@g003o`000?m^RMcoKXWL00ooKXWL00?o0000oeeofomMOm/00_m>L=D2
o`0000[o=VgJ00?o0000oaYHd?lJF=000_lJF=02o`000004o`15aol0003o00jMo`0001Cooo]Z00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0noookJP00DOoonfX3o`000=kooo]Z00?o0000
oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP38oookJP?o0000:?oonfX00ol0003o`KcEol6le@0C
ol6le@04o`000?ne^=co0000o`0001oo/ZoE0_l000000on`ZM7o0000oinSf00OoinSf003o`000?n@
Vm_oT9_K00GoT9_K00?o0000ohNDfOn7U=T05?n7U=T00ol0003oNY3LogZ@g006ogZ@g003o`000?m^
RMcoKXWL013oKXWL00Co0000oeeofomMOm_o00000om>L=D2o`0000So=VgJ00?o0000oaYHd?lJF=00
1?lJF=02o`0000;o00jM00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0^oookJP03o`00
0?oonf[ooo]Z03gooo]Z001?oookJP;o0000hOoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oo
nf[ooo]Z0<Gooo]Z0_l0000YoookJP;o00005_o1_=D2o`0001oo/ZoE0_l00004ok2Yd@03o`000?nO
XmSoWj?H01koWj?H00?o0000oi2Kfon@Vm/01?n@Vm/00ol0003oQiCIohNDf@0DohNDf@03o`000?mj
T=coNY3L00KoNY3L00?o0000ofj9g?m^RM`04Om^RM`00ol0003oGGoKo`000005odi`e@;o00001_lf
KMX00ol0003o6US@oaYHd005oaYHd005o`15aol0003o00jMo`0>WOl000004ooonfX00ol0003ooo]Z
oookJP0]oookJP03o`000?oonf[ooo]Z03gooo]Z001<oookJP?o0000hooonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z0<;ooo]Z0ol0000ZoookJP03o`000?o1_=Go`KcE01Go`KcE00?o
0000okfddOl000007Onb[mD2o`0000Ko/:WA00?o0000oinSf?nOXmP07_nOXmP00ol0003oT9_Koi2K
f`03oi2Kf`03o`000?n7U=WoQiCI01KoQiCI00?o0000ogZ@g?mjT=`01OmjT=`00ol0003oKXWLofj9
g00Bofj9g0;o00001om>L=D2o`0000Go=VgJ00?o0000oaYHd?lJF=001?lJF=02o`0000?o00jM00?o
0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z03cooo]Z001:
oookJP;o0000i_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z0;oooo]Z0_l0000[
oookJP;o00005_o1_=D2o`0000?o_KCA00?o0000ok:_eOnb[mD06?nb[mD2o`0000Wo/:WA00?o0000
oinSf?nOXmP07_nOXmP00ol0003oT9_Koi2Kf`02oi2Kf`03o`000?n7U=WoQiCI01OoQiCI00?o0000
ogZ@g?mjT=`01?mjT=`00ol0003oKXWLofj9g00Bofj9g003o`000?mMOm_o000000SoCW3E0_l00003
ocI]fP03o`000?lJF=3o6US@00Go6US@0_l00002o`0>W@03o`000?oonf[ooo]Z013ooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0koookJP00B?oonfX2o`000>Sooo]Z00?o0000oook
J_oonfX0<_oonfX00ol0003ooo]ZoookJP2loookJP?o0000;?oonfX00ol0003o`KcEol6le@0Eol6l
e@03o`000?nm]=7o_KCA00Co_KCA00?o0000ok:_eOnb[mD05Onb[mD2o`0000co/:WA00?o0000oinS
f?nOXmP07_nOXmP01Ol0003oT9_Koi2Kfon@Vm_o000001WoQiCI00?o0000ogZ@g?mjT=`01?mjT=`0
0ol0003oKXWLofj9g00Cofj9g0;o00002_m>L=D2o`000003ocI]f_l0003o6US@00Oo6US@00Go02>_
o`000?l03Ygo00jMo`00000AoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0>ooo
nfX004Gooo]Z0ol0003ZoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0^?oonfX3
o`0002gooo]Z0_l0000Fol6le@;o00001onm]=400ol0003o/ZoEok:_e@0Cok:_e@;o00003_n`ZM40
0ol0003oWj?HoinSf00NoinSf004o`000?n@Vm_oT9_Ko`0000goQiCI4_l00002ogZ@g003o`000?m^
RMcoKXWL01?oKXWL0_l0000<odi`e@03o`000?lfKM[o000000Oo6US@00?o0000o`0S[ol000000_l0
3Yd00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0>_oo
nfX004?ooo]Z0_l0003^oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0]OoonfX2
o`0002oooo]Z00?o0000ol6leOo1_=D05Oo1_=D00ol0003o_KCAokfdd@08okfdd@03o`000?nb[mGo
/ZoE00oo/ZoE0ol0000Aok2Yd@03o`000?nOXmSoWj?H01koWj?H4?l0000>ohjBdP04o`000?mmS=So
OHcHogf<f0Go00005?m^RM`00ol0003oCW3Eodi`e@0<odi`e@;o00001olJF=001Ol0003o02>_o`00
0?l03Ygo0000013ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0joookJP00@?oo
nfX3o`000?3ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP2boookJP?o0000<?oo
nfX2o`0001Go`KcE0_l0000<okfdd@03o`000?nb[mGo/ZoE00co/ZoE0_l0000Dok2Yd@03o`000?nO
XmSoWj?H01SoWj?H1?l00002oinNdP03o`000?n@UmOo000001coSY;B00?o0000ogf<f?mmS=P00_mm
S=P00ol0003oMhCCogN4d`05o`0000ooKXWL00?o0000odi`eOm>L=D03?m>L=D2obYHc003o`000?lJ
F=3o6US@00Co6US@00Ko0000o`0S[ol08joo0000o`0>WOl0000?oookJP03o`000?oonf[ooo]Z037o
oo]Z00?o0000oookJ_oonfX0>OoonfX003kooo]Z0_l0003coookJP03o`000?oonf[ooo]Z03Cooo]Z
00?o0000oookJ_oonfX0[ooonfX2o`0003;ooo]Z00Co0000olFld_o5_=;o00004oo1_=D00ol0003o
_KCAokfdd@0<okfdd@03o`000?nb[mGo/ZoE00[o/ZoE0_l0000Gok2Yd@03o`000?nOXmSoWj?H01?o
Wj?H1?l00006oinNdP;o00007On>T]800ol0003oOHcHogf<f002ogf<f003o`000?mgQ=?oMhCC00Go
MhCC1Ol0000:ofj9g0;o00003Om>L=D00ol0003o:US<obYHc002o`0000Go6US@00Ko0000o`0S[ol0
8joo0000o`00H_l0000>oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>?oonfX0
03cooo]Z0_l0003eoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0ZooonfX3o`00
03?ooo]Z00?o0000olFld_o5_=800_o5_=800ol0003o`KcEol6le@0?ol6le@03o`000?nm]=7o_KCA
00ko_KCA00?o0000ok:_eOnb[mD01onb[mD2o`0001Wo/:WA00?o0000oinSf?nOXmP03_nOXmP5o`00
00WoWikB00?o0000oifHcol000007_n>T]801?l0003oOHcHogf<f?l0000=ogN4d`Co00001_m^RM`2
o`0000goCW3E00?o0000obYHc?lZF<`00_lZF<`2o`0000Co6US@00?o0000o`0S[ol08jl00_l0000>
oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0>?oonfX003Wooo]Z0ol0003goook
JP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0Z?oonfX3o`0003Gooo]Z00?o0000olFl
d_o5_=801?o5_=800ol0003o`KcEol6le@0<ol6le@;o00004_nm]=400ol0003o/ZoEok:_e@04ok:_
e@;o00007?n`ZM400ol0003oWj?HoinSf009oinSf0Co00003?nOW]82o`0000?oWIS?00?o0000ohjB
d_n>T]806on>T]801?l0003oOHcHogf<f?l0000AogN4d`Go000000?oKXWLo`000?l000003Om>L=D0
0ol0003o:US<obYHc004obYHc005o`000?lJF=3o6US@oaYHd?l000000ol08jl00ol03Ygo0000oook
JP0<oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=ooonfX003Sooo]Z00?o0000
oookJ_oonfX0n?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z0:Gooo]Z0_l0000f
oookJP;o00002?o5_=82o`0000_o`KcE00?o0000okfddOnm]=404_nm]=400ol0003o/ZoEok:_e@02
ok:_e@;o00007on`ZM400ol0003oWj?HoinSf004oinSf0Co00003onOW]800ol0003oWIS?oifHc`03
oifHc`03o`000?n>T];oSY;B01_oSY;B00Co0000ogf<f?mmS=So00005_mgQ=<4o`0000coCW3E00?o
0000obYHc?lZF<`01OlZF<`2o`0000;o6US@00Go0000o`0S[ol08joo02>_o`00000=oookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=ooonfX003Sooo]Z00?o0000oookJ_oonfX0n?oo
nfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z0:;ooo]Z0ol0000goookJP03o`000?o:
_/ko000000[oaKcB00?o0000ol6leOo1_=D01_o1_=D2o`0001Ko_KCA00Co0000ok:_eOl0003o0000
8On`ZM400ol0003oWj?HoinSf004o`00017oWikB0_l00007oifHc`03o`000?n>T];oSY;B01_oSY;B
00?o0000ogf<f?l000005omgQ=<01?l0003oIGK?o`000?l0000;odi`e@03o`000?lZF<co:US<00Oo
:US<00?o0000oaYHd?l08jl01?l08jl00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z03Co
oo]Z00?o0000oookJ_oonfX0=_oonfX003Sooo]Z0_l0003ioookJP03o`000?oonf[ooo]Z03Oooo]Z
00?o0000oookJ_oonfX0WooonfX2o`0003Wooo]Z00Go0000olZnc_o:_/kob[k>o`00000:olFldP03
o`000?o1_=Go`KcE00Co`KcE00?o0000okfddOnm]=405_nm]=42o`0002Co/:WA0_l0000CoinNdP;o
00002OnMV<l00ol0003oSY;BohjBdP0KohjBdP;o00006?mgQ=<01?l0003oIGK?oe]bdOmKL]43o`00
00WoCW3E00?o0000obYHc?lZF<`02?lZF<`00olJF=3o02>_o`0S[`02o`0S[`03o`00H_l0003ooo]Z
00_ooo]Z00?o0000oookJ_oonfX0<ooonfX2o`0003Oooo]Z000hoookJP03o`000?oonf[o00000?So
oo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP2KoookJP?o0000>_oonfX00ol0003o
b[k>olZncP03olZncP03o`000?o5_=;oaKcB00SoaKcB00Co0000ol6leOo1_=Go`KcE0_l0000Hokfd
d@03o`000?nj[/ko0000027o/:WA0_l000000on^YLoo0000oinNdP0BoinNdP03o`000?nMV<ooWIS?
00[oWIS?00?o0000ohjBd_n>T]806on>T]800ol0003oMhCCogN4d`0EogN4d`04o`000?mUM/ooIGK?
ofEfc`CoFg;A0_l00007odi`e@03o`000?lZF<co:US<00Wo:US<00?o0000o`0S[ol08jl00_l08jl0
0ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z033ooo]Z0ol000000ooonf[o0000oookJP0f
oookJP00=ooonfX01Ol0003ooo]ZoookJ_oonf[o00000?Oooo]Z00?o0000oookJ_oonfX0>?oonfX0
0ol0003ooo]ZoookJP2IoookJP;o0000??oonfX00ol0003ob[k>olZncP05olZncP03o`000?o5_=;o
aKcB00SoaKcB00?o0000ol6leOl000006?nm]=42o`0000?o^Zk>00?o0000ok2YdOn`ZM407?n`ZM42
o`0000Co[ZG?00?o0000oinNd_nOW]803_nOW]82o`0000goWIS?00?o0000ohjBd_n>T]806on>T]80
0ol0003oMhCCogN4d`0EogN4d`05o`000?mUM/ooIGK?ofEfcol000001OmKL]42o`0000GoCW3E00?o
0000obYHc?lZF<`02OlZF<`00ol0003o02>_o`0S[`03o`0S[`03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX0;OoonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0=OoonfX003Oooo]Z00?o0000
oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP3doookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000
oookJ_oonfX0UOoonfX3o`0003gooo]Z00?o0000olZnc_o:_/h01_o:_/h00ol0003oaKcBolFldP08
olFldP?o00005onm]=400ol0003o^Zk>okZ^cP03okZ^cP03o`000?n`ZM7o/:WA01[o/:WA0_l00006
ojjUc`03o`000?nOW];oWikB00goWikB00?o0000oifHconMV<l03_nMV<l00ol0003oSY;BohjBdP0I
ohjBdP03o`000?n7SM;o000001KoMhCC00?o0000ofEfcomUM/l00_mUM/l7oe]bd@?o00000_m>L=D0
0ol0003o:US<obYHc009obYHc0;o00001?l08jl00ol0003ooo]ZoookJP09oookJP03o`000?oonf[o
oo]Z02[ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z03Gooo]Z000goookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX0looonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z
09;ooo]Z0ol0000ooookJP03o`000?o:_/kob[k>00Sob[k>00?o0000olFld_o5_=801_o5_=801?l0
003o`KC>ol6dc_o1]<h2o`0001Co_KCA00?o0000okZ^c_nj[/h01Onj[/h00ol0003o/:WAok2Yd@0G
ok2Yd@;o00002On^YLl00ol0003oWikBoinNdP0:oinNdP;o00004OnMV<l00ol0003oSY;BohjBdP0I
ohjBdP03o`000?n7SM;o000001KoMhCC00?o0000ofEfcomUM/l00_mUM/l00ol0003oFg;Aoe]bd@07
oe]bd@03o`000?m>L=Go000000_o:US<0_l00004o`0S[`;o00002_oonfX00ol0003ooo]ZoookJP0W
oookJP?o00002_oonfX00ol0003ooo]ZoookJP0eoookJP00=ooonfX00ol0003ooo]ZoookJP04oook
JP03o`000?oonf[ooo]Z0?;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP2?oook
JP;o0000@OoonfX00ol0003ob[k>olZncP0:olZncP03o`000?o5_=;oaKcB00CoaKcB00?o0000ol6d
c_o1]<h01?o1]<h3o`0000oo_KCA0_l00009okZ^cP03o`000?n`ZM7o/:WA01Co/:WA0_l0000;ojjU
c`03o`000?nOW];oWikB00WoWikB00?o0000oifHconMV<l04_nMV<l00ol0003oSY;BohjBdP0GohjB
dP05o`000?n7SM;oQhgBohN=d_l000005OmgQ=<00ol0003oIGK?ofEfc`03ofEfc`03o`000?mKL]7o
Fg;A00SoFg;A0_l0000;obYHc0;o00001?l08jl2o`0000Wooo]Z00?o0000oookJ_oonfX09?oonfX3
o`0000kooo]Z00?o0000oookJ_oonfX0=?oonfX003Oooo]Z00?o0000oookJ_oonfX01OoonfX00ol0
003ooo]ZoookJP3aoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0RooonfX3o`00
04;ooo]Z00?o0000olZnc_o:_/h02oo:_/h00ol0003oaKcBolFldP03olFldP03o`000?o1]<ko`KC>
00So`KC>0_l0000<okfdd@03o`000?nj[/ko^Zk>00Wo^Zk>00?o0000ok2YdOn`ZM404_n`ZM42o`00
00ko[ZG?00?o0000oinNd_nOW]801_nOW]82o`0001GoWIS?00?o0000ohjBd_n>T]805_n>T]800ol0
003oQhgBohN=dP03ohN=dP03o`000?mgQ=?oMhCC017oMhCC00?o0000ofEfcomUM/l01?mUM/l00ol0
003oFg;Aoe]bd@08oe]bd@;o?Ec800?o0000obYHc?lZF<`02?lZF<`00ol0003o03>go`000003o`0S
[`;o00002OoonfX00ol0003ooo]ZoookJP0QoookJP?o00004OoonfX00ol0003ooo]ZoookJP0doook
JP00=ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z0?3ooo]Z00?o0000oookJ_oo
nfX0>ooonfX00ol0003ooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z047ooo]Z0_l0000?olZncP05
o`000?o5_=;oaKcBolFld_l000003Oo1]<h2o`0000So_KCA0_l0000=okZ^cP03o`000?n`ZM7o/:WA
00ko/:WA0ol0000@ojjUc`03o`000?nOW];oWikB00GoWikB00?o0000oifHconMV<l05_nMV<l00ol0
003oSY;BohjBdP0EohjBdP03o`000?n7SM;oQhgB00?oQhgB00?o0000ogN4domgQ=<04OmgQ=<00ol0
003oIGK?ofEfc`05ofEfc`03o`000?mKL]7oFg;A00OoFg;A00?o0000oceLb?lmG<P00_l00008obYH
c004o`000?l3=[So03>go`0000;o02>_0ol00008oookJP03o`000?oonf[ooo]Z01kooo]Z0ol0000D
oookJP03o`000?oonf[ooo]Z03Cooo]Z000foookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oook
J_oonfX0WooonfXPo`00033ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP29oook
JP03o`000?oonf[ooo]Z043ooo]Z00?o0000olZnc_o:_/h04?o:_/h00ol0003oaKcBo`00000@ol6d
cP?o00001?nm]=400ol0003o^Zk>okZ^cP0=okZ^cP03o`000?n`ZM7o/:WA00co/:WA0_l0000CojjU
c`03o`000?nOW];oWikB00CoWikB6_nMV<l00ol0003oSY;BohjBdP09ohjBdQKo00004?mgQ=<00ol0
003oIGK?ofEfc`05ofEfc`03o`000?mKL]7oFg;A00OoFg;A00?o0000oceLb?lmG<P00_lmG<P00ol0
003o:US<obYHc005obYHc005o`000?l3=[So03>go`0c]ol000000_l08jl2o`0000Sooo]Z00?o0000
oookJ_oonfX06ooonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0=?oonfX003Kooo]Z00?o0000oook
J_oonfX02OoonfX00ol0003ooo]ZoookJP2FoookJPSo00002?lP000Co`0000Go@`001?l0000/oook
JP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0R?oonfX2o`00043ooo]Z00?o0000olZn
c_o:_/h04Oo:_/h2o`0001Co`KC>0_l000000onm]=7o0000okZ^cP0@okZ^cP03o`000?n`ZM7o/:WA
00Wo/:WA0_l0000FojjUc`05o`000?nOW];oWikBoinNd_l000006_nMV<l=o`0000_oSXo@00?o0000
ohV7bon9Ql/01On9Ql/3ogf4c`Go00002omgQ=<00ol0003oIGK?ofEfc`05ofEfc`03o`000?mKL]7o
Fg;A00OoFg;A00?o0000oceLb?lmG<P00olmG<P2o`0000Go:US<00?o0000o`<f^?l000000_l0<kL0
1Ol0003o02>_o`000?o=JP3o000000Oooo]Z00?o0000oookJ_oonfX06?oonfX3o`0001[ooo]Z00?o
0000oookJ_oonfX0=?oonfX003Kooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP2@
oookJQGo00002_m?00000ol0003oMP00ogH00005ogH000So00000_m30005o`0002Sooo]Z00?o0000
oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP28oookJP03o`000?oonf[o000003kooo]Z00?o0000
olZnc_o:_/h04Oo:_/h00ol0003oa[K;o`00000Fol6dcP?o00004?nj[/h00ol0003o/:WAok2Yd@07
ok2Yd@;o00006?n^YLl00ol0003oWikBoinNdP0HoifHc`Co00000_nNU//00ol0003oSXo@ohj?d00B
ohj?d003o`000?n9Ql_oRHO;00OoRHO;1ommQ<l4o`0000OoMhCC00?o0000ofEfcomUM/l01_mUM/l0
0ol0003oFg;Aoe]bd@06oe]bd@03o`000?lmG<So?Ec800Go?Ec80_l00003obYHc003o`000?l3=[So
0cJh00?o03>g00Go02>_o`000?l0003ocFX0o`000006oookJP03o`000?oonf[ooo]Z01Gooo]Z0ol0
000MoookJP03o`000?oonf[ooo]Z03Cooo]Z000foookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000
oookJ_oonfX0RooonfX9o`0000[oF`002_l00005odl00003o`000?mf003oMP0000_oMP003_l0000T
oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0QooonfX01?l0003ooo]ZoookJ_l0
000loookJP03o`000?o:_/kob[k>017ob[k>00Go0000olJfboo6]/_oa[K;o`00000Col6dcP03o`00
0?nl[<Wo_:c900;o_:c91?l0000=okZ^cP03o`000?n`ZM7o/:WA00Co/:WA0_l0000HojjUc`Co0000
5OnMV<l4o`0000OoWYK;00?o0000ohj?d?n>Sm004?n>Sm000ol0003oRHO;ohV7b`08ohV7b`03o`00
0?mmQ<ooOHC?00SoOHC?1?l00002ogN4d`03o`000?mUM/ooIGK?00OoIGK?00?o0000oe]bdOmKL]40
1_mKL]400ol0003o?Ec8oceLb007oceLb004o`000?lZF<co:US<o`0000;o0cJh00So0000o`0c]ol0
<kOo03>go`0S[ol0003ocFX0o`0000Kooo]Z00?o0000oookJ_oonfX04_oonfX3o`00023ooo]Z00?o
0000oookJ_oonfX0=?oonfX003Kooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP26
oookJPSo00005omK0009o`0000ooMP000ol00004ofh000Wo00007ooonfX00ol0003ooo]ZoookJP0m
oookJP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0h
oookJP03o`000?o:_/kob[k>017ob[k>00?o0000olJfboo6]//00oo6]//00ol0003o`KC>ol6dcP0?
ol6dcP03o`000?nl[<Wo_:c900Oo_:c91?l0000:okZ^cP04o`000?n`ZM7o/:WAok2Yd@;o00004on^
YLl7o`0000?o[Z7;00?o0000oifHconMV<l03_nMV<l5o`0000_oWYK;00?o0000ohj?d?n>Sm003on>
Sm000ol0003oRHO;ohV7b`09ohV7b`03o`000?mmQ<ooOHC?00goOHC?1?l00008ofEfc`03o`000?mK
L]7oFg;A00CoFg;A00?o0000oceLb?lmG<P02OlmG<P01?l0003o:US<obYHc?l00002o`<f^0Co03>g
00Co0000oleZ0?o=JP3o00001_oonfX00ol0003ooo]ZoookJP0>oookJP?o00008ooonfX00ol0003o
oo]ZoookJP0doookJP00=_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z083ooo]Z
2?l00002oal000;o00003OmK000;o`0000GoN0<F00?o0000oiHN6onF7Q/02?l0000;ogH000?o0000
2?m^0006o`0001_ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP25oookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ob[k>olZncP0AolZncP03o`00
0?o6]/_oa[K;00Goa[K;00?o0000ol6dc_o1]<h03Oo1]<h00ol0003o_:c9okb/b@0<okb/b@Co0000
1_nj[/h01?l0003o/:WAo`000?l0000?ojjUc`Ko00002on^XL/00ol0003oWIS?oifHc`09oifHc`Co
00004OnNU//00ol0003oSXo@ohj?d00=ohj?d003o`000?n9Ql_oRHO;00_oRHO;00?o0000ogf4comm
Q<l03OmmQ<l3og9lcP?o00001OmUM/l00ol0003oFg;Aoe]bd@04oe]bd@03o`000?lmG<So?Ec800_o
?Ec800Go:US<o`000?l3=[So0cJho`000003o`0c]`;o000000?ocFX0o`000?oonfX01OoonfX00ol0
003ooo]ZoookJP0;oookJP?o00009ooonfX00ol0003ooo]ZoookJP0coookJP00=_oonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z07[ooo]Z2Ol00005oal00003o`000?mK003oF`0000;o
F`002ol0000?ogP35P03o`000?nF7Q_oUQhK00CoUQhK0_l00003oi@B0@co00000_mf0003o`0000Wo
KP001Ol0000HoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000olZnc_o:_/h04Oo:_/h00ol0003o
a[K;olJfb`06olJfb`03o`000?o1]<ko`KC>00_o`KC>0_l0000Cokb/b@Co00000_nj[/h2o`0000_o
[ZG?1_l0000BojjQb`03o`000?nMV<ooWIS?00CoWIS?1?l0000EoijFb`03o`000?n>Sm3oSXo@00co
SXo@00?o0000ohV7bon9Ql/03?n9Ql/00ol0003oOHC?ogf4c`0<ogf4c`03o`000?mbO<koLWc>00Co
LWc>0ol00003ofEfc`03o`000?mKL]7oFg;A00?oFg;A00?o0000oceLb?lmG<P03?lmG<P01Ol0003o
0cJho`<f^?l3=[So000000;o03>g0_l00002oleZ0003o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX02?oonfX3o`0002[ooo]Z00?o0000oookJ_oonfX0<ooonfX003Gooo]Z00?o0000oookJ_oo
nfX04?oonfX00ol0003ooo]ZoookJP1foookJPSo00001olO0007o`0001WoN0<F00?o0000oiHN6onF
7Q/01onF7Q/2o`0000goU1812Ol00007ofh000Ko00005OoonfX00ol0003ooo]ZoookJP0ooookJP03
o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0boookJP03
o`000?o:_/kob[k>017ob[k>00?o0000olJfboo6]//02?o6]//00ol0003o`KC>ol6dcP09ol6dcP03
o`000?nl[<Wo_:c901Oo_:c91Ol00003ojjUc`Oo00006?n^XL/00ol0003oWIS?oifHc`04o`0001Wo
WYK;00?o0000ohj?d?n>Sm002on>Sm000ol0003oRHO;ohV7b`0>ohV7b`03o`000?mmQ<ooOHC?00_o
OHC?00?o0000og9lc_mbO<h01ombO<h4o`0000GoFg;A00?o0000oceLb?lmG<P03?lmG<P01OlXBKko
0000o`<f^?l3=[So000000?o03>g0_l000000oo=JP3o0000oookJP04oookJP03o`000?oonf[ooo]Z
00Kooo]Z0_l0000]oookJP03o`000?oonf[ooo]Z03?ooo]Z000eoookJP03o`000?oonf[ooo]Z017o
oo]Z00?o0000oookJ_oonfX0LooonfX6o`0000So7`002?l0000JogP35P03o`000?nF7Q_oUQhK00[o
UQhK0_l0000Boi@B0@Oo00000om^0008o`0001;ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003o
oo]ZoookJP23oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0<?oonfX2o`0001;o
b[k>00?o0000olJfboo6]//02_o6]//00ol0003o`KC>ol6dcP07ol6dcP03o`000?nl[<Wo_:c901Oo
_:c900?o0000okVYbOniZLT00_niZLT4o`0001oo[Z7;0ol0000NoijFb`03o`000?n>Sm3oSXo@00Wo
SXo@00?o0000ohV7bon9Ql/03on9Ql/00ol0003oOHC?ogf4c`0:ogf4c`03o`000?mbO<koLWc>00_o
LWc>0ol00003oe]bd@03o`000?lmG<So?Ec800co?Ec800?o0000obQ9__l000000_l3=[P01ol0003o
03>go`0c]ol0093o0000oleZ0?l000001OoonfX00ol0003ooo]ZoookJP03oookJP?o0000;ooonfX0
0ol0003ooo]ZoookJP0coookJP00=OoonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z
073ooo]Z1?l00008oal000Go00000om?00@01?l0003oN0@GogP45omh11L6o`0001?oN0<F00?o0000
oiHN6onF7Q/03OnF7Q/2o`0001;oU18100?o0000oi/G0?nK5`000_nK5`04o`0000;oSP000_l00002
ohP000?o00004?oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z08;ooo]Z00?o0000
oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0^oookJP04o`000?o?_/[ockk:o`00013ob[k>00?o
0000olJfboo6]//03?o6]//00ol0003o`KC>ol6dcP04ol6dcP;o00006Onl[<T00ol0003o^JW9okVY
b@04okVYb@03o`000?n^XL_o[Z7;01go[Z7;0_l000000on/W/Wo0000oijFb`0NoijFb`03o`000?n>
Sm3oSXo@00SoSXo@00?o0000ohV7bon9Ql/04?n9Ql/00ol0003oOHC?ogf4c`0:ogf4c`03o`000?mb
O<koLWc>00coLWc>00Ko0000of1acOl0003o0000oe]bdOl0000>oceLb006o`000?lXBKko:4Vno`00
0?l3=[So00000_l0<kL3o`000003oleZ0?l0003ooo]Z00?ooo]Z00?o0000oookJ_oonfX00ol0000b
oookJP03o`000?oonf[ooo]Z03?ooo]Z000eoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX0K?oonfX3o`0000Oo7`001Ol00007odl01003o`000?mh11OoN0@G00SoN0@G1Ol00008ogP3
5Q7o00001onF7Q/2o`00017oU1810_l000000onK5`3o0000ojXX2003ojXX20?o000000?oSP00o`00
0?n800000on80002o`0000kooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP22oook
JP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ockk:olnnbP02olnn
bP03o`000?o:_/kob[k>00cob[k>00?o0000olJfboo6]//03Oo6]//00ol0003o`KC>ol6dcP03ol6d
cP03o`000?nl[<Wo_:c901Oo_:c90_l00008okVYb@03o`000?n^XL_o[Z7;01Wo[Z7;0ol00004ojbN
b@03o`000?nNU/_oWYK;01goWYK;00?o0000ohj?d?n>Sm001on>Sm000ol0003oRHO;ohV7b`0AohV7
b`03o`000?mmQ<ooOHC?00SoOHC?00?o0000og9lc_mbO<h03_mbO<h01?l0003oH77=of1acOmPLLd2
o`0000go?Ec800Co0000obQ9__lXBKko:4Vn0_l00002o`0c]`;o000000?okYPVo`000?l000001?oo
nfX3o`0003Gooo]Z00?o0000oookJ_oonfX0<ooonfX003Gooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP1YoookJP;o00001OlO0006o`0000[oC`0400?o0000ogP45omh11L02omh11L;
o`0000GoSBHk00?o0000oj4j@onQ>T<02OnQ>T<>o`0000koU18100?o0000ojXX2?nZ:0P01_nZ:0P4
o`0000CoR0000_l0000<oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0POoonfX0
0ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000olnnb_o?_/X01?o?_/X0
0ol0003ob[k>olZncP0:olZncP03o`000?o6]/_oa[K;00ooa[K;00Go0000ol6dc_o1]<ko`KC>o`00
000Iokb/b@03o`000?niZLWo^JW900So^JW900?o0000ojjQbon^XL/05on^XL/2o`0000Oo[9k900?o
0000oijFbonNU//07OnNU//00ol0003oSXo@ohj?d006ohj?d003o`000?n9Ql_oRHO;01;oRHO;00?o
0000ogf4commQ<l02?mmQ<l00ol0003oLWc>og9lcP0>og9lcP04o`000?mPLLgoH77=of1ac@;oEfC4
00?o0000oceLb?lmG<P02_lmG<P00ol0003o:4VnobQ9_P02obQ9_P;o00000_l0<kL01?l0003okYPV
o`000?o=JP05o`0003Oooo]Z00?o0000oookJ_oonfX0<ooonfX003Gooo]Z00?o0000oookJ_oonfX0
5OoonfX00ol0003ooo]ZoookJP1VoookJP?o000000?o7`00o`000?l000001_l0000<odl01004o`00
0?mh11OoN0@GogP45`_o00001on<:D82o`0000KoSBHk00?o0000oj4j@onQ>T<05?nQ>T<01?l0003o
ZS`hojXl>?nZ?3P9o`0000CoU18100?o0000ojX[4?l000002_nZ:0P3o`0000CoR0000_l0000:oook
JP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0P?oonfX00ol0003ooo]ZoookJP0;oook
JP03o`000?oonf[ooo]Z02Sooo]Z00?o0000olnnb_o?_/X01_o?_/X2o`0000Wob[k>00?o0000olJf
boo6]//04Oo6]//00ol0003o`KC>o`00000Hokb/b@;o00003?niZLT00ol0003o[Z7;ojjQb`0DojjQ
b`;o00002On/W/T00ol0003oWYK;oijFb`0NoijFb`03o`000?n>Sm3oSXo@00CoSXo@00?o0000ohV7
bon9Ql/04on9Ql/00ol0003oOHC?ogf4c`07ogf4c`03o`000?mbO<koLWc>013oLWc>00Co0000of1a
cOmPLLgo00000_mGI<@2o`0000[o?Ec800?o0000obQ9__lXBKh00olXBKh01?l0003o03>go`0c]ol0
0002onjH9P;o00000ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z03?ooo]Z000d
oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0HooonfX:o`0000goC`041ol0000D
oh`Y@P?o00000on=9S/00ol0003oXCY3oj4j@`0Eoj4j@`03o`000?nZ?3SoZS`h00WoZS`h1_l00000
0onZ:a3o0000ojXX200;ojXX20?o00000_n80003o`0000Sooo]Z00?o0000oookJ_oonfX0@ooonfX0
0ol0003ooo]ZoookJP1ooookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX09_oonfX0
0ol0003ockk:olnnbP09olnnbP03o`000?o:_/kob[k>00Gob[k>00?o0000olJfboo6]//04_o6]//2
o`0001So_:c900?o0000okVYbOniZLT03?niZLT00ol0003o[Z7;ojjQb`0BojjQb`;o00003?n/W/T0
0ol0003oWYK;oijFb`0MoijFb`03o`000?n>Sm3oSXo@00?oSXo@00?o0000ohV7bon9Ql/05On9Ql/0
0ol0003oOHC?ogf4c`06ogf4c`03o`000?mbO<koLWc>013oLWc>00Co0000of1acOmPLLgo00001?mG
I<@00ol0003o?Ec8oceLb006oceLb003o`000?lXBKko:4Vn00Go:4Vn00Go0000o`0c]ol0003o0000
onjH9P03o`0000;ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0coookJP00=?oo
nfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z063ooo]Z2?l0000>odl010?o00000_mY
23D00ol0003oS2U2oh`Y@P0Ioh`Y@P;o000000?oSBHko`000?nQ>T<05onQ>T<00ol0003oZS`hojXl
>00;ojXl>003o`000?njCSoo^Tho00?o00003?nZ:0P01?l0003o/R/0o`000?l00002ohP000Co0000
1OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z07kooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?o?_/[ockk:00_ockk:00?o0000olZnc_o:_/h0
0oo:_/h00ol0003oa[K;olJfb`0BolJfb`03o`000?o2/<So000001Oo_:c900?o0000okVYbOniZLT0
3_niZLT00ol0003o[Z7;ojjQb`0>ojjQb`?o00003_n/W/T00ol0003oWYK;oijFb`0MoijFb`03o`00
0?n>Sm3oSXo@00;oSXo@00?o0000ohV7bon9Ql/05_n9Ql/00ol0003oOHC?ogf4c`05ogf4c`03o`00
0?mbO<koLWc>017oLWc>00?o0000of1acOl000001_mGI<@2o`0000Ko?Ec800?o0000obQ9__lXBKh0
1OlXBKh4o`0000;okYPV0_l00002oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0
<_oonfX003Cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP1MoookJPOo00003Om?
00@4o`0000CoJ@Pe00?o0000oh`Y@_n<:D807?n<:D82o`0001WoXCY300?o0000ojXl>?nZ?3P02OnZ
?3P00ol0003o^ThookY>?`04okY>?`?o00002_nZ:0P00ol0003o/R/0ok8[0003o`000003ohP00?l0
003oP@0000;o00000ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z07kooo]Z00?o
0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?o?_/[ockk:00gockk:00Go
0000olZnc_o:_/kob[k>o`00000DolJfb`05o`000?o2/<So`[38ol:`b?l000005?nl[<T2o`00017o
^JW900?o0000ojjQbon^XL/03?n^XL/2o`0001;o[9k900?o0000oijFbonNU//07OnNU//01?l0003o
SXo@ohj?d?l0000JohV7b`03o`000?mmQ<ooOHC?00CoOHC?00?o0000og9lc_mbO<h04_mbO<h2o`00
00SoEfC40_l00004oceLb003o`000?lXBKko:4Vn00Ko:4Vn00?o0000o`0c]ol000000oo^V2H01?l0
003ooo]ZoookJ_l0000hoookJP03o`000?oonf[ooo]Z03;ooo]Z000doookJP03o`000?oonf[ooo]Z
01[ooo]Z00?o0000oookJ_oonfX0FooonfX5o`000003o`T00?l0003oC`0400WoC`041?l00008ofT8
=@03o`000?n<:D;oS2U201coS2U200?o0000oj0jA?l000006OnQ>T<00ol0003oZS`hojXl>008ojXl
>003o`000?njCSoo^Tho00Co^Tho00?o0000ol5A=_o1DCH00ol00008ojXX2003o`000?nb:`3o/R/0
00;o/R/01?l000001On1003o0000o`000?oonf[o000004Oooo]Z00?o0000oookJ_oonfX0OOoonfX0
0ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000olnnb_o?_/X03oo?_/X0
0ol0003ob[k>o`00000DolJfb`03o`000?o2/<So`[3800?o`[3800?o0000okb/bOnl[<T04?nl[<T0
0ol0003o^JW9okVYb@0AokVYb@03o`000?n^XL_o[Z7;00[o[Z7;0_l0000DojbNb@03o`000?nNU/_o
WYK;01goWYK;00?o0000ohj?d?l000006on9Ql/00ol0003oOHC?ogf4c`03ogf4c`03o`000?mbO<ko
LWc>01?oLWc>0_l0000:oeMTa005o`000?lmG<So?Ec8oceLb?l000002?lXBKh00ol0003o4SZho`00
0003onjH9P;o00000_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z03;ooo]Z000d
oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0F?oonfX5o`0000;o2@0000?o0000
odl01?m?00@01_m?00@3o`0000_oJ@Pe00?o0000oh`Y@_n<:D807?n<:D801Ol0003oX3Y4oj0jA?nP
>TCo000001WoXCY300?o0000ojXl>?nZ?3P01_nZ?3P00ol0003o^ThookY>?`06okY>?`03o`000?o1
DCKo`E4f00;o`E4f1?l00005ojXX2003o`000?nb:`3o/R/000?o/R/00ol00002oh4000;o0000Aooo
nfX00ol0003ooo]ZoookJP1moookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX07_oo
nfX00ol0003ockk:olnnbP0AolnnbP;o00004oo6]//00ol0003o`[38ol:`b004ol:`b003o`000?nl
[<Wo_:c900oo_:c900?o0000okVYbOniZLT04oniZLT00ol0003o[Z7;ojjQb`07ojjQb`;o00005on/
W/T00ol0003oWYK;oijFb`0MoijFba3o00003On9Ql/00ol0003oOHC?ogf4c`03ogf4c`03o`000?mb
O<koLWc>01CoLWc>00?o0000oeMTa?mGI<@02OmGI<@2o`000003oceLb?l0003o:4Vn00Oo:4Vn00?o
0000oa8j^?l000001?o^V2H01?l0003ooo]ZoookJ_l0000goookJP03o`000?oonf[ooo]Z03;ooo]Z
000doookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0EOoonfX5o`0000?o2@0000?o
0000odl01?m?00@00om?00@4o`0000koJ@Pe00?o0000oh`Y@_n<:D805on<:D8Bo`0001;oXCY300?o
0000ojXl>?nZ?3P01OnZ?3P00ol0003o^ThookY>?`07okY>?`03o`000?o1DCKo`E4f00Go`E4f1?l0
0002ojXX2003o`000?nb:`3o/R/000Go/R/00_l000000on1003o0000o`000017oookJP03o`000?oo
nf[ooo]Z07cooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0LoookJP;o00004_o?
_/X01?l0003obkK6ol^fa_l0000AolJfb`03o`000?o2/<So`[3800Ko`[3800?o0000okb/bOnl[<T0
3?nl[<T2o`0001Ko^JW900?o0000ojjQbon^XL/01On^XL/2o`0001Wo[9k900?o0000oijFbonNU//0
6onNU//00ol0003oWYK;ohn8b00?ohn8b1Go00005OmbO<h>oeMTa003oceLb?l0003o:4Vn00So:4Vn
0ol00003onjH9P;o000000?ooo]Zo`000?oonfX0=_oonfX00ol0003ooo]ZoookJP0boookJP00<ooo
nfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z05;ooo]Z1Ol00004o`T00003o`000?m?
00CoC`0400Co00004OmY23D00ol0003oS2U2oh`Y@P0=oh`Y@P_o00001OnD?el00ol0003oZU9RojYB
HP02ojYBHP03o`000?n^Deco[U=L00Go[U=L3_l00005oj4j@`03o`000?nZ?3SoZS`h00CoZS`h00?o
0000okY>?onjCSl02?njCSl00ol0003o`E4fol5A=P08ol5A=PCo00002?nb:`05o`0004Kooo]Z00?o
0000oookJ_oonfX0NooonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z01[ooo]Z00Co
0000om6nb?oA_/So00004?o?_/X00ol0003obkK6ol^faP02ol^faP;o00003_o6]//00ol0003o`[38
ol:`b007ol:`b003o`000?nl[<Wo_:c900_o_:c900?o0000okVYbOniZLT05oniZLT00ol0003o[Z7;
ojjQb`02ojjQb`;o00006on/W/T00ol0003oWYK;oijFb`0GoijFb`Go00000_nKS/DMohn8b004o`00
0?mnP/coOX;<ogj2c0?oNgW60ol0000Aog9lcP03o`000?mUKLKoEfC400goEfC40_l00008obQ9_P?o
00000oo^V2H2o`000003oookJ_l0003ooo]Z03Kooo]Z00?o0000oookJ_oonfX0<_oonfX003?ooo]Z
00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP1?oookJPCo00001_l90004o`0001GoJ@Pe
00?o0000oh`Y@_n<:D800_n<:D8;o`00013oU3mO00?o0000ojYBH_nZDV800onZDV800ol0003o[U=L
ojiCG00BojiCG0ko00002_njCSl00ol0003o`E4fol5A=P0:ol5A=P?o00001onb:`03o`000003oh40
0?l0003o000004Cooo]Z00?o0000oookJ_oonfX0N_oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Sooo]Z00?o0000om6nb?oA_/P00_oA_/P00ol0003ockk:olnnbP0<olnnbP03o`00
0?o;]/KobkK600GobkK60_l0000;olJfb`03o`000?o2/<So`[3800Wo`[3800?o0000okb/bOnl[<T0
2Onl[<T00ol0003o^JW9okVYb@0HokVYb@04o`000?n^XL_o[Z7;o`0001oo[9k900?o0000oijFbonN
U//04_nNU//4o`000003oijDbOl0003o000000CoVhk500?o0000ohn8b?n?R<P06on?R<P00ol0003o
OX;<o`000006og]iaPCo00003OmbO<h00ol0003oIFg6o`00000=oeMTa0;o=dZi00?o0000obQ9__lX
BKh01OlXBKh3o`0000CokYPV00?o0000oookJ_l00000=ooonfX00ol0003ooo]ZoookJP0boookJP00
<ooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z04cooo]Z1?l00006o`T000?o0000
5_mY23D7o`0001[oU3mO00?o0000ojYBH_nZDV801?nZDV800ol0003o[U=LojiCG00HojiCG003o`00
0?ndF5co]5QL00;o]5QL00?o0000okeQGOnmHEd01?l00006okY>?`03o`000?o1DCKo`E4f00_o`E4f
00?o0000olE<7ol000000_l00005ok8[0003o`000?nW6@3o000000?o0000A?oonfX00ol0003ooo]Z
oookJP1ioookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003odKk8
om6nb004om6nb003o`000?o?_/[ockk:00[ockk:00?o0000ol^fa_o;]/H02?o;]/H00ol0003oa[K;
olJfb`07olJfb`03o`000?o2/<So`[3800_o`[3800?o0000okb/bOnl[<T01_nl[<T2o`0001_o^JW9
0_l0000QojbNb@03o`000?nNU/_oWYK;00goWYK;1Ol00003oijDb@;o00001_nKS/D00ol0003oShS8
ohn8b00Kohn8b003o`000?mnP/co000000[oNgW60ol00009og9lcP04o`000?mUKLKoIFg6o`0000go
EfC400Co0000ocM:^OlgB[Wo00001olXBKh3o`0000?okYPV0ol0000goookJP03o`000?oonf[ooo]Z
03;ooo]Z000coookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0BOoonfX4o`0000Ko
2@000_l000000olg01co0000ofT8=@0CofT8=@?o000000?oO2UHo`000?nD?el07_nD?el00ol0003o
ZU9RojYBHP05ojYBHP03o`000?n^Deco[U=L01So[U=L00Go0000okAHG?ndF5co]5QLo`000006okeQ
G@Co00000onjCSl00ol0003o`E4fol5A=P0;ol5A=P04o`000?o5C1ooaD`OolE<7`;o00000onb:`02
o`0000?oYaT00ol00013oookJP03o`000?oonf[ooo]Z07Sooo]Z00?o0000oookJ_oonfX05_oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oA_/SodKk800KodKk800?o0000olnnb_o?_/X02?o?_/X0
0ol0003obkK6ol^faP0:ol^faP;o00001_o6]//00ol0003o`[38ol:`b00<ol:`b003o`000?nl[<Wo
_:c900Go_:c900?o0000okVYbOniZLT06_niZLT00ol0003o]Z?5ojbNb@0RojbNb@03o`000?nNU/_o
WYK;00SoWYK;1?l00006oijDb@;o00002OnKS/D00ol0003oShS8ohn8b00John8b0;o00003_mkNLH4
o`0000GoLWc>00Go0000ofE]a_mUKLKoIFg6o`00000;oeMTa003o`000?lgB[Wo=dZi00;o=dZi00?o
0000obQ9__lXBKh01?lXBKh3o`0000?okYPV0ol0000hoookJP03o`000?oonf[ooo]Z037ooo]Z000c
oookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0AooonfX3o`0000Ko2@000_l00002
ocL07003o`000?mY23GoJ@Pe013oJ@Pe0ol00004og`YF003o`000?nD?eooU3mO01goU3mO00?o0000
ojYBH_nZDV801OnZDV800ol0003o[U=LojiCG00IojiCG004o`000?ndF5co]5QLo`0000[o_F5M1Ol0
000=ol5A=P03o`000?o5C1ooaD`O00;oaD`O1?l000000onb:`3o0000ojLI0003ojLI00;o0000@_oo
nfX00ol0003ooo]ZoookJP1hoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX04_oo
nfX00ol0003odKk8om6nb008om6nb003o`000?o?_/[ockk:00Kockk:00?o0000ol^fa_o;]/H03Oo;
]/H2o`0000?oa[K;00?o0000ol:`b?o2/<P03_o2/<P00ol0003o_:c9okb/b@02okb/b@;o00006oni
ZLT2o`0000?o]Z?58_n/W/T00ol0003oWYK;oijFb`04oijFb`Co00002?nNU<T2o`0000_oVhk500?o
0000ohn8b?n?R<P06On?R<P00ol0003oRH;5og]iaP0Bog]iaP?o00000_mbO<h01Ol0003oIFg6ofE]
a_mUKLKo000000_oEfC400?o0000ocM:^OlgB[T00olgB[T00ol0003o:4VnobQ9_P03obQ9_P04o`0J
X_l0003oo;EJo`0000;okYPV0ol0000hoookJP03o`000?oonf[ooo]Z037ooo]Z000coookJP03o`00
0?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0AOoonfX2o`0000Ko2@000_l00004ocL07003o`00
0?mY23GoJ@Pe00goJ@Pe0ol00007og`YF003o`000?nD?eooU3mO01goU3mO00?o0000ojYBH_nZDV80
1_nZDV800ol0003o[U=LojiCG00HojiCG003o`000?ndF5co000000oo_F5M1?l0000;ol5A=P03o`00
0?o5C1ooaD`O00CoaD`O0_l000000onb:`3o0000ojLI0004ojLI00;o0000@OoonfX00ol0003ooo]Z
oookJP1goookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003odKk8
om6nb009om6nb003o`000?o?_/[ockk:00Gockk:00?o0000ol^fa_o;]/H04?o;]/H00ol0003oa[K;
o`00000Aol:`b005o`000?nl[<Wo_:c9okb/bOl000007?niZLT00ol0003o]Z?5okJSa@03okJSaB;o
[9k900?o0000oijFbonNU//01?l0000:oijDb@;o00003_nKS/D00ol0003oShS8ohn8b00Gohn8b004
o`000?n9P/GoRH;5ohV2aAGoNgW60ol00003ofE]aP03o`000?mGI<CoEfC400WoEfC400?o0000ocM:
^OlgB[T01?lgB[T00ol0003o:4VnobQ9_P02obQ9_P;o00000_ol]EX01Ol0003okYPVo`000?oLS`So
000003Sooo]Z00?o0000oookJ_oonfX0<OoonfX003?ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0
003ooo]ZoookJP12oookJP;o00001_l90002o`0000Go=`0L00?o0000ofT8=OmY23D02omY23D3o`00
00WoO2UH00?o0000oi@oGonD?el07_nD?el00ol0003oZU9RojYBHP06ojYBHP03o`000?n^Deco[U=L
01Wo[U=L0_l0000@okeQG@03o`000?o9JESobFUH00?o00002Oo1DCH00ol0003oaD`OolE<7`03olE<
7`03o`000?o5C1oo000000;o00001OnW6@02o`00043ooo]Z00?o0000oookJ_oonfX0MooonfX00ol0
003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000om6nb?oA_/P02ooA_/P00ol0
003ockk:olnnbP03olnnbP03o`000?o;]/KobkK601;obkK60_l0000Bol:`b003o`000?nl[<Wo0000
01co^JW900?o0000okJSaOnfXlD01OnfXlDQojbNb@?o00003?nNU<T2o`00013oVhk500?o0000ohn8
b?n?R<P05_n?R<P00ol0003oRH;5ohV2a@02ohV2a@03o`000?mkNLKoNgW601?oNgW60_m_L<<2o`00
00;oIFg600?o0000oeMTa?mGI<@02?mGI<@00ol0003o=dZiocM:^@05ocM:^@04o`000?lXBKko:4Vn
obQ9_P;o00000_ol]EX00ol0003okYPVonjH9P02o`0003Sooo]Z00?o0000oookJ_oonfX0<OoonfX0
03;ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP10oookJP03o`000?l9003o2@00
00Co2@000_l00007ocL07003o`000?mY23GoJ@Pe00SoJ@Pe0ol0000<og`YF003o`000?nD?eooU3mO
01goU3mO00?o0000ojYBH_nZDV802?nZDV800ol0003o[U=LojiCG00IojiCG003o`000?nmHEgo_F5M
00oo_F5M00?o0000olUYF?o9JEP00_o9JEP4o`0000Go`E4f00?o0000olE<7oo5C1l00oo5C1l00ol0
003oaD`OolE<7`02olE<7`;o00001?nW6@02o`00043ooo]Z00?o0000oookJ_oonfX0M_oonfX00ol0
003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z00cooo]Z0_l0000>om6nb005o`000?o?_/[ockk:
olnnb_l000004oo;]/H01?l0003oa[76olJaa_o6/LH3o`0000oo`[380_l0000KokVYb@;o00002?nf
XlD00ol0003o[9k9ojbNb@0LojbNb@;o000000?oZY_6o`000?nNU<T02_nNU<T2o`0001;oVhk500?o
0000ohn8b?n?R<P05On?R<P00ol0003oRH;5ohV2a@03ohV2a@03o`000?mkNLKoNgW601;oNgW600?o
0000ofm``om_L<<00_m_L<<00ol0003oIFg6o`000009oeMTa003o`000?lgB[Wo=dZi00Oo=dZi00?o
0000obQ9__lXBKh00_l00003oobeFP03o`000?o^V2Ko000000;o0000=ooonfX00ol0003ooo]Zoook
JP0aoookJP00<_oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z03gooo]Z0_l00005
o`T000;o00002Olg01`01?l0003oJ@PeofT8=OmY23D?o`0000OoO2UH00?o0000oi@oGonD?el06OnD
?el;o`0000CoZU9R00?o0000ojiCG?n^De`06On^De`00ol0003o_F5MokeQG@0?okeQG@03o`000?o9
JESobFUH00KobFUH1?l00002ol5A=P03o`000?o5C1ooaD`O00;oaD`O00?o0000olE<7oo5C1l00_o5
C1l01?l0003obe0Do`000?l00003ojLI0003o`000?n/8@3o000003oooo]Z00?o0000oookJ_oonfX0
MOoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000omJn`ol00000
3_oA_/P00ol0003ockk:o`00000Col^faP03o`000?o6/LKoa[7600Goa[760_l0000<ol:`b003o`00
0?o0[<Go000001[o^JW900?o0000okJSaOnfXlD02OnfXlDKojbNb@?o00001?nZVlH00ol0003oWYC9
oijDb@06oijDb@;o00005OnKS/D00ol0003oShS8ohn8b00Cohn8b003o`000?n9P/GoRH;500GoRH;5
00?o0000og]ia_mkNLH04?mkNLH00ol0003oKg33ofm```04ofm```;o00002OmGI<@00ol0003o=dZi
ocM:^@08ocM:^@04o`000?lXBKko0000o`0000?oo;EJ00?o0000onjH9_l000000_l0000goookJP03
o`000?oonf[ooo]Z037ooo]Z000boookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0
>ooonfX3o`0000?o2@000_l00009ocL070Wo00003?ml:UX8o`0001CoU3mO1ol00004oiiEMP03o`00
0?n_HgOo[f=g00Co[f=g4ol0000<ojiCG0;o00004_nmHEd00ol0003obFUHolUYF009olUYF0Co0000
0oo5C1l00ol0003oaD`OolE<7`03olE<7`03o`000?o;D1Cobe0D00;o00000_nW6@000ol0003o[240
o`00000noookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]Z
oookJP09oookJP05o`000?oF_/?oe[k3omJn`ol000003OoA_/P2o`0001?obkK600?o0000olJaa_o6
/LH02?o6/LH3o`0000So`[3800Go0000ol2/aOo0[<Go`:c5o`00000GokVYb@;o00003?nfXlD00ol0
003o[9k9ojbNb@0FojbNb@;o00001onZVlH00ol0003oWYC9oijDb@04oijDb@;o00005onKS/D00ol0
003oShS8ohn8b00Bohn8b003o`000?n9P/GoRH;500KoRH;500?o0000og]ia_mkNLH04?mkNLH00ol0
003oKg33ofm```06ofm```;o00001omGI<@00ol0003o=dZiocM:^@09ocM:^@03obQ9__l0003o0000
00Coo;EJ1?l0000goookJP03o`000?oonf[ooo]Z037ooo]Z000boookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0>OoonfX3o`0000;o2@000_l0000:ocL070Go00006?ml:UX2o`0000co
U3mO1ol0000;oiiEMP03o`000?n_HgOo[f=g00Wo[f=g00?o0000okAVM_ndIWH02ondIWH?o`00017o
_F5M00?o0000olUYF?o9JEP03?o9JEP3o`000003olE<7ol0003oaD`O00GoaD`O00Co0000ol]@5?o;
D1Cobe0D0_l000001OnW6@3o0000oj`Q0?n/8@3o000003gooo]Z00?o0000oookJ_oonfX0LooonfX0
0ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000omJn`ooF_/<00ooF_/<0
0ol0003odKk8om6nb009om6nb003o`000?o=^<Go000001;obkK600?o0000olJaa_o6/LH03?o6/LH2
o`0000Go`[3800?o0000ol2/aOo0[<D00oo0[<D00ol0003o^JW9okVYb@0CokVYb@03o`000?nfXlGo
]Z?500go]Z?55_n/W/T2o`0000[oZY_600Co0000oijDbOnNU<WoWYC90_l0000Joi^>a@03o`000?n?
R<SoShS800ooShS80_l00009ohV2a@03o`000?mkNLKoNgW600ooNgW600?o0000ofm``om_L<<01om_
L<<01?l0003oFf?2o`000?l00005oeMTa003o`000?lgB[Wo=dZi00[o=dZi0_l00005oobeFP04o`00
0?oLS`So0000o`0003Kooo]Z00?o0000oookJ_oonfX0<OoonfX003;ooo]Z00?o0000oookJ_oonfX0
:_oonfX00ol0003ooo]ZoookJP0goookJP?o000000?o2@00o`000?l000002_lg01`3o`000003oe@6
B_l0003oO2YJ01SoO2YJ00Co0000oi@oGonD?eoo00001?nD?el7o`0001;oWUEf00?o0000ojmSMon_
HgL02On_HgL00ol0003o]6IfokAVMP0GokAVMP03o`000?noLGKo000000?o00003onmHEd00ol0003o
bFUHolUYF00<olUYF004o`000?oAK4ko0000o`0000OoaD`O00Co0000ol]@5?o;D1Cobe0D1ol0000m
oookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP05
oookJP03o`000?oF_/?oe[k300Goe[k300?o0000om6nb?oA_/P01ooA_/P01Ol0003ocKS5olfhaOo=
^<Go0000013obkK600?o0000olJaa_o6/LH03oo6/LH3o`000003ol:`b?l0003o`:c500Go`:c500?o
0000okVYbOniZLT04_niZLT00ol0003o]Z?5okJSa@0>okJSa@03o`000?n/W/Wo[9k9017o[9k90_l0
000<ojZKaP04o`000?nNU<Wo0000o`0001coVhk500?o0000ohn8b?n?R<P03_n?R<P00ol0003oRH;5
ohV2a@0:ohV2a@03o`000?mkNLKoNgW600koNgW600?o0000ofm``om_L<<02?m_L<<00ol0003oFf?2
oe]S`P02o`0000?oEfC400?o0000ocM:^OlgB[T02_lgB[T2o`0000Goo;EJ1?l0000goookJP03o`00
0?oonf[ooo]Z033ooo]Z000boookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0=Ooo
nfX5o`0000_o=`0L0_l00003oe@6BP03o`000?ml:U[oO2YJ01GoO2YJ2_l0000IoiiEMP03o`000?n_
HgOo[f=g00Wo[f=g00?o0000okAVM_ndIWH05ondIWH00ol0003o_g5fo`000003olEeM0Go00002_nm
HEd00ol0003obFUHolUYF00=olUYF003o`000?oAK4ko000000?o00001Oo5C1l00ol0003obe0Do`00
0003olmF60;o000000CoZQl0o`000?l0003o0000>ooonfX00ol0003ooo]ZoookJP1boookJP03o`00
0?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003oe[k3omJn``07omJn``03o`00
0?oA_/SodKk800GodKk800?o0000olfhaOo=^<D00oo=^<D00ol0003obkK6ol^faP0<ol^faP03o`00
0?o6/LKoa[7601?oa[760ol00006ol2/a@03o`000?niZLWo^JW900oo^JW90_l0000BokJSaA3o[9k9
0ol0000=ojZKaP?o00007_nKS/D00ol0003oShS8ohn8b00=ohn8b003o`000?n9P/GoRH;500_oRH;5
00?o0000og]ia_mkNLH03OmkNLH00ol0003oKg33ofm```09ofm```03o`000?mKHl;oFf?200;oFf?2
00?o0000oeMTa?l000003OlgB[T00olQ=:co0000oobeFP05oobeFP?o0000=ooonfX00ol0003ooo]Z
oookJP0`oookJP00<OoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z03?ooo]Z1?l0
000;ocL070;o00001?mD1TX00ol0003oO2YJog`ZFP0Cog`ZFP?o00000_n7@W<01Ol0003oW5AfoiaD
M_nLE7Ko000001coWUEf00?o0000ojmSMon_HgL02_n_HgL00ol0003o]6IfokAVMP0FokAVMP03o`00
0?noLGKo000000SoaGEd1Ol00006okeQG@03o`000?o9JESobFUH00cobFUH00?o0000om5/C_l00000
0ooAK4h2o`0000CoaD`O00?o0000olmF6?o?EQP01?o?EQP01Ol0003oZQl0ojXO0?nZ7`3o000003_o
oo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000omJn`ooF_/<02?oF_/<00ol0003odKk8om6nb003om6nb003o`000?o=^<GocKS500Co
cKS500?o0000ol^fa_o;]/H02oo;]/H00ol0003oa[76olJaaP0ColJaaP04o`000?o1Z<7o`JS1ol6X
`@Co00000_o0[<D00ol0003o^JW9okVYb@0>okVYb@03o`000?nfXlGo]Z?501;o]Z?500?o0000ojbN
bOn/W/T02on/W/T2o`0000_oZY_61Ol00002ojVE`@03o`000?nKS/GoVhk501goVhk500?o0000ohn8
b?n?R<P02on?R<P00ol0003oRH;5ohV2a@0=ohV2a@03o`000?mkNLKoNgW600_oNgW600?o0000ofm`
`om_L<<02_m_L<<00ol0003oFf?2oe]S`P04oe]S`P;o00002olgB[T00ol0003o8CB/o`000006oobe
FP?o0000=ooonfX00ol0003ooo]ZoookJP0`oookJP00<OoonfX00ol0003ooo]ZoookJP0^oookJP03
o`000?oonf[ooo]Z037ooo]Z0ol0000<ocL070;o00001OmD1TX00ol0003oO2YJog`ZFP0?og`ZFPCo
00001On7@W<01Ol0003oW5AfoiaDM_nLE7Ko000001coWUEf00?o0000ojmSMon_HgL02_n_HgL00ol0
003o]6IfokAVMP0FokAVMP03o`000?noLGKo000000goaGEd1Ol000000onmHEgo0000olUYF00>olUY
F0;o00001OoAK4h2o`000003olE<7ol0003o000000OoceHH0_l000000onZ7`3o0000oookJP0joook
JP03o`000?oonf[ooo]Z077ooo]Z00?o0000oookJ_oonfX08_oonfX01?l0003ooo]ZoookJ_l0000<
omJn``05o`000?oA_/SodKk8om6nb?l000002?o=^<D00ol0003obkK6ol^faP09ol^faP03o`000?o6
/LKoa[7601?oa[7600?o0000ol6X`Oo1Z<401_o1Z<44o`0000go^JW90_l0000FokJSa@_o[9k90_l0
0008ojZKaPGo00002?nYUL400ol0003oVhk5oi^>a@0Loi^>a@03o`000?n?R<SoShS800[oShS800?o
0000ohV2aOn9P/D03_n9P/D00ol0003oNgW6og]iaP0;og]iaP03o`000?m_L<?oKg3300_oKg3300?o
0000oe]S`_mKHl800omKHl82oe=F]`03o`000?lgB[Wo=dZi00So=dZi00?o0000ob4d[?l000001_ol
]EX2o`000003omb?2?l0003ooo]Z03Gooo]Z00?o0000oookJ_oonfX0<?oonfX0037ooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0_oookJPCo00002_lg01`2o`0000OoE0I:00?o0000
og`ZF_ml:UX02oml:UX4o`0000WoQd9c00?o0000oiaDM_nLE7H00_nLE7H00ol0003oWUEfoiiEMP0I
oiiEMP03o`000?n_HgOo[f=g00[o[f=g00?o0000okAVM_ndIWH05_ndIWH01?l0003o_g5fokmaM_l0
000AolEeM0Go00003?o9JEP2o`0000OodFa>1?l00006olmF6004o`000?oBF0;o0000ojXO00;o0000
>_oonfX00ol0003ooo]ZoookJP1`oookJP03o`000?oonf[ooo]Z02?ooo]Z0_l0000>omJn``03o`00
0?oA_/So000000[ocKS500?o0000ol^fa_o;]/H01oo;]/H00ol0003oa[76olJaaP0ColJaaP03o`00
0?o1Z<7o`JS100[o`JS11Ol00008okVYb@03o`000?nfXlGo]Z?501Ko]Z?500?o0000ojbNbOn/W/T0
1_n/W/T2o`0000GoZY_61Ol0000=ojVE`@03o`000?nKS/GoVhk501goVhk500?o0000ohn8b?n?R<P0
2?n?R<P00ol0003oRH;5ohV2a@0?ohV2a@03o`000?mkNLKoNgW600[oNgW600?o0000ofm``om_L<<0
3?m_L<<00ol0003oFf?2oe]S`P02oe]S`P05o`000?mCE[OoDeJgoe=F]ol000002OlgB[T00ol0003o
8CB/o`000006oobeFP;o000000?og8l8o`000?oonfX0=OoonfX00ol0003ooo]ZoookJP0`oookJP00
<OoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02gooo]Z1?l00009ocL070;o0000
2?mD1TX00ol0003oO2YJog`ZFP09og`ZFP?o00003On7@W<00ol0003oW5AfoiaDMP02oiaDMP03o`00
0?nNEGKoWUEf01WoWUEf00?o0000ojmSMon_HgL02_n_HgL00ol0003o]6IfokAVMP0FokAVMP04o`00
0?noLGKo_g5fo`0001?oaGEd00?o0000olekLOo=Ng400ol0000:olUYF003o`000?oAK4kodFa>00Go
dFa>00?o0000omMdD?oGM5000ol00005olmF6003o`000?oBF0;o000000?o0000>_oonfX00ol0003o
oo]ZoookJP1_oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000omJn`ooF_/<03_oF_/<2o`0000[o
cKS500?o0000ol^fa_o;]/H01_o;]/H00ol0003oa[76olJaaP0ColJaaP03o`000?o1Z<7o`JS100co
`JS100Co0000okZVa?njY/Co^ZK41Ol00002okVYb@03o`000?nfXlGo]Z?501So]Z?500?o0000ojbN
bOn/W/T00_n/W/T3o`0000;oZY_61Ol0000BojVE`@03o`000?nKS/GoVhk501goVhk500?o0000ohn8
b?n?R<P01on?R<P00ol0003oRH;5ohV2a@0AohV2a@03o`000?mkNLKoNgW600SoNgW600?o0000ofm`
`om_L<<03_m_L<<01Ol0003oFf?2oe]S`_mKHl;o000000CoDeJg00?o0000ocM:^OlgB[T01_lgB[T0
0ol0003o8CB/o`000006oobeFP;o000000?og8l8o`000?oonfX0=OoonfX00ol0003ooo]ZoookJP0`
oookJP00<OoonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z02_ooo]Z1Ol00006ocL0
70Co00002OmD1TX00ol0003oO2YJog`ZFP05og`ZFPCo00004?n7@W<00ol0003oW5AfoiaDMP02oiaD
MP03o`000?nNEGKoWUEf01WoWUEf00?o0000ojmSMon_HgL02_n_HgL00ol0003o]6IfokAVMP0FokAV
MP04o`000?noLGKo_g5fo`0001?oaGEd00?o0000olekLOo=Ng400oo=Ng43o`0000OobFUH00?o0000
om5/C_oAK4h01OoAK4h01_l0003oegA@omMdD?oGM53o0000omihAP;o00001?o?EQP00ol0003odUP2
om9H0P03o`0003Wooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP0SoookJP03o`00
0?oF_/?oe[k300koe[k300?o0000om:g`?l000002_o=^<D00ol0003obkK6ol^faP04ol^faP03o`00
0?o6/LKoa[7601?oa[7600?o0000ol6X`Oo1Z<403_o1Z<400ol0003o^ZK4okZVa005okZVa17o0000
3?nfXlD01?l0003o[9k9ojbNbOn/W/T6o`0001SoZIG100?o0000oi^>aOnKS/D07?nKS/D00ol0003o
ShS8ohn8b002ohn8b0_o00003_n9P/D00ol0003oNgW6og]iaP08og]iaP03o`000?m_L<?oKg3300ko
Kg3300Go0000oe]S`_mKHl;oFf?2o`000005oe=F]`03o`000?lgB[Wo=dZi00Co=dZi00Co0000ob4d
[?lQ=:co00001_ol]EX4o`0003Kooo]Z00?o0000oookJ_oonfX0<?oonfX0037ooo]Z00?o0000oook
J_oonfX0<_oonfX00ol0003ooo]ZoookJP0XoookJPKo00001Olg01`2o`0000;oE0M:00?o0000oe@6
B_mD1TX02?mD1TX01?l0003oO2YJog`ZF_ml:UX4o`0001?oQd9c00?o0000oiaDM_nLE7H01?nLE7H0
0ol0003oWUEfoiiEMP0HoiiEMP03o`000?n_HgOo[f=g00_o[f=g00?o0000okAVM_ndIWH05OndIWH0
1?l0003o_g5fokmaM_l0000ColEeM003o`000?o=Ng7ocG]a00KocG]a0ol00004olUYF0;o00001OoA
K4h00ol0003oegA@omMdD003omMdD004o`000?oNN4KogWQ6o`0000?oceHH00Co0000om9H0_oBF0;o
dUP20ol0000ioookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003o
e[k3omJn``0>omJn``04o`000?oB]l3od[O0om:g`0;o00002Oo=^<D00ol0003obkK6ol^faP02ol^f
aP03o`000?o6/LKoa[7601?oa[7600?o0000ol6X`Oo1Z<403oo1Z<400ol0003o^ZK4okZVa004okZV
a003o`000?ngWl3o]io000oo]io03_l000000on/W/Wo0000o`00000MojVE`@03o`000?nKS/GoVhk5
01_oVhk51_l00003ohn7aP03o`000?n=P<3oSH3000GoSH302ol00003ohV2a@03o`000?mkNLKoNgW6
00OoNgW600?o0000ofm``om_L<<04?m_L<<00ol0003oFf?2o`000007oe=F]`03o`000?lgB[Wo=dZi
00?o=dZi00?o0000ob4d[?lQ=:`00_l00005oobeFPCo0000=_oonfX00ol0003ooo]ZoookJP0`oook
JP00<?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02Kooo]Z1ol00003ocL070;o
00000omD1dX00ol0003oE0I:oe@6BP08oe@6BP03o`000?ml:U[o000000;o00005on7@W<00ol0003o
W5AfoiaDMP04oiaDMP03o`000?nNEGKoWUEf01SoWUEf00?o0000ojmSMon_HgL02on_HgL00ol0003o
]6IfokAVMP0EokAVMP04o`000?noLGKo_g5fo`0001CoaGEd00?o0000olekLOo=Ng402?o=Ng43o`00
00;obFUH00?o0000om5/C_oAK4h00ooAK4h00ol0003oegA@omMdD003omMdD004o`000?oNN4KogWQ6
omihAP;o00000_o?EQP01?l0003odUP2om9H0_oBF083o`0003Sooo]Z00?o0000oookJ_oonfX0KOoo
nfX00ol0003ooo]ZoookJP0RoookJP03o`000?oF_/?oe[k300koe[k300?o0000om:g`?oB]l001?oB
]l000ol0003ocKS5olfha@06olfha@05o`000?o;]/KobkK6ol^fa_l000005Oo6/LH00ol0003o`JS1
ol6X`@0Aol6X`@04o`000?njY/Co^ZK4okZVa0;o00007ongWl000ol0003oZIG1ojVE`@0OojVE`@03
o`000?nKS/GoVhk501GoVhk51Ol00002oib=``03o`000?n?QlKoShO600?oShO600?o0000ohf0`?n=
P<004On=P<07o`0000KoNgW600?o0000ofm``om_L<<04?m_L<<00ol0003oFf?2o`000008oe=F]`03
o`000?lgB[Wo=dZi00;o=dZi00Ko0000ob4d[?lQ=:co0000ook6P?l00004oobeFPCo0000=ooonfX0
0ol0003ooo]ZoookJP0_oookJP00<?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z
02Cooo]Z1ol000001?lg01co0000o`000?l00003oe@7BP;o00002_mD1TX3o`0001[oQd9c00?o0000
oiaDM_nLE7H01?nLE7H00ol0003oWUEfoiiEMP0BoiiEMQ_o00004OndIWH01Ol0003o_g5fokmaM_no
LGKo000001?oaGEd00?o0000olekLOo=Ng402oo=Ng43o`0000GodFa>00?o0000omMdD?oGM5000ooG
M5000ol0003ogWQ6omihAP03omihAP;o000000?oceHHo`000?oBF0800ooBF082o`0003Sooo]Z00?o
0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oF_/?oe[k300koe[k300?o
0000om:g`?oB]l001_oB]l02o`0000OocKS500?o0000ol^fa_l000005Oo6/LH00ol0003o`JS1ol6X
`@0Bol6X`@04o`000?njY/Co^ZK4o`0001oo]io000?o0000okBN`_l000008OnYUL400ol0003oVhk5
oi^>a@0@oi^>a@Go00002?nLSL<01Ol0003oShO6ohn7a_n?QlKo000001SoSH3000?o0000ogaha?ml
N<@00ol00002og]iaP03o`000?m_L<?oKg33017oKg3300?o0000oe]S`_l000002OmCE[L01ol0003o
=dZiocM:^OlgB[Wo0000ob4d[?l000000_onaX000ol0003oo;EJoobeFP02oobeFP;o000000?om[I6
o`000?l00000=_oonfX00ol0003ooo]ZoookJP0_oookJP00<?oonfX00ol0003ooo]ZoookJP0foook
JP03o`000?oonf[ooo]Z02;ooo]Z2Ol00005oe@7BP03o`000?mD1T[oE0I:00SoE0I:0_l000000omY
:6_o0000ohM2L`0JohM2L`03o`000?nLE7KoW5Af00GoW5Af00?o0000oiiEM_nNEGH01?nNEGH=o`00
00KoY6F700?o0000ok9`QonbL8L02onbL8L00ol0003o]gB8okMdR004okMdR0co00001OndIWH01Ol0
003o_g5fokmaM_noLGKo000001?oaGEd00?o0000olekLOo=Ng403Oo=Ng44o`000003om5/C_l0003o
egA@00KoegA@00?o0000omihA_oNN4H01?oNN4H2o`0000GodUP200?o0000oookJ_oonfX0=ooonfX0
0ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000omJn`ooF_/<03ooF_/<0
0ol0003od[O0om:g`008om:g`003o`000?o=^<GocKS500GocKS500?o0000olJaa_o6/LH04oo6/LH0
0ol0003o`JS1ol6X`@0Col6X`@03o`000?njY/Co000001ko]io00_l00003okBN`P03o`000?nYUL7o
ZIG101ooZIG100?o0000oi^>aOnKS/D02_nKS/D5o`0000goW8g300Co0000ohn7a_n?QlKo00006_n=
P<000ol0003oO7S4ogaha002ogaha0?o00005?m_L<<00ol0003oDeJgoe=F]`09oe=F]`06o`000?lg
B[Wo=dZio`000?lQ=:co00000oonaX001?l0003oo;EJoobeF_ol]EX2o`000003ooJfA_l0003o0000
03Kooo]Z00?o0000oookJ_oonfX0;ooonfX0033ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003o
oo]ZoookJP0PoookJPSo00001_mD1dX00ol0003oE0I:oe@6BP07oe@6BP;o00000omY:6/00ol0003o
Qd9cohM2L`0IohM2L`04o`000?nLE7KoW5AfoiaDMP_o00004onTIHL00ol0003o/W27ok9`Q`0;ok9`
Q`03o`000?ngM8So]gB8013o]gB83?l0000AolEeM003o`000?o=Ng7ocG]a00gocG]a0_l00002omF0
K@?o00001_oGM5000ol0003ogWQ6omihAP05omihAP;o00001?oBF082o`0003Sooo]Z00?o0000oook
J_oonfX0JooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oF_/?oe[k300koe[k300?o0000om:g
`?oB]l002_oB]l000ol0003ocKS5olfha@04olfha@03o`000?o6/LKoa[7601;oa[7600?o0000ol6X
`Oo1Z<405?o1Z<42o`0001ko]io000?o0000okBN`_ndW/800ondW/800ol0003oZIG1ojVE`@0OojVE
`@03o`000?nKS/GoVhk500GoVhk51Ol0000Boib=``03o`000?n?QlKo000001_oSH3000?o0000ogah
a?mlN<@00omlN<@2ogQ__0?o00004Om_L<<00ol0003oDeJgoe=F]`0:oe=F]`05ocM:^Ol0003o8CB/
ob4d[?l000001?onaX001Ol0003oo;EJoobeF_l0003om[I600?o0000=_oonfX00ol0003ooo]Zoook
JP0_oookJP00<?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z01kooo]Z1ol00000
0olG02ko0000oe@7BP04oe@7BP03o`000?mD1T[oE0I:00KoE0I:0_l00005ofTXJ`03o`000?n7@W?o
Qd9c01OoQd9c1_l00004oj5SQ`03o`000?nTIHOoY6F701OoY6F700?o0000ok9`QonbL8L02onbL8L0
0ol0003o]gB8okMdR00EokMdR005o`000?o2OHKo`Wf6ol9mQ_l000000_o7PHH4o`0000goaGEd00?o
0000olekLOo=Ng403Oo=Ng42o`0000?oeH1]00Co0000omZ6K?l0003o00001?oGM5000ol0003ogWQ6
omihAP07omihAP;o00000ooBF082o`0003Sooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oF_/?oe[k300koe[k300?o0000om:g`?oB]l003?oB]l02o`0000?ocKS5
00?o0000olZb`ol000004_o6/LH00ol0003o`JS1ol6X`@0Dol6X`@03o`000?nmY<3o000001go]io0
00?o0000okBN`_ndW/801OndW/800ol0003oZIG1ojVE`@0NojVE`@03o`000?nKS/GoVhk500Go0000
5onLSL<2o`0001goSH3000Go0000ogaha?mlN<CoO7S4o`000005ogQ__0;o00003_m_L<<2o`0000go
DeJg00Co0000ob4d[?lQ=:co00001?onaX002?l0003oo;EJoobeF_l0003om[I6o`000?of]TKo0000
=_oonfX00ol0003ooo]ZoookJP0_oookJP00<?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oo
nf[ooo]Z01cooo]Z1ol00002oaL0;P04o`000?mD1d[oE0M:oe@7BP;o00001omD1TX2o`0000OoJBQ[
00?o0000ohM2Lon7@W<05?n7@W<3o`0000;oSeB500?o0000oj5SQonQHhL01OnQHhL00ol0003oY6F7
ojAUQ`0GojAUQ`03o`000?nbL8Oo/W2700_o/W2700?o0000okMdR?ngM8P05OngM8P01Ol0003o`Wf6
ol9mQ_o2OHKo000000Koah661Ol00008olEeM003o`000?o=Ng7ocG]a00gocG]a0_l00003omF0K@04
o`000?oJQVcofXI/omZ6K0;o00000ooGM5000ol0003ogWQ6omihAP06omihAP03o`000?oTNcOo0000
00?odUP20_l0000hoookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003oe[k3omJn``0?omJn``03o`000?oB]l3od[O000kod[O000?o0000olfhaOl000000oo://<00ol0
003oa[76olJaaP0>olJaaP03o`000?o1Z<7o`JS101Co`JS100Go0000okfT`?nmY<3o_JC0o`00000J
okNO`0;o00002?ndW/800ol0003oZIG1ojVE`@0OojVE`@;o00006_nLSL<2o`000003oiZ6_On=P<3o
SH3001coSH3000Co0000ogaha?mlN<Co00002?mhKk`3o`0000[oKg3300Co0000of=P^OmSH;Wo0000
3?mCE[L01?l0003o8CB/ob4d[?l00005ook6P007o`000?ol]E[o0000ooJfA_l0003om[I6o`00000f
oookJP03o`000?oonf[ooo]Z02oooo]Z000`oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oook
J_oonfX06_oonfX7o`0000?o5`0^00Co0000oe@7B_mD1d[o00001omD1TX2o`0000WoJBQ[00?o0000
ohM2Lon7@W<04?n7@W<4o`0000GoSeB500?o0000oj5SQonQHhL01?nQHhL00ol0003oY6F7ojAUQ`0H
ojAUQ`03o`000?nbL8Oo/W2700_o/W2700?o0000okMdR?ngM8P05OngM8P01Ol0003o`Wf6ol9mQ_o2
OHKo000000_oah661?l00005olEeM003o`000?o=Ng7ocG]a00cocG]a00?o0000olekLOl000000_oE
P6d00ol0003ofXI/omZ6K003omZ6K0;o000000?oegA@o`000?oNN4H02?oNN4H00ol0003oi7/go`00
0002om9H0P03o`000?o;D03o000003Oooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]Zoook
JP0MoookJP;o00004?oF_/<00ol0003od[O0om:g`00@om:g`0;o00001?o://<00ol0003oa[76olJa
aP0<olJaaP03o`000?o1Z<7o`JS101Co`JS100?o0000okfT`?nmY<000_nmY<000ol0003o]io0okNO
`00GokNO`003o`000?ndW/;o]9k200So]9k200?o0000ojVE`OnYUL407?nYUL42o`000003ojVE`Ol0
003oW8g301SoW8g30_l00004oiZ6_AgoSH3000?o0000ogaha?l000003?mhKk`2o`0000OoKg3300Go
0000of=P^OmSH;WoHf2io`00000;oe=F]`04o`000?lc>JWo0000o`0000Koo/J000Ko0000oobeF_l0
003om[I6o`000?of]TH2o`0003Gooo]Z00?o0000oookJ_oonfX0;ooonfX002oooo]Z00?o0000oook
J_oonfX0??oonfX00ol0003ooo]ZoookJP0HoookJPOo00000olG02h01?l0003oE0M:oe@7B_l00006
oe@6BP;o00002_mY:6/00ol0003oQd9cohM2L`0=ohM2L`Co00002On?E8D00ol0003oXF>7oj5SQ`04
oj5SQ`03o`000?nTIHOoY6F701SoY6F700?o0000ok9`QonbL8L02onbL8L00ol0003o]gB8okMdR00E
okMdR005o`000?o2OHKo`Wf6ol9mQ_l000003oo7PHH4o`000003olEeM?l0003ocG]a00gocG]a00?o
0000olekLOl000000_oEP6d00ol0003ofXI/omZ6K005omZ6K0;o00002OoNN4H01?l0003oi7/gonAk
=ol00002om9H0P03o`000?o;D03o000003Oooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]Z
oookJP0NoookJP03o`000?oJ_Kco000000koe[k300?o0000om:g`?oB]l004OoB]l001?l0003oc:nm
o`000?l00002olZb``03o`000?o6/LKoa[7600_oa[7600?o0000ol6X`Oo1Z<405?o1Z<400ol0003o
_JC0okfT`004okfT`003o`000?ngWl3o]io001Co]io00_l0000<okBN`P03o`000?nYUL7oZIG101Wo
ZIG10_l00004ojVE`@03o`000?nLSL?oW8g301?oW8g30ol00006oiZ6_@03o`000?n=P<3oSH3001[o
SH300_l0000?ogQ__0;o00001Om_L<<01Ol0003oHf2iof=P^OmSH;Wo000000_oDeJg00Co0000oc<i
ZOlc>JWo00001oonaX02o`000003ooJfA_l0003om[I600;o0000=OoonfX00ol0003ooo]ZoookJP0_
oookJP00;ooonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01Kooo]Z1ol00004oaL0
;P03o`000?mD1d[o000000GoE0I:0_l0000<ofTXJ`03o`000?n7@W?oQd9c00[oQd9c0ol0000=ohmD
Q@03o`000?nQHhOoXF>700CoXF>700?o0000ojAUQonTIHL06?nTIHL00ol0003o/W27ok9`Q`0:ok9`
Q`03o`000?ngM8So]gB801Ko]gB800Go0000ol9mQ_o2OHKo`Wf6o`00000ColN1QPCo00003?o=Ng40
0ol0003ocG]ao`000002omF0K@03o`000?oJQVcofXI/00OofXI/0_l00007omihAP04o`000?oTNcOo
i7/gonAk=`?o00000_o;D0000ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06Oooo]Z00?o
0000oookJ_oonfX07OoonfX01Ol0003of[flomZm_?oJ_Kco000000coe[k300?o0000om:g`?oB]l00
4OoB]l000ol0003oc:nmolb__@02olb__@Co00002oo6/LH00ol0003o`JS1ol6X`@0Dol6X`@03o`00
0?nmY<3o_JC000Go_JC000?o0000okNO`?ngWl004ongWl000ol0003o]9k2okBN`P0<okBN`P03o`00
0?nYUL7oZIG101KoZIG10ol00006ojVE`@03o`000?nLSL?oW8g3017oW8g30_l00009oiZ6_@03o`00
0?n=P<3oSH3001WoSH3000?o0000ohMh_?l000004OmhKk`3o`000003ofm``ol0003oHf2i00?oHf2i
00?o0000oe=F]omCE[L02?mCE[L01Ol0003o<cVYoc<iZOlc>JWo000000Soo/J000Co0000ooJfA_l0
003om[I60_l0000foookJP03o`000?oonf[ooo]Z02kooo]Z000_oookJP03o`000?oonf[ooo]Z03ko
oo]Z00?o0000oookJ_oonfX05?oonfX6o`0000Ko5`0^0_l00004oe@6BP;o00003_mY:6/00ol0003o
Qd9cohM2L`06ohM2L`Co00004?n?E8D00ol0003oXF>7oj5SQ`04oj5SQ`03o`000?nTIHOoY6F701So
Y6F700?o0000ok9`QonbL8L02_nbL8L00ol0003o]gB8okMdR00FokMdR005o`000?o2OHKo`Wf6ol9m
Q_l000005?o7PHH00ol0003ocXN5olj7Q@03o`0000WocG]a00?o0000olekLOl000000_oEP6d00ol0
003ofXI/omZ6K007omZ6K004o`000?oRS6Oo0000o`0000KogWQ600?o0000onAk=ooTNcL00_oTNcL2
o`0000;obe0000?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[o
oo]Z01cooo]Z00?o0000omZm_?oJ_K`00ooJ_K`00ol0003oe[k3omJn``09omJn``03o`000?oB]l3o
d[O0013od[O000?o0000olb__Oo<[kd01_o<[kd2o`0000Woa[7600?o0000ol6X`Oo1Z<405?o1Z<40
0ol0003o_JC0okfT`007okfT`003o`000?ngWl3o]io0017o]io000?o0000okBN`_ndW/803_ndW/80
0ol0003oZIG1ojVE`@0CojVE`@;o00002_nYUL400ol0003oW8g3oib=``0>oib=``;o00003?nJQ[d0
0ol0003oSH30ohf0`00Gohf0`004o`000?n7N;coQgRlo`0001CoN6nl0_l00005of=P^@03o`000?mC
E[OoDeJg00OoDeJg00Go0000oc<iZOlc>JWo<cVYo`000008ook6P004o`000?of]TKo0000ooJfAP;o
0000=_oonfX00ol0003ooo]ZoookJP0^oookJP00;ooonfX00ol0003ooo]ZoookJP0ooookJP03o`00
0?oonf[ooo]Z01;ooo]Z1_l00007oaL0;P04o`000?mD1T[oE0I:oe@6BP;o00004?mY:6/00ol0003o
Qd9cohM2L`02ohM2L`Co00005?n?E8D00ol0003oXF>7oj5SQ`04oj5SQ`03o`000?nTIHOoY6F701So
Y6F700?o0000ok9`QonbL8L02_nbL8L00ol0003o]gB8okMdR00GokMdR003o`000?o2OHKo000001Go
ah6600?o0000olj7QOo>QhD00oo>QhD4o`0000GocG]a00?o0000olekLOl000000_oEP6d00ol0003o
fXI/omZ6K007omZ6K005o`000?oRS6OohXaWon:<Iol000001OoNN4H00ol0003oi7/gonAk=`03onAk
=`;o00000_o;D0000ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oook
J_oonfX07?oonfX00ol0003of[flomZm_004omZm_0;o00002?oF_/<00ol0003od[O0om:g`00@om:g
`003o`000?o<[kgoc:nm00Woc:nm0_l00006olJaaP03o`000?o1Z<7o`JS101Co`JS100?o0000okfT
`?nmY<002?nmY<000ol0003o]io0okNO`00?okNO`0;o00004OndW/800ol0003oZIG1ojVE`@0AojVE
`@;o00003?nYUL400ol0003oW8g3oib=``0<oib=``;o00003_nJQ[d00ol0003oSH30ohf0`00Eohf0
`0;o00001?n7N;`00ol0003oN6nlogQ__00AogQ__0;oK6Bh00?o0000of=P^OmSH;T00_mSH;T00ol0
003oDeJgoe=F]`07oe=F]`05o`000?lc>JWo<cVYoc<iZOl000002?onaX03o`000004ooJfA_l0003o
0000o`0003Gooo]Z00?o0000oookJ_oonfX0;_oonfX002oooo]Z00?o0000oookJ_oonfX0@?oonfX0
0ol0003ooo]ZoookJP0@oookJPKo00002?lG02h01?l0003oE0I:o`000?l0000BofTXJ`03o`000?n7
@W?o000000;o00006?n?E8D00ol0003oXF>7oj5SQ`03oj5SQ`03o`000?nTIHOoY6F701WoY6F700?o
0000ok9`QonbL8L02_nbL8L00ol0003o]gB8okMdR00GokMdR003o`000?o2OHKo000001Goah6600?o
0000olj7QOo>QhD01oo>QhD4o`000007olekLOl0003ocG]aolekLOl0003oeH1]o`000009omZ6K003
o`000?oRS6OohXaW00;ohXaW0_l00003omihAP03o`000?oTNcOoi7/g00Coi7/g00Co0000ol]@0?o;
D03o0000=_oonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000omZm
_?oJ_K`01ooJ_K`00ol0003oe[k3omJn``04omJn``03o`000?oB]l3od[O0013od[O000?o0000olb_
_Oo<[kd02_o<[kd01?l0003obJo0o`000?l00003olJaaP03o`000?o1Z<7o`JS101Co`JS100?o0000
okfT`?nmY<002_nmY<000ol0003o]io0okNO`00=okNO`003o`000?ndW/;o]9k201;o]9k200?o0000
ojVE`OnYUL403_nYUL42o`0000ooZIG100?o0000oib=`onLSL<02OnLSL<2o`00013oVXJm00?o0000
ohf0`?n=P<005?n=P<000ol0003oQgRlohMh_004ohMh_003o`000?mhKkcoN6nl013oN6nl00Co0000
ofaT^?m/I;SoK6Bh0_l00002of=P^@03o`000?mCE[OoDeJg00KoDeJg00Go0000oc<iZOlc>JWo<cVY
o`000009ook6P0?o000000Com[I6o`000?oS[BSo0000=OoonfX00ol0003ooo]ZoookJP0^oookJP00
;ooonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z00oooo]Z1Ol00008oaL0;P?o0000
4omY:6/3o`0001_oSeB500?o0000oj5SQonQHhL00onQHhL00ol0003oY6F7ojAUQ`0IojAUQ`03o`00
0?nbL8Oo/W2700[o/W2700?o0000okMdR?ngM8P05ongM8P00ol0003o`Wf6o`00000EolN1QP03o`00
0?o>QhGocXN500_ocXN50ol000001?o=Ng7o0000omF0KOl0000:omZ6K003o`000?oRS6OohXaW00?o
hXaW0_l00002omihAP03o`000?oTNcOoi7/g00Coi7/g00Co0000ol]@0?o;D03o0000=_oonfX00ol0
003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000omZm_?oJ_K`02OoJ_K`00ol0
003oe[k3omJn``03omJn``03o`000?oB]l3od[O000ood[O000?o0000olb__Oo<[kd03?o<[kd01_l0
003obJo0olV_`?l0003oa[76o`0001Ko`JS100?o0000okfT`?nmY<002onmY<000ol0003o]io0okNO
`00;okNO`0;o00005OndW/800ol0003oZIG1ojVE`@0<ojVE`@;o00004OnYUL400ol0003oW8g3oib=
``07oib=``;o00004onJQ[d00ol0003oSH30ohf0`00Bohf0`003o`000?n7N;coQgRl00GoQgRl00?o
0000ogQ__?mhKk`03omhKk`00ol0003oK6BhofaT^004ofaT^0?o00002?mCE[L01Ol0003o<cVYoc<i
ZOlc>JWo000000Soo/J000So0000ooo=M?l0003o0000ooJfA_l0003ohjdXo`0003Gooo]Z00?o0000
oookJ_oonfX0;_oonfX002kooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0=oook
JPGo00002?lG02h2o`0001?oJBQ[0_l000000omf@8;o0000ohmDQ@0KohmDQ@03o`000?nQHhOoXF>7
00?oXF>700?o0000ojAUQonTIHL06OnTIHL00ol0003o/W27ok9`Q`0:ok9`Q`03o`000?ngM8So]gB8
01Oo]gB800?o0000ol9mQ_l000005Oo7PHH00ol0003ocXN5olj7Q@0<olj7Q@03o`000?o>QhGo0000
00?o00002_oJQV`00ol0003ohXaWon:<I`05on:<I`03o`000?oNN4Ko000000Koi7/g0_l00002ol]@
0003o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0Joook
JP03o`000?oJ_Kcof[fl00[of[fl00Go0000omJn`ooF_/?oe[k3o`00000Bom:g`003o`000?o<[kgo
c:nm00goc:nm00?o0000olV_`?o9[l000ol0000Dol6X`@03o`000?nmY<3o_JC000co_JC000?o0000
okNO`?ngWl002_ngWl000ol0003o]9k2okBN`P0FokBN`P03o`000?nYUL7oZIG100WoZIG10_l0000C
ojVE`@03o`000?nLSL?oW8g300CoW8g30ol0000EoiZ6_@03o`000?n=P<3oSH30013oSH300_l00009
ohMh_003o`000?mhKkcoN6nl00goN6nl00?o0000ofaT^?m/I;P01om/I;P2o`0000KoDeJg00?o0000
oc<iZOlc>JT00_lc>JT00ol0003oo/J0ook6P006ook6P008o`000?oocGCooledo`000?of]TKo0000
on>]:?l0000eoookJP03o`000?oonf[ooo]Z02kooo]Z000^oookJP03o`000?oonf[ooo]Z04Cooo]Z
00?o0000oookJ_oonfX02ooonfX5o`0000So5`0^00?o0000od07G_l000004OmY:6/2o`0000?oMT22
00?o0000ohmDQOn?E8D06_n?E8D00ol0003oXF>7oj5SQ`03oj5SQ`03o`000?nTIHOoY6F701CoY6F7
8?l0000<okMdR003o`000?o2OHKo000001Goah6600?o0000olj7QOo>QhD03?o>QhD01Ol0003ocXN5
olj7QOl0003oeHj400;o00002OoJQV`00ol0003ohXaWon:<I`06on:<I`;o00001ooTNcL2o`000003
ol]@0?l0003o000003Gooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP0IoookJP03
o`000?oJ_Kcof[fl00cof[fl00?o0000omJn`ol000004_oB]l000ol0003oc:nmolb__@0>olb__@03
o`000?o9[l3o000000?oaJRl0ol0000@ol6X`@03o`000?nmY<3o_JC000ko_JC000?o0000okNO`?ng
Wl002?ngWl000ol0003o]9k2okBN`P0GokBN`P03o`000?nYUL7oZIG100OoZIG10_l0000FojVE`@03
o`000?nLSL?oW8g300;oW8g300?o0000oiZ6_OnJQ[d05onJQ[d00ol0003oSH30ohf0`00>ohf0`003
o`000?n7N;coQgRl00WoQgRl00?o0000ogQ__?mhKk`03?mhKk`00ol0003oK6BhofaT^009ofaT^0;o
00001OmCE[L00ol0003o<cVYoc<iZ@02oc<iZ@03o`000?onaX3oo/J000Koo/J000So0000ooo=M?oo
cGCo0000ooJfA_l0003ohjdXo`0003Gooo]Z00?o0000oookJ_oonfX0;_oonfX002kooo]Z00?o0000
oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0:oookJP?o00002?lG02h2o`0000;o@0MN00?o0000
ofTXJomY:6/03OmY:6/2o`0000GoMT2200?o0000ohmDQOn?E8D06_n?E8D00ol0003oXF>7oj5SQ`03
oj5SQ`03o`000?nTIHOoY6F700[oY6F72_l00005ojMaU@03o`000?ndNiCo]7^D00[o]7^D00?o0000
okQoUOnhOiD02onhOiD?o`0001Coah6600?o0000olj7QOo>QhD03Oo>QhD01ol0003ocXN5olj7QOl0
003oeHj4o`000?oKTX800_l00007omZ6K003o`000?oRS6OohXaW00SohXaW0_l00005onAk=`04o`00
0?oVNb;o0000ol]@00;o0000=OoonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z01Wo
oo]Z00?o0000omZm_?oJ_K`03_oJ_K`2o`00017od[O000?o0000olb__Oo<[kd04?o<[kd00ol0003o
aJRlolFX_005olFX_0Co00002oo1Z<400ol0003o_JC0okfT`00?okfT`003o`000?ngWl3o]io000Ko
]io00_l0000JokBN`P03o`000?nYUL7oZIG100CoZIG10ol0000HojVE`@04o`000?nLSL?oW8g3o`00
01_oVXJm00?o0000ohf0`?n=P<003On=P<000ol0003oQgRlohMh_00:ohMh_003o`000?mhKkcoN6nl
00coN6nl00?o0000ofaT^?m/I;P02Om/I;P00ol0003oEUJfo`000003oe=F]`03o`000?lc>JWo<cVY
00?o<cVY0_l00007ook6P003o`000?oocGCooled00?o00000_oS[BP00ol0003ooo]ZoookJP0boook
JP03o`000?oonf[ooo]Z02kooo]Z000^oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oo
nfX02?oonfX3o`0000So5`0^00?o0000ocP0F_l000000_m01eh00ol0003oJBQ[ofTXJ`0;ofTXJ`;o
00001omf@8800ol0003oSeB5ohmDQ@0JohmDQ@03o`000?nQHhOoXF>700;oXF>700?o0000ojAUQonT
IHL00_nTIHL9o`0000ooYg6E00?o0000okAkU?ndNi@02OndNi@00ol0003o^7nEokQoU@0HokQoU@03
o`000?o2QY?o000000?o00004Oo7PHH00ol0003ocXN5olj7Q@0>olj7Q@05o`000?o>QhGo0000omF>
Q?l000000ooKTX82o`0000GofXI/00?o0000on:<IooRS6L02?oRS6L00ol0003ojY9No`000004onAk
=`03o`000?oVNb;oiW/R00;o000000?o]T80o`000?oonfX0<ooonfX00ol0003ooo]ZoookJP1Qoook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000omZm_?oJ_K`03_oJ_K`00ol0003oeKNko`00000?om:g
`003o`000?o<[kgoc:nm017oc:nm00?o0000olFX_?o5Z;`02Oo5Z;`4o`0000Ko`JS100?o0000okfT
`?nmY<004OnmY<000ol0003o]io0okNO`004okNO`003o`000?ndW/;o]9k201_o]9k200Co0000ojVE
`OnYUL7oZIG10_l0000JojVE`@?o00007OnJQ[d00ol0003oSH30ohf0`00<ohf0`003o`000?n7N;co
QgRl00coQgRl00?o0000ogQ__?mhKk`02_mhKk`00ol0003oK6BhofaT^00;ofaT^003o`000?mFE[Ko
000000;oDeJg00?o0000oc<iZOlc>JT00_lc>JT01?l0003on/nJoo[?V_l00006ook6P004o`000?oo
cGCooledooo=M0;o00000_oS[BP00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z02kooo]Z
000^oookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX01_oonfX3o`0000So5`0^00Ko
0000ocP0F_lh05[o0000od07G_l0000<ofTXJ`;o00002Omf@8800ol0003oSeB5ohmDQ@0HohmDQ@co
00006?nWLID00ol0003o]7^DokAkU009okAkU003o`000?nhOiGo^7nE01So^7nE00?o0000ol:6Tol0
00000oo7Ri@5o`0000coah6600?o0000olj7QOo>QhD03_o>QhD01Ol0003ocXN5o`000?oESXCo0000
00Gofi:20_l00003omZ6K003o`000?oRS6OohXaW00SohXaW00?o0000onZBG_oZTUh00_l00003onAk
=`03o`000?oVNb;oiW/R00;o000000?o]T80o`000?oonfX0<ooonfX00ol0003ooo]ZoookJP1Poook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000omZm_?oJ_K`03_oJ_K`01?l0003oeKNkomFg^ooE]k/2
o`0000cod[O000?o0000olb__Oo<[kd04Oo<[kd00ol0003ob:Zlo`00000>olFX_0?o00000_o1Z<40
0ol0003o_JC0okfT`00BokfT`003o`000?ngWl3o]io000;o]io00_l0000NokBN`P04o`000?nYUL7o
0000o`0001OoZIG11Ol00002ojN?_003o`000?nJQ[goVXJm01coVXJm00?o0000ohf0`?n=P<002On=
P<02o`0000ooQgRl00?o0000ogQ__?mhKk`02OmhKk`00ol0003oK6BhofaT^00<ofaT^006o`000?mF
E[KoEUJfo`000?mCE[Oo00001?lc>JT01?l0003on/nJoo[?V_l00005ook6P003o`000?oocGCooled
00;ooled0_l00002on>]:003o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0;OoonfX002ko
oo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP05oookJP;o00001olG02h2o`0000;o
>01J00Co0000od07G_m01eko00002OmY:6/3o`0000_oMT2200?o0000ohmDQOn?E8D05On?E8D3o`00
00;oUF>D00?o0000ojE^U?nUKY@00_nUKY@00ol0003oYg6EojMaU@0KojMaU@03o`000?ndNiCo]7^D
00So]7^D00?o0000okQoUOnhOiD06?nhOiD00ol0003o`XJCo`000008olN;U0Go00001oo7PHH00ol0
003ocXN5olj7Q@0>olj7Q@05o`000?o>QhGo0000omF>Q?l000001ooKTX82o`0000;ofXI/00?o0000
on:<IooRS6L01ooRS6L00ol0003ojY9NonZBGP02onZBGP04o`000?oTNcOoi7/go`0000?oiW/R0_l0
00000onf@P3o0000oookJP0coookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX05ooo
nfX00ol0003of[flomZm_00>omZm_003o`000?oE]k_oeKNk00CoeKNk00?o0000om:g`?oB]l002OoB
]l000ol0003oc:nmolb__@0@olb__@04o`000?o8Z[cob:Zlo`00017oaJRl00Co0000ol6X`Ol0003o
00005?nmY<001?l0003o]io0okNO`?l0000PokBN`P;o00005OnYUL44o`0000OoYhnl00?o0000oiZ6
_OnJQ[d07?nJQ[d00ol0003oSH30ohf0`008ohf0`003o`000?n7N;coQgRl00ooQgRl00?o0000ogQ_
_?mhKk`02?mhKk`00ol0003oK6BhofaT^00=ofaT^005o`000?mFE[KoEUJfoeIF]_l000001Olc>JT0
1Ol0003on/nJoo[?V_ojci[o000000Coo/J000?o0000ooo=M?oocG@00_oocG@2o`0000;ohjdX00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0]oookJP00;OoonfX00ol0003ooo]ZoookJP1:
oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l00007oaL0;P03o`000?lh05[o>01J00;o>01J00Co0000
od07G_m01eko00001omY:6/2o`0000koMT2200?o0000ohmDQOn?E8D04On?E8D4o`0000GoUF>D00Go
0000ojE^U?nUKYCoYFjDo`00000NojMaU@03o`000?ndNiCo]7^D00Oo]7^D00?o0000okQoUOnhOiD0
6OnhOiD00ol0003o`XJCo`00000=olN;U0Go00000_o7PHH00ol0003ocXN5olj7Q@0>olj7Q@05o`00
0?o>QhGo0000omF>Q?l000002OoKTX83o`0000[ohXaW00?o0000onZBG_oZTUh00_oZTUh01?l0003o
i7/gonAk=ol00003onIk8P03o`000?nf@P3o000003Cooo]Z00?o0000oookJ_oonfX0GooonfX00ol0
003ooo]ZoookJP0GoookJP;o00003ooJ_K`00ol0003oeKNkomFg^`05omFg^`;o00002?oB]l000ol0
003oc:nmolb__@0@olb__@03o`000?o8Z[cob:Zl00;ob:Zl00?o0000olFX_?o5Z;`03oo5Z;`00ol0
003o`JFmol6U_@04o`00013o_JC000?o0000okNO`?l000008?ndW/800ol0003o/YZno`00000@ojVE
`@Go00003?nWSk`00ol0003oVXJmoiZ6_@0KoiZ6_@03o`000?n=P<3oSH3000SoSH304_n7N;`00ol0
003oN6nlogQ__007ogQ__003o`000?m/I;SoK6Bh00ooK6Bh00Co0000oeIF]_mFE[Ko00001?lc>JT0
0ol0003on/nJoo[?VP03oo[?VP05o`000?onaX3oo/J0ook6P?l000001?oocG@2o`0000;ohjdX00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0]oookJP00;OoonfX00ol0003ooo]ZoookJP1;
oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00006oaL0;P03o`000?lh05[o>01J00?o>01J00Co0000
od07G_m01eko00001OmY:6/2o`00013oMT2200?o0000ohmDQOn?E8D03On?E8D4o`0000WoUF>D00Go
0000ojE^U?nUKYCoYFjDo`00000NojMaU@03o`000?ndNiCo]7^D00Oo]7^D00?o0000okQoUOnhOiD0
6_nhOiD00ol0003oah^DolN;U00AolN;U0Go00003_o>QhD2o`0000;oeHj400?o0000om^BP_oKTX80
2OoKTX82o`0000WohXaW00?o0000onZBG_oZTUh00ooZTUh3o`0000CoiW/R00?o0000okI20?l00000
=?oonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z01Kooo]Z00Co0000om^m_?oK_Kco
00003OoJ_K`00ol0003oeKNkomFg^`08omFg^`03o`000?oB]l3od[O000Cod[O000?o0000olb__Oo<
[kd04?o<[kd00ol0003ob:ZlolRZ_003olRZ_003o`000?o5Z;coaJRl00koaJRl00?o0000ol6U_Oo1
YKd01Oo1YKd5o`0000co_JC000?o0000okBN`_ndW/807_ndW/801Ol0003o/YZnok:J__nbV[ko0000
00_oZIG11?l0000AojN?_003o`000?nJQ[goVXJm01[oVXJm2_l000001?n=P<3o0000o`000?l0000A
ohMh_003o`000?mhKkcoN6nl00GoN6nl00?o0000ofaT^?m/I;P04?m/I;P01Ol0003oEUJfo`000?m5
@JSo000000?o<cVY00?o0000oo[?V_ojciX00oojciX01Ol0003oo/J0ook6P?onaX3o000000Cooled
0_l00002on>]:003o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0;OoonfX002gooo]Z00?o
0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP02o`0000Go5`0^0_l00005ocP0FP05o`000?m0
1eko@0MNod07G_l000000omY:6/2o`0001;oMT2200?o0000ohmDQOn?E8D02_n?E8D3o`0000koUF>D
00?o0000ojE^U?l000007onWLID00ol0003o]7^DokAkU007okAkU003o`000?nhOiGo^7nE01[o^7nE
00?o0000olN;U?o7Ri@04oo7Ri@00ol0003ocI6DolfAU003o`0000_ocXN50_l00003omF>Q003o`00
0?oKTX;ofi:200Sofi:200Co0000on>IOol0003o00001ooRS6L00ol0003ojY9NonZBGP05onZBGP03
o`000?oVNb;oiW/R00;oiW/R00Co0000okI20?nf@P3o0000<ooonfX00ol0003ooo]ZoookJP1Noook
JP03o`000?oonf[ooo]Z01Gooo]Z00?o0000om^m_?oK_K`00_oK_K`00ol0003of[flomZm_009omZm
_003o`000?oE]k_oeKNk00[oeKNk0_l00003om:g`003o`000?o<[kgoc:nm013oc:nm00?o0000olRZ
_?o8Z[`01Oo8Z[`00ol0003oaJRlolFX_00<olFX_003o`000?o1YKgo`JFm00_o`JFm1?l00007okfT
`0;o00007_ndW/82o`0000Co/YZn00?o0000ojVE`OnYUL401OnYUL44o`0001GoYhnl00?o0000oiZ6
_OnJQ[d05OnJQ[d5o`0000;oVXJm00?o0000oheo_on=Okl00on=Okl00ol0003oR7JiohQf^@03ohQf
^@Go00003?n7N;`00ol0003oN6nlogQ__005ogQ__003o`000?m/I;SoK6Bh013oK6Bh00?o0000oeIF
]_l000000_m5@JP01?l0003o<cVYoc<iZOl00006oo[?VP04o`000?onaX3oo/J0o`0000Cooled0_l0
0002on>]:003o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0;OoonfX002gooo]Z00?o0000
oookJ_oonfX0COoonfX4o`0000Co5`0^00?o0000ocP0F_lh05X01Olh05X01?l0003o@0MNod07G_l0
0002ofTXJ`;o00005?mf@8800ol0003oSeB5ohmDQ@06ohmDQ@Co00004OnEHi@2o`00023oYg6E00?o
0000okAkU?ndNi@01_ndNi@00ol0003o^7nEokQoU@0KokQoU@03o`000?o7RiCoah^D01?oah^D00?o
0000olfAU?o=TI@00oo=TI@3o`0000SocXN50_l00003omF>Q003o`000?oKTX;ofi:200Sofi:200Go
0000on>IOooSVGoohiUoo`000006on:<I`03o`000?oZTUkojY9N00KojY9N00?o0000onIk8_oVNb80
0_oVNb800ol0003o]T80o`00000doookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0
5?oonfX2o`0000Gofkfl00?o0000omZm_?oJ_K`01ooJ_K`00ol0003oeKNkomFg^`0=omFg^`03o`00
0?oB]l3o000001;oc:nm00?o0000olRZ_?o8Z[`01_o8Z[`00ol0003oaJRlolFX_00;olFX_003o`00
0?o1YKgo`JFm013o`JFm1?l00002okfT`004o`000?nlX[ko_::no`0001co]9k200?o0000ok:J__nb
V[h01?nbV[h00ol0003oZIG1ojVE`@05o`0001[oYhnl00?o0000oiZ6_OnJQ[d03onJQ[d5o`0000Oo
VXJm00Co0000oheo_on=OkooSGno0_l0000;ohQf^@Ko00001_n7N;`00ol0003oN6nlogQ__004ogQ_
_003o`000?m/I;SoK6Bh01;oK6Bh0_l00003odE1Z0;o00001oojciX00ol0003oo/J0o`000005ooo=
M0?o000000?ohjdXo`000?oonfX0=?oonfX00ol0003ooo]ZoookJP0]oookJP00;OoonfX00ol0003o
oo]ZoookJP1>oookJP03o`000?l000So000000?o5`0^00?o0000ocP0F_lh05X01_lh05X00ol0003o
@0MNod07GP03o`0001KoMT2200?o0000ohmDQOn?E8D00_n?E8D4o`0001GoUF>D0_l0000PojMaU@03
o`000?ndNiCo]7^D00Ko]7^D00?o0000okQoUOnhOiD06onhOiD00ol0003oah^DolN;U00BolN;U003
o`000?o=TICocI6D00OocI6D0ol00005olj7Q@;o00000ooESX@00ol0003ofi:2om^BPP08om^BPP03
o`000?oSVGoohiUo00;ohiUo0_l00004on:<I`03o`000?oZTUkojY9N00KojY9N0_l00003onIk8P;o
000000?o]T80o`000?oonfX0<OoonfX3o`0005gooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003o
gk^co`000005om^m_003o`000?oJ_Kcof[fl00Kof[fl00?o0000omFg^ooE]k/03_oE]k/2o`00017o
c:nm00?o0000olRZ_?o8Z[`02?o8Z[`00ol0003oaJRlolFX_009olFX_003o`000?o1YKgo`JFm01Go
`JFm5?l0000=okBN`P04o`000?nbV[ko/YZnok:J_POo00007onWSk`00ol0003oVXJmoiZ6_@0:oiZ6
_@Go00003OnJQ[d00ol0003oSGnoo`00000CohQf^@Go00000_n7N;`00ol0003oN6nlogQ__002ogQ_
_003o`000?m/I;SoK6Bh01?oK6Bh00?o0000odE1Z?m5@JP00om5@JP00ol0003on/nJoo[?VP06oo[?
VP;o00001OoocG@3o`000003on>]:?l0003ooo]Z03Cooo]Z00?o0000oookJ_oonfX0;OoonfX002go
oo]Z00?o0000oookJ_oonfX0COoonfX3o`0000?o5`0^00?o0000ocP0F_lh05X01_lh05X00ol0003o
@0MNod07GP02o`0001SoMT2200?o0000ohmDQOl000000_l0000HoiESU0;o00008OnWLID00ol0003o
]7^DokAkU006okAkU003o`000?nhOiGo^7nE01_o^7nE00?o0000olN;U?o7Ri@04_o7Ri@00ol0003o
cI6DolfAU00:olfAU0?o00000_o>QhD2o`0000?oeHj400?o0000om^BP_oKTX802?oKTX800ol0003o
hiUoon>IO`04on>IO`;o00000_oRS6L00ol0003ojY9NonZBGP06onZBGP03o`000?oaUe7o000000;o
iW/R00Co0000ommf1Ol0003o0000;ooonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0FooonfX00ol0
003ooo]ZoookJP0DoookJP05o`000?oO^k?ogk^comnk/ol000001OoK_K`00ol0003of[flomZm_004
omZm_003o`000?oE]k_oeKNk00ooeKNk00Co0000om6`^?l0003o00003oo<[kd00ol0003ob:ZlolRZ
_008olRZ_003o`000?o5Z;coaJRl00SoaJRl00?o0000ol6U_Oo1YKd05Oo1YKd00ol0003o^ifiok^M
^@04ok^M^@03o`000?ndVKco]9Vl00_o]9Vl4Ol00005ok:G^`03o`000?nWSkcoYhnl01koYhnl00?o
0000oiZ6_OnJQ[d01OnJQ[d5o`0001;oVXJm0_l0000IohQf^@Go000000?oN6nlo`000?m/I;P05Om/
I;P00ol0003oAD6XodE1Z003odE1Z003o`000?ojci[on/nJ00Oon/nJ00?o0000ooo=M?oocG@00ooo
cG@01Ol0003omliPo`000?oS[BSo000003Gooo]Z00?o0000oookJ_oonfX0;OoonfX002gooo]Z00?o
0000oookJ_oonfX0C?oonfX2o`000003o`002?l0003o5`0^00;o00002Olh05X01Ol0003o@0MNo`00
0?mD9GWo000001OoMT220ol0000JoiESU003o`000?nFI9Ko000002;oYg6E00?o0000okAkU?ndNi@0
1?ndNi@00ol0003o^7nEokQoU@0KokQoU@;o00005?o7Ri@00ol0003ocI6DolfAU00=olfAU0Co0000
0ooESX@00ol0003ofi:2om^BPP08om^BPP03o`000?oSVGoohiUo00KohiUo00Co0000on:<IooRS6Oo
00001ooZTUh01?l0003olIMAoo6GDOl00002onIk8P04o`000?oOMPGo0000o`0002_ooo]Z0ol00005
oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ogk^comnk/`02
omnk/`03o`000?oK_Kcofkfl00?ofkfl00?o0000omZm_?oJ_K`00_oJ_K`00ol0003oeKNkomFg^`0?
omFg^`03o`000?oA/;SodK2h00;odK2h0_l0000<olb__@03o`000?o8Z[cob:Zl00[ob:Zl00?o0000
olFX_?o5Z;`01_o5Z;`00ol0003o`JFmol6U_@0Eol6U_@03o`000?nkWKWo^ifi00Ko^ifi00?o0000
okBI_?ndVK`05?ndVK`00ol0003o/YNkok:G^`0:ok:G^`03o`000?nWSkcoYhnl01koYhnl00?o0000
oiZ6_Ol000001?l0000FoiZ6_@;o00007?n8M[T00ol0003oNFnkogU_^`02o`0001GoK6Bh0_l00005
odE1Z003o`000?ojci[on/nJ00Oon/nJ00?o0000ooo=M?oocG@00ooocG@01Ol0003omliPo`000?oS
[BSo000003Kooo]Z00?o0000oookJ_oonfX0;?oonfX002cooo]Z00?o0000oookJ_oonfX0COoonfX2
o`000003o`002?l0003o000000_o>01J0_l00002oe@UN@03o`000?mf@8;oMT2201?oMT220_l00000
0omoDi?o0000oiESU00IoiESU004o`000?nFI9KoUVBFo`0002;oYg6E00?o0000okAkU?ndNi@01?nd
Ni@00ol0003o^7nEokQoU@0KokQoU@;o00005?o7Ri@00ol0003ocI6DolfAU00?olfAU0Co000000?o
eHj4o`000?oKTX802OoKTX800ol0003ohiUoon>IO`07on>IO`?o00002?oZTUh01_l0003olIMAoo6G
DOl0003oiW/Ro`0000;oggH50_l0000WoookJP?o00002?oonfX00ol0003ooo]ZoookJP1KoookJP03
o`000?oonf[ooo]Z01?ooo]Z00?o0000omnk/ooO^k<01?oO^k<00ol0003ofkflom^m_003om^m_005
o`000?oJ_Kcof[flomZm_?l000004?oE]k/00ol0003odK2hom6`^005om6`^0;o00002Oo<[kd00ol0
003ob:ZlolRZ_00;olRZ_003o`000?o5Z;coaJRl00GoaJRl00?o0000ol6U_Oo1YKd05Oo1YKd00ol0
003o^ifiok^M^@07ok^M^@03o`000?ndVKco]9Vl01?o]9Vl00?o0000ok:G^onbUk/02onbUk/00ol0
003oYhnlojN?_00MojN?_0?o00006OnJQ[d2o`000003oiQo]_l0003oR7Ji01coR7Ji0_l00002og1R
/P;o00004_m/I;P01?l0003oH5>/of1C[?l00003odE1Z003o`000?ojci[on/nJ00Son/nJ0_l00004
ooo=M003o`000?ogcV3omliP00;o0000=_oonfX00ol0003ooo]ZoookJP0/oookJP00;?oonfX00ol0
003ooo]ZoookJP1<oookJPGo00002olh05X2o`0000?oE2Ei00?o0000ogI0P_mf@8804Omf@882o`00
00?oOe>C00?o0000oiESU?nEHi@05onEHi@01Ol0003oUVBFoiITU_nFI9Ko000002;oYg6E00?o0000
okAkU?ndNi@01?ndNi@00ol0003o^7nEokQoU@0JokQoU@04o`000?nmQ9Oo_HBGo`0001?oah^D00?o
0000olfAU?o=TI@03oo=TI@2o`0000;oe9RE0ol00009om^BPP03o`000?oSVGoohiUo00WohiUo0_l0
0007onZBGP07o`000?oaUe7olIMAoo6GDOl0003oiW/Ro`000002ommf1@03o`000?oonf[ooo]Z02;o
oo]Z0ol0000;oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003o
gk^comnk/`05omnk/`03o`000?oK_Kcofkfl00?ofkfl00?o0000omZm_?l000004?oE]k/00ol0003o
dK2hom6`^008om6`^003o`000?o<[kgoc:nm00Goc:nm00?o0000olRZ_?o8Z[`03Oo8Z[`00ol0003o
aJRlolFX_003olFX_003o`000?o1YKgo`JFm01Go`JFm00?o0000ok^M^OnkWKT02?nkWKT00ol0003o
]9VlokBI_00AokBI_0;o00003_nbUk/00ol0003oYhnlojN?_00KojN?_0;o000000?oYhjko`000?nJ
Q[d05onJQ[d2o`0000?oV7nf00?o0000ohQf^On8M[T06_n8M[T2o`0000GoL6:b00?o0000ofaT^?m/
I;P03_m/I;P01Ol0003oH5>/of1C[?mPDjco000000?oAD6X00?o0000oo[?V_ojciX01oojciX00ol0
003oo]VDo`000004ooo=M0;o000000?omliPo`000?l00000=_oonfX00ol0003ooo]ZoookJP0/oook
JP00;?oonfX00ol0003ooo]ZoookJP1;oookJP?o000000?o0008o`000?lh05X02_lh05X2o`0000Co
E2Ei00?o0000ogI0P_mf@8803omf@882o`0000GoOe>C00?o0000oiESU?nEHi@05OnEHi@2o`0000Co
UVBF00?o0000ojMaUOnWLID07?nWLIDBo`0001Ko^7nE00Co0000okf4UonmQ9Oo00004_o7Ri@00ol0
003ocI6DolfAU00@olfAU0;o00000ooDV9D01?l0003ofY^Bo`000?l00007om^BPP03o`000?oSVGoo
hiUo00WohiUo00?o0000on^QN_l000001_oZTUh00ol0003olIMAoo6GD@02oo6GD@;o00000ooOMPD0
0ol0003ooo]ZoookJP0NoookJP?o00003ooonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[o
oo]Z01;ooo]Z00?o0000omnk/ooO^k<01ooO^k<00ol0003ofkflom^m_003om^m_003o`000?oE]k_o
eKNk00ooeKNk00?o0000om6`^?oA/;P02OoA/;P2o`0000Coc:nm00?o0000olRZ_?o8Z[`03_o8Z[`0
0ol0003oaJRlolFX_002olFX_003o`000?o1YKgo`JFm01Go`JFm00?o0000ok^M^OnkWKT02_nkWKT0
0ol0003o]9VlokBI_00?okBI_003o`000?nbUk_o/YNk00oo/YNk00?o0000ojN?_?nWSk`06?nWSk`2
o`0000CoYhjk00?o0000oiZ6_OnJQ[d04_nJQ[d3o`0000KoV7nf00?o0000ohQf^On8M[T06?n8M[T0
0ol0003oQFf`o`000006og1R/P;o00003Om/I;P00ol0003oH5>/of1C[002of1C[005o`000?m5@JSo
AD6XodE1Z?l000002OojciX00ol0003oo]VDo`000004ooo=M0;o000000?omliPo`000?l00000=_oo
nfX00ol0003ooo]ZoookJP0/oookJP00;?oonfX00ol0003ooo]ZoookJP1;oookJP?o000000?o0008
o`000?lh05X02Olh05X00ol0003oCb9io`000004oe@UN@03o`000?mf@8;oMT2200goMT220_l00007
ogmCT`03o`000?nEHiCoUF>D01CoUF>D00?o0000oiITU_nFI9H01?nFI9H00ol0003oYg6EojMaU@0C
ojMaU@Wo00001?nZNj400ol0003o]H>NokF3WP03okF3WP03o`000?niQj3o^HNP00Go^HNP3ol00007
okQoU@04o`000?nmQ9Oo_HBGo`0001;oah^D00?o0000olfAU?o=TI@04?o=TI@00ol0003oe9REomBH
U@02omBHU@04o`000?oJVi;ofY^BomZKTP?o00001?oKTX800ol0003ohiUoon>IO`09on>IO`03o`00
0?o[XG[ojj5j00;o00001?oZTUh00ol0003olIMAoo6GD@03oo6GD@05o`000?oOMPGoggH5ommf1Ol0
00007OoonfX3o`0001;ooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP0BoookJP03
o`000?oO^k?ogk^c00Sogk^c00Co0000om^m_?oK_Kcofkfl0_l0000@omFg^`03o`000?oA/;SodK2h
00codK2h0_l000000oo<[kgo0000olRZ_00AolRZ_004o`000?o5Z;coaJRlo`0001Oo`JFm00?o0000
ok^M^OnkWKT02onkWKT00ol0003o]9VlokBI_00>okBI_003o`000?nbUk_o/YNk013o/YNk00?o0000
ojN?_?nWSk`05OnWSk`3o`0000KoYhjk00?o0000oiZ6_OnJQ[d04?nJQ[d2o`0000WoV7nf00?o0000
ohQf^On8M[T05_n8M[T2o`0000;oQFf`00?o0000og1R/_m`H[801_m`H[82o`0000[oK6Bh00?o0000
of1C[?mPDj`00omPDj`01?l0003oAD6XodE1Z?l0000:oo[?VP04o`000?onfICoo]VDo`0000?ooled
0_l000000oogcV3o0000o`00000foookJP03o`000?oonf[ooo]Z02cooo]Z000/oookJP03o`000?oo
nf[ooo]Z04[ooo]Z0ol000000ol000So0000o`000009ocP0FP04o`000?m?8WWoCb9io`0000CoE2Ei
00?o0000ogI0P_mf@8802omf@882o`0000WoOe>C00?o0000oiESU?nEHi@04onEHi@00ol0003oUVBF
oiITUP05oiITUP03o`000?nWLIGoYg6E00[oYg6E2Ol0000=ojYkX@03o`000?nePiko]H>N00;o]H>N
00?o0000okV7X?niQj005OniQj0=o`00013oah^D00?o0000olfAU?o=TI@04?o=TI@00ol0003oe9RE
omBHU@03omBHU@03o`000?oJVi;ofY^B00?ofY^B0_l00002om^BPP03o`000?oSVGoohiUo00WohiUo
00?o0000on^QN_o[XGX00_o[XGX01Ol0003ojY9NonZBG_oZTUko000000KolIMA00Go0000ommf1OoO
MPGoggH5o`00000IoookJP?o00005OoonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z
017ooo]Z00?o0000omnk/ooO^k<02_oO^k<00ol0003ofkflo`000002omNg^@03o`000?oE]k_oeKNk
00coeKNk00?o0000om6`^?oA/;P03ooA/;P2o`0001;ob:Zl00?o0000olFX_?l000005oo1YKd00ol0
003o^ifiok^M^@0<ok^M^@03o`000?ndVKco]9Vl00co]9Vl0_l0000Cok:G^`03o`000?nWSkcoYhnl
01?oYhnl0_l00009ojN>^`03o`000?nJQ[goVXJm00koVXJm0_l0000;oiQo]P03o`000?n8M[WoR7Ji
01GoR7Ji00?o0000ohE]/?n5KK000on5KK000ol0003oL6:bog1R/P07og1R/P03o`000?m/I;SoK6Bh
00OoK6Bh00?o0000of1C[?mPDj`00omPDj`01?l0003oAD6XodE1Z?l00009oo[?VP05o`000?onfICo
o]VDookIU?l000000ooocG@2o`0000;omliP00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP0/oookJP00;?oonfX00ol0003ooo]ZoookJP1:oookJPCo000000?o000oo`000?lh05X01_lh05X2
o`0000?oCb9i00?o0000oe@UNOmD9GT00_mD9GT00ol0003oMT22ogI0PP08ogI0PP?o00002omoDi<0
0ol0003oUF>DoiESU00AoiESU0;o00002?nFI9H01?l0003oYg6EojMaUOnWLID9o`0001KoZW^Q00Go
0000okF3W_nePiko]H>No`00000NokV7X005o`000?nmSJ;o_HfRokf=X_l000000_o6TYl5o`0000_o
ah^D00?o0000olfAU?o=TI@04?o=TI@00ol0003oe9REomBHU@03omBHU@03o`000?oJVi;ofY^B00Go
fY^B0ol0000;on>IO`03o`000?o[XG[ojj5j00?ojj5j00Co0000onZBG_oZTUko00001_oaUe401?l0
003oggH5ommf1OoOMPD2o`0001Gooo]Z0ol0000HoookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000
oookJ_oonfX04OoonfX00ol0003ogk^comnk/`0;omnk/`;o00000ooG]kT00ol0003oeKNkomFg^`0:
omFg^`03o`000?oA/;SodK2h013odK2h00?o0000olfY]_l000000_l0000@olRZ_003o`000?o1YKgo
`JFm01Go`JFm00?o0000ok^M^OnkWKT03_nkWKT00ol0003o]9VlokBI_00:okBI_003o`000?nbUk_o
/YNk01Co/YNk00?o0000ojN?_?nWSk`04?nWSk`2o`0000coYhjk00?o0000oiZ6_OnJQ[d02onJQ[d2
o`0000koV7nf00?o0000ohQf^On8M[T04on8M[T00ol0003oQFf`ohE]/004ohE]/003o`000?m`H[;o
L6:b00SoL6:b0_l00006ofaT^003o`000?mPDjcoH5>/00GoH5>/00?o0000odE1Z?l000002OojciX0
0ol0003oo]VDookIU002ookIU003o`000?oocGCooled00;o00000_ogcV000ol0003ooo]ZoookJP0d
oookJP03o`000?oonf[ooo]Z02cooo]Z000[oookJP03o`000?oonf[ooo]Z04[ooo]Z1?l000000ol0
03oo0000ocP0FP06ocP0FP03o`000?m?8WWoCb9i00CoCb9i00Go0000oe@UNOmD9GWoE2Eio`000008
ogI0PP;o00003_moDi<00ol0003oUF>DoiESU00@oiESU003o`000?nFI9KoUVBF00KoUVBF1_l0000O
ojYkX@05o`000?nePiko]H>NokF3W_l000007OniQj000ol0003o_HfRokf=XP02okf=XP03o`000?o6
TYooaY:O00GoaY:O1?l00007olN;U003o`000?o=TICocI6D013ocI6D00?o0000omBHUOoDV9D00ooD
V9D00ol0003ofY^BomZKTP07omZKTP;o00002_oSVGl00ol0003ojj5jon^QNP04on^QNP;o000000?o
jY9No`000?oaUe401?oaUe42o`0000;oggH50_l0000BoookJP?o00006ooonfX00ol0003ooo]Zoook
JP1IoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000omnk/ooO^k<03?oO^k<00ol0003of[Bbo`00
0002omNg^@03o`000?oE]k_oeKNk00[oeKNk00?o0000om6`^?oA/;P03ooA/;P00ol0003ocJVfolfY
]P03olfY]P?o00003?o8Z[`2o`0001Ko`JFm00?o0000ok^M^OnkWKT03onkWKT00ol0003o]9VlokBI
_009okBI_003o`000?nbUk_o/YNk01Go/YNk00?o0000ojN?_?nWSk`03_nWSk`2o`0000koYhjk00?o
0000oiZ6_OnJQ[d02OnJQ[d2o`00013oV7nf00?o0000ohQf^On8M[T04On8M[T2o`0000OoQFf`00?o
0000og1R/_m`H[802_m`H[82o`0000?oK6Bh00?o0000of1C[?mPDj`01_mPDj`2o`000003ooCD[Ol0
003on/nJ00Oon/nJ00?o0000ookIU?onfI@00_onfI@00ol0003ooledooo=M002o`0000;omliP00?o
0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0/oookJP00:ooonfX00ol0003ooo]ZoookJP19
oookJPGo000000?o000oo`000?lh05X01?lh05X2o`0000OoCb9i00Go0000oe@UNOmD9GWoE2Eio`00
0006ogI0PP;o00004OmoDi<00ol0003oUF>DoiESU00>oiESU003o`000?nFI9KoUVBF00;oUVBF1Ol0
0002oiY`XP03o`000?nZNj7oZW^Q027oZW^Q00?o0000okF3W_l000007_niQj000ol0003o_HfRokf=
XP03okf=XP03o`000?o6TYooaY:O00SoaY:O1Ol000000oo7RiCo0000olfAU00AolfAU0;o00001OoD
V9D00ol0003ofY^BomZKTP07omZKTP04o`000?oQXi7o0000o`0000SohiUo00?o0000on^QN_o[XGX0
1_o[XGX2o`0000KolIMA0_l00002ommf1@;o00003_oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0
FOoonfX00ol0003ooo]ZoookJP0AoookJP03o`000?oO^k?ogk^c00_ogk^c00Co0000omZd/_oJ];;o
f[Bb0_l000000ooG]kWo0000omFg^`09omFg^`03o`000?oA/;SodK2h00oodK2h00?o0000olfY]_o=
ZKH01oo=ZKH2o`0000Wob:Zl00Co0000olFV^_o5Y[[o00005?o1YKd00ol0003o^ifiok^M^@0Aok^M
^@03o`000?ndVKco]9Vl00Ko]9Vl0_l0000Iok:G^`03o`000?nWSkcoYhnl00_oYhnl0_l0000@ojN>
^`03o`000?nJQ[goVXJm00OoVXJm0_l0000BoiQo]P03o`000?n8M[WoR7Ji013oR7Ji00?o0000ohE]
/?n5KK001on5KK000ol0003oL6:bog1R/P0<og1R/P03o`000?m/I;So000000WoH5>/0_l00002ooCD
[@03o`000?ojci[on/nJ00Con/nJ00?o0000ookIU?onfI@01?onfI@2o`000005ooO>H?l0003omliP
ooO>H?l00000=ooonfX00ol0003ooo]ZoookJP0[oookJP00:ooonfX00ol0003ooo]ZoookJP19oook
JPCo00000_l003l00ol0003o>01JocP0FP02ocP0FP03o`000?m?8WWoCb9i00OoCb9i00Go0000oe@U
NOmD9GWoE2Eio`000004ogI0PP;o00004omoDi<00ol0003oUF>DoiESU00=oiESU0Ko00001onJL:80
0ol0003oZW^QojYkX@0QojYkX@03o`000?nePiko000001go^HNP00?o0000okf=X_nmSJ801?nmSJ80
0ol0003oaY:OolJBW`0=olJBW`Co00004?o=TI@00ol0003oe9REo`000005omBHU@03o`000?oJVi;o
fY^B00KofY^B00Go0000on6STOoQXi7ohJ>Ao`000007on>IO`03o`000?o[XG[ojj5j00Oojj5j0_l0
0005oo6GD@04o`000?ocVSoo0000ommf1@;o00002_oonfX4o`00027ooo]Z00?o0000oookJ_oonfX0
FOoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oO^k?ogk^c00cogk^c00?o0000omZd/_oJ];80
0ooJ];800ol0003oekNio`000008omFg^`03o`000?oA/;SodK2h013odK2h00?o0000olfY]_o=ZKH0
2Oo=ZKH3o`0000Gob:Zl00Go0000olFV^_o5Y[[oaJJjo`00000Col6U_@03o`000?nkWKWo^ifi01;o
^ifi00?o0000okBI_?ndVK`01OndVK`00ol0003o/YNkok:G^`0Iok:G^`03o`000?nWSkcoYhnl00Wo
Yhnl0_l0000CojN>^`03o`000?nJQ[goVXJm00?oVXJm0ol0000EoiQo]P03o`000?n8M[WoR7Ji00go
R7Ji0_l0000;ohE]/003o`000?m`H[;oL6:b00coL6:b0_l00009of1C[0;o00000_ode:d00ol0003o
n/nJoo[?VP04oo[?VP03o`000?onfICoo]VD00Coo]VD0_l000001OogcV3o0000ooO>H?ogcV3o0000
03Oooo]Z00?o0000oookJ_oonfX0:ooonfX002_ooo]Z00?o0000oookJ_oonfX0B?oonfX4o`0000?o
000o00Go0000ocP0F_lh05[o>01Jo`00000:odlRN@05o`000?mD9GWoE2Eioe@UNOl000000_mf@882
o`0001GoOe>C00?o0000oiESU?nEHi@02_nEHi@4o`0000coVW2R00?o0000ojYkXOnZNj408OnZNj42
o`0001go^HNP00?o0000okf=X_nmSJ801OnmSJ800ol0003oaY:OolJBW`0>olJBW`03o`000?o<V:3o
c9RP00?o00003Oo=TI@00ol0003oe9REo`000005omBHU@03o`000?oJVi;ofY^B00KofY^B00?o0000
on6STOoQXi400_oQXi42o`0000GohiUo00?o0000on^QN_o[XGX01oo[XGX00ol0003oljUdo`000004
oo6GD@05o`000?ocVSooliXoo`000?oOMPD00_l00006oookJP?o00009_oonfX00ol0003ooo]Zoook
JP1HoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000omnk/ooO^k<02ooO^k<00ol0003of[BbomZd
/P05omZd/P;o00001ooE]k/00ol0003odK2hom6`^00@om6`^003o`000?o=ZKKocJVf00gocJVf0ol0
00000oo8Z[co0000olFV^P04olFV^P03o`000?o1YKgo`JFm00oo`JFm00?o0000ok^M^OnkWKT04onk
WKT00ol0003o]9VlokBI_004okBI_003o`000?nbUk_o/YNk01[o/YNk00?o0000ojN?_?nWSk`01onW
Sk`2o`0001GoYhjk00?o0000oiZ6_OnJQ[d00_nJQ[d00ol0003oV7nfoiQo]P0FoiQo]P03o`000?n8
M[WoR7Ji00coR7Ji00?o0000ohE]/?n5KK002on5KK000ol0003oL6:bog1R/P0;og1R/P04o`000?m]
F:SoKERXo`0000SoH5>/00?o0000ooCD[Oode:d00_ode:d00ol0003on/nJoo[?VP03oo[?VP03o`00
0?onfICoo]VD00Coo]VD0_l000001OogcV3o0000ooO>H?ogcV3o000003Oooo]Z00?o0000oookJ_oo
nfX0:ooonfX002_ooo]Z00?o0000oookJ_oonfX0AooonfX5o`0000?o000o00Co0000ocP0F_l0003o
00002om?8WT01?l0003oE2Eioe@UNOmD9GT3o`0001OoOe>C00?o0000oiESU?nEHi@01_nEHi@5o`00
013oVW2R00?o0000ojYkXOnZNj408?nZNj400ol0003o^HNPokV7X00LokV7X003o`000?nmSJ;o_HfR
00Go_HfR00?o0000olJBWoo6TYl03Oo6TYl00ol0003oc9RPolbHX004olbHX0Co00002Oo=TI@00ol0
003oe9REo`000005omBHU@03o`000?oJVi;ofY^B00GofY^B00?o0000on6STOoQXi401OoQXi42o`00
00?ohiUo00?o0000on^QN_o[XGX01oo[XGX01?l0003oljUdoo>YM?l00003oo6GD@04o`000?ocVSoo
liXooo>J?`;o000000CobfT0o`000?oonf[ooo]Z0ol0000YoookJP03o`000?oonf[ooo]Z05Sooo]Z
00?o0000oookJ_oonfX03ooonfX00ol0003ogk^comnk/`0<omnk/`03o`000?oJ];;of[Bb00Oof[Bb
00?o0000omFg^ooE]k/01?oE]k/00ol0003odK2hom6`^00?om6`^003o`000?o=ZKKocJVf017ocJVf
0ol00004olFV^P03o`000?o1YKgo`JFm00ko`JFm00?o0000ok^M^OnkWKT05OnkWKT01?l0003o]9Vl
okBI_?ndVK`2o`0001ko/YNk00?o0000ojN?_?nWSk`00onWSk`3o`0001OoYhjk00Co0000oiZ6_OnJ
Q[go00006_nHOkH00ol0003oR7JiohQf^@0;ohQf^@03o`000?n5KK3oQFf`00coQFf`00?o0000og1R
/_m`H[802_m`H[800ol0003oKERXofeHZ002ofeHZ003o`000?mPDjcoH5>/00GoH5>/00?o0000ooCD
[Oode:d00oode:d00ol0003on/nJoo[?VP02oo[?VP03o`000?onfICoo]VD00Goo]VD00Co0000ooO>
H?l0003omliP0_l0000goookJP03o`000?oonf[ooo]Z02_ooo]Z000[oookJP03o`000?oonf[ooo]Z
04Oooo]Z1Ol00002o`00?`03o`000?lh05[o000000koCb9i00Co0000oe@UNOl0003o00006OmoDi<0
0ol0003oUF>DoiESU003oiESU0?o00000_nIKIl2o`00017oVW2R00?o0000ojYkXOnZNj408?nZNj40
0ol0003o^HNPokV7X00KokV7X003o`000?nmSJ;o_HfR00Ko_HfR00?o0000olJBWoo6TYl03Oo6TYl0
0ol0003oc9RPolbHX008olbHX0Co00001Oo=TI@00ol0003oe9REo`000005omBHU@03o`000?oJVi;o
fY^B00GofY^B00?o0000on6STOoQXi401ooQXi401?l0003ohiUoon>IOol00009on^QNP05o`000?oc
ZGColjUdoo>YM?l000000ooaUe401_l0003oliXooo>J?oocVSoo0000ol]Y00?o0000;?oonfX00ol0
003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000omnk/ooO^k<02ooO^k<00ol0
003of[BbomZd/P09omZd/P;o00000ooE]k/00ol0003odK2hom6`^00@om6`^003o`000?o=ZKKocJVf
017ocJVf00?o0000olJR]?o6X[@00ol00002olFV^P03o`000?o1YKgo`JFm00co`JFm00?o0000ok^M
^OnkWKT05_nkWKT01?l0003o]9VlokBI_?l0000Pok:G^`04o`000?nWSkcoYhnlojN?_0;o00006OnW
S[/3o`0001goV7nf00?o0000ohQf^On8M[T02?n8M[T2o`00013oQFf`00?o0000og1R/_m`H[802?m`
H[800ol0003oKERXofeHZ004ofeHZ003o`000?mPDjcoH5>/00?oH5>/00?o0000ooCD[Oode:d01?od
e:d01Ol0003on/nJoo[?V_ojci[o000000Soo]VD00Co0000ooO>H?l0003omliP0_l0000goookJP03
o`000?oonf[ooo]Z02_ooo]Z000ZoookJP03o`000?oonf[ooo]Z04Oooo]Z1Ol00003o`00?`;o0000
3om?8WT2o`000003of8lSOl0003oOe>C01SoOe>C00?o0000oiESU?l000000ol00004oiU]W`03o`00
0?nJL:;oVW2R017oVW2R00?o0000ojYkXOnZNj407onZNj42o`0001go^HNP00?o0000okf=X_nmSJ80
1onmSJ800ol0003oaY:OolJBW`0<olJBW`03o`000?o<V:3oc9RP00coc9RP0ol000001Oo=TICo0000
omBHUOoDV9Go000000Koe9RE00?o0000omZKT_oJVi801?oJVi800ol0003ohJ>Aon6ST@08on6ST@?o
00002Oo[XGX00ol0003oljUdoo>YM002oo>YM004o`000?oaUe7olIMAo`0000ColiXo00?o0000ol]Y
0?l00000;OoonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z00kooo]Z0_l0000=omnk
/`03o`000?oJ];;of[Bb00Wof[Bb00Go0000omVc/ol0003oeKNko`00000Bom6`^003o`000?o=ZKKo
cJVf017ocJVf00?o0000olJR]?o6X[@01?o6X[@3o`0000go`JFm00?o0000ok^M^OnkWKT05onkWKT0
0ol0003o]9Vlo`00000Qok:G^`04o`000?nWSkcoYhnlo`0001KoYhjk1Ol00002ojF7]@03o`000?nH
OkKoV7nf01_oV7nf00?o0000ohQf^On8M[T01on8M[T00ol0003oQFf`ohE]/00@ohE]/003o`000?m`
H[;oL6:b00OoL6:b00?o0000ofeHZ?m]F:P01_m]F:P00ol0003oH5>/of1C[002of1C[003o`000?od
e:gom=B]00Gom=B]00Co0000oo[?V_ojci[o00002?onfI@01?l0003omliPo`000?ogcV02o`0003Oo
oo]Z00?o0000oookJ_oonfX0:ooonfX002[ooo]Z00?o0000oookJ_oonfX0AooonfX5o`0000?o000o
00?o0000odlRNOm?8WT03Om?8WT2o`0000;oHSb=00?o0000ogmCTomoDi<05_moDi<3o`0000KoVFfO
0_l0000DoiY`XP03o`000?nZNj7oZW^Q01koZW^Q00Co0000ojeoXon]Oj?o00006oniQj000ol0003o
_HfRokf=XP08okf=XP03o`000?o6TYooaY:O00_oaY:O00?o0000olbHX?o<V:004?o<V:03o`000003
omBHUOl0003oe9RE00Goe9RE00?o0000omZKT_oJVi801?oJVi800ol0003ohJ>Aon6ST@0:on6ST@;o
00002?o[XGX00ol0003oljUdoo>YM003oo>YM003o`000?oaUe7o000000ColiXo00?o0000ol]Y0?l0
0000;OoonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000onBiZ_l0
00002ooO^k<00ol0003of[BbomZd/P0;omZd/P04o`000?oI/k?o0000o`00017odK2h00?o0000olfY
]_o=ZKH04Oo=ZKH00ol0003oaZ:dolJR]008olJR]0Co00002?o1YKd00ol0003o^ifiok^M^@0Iok^M
^@03o`000?nbUk_o/YNk023o/YNk0_l0000DojN>^`Co00001onUQkD00ol0003oV7nfoiQo]P0KoiQo
]P03o`000?n8M[WoR7Ji00GoR7Ji0_l0000CohE]/003o`000?m`H[;oL6:b00KoL6:b00?o0000ofeH
Z?m]F:P02?m]F:P01?l0003oH5>/of1C[?l00008ooCD[@04o`000?ojci[on/nJo`0000Ooo]VD00Co
0000oogOROl0003omliP0ol0000goookJP03o`000?oonf[ooo]Z02_ooo]Z000ZoookJP03o`000?oo
nf[ooo]Z04Kooo]Z1?l000000ol002go0000o`00?`02o`00?`03o`000?m?8WWoCb9i00coCb9i00?o
0000of0lT?l000000_mR?8d00ol0003oOe>CogmCT`0DogmCT`;o000000?oQEnNo`000?nIKIl01OnI
KIl00ol0003oVW2RoiY`XP0DoiY`XP03o`000?nZNj7oZW^Q01goZW^Q00Go0000ojeoXon]Oj?o[GnS
o`00000KokV7X003o`000?nmSJ;o_HfR00So_HfR00?o0000olJBWoo6TYl02oo6TYl00ol0003oc9RP
olbHX00AolbHX003o`000?oBWj;o000000;o00001OoDV9D00ol0003ofY^BomZKTP04omZKTP03o`00
0?oQXi7ohJ>A00[ohJ>A00?o0000onR[Sol000001oo[XGX00ol0003oljUdoo>YM004oo>YM0;o0000
1?ocVSl3o`0002gooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP0>oookJP05o`00
0?oT^J[oi;VZonBiZ_l000002_oO^k<00ol0003of[BbomZd/P0;omZd/P04o`000?oI/k?o0000omB]
/@;o00003ooA/;P00ol0003ocJVfolfY]P0AolfY]P03o`000?o6X[CoaZ:d00SoaZ:d00Co0000ol:Q
]oo2XKOo`Z6g1Ol00002ol6U_@03o`000?nkWKWo^ifi01Wo^ifi0_l0000Qok:G^`03o`000?n`TkWo
000000ooYhjk1Ol0000<ojF7]@03o`000?nHOkKoV7nf01_oV7nf00?o0000ohQf^On8M[T00on8M[T0
0ol0003oQFf`ohE]/00CohE]/003o`000?m`H[;oL6:b00GoL6:b00?o0000ofeHZ?m]F:P02_m]F:P0
0ol0003oH5>/o`000009ooCD[@;o00002?onfI@01?l0003ooMn9o`000?ogcV03o`0003Oooo]Z00?o
0000oookJ_oonfX0:ooonfX002[ooo]Z00?o0000oookJ_oonfX0A_oonfX3o`0000;o000]00?o0000
o`00?ol003l00_l0000=odlRN@07o`000?mP?93oH3b@of0lT?l0003oHSb=o`00000DogmCT`;o0000
0on5Gih00ol0003oVFfOoiU]W`02oiU]W`;o00006?nJL:800ol0003oZW^QojYkX@0KojYkX@03o`00
0?n]Oj?o[GnS00;o[GnS00?o0000okV7X?niQj006?niQj000ol0003o_HfRokf=XP09okf=XP03o`00
0?o6TYooaY:O00[oaY:O00?o0000olbHX?o<V:004Oo<V:001_l0003odYnRom:OX_oBWj;o0000om:O
XP?o00000_oDV9D00ol0003ofY^BomZKTP04omZKTP03o`000?oQXi7ohJ>A00[ohJ>A00?o0000onR[
SooXZhl00_l00005on^QNP03o`000?ocZGColjUd00GoljUd0_l00003oo>J?`;o000000?obfT0o`00
0?oonfX0:ooonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000onBi
Z_oT^JX00_oT^JX00ol0003ogk^comnk/`06omnk/`03o`000?oJ];;of[Bb00gof[Bb00?o0000omB]
/OoD[K400_oD[K400ol0003odK2hom6`^00;om6`^003o`000?o=ZKKocJVf017ocJVf00?o0000olJR
]?o6X[@02_o6X[@00ol0003o`Z6gol:Q]`05ol:Q]`Go00006?nkWKT00ol0003o^Y^ho`00000Pok:G
^`04o`000?n`TkWo/9>io`0000_oYhjk1?l0000AojF7]@03o`000?nHOkKoV7nf01_oV7nf00?o0000
ohQf^On8M[T00_n8M[T00ol0003oQFf`ohE]/00EohE]/0KoL6:b00?o0000ofeHZ?m]F:P03?m]F:P2
o`0000[om=B]00?o0000ookIU?onfI@01_onfI@01?l0003ooMn9o`000?ogcV03o`0003Sooo]Z00?o
0000oookJ_oonfX0:_oonfX002[ooo]Z00?o0000oookJ_oonfX0A_oonfX2o`0000;o000]00Ko0000
o`00?ol003oo0000oaT0Iol0000;odlRN@;o00001OmP?902o`00017oOe>C0ol00005ohEOWP05o`00
0?nIKIooVFfOoiU]Wol000006_nJL:800ol0003oZW^QojYkX@0JojYkX@03o`000?n]Oj?o[GnS00?o
[GnS00?o0000okV7X?niQj006?niQj000ol0003o_HfRokf=XP0:okf=XP03o`000?o6TYooaY:O00Wo
aY:O00?o0000olbHX?o<V:004Oo<V:001Ol0003odYnRom:OX_oBWj;o000000CodYnR1?l00005omZK
TP03o`000?oQXi7ohJ>A00[ohJ>A00?o0000onR[SooXZhl00_oXZhl00ol0003ojj5jon^QNP02on^Q
NP03o`000?ocZGColjUd00KoljUd00?o0000oo>J?oocVSl00_ocVSl3o`0002gooo]Z00?o0000oook
J_oonfX0E_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oT^J[oi;VZ00Coi;VZ00?o0000omnk
/ooO^k<01OoO^k<00ol0003of[BbomZd/P0=omZd/P03o`000?oD[K7oe:fa00?oe:fa0_l0000;om6`
^003o`000?o=ZKKocJVf013ocJVf00?o0000olJR]?o6X[@02oo6X[@00ol0003o`Z6gol:Q]`06ol:Q
]`04o`000?nnWKKo_YffokjM]PKo00004OnkWKT01Ol0003o^Y^hokZK^?njVkSo000001go/YNk0_l0
0004ok2C^@03o`000?nWS[_oYhjk00CoYhjk1?l0000EojF7]@03o`000?nHOkKoV7nf01_oV7nf00Go
0000ohQf^On8M[WoR7Jio`00000HohE]/0GoL6:b00?o0000ofeHZ?m]F:P03Om]F:P00ol0003om=B]
ooCD[@09ooCD[@03o`000?onfICoo]VD00Goo]VD00Co0000oogOROomghWooMn91?l0000hoookJP03
o`000?oonf[ooo]Z02[ooo]Z000ZoookJP03o`000?oonf[ooo]Z04Gooo]Z0ol00002o`00;@03o`00
0?l003oo000000;o6@1W00?o0000odlRNOm?8WT02?m?8WT00ol0003oH3b@of0lT006of0lT0Co0000
3?moDi<2o`0000SoQEnN00Co0000oiU]Wol0003o00006onJL:800ol0003oZW^QojYkX@0IojYkX@03
o`000?n]Oj?o[GnS00Co[GnS00?o0000okV7X?niQj005oniQj000ol0003o_HfRokf=XP0;okf=XP03
o`000?o6TYooaY:O00WoaY:O00?o0000olbHX?o<V:004Oo<V:001Ol0003odYnRom:OX_oBWj;o0000
00OodYnR0_l00003omZKTP03o`000?oQXi7ohJ>A00[ohJ>A00?o0000onR[SooXZhl01?oXZhl01Ol0
003ojj5jon^QN_o[XG[o000000SoljUd00?o0000oo>J?oocVSl00_ocVSl00ol0003okILUo`00000]
oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003oi;VZonBiZP05
onBiZP03o`000?oO^k?ogk^c00?ogk^c00?o0000omZd/_oJ];803OoJ];800ol0003oeJjao`000006
omB]/@;o00002?oA/;P00ol0003ocJVfolfY]P0AolfY]P03o`000?o6X[CoaZ:d00_oaZ:d00?o0000
ol:Q]oo2XKL01Oo2XKL00ol0003o_YffokjM]P08okjM]PKo00002_nkWKT00ol0003o^Y^hokZK^002
okZK^003o`000?nbUk_o/YNk01[o/YNk00?o0000ok2C^On`TkT01?n`TkT00ol0003oYhjko`000004
o`0001WoYHNe00?o0000oiQo]_nHOkH07?nHOkH2ohQf^A[oQFf`00Go0000og1R/_m`H[;oL6:bo`00
000@ofeHZ003o`000?ode:gom=B]00Som=B]00?o0000ooWMZol000001_onfI@01?l0003ooMn9oogO
ROomghT4o`0003Sooo]Z00?o0000oookJ_oonfX0:_oonfX002[ooo]Z00?o0000oookJ_oonfX0AOoo
nfX2o`0000?o000]00?o0000o`00?ol000000_lI06L00ol0003oCb9iodlRN@07odlRN@03o`000?mP
?93oH3b@00OoH3b@00Co0000ogmCU?moDiCoOe>D1ol00003ogmCT`;o00002_n5Gih2o`0001goVW2R
00?o0000ojYkXOnZNj406?nZNj400ol0003o[GnSojeoX`06ojeoX`03o`000?niQj3o^HNP01Go^HNP
00?o0000okf=X_nmSJ803?nmSJ800ol0003oaY:OolJBW`08olJBW`03o`000?o<V:3oc9RP017oc9RP
00?o0000om:OX_oBWj800_oBWj800ol0003odYnRom:OXP05om:OXP03o`000?oHXYko000000?o0000
3?oQXi400ol0003oj:^?onR[S`05onR[S`;o000000?ojj5jo`000?ocZG@01oocZG@2o`0000?oliXo
00Co0000onfG9Ol0003o0000;?oonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z00co
oo]Z00?o0000onBiZ_oT^JX01ooT^JX00ol0003ogk^comnk/`02omnk/`03o`000?oJ];;of[Bb00go
f[Bb00?o0000omF^/Ol000002?oD[K42o`0000GodK2h00?o0000olfY]_o=ZKH04Oo=ZKH00ol0003o
aZ:dolJR]00=olJR]003o`000?o2XKOo`Z6g00?o`Z6g00?o0000okjM]_nnWKH03onnWKH6o`0000?o
^ifi00?o0000okZK^?njVkP00onjVkP00ol0003o/YNkok:G^`0Iok:G^`04o`000?n`TkWo/9>iok2C
^@Ko00007_nUQkD00ol0003oV7nfoiQo]P0KoiQo]P03o`000?n8M[WoQFf`01[oQFf`00Co0000og1R
/_m`H[;o00004?m]F:P00ol0003om=B]ooCD[@09ooCD[@03o`000?oigJ_o000000Koo]VD00Co0000
oogOROomghWooMn90_l000000ooPa4?o0000oookJP0goookJP03o`000?oonf[ooo]Z02[ooo]Z000Y
oookJP03o`000?oonf[ooo]Z04Gooo]Z0_l00004o`00;@;o00000olI06L00ol0003oCb9iodlRN@05
odlRN@;o00002_mP?9000ol0003oOe>DogmCU008ogmCU13o00007_nJL:800ol0003oZW^QojYkX@0C
ojYkXA_o00002oniQj000ol0003o_HfRokf=XP0<okf=XP03o`000?o6TYooaY:O00SoaY:O00?o0000
olbHX?o<V:004Oo<V:000ol0003odYnRom:OXP02om:OXP03o`000?oBWj;odYnR00GodYnR00?o0000
omRRW_oHXYh00_oHXYh2o`0000_ohJ>A00?o0000onR[SooXZhl01ooXZhl2o`0000SoljUd00?o0000
ooV`JOl000000_ocVSl01?l0003okILUonfG9Ol0000/oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003oi;VZonBiZP08onBiZP04o`000?oO^k?ogk^co`0000oof[Bb
00Go0000omF^/OoE[[7oeJjao`000009omB]/@03o`000?oA/;SodK2h00;odK2h00?o0000olfY]_o=
ZKH04?o=ZKH00ol0003oaZ:dolJR]00>olJR]003o`000?o2XKOo`Z6g00;o`Z6g00?o0000okjM]_nn
WKH05_nnWKH7o`0000?o^Y^h00?o0000ok:G^onbUk/02_nbUk/<o`000003ok:G^ol0003o000000?o
00001?naTK@00ol0003oYHNeojF7]@0NojF7]@03o`000?nHOkKoV7nf01SoV7nf0_l000000onEMk3o
0000ohE]/00KohE]/003og1R/_l0003oKERX013oKERX00?o0000ooCD[Oode:d02Oode:d00ol0003o
nMf[o`000005ookIU003o`000?omghWooMn900;ooMn90_l000000ooPa4?o0000oookJP0goookJP03
o`000?oonf[ooo]Z02[ooo]Z000YoookJP03o`000?oonf[ooo]Z04Gooo]Z0_l00003o`00;@;o0000
1?lI06L00ol0003oCb9iodlRN@04odlRN@03o`000?mP?93oH3b@00[oH3b@00?o0000ogmCU?moDi@0
1omoDi@2o`0000koQV:R00?o0000oiY`X_nJL:807OnJL:800ol0003oZW^QojYkX@09ojYkX@Wo0000
0_n[PjT00ol0003o[XR]ojj8[@09ojj8[@03o`000?niSZWo^HjY00[o^HjY3ol0000;okf=XP03o`00
0?o6TYooaY:O00OoaY:O00?o0000olbHX?o<V:004Oo<V:000ol0003odYnRom:OXP03om:OXP03o`00
0?oBWj;odYnR00KodYnR00Ko0000omRRW_oHXYkof::No`000?oNZYl2o`0000WohJ>A00?o0000onR[
SooXZhl02?oXZhl2o`0000OoljUd00Ko0000ooV`JOoi/6Wo0000oo>J?ol00002onfG9@03o`000?oo
nf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oT
^J[oi;VZ00[oi;VZ00?o0000omnk/ol000003ooJ];800ol0003oeJjaomF^/@02omF^/@03o`000?oD
[K7oe:fa00Ooe:fa0_l000000ooA/;So0000olfY]P0BolfY]P03o`000?o6X[CoaZ:d00ooaZ:d00Go
0000ol:Q]oo2XKOo`Z6go`00000JokjM]P03o`000?niUK?o^IFc00;o^IFc4?l0000;ok:B]@03o`00
0?naTKCo/I6d00So/I6d00?o0000ojF7]OnUQkD07_nUQkD00ol0003oV7nfoiQo]P0FoiQo]P;o0000
00?oUGN`o`000?l000001?l0000HohE]/0;o00004Om]F:P00ol0003om=B]ooCD[@09ooCD[@05o`00
0?oigJ_onMf[ooWMZol000001?onfI@00ol0003ooMn9oogOR@03oogOR@03o`000?oPa4?o000003So
oo]Z00?o0000oookJ_oonfX0:_oonfX002Wooo]Z00?o0000oookJ_oonfX0A?oonfX2o`0000Co000]
00?o0000oaT0IolI06L00olI06L00ol0003oCb9iodlRN@03odlRN@03o`000?mP?93oH3b@00_oH3b@
00?o0000ogmCU?moDi@01OmoDi@2o`00013oQV:R00?o0000oiY`X_nJL:807OnJL:801?l0003oZW^Q
ojYkXOnZNj48o`0000[oZh>Y00?o0000ojj8[On^R:d02_n^R:d00ol0003o^HjYokV>Z@0DokV>Z@03
o`000?nmTjco_I>/00;o_I>/2Ol00003okf=XP03o`000?o6TYooaY:O00KoaY:O00?o0000olbHX?o<
V:004Oo<V:000ol0003odYnRom:OXP03om:OXP03o`000?oBWj;odYnR00KodYnR00Co0000omRRW_oH
XYko00001?oNZYl00ol0003ohJ>Aon6ST@06on6ST@03o`000?oXZhooj:^?00Soj:^?00?o0000oo2d
SOl000001_ocZG@01_l0003onK1YooV`JOl0003oliXoo`0000?okILU00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000onBiZ_oT^JX02ooT
^JX2o`0000kof[Bb00?o0000omF^/OoE[[400ooE[[400ol0003oe:faomB]/@09omB]/@;o00004_o=
ZKH00ol0003oaZ:dolJR]00@olJR]004o`000?o2XKOo`Z6go`0001[o_Yff00?o0000okVE/oniUK<0
1_niUK<00ol0003o/Y:eok:B]@0Dok:B]@03o`000?naTKCo/I6d00[o/I6d00?o0000ojF7]OnUQkD0
7OnUQkD00ol0003oV7nfoiQo]P0BoiQo]POo00000onEMjl00ol0003oQFf`ohE]/004o`0001?oQFf`
00?o0000ogiSZOl000004Om]F:P00ol0003om=B]ooCD[@09ooCD[@05o`000?oigJ_onMf[ooWMZol0
00001?onfI@00ol0003ooMn9oogOR@03oogOR@03o`000?oPa4?o000003Sooo]Z00?o0000oookJ_oo
nfX0:_oonfX002Wooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003o000]o`00;@03o`00;@03o`00
0?lI06Oo6@1W00?o6@1W00?o0000odlRNOm?8WT00_m?8WT00ol0003oH3b@of0lT00=of0lT003o`00
0?moDiCoOe>D00;oOe>D0_l0000CohIRXP03o`000?nJL:;oVW2R01[oVW2R1_l0000Aoj^3Z@03o`00
0?n^R:go[XR]00co[XR]00?o0000okV>ZOniSZT04_niSZT00ol0003o_I>/okfC[00<okfC[0So0000
1?o6TYl00ol0003oc9RPolbHX00AolbHX003o`000?oBWj;odYnR00?odYnR00?o0000om:OX_oBWj80
1_oBWj801?l0003of::NomRRW_l00005omjZW`;o00001_oQXi400ol0003oj:^?onR[S`08onR[S`04
o`000?o`]8gol;B=o`0000GoljUd00Oo0000ooV`JOoi/6WonK1Yo`000?ocVSoo000000;okILU00?o
0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000onBiZ_oT^JX02ooT^JX00ol0003og[6Yo`00000=omZd/P03o`000?oE[[7oeJja00CoeJja00?o
0000omB]/OoD[K402?oD[K400ol0003ocjRao`000002o`0000oocJVf00?o0000olJR]?o6X[@04?o6
X[@00ol0003o`Z6go`00000JokjM]P03o`000?niUK?o^IFc00So^IFc00?o0000ok:B]OnbT[D04_nb
T[D00ol0003o/I6dok6A]00;ok6A]003o`000?nUQkGoYHNe01goYHNe00?o0000oiQo]_nHOkH03?nH
OkH8o`0000SoUGN_00?o0000ohE]/?n5KK001?n5KK04o`0000goQFf`0_l00002ogiSZ@03o`000?m]
F:SoKERX00ooKERX00?o0000ooCD[Oode:d02?ode:d00ol0003onMf[ooWMZ`03ooWMZ`05o`000?on
fICoo]VDookIU?l000001OomghT00ol0003oh<A3o`00000hoookJP03o`000?oonf[ooo]Z02[ooo]Z
000YoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000o`00;Ol002d00_l002d2o`0000Go6@1W00?o
0000odlRNOm?8WT00_l0000@of0lT003o`000?moDiCoOe>D00;o00005On6HZ800ol0003oVW2RoiY`
XP0FoiY`XPCo00000_nNO:d00ol0003oZh>Yoj^3Z@0Aoj^3Z@03o`000?n^R:go[XR]00go[XR]00?o
0000okV>ZOniSZT04OniSZT00ol0003o_I>/okfC[00@okfC[003o`000?o6V:SoaYRX00;oaYRX1_l0
000AolbHX003o`000?oBWj;odYnR00CodYnR00?o0000om:OX_oBWj801_oBWj801?l0003of::NomRR
W_l00007omjZW`;o00001?oQXi400ol0003oj:^?onR[S`08onR[S`05o`000?o`]8gol;B=oo2dSOl0
00001?ocZG@00ol0003onK1YooV`J@02ooV`J@;o00000_o]UbD2o`0002[ooo]Z00?o0000oookJ_oo
nfX0EOoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oT^J[oi;VZ00_oi;VZ00Co0000omjaZOoN
/JWog[6Y0_l0000:omZd/P03o`000?oE[[7oeJja00GoeJja00?o0000omB]/OoD[K401ooD[K400ol0
003ocjRaolnX/@03olnX/@?o00002oo=ZKH00ol0003oaZ:dolJR]00BolJR]003o`000?nnWKKo_Yff
01So_Yff00?o0000okVE/oniUK<02OniUK<00ol0003o/Y:eok:B]@0Aok:B]@03o`000?naTKCo/I6d
00co/I6d00?o0000ojF7]OnUQkD07OnUQkD00ol0003oV7nfoiQo]P07oiQo]PGo00000onHOkH2o`00
00_oUGN_00?o0000ohE]/?n5KK002?n5KK04o`0000OoQFf`0_l00004ogiSZ@03o`000?m]F:SoKERX
00koKERX00?o0000ooCD[Oode:d02Oode:d00ol0003onMf[ooWMZ`03ooWMZ`04o`000?onfICoo]VD
o`0000KooMn90_l0000ioookJP03o`000?oonf[ooo]Z02[ooo]Z000YoookJP03o`000?oonf[ooo]Z
04Cooo]Z00Oo0000o`00;Ol002go000]o`000?l4063o000000Go6@1W00?o0000odlRNOl000004_mP
?903o`0001OoQV:R00?o0000oiY`X_nJL:804OnJL:85o`0000KoWWb]00?o0000oj^3ZOn[PjT04?n[
PjT00ol0003o[XR]ojj8[@0>ojj8[@03o`000?niSZWo^HjY013o^HjY00?o0000okfC[?nmTj`04Onm
Tj`00ol0003oaYRXolJHZ005olJHZ003o`000?o;Wj_obin[00?o00003_o<V:000ol0003odYnRom:O
XP04om:OXP03o`000?oBWj;odYnR00KodYnR00?o0000omRRW_l000002_oNZYl01?l0003ohJ>Aon6S
TOl0000:onR[S`03o`000?o`]8gol;B=00?ol;B=00Go0000oo>YM?ocZGColjUdo`000005ooV`J@03
o`000?o]UbGokILU00;o0000:ooonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z00_o
oo]Z00?o0000onBiZ_oT^JX02ooT^JX00ol0003og[6YomjaZ@03omjaZ@03o`000?oJ];;of[Bb00Oo
f[Bb00?o0000omF^/OoE[[401_oE[[400ol0003oe:faomB]/@05omB]/@03o`000?o?Z;7ocjRa00Oo
cjRa0_l00008olfY]P03o`000?o6X[CoaZ:d01?oaZ:d00?o0000okjM]_nnWKH05onnWKH00ol0003o
^IFcokVE/`0:okVE/`03o`000?nbT[Go/Y:e013o/Y:e00?o0000ok6A]?naTK@03_naTK@00ol0003o
YHNeojF7]@0MojF7]@03o`000?nHOkKoV7nf00Ko00001_nHOkH2o`0000koUGN_00?o0000ohE]/?n5
KK002on5KK04o`0000;oQFf`00?o0000ogiSZOmnHjT01OmnHjT00ol0003oKERXofeHZ00<ofeHZ0;o
00002_ode:d00ol0003onMf[ooWMZ`05ooWMZ`03o`000?onfICo000000GooMn90ol0000joookJP03
o`000?oonf[ooo]Z02Wooo]Z000XoookJP03o`000?oonf[ooo]Z04Cooo]Z0_l00003o`00;@03o`00
0?l4063o000000Go6@1W0_l0000Bof0lT0;o00006On6HZ800ol0003oVW2RoiY`XP0=oiY`XPCo0000
3?nNO:d00ol0003oZh>Yoj^3Z@0>oj^3Z@03o`000?n^R:go[XR]00oo[XR]00?o0000okV>ZOniSZT0
4?niSZT00ol0003o_I>/okfC[00BokfC[003o`000?o6V:SoaYRX00?oaYRX00?o0000ol^OZoo;Wj/0
1?o;Wj/4o`0000Woc9RP00?o0000om:OX_oBWj801_oBWj800ol0003odYnRom:OXP06om:OXP;o0000
2ooNZYl3o`0000[oj:^?00?o0000oo2dSOo`]8d01?o`]8d01?l0003oljUdoo>YM?l00005ooV`J@05
o`000?o]UbGokILUonfG9Ol00000:ooonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z
00[ooo]Z00?o0000onBiZ_oT^JX03?oT^JX00ol0003og[6YomjaZ@04omjaZ@;o00001_oJ];800ol0
003oeJjaomF^/@07omF^/@03o`000?oD[K7oe:fa00Goe:fa00?o0000olnX/Oo?Z;402Oo?Z;43o`00
00GocJVf00?o0000olJR]?o6X[@04_o6X[@00ol0003oa9nco`00000GokjM]P03o`000?niUK?o^IFc
00co^IFc00?o0000ok:B]OnbT[D03OnbT[D2o`00017o/I6d00?o0000ojF7]OnUQkD07?nUQkD4o`00
00WoV7nf0ol0000@oiEg[`03o`000?n5KK3oQFf`00ooQFf`0ol00007ogiSZ@03o`000?m]F:SoKERX
00_oKERX0_l000000oo_e[So0000ooCD[@08ooCD[@03o`000?oigJ_onMf[00GonMf[00?o0000ookI
U?l000001OomghT3o`0003[ooo]Z00?o0000oookJ_oonfX0:OoonfX002Sooo]Z00?o0000oookJ_oo
nfX0A?oonfX01Ol0003o000]o`00;Ol002go000000;o101P00?o0000oaT0IolI06L00olI06L00ol0
003oH3b@of0lT00@of0lT003o`000?m[D:3o000001WoQV:R00?o0000oiY`X_nJL:802OnJL:84o`00
013oWWb]00?o0000oj^3ZOn[PjT03On[PjT00ol0003o[XR]ojj8[@0@ojj8[@03o`000?niSZWo^HjY
00oo^HjY00?o0000okfC[?nmTj`04onmTj`00ol0003oaYRXolJHZ003olJHZ003o`000?o;Wj_obin[
00Sobin[1?l00005olbHX003o`000?oBWj;odYnR00KodYnR00?o0000om:OX_oBWj801_oBWj82o`00
00gogZZO0_l00009onR[S`03o`000?o`]8gol;B=00Gol;B=00?o0000oo>YM?l000001Ooi/6T2o`00
00;okILU0_l0000ZoookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX02_oonfX00ol0
003oi;VZonBiZP0;onBiZP03o`000?oN/JWog[6Y00Oog[6Y00?o0000omZd/_oJ];800ooJ];800ol0
003oeJjaomF^/@08omF^/@03o`000?oD[K7oe:fa00?oe:fa00?o0000olnX/Oo?Z;403Oo?Z;43o`00
0003olfY]_l0003oaZ:d01?oaZ:d00Co0000olBO/oo4Wk?o00005_nnWKH00ol0003o^IFcokVE/`0=
okVE/`03o`000?nbT[Go/Y:e00co/Y:e00?o0000ok6A]?naTK@04OnaTK@00ol0003oYHNeojF7]@0J
ojF7]@;o000000?oY8Jdo`000?nHOkH02?nHOkH2o`0001?oUGN_00?o0000ohE]/?n5KK003_n5KK00
1?l0003oP6>Woh1SYon0HjL2o`0000GoOV>Y00?o0000ofeHZ?m]F:P02_m]F:P00ol0003oG4FNo`00
0002onoF^003o`000?ode:gom=B]00Kom=B]00?o0000ooWMZooigJ/01OoigJ/2o`0000KooMn90ol0
000joookJP03o`000?oonf[ooo]Z02Wooo]Z000XoookJP03o`000?oonf[ooo]Z04Cooo]Z00Co0000
o`00;Ol002go00000ol406000ol0003o6@1WoaT0I`03oaT0I`03o`000?mP?93oH3b@00koH3b@0_l0
0002of]@X003o`000?n6HZ;oQV:R01SoQV:R00?o0000oiY`X_nJL:800onJL:85o`0001CoWWb]00?o
0000oj^3ZOn[PjT03?n[PjT00ol0003o[XR]ojj8[@0Bojj8[@03o`000?niSZWo^HjY00go^HjY00?o
0000okfC[?nmTj`05?nmTj`00ol0003oaYRXolJHZ002olJHZ003o`000?o;Wj_obin[00gobin[0ol0
0002olbHX003o`000?oBWj;odYnR00KodYnR00?o0000om:OX_oBWj801_oBWj800ol0003ogZZOomjZ
W`0<omjZW`03o`000?oU/Ioo000000Soj:^?00?o0000oo2dSOo`]8d01_o`]8d2o`0000GonK1Y00Co
0000oobeFOl0003okILU0_l0000ZoookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0
2OoonfX2o`0000goi;VZ00?o0000omjaZOoN/JT02?oN/JT2o`0000;of[Bb00?o0000omF^/OoE[[40
2OoE[[400ol0003oe:faomB]/@03omB]/@03o`000?o?Z;7ocjRa013ocjRa0ol0000BolJR]005o`00
0?o4Wk?oa9ncolBO/ol000005OnnWKH00ol0003o^IFcokVE/`0>okVE/`03o`000?nbT[Go/Y:e00_o
/Y:e00?o0000ok6A]?naTK@04onaTK@00ol0003oYHNeojF7]@0FojF7]@?o00001?nTQ[@00ol0003o
V7nfoiQo]P04oiQo]P;o00005OnEMjl00ol0003oQFf`ohE]/00<ohE]/0;o00001_n0HjL00ol0003o
OV>YogiSZ@02ogiSZ@03o`000?m]F:SoKERX00WoKERX00?o0000oea5W_l000000oo_e[P00ol0003o
m=B]ooCD[@05ooCD[@03o`000?oigJ_onMf[00OonMf[00?o0000oogOROomghT00oomghT01?l0003o
m>1ho`000?l0000joookJP03o`000?oonf[ooo]Z02Wooo]Z000XoookJP03o`000?oonf[ooo]Z04?o
oo]Z0_l00002o`00;@05o`000?l4063o101Po`@0H?l000001?lI06L2o`0000ooH3b@00?o0000of]@
X?m[D:000_m[D:000ol0003oQV:RohIRXP0HohIRXP03o`000?nJL:;o000000?o00006OnNO:d00ol0
003oZh>Yoj^3Z@0;oj^3Z@03o`000?n^R:go[XR]01?o[XR]00?o0000okV>ZOniSZT03?niSZT00ol0
003o_I>/okfC[00FokfC[004o`000?o6V:SoaYRXo`0001?obin[0ol00008om:OXP03o`000?oBWj;o
dYnR00KodYnR00?o0000omjZWooNZYl03?oNZYl01?l0003oiK6OonFaWol00007onR[S`03o`000?o`
]8gol;B=00Ool;B=00?o0000ooV`JOoi/6T00ooi/6T01?l0003oo;EIo`000?o]UbD2o`0002[ooo]Z
00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oW]Ioo000000_oi;VZ
00?o0000omjaZOoN/JT02ooN/JT00ol0003of[Bbo`00000<omF^/@05o`000?oD[K7oe:faomB]/Ol0
00004oo?Z;400ol0003obZ6^olZQ[P03o`0000koaZ:d00?o0000olBO/oo4Wk<00oo4Wk<00ol0003o
_YffokjM]P0AokjM]P03o`000?niUK?o^IFc013o^IFc00?o0000ok:B]OnbT[D02OnbT[D00ol0003o
/I6dok6A]00Dok6A]003o`000?nUQkGoYHNe01CoYHNe0_l00007ojB6]004o`000?nHOkKoV7nfoiQo
]P?o00005onEMjl00ol0003oQFf`ohE]/00;ohE]/003o`000?n0HjOoP6>W00OoP6>W0_l00002ogiS
Z@03o`000?m]F:SoKERX00SoKERX00?o0000oea5W_l000001Oo_e[P00ol0003om=B]ooCD[@04ooCD
[@03o`000?oigJ_onMf[00OonMf[00?o0000oogOROomghT00oomghT01?l0003om>1ho`000?l0000j
oookJP03o`000?oonf[ooo]Z02Wooo]Z000XoookJP03o`000?oonf[ooo]Z04?ooo]Z0_l000000ol0
02go0000o`@0H003o`@0H007o`000?lI06Oo6@1WoaT0Iol0003o=1b5o`00000>of0lT003o`000?m[
D:3oJe2P00?oJe2P00?o0000ohIRX_n6HZ805on6HZ83o`0001koWWb]00?o0000oj^3ZOn[PjT02On[
PjT00ol0003o[XR]ojj8[@0Dojj8[@03o`000?niSZWo^HjY00_o^HjY00?o0000okfC[?nmTj`05onm
Tj`01?l0003oaYRXolJHZ?l0000Dol^OZ`03o`000?o?Y:co000000;o00001OoBWj800ol0003odYnR
om:OXP06om:OXP;o00003?oNZYl00ol0003oiK6OonFaW`02onFaW`03o`000?oXZhooj:^?00Coj:^?
00?o0000oo2dSOo`]8d01oo`]8d00ol0003onK1YooV`J@03ooV`J@03o`000?ol]EWoo;EI00;o0000
00?of8/2o`000?oonfX0:?oonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z00Wooo]Z
00Co0000onNeWooW]Ioo00002_oT^JX00ol0003og[6YomjaZ@0<omjaZ@;o00003OoE[[400ol0003o
e:fao`00000ColnX/@03o`000?o:XJkobZ6^00CobZ6^1?l0000:olJR]003o`000?o4Wk?oa9nc00?o
a9nc00?o0000okjM]_nnWKH04OnnWKH00ol0003o^IFcokVE/`0@okVE/`03o`000?nbT[Go/Y:e00So
/Y:e00?o0000ok6A]?naTK@05OnaTK@00ol0003oYHNeojF7]@0BojF7]@;o00002OnTQ[@01?l0003o
V7nfo`000?l0000KoiEg[`03o`000?n5KK3oQFf`00SoQFf`0_l0000<oh1SY`;o000000?oOV>Yo`00
0?m]F:P01om]F:P01?l0003oG4FNoea5W_l00006onoF^003o`000?ode:gom=B]00;om=B]00?o0000
ooWMZooigJ/01ooigJ/2o`0000GooMn900Co0000ooCPN?l0003o0000>_oonfX00ol0003ooo]Zoook
JP0YoookJP00:?oonfX00ol0003ooo]ZoookJP13oookJP?o00001Ol406001?l0003o6@1WoaT0Iol0
0002oc@LQ@03o`000?mP?93oH3b@00[oH3b@0_l00007of]@X003o`000?n6HZ;oQV:R01CoQV:R0_l0
00000on<L:ko0000oiil[@0Noiil[@03o`000?n[PjWoZh>Y00SoZh>Y00?o0000ojj8[On^R:d05On^
R:d00ol0003o^HjYokV>Z@0;okV>Z@03o`000?nmTjco_I>/01Oo_I>/00?o0000olJHZ?l000005?o;
Wj/00ol0003ocjB/olnT[003olnT[0?o00000_oBWj800ol0003odYnRom:OXP05om:OXP03o`000?oI
YjCo000000cogZZO00?o0000onFaWooU/Il00ooU/Il2o`0000Coj:^?00?o0000oo2dSOo`]8d01oo`
]8d2o`0000ConK1Y00Go0000oobeFOol]EWo0000onfG9@02o`0002Wooo]Z00?o0000oookJ_oonfX0
DooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oW]IooikFO00;oikFO00?o0000onBiZ_oT^JX0
1ooT^JX00ol0003og[6YomjaZ@0<omjaZ@04o`000?oIZjSo0000o`0000_oeJja00?o0000omB]/Ol0
00004_o?Z;400ol0003obZ6^olZQ[P09olZQ[P?o00001_o6X[@00ol0003oa9ncolBO/`04olBO/`03
o`000?nnWKKo_Yff013o_Yff00?o0000okVE/oniUK<04_niUK<00ol0003o/Y:eok:B]@05ok:B]@;o
00006OnaTK@00ol0003oYHNeojF7]@0?ojF7]@;o00002_nTQ[@3o`0001goUGN_00?o0000ohE]/?n5
KK001_n5KK02o`00013oP6>W0_l00007ofeHZ004o`000?mLAIkoG4FNo`0000OokmJh00?o0000ooCD
[Oode:d00_ode:d00ol0003onMf[ooWMZ`07ooWMZ`03o`000?okijGo000000?ooMn900?o0000ooCP
N?odh7P00_l0000joookJP03o`000?oonf[ooo]Z02Wooo]Z000WoookJP03o`000?oonf[ooo]Z04?o
oo]Z0_l000000ol002go0000o`@0H004o`@0H003o`000?lI06Oo000000?o=1b500?o0000of0lT?mP
?9002OmP?9000ol0003oJe2Pof]@X007of]@X003o`000?n6HZ;oQV:R01;oQV:R0_l00003oha`[P03
o`000?nNO:goWWb]01goWWb]00?o0000oj^3ZOn[PjT01on[PjT00ol0003o[XR]ojj8[@0Gojj8[@03
o`000?niSZWo^HjY00Wo^HjY00?o0000okfC[?nmTj`06OnmTj`2o`0001Cobin[00?o0000olnT[?o?
Y:`01_o?Y:`3o`0000OodYnR00?o0000omVWY?l000003?oNZYl00ol0003oiK6OonFaW`05onFaW`04
o`000?oXZhooj:^?o`0000[ol;B=00?o0000ooRmQol000001?oi/6T00ol0003oo;EIoobeF@03o`00
02[ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oW]IooikFO
00?oikFO0_l00006onBiZP03o`000?oN/JWog[6Y00cog[6Y00?o0000omV[Z?oIZjP00_oIZjP2o`00
00[oeJja00?o0000olnX/Oo?Z;404Oo?Z;400ol0003obZ6^olZQ[P0<olZQ[P?o00000_o6X[@00ol0
003oa9ncolBO/`06olBO/`03o`000?nnWKKo_Yff00ko_Yff00?o0000okVE/oniUK<04oniUK<00ol0
003o/Y:eok:B]@04ok:B]@03o`000?naTKCo/I6d01Wo/I6d00?o0000ojF7]OnUQkD03OnUQkD2o`00
00OoY8Jd1Ol00002oj>0[P03o`000?nEMjooUGN_01_oUGN_00?o0000ohE]/?n5KK001On5KK000ol0
003oP6>Woh1SY`0Aoh1SY`;o00001Om]F:P01Ol0003oG4FNoea5W_mLAIko000000SokmJh00Co0000
ooCD[Oode:go00002OoigJ/01?l0003onnNUoo_WYOl00003oogOR@03o`000?odh7Som>1h00;o0000
>_oonfX00ol0003ooo]ZoookJP0YoookJP009ooonfX00ol0003ooo]ZoookJP13oookJP?o00001_l4
0602o`0000Co=1b500?o0000of0lT?mP?9001omP?902o`0000[oJe2P00?o0000ohIRX_n6HZ804?n6
HZ82o`0000KoS72^00?o0000oiil[OnNO:d07?nNO:d00ol0003oZh>Yoj^3Z@06oj^3Z@03o`000?n^
R:go[XR]01So[XR]00?o0000okV>ZOniSZT02?niSZT00ol0003o_I>/okfC[00JokfC[003o`000?o;
Wj_obin[01;obin[00?o0000olnT[?o?Y:`02Oo?Y:`4o`0000CodYnR00Co0000omVWY?oIYjCo0000
2ooNZYl00ol0003oiK6OonFaW`06onFaW`03o`000?oXZhoo000000Wol;B=00Go0000ooRmQooh_HOo
n;f7o`000003ooV`J@04o`000?ol]EWoo;EIoobeF@;o0000:_oonfX00ol0003ooo]ZoookJP1Boook
JP03o`000?oonf[ooo]Z00Wooo]Z00?o0000onNeWooW]Il01OoW]Il00ol0003oi;VZonBiZP03onBi
ZP03o`000?oN/JWog[6Y00cog[6Y00?o0000omV[Z?oIZjP01?oIZjP2o`0000SoeJja00?o0000olnX
/Oo?Z;404?o?Z;400ol0003obZ6^olZQ[P0@olZQ[PCo00001oo4Wk<00ol0003o_YffokjM]P0=okjM
]P03o`000?niUK?o^IFc01Co^IFc00?o0000ok:B]OnbT[D00onbT[D00ol0003o/I6dok6A]00Jok6A
]003o`000?nUQkGoYHNe00[oYHNe0ol00004ojB6]0Go00001onSP:h00ol0003oUGN_oiEg[`0KoiEg
[`03o`000?n5KK3oQFf`00?oQFf`0_l0000Doh1SY`03o`000?m]F:So000000?oKERX00Oo0000oea5
W_mLAIkoG4FNo`000?oYf<;o000000OokmJh00Co0000ooCD[Oode:go00002OoigJ/01?l0003onnNU
oo_WYOl00003oogOR@03o`000?odh7Som>1h00;o0000>ooonfX00ol0003ooo]ZoookJP0XoookJP00
9ooonfX00ol0003ooo]ZoookJP13oookJP;o00001ol406000ol0003o=1b5oc@LQ@03oc@LQ@03o`00
0?mP?93oH3b@00KoH3b@00?o0000of]@X?m[D:002_m[D:000ol0003oQV:RohIRXP0>ohIRXP;o0000
2?n<L:h00ol0003oWWb]oiil[@0Loiil[@03o`000?n[PjWoZh>Y00GoZh>Y00?o0000ojj8[On^R:d0
6On^R:d00ol0003o^HjYokV>Z@07okV>Z@03o`000?nmTjco_I>/01_o_I>/00?o0000ol^OZoo;Wj/0
4_o;Wj/00ol0003ocjB/olnT[009olnT[004o`000?o?Y:cocjB/olnT[0Co00000ooIYj@00ol0003o
gZZOomjZW`08omjZW`03o`000?oU/IooiK6O00SoiK6O0_l00009oo2dS@03o`000?oh_HOon;f700;o
n;f700Co0000ooV`JOoi/6Wo00000ool]ET00ol0003of8/2o`00000YoookJP03o`000?oonf[ooo]Z
05;ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003oikFOonNeW`06onNeW`05o`000?oT^J[oi;VZ
onBiZ_l000003ooN/JT00ol0003ofJ^XomV[Z006omV[Z003o`000?oE[[7oeJja00CoeJja00?o0000
om6Y[ol000004Oo?Z;400ol0003obZ6^olZQ[P0AolZQ[P03o`000?o3VZgo`iZ]00Co00000oo4Wk<0
0ol0003o_YffokjM]P0<okjM]P03o`000?niUK?o^IFc01Ko^IFc00Go0000ok:B]OnbT[Go/Y:eo`00
000Nok6A]003o`000?nUQkGoYHNe00OoYHNe0_l00002ojB6]0Go00003OnSP:h00ol0003oUGN_oiEg
[`0JoiEg[`03o`000?n5KK3oQFf`00;oQFf`00?o0000oh1SYon0HjL05On0HjL01Ol0003oKERXo`00
0?m]F:So000000?oG4FN00Go0000onWH`_oYf<;ojMS2o`000007onoF^003o`000?ode:go000000Wo
nMf[00Go0000oo_WYOokijGonnNUo`000002oogOR@03o`000?odh7Som>1h00;o0000>ooonfX00ol0
003ooo]ZoookJP0XoookJP009ooonfX00ol0003ooo]ZoookJP12oookJP?o00001ol406000ol0003o
=1b5oc@LQ@03oc@LQ@03o`000?mP?93oH3b@00GoH3b@00?o0000of]@X?m[D:002om[D:000ol0003o
QV:RohIRXP0<ohIRXP;o00002_n<L:h00ol0003oWWb]oiil[@0Moiil[@03o`000?n[PjWoZh>Y00?o
Zh>Y00?o0000ojj8[On^R:d06_n^R:d00ol0003o^HjYokV>Z@07okV>Z@03o`000?nmTjco_I>/01[o
_I>/0_l0000Col^OZ`03o`000?o?Y:cocjB/00[ocjB/00?o0000olnT[?o?Y:`01?o?Y:`2o`0000?o
fJNT00?o0000omjZWooNZYl01ooNZYl00ol0003oiK6OonFaW`09onFaW`;o00002?o`]8d00ol0003o
n;f7ooRmQ`03ooRmQ`03o`000?oi/6Wo000000?oo;EI0ol0000YoookJP03o`000?oonf[ooo]Z05;o
oo]Z00?o0000oookJ_oonfX02?oonfX00ol0003oikFOonNeW`08onNeW`04o`000?oT^J[oi;VZo`00
00kog[6Y00?o0000omV[Z?oIZjP02?oIZjP2o`0000?oeJja00Co0000om6Y[ooAZJoo00004?o?Z;40
0ol0003obZ6^olZQ[P0AolZQ[P03o`000?o3VZgo`iZ]00Go`iZ]0ol000000oo4Wk?o0000okjM]P0;
okjM]P03o`000?niUK?o^IFc01Oo^IFc00Co0000ok:B]OnbT[Go00007onaTK@00ol0003oYHNeojF7
]@05ojF7]@Ko00004_nSP:h00ol0003oUGN_oiEg[`0KoiEg[`04o`000?n5KK3o0000o`0001SoP6>W
00Co0000ofeHZ?m]F:So00001?mLAIh00ol0003ojMS2onWH`P02onWH`P03o`000?o_e[SokmJh00Go
kmJh00?o0000ooWMZooigJ/01ooigJ/00ol0003onnNUoo_WY@02oo_WY@03o`000?omghWo000000?o
m>1h0_l0000koookJP03o`000?oonf[ooo]Z02Sooo]Z000WoookJP03o`000?oonf[ooo]Z04;ooo]Z
0ol00006o`@0H003o`000?lU4h?o000000Co=1b500?o0000of0lT?mP?9000omP?902o`0000koJe2P
00?o0000ohIRX_n6HZ802On6HZ83o`0000coS72^00?o0000oiil[OnNO:d07OnNO:d00ol0003oZh>Y
oj^3Z@02oj^3Z@03o`000?n^R:go[XR]01_o[XR]00?o0000okV>ZOniSZT01_niSZT00ol0003o_I>/
okfC[00JokfC[004o`000?o1VZoo`IZ_o`0001;obin[00?o0000olnT[?o?Y:`02_o?Y:`00ol0003o
cjB/olnT[004olnT[006o`000?oF[Joo0000o`000?oIYjCo00002OoNZYl00ol0003oiK6OonFaW`09
onFaW`03o`000?o/^ioo000000Ool;B=00?o0000ooRmQooh_HL01?oh_HL2o`0000?oo;EI0ol0000Y
oookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003oikFOonNeW`09
onNeW`03o`000?oT^J[o000000kog[6Y00?o0000omV[Z?oIZjP02_oIZjP2o`000005omF^/Ol0003o
dJV_om6Y[ol000003oo?Z;400ol0003obZ6^olZQ[P0BolZQ[P03o`000?o3VZgo`iZ]00So`iZ]1Ol0
0008okjM]P03o`000?niUK?o^IFc01So^IFc00?o0000ok:B]Ol000008?naTK@00ol0003oYHNeojF7
]@03ojF7]@?o00005onSP:h00ol0003oUGN_oiEg[`0KoiEg[`;o00006_n0HjL01?l0003oKERXofeH
Z?l00003oea5WP03o`000?oYf<;ojMS200CojMS200?o0000onoF^?o_e[P01?o_e[P00ol0003onMf[
ooWMZ`07ooWMZ`03o`000?okijGonnNU00;onnNU00?o0000oogOROl000000oodh7P2o`0003_ooo]Z
00?o0000oookJ_oonfX0:?oonfX002Oooo]Z00?o0000oookJ_oonfX0@_oonfX3o`0000Go101P00Co
0000obDCPolU4h?o00001?ld78D00ol0003oH3b@of0lT002of0lT003o`000?m[D:3oJe2P00koJe2P
00?o0000ohIRX_n6HZ801on6HZ82o`0000ooS72^00?o0000oiil[OnNO:d07OnNO:d01Ol0003oZh>Y
oj^3ZOn[PjWo000001oo[XR]00?o0000okV>ZOniSZT01?niSZT00ol0003o_I>/okfC[00JokfC[005
o`000?o1VZoo`IZ_ol6J[ol000004Oo;Wj/00ol0003ocjB/olnT[00;olnT[003o`000?o?Y:cocjB/
00?ocjB/00?o0000omJ][ooF[Jl00_oF[Jl2o`0000SogZZO00?o0000onFaWooU/Il02_oU/Il01?l0
003ok;^OonbkWol00006oo2dS@03o`000?oh_HOon;f700Gon;f700Ko0000oobeFOol]EWoo;EIo`00
0?od]442o`0002Sooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?oW]IooikFO00[oikFO0_l0000=omjaZ@03o`000?oIZjSofJ^X00gofJ^X0_l00003om6Y[`03o`00
0?o?Z;7ocjRa00cocjRa00?o0000olZQ[_o:XJh04Oo:XJh00ol0003o`iZ]ol>J[@0:ol>J[@04o`00
0?noV:oo_iR_oknH[`Go00000_nnWKH00ol0003o^IFcokVE/`0IokVE/`;o00008_naTK@00ol0003o
YHNeo`000002o`0001[oXh2^00?o0000oiEg[onEMjl06_nEMjl2o`0001coP6>W0_l000001?mSAico
0000oea5W_l00008onWH`P03o`000?o_e[SokmJh00;okmJh00?o0000ooCP^?l000001ooigJ/00ol0
003onnNUoo_WY@03oo_WY@03o`000?omghWo000000?om>1h0_l0000koookJP03o`000?oonf[ooo]Z
02Sooo]Z000WoookJP03o`000?oonf[ooo]Z04;ooo]Z0ol00004o`@0H005o`000?lU4h?o9A>3obDC
Pol000001?ld78D01Ol0003oH3b@of0lT?mP?93o0000017oJe2P00?o0000ohIRX_n6HZ801On6HZ82
o`0001;oS72^00?o0000oiil[OnNO:d07?nNO:d01?l0003oZh>Yoj^3ZOl0000Gojj8[AGo00006?nm
Tj`01Ol0003o`IZ_ol6J[oo1VZoo0000017obin[00?o0000olnT[?o?Y:`02oo?Y:`00ol0003ocjB/
olnT[003olnT[003o`000?oF[JooeZf_00CoeZf_0_l00006omjZW`03o`000?oU/IooiK6O00WoiK6O
00?o0000onbkWoo/^il00_o/^il2o`0000Col;B=00?o0000ooRmQooh_HL01Ooh_HL01_l0003oo;EI
oobeFOol]EWo0000ooBd@@;o0000:?oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z
00Oooo]Z00?o0000onNeWooW]Il02ooW]Il00ol0003ohZjOo`00000<omjaZ@03o`000?oIZjSofJ^X
00gofJ^X00Ko0000om:TZ?l0003o0000om6Y[ol0000=olnX/@03o`000?o:XJkobZ6^017obZ6^00?o
0000ol>J[Oo3VZd03?o3VZd00ol0003o_iR_oknH[`05oknH[`Wo00005?niUK<00ol0003o^9Bbo`00
000Jok6A]0co00007?nSP:h00ol0003oUGN_oiEg[`0FoiEg[`?o000000?oTVjWo`000?n0HjL06_n0
HjL2o`0000;oHdNL0_l0000:onWH`P04o`000?o_e[SokmJho`0000;om>2h00?o0000ooWMZooigJ/0
1OoigJ/00ol0003onnNUoo_WY@04oo_WY@04o`000?odh7Som>1hooCPN0;o000000?ooo]Zo`000?oo
nfX0>OoonfX00ol0003ooo]ZoookJP0XoookJP009_oonfX00ol0003ooo]ZoookJP13oookJP?o0000
1?l406000ol0003o9A>3obDCP`02obDCP`05o`000?ld78Go=1b5oc@LQOl000000_mP?90Dof]@X003
o`000?n6HZ;oQV:R00;oQV:R0_l0000Doha`[P03o`000?nNO:goWWb]01goWWb]0_l00007ojj8[A7o
00002On_S[@00ol0003o^I>`okVC/003okVC/003o`000?nmVK?o_IVc00?o_IVc2Ol0000>okfC[003
o`000?o1VZoo`IZ_00;o`IZ_00?o0000ol^OZoo;Wj/03_o;Wj/00ol0003ocjB/olnT[00<olnT[003
o`000?o?Y:cocjB/00;ocjB/00?o0000omJ][ooF[Jl01OoF[Jl01?l0003ofjjYo`000?l00004omjZ
W`03o`000?oU/IooiK6O00WoiK6O00?o0000onbkWoo/^il01?o/^il01Ol0003ol;B=oo2dSOo`]8go
000000Oon;f70_l00002oobeF@04o`000?od]47o0000o`0002Wooo]Z00?o0000oookJ_oonfX0D?oo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oW]IooikFO00[oikFO00Co0000on:^WooR[YoohZjO
0_l0000:omjaZ@03o`000?oIZjSofJ^X00cofJ^X00?o0000om:TZ?oBY:P00_oBY:P2o`0000cocjRa
00?o0000olZQ[_o:XJh04_o:XJh00ol0003o`iZ]ol>J[@0<ol>J[@03o`000?noV:oo_iR_00Ko_iR_
00?o0000okbD[onlU:l01OnlU:l=o`0000Ko^IFc00Go0000okRD/_nhU;;o^9Bbo`000008ok6A]17o
00002?n_RZh2o`0001koXh2^00?o0000oiEg[onEMjl05?nEMjl2o`0000CoTVjW00?o0000oh1SYon0
HjL05on0HjL2o`000003ogaHWOl0003oHdNL00;oHdNL00?o0000onWH`_oYf<802OoYf<800ol0003o
kmJho`000003ooCP^003o`000?oigJ_onMf[00?onMf[00?o0000oo_WYOokijD01OokijD01?l0003o
m>1hooCPN?odh7P2o`000003oookJ_l0003ooo]Z03Wooo]Z00?o0000oookJ_oonfX0:?oonfX002Ko
oo]Z00?o0000oookJ_oonfX0@_oonfX4o`0000?o101P00?o0000obDCPolU4h<00olU4h<01?l0003o
=1b5oc@LQOld78D2o`0001GoJe2P00?o0000ohIRX_n6HZ800_l0000Foha`[P03o`000?nNO:goWWb]
01_oWWb]2ol0000Kojn>]005o`000?niTk3o^I>`okVC/?l000003onmVK<9o`0000Co_I>/00?o0000
ol6J[oo1VZl00oo1VZl00ol0003obin[ol^OZ`0>ol^OZ`03o`000?o?Y:cocjB/00cocjB/00Go0000
olnT[?o?Y:cocjB/o`000009omJ][`04o`000?oK[ZWofjjYo`0000?ogZZO00?o0000onFaWooU/Il0
2OoU/Il00ol0003ok;^OonbkW`05onbkW`03o`000?o`]8go000000Son;f700?o0000ook6Ool00000
0_ol]ET00ol0003om;A1o`00000YoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003oikFOonNeW`0:onNeW`03o`000?oR[YoohZjO00?ohZjO00?o0000omjaZOoN/JT0
1_oN/JT00ol0003ofJ^XomV[Z00=omV[Z003o`000?oBY:SodZBX00CodZBX0_l0000:olnX/@03o`00
0?o:XJkobZ6^017obZ6^00?o0000ol>J[Oo3VZd03Oo3VZd00ol0003o_iR_oknH[`05oknH[`03o`00
0?nlU:oo_9B_01?o_9B_4ol0000Hojn:[P;o00007onSP:h00ol0003oUGN_oiEg[`0AoiEg[`?o0000
1onBKZL00ol0003oP6>Woh1SY`0Eoh1SY`05o`000?mlF9goO5RMogaHWOl000000_mSAi`00ol0003o
jMS2onWH`P0;onWH`P;o00000oodh;P00ol0003onMf[ooWMZ`03ooWMZ`03o`000?okijGonnNU00Go
nnNU00Co0000ooCPN?odh7Som>1h0_l000000ooonf[o0000oookJP0ioookJP03o`000?oonf[ooo]Z
02Sooo]Z000VoookJP03o`000?oonf[ooo]Z04;ooo]Z0ol00003o`@0H003o`000?lU4h?o9A>300Go
9A>300Co0000oc@LQOld78Go00005_m[D:000ol0003oQV:Ro`00000Hoha`[P03o`000?nNO:goWWb]
01OoWWb]1Ol000000onRQ[Oo0000ojn>]00Rojn>]004o`000?niTk3o^I>`o`0001Wo_IVc2?l00003
ol6J[`03o`000?o;Wj_obin[00cobin[00?o0000olnT[?o?Y:`03Oo?Y:`01Ol0003ocjB/olnT[?o?
Y:co000000WoeZf_00Co0000om^^ZOoK[ZWofjjY0ol0000;onFaW`03o`000?o/^iook;^O00Ook;^O
0_l00007ooRmQ`04o`000?onaWooo/Ioo`0000;oo;EI00Co0000ooBd@Ol0003o0000:?oonfX00ol0
003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000onNeWooW]Il02_oW]Il00ol0
003ohZjOon:^W`04on:^W`;o00001_oN/JT00ol0003ofJ^XomV[Z00=omV[Z003o`000?oBY:SodZBX
00CodZBX00Co0000om6SZOl0003o00001oo?Z;400ol0003obZ6^olZQ[P0BolZQ[P03o`000?o3VZgo
`iZ]00ko`iZ]00?o0000oknH[onoV:l00onoV:l00ol0003o_9B_okbD[`0IokbD[`03o`000?nhSjco
^8n/00;o^8n/00?o0000ojn:[_n_RZh07On_RZh00ol0003o[HN/o`00000Ooj>0[P03o`000?nEMjoo
UGN_00ooUGN_0_l0000:oi9^Y`03o`000?n0HjOoP6>W01?oP6>W0_l00004ogaHW@03o`000?mSAico
000000kojMS200?o0000onkS`ol000000oodh;P01Ol0003onMf[ooWMZooigJ_o000000OonnNU0_l0
0003ooCPN004o`000?oonf[ooo]Zo`0003_ooo]Z00?o0000oookJ_oonfX09ooonfX002Kooo]Z00?o
0000oookJ_oonfX0@_oonfX3o`0000;o101P00?o0000obDCPolU4h<01_lU4h<01?l0003o=1b5oc@L
QOl0000Eof]@X0;o00006on<L:h00ol0003oWWb]oiil[@0Coiil[@?o000000?oWh6bo`000?l00000
0onRQ[L00ol0003o[hjdojn>]00Qojn>]003o`000?niTk3o000001go_IVc00?o0000ol2O]oo0WkL0
0_o0WkL6o`0000cobin[00?o0000olnT[?o?Y:`03Oo?Y:`01?l0003ocjB/olnT[?l0000:omJ][`03
o`000?oK[ZWofjjY00?ofjjY0_l0000:onFaW`03o`000?o/^iook;^O00Sok;^O00?o0000ooRmQooh
_HL01Ooh_HL01ol0003oo/Ioook6OoonaWoo0000oobeFOl000000_od]4400ol0003ooo]ZoookJP0V
oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003oikFOonNeW`0:
onNeW`03o`000?oR[YoohZjO00OohZjO00?o0000omjaZOoN/JT00_oN/JT00ol0003ofJ^XomV[Z00=
omV[Z003o`000?oBY:SodZBX00KodZBX00?o0000om6SZOoAXjT00ol00004olnX/@03o`000?o:XJko
bZ6^017obZ6^00?o0000ol>J[Oo3VZd03oo3VZd00ol0003o_iR_oknH[`03oknH[`03o`000?nlU:oo
_9B_01So_9B_00?o0000okR?[?nhSj`00onhSj`00ol0003o[hZ^ojn:[P0Lojn:[P04o`000?n]Qjco
[HN/o`0001ooXh2^00?o0000oiEg[onEMjl03?nEMjl3o`0000coTVjW00?o0000oh1SYon0HjL04On0
HjL2o`0000KoO5RM00?o0000of=7W?l000003OoYf<801Ol0003ok^?3onkS`oo^hl?o000000;om>2h
00Go0000ooWMZooigJ_onMf[o`000007oo_WY@;o00000_odh7P2o`0000;ooo]Z00?o0000oookJ_oo
nfX0>OoonfX00ol0003ooo]ZoookJP0WoookJP009_oonfX00ol0003ooo]ZoookJP12oookJP03o`00
0?l002[o000000;o101P00?o0000obDCPolU4h<01_lU4h<01?l0003o=1b5o`000?l0000Dof]@X003
o`000?mdGjco000001_oS72^00?o0000oiil[OnNO:d03onNO:d4o`0000;oWh6b0_l00006oj:6]`03
o`000?n_S[Co[hjd023o[hjd0_l0000MokfI/`03o`000?o0WkOo`9ng00Ko`9ng00?o0000olVR/_o9
X[801Ol00006ol^OZ`03o`000?o?Y:cocjB/00oocjB/00?o0000olnT[?l000002ooF[Jl00ol0003o
fjjYom^^Z@02om^^Z@03o`000?oQ]jco000000WoiK6O00?o0000onbkWoo/^il02?o/^il00ol0003o
n;f7ooRmQ`05ooRmQ`07o`000?onaWooo/Ioook6Ool0003oo;EIo`000002ooBd@@03o`000?oonf[o
oo]Z02Kooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP07oookJP;o00002ooW]Il0
0ol0003ohZjOon:^W`08on:^W`;o00000_oN/JT00ol0003ofJ^XomV[Z00=omV[Z003o`000?oBY:So
dZBX00KodZBX00?o0000om6SZOoAXjT00ooAXjT2o`000003olnX/Ol0003obZ6^01?obZ6^00?o0000
ol>J[Oo3VZd03oo3VZd00ol0003o_iR_oknH[`02oknH[`03o`000?nlU:oo_9B_01So_9B_00?o0000
okR?[?nhSj`01OnhSj`00ol0003o[hZ^ojn:[P0Jojn:[P03o`000?n]Qjco[HN/00;o[HN/00?o0000
oj>0[_nSP:h07OnSP:h00ol0003oUGN_oiEg[`09oiEg[`;o00003onBKZL00ol0003oP6>Woh1SY`0@
oh1SY`03o`000?mlF9goO5RM00OoO5RM00?o0000onWH`_oYf<802ooYf<800ol0003ok^?3onkS``03
onkS``?o00000ooigJ/00ol0003onnNUoo_WY@04oo_WY@03o`000?ogk9So000000;om>1h0_l00002
oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09ooonfX002Kooo]Z00?o0000oook
J_oonfX0@_oonfX01Ol0003o000Zo`000?l4063o000000[o9A>300?o0000odHeVOl000004om[D:00
1?l0003oM5n/ogAO[?l0000Koha`[P03o`000?nNO:goWWb]00_oWWb]1?l00004oin1/P;o00002?nR
Q[L00ol0003o[hjdojn>]00Oojn>]003o`000?naTkOo000001co_IVc00?o0000ol2O]oo0WkL02?o0
WkL00ol0003obJ:bolVR/P04olVR/PCo00000_o;Wj/00ol0003ocjB/olnT[00?olnT[0;o00003?oF
[Jl01Ol0003ofjjYom^^ZOoK[ZWo000000?ohKN/0_l00007onFaW`03o`000?o/^iook;^O00Sok;^O
0_l00006ooRmQ`03o`000?onaWooo/Io00;oo/Io0_l00002ooBd@@03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?o[[i7o000000[oikFO
00?o0000on:^WooR[Yl02_oR[Yl00ol0003og[6Yo`00000>omV[Z003o`000?oBY:SodZBX00OodZBX
00?o0000om6SZOoAXjT01OoAXjT3o`0001;obZ6^00?o0000ol>J[Oo3VZd04Oo3VZd01?l0003o_iR_
oknH[ol0000KokbD[`03o`000?nhSjco^8n/00Go^8n/00?o0000ojn:[_n_RZh06On_RZh00ol0003o
[HN/ojf7[003ojf7[003o`000?nSP:koXh2^01goXh2^00?o0000oiEg[onEMjl01onEMjl2o`0001;o
TVjW00?o0000oh1SYon0HjL03On0HjL2o`0000WoO5RM00?o0000onWH`_oYf<803?oYf<800ol0003o
k^?3onkS``05onkS``;o000000?onMf[o`000?okijD01_okijD01?l0003omnbHo`000?odh7P2o`00
00?ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0WoookJP009OoonfX00ol0003o
oo]ZoookJP13oookJP04o`000?l002[o0000o`0000_o9A>300?o0000odHeVOl000004Om[D:02o`00
00?oM5n/00?o0000oha`[_n<L:h06On<L:h00ol0003oWWb]oiil[@07oiil[@Co00001_nOPK82o`00
00[oXXJg00?o0000ojn>]?n_S[@07_n_S[@01Ol0003o/I>gok6C]onaTkOo000001[o_IVc00?o0000
ol2O]oo0WkL02Oo0WkL00ol0003obJ:bolVR/P08olVR/P?o00004Oo?Y:`2o`0000goeZf_00Co0000
om^^ZOoK[ZWo00001OoQ]j`00ol0003oiK6OonFaW`03onFaW`03o`000?o/^iook;^O00Sok;^O00Co
0000ooC5WOodaIgo00001Ooh_HL00ol0003oo/Ioook6O`03ook6O`04o`000?od]47om;A1o`0002So
oo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP07oookJP04o`000?o[[i7ojjnAo`00
00SoikFO00?o0000on:^WooR[Yl03?oR[Yl2o`0000kofJ^X00?o0000om:TZ?oBY:P02?oBY:P00ol0
003odJ>Yom6SZ@04om6SZ@03o`000?o<WZSoc9jX00?o00003oo:XJh00ol0003o`iZ]ol>J[@0Aol>J
[@04o`000?noV:oo_iR_o`0001[o_9B_00?o0000okR?[?nhSj`01_nhSj`00ol0003o[hZ^ojn:[P0H
ojn:[P03o`000?n]Qjco[HN/00Co[HN/00?o0000oj>0[_nSP:h07OnSP:h00ol0003oUGN_oiEg[`04
oiEg[`?o00005?nBKZL00ol0003oP6>Woh1SY`0;oh1SY`;o00002omlF9d00ol0003ojMS2onWH`P0;
onWH`P03o`000?o^hl?ok^?300Ook^?300?o0000ooWMZol000001_okijD00ol0003omnbHooO/V004
o`0000?ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0WoookJP009OoonfX00ol0
003ooo]ZoookJP12oookJP;o000000?o000Zo`000?lU4h<02_lU4h<01Ol0003o?C6Jo`000?m6=IWo
000000ooJe2P00?o0000ogAO[?mdGj`01?mdGj`00ol0003oS72^oha`[P0Hoha`[P03o`000?nNO:go
WWb]00CoWWb]0ol00008oin1/P;o00003OnRQ[L00ol0003o[hjdojn>]00Lojn>]003o`000?naTkOo
/I>g00;o/I>g00?o0000okfI/onmVK<05onmVK<00ol0003o`9ngol2O]`0:ol2O]`03o`000?o9X[;o
bJ:b00WobJ:b00?o0000oljZ]Ol000000_l0000>olnT[003o`000?oF[JooeZf_00coeZf_00?o0000
om^^ZOl000001ooQ]j`00ol0003oiK6OonFaW`02onFaW`03o`000?o/^iook;^O00Sok;^O00Go0000
ooC5WOodaIgom<FMo`000004ooRmQ`03o`000?onaWooo/Io00?oo/Io00Co0000ooBd@Ood]47o0000
:?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000on^_TOo[[i40
0_o[[i400ol0003oikFOonNeW`05onNeW`03o`000?oR[YoohZjO00cohZjO00Co0000ombWWol0003o
00003?oIZjP00ol0003odZBXom:TZ008om:TZ003o`000?oAXjWodJ>Y00?odJ>Y00?o0000olbNZ?o<
WZP01?o<WZP4o`0000[obZ6^00?o0000ol>J[Oo3VZd04_o3VZd00ol0003o_iR_o`00000JokbD[`03
o`000?nhSjco^8n/00Oo^8n/00?o0000ojn:[_n_RZh05on_RZh00ol0003o[HN/ojf7[005ojf7[003
o`000?nSP:koXh2^01goXh2^00?o0000oiEg[onEMjl00_nEMjl2o`0001OoTVjW00?o0000oh1SYon0
HjL02_n0HjL00ol0003oO5RMogaHW@0:ogaHW@03o`000?oSf<_o000000cojMS200?o0000onkS`oo^
hl<02?o^hl<5o`0000?onnNU1?l000000oo[iGco0000o`000003oookJP03o`000?oonf[ooo]Z03Wo
oo]Z00?o0000oookJ_oonfX09ooonfX002Gooo]Z00?o0000oookJ_oonfX0@_oonfX01?l0003o000Z
o`00:_l0000:obDCP`04o`000?lm<I[o?C6JocdaVP;o00003Om[D:02o`0000OoM5n/00?o0000oha`
[_n<L:h06On<L:h00ol0003oWWb]o`000003o`0000WoWh6b0_l0000?oj:6]`03o`000?n_S[Co[hjd
01[o[hjd0_l00005ok6C]`03o`000?nmVK?o_IVc01Ko_IVc00?o0000ol2O]oo0WkL03?o0WkL00ol0
003obJ:bolVR/P07olVR/P03o`000?o>Z[GocZZe00?ocZZe0ol0000;olnT[003o`000?oF[JooeZf_
00coeZf_00?o0000om^^ZOl000002?oQ]j`2o`0000;oiK6O00?o0000onbkWoo/^il02?o/^il00ol0
003om<FMooC5W@02ooC5W@05o`000?oh_HOon;f7ooRmQol000001OonaWl2o`000003ooBd@Ol0003o
000002Sooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP06oookJP03o`000?o[[i7o
jjnA00?ojjnA00?o0000onNeWooW]Il01?oW]Il00ol0003ohZjOon:^W`0;on:^W`03o`000?oLYioo
g:NO00;og:NO0_l00009omV[Z003o`000?oBY:SodZBX00[odZBX00?o0000om6SZOoAXjT00_oAXjT0
0ol0003oc9jXolbNZ008olbNZ0Co00001Oo:XJh00ol0003o`iZ]ol>J[@0Dol>J[@03o`000?nlU:oo
_9B_01So_9B_00?o0000okR?[?nhSj`02?nhSj`00ol0003o[hZ^ojn:[P0Fojn:[P03o`000?n]Qjco
[HN/00Oo[HN/00?o0000oj>0[_nSP:h07OnSP:h4o`0001WoTVjW00?o0000oh1SYon0HjL02?n0HjL2
o`0000coO5RM00Go0000on?HbooSf<_ohmS;o`00000:onWH`P03o`000?o^hl?ok^?300Wok^?300?o
0000ooO]/?ogkK000_ogkK04o`0000;olO>S0_l000000oo7dESooo]ZoookJP02oookJP03o`000?oo
nf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09ooonfX002Gooo]Z00?o0000oookJ_oonfX0@_oonfX0
1?l0003o000Zo`00:_l0000:obDCP`04o`000?lm<I[o?C6JocdaVP;o00003?m[D:000ol0003oM5n/
ogAO[007ogAO[003o`000?n<L:koS72^01SoS72^0ol0000;oin1/P;o00004OnRQ[L00ol0003o[hjd
ojn>]00Iojn>]003o`000?naTkOo/I>g00Ko/I>g00?o0000okfI/onmVK<05?nmVK<00ol0003o`9ng
ol2O]`0=ol2O]`03o`000?o9X[;obJ:b00KobJ:b00?o0000oljZ]Oo>Z[D01oo>Z[D2o`0000SocjB/
0_l0000?omJ][`03o`000?oQ]jcohKN/00WohKN/0_l0000:onbkW`03o`000?odaIgom<FM00Com<FM
00?o0000ooRmQol000001_onaWl2o`000003ooBd@Ol0003o000002Sooo]Z00?o0000oookJ_oonfX0
C_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?o[[i7ojjnA00CojjnA00?o0000onNeWooW]Il0
0_oW]Il00ol0003ohZjOon:^W`0<on:^W`03o`000?oLYioog:NO00Cog:NO0_l00007omV[Z003o`00
0?oBY:SodZBX00[odZBX00Go0000om6SZOoAXjWodJ>Yo`00000?olbNZ0?o00000_o:XJh00ol0003o
`iZ]ol>J[@0Dol>J[@03o`000?nlU:oo_9B_01So_9B_00?o0000okR?[?nhSj`02OnhSj`00ol0003o
[hZ^ojn:[P0Cojn:[P;o00002_n]Qj`00ol0003oXh2^oj>0[P0Koj>0[P?o00007OnBKZL00ol0003o
P6>Woh1SY`05oh1SY`;o00003OmlF9d00ol0003ohmS;on?Hb`03on?Hb`03o`000?oYf<;ojMS200Ko
jMS200?o0000onkS`oo^hl<02_o^hl<00ol0003omnf`ooO]/004ooO]/004o`000?oalj?olO>Soo7c
X`?o00001?oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z02Oooo]Z000UoookJP03
o`000?oonf[ooo]Z04;ooo]Z00Co0000o`00:_l002[o00002OlU4h<00ol0003o?C6JocdaVP03ocda
VP;o00002_m[D:000ol0003oM5n/ogAO[008ogAO[003o`000?n<L:koS72^01GoS72^0ol000000on?
MkCo0000oin1/P09oin1/P;o00005?nRQ[L00ol0003o[hjdojn>]00Gojn>]003o`000?naTkOo/I>g
00Oo/I>g00?o0000okfI/onmVK<04onmVK<00ol0003o`9ngol2O]`0>ol2O]`03o`000?o9X[;obJ:b
00GobJ:b00?o0000oljZ]Oo>Z[D02_o>Z[D3o`0000CocjB/00?o0000omJ][ol000003ooF[Jl00ol0
003ohKN/on6g[00:on6g[0;o00002Oo/^il00ol0003om<FMooC5W@05ooC5W@;o00001OonaWl01?l0
003oo/a`o`000?od]442o`0002Sooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP07
oookJP03o`000?o[[i7ojjnA00GojjnA00Go0000onNeWooW]IooikFOo`00000>on:^W`03o`000?oL
Yioog:NO00Kog:NO00?o0000omV[Z?oIZjP00ooIZjP00ol0003odZBXom:TZ00;om:TZ005o`000?oA
XjWodJ>Yom6SZOl000004_o<WZP4o`0001Co`iZ]0_l0000IokbD[`03o`000?nhSjco^8n/00[o^8n/
00?o0000ojn:[_n_RZh04_n_RZh00ol0003o[HN/ojf7[00:ojf7[003o`000?nSP:koXh2^01OoXh2^
1?l00002oj1hYP03o`000?nBKZOoTVjW01_oTVjW00?o0000oh1SYon0HjL01?n0HjL00ol0003oO5RM
ogaHW@0=ogaHW@03o`000?oSf<_ohmS;00?ohmS;00?o0000onWH`_oYf<801_oYf<800ol0003ok^?3
onkS``09onkS``03oo7_`Ol0003omnf`00Comnf`00?o0000oo7cXooalj<00_oalj<2o`0000Gooo]Z
00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0VoookJP009OoonfX00ol0003ooo]Zoook
JP12oookJP03o`000?l002[o000Z00;o00001olU4h<00ol0003o?C6JocdaVP04ocdaVP04o`000?mX
DJ?o0000o`0000KoJe2P0_l0000;ogAO[003o`000?n<L:koS72^01?oS72^0_l00005ohmg]003o`00
0?nOPK;oWh6b00GoWh6b0_l0000Foj:6]`03o`000?n_S[Co[hjd01Ko[hjd00?o0000ok6C]onaTkL0
2?naTkL00ol0003o_IVcokfI/`0BokfI/`03o`000?o0WkOo`9ng013o`9ng00?o0000olVR/_o9X[80
1?o9X[800ol0003ocZZeoljZ]@0=oljZ]@?o000000CocjB/o`000?oF[Joo00003_oF[Jl00ol0003o
g;Fao`00000;on6g[003o`000?oX`:go000000Sok;^O00?o0000ooC5WOodaId01_odaId00ol0003o
o/Ioook6O`03ook6O`03o`000?onc73oo/a`00?o0000:?oonfX00ol0003ooo]ZoookJP1>oookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000on^_TOo[[i401_o[[i401?l0003oikFOonNeWol0000=on:^
W`03o`000?oLYioog:NO00Sog:NO0_l00003omV[Z003o`000?oBY:SodZBX00codZBX00Co0000om6S
ZOoAXjWo00004oo<WZP00ol0003oaiRVolNHYP04o`0000oo`iZ]00Co0000ol:H[?o2V:co00005onl
U:l00ol0003o^8n/okR?[00;okR?[003o`000?n_RZko[hZ^017o[hZ^00?o0000ojf7[?n]Qj`03?n]
Qj`00ol0003oXh2^oj>0[P0Aoj>0[PGo00001_nPN:H00ol0003oTVjWoi9^Y`0Koi9^Y`03o`000?n0
HjOoP6>W00;oP6>W0_l0000?ogaHW@03o`000?oSf<_ohmS;00GohmS;00?o0000onWH`_oYf<801?oY
f<800ol0003ok^?3onkS``09onkS``04o`000?oakl7olNo1o`0000Comnf`00Co0000oo7cXooalj?o
lO>S0_l000000oo7dESooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oo
nfX09_oonfX002Cooo]Z00?o0000oookJ_oonfX0@ooonfX01Ol0003o000Zo`000?l0067o000000Oo
9A>300?o0000ocdaV_lm<IX01?lm<IX01Ol0003oJ56SofQAXomXDJ?o000000CoJe2P00?o0000ogAO
[?mdGj`03?mdGj`00ol0003oS72^oha`[P0@oha`[P;o00001on?Mk@00ol0003oWh6boin1/P03oin1
/P;o00006?nRQ[L00ol0003o[hjdojn>]00Dojn>]0;o00003?naTkL00ol0003o_IVcokfI/`0AokfI
/`03o`000?o0WkOo`9ng013o`9ng00?o0000olVR/_o9X[800oo9X[800ol0003ocZZeoljZ]@0AoljZ
]@Co00003_oF[Jl00ol0003og;Fao`00000:on6g[005o`000?oX`:goj<2]onS0[Ol000001oo/^il0
0ol0003om<FMooC5W@06ooC5W@03o`000?onaWooo/Io00?oo/Io00?o0000ook<L?onc7000ol0000X
oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ojjnAon^_T@08
on^_T@;o00003_oR[Yl00ol0003og:NOombWW`0:ombWW`;o000000?ofJ^Xo`000?oBY:P03OoBY:P0
0ol0003odJ>Yo`00000ColbNZ003o`000?o7V:KoaiRV00GoaiRV1?l0000:ol>J[@05o`000?o2V:co
`YR/ol:H[?l000005onlU:l00ol0003o^8n/okR?[00;okR?[003o`000?n_RZko[hZ^013o[hZ^00?o
0000ojf7[?n]Qj`03On]Qj`00ol0003oXh2^oj>0[P0=oj>0[PCo00002onPN:H00ol0003oTVjWoi9^
Y`0Koi9^Y`05o`000?n0HjOoP6>Woh1SYol000004?mlF9d00ol0003ohmS;on?Hb`07on?Hb`03o`00
0?oYf<;ojMS200?ojMS200?o0000onkS`oo^hl<02Oo^hl<3oo7_`@05o`000?ogkK3omnf`ooO]/?l0
00001?oalj<3o`0000Kooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0VoookJP00
9?oonfX00ol0003ooo]ZoookJP13oookJP05o`000?l002[o0000o`00HOl000001_lU4h<00ol0003o
?C6JocdaVP06ocdaVP04o`000?mXDJ?oJ56SofQAX`;o000000?oJe2Po`000?mdGj`03_mdGj`00ol0
003oS72^oha`[P0=oha`[P?o00002On?Mk@01?l0003oWh6boin1/_nOPK82o`0001[oXXJg00?o0000
ojn>]?n_S[@04on_S[@00ol0003o/I>gok6C]`0<ok6C]`03o`000?nmVK?o_IVc013o_IVc00?o0000
ol2O]oo0WkL04Oo0WkL00ol0003obJ:bolVR/P02olVR/P03o`000?o>Z[GocZZe013ocZZe0ol00000
1?oB/;Oo0000o`000?l0000<omJ][`05o`000?oL]K7og;Faombe/Ol000002OoQ]j`00ol0003oj<2]
onS0[@02onS0[@;o00001?o/^il00ol0003om<FMooC5W@07ooC5W@;o00001?onaWl00ol0003oo/a`
ook<L003o`0002Sooo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP06oookJP03o`00
0?o[[i7ojjnA00WojjnA0_l0000=on:^W`03o`000?oLYioog:NO00cog:NO0_l0000>om:TZ003o`00
0?oAXjWo000001?oc9jX00?o0000olNHY_o7V:H02Oo7V:H3o`0000Oo`iZ]00Go0000ol:H[?o2V:co
`YR/o`00000FokbD[`03o`000?nhSjco^8n/00go^8n/00?o0000ojn:[_n_RZh03_n_RZh00ol0003o
[HN/ojf7[00>ojf7[003o`000?nSP:koXh2^00WoXh2^1?l0000@oj1hYP03o`000?nBKZOoTVjW01_o
TVjW00?o0000oh1SYomlF9d04?mlF9d00ol0003ohmS;on?Hb`08on?Hb`03o`000?oYf<;ojMS200;o
jMS200?o0000onkS`oo^hl<02Oo^hl<4oo7_`@05o`000?ogkK3omnf`ooO]/?l000001?oalj<00ol0
003oam5HoookJP06oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09_oonfX002Co
oo]Z00?o0000oookJ_oonfX0@ooonfX01Ol0003o000Zo`000?l0067o000000Go9A>300?o0000ocda
V_lm<IX01olm<IX00ol0003oJ56SofQAX`02ofQAX`Co00003_mdGj`00ol0003oS72^oha`[P0;oha`
[P;o00003On?Mk@3o`0001goXXJg00?o0000ojn>]?n_S[@04On_S[@00ol0003o/I>gok6C]`0=ok6C
]`03o`000?nmVK?o_IVc00oo_IVc00?o0000ol2O]oo0WkL04oo0WkL01Ol0003obJ:bolVR/_o9X[;o
000000oocZZe0ol000000oo>Z[Go0000om:`]`03om:`]`?o00002OoF[Jl00ol0003og;Faombe/@02
ombe/@03o`000?oQ]jcohKN/00OohKN/00?o0000onS0[OoX`:d01?oX`:d01Ol0003ok;^OonbkWoo/
^ioo000000Som<FM00Co0000oo[?V_ojci[o00000oonaWl01?l0003oo/a`ook<L?onc702o`0002So
oo]Z00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP06oookJP03o`000?o[[i7ojjnA00Wo
jjnA00Co0000onBXT_l0003o00002_oR[Yl00ol0003og:NOombWW`0=ombWW`04o`000?oFXIko0000
o`0000godZBX00?o0000olbNZ?o<WZP04Oo<WZP00ol0003oaiRVolNHYP0=olNHYPCo00000_o3VZd0
0ol0003o`YR/ol:H[002ol:H[003o`000?nlU:oo_9B_01?o_9B_00?o0000okR?[?nhSj`03_nhSj`0
0ol0003o[hZ^ojn:[P0=ojn:[P03o`000?n]Qjco[HN/00oo[HN/00?o0000oj>0[_nSP:h01?nSP:h5
o`0001CoX7RV00?o0000oi9^YonBKZL06_nBKZL2o`00017oO5RM00?o0000on?HbooSf</02_oSf</0
1?l0003ojMS2onWH`_l0000;onkS``03o`000?oakl7olNo100;olNo100Co0000ooO]/?ogkK3o0000
1Ooalj<00ol0003oam5HoookJP06oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0
9_oonfX002Cooo]Z00?o0000oookJ_oonfX0@_oonfX2o`000004o`00:_l0003o001Qo`0000Go9A>3
00?o0000ocdaV_lm<IX01olm<IX01Ol0003oJ56SofQAXomXDJ?o000000CoLV6`0ol0000;ogAO[003
o`000?n<L:koS72^00WoS72^0_l0000<ohmg]0Co00007onRQ[L00ol0003o[hjdojn>]00@ojn>]003
o`000?naTkOo/I>g00oo/I>g00?o0000okfI/onmVK<03OnmVK<00ol0003o`9ngol2O]`0Dol2O]`04
o`000?o9X[;obJ:bo`0000gocZZe0ol00003oljZ]@03o`000?oB/;Ood[2g00Cod[2g00Co0000om:`
]ol0003o00001ooF[Jl00ol0003og;Faombe/@02ombe/@03o`000?oQ]jcohKN/00KohKN/00?o0000
onS0[OoX`:d01_oX`:d01?l0003ok;^OonbkWol00008ooC5W@04o`000?ojci[on/nJo`0000?oo/Io
00Co0000ook<L?onc73oo/a`0_l0000YoookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ojjnAon^_T@09on^_T@05o`000?oTZ9;oi:RBonBXT_l000002OoR[Yl00ol0
003og:NOombWW`0=ombWW`04o`000?oFXIkoeZ6NomJQWP;o00002ooBY:P00ol0003oc9jXolbNZ00A
olbNZ003o`000?o7V:KoaiRV017oaiRV1_l00002ol:H[003o`000?nlU:oo_9B_017o_9B_00?o0000
okR?[?nhSj`03onhSj`00ol0003o[hZ^ojn:[P0<ojn:[P03o`000?n]Qjco[HN/017o[HN/0_nSP:h4
o`0001WoX7RV00?o0000oi9^YonBKZL05onBKZL3o`000003ohiTW_l0003oO5RM013oO5RM00?o0000
on?HbooSf</02ooSf</00ol0003ojMS2o`00000;onkS``GolNo100Co0000ooO]/?ogkK3o00001?oa
lj<3o`0000Oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0VoookJP009?oonfX0
0ol0003ooo]ZoookJP12oookJP?o00000_l00642o`0000?o9A>300?o0000ocdaV_lm<IX02?lm<IX0
1?l0003oJ56SofQAXol00008og9Q/0?o00002?mdGj`00ol0003oS72^oha`[P06oha`[P?o00002On?
Mk@5o`0000?oT7^h00?o0000oj:6]onRQ[L07OnRQ[L00ol0003o[hjdojn>]00>ojn>]0;o00004_na
TkL00ol0003o_IVcokfI/`0<okfI/`03o`000?o0WkOo`9ng01Go`9ng00?o0000olVR/_l000002oo>
Z[D3o`0000KocZZe00?o0000om:`]ooB/;L01OoB/;L00ol0003od[2gom:`]`03o`0000?oeZf_00?o
0000ombe/OoL]K401?oL]K400ol0003ohKN/on6g[005on6g[003o`000?oX`:goj<2]00Ooj<2]0_l0
0009ooC5W@05o`000?ojci[on/nJoo[?V_l000000_onaWl01?l0003oo/a`ook<L?onc702o`0002Wo
oo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP06oookJP03o`000?o[[i7ojjnA00Wo
jjnA00?o0000onBXT_oTZ9800_oTZ982o`0000OohZjO00?o0000ombWWooLYil03?oLYil00ol0003o
eZ6NomJQWP04omJQWP?o00001ooBY:P2o`0001;oc9jX00?o0000olNHY_o7V:H04oo7V:H00ol0003o
`i>Uol>CY@02ol>CY@So00003_nlU:l00ol0003o^8n/okR?[00?okR?[003o`000?n_RZko[hZ^00_o
[hZ^00?o0000ojf7[?n]Qj`03?n]Qj`8o`0001goX7RV00?o0000oi9^YonBKZL05OnBKZL2o`0000Co
SVBN00?o0000ogaHWOmlF9d03_mlF9d00ol0003ohmS;on?Hb`0=on?Hb`03o`000?o^hl?ok^?300Wo
k^?31_oakl401?l0003omnf`ooO]/?l00004oo7cX`03o`000?o7dESooo]Z00Oooo]Z00?o0000oook
J_oonfX0>OoonfX00ol0003ooo]ZoookJP0VoookJP009?oonfX00ol0003ooo]ZoookJP12oookJP?o
00000_l00642o`0000;o9A>300?o0000ocdaV_lm<IX02_lm<IX2o`0000coLV6`0ol00005ogAO[003
o`000?n<L:koS72^00CoS72^0_l00006ohmg]0Ko00002?n@NkP00ol0003oXXJgoj:6]`0Noj:6]`03
o`000?n_S[Co[hjd00co[hjd00?o0000ok6C]onaTkL04_naTkL00ol0003o_IVcokfI/`0;okfI/`03
o`000?o0WkOo`9ng01Oo`9ng00?o0000oljZ]Oo>Z[D01_o>Z[D4o`0000SocZZe00?o0000om:`]ooB
/;L01ooB/;L00ol0003od[2gom:`]`02om:`]`;o000000?oeZf_o`000?oL]K401OoL]K400ol0003o
hKN/on6g[004on6g[003o`000?oX`:goj<2]00Woj<2]00?o0000ooC5WOodaId01_odaId00ol0003o
n/nJoo[?VP02oo[?VP03o`000?onaWoo000000Coo/a`0_l0000YoookJP03o`000?oonf[ooo]Z04co
oo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ojjnAon^_T@09on^_T@03o`000?oTZ9;oi:RB00Go
i:RB0_l00004on:^W`03o`000?oLYioog:NO00gog:NO00?o0000omJQW_oFXIh01ooFXIh2o`0000Go
dZBX00?o0000olnPYol000004Oo<WZP00ol0003oaiRVolNHYP0BolNHYP03o`000?o3TjGo`i>U00Go
`i>U00?o0000okb?YonlSjL00onlSjL9o`0000Co_9B_00?o0000okR?[?nhSj`04?nhSj`00ol0003o
[hZ^ojn:[P0:ojn:[P03o`000?n]Qjco[HN/00;o[HN/2ol00006ojj3YP03o`000?nPN:KoX7RV01co
X7RV00?o0000oi9^YonBKZL04onBKZL2o`0000KoSVBN00?o0000ogaHWOmlF9d03OmlF9d00ol0003o
hmS;on?Hb`0>on?Hb`03o`000?o^hl?ok^?300Sok^?300?o0000oo7_`Ooakl401Ooakl42o`0000Co
lO>S0_l000000oo7dESooo]ZoookJP06oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oo
nfX09_oonfX002Cooo]Z00?o0000oookJ_oonfX0@_oonfX3o`0000;o001Q0_l00002obDCP`03o`00
0?lm<I[o?C6J00[o?C6J00?o0000og9Q/?mbHK003_mbHK03o`0000?oM5n/00Co0000oha`[_n<L:ko
S72^0_l00002ohmg]0Ko00003on@NkP00ol0003oXXJgoj:6]`0Moj:6]`03o`000?n_S[Co[hjd00_o
[hjd00?o0000ok6C]onaTkL05?naTkL00ol0003o_IVcokfI/`09okfI/`03o`000?o0WkOo`9ng01So
`9ng00?o0000oljZ]Oo>Z[D00oo>Z[D3o`0000_ocZZe00?o0000om:`]ooB/;L02?oB/;L00ol0003o
d[2gom:`]`04om:`]`;o00001ooL]K400ol0003ohKN/on6g[003on6g[003o`000?oX`:goj<2]00Wo
j<2]00?o0000ooC5WOodaId01_odaId00ol0003on/nJoo[?VP03oo[?VP;o00001?onc702o`0002Wo
oo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP06oookJP;o00002_o[[i400ol0003o
i:RBonBXTP07onBXTP05o`000?oR[YoohZjOon:^Wol000003ooLYil00ol0003oeZ6NomJQWP09omJQ
WP;o00000ooBY:P00ol0003ocj2Wo`00000@olbNZ003o`000?o7V:KoaiRV01?oaiRV00?o0000ol>C
YOo3TjD01Oo3TjD00ol0003o_8nWokb?Y`0<okb?Y`oo00002OnhSj`00ol0003o[hZ^ojn:[P03ojn:
[P_o00004On^PjH00ol0003oX7RVoj1hYP0Loj1hYP03o`000?nBKZOoTVjW013oTVjW0ol00008ohiT
WP03o`000?mlF9goO5RM00coO5RM00?o0000on?HbooSf</03_oSf</00ol0003oin?>o`000009onkS
``SolNo10_l00004oo7cX`?o00002?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z
02Gooo]Z000SoookJP03o`000?oonf[ooo]Z04?ooo]Z0ol00002o`00H@04o`000?lA287o0000o`00
00go?C6J00?o0000og9Q/?mbHK004OmbHK0;o`0001GoT7^h00?o0000oj:6]onRQ[L07OnRQ[L00ol0
003o[hjdojn>]00:ojn>]003o`000?naTkOo/I>g00Wo/I>g4_l00005okfI/`03o`000?o0WkOo`9ng
01So`9ng00Co0000olBV^_l0003ocZZe0ol0000>oljZ]@03o`000?oB/;Ood[2g00Wod[2g00?o0000
om:`]ooB/;L00ooB/;L01?l0003of;Rjo`000?l00005ombe/@03o`000?oQ]jcohKN/00?ohKN/00?o
0000onS0[OoX`:d02?oX`:d00ol0003ok/V]o`000007ooC5W@03o`000?ojci[on/nJ00Con/nJ00Ko
0000ook<L?onc73oo/a`o`000?odbeP2o`0002Sooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003o
oo]ZoookJP06oookJP03o`000?o]Ygoo000000WojjnA00?o0000onBXT_oTZ9802?oTZ982o`000003
on:^Wol0003og:NO00kog:NO00?o0000omJQW_oFXIh02ooFXIh3o`0000;ocj2W00?o0000olbNZ?o<
WZP03_o<WZP00ol0003oaiRVolNHYP0BolNHYP03o`000?o3TjGo`i>U00Ko`i>U00?o0000okb?Yonl
SjL03onlSjL00ol0003o]XRUokJ8Y@09okJ8Y@oo00001On^PjH00ol0003o[X>Vojj3YP0Dojj3YP03
o`000?nPN:KoX7RV01coX7RV00?o0000oi9^YonBKZL03_nBKZL2o`0000_oSVBN00?o0000ogaHWOml
F9d03?mlF9d00ol0003ohmS;on?Hb`0=on?Hb`04o`000?oWhlkoin?>o`0000Sok^?300?o0000oo7_
`Ooakl401_oakl400ol0003olO>Soo7cX`02oo7cX`03o`000?oJk8So000000Wooo]Z00?o0000oook
J_oonfX0>_oonfX00ol0003ooo]ZoookJP0UoookJP008ooonfX00ol0003ooo]ZoookJP13oookJP;o
00000ol006400ol0003o4@R1o`00000=ocdaVP;o00005_mbHK03o`0001[oT7^h00?o0000oj:6]onR
Q[L07_nRQ[L00ol0003o[hjdojn>]003ojn>]1;o00003?nbV;d00ol0003o_9fiokbM^@03okbM^@So
00005oo0WkL00ol0003oa:Jjo`000002o`00013ocZZe00?o0000om:`]ooB/;L02ooB/;L01Ol0003o
d[2gom:`]ooB/;Oo000000Cof;Rj00?o0000ombe/OoL]K400ooL]K401Ol0003ohKN/on6g[?oQ]jco
000000_oj<2]00Co0000onk9[Oo^bJgo00001_odaId00ol0003on/nJoo[?VP04oo[?VP06o`000?on
c73oo/a`ook<L?l0003om<]H0_l0000XoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oo
nfX01_oonfX01?l0003okJMoonfWOol00008on^_T@03o`000?oTZ9;oi:RB00[oi:RB0_l0000>ombW
W`03o`000?oFXIkoeZ6N00koeZ6N0ol000000oo?X:Oo0000olbNZ00>olbNZ003o`000?o7V:KoaiRV
01;oaiRV00?o0000ol>CYOo3TjD01oo3TjD00ol0003o_8nWokb?Y`0=okb?Y`03o`000?nfR:Go]XRU
01?o]XRU00?o0000ojj3Y_n^PjH01on^PjH00ol0003o[X>Vojj3YP0Fojj3YP03o`000?nPN:KoX7RV
01coX7RV00?o0000oi9^YonBKZL02onBKZL2o`0000koSVBN00?o0000ogaHWOmlF9d02_mlF9d00ol0
003ohmS;on?Hb`0=on?Hb`05o`000?oWhlkoin?>onOSc_l000002?o^hl<9oo7_`@03o`000?oalj?o
lO>S00;olO>S0_l000000oo7dESooo]ZoookJP07oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000
oookJ_oonfX09OoonfX002?ooo]Z00?o0000oookJ_oonfX0@ooonfX2o`0000?o001Q0ol0000<ocda
VP04o`000?m?BJcoCdV/o`0001CoLV6`00?oNFjjoi1k^?n@NkP06on@NkP00ol0003oXXJgoj:6]`0L
oj:6]`So00000on_T[T00ol0003o/YRmok:H_@0Iok:H_@03o`000?nlWKWo_9fi00Go_9fi00?o0000
oknS_?noXk`00_noXk`6o`00013o`9ng0ol00002olBV^P03o`000?o>Z[GocZZe00gocZZe00?o0000
om:`]ooB/;L03OoB/;L00ol0003od[2go`000006omRh^P;o00000ooL]K401Ol0003ohKN/on6g[?oQ
]jco000000_oj<2]00Go0000onk9[Oo^bJgok/V]o`000004ooC5W@03o`000?ojci[on/nJ00Gon/nJ
0_l00002ook<L004o`000?odbeSo0000o`0002Sooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003o
oo]ZoookJP06oookJP05o`000?o]YgookJMoonfWOol000001oo[[i400ol0003oi:RBonBXTP0:onBX
TP04o`000?oNXI?o0000o`0000cog:NO00?o0000omJQW_oFXIh03_oFXIh00ol0003odI^Nom6KWP04
o`0000coc9jX00?o0000olNHY_o7V:H04_o7V:H00ol0003o`i>Uol>CY@08ol>CY@03o`000?nlSjOo
_8nW00go_8nW00?o0000okJ8YOnfR:D04onfR:D00ol0003o[X>Vojj3YP06ojj3YP03o`000?n^PjKo
[X>V01Oo[X>V00?o0000oj1hY_nPN:H07?nPN:H00ol0003oTVjWoi9^Y`08oi9^Y`?o00004?n>I9h0
0ol0003oO5RMogaHW@09ogaHW@03o`000?oSf<_ohmS;00gohmS;00?o0000onOSc_oWhlh00ooWhlh0
0ol0003ok^?3onkS``04onkS``WolNo10_l00003oo7cX`04o`000?oJk8So0000o`0000Wooo]Z00?o
0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0UoookJP008ooonfX00ol0003ooo]ZoookJP13
oookJP;o00000ol006401?l0003o;bfLobl]W?l0000:ocdaVP05o`000?m?BJcoCdV/odm9[?l00000
4ombHK02ogU^^QkoT7^h00?o0000oj:6]onRQ[L05_nRQ[L5o`0000;oXXbl00?o0000ojnB^On_T[T0
1On_T[T00ol0003o/YRmok:H_@0Jok:H_@03o`000?nlWKWo_9fi00Co_9fi00?o0000oknS_?noXk`0
2OnoXk`5o`0000Oo`9ng1?l00005olBV^P03o`000?o>Z[GocZZe00gocZZe00?o0000om:`]ooB/;L0
3_oB/;L2o`0000Sof;Rj0_l000001OoL]K7o0000on6g[?oQ]jco000000_oj<2]00?o0000onk9[Oo^
bJd00oo^bJd01Ol0003om<FMooC5WOodaIgo000000Kon/nJ00?o0000ookIT_l000000_onc7001?l0
003om<]Ho`000?l0000XoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX01_oonfX0
0ol0003okJMoonfWO`02onfWO`;o00001Oo[[i400ol0003oi:RBonBXTP0:onBXTP05o`000?oNXI?o
gZ6ComjQTol000002ooLYil00ol0003oeZ6NomJQWP0=omJQWP03o`000?oAVikodI^N00;odI^N00?o
0000olfIWoo=VIl00ol00009olbNZ003o`000?o7V:KoaiRV01;oaiRV00?o0000ol>CYOo3TjD02?o3
TjD00ol0003o_8nWokb?Y`0<okb?Y`03o`000?nfR:Go]XRU01Co]XRU00?o0000ojj3Y_n^PjH01On^
PjH00ol0003o[X>Vojj3YP0Hojj3YP03o`000?nPN:KoX7RV01_oX7RV3ol0000@ohiTWP03o`000?ml
F9goO5RM00SoO5RM00?o0000on?HbooSf</03OoSf</00ol0003oin?>onOScP04onOScP03o`000?o^
hl?ok^?300?ok^?300?o0000oo7_`Ooakl401_oakl400ol0003ok_Rko`000003oo7cX`03o`000?oJ
k8So000000[ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0UoookJP008ooonfX0
0ol0003ooo]ZoookJP13oookJP;o00000ol006401Ol0003o;bfLobl]W?l_;Ico000000So?C6J00?o
0000odm9[?m?BJ`00_m?BJ`00ol0003oLV6`og9Q/00@og9Q/0CoNFjj7On@NkP00ol0003oXXJgoj:6
]`0Boj:6]`Co00002?nRS;`00ol0003o[i:iojnB^@02ojnB^@;o00007OnbV;d00ol0003o_9fiokbM
^@03okbM^@03o`000?noXkco_j>l00oo_j>l1ol00002ol2O]`03o`000?o4Y[[oa:Jj00Coa:Jj00?o
0000oljZ]Oo>Z[D03?o>Z[D00ol0003od[2gom:`]`0?om:`]`03o`000?oH^;[of;Rj00Wof;Rj00Go
0000ombe/Ol0003ohKN/o`00000;onS0[@03o`000?o^bJgok/V]00Cok/V]00Co0000ooC5WOodaIgo
00001_ojciX00ol0003oo]VBo`000002ook<L004o`000?odbeSom<]Ho`0002Wooo]Z00?o0000oook
J_oonfX0BooonfX00ol0003ooo]ZoookJP06oookJP03o`000?o]YgookJMo00CokJMo00?o0000on^_
TOo[[i400_o[[i400ol0003oi:RBonBXTP0:onBXTP03o`000?oNXI?ogZ6C00;ogZ6C0_l00008ombW
W`03o`000?oFXIkoeZ6N00koeZ6N00?o0000om6KW_oAVih00_oAVih00ol0003ocIVOolfIW`03olfI
W`?o00001Oo<WZP00ol0003oaiRVolNHYP0BolNHYP03o`000?o3TjGo`i>U00Wo`i>U00?o0000okb?
YonlSjL02onlSjL00ol0003o]XRUokJ8Y@0FokJ8Y@03o`000?n^PjKo[X>V00Co[X>V00?o0000ojj3
Y_n^PjH06?n^PjH00ol0003oX7RVoj1hYP0Joj1hYP03o`000?nPN:Ko000000GoTVnW0ol00005ohiT
W@Oo00002On>I9h00ol0003oO5RMogaHW@07ogaHW@03o`000?oSf<_ohmS;00kohmS;00?o0000onOS
c_oWhlh01?oWhlh00ol0003ok^?3onkS``03onkS``WolNo100?o0000onkh^ol000000_oalj<01?l0
003of^b8om[/R?l0000:oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09OoonfX0
02?ooo]Z00?o0000oookJ_oonfX0@ooonfX2o`0000?o001Q00Go0000obl]W?l_;Ico;bfLo`000007
ocdaVP03o`000?m?BJcoCdV/00?oCdV/00?o0000og9Q/?mbHK003ombHK05ogU^^QgoT7^h00?o0000
oj:6]onRQ[L03OnRQ[L5o`0000coXXbl00Go0000ojnB^On_T[Wo[i:io`00000Pok:H_@05o`000?nl
WKWo_9fiokbM^Ol000004onoXk`3o`0000;o_j>l1_l00005olBV^P03o`000?o>Z[GocZZe00_ocZZe
00?o0000om:`]ooB/;L03_oB/;L00ol0003of;Rjo`00000;omRh^P;o000000?ohKN/o`000?oX`:d0
2OoX`:d00ol0003ok/V]onk9[@06onk9[@;o00001oojciX01_l0003oo]VBookIT_l0003oo/a`o`00
00;om<]H00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000onfWOoo]Ygl01Oo]Ygl01?l0003ojjnAon^_TOl0000<onBXTP03o`000?oNXI?o
gZ6C00GogZ6C0_l00006ombWW`03o`000?oFXIkoeZ6N00koeZ6N00?o0000om6KW_oAVih00_oAVih0
0ol0003ocIVOolfIW`06olfIW`?o00000_o<WZP00ol0003oaiRVolNHYP0BolNHYP03o`000?o3TjGo
`i>U00Wo`i>U00?o0000okb?YonlSjL02onlSjL00ol0003o]XRUokJ8Y@0FokJ8Y@03o`000?n^PjKo
[X>V00?o[X>V00?o0000ojj3Y_n^PjH06On^PjH00ol0003oX7RVoj1hYP0Hoj1hYP;o00000onPN:H0
0ol0003oTVnWo`000002o`0000ooSVBM1ol00002ohiTWP03o`000?mlF9goO5RM00KoO5RM0_l0000?
on?Hb`03o`000?oWhlkoin?>00Koin?>00Co0000onkS`oo^hl?ok^?32Ooakl401?l0003ok_Rkonkh
^ol00002oo7cX`04o`000?oJk8Sof^b8o`0000_ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003o
oo]ZoookJP0UoookJP008_oonfX00ol0003ooo]ZoookJP14oookJP?o000000?o001Qo`000?l00000
1?l_;I`00ol0003o?C6JocdaVP04ocdaVP03o`000?m?BJcoCdV/00CoCdV/00?o0000og9Q/?mbHK00
3?mbHK07ogU^^QgoT7^h00?o0000oj:6]onRQ[L02OnRQ[L4o`00017oXXbl00Co0000ojnB^On_T[Wo
00008OnbV;d01?l0003o_9fiokbM^Ol0000AoknS_0?o00001_noXk`5ol:Y`0Ko00003?o>Z[D00ol0
003od[2gom:`]`0?om:`]`04o`000?oH^;[of;Rjo`0000cof;Rj0_l0000:onS0[@03o`000?o^bJgo
k/V]00Ook/V]00?o0000oo[?V_ojciX01?ojciX01ol0003oo]VBookIT_onfI;o0000ook<L?l00000
0_odbeP00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0
1ooonfX00ol0003okJMoonfWO`06onfWO`03o`000?o[[i7o000000coi:RB00?o0000omjQTooNXI<0
1ooNXI<2o`0000Cog:NO00?o0000omJQW_oFXIh03OoFXIh00ol0003odI^Nom6KWP04om6KWP03o`00
0?o=VIoocIVO00SocIVO1?l0000ColNHYP03o`000?o3TjGo`i>U00[o`i>U00?o0000okb?YonlSjL0
2OnlSjL00ol0003o]XRUokJ8Y@0GokJ8Y@03o`000?n^PjKo[X>V00;o[X>V00?o0000ojj3Y_n^PjH0
6on^PjH00ol0003oX7RVoj1hYP0Foj1hYP04o`000?nPN:KoX7RVoj1hYPCo00006On>I9d4o`0000Ko
O5RM0_l0000?on?Hb`03o`000?oWhlkoin?>00Ooin?>00Co0000onkS`oo^hl?o00002?oakl401ol0
003ok_Rkonkh^oo^n;_o0000oo7cXol000000_oJk8P00ol0003ooo]ZoookJP0:oookJP03o`000?oo
nf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX09OoonfX002;ooo]Z00?o0000oookJ_oonfX0A?oonfX3
o`000004o`00HOl0003o00:8o`0000Co;bfL00?o0000ocdaV_lm<IX00_lm<IX00ol0003oCdV/odm9
[005odm9[003o`000?mbHK3oLV6`00_oLV6`2OmiK[XLoi1k^003o`000?nRQ[OoXXJg00GoXXJg1?l0
000Foj:<_0;o00008_nbV;d00ol0003o_9fio`00000>oknS_0Co00002?noXk`;ol:Y`0Co00002?o>
Z[D00ol0003od[2gom:`]`0?om:`]`03o`000?oH^;[of;Rj00;of;Rj00?o0000omRh^_oH^;X02OoH
^;X00ol0003ohl:fo`000009onS0[@03o`000?o^bJgok/V]00Ook/V]00?o0000oo[?V_ojciX01?oj
ciX01?l0003oo]VBookIT_onfI82o`0000?om<]H00?o0000oookJ_oonfX09ooonfX00ol0003ooo]Z
oookJP1:oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000onfWOoo]Ygl02?o]Ygl2o`0000coi:RB
00?o0000omjQTooNXI<02OoNXI<01Ol0003og:NOombWWooLYioo000000ooeZ6N00?o0000om6KW_oA
Vih01?oAVih00ol0003ocIVOolfIW`09olfIW`03o`000?o8Tikob9>N00Co00003_o7V:H00ol0003o
`i>Uol>CY@0;ol>CY@03o`000?nlSjOo_8nW00Wo_8nW00?o0000okJ8YOnfR:D05onfR:D01Ol0003o
[X>Vojj3Y_n^PjKo000001ko[X>V00?o0000oj1hY_nPN:H05?nPN:H2o`000004oj1hY_l0003o0000
o`0000;oWG2N00?o0000ohiTWOn>I9d06_n>I9d00ol0003oO5RMo`000003ogaHW@?o00003ooSf</0
0ol0003oin?>onOScP08onOScP03o`000?o^hl?ok^?300WolNo100Co0000onkh^oo^n;_o00000_oa
lj<01?l0003of^b8om[/R?l0000<oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oonfX0
9OoonfX002;ooo]Z00?o0000oookJ_oonfX0A?oonfX01ol0003o0019o`000?l0067o0000o`02R?l0
00001?l_;I`01Ol0003o?C6JocdaV_lm<I[o000000SoCdV/00?o0000og9Q/?mbHK002_mbHK0:ogU^
^QgoT7^h00?o0000oj:6]ol000001?l0000Ioj:<_0;o00008onbV;d2o`0000co_j>l0ol0000;oknS
_0go`ZW000?o0000ol^/^_o;[;X00ol00005oljZ]@03o`000?oB/;Ood[2g00kod[2g00?o0000omRh
^_oH^;X01?oH^;X00ol0003of;RjomRh^P07omRh^P05o`000?oM`[go0000on?2]_l000001ooX`:d0
0ol0003ok/V]onk9[@07onk9[@03o`000?oee:co000000Gon/nJ00?o0000ookIT_onfI800_onfI80
1Ol0003om<]HooC;F?odbeSo000002Wooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]Zoook
JP06oookJP03o`000?o]YgookJMo00WokJMo0_l0000;onBXTP03o`000?oNXI?ogZ6C00[ogZ6C0ol0
000@omJQWP03o`000?oAVikodI^N00CodI^N00?o0000olfIWoo=VIl02?o=VIl00ol0003ob9>NolRC
WP05olRCWPCo00002_o7V:H00ol0003o`i>Uol>CY@0;ol>CY@03o`000?nlSjOo_8nW00So_8nW00?o
0000okJ8YOnfR:D06?nfR:D01Ol0003o[X>Vojj3Y_n^PjKo000001ko[X>V00?o0000oj1hY_nPN:H0
4onPN:H4o`0000GoWG2N00?o0000ohiTWOn>I9d06_n>I9d02?l0003oO5RMogaHWOl0003oO5RMo`00
0?mbB97o00003ooSf</00ol0003oin?>onOScP0:onOScP03o`000?oakl7olNo100OolNo100Oo0000
onkh^oo^n;_ok_Rko`000?oalj?o000000?of^b800?o0000oookJ_oonfX02_oonfX00ol0003ooo]Z
oookJP0joookJP03o`000?oonf[ooo]Z02Cooo]Z000RoookJP03o`000?oonf[ooo]Z04Cooo]Z00Oo
0000o`00BOl0003o001Qo`000?l00XSo000000Go;bfL00?o0000ocdaV_l000002Om?BJ`00ol0003o
LV6`og9Q/008og9Q/0coNFjj7?n@NkP3o`0001coXXbl0_l000000onUT/7o0000ok:H_@0Qok:H_@03
o`000?ndW/7o000000Wo_j>l0ol0000=oknS_0oo`ZW000?o0000ol^/^_o;[;X00_o;[;X3o`000003
oljZ]Ol0003od[2g013od[2g00?o0000omRh^_oH^;X01?oH^;X00ol0003of;RjomRh^P06omRh^P06
o`000?oM`[gogL:momg2_Ol0003ohl:f0_l00005onS0[@03o`000?o^bJgok/V]00Ook/V]00Co0000
ooGD[?oee:co00001?ojciX00ol0003oo]VBookITP02ookITP03o`000?odbeSom<]H00;o0000:Ooo
nfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000onfWOoo]Ygl02Oo]
Ygl01?l0003oiZ23o`000?l00009onBXTP03o`000?oNXI?ogZ6C00cogZ6C0_l0000>omJQWP03o`00
0?oAVikodI^N00GodI^N00?o0000olfIWoo=VIl02?o=VIl00ol0003ob9>NolRCWP09olRCWP?o0000
1_o7V:H00ol0003o`i>Uol>CY@0<ol>CY@03o`000?nlSjOo_8nW00So_8nW00?o0000okJ8YOnfR:D0
6OnfR:D00ol0003o[X>Vo`00000Oojj3YP03o`000?nPN:KoX7RV013oX7RV1?l00008oie`WP03o`00
0?n>I9goSVBM01_oSVBM00Co0000ogaHWOl0003o00000_mbB9400ol0003ohmS;on?Hb`0=on?Hb`03
o`000?oWhlkoin?>00[oin?>00?o0000oo7_`Ooakl401_oakl400ol0003ok_Rkonkh^`02onkh^`03
o`000?oalj?o000000;of^b800?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0joookJP03
o`000?oonf[ooo]Z02Cooo]Z000RoookJP03o`000?oonf[ooo]Z04Cooo]Z00Oo0000o`00BOl0003o
001Qo`000?l00XSo000000Ko;bfL0_l00009odm9[003o`000?mbHK3oLV6`00OoLV6`3_miK[XIoi1k
^0;o000000?oTX:no`000?nRS;`06OnRS;`3o`0000CoYI;100?o0000ok:H_OnbV;d07OnbV;d2o`00
00?o]9k100?o0000oknS_?noXk`00onoXk`3o`0000ko_j>l00?o0000ol:Y`?o2ZL003_o2ZL000ol0
003objbjol^/^P05ol^/^P;o00004?oB/;L00ol0003of;RjomRh^P06omRh^P03o`000?oH^;[of;Rj
00Gof;Rj00Go0000omg2_OoM`[gogL:mo`000003on?2]P05o`000?oX`:goj<2]onS0[Ol000002_o^
bJd01?l0003omMB/ooGD[?l00003oo[?VP03o`000?onfI;oo]VB00?oo]VB00?o0000ooC;F?odbeP0
0_l0000YoookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003okJMo
onfWO`09onfWO`05o`000?oVX8?oiZ23onJPPol000002?oTZ9800ol0003ogZ6ComjQT`0<omjQT`03
o`000?oHVi?o000000;o00002ooFXIh00ol0003odI^Nom6KWP05om6KWP03o`000?o=VIoocIVO00So
cIVO00?o0000olRCW_o8Tih03?o8Tih4o`0000;oaiRV00?o0000ol>CYOo3TjD03?o3TjD00ol0003o
_8nWokb?Y`07okb?Y`03o`000?nfR:Go]XRU01[o]XRU0_l0000Pojj3YP03o`000?nPN:KoX7RV00_o
X7RV1_l0000;oie`WP03o`000?n>I9goSVBM01_oSVBM0_l000001_mdBY3o0000og98TOl0003og]OA
o`0000gohmS;00?o0000onOSc_oWhlh02_oWhlh2o`0000SolNo100?o0000onkh^oo^n;/00_o^n;/2
o`0000?of^b800?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[o
oo]Z02Cooo]Z000RoookJP03o`000?oonf[ooo]Z04Cooo]Z00Co0000o`00BOl004Wo00000_l00XP0
0ol0003o;bfLobl]W004obl]W003o`000?m6B;3o000000WoCdV/00?o0000og9Q/?mbHK001OmbHK0?
ogU^^QKoT7^h0ol00004oi:2_P03o`000?nRS;coXXbl01GoXXbl0_l00007ojFB`@03o`000?nbV;go
/YRm01co/YRm00?o0000okBN`OndW/400ondW/400ol0003o_j>loknS_003o`00013o_j>l00?o0000
ol:Y`?o2ZL004?o2ZL000ol0003objbjol^/^P04ol^/^P03o`000?o?/kko000000;o00003OoB/;L0
0ol0003of;RjomRh^P07omRh^P03o`000?oH^;[of;Rj00?of;Rj00?o0000omg2_OoM`[d00ooM`[d0
1Ol0003ohl:fon?2]_oS`[Ko000000;oj<2]00?o0000onk9[Oo^bJd01oo^bJd00ol0003omMB/ooGD
[002ooGD[004o`000?ojci[on/nJo`0000Goo]VB00?o0000ooC;F?odbeP00_l0000ZoookJP03o`00
0?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003okJMoonfWO`09onfWO`03o`00
0?oVX8?oiZ2300;oiZ230_l00006onBXTP03o`000?oNXI?ogZ6C00cogZ6C00?o0000omRKTooHVi<0
0_oHVi<2o`0000WoeZ6N00?o0000om6KW_oAVih01_oAVih00ol0003ocIVOolfIW`06olfIW`03o`00
0?o8Tikob9>N017ob9>N1Ol0000<ol>CY@03o`000?nlSjOo_8nW00Oo_8nW00?o0000okJ8YOnfR:D0
6_nfR:D00ol0003o[X>Vojj3YP0Pojj3YP03o`000?nPN:KoX7RV00GoX7RV1Ol00004oie`WP03o`00
0?nML9koWG2N00_oWG2N00?o0000ohiTWOn>I9d06On>I9d2o`0000;oM4Z@0_l00003omkGd@03o`00
0?oSf<_ohmS;00WohmS;00?o0000onOSc_oWhlh02_oWhlh00ol0003ojNg?o`000007oo7_`@03o`00
0?o^n;_ok_Rk00?ok_Rk0_l00002om[/R003o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0
>_oonfX00ol0003ooo]ZoookJP0ToookJP008OoonfX00ol0003ooo]ZoookJP15oookJP04o`000?l0
04Wo0019o`0000?o00:800?o0000obl]W?l_;I`00_l_;I`01Ol0003oATR`odI8/?m6B;3o000000So
CdV/00?o0000og9Q/?mbHK001?mbHK0@ogU^^QCoT7^h0_l00007oi:2_P03o`000?nRS;coXXbl01?o
XXbl0_l00009ojFB`@03o`000?nbV;go/YRm01_o/YRm00?o0000okBN`OndW/400ondW/44o`0001;o
_j>l00?o0000ol:Y`?o2ZL004Oo2ZL000ol0003objbjol^/^P03ol^/^P03o`000?o?/kkock>n00?o
ck>n0_l0000:om:`]`03o`000?oH^;[of;Rj00Wof;Rj00Go0000omRh^_oH^;[of;Rjo`000007omg2
_@07o`000?oS`[Kohl:fon?2]_l0003oj<2]o`000009onk9[@03o`000?oee:comMB/00;omMB/00Co
0000oo[?V_ojci[o00001?onfI801?l0003oo=n4o`000?odbeP2o`0002[ooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP06oookJP03o`000?o]YgookJMo00WokJMo00?o0000onJPPooV
X8<01?oVX8<2o`0000?oi:RB00?o0000omjQTooNXI<03?oNXI<00ol0003of9^ComRKT`05omRKT`;o
00001_oFXIh00ol0003odI^Nom6KWP07om6KWP03o`000?o=VIoocIVO00KocIVO00?o0000olRCW_o8
Tih04_o8Tih01?l0003o`HbMol6<WOo1S9d6o`0000Oo`i>U00?o0000okb?YonlSjL01OnlSjL00ol0
003o]XRUokJ8Y@0KokJ8Y@03o`000?n^PjKo[X>V023o[X>V00?o0000oj1hY_nPN:H01Ol00008oie`
WP03o`000?nML9koWG2N00coWG2N00?o0000ohiTWOn>I9d05_n>I9d3o`000005ohUIT_l0003oM4Z@
ogA:T?l000001?oNem400ol0003ohmS;on?Hb`08on?Hb`03o`000?oWhlkoin?>00[oin?>00Go0000
onW]cooYkLoojNg?o`000006oo7_`@03o`000?o^n;_ok_Rk00?ok_Rk00?o0000om[/R?oJk8P00_l0
000>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09?oonfX0027ooo]Z00?o0000
oookJ_oonfX0AOoonfX01?l0003o0019o`00BOl00003o`02R003o`000?l_;Ico;bfL00;o;bfL00?o
0000odI8/?m6B;000_m6B;000ol0003oCdV/odm9[005odm9[003o`000?mbHK3oLV6`00;oLV6`4omi
K[XAoi1k^0;o00002OnBP[h00ol0003oXXbloj:<_00Aoj:<_0;o00003?nUT/400ol0003o/YRmok:H
_@0Hok:H_@;o00000ondW/43o`0000;o]9k100?o0000oknS_?noXk`04?noXk`00ol0003o`ZW0ol:Y
`00Bol:Y`003o`000?o;[;[objbj00;objbj00?o0000olnc__o?/kh01_o?/kh2o`0000Ood[2g00?o
0000omRh^_oH^;X02ooH^;X01?l0003of;RjomRh^_l00007omg2_@03o`000?oS`[Kohl:f00;ohl:f
00?o0000onk9[Oo^bJd01oo^bJd00ol0003omMB/ooGD[004ooGD[0;o00001OonfI801?l0003oo=n4
o`000?odbeP2o`0002[ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP06oookJP;o
00002_o]Ygl00ol0003oiZ23onJPP`06onJPP`04o`000?oTZ9;oi:RBo`0000kogZ6C00?o0000omRK
TooHVi<01ooHVi<3o`0000?oeZ6N00?o0000om6KW_oAVih01ooAVih00ol0003ocIVOolfIW`06olfI
W`03o`000?o8Tikob9>N017ob9>N00?o0000ol6<WOo1S9d02?o1S9d5o`0000;o`i>U00?o0000okb?
YonlSjL01?nlSjL00ol0003o]XRUokJ8Y@0KokJ8Y@;o00007?n^PjH9o`0000_oWG2N0_l0000?oie`
WP03o`000?n>I9goSVBM01?oSVBM0ol00004ohUITP03o`000?mdBY3o000000Kog]OA00?o0000on?H
booSf</01_oSf</00ol0003oin?>onOScP0;onOScP05o`000?oYkLoojNg?onW]col000001Ooakl40
0ol0003ok_Rkonkh^`04onkh^`04o`000?oJk8Sof^b8o`0000oooo]Z00?o0000oookJ_oonfX0>_oo
nfX00ol0003ooo]ZoookJP0ToookJP008OoonfX00ol0003ooo]ZoookJP15oookJP04o`000?l004Wo
0019o`0000?o00:800Go0000obl]W?l_;Ico;bfLo`000006odI8/0;o00001Om?BJ`01?l0003oLV6`
og9Q/?mbHK0DogU^^PkoT7^h0ol0000<oi:2_P03o`000?nRS;coXXbl00goXXbl0ol0000>ojFB`@03
o`000?nbV;go/YRm01Oo/YRm00?o0000okBN`OndW/400ol00005okBN`@03o`000?noXkco_j>l00oo
_j>l00?o0000ol:Y`?o2ZL005?o2ZL001?l0003objbjol^/^_l0000;olnc_P?o00001?oB/;L00ol0
003of;RjomRh^P0;omRh^P03o`000?oH^;[o000000WogL:m00Go0000on?2]_oS`[Kohl:fo`000009
onk9[@03o`000?oee:comMB/00GomMB/00?o0000ookIT_onfI800oonfI801?l0003oo=n4o`000?od
beP2o`0002[ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP07oookJP03o`000?o^
VfOo000000WokJMo00?o0000onJPPooVX8<01ooVX8<3o`0000kogZ6C00?o0000omRKTooHVi<02_oH
Vi<2o`000003omJQW_l0003odI^N00SodI^N00?o0000olfIWoo=VIl01Oo=VIl00ol0003ob9>NolRC
WP0BolRCWP03o`000?o1S9go`HbM00go`HbM1_l00003okb?Y`03o`000?nfR:Go]XRU01[o]XRU00Co
0000okJ8YOnfR:Go00004?n^PjH;o`0000KoZgZN00?o0000oie`W_nML9h02_nML9h00ol0003oWG2N
oie`WP0?oie`WP03o`000?n>I9goSVBM013oSVBM0ol00007ohUITP;o00002?oNem400ol0003ohmS;
on?Hb`04on?Hb`03o`000?oWhlkoin?>00_oin?>00?o0000onW]cooYkLl00_oYkLl00ol0003olNo1
oo7_`@02oo7_`@03o`000?o^n;_ok_Rk00Cok_Rk0_l000000ooJk8So0000o`00000?oookJP03o`00
0?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX09?oonfX0027ooo]Z00?o0000oookJ_oonfX0AOoo
nfX00ol0003o0019o`00B@02o`0000;o00:800Co0000obl]W?l_;Ico00002Om6B;000ol0003oCdV/
odm9[003odm9[0;oLV6`5OmiK[X<oi1k^0;o00003onBP[h00ol0003oXXbloj:<_00;oj:<_0;o0000
4OnUT/400ol0003o/YRmok:H_@0Eok:H_@Go00002?ndW/400ol0003o_j>loknS_00>oknS_003o`00
0?o2ZL3o`ZW001Go`ZW000?o0000ol^/^_l000003oo?/kh2o`000003om:`]ol0003of;Rj00kof;Rj
00?o0000omg2_OoM`[d02?oM`[d01_l0003ohl:fon?2]_l0003ojLbgo`0000Sok/V]00?o0000ooGD
[?oee:`01Ooee:`00ol0003oo]VBookITP02ookITP05o`000?olghCoo=n4o`000?odbeP00_l0000Z
oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX01ooonfX01?l0003okY]WonjKIol0
0007onfWO`03o`000?oVX8?oiZ2300[oiZ230_l0000=omjQT`03o`000?oHVi?of9^C00cof9^C0ol0
0008om6KWP03o`000?o=VIoocIVO00GocIVO00?o0000olRCW_o8Tih04_o8Tih00ol0003o`HbMol6<
W@0?ol6<W@04o`000?nlR9ko_8RNokb8WQ7o00003_nfR:D01Ol0003o]XRUokJ8YOnfR:Go000000Go
[X>V2ol0000Aoj]jWP03o`000?nML9koWG2N00WoWG2N00?o0000oie`W_nML9h04?nML9h00ol0003o
SVBMohiTW@0=ohiTW@?o00002_n9FI800ol0003og]OAomkGd@07omkGd@03o`000?oSf<_ohmS;00Co
hmS;00?o0000onOSc_oWhlh02_oWhlh00ol0003ojNg?onW]c`03onW]c`03o`000?oakl7olNo100;o
lNo100?o0000onkh^oo^n;/00oo^n;/2o`0000;of^b80_l0000?oookJP03o`000?oonf[ooo]Z03[o
oo]Z00?o0000oookJ_oonfX09?oonfX0027ooo]Z00?o0000oookJ_oonfX0AOoonfX2o`000003o`00
BOl0003o000000;o00:800Co0000obl]W?l_;Ico00002_m6B;000ol0003oCdV/odm9[002odm9[003
og9Q/?miK[[oNFjj01GoNFjj2On@NkP2o`00017oTX:n00?o0000oj:<_?nRS;`02OnRS;`2o`0001Co
YI;100?o0000ok:H_OnbV;d04onbV;d3o`0000co]9k100?o0000oknS_?noXk`03?noXk`00ol0003o
`ZW0ol:Y`00Gol:Y`003o`000?o?/kkock>n013ock>n0_l0000>omRh^P03o`000?oM`[go000000[o
gL:m00?o0000on?2]_l000000_oYc;L00ol0003ok/V]onk9[@04onk9[@03o`000?oee:comMB/00Go
mMB/00?o0000ooWNZ_l000000oonfI800ol0003oo=n4oocOQ002o`000003omFk=Ol0003ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP07oookJP04o`000?o^VfOokY]WonjK
I`;o00001Oo]Ygl00ol0003oiZ23onJPP`0:onJPP`03o`000?oOVXGo000000cogZ6C00?o0000omRK
TooHVi<03?oHVi<00ol0003odYFDom:EU003o`0000GodI^N00?o0000olfIWoo=VIl01Oo=VIl00ol0
003ob9>NolRCWP0AolRCWP03o`000?o1S9go`HbM013o`HbM00?o0000okb8W_nlR9h00onlR9h00ol0
003o^8FNokR5WP0<okR5WQSo00007?n[NYh00ol0003oWG2Noie`WP07oie`WP;o00004onML9h00ol0
003oSVBMohiTW@0;ohiTW@;o00003?n9FI800ol0003og]OAomkGd@09omkGd@03o`000?oSf<_ohmS;
00;ohmS;00?o0000onOSc_oWhlh02_oWhlh00ol0003ojNg?onW]c`04onW]c`05o`000?oakl7olNo1
oo7_`Ol000001_o^n;/2o`000003om[/R?l0003o0000013ooo]Z00?o0000oookJ_oonfX0>ooonfX0
0ol0003ooo]ZoookJP0SoookJP008OoonfX00ol0003ooo]ZoookJP15oookJP;o000000?o0019o`00
0?l000000ol00XP2o`0000coATR`00Go0000odm9[?m?BJcoCdV/o`00000GogU^^POoT7^h0_l0000D
oi:2_P03o`000?nRS;coXXbl00KoXXbl0_l0000FojFB`@03o`000?nbV;go/YRm00oo/YRm1?l0000?
okBN`@03o`000?noXkco_j>l00_o_j>l00?o0000ol:Y`?o2ZL005oo2ZL02o`0001;ock>n00Co0000
omBl`_l0003o00003?oH^;X01?l0003ogL:momg2_Ol0000:omg2_@03o`000?oYc;OojLbg00;ojLbg
00?o0000onk9[Oo^bJd00oo^bJd00ol0003omMB/ooGD[005ooGD[003o`000?oigZ[o000000?oo]VB
00Oo0000oocOQ?olghCoo=n4o`000?oE^cGo000002[ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0
003ooo]ZoookJP08oookJP03o`000?o^VfOokY]W00;okY]W00?o0000onfWOoo]Ygl00_o]Ygl00ol0
003oiZ23onJPP`0:onJPP`03o`000?oOVXGogiZ500;o00002OoNXI<00ol0003of9^ComRKT`0=omRK
T`03o`000?oBUICodYFD00?odYFD0ol00003om6KWP03o`000?o=VIoocIVO00?ocIVO00?o0000olRC
W_o8Tih04_o8Tih00ol0003o`HbMol6<W@0@ol6<W@03o`000?nlR9ko_8RN00;o_8RN00?o0000okR5
W_nhQIh06_nhQIh00ol0003o]H6MokF1W@02okF1W@03o`000?n[NYkoZgZN01ooZgZN00?o0000oie`
W_nML9h01_nML9h00ol0003oWG2Noie`WP0Coie`WP03o`000?n>I9goSVBM00SoSVBM0ol0000=ohUI
TP03o`000?oNem7og]OA00[og]OA00Go0000on?HbooSf<_ohmS;o`00000<onOScP03o`000?oYkLoo
jNg?00GojNg?00Co0000oo7_`Ooakl7o00001_o^n;/01?l0003oi?Z`o`000?oJk8P2o`00017ooo]Z
00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0SoookJP008OoonfX00ol0003ooo]Zoook
JP15oookJP;o000000Co0019o`000?l007ko00000_l00XP2o`0000goATR`00Co0000odm9[?l0003o
00005omiK[X4oi1k^0?o00005_nBP[h00ol0003oXXbloj:<_004oj:<_0;o00006OnUT/400ol0003o
/YRmok:H_@0;ok:H_@?o000000?o/YRmo`000?ndW/404OndW/400ol0003o_j>loknS_009oknS_003
o`000?o2ZL3o`ZW001Oo`ZW000Co0000olN`a?o7/<Co00004?o?/kh00ol0003oe;c2omBl`P02omBl
`P;o00002OoH^;X00ol0003ogL:momg2_@02omg2_@03o`000?oM`[gogL:m00OogL:m00?o0000onW<
]ooYc;L00ooYc;L01Ol0003ok/V]onk9[Oo^bJgo000000SomMB/00?o0000ooWNZ_l000000oonfI80
1?l0003oo=n4oocOQ?olgh@2o`0002cooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]Zoook
JP08oookJP03o`000?o^VfOokY]W00?okY]W0_l00002onfWO`03o`000?oVX8?oiZ2300[oiZ2300?o
0000omnJQOoOVXD00_oOVXD2o`0000OogZ6C00?o0000omRKTooHVi<03OoHVi<00ol0003odYFDom:E
U006om:EU0Co00001Oo=VIl00ol0003ob9>NolRCWP0BolRCWP03o`000?o1S9go`HbM017o`HbM00Go
0000okb8W_nlR9ko_8RNo`00000KokR5WP03o`000?nePIgo]H6M00?o]H6M00?o0000oj]jW_n[NYh0
7on[NYh00ol0003oWG2Noie`WP05oie`WP03o`000?nML9koWG2N01GoWG2N00?o0000ohiTWOn>I9d0
1?n>I9d3o`0000koREVB0_l0000>omkGd@03o`000?oSf<_o000000goin?>00?o0000onW]cooYkLl0
1_oYkLl00ol0003olNo1o`000005onkh^`04o`000?oTn[3o0000om[/R0;o00004_oonfX00ol0003o
oo]ZoookJP0joookJP03o`000?oonf[ooo]Z02?ooo]Z000PoookJP03o`000?oonf[ooo]Z04Kooo]Z
0ol00002o`00OP04o`000?l00XSo00:8o`0000ooATR`0_l000000omJFKOo0000ogU^^P0FogU^^P03
oi1k^?l0003o000001WoTX:n00?o0000oj:<_?nRS;`00_nRS;`2o`0001_oYI;100?o0000ok:H_Onb
V;d02?nbV;d3o`0000;o/YRm0_l0000CokBN`@03o`000?noXkco_j>l00So_j>l00?o0000ol:Y`?o2
ZL005oo2ZL001Ol0003oak34olN`a?o7/<Co000000oock>n00?o0000omBl`_oD_<801OoD_<82o`00
00Kof;Rj00?o0000omg2_OoM`[d00ooM`[d00ol0003ogL:momg2_@06omg2_@03o`000?oTc<3o0000
00GojLbg00Co0000onk9[Oo^bJgo00001ooee:`01ol0003onMjZooWNZ_oigZ[o0000ookIT_l00000
1?olgh@2o`0002cooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?o^VfOokY]W00GokY]W00?o0000onfWOol000003?oVX8<00ol0003ogiZ5omnJQ@04omnJQ@03o`00
0?oNXI?ogZ6C00CogZ6C00?o0000omRKTooHVi<03?oHVi<00ol0003odYFDom:EU00:om:EU0;o0000
1?o=VIl00ol0003ob9>NolRCWP0AolRCWP03o`000?o1S9go`HbM01;o`HbM00Go0000okb8W_nlR9ko
_8RNo`00000KokR5WP03o`000?nePIgo]H6M00?o]H6M00?o0000oj]jW_n[NYh08?n[NYh00ol0003o
WG2Noie`WP03oie`WP03o`000?nML9koWG2N01KoWG2N00Co0000ohiTWOn>I9goSVBM0ol0000@ohUI
TP04o`000?oCemcodmOLo`0000kog]OA00?o0000onOSc_oWhlh02ooWhlh00ol0003ojNg?onW]c`07
onW]c`;o00001_o^n;/01?l0003oi?Z`o`000?oJk8P2o`0001;ooo]Z00?o0000oookJ_oonfX0>_oo
nfX00ol0003ooo]ZoookJP0SoookJP008?oonfX00ol0003ooo]ZoookJP17oookJP;o00000ol007h0
0ol0003o00:8o`00000?odI8/0;oEE^l0_l0000FogU^^P;o00007?nBP[h00ol0003oXXblo`00000N
ojFB`@03o`000?nbV;go/YRm00Go/YRm0ol00004ok:H_@03o`000?ndW/7o]9k101?o]9k100?o0000
oknS_?noXk`01onoXk`00ol0003o`ZW0ol:Y`00Gol:Y`003o`000?o7/<Coak3400?oak3400?o0000
olnc__o?/kh02oo?/kh00ol0003oe;c2omBl`P08omBl`P;o00001?oH^;X00ol0003ogL:momg2_@04
omg2_@03o`000?oM`[gogL:m00CogL:m00Go0000onC<`?oTc<3oi<c0o`000005onW<]`03o`000?o^
bJgo000000OomMB/00Oo0000ooWNZ_oigZ[onMjZo`000?onfI;o000000Coo=n40_l0000/oookJP03
o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003okY]WonjKI`06onjKI`;o
00003?oVX8<00ol0003ogiZ5omnJQ@05omnJQ@;o00001?oNXI<00ol0003of9^ComRKT`0<omRKT`03
o`000?oBUICodYFD00[odYFD00?o0000oljBUOl000000ol0000DolRCWP03o`000?o1S9go`HbM01;o
`HbM00Co0000okb8W_nlR9ko00007?nhQIh00ol0003o]H6MokF1W@03okF1W@03o`000?n[NYkoZgZN
023oZgZN00Co0000oie`W_nML9koWG2N0_l0000Ioie`WPCo00004_n9FI800ol0003odmOLom?Gg002
om?Gg003o`000?oNem7og]OA00_og]OA00?o0000onOSc_oWhlh02_oWhlh00ol0003ojNg?onW]c`08
onW]c`03o`000?o^n;_ok_Rk00Cok_Rk00?o0000onCj/?oTn[000ol0000CoookJP03o`000?oonf[o
oo]Z03[ooo]Z00?o0000oookJ_oonfX08ooonfX0023ooo]Z00?o0000oookJ_oonfX0AooonfX2o`00
00?o001n00?o0000o`02R?l000003_m6B;001?l0003oEE^loeEK_?mEFk`3o`0001?oNFjj00?o0000
ogif`?l000006OnBP[h4o`00027oYI;100Co0000ok:H_OnbV;go/YRm0ol00006ok:H_@03o`000?nd
W/7o]9k101Go]9k100?o0000oknS_?noXk`01OnoXk`00ol0003o`ZW0ol:Y`00Gol:Y`003o`000?o7
/<Coak3400Coak3400?o0000olnc__o?/kh02_o?/kh00ol0003oe;c2omBl`P0;omBl`P;o000000?o
f;Rjo`000?oM`[d01ooM`[d00ol0003ogL:momg2_@03omg2_@05o`000?oTc<3oi<c0onC<`?l00000
1_oYc;L00ol0003omMB/ooGD[005ooGD[003o`000?oigZ[onMjZ00;onMjZ00?o0000ookIT_l00000
0oolgh@3o`0002cooo]Z00?o0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP08oookJP03o`00
0?o^VfOokY]W00OokY]W0_l0000;onJPP`03o`000?oOVXGogiZ500OogiZ50_l00002omjQT`03o`00
0?oHVi?of9^C00cof9^C00?o0000om:EU?oBUI@02_oBUI@00ol0003ocY:EoljBU@02oljBU@?o0000
4_o8Tih00ol0003o`HbMol6<W@0Bol6<W@04o`000?nlR9ko_8RNo`0001_o^8FN00?o0000okF1WOne
PId01OnePId00ol0003oZgZNoj]jWP0Ooj]jWP04o`000?nML9koWG2No`0001WoWG2N0ol0000DohUI
TP03o`000?oCemcodmOL00CodmOL00?o0000omkGdOoNem402OoNem400ol0003ohN;Do`00000:onOS
cP03o`000?oYkLoojNg?00WojNg?00?o0000onkh^oo^n;/00oo^n;/00ol0003oi?Z`onCj/002o`00
0003ok[JK?l0003ooo]Z01;ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0Soook
JP008?oonfX00ol0003ooo]ZoookJP17oookJP;o00000ol007h2o`000003oa8TX_l0003oATR`00_o
ATR`00?o0000oeEK_?mEFk`00_mEFk`00ol0003oN76oogQa_`05o`0000goNFjj00Go0000ogif`?mn
M/3oOWK0o`00000Coi:2_PGo00000onCR<@00ol0003oYI;1ojFB`@0OojFB`@Co00001onbV;d2o`00
01So]9k100?o0000oknS_?noXk`01?noXk`00ol0003o`ZW0ol:Y`00Gol:Y`003o`000?o7/<Coak34
00Koak3400?o0000olnc__o?/kh02Oo?/kh00ol0003oe;c2omBl`P0=omBl`P;o00002OoM`[d01Ol0
003ogL:momg2_OoM`[go000000Goi<c000?o0000onW<]ooYc;L00ooYc;L00ol0003omMB/ooGD[005
ooGD[003o`000?oigZ[onMjZ00?onMjZ00?o0000oocOQ?olgh@00_olgh@3o`0002cooo]Z00?o0000
oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?o^VfOokY]W00OokY]W00?o0000
onNEK_l000002_oVX8<00ol0003ogiZ5omnJQ@09omnJQ@;o00003ooHVi<00ol0003odYFDom:EU00:
om:EU003o`000?o>TYGocY:E00;ocY:E00?o0000olV=U?o9SI@01?l0000=olRCWP03o`000?o1S9go
`HbM01?o`HbM00?o0000okb8W_l000007?nhQIh00ol0003o]H6MokF1W@05okF1W@03o`000?n[NYko
ZgZN01ooZgZN00?o0000oie`W_l000005OnML9h5o`0000;oVVFC00?o0000ohUIT_n9FI804On9FI80
0ol0003odmOLom?Gg006om?Gg003o`000?oNem7og]OA00Oog]OA00Co0000on7Re?oQh]Co00002_oW
hlh00ol0003ojNg?onW]c`08onW]c`;o00001Oo^n;/00ol0003oi?Z`onCj/003o`0001Cooo]Z00?o
0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0SoookJP008?oonfX00ol0003ooo]ZoookJP17
oookJP;o00001?l007h00ol0003o4RBRo`00000<odI8/003o`000?mEFkcoEE^l00?oEE^l00?o0000
ogQa_omhLKl01?mhLKl4o`0000SoNFjj00?o0000ogif`?mnM/000_mnM/000ol0003oTX:noi:2_P0;
oi:2_PKo00002OnCR<@00ol0003oYI;1ojFB`@0KojFB`@Co00002OnbV;d00ol0003o]9k1okBN`@0H
okBN`@03o`000?noXkco_j>l00?o_j>l00?o0000ol:Y`?o2ZL005oo2ZL000ol0003oak34olN`a007
olN`a003o`000?o?/kkock>n00Sock>n00?o0000omBl`_oD_<803_oD_<800ol0003ofL?5o`000009
omg2_@03o`000?oM`[go000000Koi<c000?o0000onW<]ooYc;L00_oYc;L00ol0003okmJho`000006
ooGD[003o`000?oigZ[onMjZ00?onMjZ00?o0000oocOQ?olgh@00_olgh@3o`0002cooo]Z00?o0000
oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?o^VfOokY]W00OokY]W00?o0000
onNEK_oWUFh00_l00007onJPP`03o`000?oOVXGogiZ500_ogiZ50_l0000>omRKT`03o`000?oBUICo
dYFD00[odYFD00?o0000oljBUOo>TYD00_o>TYD00ol0003obHfDolV=U004olV=U0Co00002Oo8Tih0
0ol0003o`HbMol6<W@0Dol6<W@;o00007?nhQIh00ol0003o]H6MokF1W@05okF1W@03o`000?n[NYko
ZgZN01ooZgZN0_l0000Boie`WPCo00001onJII<00ol0003oREVBohUITP0@ohUITP03o`000?oCemco
dmOL00SodmOL00?o0000omkGdOoNem401OoNem400ol0003ohN;Don7Re002on7Re003o`000?oWhlko
in?>00Koin?>00?o0000onW]cooYkLl02?oYkLl00ol0003ojOO<o`000004onkh^`07o`000?oTn[3o
i?Z`onCj/?l0003o^]Y/o`00000DoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0
8ooonfX0023ooo]Z00?o0000oookJ_oonfX0AooonfX2o`0000Co001n00?o0000oa8TX_l000002om6
B;000ol0003oEE^loeEK_004oeEK_003o`000?mhLKooN76o00SoN76o1Ol00002ogU^^P03o`000?mn
M/3oOWK000?oOWK000?o0000oi:2__nBP[h01_nBP[h5o`0000ooThS400?o0000ojFB`OnUT/406?nU
T/43o`0000;oYI;1;_l0000Gol:Y`003o`000?o7/<Coak3400Woak3400?o0000olnc__o?/kh01_o?
/kh00ol0003oe;c2omBl`P0>omBl`P04o`000?oI`lGofL?5omW3a@;o00001ooM`[d00ol0003ogL:m
o`000007onC<`005o`000?oYc;OojLbgonW<]ol000000_o_e[P00ol0003omMB/ooGD[002ooGD[003
o`000?oigZ[onMjZ00ConMjZ00Ko0000oocOQ?olghCoo=n4o`000?o_g6l2o`0002cooo]Z00?o0000
oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?o^VfOokY]W00KokY]W00?o0000
onNEK_oWUFh00_oWUFh00ol0003oiZ23onJPP`04onJPP`03o`000?oOVXGogiZ500_ogiZ500?o0000
omVCQ_l000000_l0000;omRKT`03o`000?oBUICodYFD00[odYFD00?o0000oljBUOo>TYD00_o>TYD0
0ol0003obHfDolV=U008olV=U0?o00001_o8Tih00ol0003o`HbMol6<W@0Dol6<W@;o00006onhQIh0
0ol0003o]H6MokF1W@06okF1W@03o`000?n[NYkoZgZN01ooZgZN00?o0000oie`W_nML9h03?nML9h5
o`0000_oVVFC00?o0000ohUIT_n9FI803on9FI800ol0003odmOLom?Gg00:om?Gg003o`000?oNem7o
g]OA00?og]OA00?o0000on7Re?oQh]@00ooQh]@00ol0003oin?>onOScP05onOScP03o`000?oYkLoo
jNg?00SojNg?00Co0000onWgc?oYmlco00001?o^n;/00ol0003oi?Z`onCj/003o`0001Gooo]Z00?o
0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0RoookJP007ooonfX00ol0003ooo]ZoookJP18
oookJP?o00000ol007h2o`000003oa8TX_l0003oATR`00SoATR`00?o0000oeEK_?mEFk`01OmEFk`0
0ol0003oN76oogQa_`0=ogQa_`Ko00000omnM/000ol0003oTX:noi:2_P05o`0001CoThS400?o0000
ojFB`OnUT/405OnUT/48o`0000;oYIG500?o0000ok6K`OnaVl400onaVl400ol0003o/j75ok>Qa@0L
ok>Qa@05o`000?nnYL7o_ZG1okjU`Ol000000_o1[<D4o`0001;o`ZW000?o0000olN`a?o7/<@02_o7
/<@00ol0003ock>nolnc_P05olnc_P03o`000?oD_<;oe;c200koe;c200?o0000omW3aOoI`lD01?oI
`lD00ol0003ogL:momg2_@05omg2_@03o`000?oTc<3oi<c000Ooi<c000?o0000onW<]ol000000oo_
e[P00ol0003omMB/ooGD[002ooGD[003o`000?oigZ[onMjZ00?onMjZ0_l00003oocOQ003o`000?o_
g6oo000002gooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?o^
VfOokY]W00OokY]W00?o0000onNEK_oWUFh00_oWUFh2o`0000CoiZ2300?o0000omnJQOoOVXD02ooO
VXD00ol0003ofI>6omVCQP02omVCQP;o00002OoHVi<00ol0003odYFDom:EU00:om:EU005o`000?o>
TYGocY:EoljBUOl000003_o9SI@4o`000003olRCW_l0003o`HbM01Ko`HbM00?o0000okR5W_nhQIh0
6_nhQIh00ol0003o]H6MokF1W@06okF1W@03o`000?n[NYkoZgZN01ooZgZN00?o0000oie`W_nML9h0
2?nML9h4o`00013oVVFC00?o0000ohUIT_n9FI803On9FI82o`0000kodmOL00Go0000omkGdOoNem7o
g]OAo`000007on7Re003o`000?oWhlkoin?>00?oin?>00?o0000onW]cooYkLl02?oYkLl01Ol0003o
jOO<onWgc?oYmlco000000?ok_Rk00Oo0000onCj/?oTn[3oi?Z`o`000?njfVco000001Gooo]Z00?o
0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0RoookJP007ooonfX00ol0003ooo]ZoookJP18
oookJP?o00000ol007h01?l0003o01bQo`000?l00009odI8/003o`000?mEFkcoEE^l00KoEE^l00?o
0000ogQa_omhLKl02omhLKl00ol0003oOWc6ogilaP04ogilaPKo00006_nCR<@00ol0003oYI;1ojFB
`@0AojFB`@Ko00002?nUULD00ol0003o/I_1ok6K`@02o`00023o/j7500?o0000okjU`Ol000001oo1
[<D5o`0000co`ZW000?o0000olN`a?o7/<@02oo7/<@00ol0003ock>nolnc_P04olnc_P03o`000?oD
_<;oe;c200koe;c200?o0000omW3aOoI`lD01_oI`lD00ol0003ogL:momg2_@03omg2_@03o`000?oT
c<3o000000Soi<c000?o0000onW<]ol000001?o_e[P01?l0003omMB/ooGD[?l00006ooWNZP03o`00
0?okj:?o000000;oo=n400?o0000onoLKol00000;_oonfX00ol0003ooo]ZoookJP15oookJP03o`00
0?oonf[ooo]Z00[ooo]Z0_l00008onjKI`03o`000?oWUFkoiiE^00CoiiE^00Go0000onJPPooVX8?o
iZ23o`00000=omnJQ@03o`000?oIThKofI>600CofI>60ol00005omRKT`03o`000?oBUICodYFD00_o
dYFD00Go0000oljBUOo>TYGocY:Eo`00000BolV=U0Go00005?o1S9d00ol0003o^8FNokR5WP0JokR5
WP03o`000?nePIgo]H6M00Ko]H6M00?o0000oj]jW_n[NYh07_n[NYh2o`0000KoWG2N1?l0000DoiYU
T`03o`000?n9FI;oREVB00coREVB00?o0000om?Gg?oCem`03ooCem`00ol0003og]OAo`000008on7R
e003o`000?oWhlkoin?>00;oin?>00?o0000onW]cooYkLl02?oYkLl00ol0003ojOO<onWgc002onWg
c004o`000?o^n;_ok_Rko`0000Coi?Z`0_l0000FoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000
oookJ_oonfX08_oonfX001oooo]Z00?o0000oookJ_oonfX0BOoonfX2o`0000?o001n00Co0000o`0L
XOl0003o00002?m6B;000ol0003oEE^loeEK_007oeEK_003o`000?mhLKooN76o00[oN76o00?o0000
ogila_mnO<H02?mnO<H00ol0003oThS4oi>8a00Joi>8a003o`000?nUT/7oYI;100goYI;11_l0000<
ojFEa@03o`000?naVl7o000002;o/j750_l0000=ol6/a@Co00001oo2ZL000ol0003oak34olN`a00=
olN`a003o`000?o?/kkock>n00?ock>n00?o0000omBl`_oD_<803OoD_<800ol0003ofL?5omW3a@08
omW3a@;o00000ooM`[d01?l0003oi<c0onC<`?l00008onC<`003o`000?o_e[SokmJh00?okmJh00Co
0000ooGD[?oee:co00001OoigZX01_l0003onnRSoo_XXol0003oo=n4o`0000;okma_00?o0000oook
J_oonfX0;?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000onZ8
Aol000001oo^VfL00ol0003oiiE^onNEKP05onNEKP;o000000?oiZ23o`000?oOVXD03?oOVXD00ol0
003ofI>6omVCQP07omVCQP;o00000ooHVi<00ol0003odYFDom:EU00;om:EU005o`000?o>TYGocY:E
oljBUOl000004oo9SI@01?l0003o`hNDol>7U?o3Qi@5o`0000ko`HbM0_l0000KokR5WP03o`000?ne
PIgo]H6M00Oo]H6M00?o0000oj]jW_n[NYh07On[NYh01?l0003oZGRMo`000?nML9h5o`0001SoVVFC
00?o0000ohUIT_n9FI802on9FI800ol0003odmOLom?Gg00@om?Gg0;o00002OoQh]@00ol0003oin?>
onOScP02onOScP03o`000?oYkLoojNg?00SojNg?00Go0000onWgc?oYmlcojOO<o`000003onkh^`07
o`000?oTn[3oi?Z`onCj/?l0003o^]Y/o`00000FoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000
oookJ_oonfX08_oonfX001oooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003o001^o`000002o`00
OP03o`000?l07:7o01bQ00;o00001om6B;000ol0003oEE^loeEK_007oeEK_003o`000?mhLKooN76o
00WoN76o00?o0000ogila_mnO<H02_mnO<H00ol0003oThS4oi>8a00Joi>8a003o`000?nUT/7oYI;1
00WoYI;11?l0000AojFEa@;o00008_ncXLD00ol0003o]jW;o`00000Aol6/a@Co00000_o2ZL000ol0
003oak34olN`a00>olN`a003o`000?o?/kkock>n00;ock>n00?o0000omBl`_oD_<803_oD_<800ol0
003ofL?5omW3a@0:omW3a@03o`000?oM`[go000000Coi<c000?o0000onC<`?oTc<001OoTc<02o`00
00GokmJh00?o0000ooGD[?l000001OoigZX01_l0003onnRSoo_XXol0003oo=n4o`0000;okma_00?o
0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z00[ooo]Z00Co
0000onZ8AooZR4Oo00001_o^VfL00ol0003oiiE^onNEKP07onNEKP;o00003OoOVXD00ol0003ofI>6
omVCQP09omVCQPCo00003OoBUI@01Ol0003ocY:EoljBUOo>TYGo000001?obHfD00?o0000ol>7U?o3
Qi@01_o3Qi@6o`0000So`HbM0_l0000KokR5WP03o`000?nePIgo]H6M00Oo]H6M00?o0000oj]jW_n[
NYh07On[NYh4o`0001goVVFC00?o0000ohUIT_n9FI802_n9FI800ol0003odmOLom?Gg00@om?Gg005
o`000?oFhn3oe^?PomKSh?l000002?oQh]@01?l0003oin?>onOSc_l0000:onW]c`03o`000?oYmlco
jOO<00;ojOO<00Co0000onkh^oo^n;_o00000ooTn[03o`0001Oooo]Z00?o0000oookJ_oonfX0>ooo
nfX00ol0003ooo]ZoookJP0RoookJP007ooonfX00ol0003ooo]ZoookJP19oookJP05o`000?l006ko
0000o`00O_l000001?l07:400ol0003oATR`odI8/004odI8/003o`000?mEFkcoEE^l00WoEE^l00?o
0000ogQa_omhLKl01omhLKl00ol0003oOWc6ogilaP0;ogilaP03o`000?nCR<CoThS401[oThS400?o
0000ojFB`OnUT/401OnUT/44o`0001;oYIG50ol000000onWW<_o0000ok>Qa@0Ook>Qa@;o00000ong
ZL/00ol0003o`Jc5ol6/a@0Bol6/a@Co00004?o7/<@01?l0003ock>nolnc__l0000@omBl`P03o`00
0?oI`lGofL?500cofL?500?o0000onC<`?oTc<000ooTc<000ol0003oi<c0onC<`004onC<`004o`00
0?oZf<;oj]S2o`0000GokmJh00?o0000ooWNZ_oigZX01?oigZX01_l0003onnRSoo_XXol0003oo=n4
o`0000;okma_00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[o
oo]Z00_ooo]Z00Co0000onZ8AooZR4Oo00001Oo^VfL00ol0003oiiE^onNEKP08onNEKP;o00003?oO
VXD00ol0003ofI>6omVCQP0<omVCQP;o00003?oBUI@01Ol0003ocY:EoljBUOo>TYGo000001?obHfD
00?o0000ol>7U?o3Qi@03?o3Qi@5o`0000?o`HbM0_l0000KokR5WP03o`000?nePIgo]H6M00So]H6M
00?o0000oj]jW_n[NYh05_n[NYh7o`000003ojM`Tol0003oVVFC01koVVFC00?o0000ohUIT_n9FI80
2?n9FI800ol0003odmOLom?Gg00@om?Gg003o`000?oFhn3oe^?P00?oe^?P00?o0000on7Re?oQh]@0
1OoQh]@00ol0003oin?>o`00000:onW]c`03o`000?oYmlcojOO<00?ojOO<00?o0000onkh^ol00000
1?oTn[000ol0003o^]Y/o`00000HoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0
8_oonfX001oooo]Z00?o0000oookJ_oonfX0BOoonfX01Ol0003o001^o`000?l007ko000000Co01bQ
0_l00004odI8/003o`000?mEFkcoEE^l00[oEE^l00?o0000ogQa_omhLKl01OmhLKl2o`0000koOWc6
00?o0000oi>8a?nCR<@06_nCR<@00ol0003oYI;1ojFB`@06o`0001?oYIG50_l00005ojNLb`03o`00
0?ncXLGo/j7501_o/j750_l00005okNYb`03o`000?o1[<Go`Jc5017o`Jc500?o0000olFdbOo5]<T0
0_o5]<T3o`0000goak3400?o0000olnc__l000004?oD_<800ol0003ofL?5omW3a@0=omW3a@03o`00
0?oTc<3oi<c000Coi<c000?o0000onC<`?oTc<000_oTc<000ol0003oj]S2on[H`P02on[H`P03o`00
0?o_e[SokmJh00;okmJh00?o0000ooWNZ_oigZX00ooigZX00ol0003onnRSoo_XX`02oo_XX`04o`00
0?o_g6ookma_o`0002oooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0;oookJP04
o`000?oZR4OojXQ7onZ8A`;o00000oo^VfL00ol0003oiiE^onNEKP08onNEKP04o`000?oPSg;o0000
o`0000[ogiZ500?o0000omVCQ_oIThH03?oIThH00ol0003odhj8o`000002o`0000WodYFD00Go0000
oljBUOo>TYGocY:Eo`00000BolV=U003o`000?o3QiCo`hND01;o`hND4ol0000<okR5WP03o`000?ne
PIgo]H6M00Wo]H6M00?o0000oj]jW_n[NYh03?n[NYh:o`0000GoZG6D00Co0000ojM`TonWL9?o0000
7onJII<00ol0003oREVBohUITP07ohUITP03o`000?oCemcodmOL013odmOL00?o0000omKSh?oFhn00
1OoFhn02o`0000KohN;D00?o0000onW]cooYkLl02?oYkLl00ol0003ojOO<onWgc004onWgc003o`00
0?o^n;_o000000?oi?Z`0ol0000IoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0
8_oonfX001kooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003o001^o`00KP02o`0000Go01bQ0_l0
0003odI8/003o`000?mEFkcoEE^l00[oEE^l00?o0000ogQa_omhLKl01?mhLKl00ol0003oOWc6ogil
aP0?ogilaP03o`000?nCR<CoThS401WoThS41_l0000DojFEa@;o00001onWW</00ol0003o/j75ok>Q
a@0Jok>Qa@03o`000?ngZL_o]jW;00Ko]jW;00?o0000ol6/aOo1[<D03oo1[<D00ol0003oaKC9olFd
b@06olFdb@Co00002_o7/<@00ol0003oe;c2omBl`P0>omBl`P03o`000?oI`lGofL?500gofL?500?o
0000omk=b?l000001_oTc<001Ol0003oi<c0onC<`?oTc<3o000000Goj]S200Ko0000onoF^?o_e[So
0000ooCQ]ol00004ooWNZP03o`000?okj:?onnRS00;onnRS00Co0000onoLKoo_g6oo0000;ooonfX0
0ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000onZ8AooZR4L00ooZR4L0
1?l0003okY]WonjKIol0000:onNEKP04o`000?oPSg;oh8mbon2?LP;o00002?oOVXD00ol0003ofI>6
omVCQP0<omVCQP03o`000?oCSXSodhj800;odhj80ol00006om:EU005o`000?o>TYGocY:EoljBUOl0
00004_o9SI@00ol0003o`hNDol>7U00Dol>7U003o`000?noQ9Co000000ko]gfD4ol00005okF1W@03
o`000?n[NYkoZgZN00;oZgZN2_l0000?ojUaU004o`000?nWL9?oYg2Co`0001ooVVFC00?o0000ohUI
T_n9FI801_n9FI800ol0003odmOLom?Gg00@om?Gg003o`000?oFhn3oe^?P00Soe^?P00Oo0000on7R
e?oQh]CohN;Do`000?oTk=Go000000WojNg?00?o0000onWgc?oYml`01OoYml`2o`0000?oi?Z`1?l0
000IoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX08_oonfX001kooo]Z00?o0000
oookJ_oonfX0BooonfX01?l0003o001^o`000?l00005o`0LX@05o`000?ljA[Co0000odI8/?l00000
3_mEFk`00ol0003oN76oogQa_`02ogQa_`03o`000?mnO<KoOWc6013oOWc600?o0000oi>8a?nCR<@0
5onCR<@4o`0001GoYIG50ol0000:ojNLb`03o`000?ncXLGo/j7501Oo/j750_l00009okNYb`03o`00
0?o1[<Go`Jc500ko`Jc500?o0000olFdbOo5]<T02oo5]<T3o`0000Koak340_l0000@omBl`P03o`00
0?oI`lGofL?500cofL?500Go0000omk=b?oNcLSog/g8o`000006onC<`003o`000?oTc<3o000000Oo
j]S200Go0000onoF^?l0003om>6go`000003ooWNZP03o`000?okj:?onnRS00?onnRS00Co0000onoL
Koo_g6oo0000;ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000
onZ8AooZR4L01?oZR4L01?l0003okY]WonjKIol00009onNEKP03o`000?oPSg;oh8mb00?oh8mb0_l0
0006omnJQ@03o`000?oIThKofI>600cofI>600?o0000om>>R?oCSXP01OoCSXP3o`0000?odYFD00Co
0000oljBUOo>TYGo00004oo9SI@00ol0003o`hNDol>7U00Dol>7U003o`000?noQ9Co000001[o]gfD
00?o0000okAjU?ndNY@01?ndNY@:o`0001SoZG6D00Go0000ojM`TonWL9?oYg2Co`00000OoiYUT`03
o`000?n9FI;oREVB00GoREVB00?o0000om?Gg?oCem`04?oCem`00ol0003oe^?PomKSh00:omKSh003
o`000?oQh]Co000000;oi>cE00?o0000onW]cooYkLl01_oYkLl00ol0003ojOO<onWgc006onWgc003
o`000?oTn[3oi?Z`00;oi?Z`0ol0000JoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oo
nfX08OoonfX001kooo]Z00?o0000oookJ_oonfX0BooonfX01?l0003o001^o`000?l00005o`0LX@03
o`000?ljA[Co>TJd00;o00003_mEFk`01Ol0003oN76oogQa_omhLKoo000001?oOWc600?o0000oi>8
a?nCR<@05?nCR<@4o`0000?oUHg800?o0000ojFEaOnUULD04?nUULD2o`0000goYic;00?o0000ok>Q
aOncXLD05_ncXLD00ol0003o]jW;okNYb`0:okNYb`03o`000?o1[<Go`Jc500_o`Jc50_l0000AolFd
b@?o00000_o7/<@01?l0003obkW9ol^ibOl0000>omBl`P03o`000?oI`lGofL?500cofL?500?o0000
omk=b?oNcLP00ooNcLP00ol0003oi<c0onC<`003onC<`0;o00002OoZf<82o`000003ooCQ]ol0003o
nMjZ00;onMjZ00?o0000oo_XXookj:<00ookj:<00ol0003okma_o`00000aoookJP03o`000?oonf[o
oo]Z04?ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ojXQ7onZ8A`04onZ8A`03o`000?o^VfOo
000000[oiiE^00?o0000on2?L_oPSg801?oPSg82o`0000CogiZ500?o0000omVCQ_oIThH03?oIThH0
0ol0003odhj8om>>R008om>>R0Co00000_o>TYD00ol0003obHfDolV=U00AolV=U003o`000?o3QiCo
`hND01Co`hND00?o0000okn4U?l000006_ngOI@00ol0003o]7ZDokAjU009okAjU003o`000?nYLICo
ZG6D01[oZG6D00Go0000ojM`TonWL9?oYg2Co`00000OoiYUT`03o`000?n9FI;oREVB00?oREVB0_l0
000Bom?Gg003o`000?oFhn3oe^?P00_oe^?P0ol00002onC/e@03o`000?oYkLoojNg?00KojNg?00?o
0000onWgc?oYml`01_oYml`01?l0003oi?Z`onCj/?oTn[03o`0001_ooo]Z00?o0000oookJ_oonfX0
>ooonfX00ol0003ooo]ZoookJP0QoookJP007_oonfX00ol0003ooo]ZoookJP1;oookJP04o`000?l0
06ko001^o`0000Ko01bQ00Co0000ocY6]?l0003oCEc20_l0000<oeEK_004o`000?mhLKooN76oo`00
01GoOWc600?o0000oi>8a?nCR<@04OnCR<@3o`0000KoUHg800?o0000ojFEaOnUULD03OnUULD3o`00
013oYic;00?o0000ok>QaOncXLD04oncXLD2o`0000go]jW;00?o0000ol6/aOo1[<D02_o1[<D00ol0
003oaKC9olFdb@0DolFdb@Co00000_o;^LT00ol0003oe;c2omBl`P0:omBl`P03o`000?oI`lGofL?5
00cofL?500?o0000omk=b?oNcLP01OoNcLP00ol0003oi<c0onC<`002onC<`0;o00002OoZf<801ol0
003oknC3o`000?odhKOo0000ooWNZ_l000001Ookj:<2o`000003onoLKol0003ooo]Z033ooo]Z00?o
0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oZR4OojXQ700GojXQ70_l0
000:onNEKP03o`000?oPSg;oh8mb00Koh8mb0_l00002omnJQ@03o`000?oIThKofI>600cofI>600?o
0000om>>R?oCSXP02ooCSXP4o`0001?obHfD00?o0000ol>7U?o3Qi@04oo3Qi@01?l0003o_hBDokn4
U?l0000IokMmU003o`000?ndNYCo]7ZD00[o]7ZD00?o0000ojUaU?nYLI@06_nYLI@01Ol0003oYg2C
ojM`TonWL9?o000001ooVVFC00Co0000ohUIT_n9FI;oREVB0_l000000oo?e]ko0000om?Gg00@om?G
g003o`000?oFhn3oe^?P00_oe^?P00Co0000omO^h_oGk^;oenkR0_l000000ooTk=Go0000onW]c`05
onW]c`03o`000?oYmlcojOO<00KojOO<0_l00002onCj/0Co00006OoonfX3o`0003gooo]Z00?o0000
oookJ_oonfX08OoonfX001kooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003o001^o`000006o`0L
X@03o`000?ljA[Co000000?oCEc200?o0000oeEK_?mEFk`02_mEFk`2o`0001KoOWc600?o0000oi>8
a?nCR<@03_nCR<@3o`0000[oUHg800?o0000ojFEaOnUULD02_nUULD2o`0001?oYic;00?o0000ok>Q
aOncXLD04OncXLD2o`00013o]jW;00?o0000ol6/aOo1[<D02?o1[<D00ol0003oaKC9olFdb@0EolFd
b@Cob;[=1?l0000:omBl`P03o`000?oI`lGofL?500gofL?500?o0000omk=b?oNcLP01_oNcLP01ol0
003oi<c0onC<`?oTc<3o0000on[H`_l000001ooZf<801?l0003oknC3onoT`oo_i<<2o`000003ooWN
Z_l0003onnRS00ConnRS1?l0000aoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0
3OoonfX00ol0003ojXQ7onZ8A`06onZ8A`;o00002OoWUFh00ol0003oh8mbon2?LP08on2?LP?o0000
3_oIThH00ol0003odhj8om>>R00;om>>R003o`000?o?RXOochZ700?o00004Oo9SI@00ol0003o`hND
ol>7U00Col>7U004o`000?noQ9Co_hBDo`0001Wo]gfD00?o0000okAjU?ndNY@02_ndNY@00ol0003o
ZG6DojUaU00IojUaU003o`000?nWL9?oYg2C00;oYg2C00?o0000oiYUTonJII<07OnJII<5o`0000?o
cmKN00?o0000om?Gg?oCem`03?oCem`2o`0000goe^?P00?o0000omO^h_oGk^801?oGk^82o`0000Go
jNg?00?o0000onWgc?oYml`01_oYml`2o`0000?oi?Z`00?o0000ojOWUOl000005ooonfX3o`0000;o
oo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0QoookJP007_oonfX00ol0003ooo]Z
oookJP1<oookJP04o`000?l006ko0000o`0000Go01bQ0_l00005odeL`P;o00002_mEFk`00ol0003o
OWc6ogilaP0FogilaP03o`000?nCR<CoThS400WoThS41Ol0000<oiF=b003o`000?nUULGoYIG500Oo
YIG50ol0000FojNLb`03o`000?ncXLGo/j7500oo/j7500?o0000okNYbongZL/04?ngZL/00ol0003o
`Jc5ol6/a@07ol6/a@03o`000?o5]<WoaKC901GoaKC92?o8^/d3o`0000Ooe;c200?o0000omW3aOoI
`lD03OoI`lD00ol0003og/g8omk=b008omk=b003o`000?oTc<3o000000?oj]S200?o0000on[H`_oZ
f<800ooZf<800ol0003oknC3onoT``03onoT``03o`000?oigZ[o000000GonnRS0_l000000ooSh73o
0000oookJP0`oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003o
jXQ7onZ8A`06onZ8A`04o`000?oTQ5;o0000o`0000OoiiE^00?o0000on2?L_oPSg802_oPSg82o`00
00gofI>600?o0000om>>R?oCSXP02ooCSXP01?l0003ochZ7oln:Qol00002olV5R0Co00003Oo9SI@0
0ol0003o`hNDol>7U00Col>7U004o`000?noQ9Co_hBDo`0001Wo]gfD00?o0000okAjU?ndNY@02_nd
NY@00ol0003oZG6DojUaU00IojUaU003o`000?nWL9?oYg2C00?oYg2C00?o0000oiYUTonJII<06_nJ
II<3o`000003oh9;QOl0003o000000GocmKN00?o0000om?Gg?oCem`02_oCem`00ol0003oe^?PomKS
h00<omKSh003o`000?oGk^;oenkR00KoenkR0_l00003onW]c`03o`000?oYmlcojOO<00KojOO<00?o
0000on;m`_l000000_oTn[000ol0003oYnNEo`00000DoookJPCo00001_oonfX00ol0003ooo]Zoook
JP0joookJP03o`000?oonf[ooo]Z027ooo]Z000NoookJP03o`000?oonf[ooo]Z04cooo]Z00Go0000
o`00K_l0003o00^Io`000005o`0LX@03o`000?m=G<;oCEc200GoCEc20_l00008oeEK_003o`000?mn
O<KoOWc601KoOWc600?o0000oi>8a?nCR<@01_nCR<@5o`0000ooUHg800?o0000ojFEaOnUULD01OnU
ULD2o`0001WoYic;00?o0000ok>QaOncXLD03OncXLD2o`0001?o]jW;00?o0000ol6/aOo1[<D01_o1
[<D00ol0003oaKC9olFdb@0DolFdb@03o`000?o8^/gob;[=00Sob;[=00?o0000om6la_l000001_oD
_<800ol0003ofL?5omW3a@0<omW3a@03o`000?oNcLSog/g800[og/g800?o0000on[H`_oZf<800ooZ
f<800ol0003oj]S2on[H`P02on[H`P03o`000?o_i<?oknC300CoknC31?l00002oo_XX`Co0000<_oo
nfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000onZ8AooZR4L01_oZ
R4L01Ol0003oi8ABonB4D_oTQ5;o000000KoiiE^00?o0000on2?L_oPSg802_oPSg801?l0003ofHUf
o`000?l0000;omVCQP03o`000?oCSXSodhj800_odhj800Co0000oln:Qoo?RXOo00001_o9QHP4o`00
00SobHfD00?o0000ol>7U?o3Qi@05?o3Qi@01?l0003o_hBDokn4U?l0000IokMmU003o`000?ndNYCo
]7ZD00[o]7ZD00?o0000ojUaU?nYLI@06OnYLI@00ol0003oYg2CojM`T`03ojM`T`03o`000?nJII?o
VVFC01GoVVFC1Ol00002oiEJQ`;o00002?o?e]h00ol0003odmOLom?Gg008om?Gg003o`000?oFhn3o
e^?P00coe^?P00?o0000omO^h_oGk^801ooGk^801Ol0003ogO3Mo`000?oYkLoo000000SojOO<00?o
0000on;m`_oRoL800ol000000onWiiGo0000o`00000AoookJP?o00002ooonfX00ol0003ooo]Zoook
JP0ioookJP03o`000?oonf[ooo]Z027ooo]Z000MoookJP03o`000?oonf[ooo]Z04kooo]Z0_l00000
0ol02iWo0000o`0LX@04o`0LX@03o`000?m=G<;oCEc200OoCEc20_l00005oeEK_003o`000?mOJ<Co
000001OoOWc600?o0000oi>8a?nCR<@00onCR<@3o`000003oi>8a?l0003o000001;oUHg800?o0000
ojFEaOnUULD00_nUULD2o`0001_oYic;00?o0000ok>QaOncXLD02oncXLD2o`0001Ko]jW;00?o0000
ol6/aOo1[<D00oo1[<D2o`0001KoaKC900?o0000olRjcOo8^/d02_o8^/d01?l0003odKc6o`000?l0
0003omBl`P03o`000?oI`lGofL?500cofL?500?o0000omk=b?oNcLP02ooNcLP00ol0003oj]S2on[H
`P03on[H`P05o`000?oZf<;oj]S2on[H`_l000001oo_i<<01?l0003omnn^ooO_[_ogkjh3o`000003
ongbW?l0003o000003;ooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0>oookJP03
o`000?oZR4OojXQ700KojXQ700Co0000onB4D_oTQ5;oi8AB0_l00004onNEKP03o`000?oPSg;oh8mb
00[oh8mb00Co0000omV9M_oIRGKofHUf0_l00009omVCQP03o`000?oCSXSodhj800[odhj800Go0000
oln:Qoo?RXOochZ7o`00000:olV5R0?o00001Oo9SI@00ol0003o`hNDol>7U00Dol>7U005o`000?no
Q9Co_hBDokn4U?l000006?ngOI@00ol0003o]7ZDokAjU00:okAjU003o`000?nYLICoZG6D01WoZG6D
00?o0000ojM`TonWL9<00onWL9<00ol0003oVVFCoiYUT`0AoiYUT`Co00001onEFXL00ol0003ocmKN
oloFgP08oloFgP03o`000?oCemcodmOL00KodmOL00?o0000omKSh?oFhn003?oFhn000ol0003oenkR
omO^hP08omO^hP03o`000?oMl=gogO3M00Go00001?oYml`00ol0003oh_g2on;m`P02o`000004olcl
^Ol0003oYnNEo`0000kooo]Z1?l0000?oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oo
nfX08OoonfX001gooo]Z00?o0000oookJ_oonfX0C_oonfX2o`0000;o00^I00?o0000o`0LXOl07:40
0_l07:400ol0003oCEc2odeL`P09odeL`P05o`000?mEFkcoEE^loeEK_?l000000_mOJ<@00ol0003o
OWc6ogilaP0FogilaP03o`000?nCR<Co000000;o00000_nCR<@2o`0001CoUHg800Go0000ojFEaOnU
ULGoYIG5o`00000NojNLb`03o`000?ncXLGo/j7500Wo/j7500?o0000okNYbongZL/05_ngZL/00ol0
003o`Jc5ol6/a@02ol6/a@03o`000?o5]<WoaKC901GoaKC900?o0000olRjcOo8^/d02oo8^/d01ol0
003odKc6om6la_oA_<Ko0000omBl`_l000003ooI`lD00ol0003og/g8omk=b00:omk=b003o`000?oS
f<_o000000Goj]S200?o0000on[H`_l000002?o_i<<00ol0003omnn^ooO_[P03ooO_[P04o`000?o]
lYco0000o`0003;ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0?oookJP;o0000
1ooZR4L00ol0003oi8ABonB4DP03onB4DP;o00000_oWUFh00ol0003oh8mbon2?LP0:on2?LP03o`00
0?oIRGKofHUf00?ofHUf0ol00006omVCQP03o`000?oCSXSodhj800[odhj800Go0000oln:Qoo?RXOo
chZ7o`00000=olV5R0Co000000?obHfDo`000?o3Qi@05Oo3Qi@01Ol0003o_hBDokn4U?noQ9Co0000
01Oo]gfD00?o0000okAjU?ndNY@02ondNY@00ol0003oZG6DojUaU00HojUaU003o`000?nWL9?oYg2C
00CoYg2C00?o0000oiYUTonJII<03?nJII<5o`0000[oUEZ700?o0000oloFg_o?e]h02Oo?e]h00ol0
003odmOLom?Gg005om?Gg003o`000?oFhn3oe^?P00coe^?P00?o0000omO^h_oGk^802OoGk^800ol0
003ogO3Mo`000005om_kfPSo000000Coc?bio`000?nWiiGo00003?oonfX3o`0001Cooo]Z00?o0000
oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0QoookJP007OoonfX00ol0003ooo]ZoookJP1>oook
JP?o00000_l02iT01?l0003o01bQo`0LXOl07:42o`0000_oCEc20_l000000omEFkco0000oemXa002
oemXa003o`000?mnO<KoOWc601CoOWc60ol00002oi>8a0?o00005OnESLP3o`00027oYic;00?o0000
ok>QaOncXLD01oncXLD2o`0001[o]jW;0oo1[<D00ol0003oaKC9olFdb@0EolFdb@03o`000?o8^/go
b;[=00gob;[=00Co0000om6la_oA_<KodKc60_l0000>omW3a@03o`000?oNcLSog/g800[og/g800Go
0000on?HbooSf<_ohmS;o`000005on[H`P;o00001oo_i<<00ooalL3o0000ooO_[P03ooO_[P04o`00
0?o]lYcokO:Lo`0003Cooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0?oookJP03
o`000?oNKA_o000000KojXQ700?o0000onB4D_oTQ5801OoTQ5801?l0003oiiE^onNEK_l0000<on2?
LP03o`000?oIRGKofHUf00GofHUf0_l00004omVCQP03o`000?oCSXSodhj800[odhj800Go0000oln:
Qoo?RXOochZ7o`00000AolV5R0Go00004oo3Qi@01Ol0003o_hBDokn4U?noQ9Co000001Oo]gfD00?o
0000okAjU?ndNY@02ondNY@00ol0003oZG6DojUaU00HojUaU003o`000?nWL9?oYg2C00CoYg2C00?o
0000oiYUTonJII<02?nJII<4o`0000goUEZ70_l0000=oloFgP03o`000?oCemcodmOL00?odmOL00?o
0000omKSh?oFhn003?oFhn000ol0003oenkRomO^hP0:omO^hP;o00002?oKnmX00ol0003oc_o>olko
cP02olkocP;o00000_nWiiD00ol0003ooo]ZoookJP07oookJP?o00005ooonfX00ol0003ooo]Zoook
JP0goookJP03o`000?oonf[ooo]Z027ooo]Z000MoookJP03o`000?oonf[ooo]Z04oooo]Z0_l00003
o`0;V@05o`000?l07:7o0000oaXj]_l000003Om=G<83o`0000;oGfS400?o0000ogila_mnO<H04?mn
O<H4o`000005ogila_l0003oThS4oi>8a?l000004onESLP5o`0000;oUiG@00?o0000ojNLbonWW</0
8?nWW</00ol0003o/j75ok>Qa@05ok>Qa@03o`000?ngZL_o]jW;01[o]jW;00?o0000ol6/aOl00000
5_o5]<T2o`00013ob;[=00Co0000om6la_oA_<Ko00000_oEaLX00ol0003ofL?5omW3a@0:omW3a@03
o`000?oNcLSog/g800[og/g800?o0000on?HbooSf</00_oSf</00ol0003oj]S2on[H`P03on[H`P;o
00001_o_i<<00ol0003olO70o`000003ooO_[P05o`000?o]lYcokO:LongbW?l00000=?oonfX00ol0
003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000omi]6ol000001OoZR4L00ol0
003oi8ABonB4DP06onB4DP?o00003?oPSg800ol0003ofHUfomV9MP07omV9MP;o00000_oIThH00ol0
003odhj8om>>R00:om>>R005o`000?o?RXOochZ7oln:Qol000004_o9QHP01?l0003o`h29ol>0ROo3
P8T5o`0000go`hND00?o0000okn4U?noQ9@00_noQ9@00ol0003o]gfDokMmU00EokMmU003o`000?nd
NYCo]7ZD00_o]7ZD00?o0000ojUaU?nYLI@06?nYLI@00ol0003oYg2CojM`T`04ojM`T`03o`000?nJ
II?oVVFC00CoVVFC1?l0000@oiEJQ`03o`000?o?e]kocmKN00kocmKN00Go0000om?Gg?oCemcodmOL
o`00000>omKSh003o`000?oGk^;oenkR00[oenkR0_l00008om_kfP03o`000?o>olkoc_o>00?oc_o>
00Co0000ojOWUOnWiiGo00001_oonfX4o`0001_ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003o
oo]ZoookJP0PoookJP007OoonfX00ol0003ooo]ZoookJP1?oookJP;o00000ol02iT01Ol0003o01bQ
o`000?lJ>[Ko000000goCEc20omJK</3o`0000ooOWc60ol00005ogilaP;o00004OnESLP4o`0000So
UiG@00?o0000ojNLbonWW</07onWW</00ol0003o/j75ok>Qa@03ok>Qa@;o00007_ngZL/00ol0003o
aKC9olFdb@0DolFdb@03o`000?o8^/gob;[=013ob;[=00?o0000om6la_l000001?oEaLX2o`0000Wo
fL?500?o0000omk=b?oNcLP02ooNcLP00ol0003ohmS;on?Hb`03on?Hb`05o`000?oZf<;oj]S2on[H
`_l000000_o_i<<00ol0003oknC3onoT``03onoT``?olO7000Co0000ooO_[_ogkjko00000oo]lY`0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX04?oonfX0
1?l0003ogVdKomi]6ol00005onZ8A`03o`000?oTQ5;oi8AB00Ooi8AB0_l0000;on2?LP03o`000?oI
RGKofHUf00WofHUf0ol0000<om>>R005o`000?o?RXOochZ7oln:Qol000004_o9QHP00ol0003o`h29
ol>0R@06ol>0R@Ko00001oo3Qi@00ol0003o_hBDokn4U002okn4U003o`000?ngOICo]gfD01Go]gfD
00?o0000okAjU?ndNY@02ondNY@00ol0003oZG6DojUaU00GojUaU003o`000?nWL9?oYg2C00GoYg2C
00?o0000oiYUTol000001?l0000CoiEJQ`03o`000?o?e]kocmKN013ocmKN00?o0000om?Gg?l00000
3_oFhn000ol0003oenkRomO^hP0:omO^hP03o`000?oFmn;o000000Oofo_J00?o0000olkoc_o>olh0
0oo>olh01?l0003oYnNEojOWUOl00004oookJP?o00008?oonfX00ol0003ooo]ZoookJP0foookJP03
o`000?oonf[ooo]Z023ooo]Z000MoookJP03o`000?oonf[ooo]Z04oooo]Z0_l00004o`0;V@;o0000
0_lJ>[H00ol0003oCEc2odeL`P09odeL`P03o`000?mJK<_oFVc;00CoFVc;1_l00006ogilaP?o0000
1omnO<H00ol0003oPH;;o`00000<oiF=b0Go00003?nGUM000ol0003oYic;ojNLb`0PojNLb`03o`00
0?ncXLGo/j7500;o00007_ngZL/00ol0003o^Jo@o`00000EolFdb@03o`000?o8^/gob;[=01;ob;[=
00?o0000omG5b_oEaLX01OoEaLX00ol0003ofL?5omW3a@05omW3a@03o`000?oNcLSog/g800_og/g8
00?o0000on?HbooSf</01?oSf</01Ol0003oj]S2on[H`_oZf<;o000000;oknC300?o0000onoT`oo_
i<<00_o_i<<01ol0003olO70oo7a`?oalL3o0000ooO_[_l000000oo]lY`00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ogVdKomi]6`02
o`0000?ojXQ700?o0000onB4D_oTQ5801ooTQ5801?l0003ogX1Ko`000?l00009on2?LP03o`000?oI
RGKofHUf00_ofHUf0ol0000:om>>R005o`000?o?RXOochZ7oln:Qol000004_o9QHP00ol0003o`h29
ol>0R@0<ol>0R@Go00000_o3Qi@00ol0003o_hBDokn4U002okn4U003o`000?ngOICo]gfD01Go]gfD
00?o0000okAjU?ndNY@02ondNY@00ol0003oZG6DojUaU00CojUaU0ko00005_nEFXL2o`0001CocmKN
00?o0000omKSh?oFhn002ooFhn02o`0000coenkR00Co0000omKgh_oFmn;o00001_oKnmX00ol0003o
c_o>olkocP03olkocP05o`000?nWiiGoYnNEo`000?oonfX01?l0000ToookJP03o`000?oonf[ooo]Z
03Gooo]Z00?o0000oookJ_oonfX08?oonfX001cooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003o
00^Io`0;V@03o`0;V@04o`000?lJ>[Ko6SZfo`0000_oCEc200?o0000oeY/bomJK</01?mJK</00ol0
003oO83<ogb0c003ogb0c0[o00001OmnO<H01Ol0003oPH;;oh62bon1P/_o000000OoUHg81?l0000B
oiNEd003o`000?nWW<_oYic;01ooYic;00?o0000ok>QaOl000007_ngZL/2o`0000?o^Jo@00?o0000
olFdbOo5]<T04Oo5]<T00ol0003ob;[=olRjc@0BolRjc@03olc3d_l0003oeLG:00OoeLG:00?o0000
omW3aOoI`lD01?oI`lD00ol0003og/g8omk=b00:omk=b003o`000?oSf<_ohmS;00KohmS;00?o0000
on[H`_l000001?o_i<<01?l0003oknC3onoT`oo_i<<4oo7a`003o`000?ogkjko000000?okO:L00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z017ooo]Z00?o
0000omi]6ooNKA/00_oNKA/01?l0003ojXQ7onZ8Aol00009onB4DP04o`000?oNP5_ogX1Komj0F`;o
00001ooPSg800ol0003ofHUfomV9MP0;omV9MP03o`000?oCQGWodhEi00?o00001ooCSXP01Ol0003o
chZ7oln:Qoo?RXOo000001;obHF800?o0000ol>0ROo3P8T04Oo3P8TDo`0000[o]gfD00?o0000okAj
U?ndNY@03?ndNY@00ol0003oZG6DojUaU00:ojUaU0Wo00001?nVIhP00ol0003oY6J9ojAVR@05ojAV
R@03o`000?nEFXOoUEZ701CoUEZ700?o0000oloFg_o?e]h04_o?e]h00ol0003odN3So`00000<omKS
h003o`000?oGk^;oenkR00_oenkR00Co0000omKgh_oFmn;o00001_oKnmX00ol0003oc_o>olkocP03
olkocP03o`000?nWiiGoYnNE00?o0000:OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o
oo]Z023ooo]Z000LoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000o`0;VOl02iT00ol02iT01?l0
003o6SZfoaXj]_l0000:odeL`P03o`000?mJK<_oFVc;00KoFVc;00?o0000ogb0c?mlP<`00_mlP<`3
o`0000OoO83<2?l000001?n1P/_o0000oiF=b?nESLP5o`0001KoUiG@00?o0000ojNLbonWW</07onW
W</2o`0001ko]jW;00?o0000okV_d?ni[m000oni[m000ol0003oaKC9olFdb@0@olFdb@03o`000?o8
^/gob;[=017ob;[=00Go0000olc3d_o<`m;oc<?Bo`000008omG5bP;o00000ooI`lD00ol0003og/g8
omk=b00:omk=b003o`000?oSf<_ohmS;00SohmS;00?o0000onoT`oo_i<<01?o_i<<00ol0003oknC3
oo7a`004oo7a`0;o00000oo]lY`2o`0003Gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Z
oookJP0BoookJP03o`000?oNKA_ogVdK00;ogVdK00?o0000onZ8Aol000002_oTQ5800ol0003ogX1K
omj0F`02omj0F`;o00001OoPSg800ol0003ofHUfomV9MP0;omV9MP03o`000?oCQGWodhEi00?odhEi
0ol00003om>>R003o`000?o?RXOochZ700;ochZ700?o0000olV5R?o9QHP04?o9QHP00ol0003o`h29
ol>0R@0Col>0R@03o`000?noO8Wo_gb900;o_gb900?o0000okIdROnfM8T02_nfM8TCo`0000Ko]7ZD
00Co0000ojUaU?nYLICoZG6D2Ol0000=ojIWR003o`000?nTIXWoY6J900GoY6J900?o0000oiEJQonE
FXL04onEFXL00ol0003ocmKNoloFgP0BoloFgP04o`000?oAh>?odN3So`0000_oe^?P00?o0000omO^
h_oGk^802ooGk^801Ol0003oe_ORomKgh_oFmn;o000000Gofo_J00?o0000olkoc_o>olh00oo>olh4
o`0002cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0PoookJP007?oonfX00ol0
003ooo]ZoookJP1AoookJP;o00001?l02iT2o`0000;o6SZf00?o0000odeL`_m=G<801om=G<800ol0
003oFVc;oeY/b`06oeY/b`Go00003?mlP<`00ol0003oOhK@ogn6d003ogn6d0Co00007?nGUM000ol0
003oYic;ojNLb`0LojNLb`;o000000?oZ:?@o`000?ngZL/06ongZL/2o`0000Oo^Jo@00?o0000olFd
bOo5]<T03_o5]<T00ol0003ob;[=olRjc@0AolRjc@03o`000?o<`m;oc<?B00?oc<?B00?o0000omG5
b_oEaLX01ooEaLX00ol0003ofL?5o`00000<omk=b003o`000?oSf<_ohmS;00WohmS;00?o0000onoT
`oo_i<<01Oo_i<<00ol0003olO70oo7a`003oo7a`004o`000?o]lYcokO:LongbW0;o0000=_oonfX0
0ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000omi]6ooNKA/00ooNKA/2
o`0000[oi8AB00?o0000omj0FooNP5/01?oNP5/2o`0000?oh8mb00?o0000omV9M_oIRGH02ooIRGH0
0ol0003odhEiom>5N@06om>5N@Co00001?o?RXL00ol0003obHF8olV5R00@olV5R003o`000?o3P8Wo
`h2901?o`h2900?o0000okmlROnoO8T00_noO8T00ol0003o]WB9okIdR@0DokIdR@03o`000?nbLXWo
/W:900Ko/W:92_l0000GojIWR003o`000?nTIXWoY6J900CoY6J900?o0000oiEJQonEFXL04_nEFXL0
0ol0003ocmKNoloFgP0AoloFgP;o00001?oAh><00ol0003oe^?PomKSh007omKSh003o`000?oGk^;o
enkR00_oenkR00?o0000omKgh_oFmn800_oFmn800ol0003ofo_Jom_kfP02om_kfP04o`000?o>olko
c_o>olkocPCo000000?oYnNEo`000?oonfX0;OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z023ooo]Z000LoookJP03o`000?oonf[ooo]Z05;ooo]Z0_l00003o`0;V@05o`000?l5=KOo
0000oaXj]_l000002?m=G<800ol0003oFVc;oeY/b`05oeY/b`?o00003omlP<`00ol0003oOhK@ogn6
d006ogn6d003o`000?nGUM3oUiG@01_oUiG@00?o0000ojNLbonWW</06OnWW</3o`0000CoZ:?@00?o
0000okNYbongZL/06?ngZL/00ol0003o^Jo@okV_d007okV_d003o`000?o5]<WoaKC900coaKC90_l0
000ColRjc@03o`000?o<`m;oc<?B00Coc<?B00?o0000omG5b_oEaLX02?oEaLX2o`0000cog/g800?o
0000on?HbooSf</02?oSf</00ol0003oinC>o`000006onoT``03oo7a`?l0003olO7000?olO7000Co
0000ongbW?o]lYcokO:L0_l0000foookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0
4ooonfX00ol0003ogVdKomi]6`04omi]6`;o00002OoTQ5800ol0003ogX1Komj0F`06omj0F`;o0000
0_oPSg800ol0003ofHUfomV9MP0;omV9MP03o`000?oCQGWodhEi00SodhEi1?l000000oo?RXOo0000
olV5R00BolV5R003o`000?o3P8Wo`h2901;o`h2900?o0000okmlROnoO8T00_noO8T00ol0003o]WB9
okIdR@0DokIdR@03o`000?nbLXWo/W:900co/W:900?o0000ojIWR?nVIhP06?nVIhP00ol0003oY6J9
ojAVR@04ojAVR@03o`000?nEFXOoUEZ7013oUEZ70_l0000ColoFgP03o`000?oAh>?odN3S00CodN3S
00?o0000omKSh?oFhn001_oFhn000ol0003oenkRomO^hP0;omO^hP03o`000?oFmn;oe_OR00;oe_OR
00?o0000om_kf_oKnmX00_oKnmX5o`000005olkoc_l0003o^oVkojOWUOl00000<?oonfX00ol0003o
oo]ZoookJP0boookJP03o`000?oonf[ooo]Z023ooo]Z000LoookJP03o`000?oonf[ooo]Z05;ooo]Z
0_l00003o`0;V@03o`000?l5=KOo1CFg00;o00002?m=G<800ol0003oFVc;oeY/b`02oeY/b`?o0000
0omJK</00ol0003oO83<ogb0c00;ogb0c003o`000?moQ]3oOhK@00SoOhK@00?o0000oiNEd?nGUM00
6onGUM000ol0003oYic;ojNLb`0FojNLb`;o00001onXXm000ol0003o]jW;okNYb`0GokNYb`03o`00
0?ni[m3o^Jo@00Wo^Jo@00?o0000olFdbOo5]<T02_o5]<T00ol0003ob;[=olRjc@0BolRjc@03o`00
0?o<`m;oc<?B00Koc<?B00?o0000omG5b_oEaLX01_oEaLX01?l0003ofLk>omW>c_l0000:omk=b003
o`000?oSf<_ohmS;00SohmS;00Co0000onOTc_oWi<ko00001Oo_i<<2oo7a`004o`000?oalL3olO70
oo7a`0;o00000_o]lY`00ol0003ocN=ho`00000goookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ogVdKomi]6`04omi]6`;o00002OoTQ5800ol0003ogX1Komj0F`07
omj0F`?o00003OoIRGH00ol0003odhEiom>5N@08om>5N@04o`000?o>OgOocWmgolioM`Co00004Oo9
QHP00ol0003o`h29ol>0R@0Bol>0R@05o`000?noO8Wo_gb9okmlROl000005onfM8T00ol0003o/W:9
ok9bR@0<ok9bR@03o`000?nVIhSoYVN801SoYVN800?o0000ojAVROnTIXT01?nTIXT00ol0003oUEZ7
oiEJQ`0>oiEJQ`;o00000_o0e>T00ol0003ocmKNoloFgP0?oloFgP03o`000?oAh>?odN3S00GodN3S
00?o0000omKSh?oFhn001OoFhn000ol0003oenkRomO^hP0;omO^hP03o`000?oFmn;oe_OR00?oe_OR
00?o0000om_kf_oKnmX00ol00004olkocP04o`000?nknK_oYnNEo`0003;ooo]Z00?o0000oookJ_oo
nfX0<OoonfX00ol0003ooo]ZoookJP0PoookJP007?oonfX00ol0003ooo]ZoookJP1BoookJP;o002=
00Co0000o`0;VOl02iWo00000ol5=KL2o`0000KoCEc200?o0000oeY/bomJK</00ol00006oeY/b`03
o`000?mlP<coO83<00[oO83<00?o0000ogn6d?moQ]002OmoQ]000ol0003oUiG@oiNEd00KoiNEd003
o`000?nWW<_oYic;01CoYic;0_l00009ojRSd003o`000?ngZL_o]jW;01Go]jW;0_l0000=okV_d003
o`000?o5]<WoaKC900SoaKC900?o0000olRjcOo8^/d04_o8^/d00ol0003oc<?Bolc3dP08olc3dP03
o`000?oEaL[oeLG:00CoeLG:00?o0000omW>c_oIc/h00_oIc/h00ol0003og/g8omk=b006omk=b003
o`000?oSf<_ohmS;00SohmS;00Go0000onOTc_oWi<koinC>o`000004onoT``09o`000?oalL3olO70
oo7a`?l0003olO70o`000?o/nKOo000000;okO:L0_l0000hoookJP03o`000?oonf[ooo]Z03oooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ogVdKomi]6`04omi]6`04o`000?oLKBko0000o`0000Oo
i8AB00?o0000omj0FooNP5/02OoNP5/2o`0000cofHUf00?o0000om>5NOoCQGT01ooCQGT00ol0003o
cWmgolioM`03olioM`03o`000?o7NW[oagYj00Co00003Oo9QHP00ol0003o`h29ol>0R@0Bol>0R@05
o`000?noO8Wo_gb9okmlROl000005onfM8T00ol0003o/W:9ok9bR@0<ok9bR@03o`000?nVIhSoYVN8
01SoYVN800?o0000ojAVROnTIXT01?nTIXT00ol0003oUEZ7oiEJQ`0=oiEJQ`03o`000?o0e>Wo`=CY
00?o`=CY00?o0000oloFg_o?e]h03?o?e]h2o`0000WodN3S00?o0000omKSh?oFhn000ooFhn000ol0
003oenkRomO^hP0:omO^hP;o00001OoFmn85o`0000Goc_o>00Co0000ok_i^onWiiGo0000=?oonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01oooo]Z000KoookJP03o`000?oonf[ooo]Z
05Cooo]Z00Go002=o`000?l02iWo00^Io`000004o`De]`;o00001?m=G<84o`0000[oFVc;00?o0000
ogb0c?mlP<`02?mlP<`00ol0003oOhK@ogn6d00;ogn6d003o`000?nGUM3oUiG@01[oUiG@00?o0000
ojNLbonWW</04_nWW</2o`0000WoZ:?@1?l000000ongZL_o0000o`000008o`0000[o]jW;00?o0000
okV_d?ni[m003Oni[m000ol0003oaKC9olFdb@07olFdb@03o`000?o8^/gob;[=01;ob;[=00?o0000
olc3d_o<`m802_o<`m800ol0003oeLG:omG5bP02omG5bP03o`000?oIc/kofLk>00CofLk>00?o0000
omk=b?oNcLP01?oNcLP00ol0003ohmS;on?Hb`09on?Hb`03o`000?oWi<koinC>00;oinC>00Co0000
onoT`oo_i<?oknC31OoalL02o`000006onci]ol0003okO:Lo`000?o=hgSo0000>?oonfX00ol0003o
oo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000omi]6ooNKA/01?oNKA/00ol0003o
g6d^oma];P02o`0000Goi8AB00?o0000omj0FooNP5/02OoNP5/01?l0003oegaQo`000?l0000:omV9
MP03o`000?oCQGWodhEi00OodhEi00?o0000olioMoo>OgL00oo>OgL00ol0003oagYjolMjNP04olMj
NPCo00002Oo9QHP00ol0003o`h29ol>0R@0Bol>0R@05o`000?noO8Wo_gb9okmlROl000005onfM8T0
0ol0003o/W:9ok9bR@0<ok9bR@03o`000?nVIhSoYVN801WoYVN800?o0000ojAVROnTIXT00onTIXT0
0ol0003oUEZ7oiEJQ`0;oiEJQ`;o00001oo0e>T00ol0003ocmKNoloFgP0:oloFgP03o`000?oAh>?o
dN3S00WodN3S00?o0000omKSh?oFhn000_oFhn000ol0003oenkRomO^hP0:omO^hP03o`000?oFmn;o
e_OR00;oe_OR1?l00002om_kfP03o`000?o>olkoc_o>00?oc_o>00Go0000ok_i^ol0003oYnNEo`00
000doookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX07ooonfX001_ooo]Z00?o0000
oookJ_oonfX0E?oonfX01Ol0003o002=o`000?l02iWo000000Co1CFg00?o0000od5Mb?l000001?l0
000=oeY/b`03o`000?mlP<coO83<00OoO83<00?o0000ogn6d?moQ]003?moQ]000ol0003oUiG@oiNE
d00KoiNEd003o`000?nWW<_oYic;00ooYic;0_l00006ojRSd0Go00000onXY=800ol0003o]Z[=okJZ
c@09okJZc@oo00003?ni[m000ol0003oaKC9olFdb@05olFdb@03o`000?o8^/gob;[=017ob;[=0_l0
000=olc3dP05o`000?oEaL[oeLG:omG5b_l000002?oIc/h00ol0003og/g8omk=b003omk=b003o`00
0?oSf<_ohmS;00SohmS;00?o0000onOTc_oWi<h00ooWi<h01?l0003oknC3onoT`ol00005oo7a`0?o
00000_o]lY`00ol0003ocN=ho`00000hoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oo
nfX05OoonfX00ol0003ogVdKomi]6`04omi]6`03o`000?oLKBkog6d^00;og6d^0_l00004onB4DP03
o`000?oNP5_ogX1K00SogX1K00Co0000omMlHOoGO67oegaQ0_l00008omV9MP03o`000?oCQGWodhEi
00OodhEi00?o0000olioMoo>OgL00oo>OgL00ol0003oagYjolMjNP08olMjNPCo00001Oo9QHP00ol0
003o`h29ol>0R@0Col>0R@04o`000?noO8Wo_gb9o`0001Oo]WB900?o0000ok9bROnbLXT03?nbLXT0
0ol0003oYVN8ojIWR00IojIWR003o`000?nTIXWoY6J900?oY6J900?o0000oiEJQonEFXL02OnEFXL2
o`0000[o`=CY00?o0000oloFg_o?e]h02?o?e]h00ol0003odN3Som7Ph`0:om7Ph`05o`000?oFhn3o
e^?PomKSh?l000003?oGk^800ol0003oe_ORo`000003o`0000?oe_OR00?o0000om_kf_l000001Oo>
olh01Ol0003o^oVko`000?nWiiGo000003Kooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP0OoookJP006ooonfX00ol0003ooo]ZoookJP1EoookJP04o`000?l008go0000o`0000Co1CFg
0ol000001?m1GLSo0000odeL`_l0000=oeY/b`03o`000?mlP<coO83<00KoO83<00?o0000ogn6d?mo
Q]003_moQ]000ol0003oUiG@oiNEd00JoiNEd003o`000?nWW<_oYic;00coYic;0ol00002ojRSd0Ko
00002OnXY=800ol0003o]Z[=okJZc@0>okJZc@;o00001onh/=89o`0000?o^Jo@00?o0000olFdbOo5
]<T01?o5]<T00ol0003ob;[=olRjc@0AolRjc@03o`000?o<`m;oc<?B00koc<?B00?o0000omG5b_l0
00002_oIc/h01Ol0003og/g8omk=b?oNcLSo000000[ohmS;00?o0000onOTc_oWi<h01?oWi<h00ol0
003oknC3onoT``06oo7a`007o`000?o/nKOo0000ongbW?l0003ocN=ho`00000ioookJP03o`000?oo
nf[ooo]Z03oooo]Z00?o0000oookJ_oonfX05_oonfX2o`0000GogVdK00?o0000oma];_oLKBh00ooL
KBh01Ol0003oi8ABonB4D_oTQ5;o000000_ogX1K00?o0000omMlHOoGO6400_oGO643o`0000GofHUf
00?o0000om>5NOoCQGT01_oCQGT00ol0003ocWmgolioM`05olioM`03o`000?o7NW[oagYj00_oagYj
1?l000000oo9QHSo0000ol>0R@0Dol>0R@04o`000?noO8Wo_gb9o`0001Oo]WB900?o0000ok9bROnb
LXT03?nbLXT00ol0003oYVN8ojIWR00IojIWR003o`000?nTIXWoY6J900?oY6J900?o0000oiEJQonE
FXL01onEFXL2o`0000go`=CY00?o0000oloFg_o?e]h01_o?e]h00ol0003odN3Som7Ph`0;om7Ph`04
o`000?oFhn3oe^?Po`0000coenkR0ol00007omKghP;o00001Oo>olh01Ol0003o^oVko`000?nWiiGo
000003Sooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0OoookJP006ooonfX00ol0
003ooo]ZoookJP1EoookJP05o`000?l008go0000o`000?l5=KL00ol000000ol5=KOo0000od5Mb002
od5Mb0;o00003_mJK</00ol0003oO83<ogb0c004ogb0c003o`000?moQ]3oOhK@00ooOhK@00?o0000
oiNEd?nGUM006onGUM000ol0003oYic;ojNLb`09ojNLb`Oo00003onXY=800ol0003o]Z[=okJZc@0=
okJZc@03o`000?nh/=;o^;3B013o^;3B1ol00002olFdb@03o`000?o8^/gob;[=017ob;[=00?o0000
olc3d_o<`m804?o<`m800ol0003ofLk>omW>cP0:omW>cP03o`000?oNcLSo000000[ohmS;00?o0000
onOTc_oWi<h01_oWi<h00ol0003olO70oo7a`004oo7a`003o`000?o/nKOok?Vg00;o00000_o=hgP0
0ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX05_oonfX0
0ol0003obdd0o`000004omi]6`03o`000?oLKBkog6d^00Cog6d^0_l000000ooTQ5;o0000omj0F`0:
omj0F`03o`000?oGO67oegaQ00GoegaQ0_l00003omV9MP03o`000?oCQGWodhEi00KodhEi00?o0000
olioMoo>OgL01Oo>OgL00ol0003oagYjolMjNP0?olMjNPGo00004_o3P8T01?l0003o_gb9okmlROl0
000HokIdR@03o`000?nbLXWo/W:900[o/W:900?o0000ojIWR?nVIhP06_nVIhP00ol0003oY6J9ojAV
R@03ojAVR@03o`000?nEFXOoUEZ700KoUEZ700?o0000ol3DjOo0e>T03_o0e>T00ol0003ocmKNoloF
gP03oloFgP;o00003ooAh><2o`0000[oenkR0ol00009omKghP;o00001Oo>olh00ol0003o^oVkok_i
^`02o`0003[ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0OoookJP006ooonfX0
0ol0003ooo]ZoookJP1EoookJP03o`000?l008go000000;o00001Ol5=KL01Ol0003o@Eg8od5Mb?l0
003oDVkA00?o00002omJK</00ol0003oO83<ogb0c003ogb0c003o`000?moQ]3oOhK@017oOhK@00?o
0000oiNEd?nGUM006_nGUM000ol0003oYic;ojNLb`03ojNLb`So00005OnXY=800ol0003o]Z[=okJZ
c@0:okJZc@;o00005onh/=800ol0003o`kC<ol>dc002o`0001?ob;[=00?o0000olc3d_o<`m803oo<
`m800ol0003od<gGo`00000=omW>cP03o`000?oSf<_ohmS;00SohmS;00?o0000onOTc_oWi<h01ooW
i<h00ol0003olO70oo7a`003oo7a`004o`000?o/nKOok?Vgonci]`;o000000?ocN=ho`000?oonfX0
>OoonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000ol]=0?l00000
1?oNKA/00ol0003og6d^oma];P05oma];P?o00002_oNP5/00ol0003oegaQomMlH@07omMlH@;o0000
0_oIRGH00ol0003odhEiom>5N@05om>5N@03o`000?o>OgOocWmg00GocWmg00?o0000olMjN_o7NWX0
4?o7NWX01?l0003o`WIlol9fO?o2MW`5o`0000go`h2900Co0000okmlROnoO8Wo00006?nfM8T00ol0
003o/W:9ok9bR@0:ok9bR@03o`000?nVIhSoYVN801[oYVN800?o0000ojAVROnTIXT00onTIXT00ol0
003oUEZ7oiEJQ`04oiEJQ`;o00004_o0e>T01Ol0003ocmKNoloFg_o?e]ko0000017odN3S00?o0000
omO^h_oGk^801OoGk^84o`000003omO^h_l0003oe_OR00Woe_OR00?o0000olkoc_o>olh00oo>olh0
0ol0003o^oVkok_i^`02o`0003_ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0O
oookJP006ooonfX00ol0003ooo]ZoookJP1CoookJPCo000000?o002=o`000?l000001Ol5=KL01?l0
003o@Eg8od5Mb?l00004oe9^d@;o00002_mJK</01Ol0003oO83<ogb0c?mlP<co000001CoOhK@00?o
0000oiNEd?nGUM006_nGUM02o`000005ojNLbol0003o0000o`000?nWW/d00ol0000IojRTdP03o`00
0?nfZ/go]Z[=00So]Z[=0_l0000JokR`dP03o`000?o3]<co000000;oa[cA0ol0000>olRjc@03o`00
0?o<`m;oc<?B00ooc<?B00Go0000om3=eoo@cMOod<gGo`00000<omW>cP03o`000?oSf<_ohmS;00So
hmS;00?o0000onOTc_oWi<h01_oWi<h2o`0000GolO7000Ko0000onci]oo/nKOok?Vgo`000?o=hgP2
o`0003_ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0IoookJP04o`000?o;C@3o
0000o`0000;ogVdK00?o0000oma];_oLKBh01ooLKBh2o`0000[ogX1K00?o0000omMlHOoGO6402?oG
O643o`0000KodhEi00?o0000olioMoo>OgL01_o>OgL00ol0003oagYjolMjNP0@olMjNP03o`000?o2
MWco`WIl00Ko`WIl1_l00007ol>0R@03o`000?noO8Wo000001Wo]WB900?o0000ok9bROnbLXT02_nb
LXT00ol0003oYVN8ojIWR00KojIWR003o`000?nTIXWoY6J900;oY6J900?o0000oiEJQol000001?l0
000Eol3Dj@03o`000?o?e]ko0000013odN3S00?o0000om?[i_l000001?oGk^83o`0000CoenkR00?o
0000omKgh_oFmn802?oFmn800oo>o]co0000olkocP03olkocP03o`000?nknK_o^oVk00;o0000?Ooo
nfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01oooo]Z000KoookJP03o`000?oonf[o
oo]Z053ooo]Z0ol00003oookJP05o`000?l008go0000o`0X/_l000001Ol5=KL2o`0000OoDVkA0ol0
0007oeY/b`04o`000?mlP<coO83<o`0001KoOhK@00?o0000oiNEd?nGUM005onGUM02o`000004oiNG
dOl0003oYik=ojNNc@?o00007OnXY=800ol0003o]Z[=okJZc@05okJZc@;o00007?nh/=82o`0000Ko
a[cA0_l0000;olRjc@03o`000?o<`m;oc<?B00ooc<?B00?o0000om3=eoo@cML00oo@cML00ol0003o
fLk>omW>cP08omW>cP03o`000?oNf=7o000000SohmS;00?o0000onOTc_oWi<h01_oWi<h00ol0003o
jNk>o`000004oo7a`003o`000?o/nKOok?Vg00;ok?Vg00Co0000olgSN?l0003o0000>ooonfX00ol0
003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z01[ooo]Z0_l000001Oo;C@3o0000omi]6ooNKA_o
000000Sog6d^00Co0000omQ/>ol0003o00002?oNP5/00ol0003oegaQomMlH@0:omMlH@?o00001?oC
QGT00ol0003ocWmgolioM`06olioM`03o`000?o7NW[oagYj017oagYj00?o0000ol9fO?o2MW`02oo2
MW`5o`0000;o`h2900?o0000okmlROl000006OnfM8T00ol0003o/W:9ok9bR@0:ok9bR@03o`000?nV
IhSoYVN801KoYVN83?l00002oi1;N003o`000?o0e>Wo`=CY01Go`=CY0_l0000@om7Ph`03o`000?oC
jnKodn_V00Go00001_oGk^800ol0003oe_ORomKghP07omKghP03o`000?o>o]co000000Goc_o>0_nk
nK/00ol0003oYnNEoookJP0noookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX07ooo
nfX001[ooo]Z00?o0000oookJ_oonfX0C_oonfX3o`0000Oooo]Z00Go0000o`00SOl0003o02Rbo`00
0004o`De]`;o00002_mBK]43o`0000CoFVc;00?o0000ogb0c?l000005omoQ]000ol0003oUiG@oiNE
d00FoiNEd003o`000?nGUm7oUiOA00Co00008?nXY=800ol0003o]Z[=okJZc@03okJZc@;o00007?nh
/=82o`000003okZheol0003oa[cA00Ooa[cA0_l00008olRjc@03o`000?o<`m;oc<?B00ooc<?B00?o
0000om3=eoo@cML01Oo@cML00ol0003ofLk>omW>cP06omW>cP05o`000?oNf=7og]SAomkHdOl00000
1_oSf</00ol0003oinC>onOTcP06onOTcP04o`000?oYk/kojNk>o`0000?olO7000?o0000onci]oo/
nKL00_o/nKL2o`000004olgSN?l0003ooo]Zo`0003[ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0
003ooo]ZoookJP0JoookJP04o`000?n]903o0000ol]=00?o00002OoLKBh00ol0003of6`komQ/>`02
o`0000KogX1K00?o0000omMlHOoGO6402_oGO6400ol0003odGUWom5iI`03o`000003om>5NOl0003o
cWmg00OocWmg00?o0000olMjN_o7NWX04Oo7NWX00ol0003o`WIlol9fO00@ol9fO0co00004_nfM8T0
0ol0003o/W:9ok9bR@0:ok9bR@03o`000?nVIhSoYVN800coYVN82_l00005oj9JNP03o`000?nQFgco
XE]l00;oXE]l00Co0000oi1;N?l0003o00005oo0e>T01Ol0003o`Mk^ol7Nk_o1g^ko000000godN3S
00?o0000om?[i_l000000_l00009omO^hP03o`000?oFmn;oe_OR00Ooe_OR00Co0000olkng?o>o]co
00001?o>olh3ok_i^`03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003o
oo]ZoookJP0NoookJP006_oonfX00ol0003ooo]ZoookJP1;oookJP?o00002_oonfX00ol0003o002=
o`000002o`0X/P03o`000?l5=KOo1CFg00;o1CFg00?o0000oe9^dOmBK]402omBK]42o`0000?oFVc;
00?o0000ogn6d?moQ]005omoQ]000ol0003oUiG@oiNEd00CoiNEd0Go00000_nHWML00ol0003oZ:CB
ojRTdP0PojRTdP05o`000?nfZ/go]Z[=okJZcOl000007Onh/=800ol0003o^[SGokZhe`02okZhe`03
o`000?o6_=7oa[cA00Ooa[cA0ol00004olRjc@03o`000?o<`m;oc<?B00ooc<?B00?o0000om3=eoo@
cML01oo@cML00ol0003ofLk>omW>cP04omW>cP03o`000?oNf=7og]SA00;og]SA00?o0000on?HbooS
f</00ooSf</00ol0003oinC>onOTcP07onOTcP05o`000?oYk/kojNk>onW^c_l000000_oalL001?l0
003ok?Vgonci]oo/nKL2o`000005olgSN?l0003ooo]ZoookJ_l00000>_oonfX00ol0003ooo]Zoook
JP0moookJP03o`000?oonf[ooo]Z01_ooo]Z00Go0000ojdT0?l0003o0000ol]=0002o`0000Sog6d^
00?o0000omQ/>ooHK3/00_oHK3/2o`0000GogX1K00?o0000omMlHOoGO6402_oGO6400ol0003odGUW
om5iI`02om5iI`?o00001oo>OgL00ol0003oagYjolMjNP0AolMjNP03o`000?o2MWco`WIl01;o`WIl
00?o0000okecOOl000001oncJG/=o`0000Go]WB900?o0000ok9bROnbLXT02_nbLXT00ol0003oYVN8
ojIWR002ojIWR0[o00004?nRFWX01?l0003oXE]loj5KO?nQFg`2o`0001Oo`=CY0_l00005ol7NkP03
o`000?oAh>?odN3S00SodN3S1?l00002om?[iP03o`000?oGk^;oenkR00KoenkR00?o0000omKgh_oF
mn801ooFmn801?l0003oc_kLolkng?l00004olkocP?o^oVk0_l00012oookJP03o`000?oonf[ooo]Z
02_ooo]Z00?o0000oookJ_oonfX07_oonfX001[ooo]Z00?o0000oookJ_oonfX0B?oonfX3o`0000ko
oo]Z0_l00003o`0X/P05o`000?l5=KOo1CFgo`De]ol000003omBK]44o`0001WoOhK@00?o0000oiNE
d?nGUM003onGUM05o`0000OoV9gG00?o0000ojRTd_nXY=807onXY=801?l0003o]Z[=o`000?l0000L
okR`dP;o00001_nj^=L00ol0003oa[cAolJld@09olJld@;o000000?ob;[=o`000?o<`m803oo<`m82
o`0000[od<gG00?o0000omW>c_oIc/h00ooIc/h00ol0003og]SAomkHd@04omkHd@03o`000?oSf<_o
hmS;00;ohmS;00?o0000onOTc_oWi<h01_oWi<h00ol0003ojNk>onW^cP02onW^cP03o`000?oalL3o
000000Cok?Vg1?l00003oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0?OoonfX0
0ol0003ooo]ZoookJP0LoookJP06o`000?n]903o[B@0o`000?o;C@3o00002OoLKBh00ol0003of6`k
omQ/>`03omQ/>`;o00000ooNP5/00ol0003oegaQomMlH@0:omMlH@05o`000?oANFOodGUWom5iIol0
00000oo;L644o`0000CocWmg00?o0000olMjN_o7NWX04?o7NWX00ol0003o`WIlol9fO00Bol9fO003
o`000?nmLggo000001Co/fUk5ol0000Koj9JNP?o00005oo0e>T2o`0000So`Mk^0_l00005om7Ph`?o
00001_oCjnH00ol0003oenkRomO^hP05omO^hP[oe_OR00Co0000olkng?o>o]co00001?o>olh3ok_i
^`;o0000@ooonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01kooo]Z000JoookJP03
o`000?oonf[ooo]Z04Cooo]Z1?l0000AoookJP;o00001?l0:;800ol0003o1CFgo`De]`02o`00017o
DVkA0_l0000Iogn6d003o`000?nGUM3oUiG@00OoUiG@2Ol0000:oiRMe`03o`000?nXY=;oZ:CB01oo
Z:CB0_l0000LokR`dP;o00002?nj^=L00ol0003oa[cAolJld@0:olJld@;o00004?o<`m800ol0003o
d<gGom3=e`0;om3=e`05o`000?oIc/kofLk>omW>c_l000001ooNf=401Ol0003ohmS;on?HbooSf<_o
000000SoinC>00?o0000onW^c_oYk/h00ooYk/h00ol0003olO70o`000003onci]`04o`000?oNn:So
0000o`0000Gooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oo
nf[ooo]Z01gooo]Z00Go0000ojdT0?n]903o0000ol]=0002o`0000Oog6d^00?o0000omQ/>ooHK3/0
1OoHK3/2o`000003omj0Fol0003oegaQ00_oegaQ00Co0000om5iIooANFOo00002?o;L643o`000003
olioMol0003oagYj01;oagYj00?o0000ol9fO?o2MW`04Oo2MW`00ol0003o_G=mo`00000Iok=YN`03
o`000?n`Igco/6Ml00[o/6Ml00?o0000oj9JN_nRFWX07OnRFWX00ol0003o`=CYol3Dj@0Fol3Dj@03
o`000?o1g^ko`Mk^00[o`Mk^1Ol000000ooAh>?o0000om?[iP06om?[iP03o`000?oGk^;oenkR00Co
enkR2_oFmn801Ol0003oc_kLolkng?o>o]co000000?oc_o>0onknK/2o`0004Gooo]Z00?o0000oook
J_oonfX0:_oonfX00ol0003ooo]ZoookJP0NoookJP006_oonfX00ol0003ooo]ZoookJP11oookJP?o
00005_oonfX2o`0000Co02Rb00Co0000o`De]ol0003o00004OmBK]42oeeje`ko00002omoQ]001?l0
003oUiG@oiNEd?nGUM06o`0000GoUi[E0_l0000=oiRMe`03o`000?nXY=;oZ:CB01_oZ:CB0ol00000
0onZ[=So0000okR`dP0JokR`dP03o`000?nj^=Oo^[SG00Wo^[SG00?o0000olJldOo6_=402?o6_=40
1?l0003obLCEolW4eOo9a=D2o`0000coc<?B00?o0000om3=eoo@cML03Oo@cML00ol0003ofLk>o`00
0009omkHd@03o`000?oSf<_o000000SoinC>00?o0000onW^c_oYk/h01?oYk/h2o`0000Cok?Vg0_l0
00000oo=hgSo0000oookJP05oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0?Ooo
nfX00ol0003ooo]ZoookJP0MoookJP04o`000?n]903o[B@0ojdT00;o000000?oce<8o`000?oLKBh0
1_oLKBh00ol0003of6`komQ/>`06omQ/>`?o00003?oGO642o`0000cobg1Q1?l0000AolMjNP03o`00
0?o2MWco`WIl01;o`WIl00?o0000ok=YNoncJG/06OncJG/00ol0003o/6Mlok1WO009ok1WO003o`00
0?nRFW[oXUYj01_oXUYj0_l0000Gol3Dj@;o00002oo1g^h4o`0000?odN3S00?o0000om?[i_oCjnH0
1_oCjnH00ol0003oenkRomO^hP03omO^hP[oe_OR00Go0000olkng?o>o]coc_kLo`000003olkocP?o
^oVk0_l00017oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX07_oonfX001[ooo]Z
00?o0000oookJ_oonfX0?_oonfX3o`0001Wooo]Z0_l00005o`0X/P;o000000?o7Tg6o`000?mBK]40
3_mBK]401?l0003oGG[Goeejeol0000=ogn>f0oo00002OnGV]D2o`00013oV9gG00?o0000ojRTd_nX
Y=806?nXY=82o`0000GoZZcH00?o0000okR`d_nh/=805_nh/=82o`0000go^[SG00?o0000olJldOo6
_=401_o6_=400ol0003obLCEolW4e@04olW4e@;o00002Oo<`m800ol0003od<gGom3=e`0?om3=e`03
o`000?oNf=7og]SA00Wog]SA00?o0000onOTc_oWi<h01_oWi<h00ol0003ojNk>onW^cP05onW^cP03
o`000?o/nKOok?Vg00;ok?Vg00Co0000omkhZ?l0003o00002?oonfX00ol0003ooo]ZoookJP0eoook
JP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003o[B@0ojdT0002ojdT
0004o`000?o?D`So0000o`0000Gog6d^00?o0000omQ/>ooHK3/02?oHK3/2o`0000[oegaQ0_l0000>
ol]`H@03o`000?o5KFOoaFeW00Co00003Oo7NWX00ol0003o`WIlol9fO00Bol9fO003o`000?ncJG_o
/fUk01Wo/fUk00?o0000ok1WO?n`Ig`02On`Ig`00ol0003oXUYjoj9JNP0Ioj9JNP;o00005oo0e>T2
o`0000Wo`Mk^1?l00004ol7NkP03o`000?oAh>?o000000Wodn_V00?o0000omO^h_oGk^800_oGk^89
omKghP;o00001?o>o]`00ol0003oc_o>olkocP03ok_i^`;o0000BOoonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z01kooo]Z000IoookJP03o`000?oonf[ooo]Z03cooo]Z0ol0000Moook
JP03o`000?l0:;;o02Rb00Co02Rb0ol0000?oe9^d@05o`000?mMN]OoGG[Goeejeol000006?moS]P0
0ol0003oUi[EoiNJe@06oiNJe@?o00004_nHWML00ol0003oZ:CBojRTdP0EojRTdP?o00002?nZ[=P0
0ol0003o^;3BokR`dP0CokR`dP;o00003onj^=L00ol0003oa[cAolJld@04olJld@;o00002Oo9a=D0
0ol0003oc<?Bolc3dP05olc3dP03o`000?o@cMOod<gG00kod<gG00Co0000om?Hg?oCf=co00002OoN
f=42o`0000SoinC>00?o0000onW^c_oYk/h01OoYk/h01Ol0003ok?Vgonci]oo/nKOo000000;og_RX
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z03_ooo]Z
00?o0000oookJ_oonfX08?oonfX00ol0003o[B@0ojdT0002ojdT00;o000000?oce<8o`000?l00000
0ooLKBh00ol0003of6`komQ/>`08omQ/>`04o`000?oCKDWo0000o`0000OoegaQ00?o0000om9bFOl0
00003oo;L6400ol0003oaFeWolE]I`03olE]I`Go00002?o7NWX00ol0003o`WIlol9fO00Bol9fO003
o`000?ncJG_o/fUk01Wo/fUk00?o0000ok1WO?n`Ig`02?n`Ig`00ol0003oXUYjoj9JNP0Ioj9JNP03
o`000?nndn[o000001Ko`=CY00?o0000ol7Nk_o1g^h01_o1g^h3o`0000Wo`Mk^00?o0000om?[i_oC
jnH02?oCjnH01?l0003oenkRomO^h_oGk^89omKghP03o`000?o>o]coc_kL00?oc_kL00?o0000olko
c_o>olh00onknK/2o`0004_ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0Noook
JP006OoonfX00ol0003ooo]ZoookJP0ioookJP?o00008?oonfX2o`0000Go02Rb0_l;BlP2o`0000ko
DVkA00Go0000oeejeomMN]OoGG[Go`00000Iogn>f003o`000?nGV]GoUi[E00?oUi[E0_l0000FoiRM
e`03o`000?nXY=;oZ:CB01;oZ:CB0_l0000;ojZ/f003o`000?nh/=;o^;3B017o^;3B0_l0000BokZh
e`03o`000?o6_=7oa[cA00;oa[cA00?o0000olW4eOo9a=D02_o9a=D2o`0000Coc<?B00?o0000om3=
eoo@cML03_o@cML00ol0003odmSLom?Hg002om?Hg003o`000?oNf=7og]SA00Gog]SA00Co0000on;S
e?oRhmCo00001_oWi<h00ol0003ojNk>onW^cP05onW^cP;o00000oo/nKL01?l0003og_RXo`000?l0
000:oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]Zoook
JP0QoookJP;o00000_n]90001_l0003o^C40o`000?l0003oce<8o`0000?og6d^00?o0000omQ/>ooH
K3/02?oHK3/00ol0003odfe9om=]B@02o`0000CoegaQ00Go0000om9bFOoBLUWodW9Io`00000>ol]`
H@03o`000?o5KFOoaFeW00SoaFeW1?l00004olMjNP03o`000?o2MWco`WIl01;o`WIl00?o0000ok=Y
NoncJG/06_ncJG/00ol0003o/6Mlok1WO007ok1WO003o`000?nRFW[oXUYj01OoXUYj0_l00003okkC
jP03o`000?o0e>Wo`=CY017o`=CY0_l00005ol7NkPCo00002oo1g^h3okoZlP03o`000?oCjnKodn_V
00Kodn_V00?o0000omO^h_oGk^802OoFmn800ol0003oc_kLolkng004olkng003o`000?o>olko^oVk
00;o^oVk0_l0001<oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07_oonfX001Wo
oo]Z00?o0000oookJ_oonfX0=OoonfX4o`0002Cooo]Z0_l00004o`0X/P04o`000?l;BlSo2d_8o`00
00goDVkA00?o0000oeejeomMN]L00omMN]L00ol0003oOhkHogn>f00Fogn>f004o`000?nGV]GoUi[E
oiNJe@;o00006?nHWML00ol0003oZ:CBojRTdP0?ojRTdP?o00003_nZ[=P00ol0003o^;3BokR`dP0?
okR`dP03o`000?nj^=Oo^[SG01;o^[SG00Go0000olJldOo6_=7oa[cAo`00000?olW4e@;o000000?o
c<?Bo`000?o@cML03oo@cML00ol0003odmSLom?Hg004om?Hg003o`000?oNf=7og]SA00?og]SA00Go
0000on;Se?oRhmCoh^?Do`000005onOTcP03o`000?oYk/kojNk>00GojNk>00?o0000onSib_l00000
0_o/nKL01?l0003og_RXomkhZ?l0000<oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oo
nfX0>ooonfX00ol0003ooo]ZoookJP0SoookJP04o`000?n]903o[B@0o`0000;o^C401?l000000ooL
KBko0000omQ/>`09omQ/>`03o`000?oCKDWodfe900;odfe90_l000000ooGO67o0000om9bF@03om9b
F@03o`000?o;L67obg1Q00gobg1Q00?o0000olE]Ioo5KFL02oo5KFL4o`000003olMjN_l0003o`WIl
01;o`WIl00?o0000ok=YNoncJG/06_ncJG/00ol0003o/6Mlok1WO007ok1WO003o`000?nRFW[oXUYj
01KoXUYj00?o0000okkCj_nndnX01?nndnX00ol0003o`=CYol3Dj@0>ol3Dj@;o00001?o1g^h3o`00
00go`Mk^1_noj_82o`0000Kodn_V00?o0000omO^h_oFmn802?oFmn800ol0003oc_kLolkng004olkn
g003o`000?o>olko^oVk00;o^oVk0_l0001>oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oook
J_oonfX07OoonfX001Wooo]Z00?o0000oookJ_oonfX0<_oonfX3o`0002Sooo]Z0ol00004o`0X/P03
o`000?l;BlSo2d_800;o00002omBK]400ol0003oGG[Goeeje`04oeeje`03o`000?moS]SoOhkH01Go
OhkH00Co0000oiNJeOl0003o00006onHWML00ol0003oZ:CBojRTdP0;ojRTdP?o00004OnZ[=P00ol0
003o^;3BokR`dP0=okR`dP;o00005_nj^=L2olJld@03o`000?o9a=GobLCE00oobLCE0_l0000@om3=
e`03o`000?oCf=codmSL00KodmSL00Go0000omkHdOoNf=7og]SAo`000004on;Se003o`000?oWi<ko
inC>00;oinC>00?o0000onW^c_oYk/h01OoYk/h01_l0003oj?W:onSib_l0003ok?Vgo`0000?og_RX
00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03_ooo]Z
00?o0000oookJ_oonfX09?oonfX2o`000003ojdT0?l0003o^C4000?o^C401?l00009omQ/>`03o`00
0?oCKDWodfe900?odfe91?l00003om9bF@03o`000?o;L67obg1Q00gobg1Q00?o0000olE]Ioo5KFL0
3oo5KFL5o`00013o`WIl0_l0000Lok=YN`03o`000?n`Igco/6Ml00Ko/6Ml00?o0000oj9JN_nRFWX0
5?nRFWX2o`0000Oo_]?Z00?o0000ol3DjOo0e>T03Oo0e>T01?l0003o`Mk^ol7Nk_o1g^h3o`0000ko
`Mk^00?o0000okoZl_noj_801onoj_82o`0000Codn_V00?o0000omKgh_oFmn801ooFmn800ol0003o
c_kLolkng004olkng003o`000?o>olko^oVk00;o^oVk00?o0000oookJ_oonfX0CooonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01gooo]Z000IoookJP03o`000?oonf[ooo]Z02oooo]Z
0ol0000/oookJP03o`000?l05ZCo000000?o02Rb00Go0000o`];b?l;BlSo0000odI`f002o`0000Wo
DVkA00?o0000oeejeomMN]L01?mMN]L00ol0003oOhkHogn>f00Fogn>f003o`000?nHWMOoV9gG01_o
V9gG00?o0000ojRTd_nXY=802OnXY=82o`0001GoZZcH00?o0000okR`d_nh/=802_nh/=82o`0001So
^[SG0_l0000AolW4e@05o`000?o<cM[oc<gJolc=f_l000003?o@cML2o`0000[odmSL00?o0000omkH
dOl000001_oRhm@01Ol0003oinC>onOTc_oWi<ko000000KojNk>00Co0000onSib_oXnL[o00000_o/
nKL01?l0003og_RXomkhZ?l0000?oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0
>ooonfX00ol0003ooo]ZoookJP0UoookJP04og/00?l0003o[B@0o`0000Go^C400ol00009omQ/>`03
o`000?oCKDWo000000;o00001?o;GCX3o`000003om9bFOl0003obg1Q00kobg1Q00?o0000olE]Ioo5
KFL03oo5KFL01?l0003o_fY[okmZJonoJV/7o`0000So`WIl00?o0000okQ/NOl000007?ncJG/00ol0
003o/6Mlok1WO006ok1WO003o`000?nRFW[oXUYj01?oXUYj00?o0000okkCj_nndnX02?nndnX00ol0
003o`=CYol3Dj@0:ol3Dj@Ko00003oo1g^h00ol0003o_n[bokoZlP0;okoZlP05o`000?oCjnKo0000
om7ei_l000002?oFmn800ol0003oc_kLolkng005olkng003o`000?nknK_o^oVk00;o0000DooonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01gooo]Z000IoookJP03o`000?oonf[ooo]Z
02cooo]Z0ol0000_oookJP04o`000?l05ZCo01JTo`0000;o02Rb00Go0000o`];b?l;BlSo2d_8o`00
0002odI`f0?o00001OmBK]400ol0003oGG[Goeeje`06oeeje`03o`000?moS]SoOhkH01GoOhkH00?o
0000oiRMeonHWML07?nHWML00ol0003oZ:CBojRTdP05ojRTdP?o00006?nZ[=P00ol0003o^;3BokR`
dP08okR`dP03o`000?nj^=Oo^[SG01Oo^[SG00?o0000okc1g_l000004?o9a=D00ol0003oc<gJolc=
fP03olc=fP03o`000?o@cMOod<gG00Sod<gG00?o0000om?Hg?oCf=`02_oCf=`2o`0000Ooh^?D00Co
0000onOTc_oWi<ko00001ooYk/h01_l0003oj?W:onSib_l0003ok?Vgo`0000;og_RX0_l0000?oook
JP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0Woook
JP?o00001_ni<@0<o`0000[obedj1?l0000=ol]`H@03o`000?o5KFOoaFeW013oaFeW00?o0000okmZ
JonoJV/01onoJV/6o`0000;o`WIl00?o0000okQ/NOl000007OncJG/00ol0003o/6Mlok1WO005ok1W
O003o`000?nRFW[oXUYj017oXUYj0_l0000<okkCjP03o`000?o0e>Wo`=CY00Oo`=CY1?l0000Aol7N
kP03o`000?noj_;o_n[b00ko_n[b1Ol00006omKghP03o`000?o>o]coc_kL00Goc_kL00Co0000ok_i
^ol0003o0000E_oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z01gooo]Z000Hoook
JP03o`000?oonf[ooo]Z02[ooo]Z0ol0000coookJP06o`000?l05ZCo01JTo`000?l0:;;o00001?l;
BlP00ol0003oAW3HodI`f002odI`f0;o00000omBK]400ol0003oGG[Goeeje`06oeeje`03o`000?mo
S]SoOhkH01CoOhkH00?o0000oh:Bf_l000007_nHWML00ol0003oZ:CBojRTdP02ojRTdP;o00006onZ
[=P00ol0003o^;3BokR`dP06okR`dP;o00006?nj^=L2o`0000?o_<7N00?o0000olW4eOo9a=D03?o9
a=D00ol0003oc<gJolc=fP05olc=fP;o00001oo@cML00ol0003odmSLom?Hg00:om?Hg005o`000?oG
i>3oenCPomOTh?l000001OoRhm@00ol0003oinC>o`000007onW^cP07o`000?oXnL[oj?W:onSib_l0
003ok?Vgo`000002omkhZ003o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0
003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02Sooo]Z0ol00005okTa0003o`000?no?03o0000
00;o00001Oo?FbT00ol0003obedjol]M>P0:ol]M>P03o`000?o5GDSoaEe800?o00002_o;L6400ol0
003oaFeWolE]I`0@olE]I`03o`000?noJV_o_fY[00go_fY[1_l0000Lok=YN`03o`000?n`Igco/6Ml
00Co/6Ml00?o0000oj9JN_nRFWX03_nRFWX4o`0000;oZlob00?o0000okkCj_nndnX02OnndnX00ol0
003o`=CYol3Dj@04ol3Dj@Co00004_o1g^h00ol0003o_n[bokoZlP0?okoZlP?o^o?b00?o0000okkf
l?nnm_000ol00002omKghP03o`000?o>o]coc_kL00Goc_kL1?l0001GoookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX07OoonfX001Sooo]Z00?o0000oookJ_oonfX09_oonfX4o`0003Ko
oo]Z00Co0000o`0FY?l05ZCo01JT0_l00004o`];b003o`000?m6L=SoAW3H00CoAW3H0_l000000omB
K]7o0000oeeje`08oeeje`03o`000?moS]SoOhkH01;oOhkH00Go0000oh:Bf_n2T][oPY;Jo`00000M
oiRMe`03o`000?nXY=;o000000;o00007_nZ[=P00ol0003o^;3BokR`dP03okR`dP;o00006?nj^=L2
o`0000Ko_<7N00?o0000olW4eOo9a=D02_o9a=D00ol0003oc<gJolc=fP08olc=fP03o`000?o@cMOo
d<gG00?od<gG00?o0000om?Hg?oCf=`02_oCf=`00ol0003oenCPomOTh003omOTh003o`000?oRhmCo
h^?D00?oh^?D00?o0000onW^c_oYk/h01OoYk/h00ol0003oj?W:onSibP02onSibP;o00000_oNn:P2
o`0001;ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[o
oo]Z02[ooo]Z0_l00005okTa0004o`000?no?03o_c`0okll00;o00001?o?FbT00ol0003obedjol]M
>P0:ol]M>P03o`000?o5GDSoaEe800;oaEe80ol00008ol]`H@03o`000?o5KFOoaFeW00ooaFeW00?o
0000okmZJonoJV/03onoJV/00ol0003o]5eUokAMI@0@o`0000go/fUk00?o0000ok1WO?n`Ig`01?n`
Ig`00ol0003oXUYjoj9JNP03oj9JNPco00001_n[co800ol0003o_]?ZokkCjP09okkCjP03o`000?o0
e>Wo`=CY00Go00004_o1g^h2o`0000oo_n[b00?o0000ok_cl_nklo800_nklo800ol0003o__K`okkf
l004okkfl0;o00000_o>o]`8o`0005[ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]Zoook
JP0MoookJP006?oonfX00ol0003ooo]ZoookJP0SoookJP?o0000>ooonfX01?l0003o01JTo`0FY?l0
5Z@2o`0000Co2d_800?o0000odI`f?m6L=P01Om6L=P3o`0000SoGG[G00?o0000ogn>f?moS]P04Omo
S]P00ol0003oPY;Joh:BfP02oh:BfP03o`000?nHWMOoV9gG01[oV9gG0ol0000QojZ/f003o`000?nh
/=;o^;3B00;o^;3B00?o0000okZheonj^=L05onj^=L00ol0003o_<7Nokc1gP06okc1gP03o`000?o9
a=GobLCE00SobLCE0_l0000<olc=fP05o`000?o@cMOod<gGom3=eol000003?oCf=`00ol0003oenCP
omOTh005omOTh004o`000?oRhmCoh^?Don;Se0;o00001_oYk/h00ol0003oj?W:onSibP03onSibP03
o`000?oNn:Sog_RX00;o00005?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z03[o
oo]Z00?o0000oookJ_oonfX0:ooonfX2o`0000Go^C4000?o0000okll0?no?0000_no?003o`0000;o
ce/Y00?o0000ol]M>_o;GCX02_o;GCX00ol0003oaEe8olEMB004olEMB0?o00001Oo;L6400ol0003o
aFeWolE]I`0@olE]I`03o`000?noJV_o_fY[00go_fY[00Go0000okAMIOndGFGo]5eUo`00000?ok1L
Ja[o00001onMBfP2o`0000[oZlob00?o0000okkCj_nndnX01onndnX4o`000003ol3DjOl0003o0000
01;o`Mk^0_l0000?okoZlP;o00001?nklo800ol0003o__K`okkfl004okkfl003o`000?nbn^Oo/_[W
00Ko/_[W00?oT^o;o`000?l00000G?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z
01gooo]Z000HoookJP03o`000?oonf[ooo]Z023ooo]Z0ol0000noookJP;o00000ol05Z@2o`0000?o
2d_800?o0000odI`f?m6L=P01Om6L=P00ol0003oEWkMoeIng@03o`0000KoGG[G00?o0000ogn>f?mo
S]P03omoS]P00ol0003oPY;Joh:BfP04oh:BfP03o`000?nHWMOoV9gG01CoV9gG1Ol00002oiRUgP03
o`000?nZ[=SoZZcH023oZZcH00Co0000okR`d_l0003o00006?nj^=L2o`0000[o_<7N00?o0000olW4
eOo9a=D01_o9a=D00ol0003oc<gJolc=fP0=olc=fP03o`000?o@cMOo000000codmSL00?o0000omOT
h?oGi>001ooGi>001Ol0003oh^?Do`000?oTk]Go000000KojNk>00?o0000onSib_oXnLX00ooXnLX0
0ol0003og_RXomkhZ002o`0001Gooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0i
oookJP03o`000?oonf[ooo]Z02gooo]Z00?oN`00o`000?l000001?ni<@000ol0003o_c`0okll0004
okll00;o000000?oce/Yo`000?o;GCX02_o;GCX00ol0003oaEe8olEMB007olEMB0?o00000oo;L640
0ol0003oaFeWolE]I`0?olE]I`03o`000?noJV_o_fY[00go_fY[00?o0000okAMIOndGFD00_ndGFD0
0ol0003o/5a[ok1LJ`0Jok1LJ`03o`000?n]Ffko[E]^00?o[E]^00?o0000oie;J?nMBfP01onMBfP3
o`0000goZlob00?o0000okkCj_nndnX00onndnX3o`0000;o_]?Z00?o0000ol3DjOl000004_o1g^h2
o`0000oo_n[b0_l00005ok_clP03o`000?nnm_3o__K`00?o__K`0_l00007ok;ji`03o`000?nBkl_o
000005oooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0MoookJP006?oonfX00ol0
003ooo]ZoookJP0MoookJP?o0000@_oonfX2o`0000;o01JT00?o0000o`14a_l000000ol;BlP00ol0
003oAW3HodI`f004odI`f003o`000?mFO]goEWkM00?oEWkM1?l00003oeeje`03o`000?moS]SoOhkH
00goOhkH00?o0000oh:Bf_n2T]X01On2T]X00ol0003oV9gGoiRMe`0@oiRMe`Co00002?nHYMh00ol0
003oZZcHojZ/f00OojZ/f0;o00006?nj^=L2o`0000go_<7N00?o0000olW4eOo9a=D01?o9a=D00ol0
003oc<gJolc=fP0>olc=fP;o00003?oCf=`00ol0003oenCPomOTh008omOTh0?o00000_oTk]D00ol0
003ojNk>onW^cP02onW^cP03o`000?oXnL[oj?W:00?oj?W:00Go0000omkhZ?oNn:So0000oi3FO@0F
oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0_
oookJP?o00000oni<@000ol0003o_c`0okll0005okll00?o00002oo;GCX00ol0003oaEe8olEMB009
olEMB0Co00004_o5KFL00ol0003o_fY[okmZJ`0;okmZJ`03o`000?ndGFGo]5eU00Co]5eU00?o0000
ok1LJon`G6/06_n`G6/00ol0003o[E]^ojeKKP02ojeKKP03o`000?nMBfSoWD]X00CoWD]X0ol0000A
oj_?lPGo00001_nndnX00ol0003o`Mk^ol7NkP0@ol7NkP03o`000?noj_;o_n[b00ko_n[b00?o0000
ok_cl_nklo801Onklo801?l0003o__K`okkfl?nnm_02o`0000So/_[W00?oT^o;o`000?l00000HOoo
nfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01gooo]Z000HoookJP03o`000?oonf[o
oo]Z01Wooo]Z1?l00016oookJP;o00000_l05Z@01?l0003o04C6o`000?l00002o`];b003o`000?m6
L=SoAW3H00?oAW3H00?o0000oeIngOmFO]d01omFO]d4o`0000koOhkH00?o0000oh:Bf_n2T]X01on2
T]X00ol0003oV9gGoiRMe`0:oiRMe`Go00003OnHYMh00ol0003oZZcHojZ/f00KojZ/f0?o000000?o
ZkCOo`000?nj^=L05_nj^=L00ol0003o_<7Nokc1gP0>okc1gP03o`000?o9a=GobLCE00;obLCE00?o
0000olc=f_o<cMX03_o<cMX00ol0003ocmOOo`00000;om?Hg003o`000?oGi>3oenCP00SoenCP00Co
0000omO`hooGl>?oeo3S0ol00003onW^cP03o`000?oXnL[oj?W:00?oj?W:1?l000000on@eWgooo]Z
oookJP0FoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Z
oookJP0`oookJPCo00000_ni<@000ol0003o_c`0okll0007okll00;o00002_o;GCX00ol0003oaEe8
olEMB00;olEMB0Go00003_o5KFL00ol0003o_fY[okmZJ`0;okmZJ`03o`000?ndGFGo]5eU00Go]5eU
00?o0000ok1LJon`G6/06_n`G6/01Ol0003o[E]^ojeKK_n]Ffko000000?oWD]X0ol0000Boj_?lPCo
00001_nndnX2o`000003okoMkol0003o`Mk^00oo`Mk^0_l0000?okoZlP;o00001onklo801Ol0003o
__K`okkfl?nnm_3o000000So/_[W00?oT^o;o`000?l00000HooonfX00ol0003ooo]ZoookJP0Qoook
JP03o`000?oonf[ooo]Z01cooo]Z000HoookJP03o`000?oonf[ooo]Z01Kooo]Z0ol0001;oookJP;o
000000?o01JTo`000?l0A<H00_l0A<H00ol0003o2d_8o`000005odI`f003o`000?mFO]goEWkM00[o
EWkM2?l00006ogn>f003o`000?n2T][oPY;J00WoPY;J00?o0000oiRMeonHWML01OnHWML4o`0001;o
V:GN00?o0000ojZ/f?nZ[=P06OnZ[=P2o`0000GoZkCO00?o0000okZheonj^=L04_nj^=L2o`00017o
_<7N00Go0000olW4eOo9a=GobLCEo`00000@olc=fP05o`000?o?emoocmOOoloGgol000002OoCf=`0
0ol0003oenCPomOTh008omOTh003o`000?oGl>?oeo3S00Coeo3S0_l000000ooYk/ko0000onSibP05
onSibP;o000000?o`ON]o`000?oonfX06OoonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[o
oo]Z03Wooo]Z00?o0000oookJ_oonfX0<OoonfX00omk003o0000oi810002o`000003okTa0?l0003o
_c`000Oo_c`000?o0000oke15Ol000000_l00007ol]M>P03o`000?o5GDSoaEe800coaEe800Co0000
okmLD?noG53o_ea@1Ol0000:olE]I`03o`000?noJV_o_fY[00Wo_fY[00?o0000okAMIOndGFD01ond
GFD00ol0003o/5a[ok1LJ`0Jok1LJ`03o`000?n]Ffko000000;oWD]X0_l0000Aoj_?lPCo00001?n[
co800ol0003o_]?ZokkCjP02okkCjP05o`000?nogNoo_mg_okoMkol000003_o1g^h2o`0000oo_n[b
0_l00008ok_clP03o`000?nnm_3o__K`00;o00001onbn^L01?l0003oT^o;o`000?l0001UoookJP03
o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX07?oonfX001Oooo]Z00?o0000oookJ_oonfX0
5?oonfX3o`0004oooo]Z0_l000000ol05ZCo0000o`14aP02o`14aP03o`000?l;BlSo000000CoAW3H
00?o0000oeIngOmFO]d02omFO]d00ol0003oO9COogbDg`04ogbDg`go00001On2T]X00ol0003oV9gG
oiRMe`05o`0001OoV:GN00?o0000ojZ/f?nZ[=P05OnZ[=P3o`0000SoZkCO00?o0000okZheonj^=L0
3onj^=L2o`0001Co_<7N00?o0000olW4eOl000004?o<cMX00ol0003ocmOOoloGg`03oloGg`03o`00
0?oCf=codmSL00GodmSL00?o0000omOTh?oGi>002?oGi>000ol0003oeo3SomO`h`05omO`h`03o`00
0?oMl]go000000?o00000ooXnLX2o`000003ol7g[Ol0003o000001_ooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03?ooo]Z0_l000001?nB0@3o0000
okTa0?l00008okll0004o`000?nm@AGo_D4Eoke15@?o00001Oo;GCX00ol0003oaEe8olEMB00<olEM
B003o`000?noG53o_ea@00Go_ea@1Ol00005olE]I`03o`000?noJV_o_fY[00Wo_fY[00?o0000okAM
IOndGFD02?ndGFD00ol0003o/5a[ok1LJ`0Jok1LJ`Co00004?n[co83o`0000WoZlob00Co0000okkC
j_l0003o00001?nogNl00ol0003o`Mk^ol7NkP0:ol7NkP;o00004?noj_800ol0003o^o?bok_clP07
ok_clP04o`000?nnm_3o__K`o`0000So/_[W00?oT^o;o`000?l00000J?oonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z01cooo]Z000GoookJP03o`000?oonf[ooo]Z017ooo]Z0ol0001B
oookJP04o`000?l018ko0000o`0000Co04C60_l00004odI`f003o`000?mFO]goEWkM00coEWkM00?o
0000ogbDgomlU=l02?mlU=l00ol0003oOYOQogjGh@05ogjGh@So00007?nHYMh00ol0003oZZcHojZ/
f00CojZ/f0;o00003?n[]=l00ol0003o^[SGokZhe`0=okZhe`03o`000?nl`Mko_<7N01Go_<7N00?o
0000olc=f_o<cMX03Oo<cMX2o`0000KocmOO00?o0000om?Hg?oCf=`01?oCf=`00ol0003oenCPomOT
h008omOTh003o`000?oGl>?oeo3S00Koeo3S0_l00004omWmf0?o000000Coa_k7o`000?l0003o0000
7OoonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0
=?oonfX2o`000004oi810?l0003o0000o`0000So_c`000?o0000oke15Onm@AD00onm@AD2o`0000Co
bedj00?o0000olEMB?o5GDP03?o5GDP00ol0003o_ea@okmLD009okmLD0Ko00002onoJV/00ol0003o
]5eUokAMI@08okAMI@03o`000?n`G6_o/5a[01So/5a[0ol0000@oj_?lP?o00003On[co82o`0000Go
_mg_00?o0000ol7Nk_o1g^h02Oo1g^h00ol0003o_n[bokoZlP0>okoZlP;o00002_nklo83o`0000Oo
/_[W00Co0000oi;_bol0003o0000J_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z
01cooo]Z000GoookJP03o`000?oonf[ooo]Z00kooo]Z0ol0001FoookJP04o`000?l018ko0000o`00
00Go04C600Go0000odI`f?m6L=SoAW3Ho`00000>oeIng@03o`000?mlU=ooO9CO00OoO9CO00?o0000
ogjGhOmnUn403?mnUn400ol0003oV:GNoiRUgP0LoiRUgP03o`000?nZ[=SoZZcH00ooZZcH0ol0000>
oj^dg`03o`000?nj^=Oo^[SG00_o^[SG0_l0000Fokc1gP03o`000?nnb^?o000000koc<gJ00?o0000
oloGgoo?eml01oo?eml00ol0003odmSLom?Hg002om?Hg003o`000?oGi>3oenCP00SoenCP00?o0000
omO`hooGl><01_oGl><2o`0000GofOgH00Co0000olKnaoo6o/Ooa_k70_l0000NoookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP0eoookJP04og/00?l0
003oTP40oi8100;o00002?no?0000ol0003o_D4Eoke15@04oke15@?o000000?obedjo`000?o5GDP0
3Oo5GDP00ol0003o_ea@okmLD00>okmLD0Co00001onoJV/00ol0003o]5eUokAMI@0:okAMI@03o`00
0?n`G6_o/5a[01Go/5a[0_l0000?oj_?lPCo00003?n[co83o`0000?oZMSh00?o0000okoMkonogNl0
0_nogNl00ol0003o`Mk^ol7NkP07ol7NkP;o00003onoj_82o`0000_o^o?b0_l00007ok;ji`03o`00
0?nBkl_o000000;o0000K?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01cooo]Z
000GoookJP03o`000?oonf[ooo]Z00[ooo]Z1?l0001JoookJP03o`000?l018ko000000Ko04C60_l0
00000om6L=So0000oeIng@0>oeIng@03o`000?mlU=ooO9CO00GoO9CO00?o0000ogjGhOmnUn403_mn
Un400ol0003oV:GNoiRUgP0LoiRUgP03o`000?nZ[=SoZZcH00_oZZcH0ol0000Boj^dg`03o`000?nj
^=Oo^[SG00So^[SG0_l0000Fokc1gP03o`000?nnb^?o_/[S00;o_/[S00?o0000olc=f_o<cMX02_o<
cMX00ol0003ocmOOoloGg`08oloGg`05o`000?oCf=codmSLom?Hg?l000002_oGi>000ol0003oeo3S
omO`h`06omO`h`;o00001OoIoMP01?l0003oa_k7olKnaoo6o/L2o`00023ooo]Z00?o0000oookJ_oo
nfX0:_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z03Oooo]Z0ol000000onB0@3o
0000o`000007okll0003o`000?nm@AGo_D4E00Ko_D4E0ol0000>olEMB003o`000?noG53o_ea@00ko
_ea@00?o0000ok]KEonkFeL01Ol00002okmZJ`03o`000?ndGFGo]5eU00_o]5eU00?o0000ok1LJon`
G6/04On`G6/3o`0000koZlob0ol0000=oj_?lP?o00001onYf?P2o`0000;o_mg_00?o0000ol7Nk_o1
g^h01Oo1g^h2o`0000oo_n[b0_l0000<ok_clP03o`000?nbn^Oo/_[W00Go/_[W0_l000000onBkl_o
0000o`00001^oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX07?oonfX001Oooo]Z
00?o0000oookJ_oonfX01ooonfX3o`0005oooo]Z00Co0000o`04S_l0003o00001?l0A<H01?l0003o
>7?No`000?l0000?oeIng@03o`000?mlU=ooO9CO00GoO9CO00?o0000ogjGhOmnUn403omnUn400ol0
003oV:GNoiRUgP0KoiRUgP03o`000?nZ[=SoZZcH00WoZZcH0_l0000Foj^dg`03o`000?nj^=Oo^[SG
00Ko^[SG00?o0000okc1g_nl`Mh05?nl`Mh2o`0000Ko_/[S00?o0000olc=f_o<cMX02?o<cMX00ol0
003ocmOOoloGg`0:oloGg`03o`000?oCf=co000000[oenCP00?o0000omO`hooGl><01_oGl><00ol0
003oeOWRo`000004omWmf006o`000?o6o/Ooa_k7olKnaol0003oT=Im8_oonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003o1gcQo`00
0004o`0000Ko_c`000?o0000oke15Onm@AD02?nm@AD3o`0000coaEe800?o0000okmLD?noG5003_no
G5000ol0003o^e]Gok]KE`04ok]KE`_o00001_ndGFD00ol0003o/5a[ok1LJ`0=ok1LJ`?o00003On[
co84o`0000koZlob0_l0000<ojWHn003o`000?nogNoo000000Go`Mk^0_l0000@okoZlP03o`000?nk
lo;o^o?b00_o^o?b00?o0000ok;jionbn^L01Onbn^L00ol0003oT^o;oi;_b`02o`00073ooo]Z00?o
0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0LoookJP005ooonfX00ol0003ooo]ZoookJP04
oookJP?o0000HooonfX2o`000003o`0g^_l0003o04C600?o04C600?o0000ocQcg_l000000_l0000>
oeIng@03o`000?mlU=ooO9CO00?oO9CO00?o0000ogjGhOmnUn404?mnUn400ol0003oV:GNoiRUgP0L
oiRUgP03o`000?nZ[=SoZZcH00GoZZcH0ol0000Hoj^dg`03o`000?nj^=Oo^[SG00Co^[SG0_l0000E
okc1gP;o00002Onnb^<00ol0003oc<gJolc=fP05olc=fP;o00003_o?eml00ol0003oenCPomOTh007
omOTh0;o00002?oGl><00ol0003oeOWRo`000004omWmf006o`000?o6o/Ooa_k7olKnaol0003oT=Im
9?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0
>ooonfX00ol0003o1gcQo`Mlh@04o`0000Co_c`000?o0000oke15Onm@AD02?nm@AD00ol0003o^T@V
okY49P03o`0000WoaEe800?o0000okmLD?noG5003onoG5000ol0003o^e]Gok]KE`04ok]KE`03o`00
0?n]BDgo[DU=00Oo[DU=5_l0000=oj_?lP?o00003on[co83o`0000ooZMSh0_l00004ol7NkP03o`00
0?noj_;o_n[b00ko_n[b0_l0000<ok_clP03o`000?nbn^Oo/_[W00Go/_[W00?o0000oi;_bonBkl/0
0_l0001coookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX07?oonfX001Kooo]Z00?o
0000oookJ_oonfX00_oonfX3o`0006Oooo]Z0_l000000ol0=k[o0000o`14aP03o`14aP;o00000_m:
PN@3o`0000coEWkM00?o0000ogbDgomlU=l00_mlU=l00ol0003oOYOQogjGh@0AogjGh@03o`000?nH
YMkoV:GN01_oV:GN00?o0000ojZ/f?nZ[=P00onZ[=P2o`0001coZkCO00Co0000okZheonj^=Oo^[SG
0_l0000Fokc1gP03o`000?nnb^?o_/[S00[o_/[S00?o0000olc=f_o<cMX00oo<cMX00ol0003ocmOO
oloGg`0<oloGg`03o`000?oBhN?o000000SoenCP00?o0000omO`hooGl><01ooGl><01?l0003oeOWR
omGih_l00003omWmf004o`000?o6o/Ooa_k7olKna`;o00009_oonfX00ol0003ooo]ZoookJP0Woook
JP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0??oonfX2o`0000Co1gcQ0ol00002okll
0003o`000?nm@AGo_D4E00So_D4E00?o0000okY49_njA2H00_njA2H3o`0000OoaEe800?o0000okmL
D?noG5003onoG5000ol0003o^e]Gok]KE`02ok]KE`03o`000?n]BDgo[DU=017o[DU=00?o0000ojY;
EOnZBeD00_nZBeD5o`0000CoTLKj00?o0000oj_?l_n[co801On[co84o`00013oZlob0_l0000CojWH
n0;o000000?o`Mk^o`000?l000003onoj_82o`0000co^o?b0_l00006ok;ji`;o00000_nBkl/2o`00
07Gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0KoookJP005_oonfX00ol0003o
oo]Zo`000002o`0006_ooo]Z0_l000000ol0=k[o0000o`000002o`14aP;o00001Om:PN@3o`0000Wo
EWkM00Go0000ogbDgomlU=ooO9COo`00000EogjGh@03o`000?nHYMkoV:GN01_oV:GN00?o0000ojZ/
f?l000000_l0000Ooj^dg`03o`000?nj^=Oo000001Ko_<7N0_l0000>okk:h`05o`000?o<cM[oc<gJ
olc=f_l000003_o?eml01?l0003od^7Som;Qhol00007omOTh003o`000?oGl>?oeo3S00Ooeo3S00Go
0000omGih_oEnN;oeOWRo`000002omWmf004o`000?o6o/Ooa_k7olKna`;o00009ooonfX00ol0003o
oo]ZoookJP0WoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0?OoonfX3o`0000Go
1gcQ1?l0000:oke15@03o`000?njA2Ko^T@V00Co^T@V0ol00005olEMB003o`000?noG53o_ea@00ko
_ea@00Go0000ok]KEonkFeOo^e]Go`00000Doje9C@Go00002_nAa_X01?l0003oZloboj_?l_n[co83
o`00017oZlob0ol0000DojWHn003o`000?nZfOSo000000;o00003onoj_800ol0003o^o?bok_clP0:
ok_clP?o00001_nbn^L01Ol0003oT^o;oi;_bonBkl_o000007Oooo]Z00?o0000oookJ_oonfX06ooo
nfX00ol0003ooo]ZoookJP0KoookJP005_oonfX2o`0006oooo]Z0_l00002o`0g^P03o`000?l0A<Ko
04C600;o00001om:PN@4o`0000KoEWkM00?o0000ogbDgol000005_mnUn400ol0003oV:GNoiRUgP0I
oiRUgPCo00008_n[]=l2o`0001Go_<7N0_l0000Aokk:h`03o`000?o<cM[o000000gocmOO0_l00004
om;Qh`03o`000?oGi>3oenCP00?oenCP00?o0000omO`hooGl><01ooGl><01Ol0003oeOWRomGih_oE
nN;o000000;ofOgH00Co0000olKnaoo6o/Ooa_k70ol0000XoookJP03o`000?oonf[ooo]Z02Oooo]Z
00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0ooookJP?o00001_l7O>44o`0000So_D4E
00?o0000okY49_njA2H01_njA2H3o`0000;oaEe800?o0000okmLD?noG5003onoG5000ol0003o^e]G
o`00000@oje9C@Go00003onAa_X4o`00017oZlob0ol0000FojWHn0?o00000onUh_/2o`0000_o_n[b
0_l0000<ok_clP03o`000?nan>co000000Go/_[W0_l00003oi;_b`03o`000?oonf[ooo]Z07Oooo]Z
00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0KoookJP006?oonfX00ol0003ooo]Zoook
JP1]oookJP05o`000?l0=k[o03Njo`0g^_l000000_l0A<H00ol0003oBX7TodZ1i009odZ1i0?o0000
0omFO]d00ol0003oO9COo`00000GogjGh@03o`000?nHYMkoV:GN01?oV:GN1Ol00004oiR]i@03o`00
0?n[]=ooZkCO01coZkCO0ol00002ojbli@03o`000?nl`Mko_<7N017o_<7N00?o0000okk:honnb^<0
4_nnb^<00ol0003ocmOOoloGg`0;oloGg`03o`000?oBhN?od^7S00Cod^7S00?o0000omOTh?oGi>00
0_oGi>000ol0003oeo3SomO`h`06omO`h`;o00001?oEnN800ol0003ofOgHo`000003olKna`?o0000
:_oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0
@OoonfX2o`0000Ko1gcQ00?o0000ob:=k?lRSN`00ol00006oke15@03o`000?njA2Ko^T@V00So^T@V
1?l0000@okmLD0;o00003?n]BDd5o`00017oTLKj0ol00002oi76nP03o`000?n[co;oZlob00koZlob
0_l0000HojWHn0;o00001onUh_/2o`0000Oo_n[b0_l0000<ok_clP;o000000?o/OS/o`000?nbn^L0
1?nbn^L00ol0003oT^o;oi;_b`02oi;_bgcooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Z
oookJP0KoookJP006OoonfX00ol0003ooo]ZoookJP1]oookJP04o`000?l0=k[o03Njo`0g^P?o0000
3_m:PN@3o`000003oeIngOl0003oOYOQ01SoOYOQ00?o0000oiRUg_nHYMh03?nHYMh6o`0000[oV:gU
00?o0000oj^dgon[]=l03on[]=lCo`00013o_<7N0_l0000Bokk:h`;o00000oo0e>T00ol0003ocmOO
oloGg`08oloGg`03o`000?oBhN?od^7S00God^7S00Go0000omOTh?oGi>3oenCPo`000008omO`h`03
o`000?oEnN;oeOWR00CoeOWR0_l00003olKna`;o000000?oT=ImoookJ_oonfX0:_oonfX00ol0003o
oo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0@ooonfX2o`0000Go
1gcQ0_l00003ob:=k0?o00001?nm@AD00ol0003o^T@VokY49P0:okY49PGo00002onoG5001?l0003o
/4I1ok16@Ol00006oje9C@Go00004_nAa_X4o`0000KoTLKj00?o0000oj_?l_n[co802_n[co83o`00
01WoZMSh00?o0000ojGRnonUh_/02OnUh_/00ol0003o_n[bokoZlP03okoZlP03o`000?nklo;o^o?b
00[o^o?b0_l00002ok7hk003o`000?nbn^Oo/_[W00;o/_[W0_l00003oi;_b`03o`000?oonf[ooo]Z
07cooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP0KoookJP006_oonfX2o`0006ko
oo]Z00?o0000o`0g^_l0=kX00_l0=kX2o`00013oBX7T0ol0000HogjGh@03o`000?nHYMkoV:GN00Oo
V:GN1Ol0000AoiR]i@03o`000?n[]=ooZkCO00?oZkCO2?l0000:oj^eh0?o00002?n/_NH00ol0003o
^l7Oo`000002o`0000[o_<7N0_l0000Bokk:h`;o00001_o0e>T00ol0003ocmOOoloGg`06oloGg`03
o`000?oBhN?od^7S00Kod^7S00Co0000omOTh?oGi>3o00002?oGl><00ol0003oeOWRomGihP04omGi
hP;o00000oo6o/L00ol0003o[?6/o`00000^oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oook
J_oonfX0=_oonfX00ol0003ooo]ZoookJP15oookJP?o00001?l7O>400ol0003o8Xg/ob:=k003ob:=
k0?o00000_nm@AD00ol0003o^T@VokY49P0;okY49P03o`000?nhAcCo^4Ld00Oo00000onoG5000ol0
003o/4I1ok16@@02ok16@@Ko00005?nAa_X3o`0000_oTLKj00?o0000oj_?l_n[co801on[co82o`00
01SoZMSh0ol0000>ojGRn`;o000000?o_n[bo`000?l000003?nklo801Ol0003o/OS/ok7hk?nan>co
000000?o/_[W0_l00003oi;_b`03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX05ooonfX0
0ol0003ooo]ZoookJP0KoookJP007?oonfX00ol0003ooo]ZoookJP1/oookJP;o00000ol0=kX2o`00
013oBX7T0_mFR^L>o`0000_oOYOQ00Co0000oiRUg_nHYMkoV:GN1Ol0000DoiR]i@03o`000?nH[NGo
000001CoZkGP0ol0000<ojbmiP04o`000?nk`Moo^l7Ook_1g`?o00001_nl`Mh00ol0003o_/[Sokk:
h`0Aokk:h`03o`000?o0e>Wo`=CY00Oo`=CY00?o0000oloGgoo?eml00oo?eml2o`0000[od^7S0_l0
0008omO`h`03o`000?oEnN;oeOWR00GoeOWR00Oo0000olKnaoo6o/Ooa_k7o`000?n/lJco000002oo
oo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04Oo
oo]Z00Co0000o`1_c?l0003o00000ol7O>400ol0003o8Xg/ob:=k005ob:=k2?o00005OnAa_X4o`00
00ooTLKj00?o0000oj_?l_n[co800on[co83o`0001OoZMSh1Ol0000AojGRn`03o`000?nklo;o0000
00[o^o?b0_l00003ok7hk005o`000?nbn^Oo/_[Wok;jiol000001?nBkl/00ol0003ooo]ZoookJP20
oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX06ooonfX001gooo]Z0_l0001^oook
JP05o`000?l0=k[o03Njo`0g^_l000004?m:PN@00ol0003oEX[Wo`00000=ogbPj@oo00005onH[ND2
o`0000?oV:gU00?o0000oj^eh?n[]N003_n[]N03o`00013o[;gV00?o0000ok_1gonk`Ml00onk`Ml3
o`000003okc1g_l0003o000001;o_/[S0_l0000;ol3Dj@05o`000?o?emoocmOOoloGgol000003?oB
hN<00ol0003oeo3SomO`h`06omO`h`03o`000?oEnN;oeOWR00GoeOWR00?obOoHo`000?o6o/L00_o6
o/L00on/lJco0000oookJP0`oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0=Ooo
nfX00ol0003ooo]ZoookJP19oookJPCo00000_l7O>42o`0000So8Xg/00?o0000ofBcnomT/o/05?mT
/o/00ol0003oJKGkofVen`06ofVen`03o`000?nAa_[oTLKj00ooTLKj0ol0000Doi76nP03o`000?n[
co;o000000;o00005onYf?P3o`000003ojGQnol0003o0000017oYN;k00?o0000oi[Yn_nJjOX00_nJ
jOX3o`0000Go^o?b0_l00004ok7hk003o`000?nbn^Oo/_[W00;o00000_nBkl/3o`0008Cooo]Z00?o
0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0KoookJP007ooonfX00ol0003ooo]ZoookJP1/
oookJP05o`000?l0=k[o03Njo`1Ed?l000004?m:PN@00ol0003oEX[Wo`00000HogbPj@03o`000?nH
[NGoV:gU01KoV:gU00?o0000oiR]iOnH[ND01?nH[ND00ol0003oZkGPoj^eh00:oj^eh0?o00005?n/
_NH00ol0003o^l7Ook_1g`04ok_1g`;o00004_nnb^<2o`0000ko`=CY00?o0000oloGgol000002ooB
hN<00ol0003od^gVo`000007omO`h`03o`000?oEnN;oeOWR00GoeOWR00?obOoHo`000?o6o/L00_o6
o/L00on/lJco0000oookJP0boookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0=Ooo
nfX00ol0003ooo]ZoookJP1;oookJP;o000000Go06o<o`000?l7O>7o1gcQo`000008ob:=k0;o0000
5OmT/o/2o`0000OoJKGk00?o0000oi76n_nAa_X02onAa_X3o`0001SoTLKj00?o0000ojWHn?nYf?P0
5OnYf?P3o`0000?oYN7k00?o0000ojGRnonUh_/03_nUh_/00ol0003oV^Wjoi[YnP08oi[YnP?o0000
00?o^o?bo`000?nan>`01?nan>`01Ol0003o/_[Wok;jiol0003oT^o;00?o000000?oGMC4oookJ_oo
nfX0QOoonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z01[ooo]Z000PoookJP03o`00
0?oonf[ooo]Z06cooo]Z00Co0000o`0g^_l0=k[o05G@0ol0000=odZ1i004o`000?mFR^OoEX[Wo`00
01SoO:3Y00?o0000oiR]iOnH[ND04onH[ND2o`0000SoV:gU00?o0000oj^eh?n[]N001_n[]N03o`00
01Oo[;gV00?o0000ok_1gonk`Ml00_nk`Ml2o`0000?o_L[T00?o0000okk:honnb^<03?nnb^<2o`00
013o`=CY0_l0000;om;Qh`04o`000?oBkNKod^gVo`0000Koeo3S00?o0000omGih_oEnN801?oEnN80
0ol0003obOoHo`000003olKna`03ojca[?l0003ooo]Z03Cooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z04gooo]Z00Ko0000o`1_c?l0Klco0000o`Ml
hOl00009ob:=k0;o00005OmT/o/2o`0000KoJKGk0_l00007oi76nPCo00004onAa_X5o`0000GoRLkn
00?o0000ojWHn?nYf?P04OnYf?P2o`0000CoYN7k0_l0000>ojGRn`;o00003onJjOX;o`0000;oGMC4
RooonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01[ooo]Z000QoookJP;o0000KOoo
nfX2o`000004o`0g^_l0003o>X?XocZ3j0?o00002_m:PN@01Ol0003oEX[WoeJ:iomFR^Oo000001So
O:3Y00?o0000oiR]iOnH[ND04?nH[ND2o`0000[oV:gU00?o0000oj^eh?n[]N000on[]N03o`0001_o
[;gV00Co0000ok_1gol0003o00001_nmb^@2o`0000[o_/[S0_l0000@ol3Dj@;o00000oo1gnh00ol0
003od^7Som;Qh`05om;Qh`;o00000ooBkNH00ol0003oeo3SomO`h`03omO`h`03o`000?oEnN;oeOWR
00CoeOWR00Co0000olWof?o9omSo00000_o6o/L00on/lJco0000oookJP0foookJP03o`000?oonf[o
oo]Z027ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1>oookJP;o00000ol0Kl`4
o`0000Oo8Xg/00?o0000ofBcnomT/o/05?mT/o/00ol0003oJKGkofVen`05ofVen`04o`000?nAa_[o
TLKjoi76nP?o00004OnAa_X6o`0000_oRLkn0_l0000>ojWHn0?o00001?nUhO/2o`0000goYN;k0_l0
000@oi[YnP03o`000?n5jNgoQNW]00?oQNW]1?l00002oegDa003o`000?oonf[ooo]Z08cooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0JoookJP008ooonfX00ol0003ooo]ZoookJP1[
oookJPCo00001?ljPnP4o`0000KoBX7T00?o0000oeJ:iomFR^L00_mFR^L00ol0003oO:3YogbPj@0F
ogbPj@03o`000?nH[NGoV:gU00koV:gU00?o0000oiR]iOnH[ND02onH[ND00ol0003oZkGPo`000002
o`0001ko[;gV0_l0000:okg:i003o`000?nnb^?o_/[S00Ko_/[S00?o0000ol3DjOo0e>T03oo0e>T0
0ol0003o`Mo^ol7OkP04ol7OkP03o`000?oBhN?od^7S00?od^7S00?o0000om;]i_oBkNH00ooBkNH0
0ol0003oeo3SomO`h`02omO`h`OoeOWR00Co0000olWof?o9omSo00000_o6o/L00on/lJco0000oook
JP0goookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP1@oookJP?o00000_l0Kl`7o`0000?o8Xg/0_l0000EofBcn`;o00001OmY]O/4o`0000ooTLKj1Ol0
000CohW>oP03o`000?nYf?SoZMSh00SoZMSh0ol00006ojGQn`03o`000?nUh__oYN;k00[oYN;k0ol0
000>oi[YnP;o00001On5jNd4o`0000?oGMC4TOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01[ooo]Z000ToookJP;o0000K?oonfX4o`0000Oo>X?X0ol00003odZ1i003o`000?mFR^Oo
EX[W00;oEX[W00?o0000ogbPjOmlX>T05omlX>T00ol0003oV:gUoiR]i@0;oiR]i@;o00003?nH[ND4
o`0001ko[;gV0ol000000on/aNco0000okg:i00:okg:i0;o00001?nnb^<2o`00013o`=CY0_l00008
ol7OkP05o`000?oBhN?od^7Som;Qhol000001OoBkNH00ol0003oeo3SomO`h`02omO`h`OoeOWR00So
0000olWof?o9omSobOoHo`000?o6o/Oo[?6/o`0003[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z05?ooo]Z0ol000000ol0Klco0000o`000003o`R6
h0Ko00005_mT/o/5o`0000?oJKGk00?o0000oi76n_nAa_X01onAa_X6o`0001WoRLkn0_l00005ojWH
n0?o00001onUhO/2o`0000[oYN;k0ol0000=oi[YnP?o00001On5jNd5o`0000;oGMC400?o0000oook
J_oonfX0T_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z01[ooo]Z000VoookJP03
o`000?oonf[ooo]Z06_ooo]Z00?o0000o`1Ed?l000002OljPnP3o`000003odZ1i?l0003oEX[W00?o
EX[W00?o0000ogbPjOmlX>T05_mlX>T00ol0003oV:gUoiR]i@0:oiR]i@03o`000?nH[NGoV:gU00Oo
V:gU1Ol00003oiNek003o`000?n/_NKo[;gV01Wo[;gV0ol00005ojc5k003o`000?nmb^Co_L[T00[o
_L[T00Co0000okk:hol0003o00004?o0e>T2o`0000_o`Mo^00?o0000om;Qhol000001_oBkNH01?l0
003oeo3SomO`hooGl><7omGihP08o`000?o9omSobOoHolWof?l0003oa_k7ojca[?l0000loookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1FoookJPKo
00001Ol8Q^0?o`0000KoI;?k1Ol00006ofVen`04o`000?nAa_[oTLKjoi76nPGo00008On9c_h00ol0
003oZMSho`000002o`0000WoYN7k00?o0000ojGRnonUh_/02?nUh_/2o`0000koV^Wj0_l00006ohGY
k@Co00000_mMe<@00ol0003ooo]ZoookJP2FoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX06_oonfX002Oooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003o05G@o`00000;ocZ3j0Co
00000omFR^L00ol0003oO:3YogbPj@0FogbPj@03o`000?nH[NGoV:gU00OoV:gU0_l00004oiR]i@Ko
00002OnG]N`00ol0003o[;gVojbmiP0EojbmiP?o00002On/aN`00ol0003o_L[Tokg:i009okg:i0;o
00004Oo0e>T00ol0003o`Mo^ol7OkP0<ol7OkP03o`000?oBkNKod^gV00God^gV00?o0000omO`hooG
l><01ooEnN802?l0003obOoHolWof?o9omSo0000olKnaon/lJco0000?_oonfX00ol0003ooo]Zoook
JP0NoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0F_oonfX2o`000003o`1_c?l0
003o000000Ko28KP0_l0000:oeBfn`[o000000?oI;?ko`000?l000002?l0000WohW>oP;o00002OnU
hO/2o`0000SoYN;k0ol0000=oi[YnP?o00001_n5jNd3o`0000?oGMC4W?oonfX00ol0003ooo]Zoook
JP0AoookJP03o`000?oonf[ooo]Z01[ooo]Z000XoookJP;o0000K?oonfX3o`0000_o>X?X00?o0000
odV>kOm9S^d01Ol0000HogbPj@03o`000?nH[NGoV:gU00GoV:gU00?o0000oiR]iOl000001?l0000@
oiNek003o`000?n/_NKo[;gV017o[;gV0ol0000=ojc5k003o`000?nmb^Co_L[T00Oo_L[T00?o0000
okkDj_l000003oo0e>T2o`0000ko`Mo^0onnk?<00ol0003od^gVom;]iP03om;]iP03o`000?oGl>?o
eOWR00KoeOWR00?o0000olWof?o9omP00_o9omP3o`00043ooo]Z00?o0000oookJ_oonfX07OoonfX0
0ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z05gooo]Z00Co0000o`1_c?l0003o00001_l8
Q^000ol0003oE;KkoeBfn`06oeBfn`Co00002_mD]_/3o`0000CoG;Wl00?o0000ohW>o_n9c_h07On9
c_h5o`0000GoOmCo0ol00004ojGQn`;o00002?nUh_/2o`0000goV^Wj0ol00007ohGYk@?o00000_mM
e<@00ol0003ooo]ZoookJP2MoookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX06_oo
nfX002[ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`0000_o>X?X00?o0000odV>kOm9S^d00om9S^d?
o`0000_oO:3Y00Co0000oiR]iOnH[NGoV:gU1Ol0000FoiNek003o`000?n/_NKo[;gV00ko[;gV0_l0
000Aojc5k003o`000?nmb^Co_L[T00Co_L[T0_l00003okkDjP03o`000?o0e>Wo`=CY00[o`=CY0_l0
000>ol7OkPSo_^cc0_l000000ooBkNKo0000omGihP06omGihP03o`000?o9omSobOoH00;obOoH0_l0
0012oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP1PoookJP?o00001Ol8Q^02o`0000?oE;Kk0ol0000AoeBfn`?o00000_mL^O`2o`0001OoRLkn1_l0
000=ogoDo`;o000000?oYN7ko`000?nUh_/01_nUh_/3o`0000coV^Wj0ol00007ohGYk@?o00000_mM
e<@00ol0003ooo]ZoookJP2PoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX06Ooo
nfX002_ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003o04[3o`00000:ocZ3j003o`000?m9S^go
BHk]00CoBHk]00?o0000ogRVl?mhY_002omhY_0?o`000003oiNdk?l0003oUkG/01WoUkG/00?o0000
ojbmi_n/_NH02_n/_NH3o`0001Co[<G/00Co0000okg:i?nmb^Co_L[T0_l00006okkDjP03o`000?o0
e>Wo`=CY00So`=CY00?o0000ol7Ok_o1gnh03?o1gnh00ol0003o_^ccokk/l`09okk/l`;o00001_oE
nN800ol0003obOoHolWof002olWof0;o0000A?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oo
nf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0HooonfX4o`0000;o28KP1?l0000GoeBfn`?o000000?o
G;Wlo`000?n9c_h04?n9c_h5o`0000goOmCo2Ol00006ojGRn`;o00003OnJjOX2o`0000SoQNW]0ol0
0002oegDa003o`000?oonf[ooo]Z0:?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Zoook
JP0IoookJP00;?oonfX2o`0006_ooo]Z00?o0000o`1:`ol000000_l00008ocZ3j003o`000?m9S^go
BHk]00CoBHk]00?o0000ogRVl?mhY_005omhY_000ol0003oUkC/o`00000KoiNek003o`000?n/_NKo
[;gV00Oo[;gV0ol0000Hojc5k003o`000?nmb^Co000000So_]CZ00?o0000ol3DjOo0e>T01_o0e>T2
o`0000go`Mo^00?o0000okk/lonnk?<02_nnk?<2okSel@Co00000_oEnN800ol0003obOoHolWof003
o`0004Oooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[o
oo]Z06?ooo]Z00?o0000oookJ_oonfX01ol0000JoeBfn`?o00002on9c_h5o`000003ogoDool0003o
000000oo00002_mme?l00ol0003oYN;ko`000002o`0000coV^Wj0ol00009ohGYk@04o`000?mMe<Co
GMC4o`000:Wooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0IoookJP00;_oonfX0
0ol0003ooo]ZoookJP1YoookJP;o000000?o04[3o`000?l000000_l00005ocZ3j003o`000?m9S^go
BHk]00GoBHk]00?o0000ogRVl?mhY_005omhY_000ol0003oUkG/oiNek00KoiNek003o`000?n/_NKo
[;gV00?o[;gV0ol0000Kojc5k0;o00002_nne>X00ol0003o`=CYol3Dj@03ol3Dj@;o00003_o1gnh;
okk/l`03o`000?nhmO7o^?Ga00;o^?Ga00Co0000ok[hkonjn>oo^_S_1?l000000on[nN;oOn>jo`00
0019oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0<_oonfX00ol0003ooo]Zoook
JP1SoookJP?o00000ooonfX5o`0001coE;Kk4Ol0000IoggDo`Co000000?oV^Wjo`000?nJjOX02OnJ
jOX3o`0000WoQNW]0_l000000omMe<Co0000o`00002/oookJP03o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_oonfX06OoonfX002oooo]Z0_l0001[oookJP03o`000?l0B/?o000000;o8h;Y0ol00003
ocZ3j003o`000?m9S^goBHk]00GoBHk]00?o0000ogRVl?mhY_005_mhY_000ol0003oUkG/oiNek00L
oiNek003o`000?n/_NKo000000;o00006on/aN`3o`0000?oZloc00?o0000okkDj_nne>X01_nne>X0
0ol0003o`=CYol3Dj@02ol3Dj@03o`000?o1gnko`Mo^00co`Mo^00?o0000okk/lonnk?<02?nnk?<2
o`0000Co^?Ga00Go0000ok[hkonjn>oo^_S_o`000004oj_ihP03ogoS^_l0003ooo]Z04[ooo]Z00?o
0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z05oooo]Z1Ol0
0008oookJPGo00003Olo/o<Ao`00023oOMCo1Ol00006ofWDm`Go00000_nJjOX3o`0000WoQNW]0ol0
00000omMe<Co0000oookJP2_oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX06Ooo
nfX0037ooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003o04[3o`000004ob>2j@Co00002?m9S^d0
0ol0003oN:K`ogRVl00EogRVl0;o00006onG]N`4o`0001_o[<G/0ol00007oj_?l`03o`000?nne>[o
_]CZ00Ko_]CZ00Co0000ol3DjOl0003o00003Oo1gnh00ol0003o_^ccokk/l`08okk/l`;o00001Onh
mO400ol0003o^_S_ok[hk`02o`0000?oZoWR00?oOn>jo`000?oonfX0C?oonfX00ol0003ooo]Zoook
JP0JoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0G?oonfX3o`0000Cooo]Z00?o
0000oookJ_oonfX02OoonfX5o`0001[o?k?c0_l0000IoggDo`Ko00004?mYe?L2o`0000;oQNW]0ol0
0004ohGYk@?o000000?oGMC4o`000?oonfX0/_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oo
nf[ooo]Z01Wooo]Z000boookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000o`1:`ol000001_lSP^T4
o`0000GoBHk]00?o0000ogRVl?mhY_005OmhY_000ol0003oNjW`o`00000EoiNek0Go00001?nE_O<0
0ol0003o[<G/ojc5k00Fojc5k0;o00002on[co<00ol0003o_]CZokkDjP06okkDjP03o`000?o1gnko
`Mo^00_o`Mo^00?o0000okk/lonnk?<02Onnk?<00ol0003o^?GaokSel@04okSel@04o`000?njn>oo
0000o`0000?oZoWR0ol0001?oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP1IoookJPCo00001ooonfX00ol0003ooo]ZoookJP0<oookJPGo00006Olo
/o<2o`0001;oOMCo1Ol0000BofWDm`;o00002Om6a]d6o`000;Oooo]Z00?o0000oookJ_oonfX03?oo
nfX00ol0003ooo]ZoookJP0IoookJP00<ooonfX2o`0006_ooo]Z0_l00006ob>2j@03o`000?lhSnoo
>8o_00Co00000_m9S^d00ol0003oN:K`ogRVl00DogRVl004o`000?mkZO3oNjW`o`0000koUkG/1_l0
000:oiFml`03o`000?n/aNco[<G/01;o[<G/0ol0000>oj_?l`03o`000?nne>[o_]CZ00;o_]CZ0_l0
00000onog^oo0000ol7OkP0:ol7OkP;o00002_nnk?<2o`0000Ko^?Ga00?o0000ok[hkol000001?n[
nN800omohk[o0000oookJP1AoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP1FoookJP?o00002ooonfX00ol0003ooo]ZoookJP0?oookJP_o00004_lo
/o<2o`0000_oOMCo1Ol0000?ofWDm`Go00003Om6a]d2o`000;gooo]Z00?o0000oookJ_oonfX02ooo
nfX00ol0003ooo]ZoookJP0IoookJP00=OoonfX00ol0003ooo]ZoookJP1YoookJP;o00001_lSP^T0
0ol0003o>8o_ocR?k`03ocR?k`Co00005OmhY_001?l0003oNjW`og^Yl?l00009oiNek0Go00004OnE
_O<00ol0003o[<G/ojc5k00>ojc5k0?o00004_n[co<01?l0003o_]CZo`000?l00003okoNk`03o`00
0?o1gnko`Mo^00Oo`Mo^0_l0000:okk/l`;o00001onhmO43o`0000?oZoWR0ol0001DoookJP03o`00
0?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP1BoookJPCo0000
3_oonfX00ol0003ooo]ZoookJP0BoookJPGo00000olDXMH=o`0000Oo?k?c0_l00006oggDo`;o0000
3omYe?L6o`0000coA/KM0ol00033oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
6?oonfX003Kooo]Z0_l0001ZoookJP?o00001OlSP^T00ol0003o>8o_ocR?k`05ocR?k`go00002Omh
Y_001Ol0003oNjW`og^Yl?mkZO3o000000?oUkG/1Ol0000GoiFml`03o`000?n/aNco[<G/00[o[<G/
0ol0000Foj_?l`;o00001?nog^l00ol0003o`Mo^ol7OkP06ol7OkP03o`000?nnk??o_^cc00Wo_^cc
00?o0000okSelOnhmO401_nhmO42o`0000?oZoWR00?o0000ogoS^_l00000EooonfX00ol0003ooo]Z
oookJP0GoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0CooonfX3o`0001;ooo]Z
00?o0000oookJ_oonfX06?oonfX9o`0000So5:7F1Ol00002ocncl`03o`000?mme?oo000000ooJMCg
1Ol0000=odK6g@03o`000?oonf[ooo]Z0<Wooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]Z
oookJP0HoookJP00>?oonfX00ol0003ooo]ZoookJP1YoookJPCo00000olSP^T00ol0003o>8o_ocR?
k`06ocR?k`03o`000?m_[OOoKjgg00SoKjgg4Ol0000MoiFml`03o`000?n/aNco[<G/00Oo[<G/0_l0
000Eoj_?l`?o00000onXfOT01Ol0003o_mk_okoNkonog^oo000000Ko`Mo^0_l0000:okk/l`;o0000
2?nhmO400ol0003oZoWRoj_ihP02oj_ihP?o0000F?oonfX00ol0003ooo]ZoookJP0GoookJP03o`00
0?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0BooonfX4o`0001Gooo]Z00?o0000oookJ_oonfX0
8ooonfX9o`0000So5:7F1Ol00004ofWDm`Go00001om6a]d5o`000=;ooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP0HoookJP00>OoonfX00ol0003ooo]ZoookJP1YoookJP;o000000Ko
1G_Po`000?l0003o0000ob>2jOl00008ocR?k`03o`000?m_[OOoKjgg013oKjgg00?o0000og>_momc
[oL01?mc[oL00ol0003oUKgcoiFml`0LoiFml`03o`000?n/aNco[<G/00?o[<G/0ol0000Doj_?l`?o
00001onXfOT2o`000003okoNkol0003o`Mo^00?o`Mo^0_l0000:okk/l`;o00002OnhmO401_l0003o
ZoWRoj_ih_n[nN;o0000ogoS^P;o0000F_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[o
oo]Z033ooo]Z00?o0000oookJ_oonfX0B?oonfX3o`0001Wooo]Z00?o0000oookJ_oonfX0<ooonfX3
o`0000?o5:7F1?l00002odK6g@So0000f_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[o
oo]Z01Sooo]Z000joookJP;o0000J_oonfX2o`0000?o1G_P0ol00008ocR?k`03o`000?m_[OOoKjgg
013oKjgg00?o0000og>_momc[oL01?mc[oL00ol0003oUKgcoiFml`0LoiFml`03o`000?n/aNco0000
00;o00005On[co<2o`0000coZ=Wi0_l00003ol7OkP03o`000?nnk??o_^cc00Wo_^cc00?o0000okSe
lOnhmO401onhmO401Ol0003oZoWRoj_ih_n[nN;o000000;oOn>j00?o0000oookJ_oonfX0FooonfX0
0ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0A?oonfX4
o`0001_ooo]Z00?o0000oookJ_oonfX0oooonfXToookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000
oookJ_oonfX06?oonfX003cooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003o1G_Po`Ekh003o`Ek
h0?o00001_lhSnl00ol0003oKjggofn]m`0@ofn]m`03o`000?mc[oOoLjog00CoLjog00?o0000oiFm
lonE_O<06OnE_O<4o`0001GoZloc0ol0000?ojSIn@04o`000?o1gnko0000o`0000[o_^cc0_l00008
okSel@;o00000on[nN801?l0003oOn>jogoS^_l0001OoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP11oookJP?o00007ooonfX00ol0003ooo]Zoook
JP3ooookJRGooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0HoookJP00?OoonfX0
0ol0003ooo]ZoookJP1YoookJP03o`000?l5Nn3o1G_P00Co1G_P1?l00004ocR?k`03o`000?m_[OOo
Kjgg013oKjgg00?o0000og>_momc[oL01?mc[oL00ol0003oUKgcoiFml`0AoiFml`Oo00001On@a_X0
0ol0003oZlocoj_?l`0>oj_?l`?o00004?nXfOT00ol0003oZM[io`000002o`0000Wo_^cc0_l00008
okSel@?o00000_n[nN801?l0003oOn>jogoS^_mohkYQoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0moookJPCo00008_oonfX00ol0003ooo]Zoook
JP3ooookJRGooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0HoookJP00?_oonfX2
o`0006[ooo]Z0ol00004o`Ekh0;o000000Co88g[o`000?l0003o00000_lhSnl00ol0003oKjggofn]
m`0@ofn]m`03o`000?mc[oOoLjog00CoLjog00?o0000oiFmlonE_O<02OnE_O<7o`0000goT<Kj00?o
0000oj_?lon[co<02_n[co<3o`0001;oZ=Wi0ol00003oj?So0?o00001Onnk?<00ol0003o^?GaokSe
l@06okSel@Co000000?oZoWRo`000?l000000_mohkYToookJP03o`000?oonf[ooo]Z01?ooo]Z00?o
0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP0koookJP?o00009_oonfX00ol0003ooo]Zoook
JP3ooookJRKooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0HoookJP00@?oonfX0
0ol0003ooo]ZoookJP1YoookJP04o`1Za_l0003o0000o`0000?o1G_P00Co0000ob2=jolPSN_o88g[
0_l000000olhSnoo0000ofn]m`0Aofn]m`03o`000?mc[oOoLjog00CoLjog00Co0000oiFmlonE_O?o
UKgc1ol0000Eoi36nP03o`000?n[co?oZloc00OoZloc0_l0000DojSIn@03o`000?nShocoXn?l00Oo
Xn?l0_l000000onnk??o0000o`000007okSel@;o000000GoZoSXo`000?n[nN;oZoWRo`000002ogoS
^P03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0^oook
JP03o`000?oonf[ooo]Z03Sooo]Z0ol0000YoookJP03o`000?oonf[ooo]Z0?oooo]Z9ooonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Sooo]Z0011oookJP;o0000JooonfX00ol0003o
06[6o`000002o`000003o`Ekh?l0003o000000Co88g[7_l0000Moi36nP03o`000?n[co?oZloc00?o
Zloc0ol0000AojSIn@Co00003OnSho`00ol0003o^?Gao`000006okSel@05o`000?n[n>SoZoSXo`00
0?n[nN800_l000000omohk[o0000oookJP1XoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oook
J_oonfX0;_oonfX00ol0003ooo]ZoookJP0doookJPCo0000;?oonfX00ol0003ooo]ZoookJP3ooook
JRSooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0GoookJP00@ooonfX00ol0003o
oo]ZoookJP1ZoookJP;o000000Go06[6o`000?l0003o1G_Po`000006ob2=j`03o`000?mS/o_oHk?k
013oHk?k0_l00005ofVen`03o`000?n@a_[oT<Kj01coT<Kj00?o0000oj_?lol000000_l0000AojSI
n@?o000000?oXn;lo`000?nSho`03?nSho`00ol0003oU>WhoiCYn002oiCYn0?o000000?o^?Gao`00
0?l000000_n[n>P01?l0003oZoWRo`000?mohkY]oookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0aoookJP?o0000<?oonfX00ol0003ooo]ZoookJP3o
oookJRWooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0GoookJP00A?oonfX00ol0
003ooo]ZoookJP1[oookJP?o000000?o06[6o`000?l000000_l00004ob2=j`;o00004_mS/o/00ol0
003oJKGkofVen`03ofVen`03o`000?n@a_[oT<Kj01coT<Kj00?o0000ojSInOnXfOT03onXfOT3o`00
00;oXn;l0_l0000;oj?So003o`000?nDjOSoU>Wh00SoU>Wh1ol0001_oookJP03o`000?oonf[ooo]Z
017ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0]oookJPCo0000<ooonfX00ol0
003ooo]ZoookJP3ooookJRWooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0Goook
JP00AOoonfX2o`0006kooo]Z0ol000000ol0J/Ko0000o`000003o`0000;o88g[0_l0000Aof>cn`;o
00001?mY]O/2o`0001;oT<Kj1ol00005ohS>oP;o00002onXfOT3o`0000?oXn;l0_l0000:oj?So003
o`000?nDjOSoU>Wh00WoU>Wh00Co0000ogWTi_mii>KoNNCV0ol0001boookJP03o`000?oonf[ooo]Z
013ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0ZoookJP?o0000=ooonfX00ol0
003ooo]ZoookJP3ooookJR[ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0Goook
JP00AooonfX00ol0003ooo]ZoookJP1^oookJP;o00000_l0J/H7o`0001;oHk?k0_l00004ofVen`03
o`000?n@a_[oT<Kj00WoT<Kj1_l0000>ohS>oP03o`000?nXfOWoZ=Wi00GoZ=Wi0ol00005oj?Ro003
o`000?nShocoXn?l00OoXn?l0_l00009oiCYn0;o00000omii>H3o`0007Kooo]Z00?o0000oookJ_oo
nfX03ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z02Kooo]Z1?l0000joookJP03
o`000?oonf[ooo]Z0?oooo]Z:ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z01Oo
oo]Z0018oookJP03o`000?oonf[ooo]Z073ooo]Z00?oA@00o`000?l0J/H00_l00002o`:3g@go0000
2?mS/o/00ol0003oJKGkofVen`02ofVen`04o`000?n@a_[oT<Kjoi36nPOo00005On8c_h2o`0000;o
Z=Wi0ol00006oj?Ro0;o00001_nSho`3o`0000SoU>Wh0ol00003ogWTiP?o0000N_oonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX08ooonfX3o`0003ko
oo]Z00?o0000oookJ_oonfX0oooonfX/oookJP05o`000?oonf[ooo]ZoookJ_l000006OoonfX004Wo
oo]Z0_l0001coookJP03odD00?l0003o000000;o00000_l2Pmd00ol0003oD;Gjoe2enP07oe2enPSo
000000?oHk?ko`000?l000001_l0000NohS>oP;o00001onSh_`2o`0000GoXn?l0ol00008oiCYn0?o
00000_mii>H4o`0007kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0/oookJP03
o`000?oonf[ooo]Z023ooo]Z1?l00011oookJP03o`000?oonf[ooo]Z0?oooo]Z;OoonfX01?l0003o
oo]ZoookJ_l0000IoookJP00BooonfX00ol0003ooo]ZoookJP1aoookJP03o`000?oonf[oA@0000?o
000000?o0X?Mo`000?l000004_m@]OX3o`0000;oFKSl00?o0000ohS>o_n8c_h05?n8c_h5o`0000Go
Nm?o0_l00004oj?Ro003o`000?nShocoXn?l00?oXn?l0_l00008oiCYn0?o00000_mii>H4o`00087o
oo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01go
oo]Z0ol00015oookJP03o`000?oonf[ooo]Z0?oooo]Z;OoonfX01?l0003ooo]ZoookJ_l0000Ioook
JP00C?oonfX2o`00077ooo]Z00?o0000oookJ_oonfX00_oonfX00om5003o0000o`000002o`0001Co
D;Gj0_l000000omI^?co0000ohS>oP0?ohS>oPGo00003?mkdol01?l0003oXn;lo`000?l00003oj?S
o0?o00001onDjOP3o`0000CoNNCV0_l000000om6a:oooo]ZoookJP22oookJP03o`000?oonf[ooo]Z
00gooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0IoookJPCo0000B?oonfX00ol0
003ooo]ZoookJP3ooookJRkooo]Z00Co0000oookJ_oonf[o00006?oonfX004kooo]Z00?o0000oook
J_oonfX0K_oonfX00ol0003ooo]ZoookJP05oookJP03odD00?l0003o000001GoD;Gj0ol0000:ohS>
oPGo00001Omkdol>o`0000;oXn?l0ol00007oiCYn0?o00001Omii>H00ol0003oA/B_oookJP27oook
JP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0Foook
JP?o0000C?oonfX00ol0003ooo]ZoookJP3ooookJRoooo]Z00?o0000oookJ_l000006?oonfX004oo
oo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP08oookJP03o`000?m@]O[oD;Gj01Go
D;Gj5?l0000<ogSCoPCo000000CoU>Who`000?l0003o00000onDjOP3o`0000?oNNCV0ol000000om6
a:oooo]ZoookJP2:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP0BoookJPCo0000CooonfX00ol0003ooo]ZoookJP3ooookJS3ooo]Z0_l0000Hoook
JP00D?oonfX2o`0006gooo]Z00?o0000oookJ_oonfX02ooonfX2o`0000Wo=k3`3ol0000EogSCoPKo
00002?mOdO<3o`000003ogWTi_l0003o000000Co0000T?oonfX00ol0003ooo]ZoookJP0:oookJP03
o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX03ooonfX3o`0005?ooo]Z00?o0000oookJ_oo
nfX0oooonfX_oookJP?o00006?oonfX005;ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]Z
oookJP0>oookJPOo00003olg/?03o`0000koN=?n1?l0000<oeoAl`;o00001Old^ll3o`0009?ooo]Z
00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z00cooo]Z
0ol0001EoookJP03o`000?oonf[ooo]Z0?oooo]Z;?oonfX4o`0001_ooo]Z001CoookJP;o0000J_oo
nfX00ol0003ooo]ZoookJP0AoookJPGo000000?o1YO:o`000?l000001Ol00009ocN`l0;o00001omh
doh3o`0000OoGm7c1_l00008ocBkc`;o0000VOoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z02cooo]Z00?o0000oookJ_oonfX02?oonfX4o`0005Sooo]Z00?o0000oookJ_oonfX0oooo
nfXXoookJPCo00007ooonfX005Gooo]Z00?o0000oookJ_oonfX0IooonfX00ol0003ooo]ZoookJP0K
oookJPKo00000ol6UlX2o`0000?o=k3`00?o0000ogSCo_l000001omOdO<7o`0000So=;_?0_l0002P
oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP06
oookJP?o0000G?oonfX00ol0003ooo]ZoookJP3ooookJRCooo]Z1?l0000SoookJP00E_oonfX00ol0
003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000o`JGb_l6UlX01Ol00003ocBk
c`Go0000Z_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX00_oonfX4o`0005oooo]Z00?o0000oookJ_oonfX0oooonfXPoookJPCo00009ooonfX005Oo
oo]Z0_l0001VoookJP03o`000?oonf[ooo]Z0>Kooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003o
oo]ZoookJP0ZoookJP03o`000?oonf[o000000;o0000HooonfX00ol0003ooo]ZoookJP3ooookJQco
oo]Z1?l0000[oookJP00FOoonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[ooo]Z0>Kooo]Z
00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0ZoookJP;o0000I_oonfX00ol0003ooo]Z
oookJP3ooookJQSooo]Z1?l0000_oookJP00F_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oo
nf[ooo]Z0>Oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oo
nf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0oooonfXDoookJPCo0000<ooonfX005_ooo]Z0_l0001R
oookJP03o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0]
oookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX0oooonfX@oookJPCo0000=ooonfX0
05gooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003ooo]ZoookJP3ZoookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX0;_oonfX2o`0006;ooo]Z00?o0000oookJ_oonfX0oooonfX<oook
JPCo0000>ooonfX005kooo]Z0_l0001NoookJP03o`000?oonf[ooo]Z0>_ooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oo
nfX0oooonfX8oookJPCo0000?ooonfX0063ooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]Z
oookJP3[oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0<?oonfX2o`0005oooo]Z
00?o0000oookJ_oonfX0oooonfX4oookJPCo0000@ooonfX0067ooo]Z00?o0000oookJ_oonfX0F_oo
nfX00ol0003ooo]ZoookJP3/oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0<_oo
nfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z0?oooo]Z1?l00017oookJP00H_oonfX2
o`0005[ooo]Z00?o0000oookJ_oonfX0kOoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[o
oo]Z03?ooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP3koookJPCo0000BooonfX0
06Cooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP3^oookJP05o`000?oonf[ooo]Z
oookJ_l00000=_oonfX2o`0005_ooo]Z00?o0000oookJ_oonfX0mooonfX4o`0004oooo]Z001Uoook
JP;o0000EooonfX00ol0003ooo]ZoookJP3_oookJP04o`000?oonf[ooo]Zo`0003Sooo]Z00?o0000
oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP3coookJPCo0000DooonfX006Oooo]Z00?o0000oook
J_oonfX0E?oonfX00ol0003ooo]ZoookJP3_oookJP04o`000?oonf[ooo]Zo`0003Wooo]Z0_l0001H
oookJP03o`000?oonf[ooo]Z0>oooo]Z1?l0001GoookJP00J?oonfX00ol0003ooo]ZoookJP1Coook
JP03o`000?oonf[ooo]Z0?3ooo]Z00Co0000oookJ_oonf[o0000>_oonfX00ol0003ooo]ZoookJP1E
oookJP03o`000?oonf[ooo]Z0>_ooo]Z1?l0001KoookJP00JOoonfX2o`0005?ooo]Z00?o0000oook
J_oonfX0lOoonfX00ol0003ooo]Zo`00000koookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oook
J_oonfX0j?oonfX4o`0005oooo]Z001[oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oo
nfX0l_oonfX2o`0003cooo]Z0_l0001CoookJP03o`000?oonf[ooo]Z0>Cooo]Z1?l0001SoookJP00
K?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z0?7ooo]Z0ol0000noookJP03o`00
0?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0h?oonfX4o`0006Oooo]Z001]oookJP;o0000Cooo
nfX00ol0003ooo]ZoookJP3]oookJPCo0000@_oonfX2o`00053ooo]Z00?o0000oookJ_oonfX0g?oo
nfX4o`0006_ooo]Z001_oookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0j?oonfX5
o`0004Sooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP3HoookJPCo0000KooonfX0
073ooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z0>Cooo]Z1?l0001>oookJP03o`000?oonf[ooo]Z
04cooo]Z00?o0000oookJ_oonfX0e?oonfX4o`0007?ooo]Z001boookJP03o`000?oonf[ooo]Z04Wo
oo]Z00?o0000oookJ_oonfX0h?oonfX4o`0005?ooo]Z0_l0001<oookJP03o`000?oonf[ooo]Z0=3o
oo]Z1?l0001goookJP00LooonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z0=_ooo]Z
1Ol0001IoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0c?oonfX4o`0007_ooo]Z
001doookJP;o0000B?oonfX00ol0003ooo]ZoookJP3GoookJPCo0000GooonfX00ol0003ooo]Zoook
JP18oookJP03o`000?oonf[ooo]Z0<Sooo]Z1?l0001ooookJP00M_oonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z0=?ooo]Z1?l0001ToookJP;o0000B?oonfX00ol0003ooo]ZoookJP34
oookJPCo0000PooonfX007Oooo]Z0_l00015oookJP03o`000?oonf[ooo]Z0<oooo]Z1?l0001Zoook
JP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0`?oonfX4o`0008Oooo]Z001ioookJP03
o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0b_oonfX5o`0006oooo]Z0_l00015oookJP03
o`000?oonf[ooo]Z0;cooo]Z1?l0002;oookJP00N_oonfX00ol0003ooo]ZoookJP11oookJP03o`00
0?oonf[ooo]Z0<Kooo]Z1?l0001foookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX0
^?oonfX4o`0008oooo]Z001koookJP;o0000@OoonfX00ol0003ooo]ZoookJP32oookJPCo0000Nooo
nfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z0;Cooo]Z1?l0002CoookJP00OOoonfX0
0ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z0;kooo]Z1?l00020oookJP;o0000@OoonfX0
0ol0003ooo]ZoookJP2`oookJPCo0000UooonfX007kooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0
003ooo]ZoookJP2ioookJPGo0000Q_oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z
0:cooo]Z1?l0002KoookJP00OooonfX2o`0003gooo]Z00?o0000oookJ_oonfX0]OoonfX4o`0008co
oo]Z0_l0000noookJP03o`000?oonf[ooo]Z0:Sooo]Z1?l0002OoookJP00POoonfX00ol0003ooo]Z
oookJP0joookJP03o`000?oonf[ooo]Z0;7ooo]Z1?l0002BoookJP03o`000?oonf[ooo]Z03_ooo]Z
00?o0000oookJ_oonfX0Y?oonfX4o`000:?ooo]Z0022oookJP;o0000>_oonfX00ol0003ooo]Zoook
JP2/oookJPGo0000UooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z0:7ooo]Z1?l0
002WoookJP00Q?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z0:Wooo]Z1?l0002M
oookJP;o0000>OoonfX00ol0003ooo]ZoookJP2MoookJPCo0000ZooonfX008Gooo]Z00?o0000oook
J_oonfX0=OoonfX00ol0003ooo]ZoookJP2UoookJPCo0000XooonfX00ol0003ooo]ZoookJP0foook
JP03o`000?oonf[ooo]Z09Wooo]Z1?l0002_oookJP00Q_oonfX2o`0003Gooo]Z00?o0000oookJ_oo
nfX0XOoonfX4o`000:Sooo]Z0_l0000foookJP03o`000?oonf[ooo]Z09Gooo]Z1?l0002coookJP00
R?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z09cooo]Z1Ol0002^oookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0TOoonfX4o`000;Oooo]Z0029oookJP;o0000<_oo
nfX00ol0003ooo]ZoookJP2HoookJPCo0000]?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z08gooo]Z1?l0002koookJP00RooonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[o
oo]Z09Cooo]Z1?l0002ioookJP;o0000<_oonfX00ol0003ooo]ZoookJP29oookJPCo0000_ooonfX0
08cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP2@oookJPCo0000_ooonfX00ol0
003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z08Gooo]Z1?l00033oookJP00SOoonfX2o`0002ko
oo]Z00?o0000oookJ_oonfX0RooonfX5o`000<Cooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003o
oo]ZoookJP21oookJPCo0000aooonfX008oooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ooo]Z
oookJP27oookJPCo0000b_oonfX2o`0002kooo]Z00?o0000oookJ_oonfX0OOoonfX4o`000<_ooo]Z
002@oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0PooonfX4o`000=3ooo]Z00?o
0000oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP1ioookJPCo0000cooonfX0097ooo]Z0_l0000Z
oookJP03o`000?oonf[ooo]Z07kooo]Z1Ol0003EoookJP;o0000:ooonfX00ol0003ooo]ZoookJP1e
oookJPCo0000dooonfX009?ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP1joook
JPCo0000g?oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z077ooo]Z1?l0003Goook
JP00U?oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX0M_oonfX4o`000>7ooo]Z00?o0000oookJ_oo
nfX09ooonfX00ol0003ooo]ZoookJP1]oookJPCo0000fooonfX009Kooo]Z00?o0000oookJ_oonfX0
9?oonfX00ol0003ooo]ZoookJP1boookJPCo0000i_oonfX2o`0002Oooo]Z00?o0000oookJ_oonfX0
JOoonfX4o`000=oooo]Z002GoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0KOoo
nfX5o`000>cooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP1UoookJPCo0000hooo
nfX009Sooo]Z0_l0000SoookJP03o`000?oonf[ooo]Z06Wooo]Z1?l0003boookJP;o00009?oonfX0
0ol0003ooo]ZoookJP1QoookJPCo0000iooonfX009[ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP1UoookJPCo0000n?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z
05kooo]Z1?l0003[oookJP00VooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z063o
oo]Z1Ol0003moookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000>oo
oo]Z002LoookJP;o00007ooonfX00ol0003ooo]ZoookJP1LoookJPCo0000oooonfX4oookJP;o0000
7ooonfX00ol0003ooo]ZoookJP1FoookJPCo0000looonfX009kooo]Z00?o0000oookJ_oonfX07?oo
nfX00ol0003ooo]ZoookJP1HoookJPCo0000oooonfX:oookJP03o`000?oonf[ooo]Z01cooo]Z00?o
0000oookJ_oonfX0D_oonfX4o`000?Oooo]Z002OoookJP;o00007?oonfX00ol0003ooo]ZoookJP1D
oookJPCo0000oooonfX?oookJP;o00007?oonfX00ol0003ooo]ZoookJP1>oookJPCo0000nooonfX0
0:7ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP1?oookJPGo0000oooonfXEoook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0B_oonfX4o`000?oooo]Z002RoookJP03
o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0BooonfX4o`000?oooo]Z6ooonfX00ol0003o
oo]ZoookJP0HoookJP03o`000?oonf[ooo]Z04Kooo]Z1?l0003ooookJPCooo]Z002SoookJP;o0000
6?oonfX00ol0003ooo]ZoookJP17oookJPCo0000oooonfXPoookJP;o00006?oonfX00ol0003ooo]Z
oookJP12oookJPCo0000oooonfX8oookJP00YOoonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oo
nf[ooo]Z04?ooo]Z1?l0003ooookJRKooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Zoook
JP0noookJPCo0000oooonfX<oookJP00Y_oonfX2o`0001Gooo]Z00?o0000oookJ_oonfX0?_oonfX5
o`000?oooo]Z:ooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z03[ooo]Z1?l0003o
oookJQ3ooo]Z002XoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0>_oonfX4o`00
0?oooo]Z<OoonfX2o`0001Cooo]Z00?o0000oookJ_oonfX0=_oonfX4o`000?oooo]Z5?oonfX00:Wo
oo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0foookJPCo0000oooonfXgoookJP03
o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0<_oonfX4o`000?oooo]Z6?oonfX00:[ooo]Z
0_l0000@oookJP03o`000?oonf[ooo]Z03;ooo]Z1Ol0003ooookJScooo]Z0_l0000AoookJP03o`00
0?oonf[ooo]Z02kooo]Z1?l0003ooookJQcooo]Z002/oookJP03o`000?oonf[ooo]Z00gooo]Z00?o
0000oookJ_oonfX0;_oonfX4o`000?oooo]Z@ooonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oo
nf[ooo]Z02[ooo]Z1?l0003ooookJR3ooo]Z002]oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000
oookJ_oonfX0:_oonfX4o`000?oooo]ZB?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[o
oo]Z02Kooo]Z1?l0003ooookJRCooo]Z002^oookJP;o00003?oonfX00ol0003ooo]ZoookJP0Voook
JPCo0000oooonfY=oookJP;o00003OoonfX00ol0003ooo]ZoookJP0RoookJPCo0000oooonfXXoook
JP00/?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z027ooo]Z1Ol0003ooookJU?o
oo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfX/oookJP00
/OoonfX2o`0000Wooo]Z00?o0000oookJ_oonfX07OoonfX4o`000?oooo]ZFOoonfX2o`0000Wooo]Z
00?o0000oookJ_oonfX06ooonfX4o`000?oooo]Z<?oonfX00;?ooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ooo]ZoookJP0IoookJPCo0000oooonfYOoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o
0000oookJ_oonfX05ooonfX4o`000?oooo]Z=?oonfX00;Cooo]Z00?o0000oookJ_oonfX01OoonfX0
0ol0003ooo]ZoookJP0EoookJPCo0000oooonfYToookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX04ooonfX4o`000?oooo]Z>?oonfX00;Gooo]Z0_l00005oookJP03o`000?oonf[ooo]Z
013ooo]Z1Ol0003ooookJVWooo]Z0_l00005oookJP03o`000?oonf[ooo]Z00oooo]Z1?l0003ooook
JScooo]Z002goookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX03?oonfX4o`000?oo
oo]ZL?oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00_ooo]Z1?l0003ooookJT3o
oo]Z002hoookJP;o00000_oonfX00ol0003ooo]ZoookJP08oookJPCo0000oooonfYeoookJP;o0000
0_oonfX00ol0003ooo]ZoookJP07oookJPCo0000oooonfY4oookJP00^_oonfX00ol0003ooo]Zo`00
0005oookJPGo0000oooonfYkoookJP03o`000?oonf[o000000Gooo]Z1?l0003ooookJTSooo]Z002k
oookJP;o000000?ooo]Zo`000?l000000_l0003ooookJX7ooo]Z0_l000000ooonf[o0000o`000002
o`000?oooo]ZC?oonfX00;cooo]Z0_l0003ooookJXKooo]Z0_l0003ooookJU3ooo]Z003ooookJ_oo
oo]ZoooonfZGoookJP00oooonf[ooookJ_oooo]ZUooonfX00?oooo]Zoooonf[ooookJYOooo]Z003o
oookJ_oooo]ZoooonfZGoookJP00oooonf[ooookJ_oooo]ZUooonfX00?oooo]Zoooonf[ooookJYOo
oo]Z003ooookJ_oooo]ZoooonfZGoookJP00oooonf[ooookJ_oooo]ZUooonfX00?oooo]Zoooonf[o
oookJYOooo]Z003ooookJ_oooo]ZoooonfZGoookJP00\
\>"],
  ImageRangeCache->{{{0, 915.062}, {458.5, 0}} -> {-0.0512706, -0.0250881, \
0.0022977, 0.0022977}, {{22.3125, 436.75}, {447.562, 10.875}} -> \
{-0.00940811, -0.0232745, 0.00211921, 0.00211921}, {{478.25, 892.75}, \
{447.562, 10.875}} -> {-1.02422, -0.0243539, 0.00222664, 0.00222664}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The next one takes a couple minutes, presumably because of the \
small probability values?\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3,2,1 corresponds to a 3d spin-up electron", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(H321 = \ HAtomShow[3, 2, 1, 0.8]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .51699 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0123094 0.47619 [
[ 0 0 0 0 ]
[ 1 .51699 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .51699 L
0 .51699 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0123094 0.477324 0.504685 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0568034 1.16626 0 1.16626 [
[ 0 0 0 0 ]
[ 1 1.08569 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24552 m
0 .80386 L
s
0 .80386 m
.40044 1.08569 L
s
.40044 1.08569 m
.41805 .58163 L
s
.41805 .58163 m
.08846 .24552 L
s
.67239 0 m
.92713 .41504 L
s
.92713 .41504 m
1 .94835 L
s
1 .94835 m
.70635 .58561 L
s
.70635 .58561 m
.67239 0 L
s
.08846 .24552 m
0 .80386 L
s
0 .80386 m
.70635 .58561 L
s
.70635 .58561 m
.67239 0 L
s
.67239 0 m
.08846 .24552 L
s
.41805 .58163 m
.92713 .41504 L
s
.92713 .41504 m
1 .94835 L
s
1 .94835 m
.40044 1.08569 L
s
.40044 1.08569 m
.41805 .58163 L
s
0 0 m
1 0 L
1 1.08569 L
0 1.08569 L
closepath
clip
newpath
.5 Mabswid
.701 .559 .691 r
.54146 .53865 m .5275 .539 L .53042 .54956 L closepath p F P
0 g
s
.711 .565 .687 r
.5295 .55067 m .53042 .54956 L .5275 .539 L p F P
0 g
s
.711 .565 .687 r
.50919 .55033 m .5295 .55067 L p .5275 .539 L F P
0 g
s
.711 .565 .687 r
.5275 .539 m .51948 .53886 L .50919 .55033 L p F P
0 g
s
.701 .592 .73 r
.5275 .539 m .54146 .53865 L p .54529 .52494 L F P
0 g
s
.701 .592 .73 r
.52558 .53332 m .5275 .539 L p .54529 .52494 L F P
0 g
s
.711 .585 .713 r
.52558 .53332 m .51948 .53886 L .5275 .539 L closepath p F P
0 g
s
.714 .569 .69 r
.5072 .55027 m .50919 .55033 L .51948 .53886 L p F P
0 g
s
.714 .569 .69 r
.51948 .53886 m .50386 .53843 L .5072 .55027 L p F P
0 g
s
.713 .6 .728 r
.51948 .53886 m .52558 .53332 L .52254 .52536 L p F P
0 g
s
.713 .6 .728 r
.50386 .53843 m .51948 .53886 L p .52254 .52536 L F P
0 g
s
.701 .592 .73 r
.54529 .52494 m .53656 .52516 L .52558 .53332 L p F P
0 g
s
.704 .596 .733 r
.53656 .52516 m .52254 .52536 L .52558 .53332 L closepath p F P
0 g
s
.698 .554 .688 r
.55003 .53834 m .54146 .53865 L .53042 .54956 L p F P
0 g
s
.699 .575 .713 r
.5483 .53305 m .54146 .53865 L .55003 .53834 L closepath p F P
0 g
s
.701 .592 .73 r
.54146 .53865 m .5483 .53305 L .54529 .52494 L p F P
0 g
s
.713 .6 .728 r
.50286 .53548 m .50386 .53843 L p .52254 .52536 L F P
0 g
s
.723 .593 .71 r
.50286 .53548 m .50022 .53818 L .50386 .53843 L closepath p F P
0 g
s
.725 .575 .686 r
.49137 .54917 m .5072 .55027 L .50386 .53843 L p F P
0 g
s
.725 .575 .686 r
.50386 .53843 m .50022 .53818 L .49137 .54917 L p F P
0 g
s
.689 .581 .729 r
.55003 .53834 m .56808 .53693 L p .56707 .52336 L F P
0 g
s
.689 .581 .729 r
.5483 .53305 m .55003 .53834 L p .56707 .52336 L F P
0 g
s
.687 .547 .69 r
.56808 .53693 m .55003 .53834 L .55313 .54989 L p F P
0 g
s
.698 .554 .688 r
.5307 .55068 m .55313 .54989 L .55003 .53834 L p F P
0 g
s
.698 .554 .688 r
.53042 .54956 m .5307 .55068 L p .55003 .53834 L F P
0 g
s
.713 .6 .728 r
.52254 .52536 m .51528 .52514 L .50286 .53548 L p F P
0 g
s
.715 .603 .73 r
.51528 .52514 m .49862 .52449 L .50286 .53548 L closepath p F P
0 g
s
.726 .607 .724 r
.50022 .53818 m .50286 .53548 L .49862 .52449 L p F P
0 g
s
.689 .581 .729 r
.56707 .52336 m .56214 .52377 L .5483 .53305 L p F P
0 g
s
.692 .587 .733 r
.56214 .52377 m .54529 .52494 L .5483 .53305 L closepath p F P
0 g
s
.708 .553 .676 r
.53042 .54956 m .5295 .55067 L .5307 .55068 L closepath p F P
0 g
s
.727 .586 .697 r
.48239 .54845 m .49137 .54917 L .50022 .53818 L p F P
0 g
s
.727 .586 .697 r
.48008 .54029 m .48239 .54845 L p .50022 .53818 L F P
0 g
s
.727 .586 .697 r
.50022 .53818 m .48315 .53676 L .48008 .54029 L p F P
0 g
s
.726 .607 .724 r
.48315 .53676 m .50022 .53818 L p .49862 .52449 L F P
0 g
s
.695 .525 .653 r
.55316 .55003 m .55313 .54989 L .5307 .55068 L p F P
0 g
s
.695 .525 .653 r
.54566 .56051 m .55316 .55003 L p .5307 .55068 L F P
0 g
s
.695 .525 .653 r
.5307 .55068 m .53265 .56096 L .54566 .56051 L p F P
0 g
s
.707 .533 .651 r
.52303 .56091 m .53265 .56096 L .5307 .55068 L p F P
0 g
s
.707 .533 .651 r
.5307 .55068 m .5295 .55067 L .52303 .56091 L p F P
0 g
s
.71 .542 .659 r
.50923 .56069 m .52303 .56091 L .5295 .55067 L p F P
0 g
s
.71 .542 .659 r
.50769 .55255 m .50923 .56069 L p .5295 .55067 L F P
0 g
s
.71 .542 .659 r
.5295 .55067 m .50919 .55033 L .50769 .55255 L p F P
0 g
s
.703 .611 .751 r
.52073 .52115 m .52254 .52536 L .53656 .52516 L p F P
0 g
s
.712 .615 .748 r
.52073 .52115 m .51528 .52514 L .52254 .52536 L closepath p F P
0 g
s
.701 .607 .748 r
.54347 .52057 m .53656 .52516 L .54529 .52494 L closepath p F P
0 g
s
.703 .611 .751 r
.53656 .52516 m .54347 .52057 L p .52073 .52115 L F P
0 g
s
.713 .617 .748 r
.51528 .52514 m .52073 .52115 L p .49799 .52304 L F P
0 g
s
.713 .617 .748 r
.49799 .52304 m .49862 .52449 L .51528 .52514 L p F P
0 g
s
.713 .546 .661 r
.50919 .55033 m .5072 .55027 L .50769 .55255 L closepath p F P
0 g
s
.725 .551 .654 r
.50334 .56036 m .50769 .55255 L .5072 .55027 L p F P
0 g
s
.725 .551 .654 r
.4856 .55917 m .50334 .56036 L p .5072 .55027 L F P
0 g
s
.725 .551 .654 r
.5072 .55027 m .49137 .54917 L .4856 .55917 L p F P
0 g
s
.693 .603 .751 r
.54347 .52057 m .54529 .52494 L .56214 .52377 L p F P
0 g
s
.687 .547 .69 r
.55313 .54989 m .5533 .54987 L .56808 .53693 L p F P
0 g
s
.684 .523 .663 r
.5533 .54987 m .55313 .54989 L .55316 .55003 L closepath p F P
0 g
s
.684 .542 .687 r
.5533 .54987 m .57462 .54799 L .57165 .53661 L p F P
0 g
s
.684 .542 .687 r
.57165 .53661 m .56808 .53693 L .5533 .54987 L p F P
0 g
s
.68 .518 .66 r
.57462 .54799 m .5533 .54987 L .55316 .55003 L p F P
0 g
s
.721 .544 .65 r
.50769 .55255 m .50334 .56036 L .50923 .56069 L closepath p F P
0 g
s
.68 .518 .66 r
.55316 .55003 m .55503 .56009 L p .57462 .54799 L F P
0 g
s
.692 .521 .651 r
.55316 .55003 m .54566 .56051 L .55503 .56009 L closepath p F P
0 g
s
.703 .611 .751 r
.54347 .52057 m .53865 .51042 L .52073 .52115 L p F P
0 g
s
.701 .649 .794 r
.52073 .52115 m .53865 .51042 L .53706 .5075 L p F P
0 g
s
.701 .649 .794 r
.51587 .51116 m .52073 .52115 L p .53706 .5075 L F P
0 g
s
.713 .617 .748 r
.52073 .52115 m .51587 .51116 L .49799 .52304 L p F P
0 g
s
.723 .621 .744 r
.49799 .52304 m .49645 .5243 L .49862 .52449 L closepath p F P
0 g
s
.726 .607 .724 r
.49862 .52449 m .49645 .5243 L .48315 .53676 L p F P
0 g
s
.686 .562 .709 r
.57107 .53472 m .56808 .53693 L .57165 .53661 L closepath p F P
0 g
s
.689 .581 .729 r
.56808 .53693 m .57107 .53472 L .56707 .52336 L p F P
0 g
s
.723 .635 .759 r
.49645 .5243 m .49799 .52304 L .49309 .5129 L p F P
0 g
s
.723 .635 .759 r
.49309 .5129 m .48008 .52262 L .49645 .5243 L p F P
0 g
s
.726 .62 .739 r
.47883 .53635 m .48315 .53676 L .49645 .5243 L p F P
0 g
s
.726 .62 .739 r
.47521 .5268 m .47883 .53635 L p .49645 .5243 L F P
0 g
s
.726 .62 .739 r
.49645 .5243 m .48008 .52262 L .47521 .5268 L p F P
0 g
s
.711 .653 .79 r
.49799 .52304 m .51587 .51116 L .51381 .50745 L p F P
0 g
s
.711 .653 .79 r
.49309 .5129 m .49799 .52304 L p .51381 .50745 L F P
0 g
s
.693 .603 .751 r
.56624 .52127 m .56144 .51062 L .54347 .52057 L p F P
0 g
s
.693 .603 .751 r
.56214 .52377 m .56624 .52127 L p .54347 .52057 L F P
0 g
s
.692 .64 .793 r
.54347 .52057 m .56144 .51062 L .55914 .5062 L p F P
0 g
s
.692 .64 .793 r
.53865 .51042 m .54347 .52057 L p .55914 .5062 L F P
0 g
s
.729 .589 .699 r
.48315 .53676 m .47883 .53635 L .48008 .54029 L closepath p F P
0 g
s
.675 .556 .712 r
.59241 .5338 m .58907 .52367 L .57107 .53472 L p F P
0 g
s
.675 .556 .712 r
.57107 .53472 m .57165 .53661 L .59241 .5338 L p F P
0 g
s
.681 .574 .729 r
.56707 .52336 m .57107 .53472 L .58907 .52367 L p F P
0 g
s
.673 .535 .689 r
.59394 .53937 m .59241 .5338 L .57165 .53661 L p F P
0 g
s
.673 .535 .689 r
.58453 .54668 m .59394 .53937 L p .57165 .53661 L F P
0 g
s
.673 .535 .689 r
.57165 .53661 m .57462 .54799 L .58453 .54668 L p F P
0 g
s
.728 .554 .656 r
.48458 .55908 m .4856 .55917 L .49137 .54917 L p F P
0 g
s
.728 .554 .656 r
.49137 .54917 m .48239 .54845 L .48458 .55908 L p F P
0 g
s
.69 .596 .745 r
.56624 .52127 m .56214 .52377 L .56707 .52336 L closepath p F P
0 g
s
.738 .611 .717 r
.47521 .5268 m .46769 .53479 L .47883 .53635 L closepath p F P
0 g
s
.741 .592 .69 r
.47492 .54754 m .48008 .54029 L .47883 .53635 L p F P
0 g
s
.741 .592 .69 r
.4597 .5455 m .47492 .54754 L p .47883 .53635 L F P
0 g
s
.741 .592 .69 r
.47883 .53635 m .46769 .53479 L .4597 .5455 L p F P
0 g
s
.738 .583 .682 r
.48008 .54029 m .47492 .54754 L .48239 .54845 L closepath p F P
0 g
s
.681 .591 .748 r
.56624 .52127 m .56707 .52336 L .58795 .52067 L p F P
0 g
s
.681 .574 .729 r
.58907 .52367 m .58795 .52067 L .56707 .52336 L p F P
0 g
s
.739 .562 .653 r
.46983 .55731 m .48458 .55908 L .48239 .54845 L p F P
0 g
s
.739 .562 .653 r
.48239 .54845 m .47492 .54754 L .46983 .55731 L p F P
0 g
s
.691 .496 .619 r
.54566 .56051 m .53265 .56096 L .53371 .57029 L p F P
0 g
s
.704 .506 .618 r
.51953 .57022 m .53371 .57029 L .53265 .56096 L p F P
0 g
s
.704 .506 .618 r
.53265 .56096 m .52303 .56091 L .51953 .57022 L p F P
0 g
s
.681 .591 .748 r
.58795 .52067 m .58428 .51191 L .56624 .52127 L p F P
0 g
s
.683 .627 .787 r
.56624 .52127 m .58428 .51191 L .58034 .50381 L p F P
0 g
s
.683 .627 .787 r
.56144 .51062 m .56624 .52127 L p .58034 .50381 L F P
0 g
s
.707 .51 .619 r
.51029 .57007 m .51953 .57022 L .52303 .56091 L p F P
0 g
s
.707 .51 .619 r
.52303 .56091 m .50923 .56069 L .51029 .57007 L p F P
0 g
s
.72 .519 .617 r
.50026 .56952 m .51029 .57007 L .50923 .56069 L p F P
0 g
s
.72 .519 .617 r
.50923 .56069 m .50334 .56036 L .50026 .56952 L p F P
0 g
s
.727 .621 .74 r
.48008 .52262 m .47309 .52188 L .47521 .5268 L closepath p F P
0 g
s
.74 .623 .729 r
.46769 .53479 m .47521 .5268 L .47309 .52188 L p F P
0 g
s
.667 .507 .658 r
.58453 .54668 m .57462 .54799 L .576 .55506 L closepath p F P
0 g
s
.68 .518 .66 r
.57324 .55851 m .576 .55506 L .57462 .54799 L p F P
0 g
s
.68 .518 .66 r
.55503 .56009 m .57324 .55851 L p .57462 .54799 L F P
0 g
s
.688 .493 .618 r
.55503 .56009 m .54566 .56051 L .54157 .57002 L p F P
0 g
s
.691 .496 .619 r
.53371 .57029 m .54157 .57002 L .54566 .56051 L p F P
0 g
s
.722 .654 .781 r
.48008 .52262 m .49309 .5129 L .48921 .50589 L p F P
0 g
s
.722 .654 .781 r
.47309 .52188 m .48008 .52262 L p .48921 .50589 L F P
0 g
s
.724 .525 .621 r
.48566 .56854 m .50026 .56952 L .50334 .56036 L p F P
0 g
s
.724 .525 .621 r
.48485 .56126 m .48566 .56854 L p .50334 .56036 L F P
0 g
s
.724 .525 .621 r
.50334 .56036 m .4856 .55917 L .48485 .56126 L p F P
0 g
s
.742 .569 .659 r
.45829 .55578 m .46983 .55731 L .47492 .54754 L p F P
0 g
s
.742 .569 .659 r
.45714 .55016 m .45829 .55578 L p .47492 .54754 L F P
0 g
s
.742 .569 .659 r
.47492 .54754 m .4597 .5455 L .45714 .55016 L p F P
0 g
s
.674 .483 .619 r
.57324 .55851 m .55503 .56009 L .55609 .56937 L p F P
0 g
s
.688 .493 .618 r
.54157 .57002 m .55609 .56937 L .55503 .56009 L p F P
0 g
s
.74 .623 .729 r
.45286 .53259 m .46769 .53479 L p .47309 .52188 L F P
0 g
s
.742 .602 .702 r
.45594 .54494 m .4597 .5455 L .46769 .53479 L p F P
0 g
s
.742 .602 .702 r
.45232 .53325 m .45594 .54494 L p .46769 .53479 L F P
0 g
s
.742 .602 .702 r
.46769 .53479 m .45286 .53259 L .45232 .53325 L p F P
0 g
s
.722 .654 .781 r
.47028 .51595 m .47309 .52188 L p .48921 .50589 L F P
0 g
s
.735 .638 .751 r
.47028 .51595 m .46488 .52055 L .47309 .52188 L closepath p F P
0 g
s
.74 .623 .729 r
.47309 .52188 m .46488 .52055 L .45286 .53259 L p F P
0 g
s
.701 .649 .794 r
.53706 .5075 m .52268 .50751 L .51587 .51116 L p F P
0 g
s
.702 .651 .796 r
.52268 .50751 m .51381 .50745 L .51587 .51116 L closepath p F P
0 g
s
.669 .527 .682 r
.59394 .53937 m .58453 .54668 L .59536 .54516 L closepath p F P
0 g
s
.664 .502 .655 r
.59536 .54516 m .58453 .54668 L .576 .55506 L p F P
0 g
s
.711 .653 .79 r
.51381 .50745 m .50347 .50677 L .49309 .5129 L p F P
0 g
s
.71 .652 .789 r
.50347 .50677 m .48921 .50589 L .49309 .5129 L closepath p F P
0 g
s
.692 .64 .793 r
.55914 .5062 m .5453 .50711 L .53865 .51042 L p F P
0 g
s
.694 .646 .798 r
.5453 .50711 m .53706 .5075 L .53865 .51042 L closepath p F P
0 g
s
.727 .529 .623 r
.4856 .55917 m .48458 .55908 L .48485 .56126 L closepath p F P
0 g
s
.739 .536 .619 r
.48276 .56824 m .48485 .56126 L .48458 .55908 L p F P
0 g
s
.739 .536 .619 r
.46702 .56637 m .48276 .56824 L p .48458 .55908 L F P
0 g
s
.739 .536 .619 r
.48458 .55908 m .46983 .55731 L .46702 .56637 L p F P
0 g
s
.662 .534 .698 r
.60746 .53107 m .59241 .5338 L .59394 .53937 L closepath p F P
0 g
s
.667 .569 .735 r
.59241 .5338 m .60746 .53107 L p .60809 .51701 L F P
0 g
s
.667 .569 .735 r
.58907 .52367 m .59241 .5338 L p .60809 .51701 L F P
0 g
s
.664 .502 .655 r
.576 .55506 m .57655 .5582 L p .59536 .54516 L F P
0 g
s
.676 .506 .647 r
.576 .55506 m .57324 .55851 L .57655 .5582 L closepath p F P
0 g
s
.671 .578 .743 r
.59873 .51878 m .58795 .52067 L .58907 .52367 L closepath p F P
0 g
s
.667 .569 .735 r
.60809 .51701 m .59873 .51878 L .58907 .52367 L p F P
0 g
s
.658 .527 .692 r
.59394 .53937 m .59536 .54516 L p .6125 .53011 L F P
0 g
s
.658 .527 .692 r
.6125 .53011 m .60746 .53107 L .59394 .53937 L p F P
0 g
s
.673 .596 .76 r
.58428 .51191 m .58795 .52067 L .59873 .51878 L p F P
0 g
s
.671 .479 .617 r
.57655 .5582 m .57324 .55851 L .56829 .56832 L p F P
0 g
s
.674 .483 .619 r
.55609 .56937 m .56829 .56832 L .57324 .55851 L p F P
0 g
s
.733 .648 .764 r
.46488 .52055 m .47028 .51595 L .4653 .50664 L p F P
0 g
s
.733 .648 .764 r
.4653 .50664 m .45064 .51812 L .46488 .52055 L p F P
0 g
s
.738 .634 .743 r
.45205 .53246 m .45286 .53259 L .46488 .52055 L p F P
0 g
s
.738 .634 .743 r
.44739 .52109 m .45205 .53246 L p .46488 .52055 L F P
0 g
s
.738 .634 .743 r
.46488 .52055 m .45064 .51812 L .44739 .52109 L p F P
0 g
s
.683 .627 .787 r
.58034 .50381 m .5743 .50458 L .56144 .51062 L p F P
0 g
s
.686 .637 .794 r
.5743 .50458 m .55914 .5062 L .56144 .51062 L closepath p F P
0 g
s
.735 .53 .616 r
.48485 .56126 m .48276 .56824 L .48566 .56854 L closepath p F P
0 g
s
.722 .654 .781 r
.48921 .50589 m .48591 .50546 L .47028 .51595 L p F P
0 g
s
.72 .648 .777 r
.48591 .50546 m .47028 .51595 L .4653 .50664 L p F P
0 g
s
.664 .502 .655 r
.57655 .5582 m .59727 .55531 L .59536 .54516 L p F P
0 g
s
.657 .469 .618 r
.59838 .56457 m .59727 .55531 L .57655 .5582 L p F P
0 g
s
.657 .469 .618 r
.57655 .5582 m .57761 .56744 L .59838 .56457 L p F P
0 g
s
.671 .479 .617 r
.56829 .56832 m .57761 .56744 L .57655 .5582 L p F P
0 g
s
.746 .573 .661 r
.4597 .5455 m .45594 .54494 L .45714 .55016 L closepath p F P
0 g
s
.699 .657 .805 r
.53381 .50184 m .52268 .50751 L .53706 .5075 L closepath p F P
0 g
s
.7 .658 .806 r
.52268 .50751 m .53381 .50184 L p .51098 .50261 L F P
0 g
s
.7 .658 .806 r
.51098 .50261 m .51381 .50745 L .52268 .50751 L p F P
0 g
s
.693 .654 .807 r
.53381 .50184 m .53706 .5075 L .5453 .50711 L p F P
0 g
s
.708 .662 .802 r
.51098 .50261 m .50347 .50677 L .51381 .50745 L closepath p F P
0 g
s
.744 .606 .704 r
.45286 .53259 m .45205 .53246 L .45232 .53325 L closepath p F P
0 g
s
.658 .527 .692 r
.59536 .54516 m .6154 .5414 L .6125 .53011 L p F P
0 g
s
.651 .492 .655 r
.61708 .55011 m .6154 .5414 L .59536 .54516 L p F P
0 g
s
.651 .492 .655 r
.61476 .55206 m .61708 .55011 L p .59536 .54516 L F P
0 g
s
.651 .492 .655 r
.59536 .54516 m .59727 .55531 L .61476 .55206 L p F P
0 g
s
.754 .6 .686 r
.45232 .53325 m .44577 .54301 L .45594 .54494 L closepath p F P
0 g
s
.758 .608 .692 r
.44577 .54301 m .45232 .53325 L .45205 .53246 L p F P
0 g
s
.752 .627 .72 r
.44739 .52109 m .4397 .52982 L .45205 .53246 L closepath p F P
0 g
s
.758 .608 .692 r
.43246 .54028 m .44577 .54301 L p .45205 .53246 L F P
0 g
s
.758 .608 .692 r
.45205 .53246 m .4397 .52982 L .43246 .54028 L p F P
0 g
s
.691 .648 .802 r
.55665 .50168 m .5453 .50711 L .55914 .5062 L closepath p F P
0 g
s
.693 .654 .807 r
.5453 .50711 m .55665 .50168 L p .53381 .50184 L F P
0 g
s
.685 .464 .581 r
.54157 .57002 m .53371 .57029 L .53398 .57879 L p F P
0 g
s
.699 .476 .581 r
.51866 .57871 m .53398 .57879 L .53371 .57029 L p F P
0 g
s
.699 .476 .581 r
.53371 .57029 m .51953 .57022 L .51866 .57871 L p F P
0 g
s
.757 .579 .655 r
.45483 .5552 m .45714 .55016 L .45594 .54494 L p F P
0 g
s
.757 .579 .655 r
.44112 .55263 m .45483 .5552 L p .45594 .54494 L F P
0 g
s
.757 .579 .655 r
.45594 .54494 m .44577 .54301 L .44112 .55263 L p F P
0 g
s
.703 .479 .581 r
.51052 .57857 m .51866 .57871 L .51953 .57022 L p F P
0 g
s
.703 .479 .581 r
.51953 .57022 m .51029 .57007 L .51052 .57857 L p F P
0 g
s
.717 .49 .581 r
.49946 .57797 m .51052 .57857 L .51029 .57007 L p F P
0 g
s
.717 .49 .581 r
.51029 .57007 m .50026 .56952 L .49946 .57797 L p F P
0 g
s
.682 .461 .581 r
.55609 .56937 m .54157 .57002 L .54061 .57855 L p F P
0 g
s
.685 .464 .581 r
.53398 .57879 m .54061 .57855 L .54157 .57002 L p F P
0 g
s
.708 .659 .799 r
.50347 .50677 m .51098 .50261 L p .48816 .50408 L F P
0 g
s
.708 .659 .799 r
.48816 .50408 m .48921 .50589 L .50347 .50677 L p F P
0 g
s
.743 .54 .62 r
.45943 .56536 m .46702 .56637 L .46983 .55731 L p F P
0 g
s
.743 .54 .62 r
.46983 .55731 m .45829 .55578 L .45943 .56536 L p F P
0 g
s
.673 .596 .76 r
.6072 .51471 m .60244 .50385 L .58428 .51191 L p F P
0 g
s
.673 .596 .76 r
.59873 .51878 m .6072 .51471 L p .58428 .51191 L F P
0 g
s
.678 .622 .786 r
.58034 .50381 m .58428 .51191 L .60244 .50385 L p F P
0 g
s
.721 .494 .581 r
.48583 .57706 m .49946 .57797 L .50026 .56952 L p F P
0 g
s
.721 .494 .581 r
.50026 .56952 m .48566 .56854 L .48583 .57706 L p F P
0 g
s
.753 .57 .649 r
.45714 .55016 m .45483 .5552 L .45829 .55578 L closepath p F P
0 g
s
.686 .646 .805 r
.55665 .50168 m .55914 .5062 L .5743 .50458 L p F P
0 g
s
.669 .582 .748 r
.6072 .51471 m .59873 .51878 L .60809 .51701 L closepath p F P
0 g
s
.666 .449 .581 r
.56829 .56832 m .55609 .56937 L .55641 .57786 L p F P
0 g
s
.682 .461 .581 r
.54061 .57855 m .55641 .57786 L .55609 .56937 L p F P
0 g
s
.718 .663 .794 r
.48816 .50408 m .48591 .50546 L .48921 .50589 L closepath p F P
0 g
s
.662 .545 .711 r
.61203 .52854 m .60746 .53107 L .6125 .53011 L closepath p F P
0 g
s
.667 .569 .735 r
.60746 .53107 m .61203 .52854 L .60809 .51701 L p F P
0 g
s
.739 .635 .744 r
.45064 .51812 m .4456 .51723 L .44739 .52109 L closepath p F P
0 g
s
.755 .637 .73 r
.4397 .52982 m .44739 .52109 L .4456 .51723 L p F P
0 g
s
.733 .667 .785 r
.45064 .51812 m .4653 .50664 L .46269 .50226 L p F P
0 g
s
.733 .667 .785 r
.4456 .51723 m .45064 .51812 L p .46269 .50226 L F P
0 g
s
.714 .676 .812 r
.48591 .50546 m .48816 .50408 L .48318 .49637 L p F P
0 g
s
.714 .676 .812 r
.48318 .49637 m .47084 .5033 L .48591 .50546 L p F P
0 g
s
.72 .648 .777 r
.4653 .50664 m .47084 .5033 L .48591 .50546 L p F P
0 g
s
.733 .504 .58 r
.48201 .57666 m .48583 .57706 L .48566 .56854 L p F P
0 g
s
.733 .504 .58 r
.48566 .56854 m .48276 .56824 L .48201 .57666 L p F P
0 g
s
.7 .658 .806 r
.53381 .50184 m .52895 .49443 L .51098 .50261 L p F P
0 g
s
.688 .704 .86 r
.52895 .49443 m .51098 .50261 L .50607 .49515 L p F P
0 g
s
.708 .659 .799 r
.51098 .50261 m .50607 .49515 L .48816 .50408 L p F P
0 g
s
.754 .548 .617 r
.45227 .56416 m .45943 .56536 L .45829 .55578 L p F P
0 g
s
.754 .548 .617 r
.45829 .55578 m .45483 .5552 L .45227 .56416 L p F P
0 g
s
.696 .703 .852 r
.50607 .49515 m .48816 .50408 L .48318 .49637 L p F P
0 g
s
.761 .585 .659 r
.42987 .55036 m .44112 .55263 L .44577 .54301 L p F P
0 g
s
.761 .585 .659 r
.42913 .54694 m .42987 .55036 L p .44577 .54301 L F P
0 g
s
.761 .585 .659 r
.44577 .54301 m .43246 .54028 L .42913 .54694 L p F P
0 g
s
.663 .447 .58 r
.57761 .56744 m .56829 .56832 L .56718 .57693 L p F P
0 g
s
.666 .449 .581 r
.55641 .57786 m .56718 .57693 L .56829 .56832 L p F P
0 g
s
.738 .508 .581 r
.46621 .57481 m .48201 .57666 L .48276 .56824 L p F P
0 g
s
.738 .508 .581 r
.48276 .56824 m .46702 .56637 L .46621 .57481 L p F P
0 g
s
.693 .654 .807 r
.55665 .50168 m .55185 .49407 L .53381 .50184 L p F P
0 g
s
.683 .7 .859 r
.55185 .49407 m .53381 .50184 L .52895 .49443 L p F P
0 g
s
.651 .539 .714 r
.63188 .52543 m .63027 .52025 L .61203 .52854 L p F P
0 g
s
.651 .539 .714 r
.61203 .52854 m .6125 .53011 L .63188 .52543 L p F P
0 g
s
.657 .558 .731 r
.60809 .51701 m .61203 .52854 L .63027 .52025 L p F P
0 g
s
.645 .516 .691 r
.63483 .53678 m .63188 .52543 L .6125 .53011 L p F P
0 g
s
.645 .516 .691 r
.6125 .53011 m .6154 .5414 L .63483 .53678 L p F P
0 g
s
.641 .458 .62 r
.61476 .55206 m .59727 .55531 L .59838 .56457 L p F P
0 g
s
.683 .636 .796 r
.57952 .50222 m .5743 .50458 L .58034 .50381 L closepath p F P
0 g
s
.686 .646 .805 r
.5743 .50458 m .57952 .50222 L p .55665 .50168 L F P
0 g
s
.733 .667 .785 r
.44238 .51088 m .4456 .51723 L p .46269 .50226 L F P
0 g
s
.748 .651 .753 r
.44238 .51088 m .43756 .51529 L .4456 .51723 L closepath p F P
0 g
s
.755 .637 .73 r
.42679 .52694 m .4397 .52982 L p .4456 .51723 L F P
0 g
s
.755 .637 .73 r
.4456 .51723 m .43756 .51529 L .42679 .52694 L p F P
0 g
s
.759 .554 .619 r
.43851 .56161 m .45227 .56416 L .45483 .5552 L p F P
0 g
s
.759 .554 .619 r
.45483 .5552 m .44112 .55263 L .43851 .56161 L p F P
0 g
s
.758 .616 .701 r
.42721 .53913 m .43246 .54028 L .4397 .52982 L p F P
0 g
s
.758 .616 .701 r
.4243 .53029 m .42721 .53913 L p .4397 .52982 L F P
0 g
s
.758 .616 .701 r
.4397 .52982 m .42679 .52694 L .4243 .53029 L p F P
0 g
s
.66 .577 .751 r
.6072 .51471 m .60809 .51701 L .6275 .51234 L p F P
0 g
s
.657 .558 .731 r
.63027 .52025 m .6275 .51234 L .60809 .51701 L p F P
0 g
s
.717 .665 .798 r
.47084 .5033 m .46269 .50226 L .4653 .50664 L closepath p F P
0 g
s
.686 .646 .805 r
.57952 .50222 m .57476 .49413 L .55665 .50168 L p F P
0 g
s
.68 .688 .851 r
.57476 .49413 m .55665 .50168 L .55185 .49407 L p F P
0 g
s
.647 .434 .58 r
.59879 .57305 m .59838 .56457 L .57761 .56744 L p F P
0 g
s
.647 .434 .58 r
.57761 .56744 m .57798 .57592 L .59879 .57305 L p F P
0 g
s
.663 .447 .58 r
.56718 .57693 m .57798 .57592 L .57761 .56744 L p F P
0 g
s
.664 .606 .78 r
.62547 .50718 m .6072 .51471 L .60244 .50385 L p F P
0 g
s
.66 .577 .751 r
.6275 .51234 m .62547 .50718 L .6072 .51471 L p F P
0 g
s
.676 .633 .798 r
.57952 .50222 m .58034 .50381 L .60057 .50018 L p F P
0 g
s
.678 .622 .786 r
.60244 .50385 m .60057 .50018 L .58034 .50381 L p F P
0 g
s
.637 .484 .658 r
.63528 .53898 m .63483 .53678 L .6154 .5414 L p F P
0 g
s
.637 .484 .658 r
.6154 .5414 m .61708 .55011 L .63528 .53898 L p F P
0 g
s
.714 .671 .807 r
.47084 .5033 m .48318 .49637 L p .46028 .49841 L F P
0 g
s
.714 .671 .807 r
.46028 .49841 m .46269 .50226 L .47084 .5033 L p F P
0 g
s
.676 .633 .798 r
.60057 .50018 m .59771 .49485 L .57952 .50222 L p F P
0 g
s
.676 .669 .835 r
.59771 .49485 m .57952 .50222 L .57476 .49413 L p F P
0 g
s
.743 .512 .581 r
.45956 .57393 m .46621 .57481 L .46702 .56637 L p F P
0 g
s
.743 .512 .581 r
.46702 .56637 m .45943 .56536 L .45956 .57393 L p F P
0 g
s
.677 .428 .538 r
.54061 .57855 m .53398 .57879 L .53353 .58653 L p F P
0 g
s
.693 .442 .539 r
.52022 .58646 m .53353 .58653 L .53398 .57879 L p F P
0 g
s
.693 .442 .539 r
.53398 .57879 m .51866 .57871 L .52022 .58646 L p F P
0 g
s
.697 .444 .538 r
.50997 .58629 m .52022 .58646 L .51866 .57871 L p F P
0 g
s
.697 .444 .538 r
.51866 .57871 m .51052 .57857 L .50997 .58629 L p F P
0 g
s
.746 .66 .765 r
.43756 .51529 m .44238 .51088 L .43733 .50191 L p F P
0 g
s
.746 .66 .765 r
.43733 .50191 m .42525 .51217 L .43756 .51529 L p F P
0 g
s
.754 .646 .742 r
.4227 .52597 m .42679 .52694 L .43756 .51529 L p F P
0 g
s
.754 .646 .742 r
.41931 .51813 m .4227 .52597 L p .43756 .51529 L F P
0 g
s
.754 .646 .742 r
.43756 .51529 m .42525 .51217 L .41931 .51813 L p F P
0 g
s
.733 .667 .785 r
.46269 .50226 m .45643 .5009 L .44238 .51088 L p F P
0 g
s
.729 .659 .78 r
.45643 .5009 m .44238 .51088 L .43733 .50191 L p F P
0 g
s
.711 .457 .539 r
.50074 .5858 m .50997 .58629 L .51052 .57857 L p F P
0 g
s
.711 .457 .539 r
.51052 .57857 m .49946 .57797 L .50074 .5858 L p F P
0 g
s
.673 .426 .539 r
.55641 .57786 m .54061 .57855 L .54252 .58622 L p F P
0 g
s
.677 .428 .538 r
.53353 .58653 m .54252 .58622 L .54061 .57855 L p F P
0 g
s
.727 .676 .8 r
.46028 .49841 m .45643 .5009 L .46269 .50226 L closepath p F P
0 g
s
.764 .589 .661 r
.43246 .54028 m .42721 .53913 L .42913 .54694 L closepath p F P
0 g
s
.754 .522 .58 r
.45149 .57258 m .45956 .57393 L .45943 .56536 L p F P
0 g
s
.754 .522 .58 r
.45943 .56536 m .45227 .56416 L .45149 .57258 L p F P
0 g
s
.763 .558 .62 r
.43111 .56012 m .43851 .56161 L .44112 .55263 L p F P
0 g
s
.763 .558 .62 r
.44112 .55263 m .42987 .55036 L .43111 .56012 L p F P
0 g
s
.716 .46 .538 r
.48519 .58475 m .50074 .5858 L .49946 .57797 L p F P
0 g
s
.716 .46 .538 r
.49946 .57797 m .48583 .57706 L .48519 .58475 L p F P
0 g
s
.656 .412 .538 r
.56718 .57693 m .55641 .57786 L .55604 .58562 L p F P
0 g
s
.673 .426 .539 r
.54252 .58622 m .55604 .58562 L .55641 .57786 L p F P
0 g
s
.761 .62 .703 r
.42679 .52694 m .4227 .52597 L .4243 .53029 L closepath p F P
0 g
s
.664 .606 .78 r
.60244 .50385 m .62073 .49671 L .62547 .50718 L p F P
0 g
s
.67 .628 .799 r
.60057 .50018 m .60244 .50385 L .62073 .49671 L p F P
0 g
s
.647 .483 .648 r
.61708 .55011 m .61476 .55206 L .61734 .55157 L closepath p F P
0 g
s
.639 .455 .618 r
.61734 .55157 m .61476 .55206 L .60577 .5632 L p F P
0 g
s
.641 .458 .62 r
.59838 .56457 m .60577 .5632 L .61476 .55206 L p F P
0 g
s
.632 .473 .649 r
.63675 .5469 m .63528 .53898 L .61708 .55011 L p F P
0 g
s
.632 .473 .649 r
.61708 .55011 m .61734 .55157 L .63675 .5469 L p F P
0 g
s
.63 .421 .58 r
.60577 .5632 m .59838 .56457 L .59879 .57305 L p F P
0 g
s
.77 .614 .685 r
.4243 .53029 m .42003 .53724 L .42721 .53913 L closepath p F P
0 g
s
.776 .595 .655 r
.42788 .54988 m .42913 .54694 L .42721 .53913 L p F P
0 g
s
.776 .595 .655 r
.41576 .54674 m .42788 .54988 L p .42721 .53913 L F P
0 g
s
.776 .595 .655 r
.42721 .53913 m .42003 .53724 L .41576 .54674 L p F P
0 g
s
.775 .623 .692 r
.42003 .53724 m .4243 .53029 L .4227 .52597 L p F P
0 g
s
.729 .472 .539 r
.4831 .58454 m .48519 .58475 L .48583 .57706 L p F P
0 g
s
.729 .472 .539 r
.48583 .57706 m .48201 .57666 L .4831 .58454 L p F P
0 g
s
.722 .685 .814 r
.45643 .5009 m .46028 .49841 L .45522 .49103 L p F P
0 g
s
.722 .685 .814 r
.45522 .49103 m .44346 .49798 L .45643 .5009 L p F P
0 g
s
.729 .659 .78 r
.43733 .50191 m .44346 .49798 L .45643 .5009 L p F P
0 g
s
.623 .443 .618 r
.63791 .55615 m .63675 .5469 L .61734 .55157 L p F P
0 g
s
.623 .443 .618 r
.61734 .55157 m .61846 .56079 L .63791 .55615 L p F P
0 g
s
.639 .455 .618 r
.60577 .5632 m .61846 .56079 L .61734 .55157 L p F P
0 g
s
.654 .41 .538 r
.57798 .57592 m .56718 .57693 L .56961 .58446 L p F P
0 g
s
.656 .412 .538 r
.55604 .58562 m .56961 .58446 L .56718 .57693 L p F P
0 g
s
.696 .703 .852 r
.48318 .49637 m .50112 .48854 L .50607 .49515 L p F P
0 g
s
.683 .724 .88 r
.50112 .48854 m .48318 .49637 L .47817 .48945 L p F P
0 g
s
.714 .671 .807 r
.48318 .49637 m .47817 .48945 L .46028 .49841 L p F P
0 g
s
.688 .704 .86 r
.50607 .49515 m .52407 .48795 L .52895 .49443 L p F P
0 g
s
.675 .729 .89 r
.52407 .48795 m .50607 .49515 L .50112 .48854 L p F P
0 g
s
.76 .527 .58 r
.43769 .57004 m .45149 .57258 L .45227 .56416 L p F P
0 g
s
.76 .527 .58 r
.45227 .56416 m .43851 .56161 L .43769 .57004 L p F P
0 g
s
.768 .639 .718 r
.41931 .51813 m .41487 .52369 L .4227 .52597 L closepath p F P
0 g
s
.775 .623 .692 r
.40832 .53394 m .42003 .53724 L p .4227 .52597 L F P
0 g
s
.775 .623 .692 r
.4227 .52597 m .41487 .52369 L .40832 .53394 L p F P
0 g
s
.735 .476 .538 r
.46724 .58269 m .4831 .58454 L .48201 .57666 L p F P
0 g
s
.735 .476 .538 r
.48201 .57666 m .46621 .57481 L .46724 .58269 L p F P
0 g
s
.683 .7 .859 r
.52895 .49443 m .54703 .48749 L .55185 .49407 L p F P
0 g
s
.672 .728 .892 r
.54703 .48749 m .52895 .49443 L .52407 .48795 L p F P
0 g
s
.698 .715 .862 r
.47817 .48945 m .46028 .49841 L .45522 .49103 L p F P
0 g
s
.671 .639 .809 r
.59771 .49485 m .60057 .50018 L .6202 .49569 L p F P
0 g
s
.67 .628 .799 r
.62073 .49671 m .6202 .49569 L .60057 .50018 L p F P
0 g
s
.64 .535 .72 r
.65068 .51988 m .64868 .51351 L .63027 .52025 L p F P
0 g
s
.64 .535 .72 r
.63027 .52025 m .63188 .52543 L .65068 .51988 L p F P
0 g
s
.646 .556 .738 r
.6275 .51234 m .63027 .52025 L .64868 .51351 L p F P
0 g
s
.771 .586 .648 r
.42913 .54694 m .42788 .54988 L .42987 .55036 L closepath p F P
0 g
s
.632 .508 .694 r
.65365 .53126 m .65068 .51988 L .63188 .52543 L p F P
0 g
s
.632 .508 .694 r
.63188 .52543 m .63483 .53678 L .65365 .53126 L p F P
0 g
s
.68 .688 .851 r
.55185 .49407 m .57 .48719 L .57476 .49413 L p F P
0 g
s
.673 .719 .883 r
.57 .48719 m .55185 .49407 L .54703 .48749 L p F P
0 g
s
.635 .395 .537 r
.59857 .58085 m .59879 .57305 L .57798 .57592 L p F P
0 g
s
.635 .395 .537 r
.57798 .57592 m .57769 .58371 L .59857 .58085 L p F P
0 g
s
.654 .41 .538 r
.56961 .58446 m .57769 .58371 L .57798 .57592 L p F P
0 g
s
.628 .419 .579 r
.61846 .56079 m .60577 .5632 L .60377 .57214 L p F P
0 g
s
.63 .421 .58 r
.59879 .57305 m .60377 .57214 L .60577 .5632 L p F P
0 g
s
.65 .576 .758 r
.62547 .50718 m .6275 .51234 L .6463 .50676 L p F P
0 g
s
.646 .556 .738 r
.64868 .51351 m .6463 .50676 L .6275 .51234 L p F P
0 g
s
.774 .566 .618 r
.42549 .55879 m .43111 .56012 L .42987 .55036 L p F P
0 g
s
.774 .566 .618 r
.42987 .55036 m .42788 .54988 L .42549 .55879 L p F P
0 g
s
.747 .676 .782 r
.42525 .51217 m .43733 .50191 L .43364 .49601 L p F P
0 g
s
.747 .676 .782 r
.41518 .50961 m .42525 .51217 L p .43364 .49601 L F P
0 g
s
.754 .646 .742 r
.42525 .51217 m .41518 .50961 L .41931 .51813 L closepath p F P
0 g
s
.77 .65 .729 r
.41487 .52369 m .41931 .51813 L .41518 .50961 L p F P
0 g
s
.78 .601 .658 r
.40396 .54347 m .41576 .54674 L .42003 .53724 L p F P
0 g
s
.78 .601 .658 r
.42003 .53724 m .40832 .53394 L .40396 .54347 L p F P
0 g
s
.676 .669 .835 r
.57476 .49413 m .593 .48726 L .59771 .49485 L p F P
0 g
s
.674 .702 .867 r
.593 .48726 m .57476 .49413 L .57 .48719 L p F P
0 g
s
.779 .572 .619 r
.41331 .55567 m .42549 .55879 L .42788 .54988 L p F P
0 g
s
.779 .572 .619 r
.42788 .54988 m .41576 .54674 L .41331 .55567 L p F P
0 g
s
.726 .673 .799 r
.44346 .49798 m .43364 .49601 L .43733 .50191 L closepath p F P
0 g
s
.65 .576 .758 r
.6463 .50676 m .64388 .50064 L .62547 .50718 L p F P
0 g
s
.657 .604 .784 r
.64388 .50064 m .62547 .50718 L .62073 .49671 L p F P
0 g
s
.622 .477 .664 r
.65368 .53141 m .65365 .53126 L .63483 .53678 L p F P
0 g
s
.622 .477 .664 r
.63483 .53678 m .63528 .53898 L .65368 .53141 L p F P
0 g
s
.74 .48 .536 r
.45879 .58157 m .46724 .58269 L .46621 .57481 L p F P
0 g
s
.74 .48 .536 r
.46621 .57481 m .45956 .57393 L .45879 .58157 L p F P
0 g
s
.777 .629 .696 r
.39685 .53052 m .40832 .53394 L .41487 .52369 L p F P
0 g
s
.777 .629 .696 r
.41487 .52369 m .40359 .52021 L .39685 .53052 L p F P
0 g
s
.77 .65 .729 r
.40359 .52021 m .41487 .52369 L p .41518 .50961 L F P
0 g
s
.618 .466 .654 r
.65559 .54139 m .65368 .53141 L .63528 .53898 L p F P
0 g
s
.618 .466 .654 r
.63528 .53898 m .63675 .5469 L .65559 .54139 L p F P
0 g
s
.765 .531 .58 r
.43122 .56873 m .43769 .57004 L .43851 .56161 L p F P
0 g
s
.765 .531 .58 r
.43851 .56161 m .43111 .56012 L .43122 .56873 L p F P
0 g
s
.722 .679 .807 r
.44346 .49798 m .45522 .49103 L p .43222 .49382 L F P
0 g
s
.722 .679 .807 r
.43222 .49382 m .43364 .49601 L .44346 .49798 L p F P
0 g
s
.671 .639 .809 r
.6202 .49569 m .61604 .48809 L .59771 .49485 L p F P
0 g
s
.672 .676 .845 r
.61604 .48809 m .59771 .49485 L .593 .48726 L p F P
0 g
s
.752 .491 .537 r
.45236 .58051 m .45879 .58157 L .45956 .57393 L p F P
0 g
s
.752 .491 .537 r
.45956 .57393 m .45149 .57258 L .45236 .58051 L p F P
0 g
s
.665 .386 .488 r
.54252 .58622 m .53353 .58653 L .53239 .59358 L p F P
0 g
s
.683 .403 .491 r
.52407 .59354 m .53239 .59358 L .53353 .58653 L p F P
0 g
s
.683 .403 .491 r
.53353 .58653 m .52022 .58646 L .52407 .59354 L p F P
0 g
s
.687 .404 .488 r
.5087 .59328 m .52407 .59354 L .52022 .58646 L p F P
0 g
s
.687 .404 .488 r
.52022 .58646 m .50997 .58629 L .5087 .59328 L p F P
0 g
s
.704 .42 .491 r
.50402 .59304 m .5087 .59328 L .50997 .58629 L p F P
0 g
s
.704 .42 .491 r
.50997 .58629 m .50074 .5858 L .50402 .59304 L p F P
0 g
s
.61 .405 .579 r
.63842 .56465 m .63791 .55615 L .61846 .56079 L p F P
0 g
s
.61 .405 .579 r
.61846 .56079 m .61891 .56928 L .63842 .56465 L p F P
0 g
s
.628 .419 .579 r
.60377 .57214 m .61891 .56928 L .61846 .56079 L p F P
0 g
s
.662 .386 .491 r
.55604 .58562 m .54252 .58622 L .54716 .59307 L p F P
0 g
s
.665 .386 .488 r
.53239 .59358 m .54716 .59307 L .54252 .58622 L p F P
0 g
s
.747 .676 .782 r
.41425 .50784 m .41518 .50961 L p .43364 .49601 L F P
0 g
s
.763 .66 .749 r
.41425 .50784 m .41315 .50895 L .41518 .50961 L closepath p F P
0 g
s
.77 .65 .729 r
.41518 .50961 m .41315 .50895 L .40359 .52021 L p F P
0 g
s
.708 .42 .485 r
.48613 .59184 m .50402 .59304 L .50074 .5858 L p F P
0 g
s
.708 .42 .485 r
.48449 .58803 m .48613 .59184 L p .50074 .5858 L F P
0 g
s
.708 .42 .485 r
.50074 .5858 m .48519 .58475 L .48449 .58803 L p F P
0 g
s
.616 .379 .535 r
.60377 .57214 m .59879 .57305 L .59857 .58085 L p F P
0 g
s
.643 .368 .487 r
.56961 .58446 m .55604 .58562 L .55503 .59272 L p F P
0 g
s
.662 .386 .491 r
.54716 .59307 m .55503 .59272 L .55604 .58562 L p F P
0 g
s
.775 .54 .579 r
.42469 .56721 m .43122 .56873 L .43111 .56012 L p F P
0 g
s
.775 .54 .579 r
.43111 .56012 m .42549 .55879 L .42469 .56721 L p F P
0 g
s
.747 .676 .782 r
.43364 .49601 m .43049 .49504 L .41425 .50784 L p F P
0 g
s
.741 .664 .774 r
.43049 .49504 m .41425 .50784 L .40911 .49889 L p F P
0 g
s
.763 .67 .76 r
.41315 .50895 m .41425 .50784 L .40911 .49889 L p F P
0 g
s
.763 .67 .76 r
.40911 .49889 m .40246 .50522 L .41315 .50895 L p F P
0 g
s
.772 .658 .736 r
.39248 .51663 m .40359 .52021 L .41315 .50895 L p F P
0 g
s
.772 .658 .736 r
.41315 .50895 m .40246 .50522 L .39248 .51663 L p F P
0 g
s
.758 .496 .536 r
.43851 .57797 m .45236 .58051 L .45149 .57258 L p F P
0 g
s
.758 .496 .536 r
.45149 .57258 m .43769 .57004 L .43851 .57797 L p F P
0 g
s
.657 .604 .784 r
.62073 .49671 m .63917 .49027 L .64388 .50064 L p F P
0 g
s
.663 .631 .808 r
.6202 .49569 m .62073 .49671 L .63917 .49027 L p F P
0 g
s
.739 .684 .798 r
.43222 .49382 m .43049 .49504 L .43364 .49601 L closepath p F P
0 g
s
.605 .431 .619 r
.6568 .55065 m .65559 .54139 L .63675 .5469 L p F P
0 g
s
.605 .431 .619 r
.63675 .5469 m .63791 .55615 L .6568 .55065 L p F P
0 g
s
.683 .724 .88 r
.47817 .48945 m .49613 .48267 L .50112 .48854 L p F P
0 g
s
.665 .743 .908 r
.49613 .48267 m .47817 .48945 L .47312 .4832 L p F P
0 g
s
.698 .715 .862 r
.45522 .49103 m .47312 .4832 L .47817 .48945 L p F P
0 g
s
.784 .577 .62 r
.40147 .5524 m .41331 .55567 L .41576 .54674 L p F P
0 g
s
.784 .577 .62 r
.41576 .54674 m .40396 .54347 L .40147 .5524 L p F P
0 g
s
.614 .378 .536 r
.61891 .56928 m .60377 .57214 L .6082 .57908 L p F P
0 g
s
.616 .379 .535 r
.59857 .58085 m .6082 .57908 L .60377 .57214 L p F P
0 g
s
.782 .609 .665 r
.39824 .54177 m .40396 .54347 L .40832 .53394 L p F P
0 g
s
.782 .609 .665 r
.39585 .53257 m .39824 .54177 L p .40832 .53394 L F P
0 g
s
.782 .609 .665 r
.40832 .53394 m .39685 .53052 L .39585 .53257 L p F P
0 g
s
.683 .731 .887 r
.47312 .4832 m .45522 .49103 L .45011 .48427 L p F P
0 g
s
.722 .679 .807 r
.45522 .49103 m .45011 .48427 L .43222 .49382 L p F P
0 g
s
.665 .642 .817 r
.61604 .48809 m .6202 .49569 L .6391 .49014 L p F P
0 g
s
.663 .631 .808 r
.63917 .49027 m .6391 .49014 L .6202 .49569 L p F P
0 g
s
.675 .729 .89 r
.50112 .48854 m .51915 .48229 L .52407 .48795 L p F P
0 g
s
.654 .752 .922 r
.51915 .48229 m .50112 .48854 L .49613 .48267 L p F P
0 g
s
.723 .434 .488 r
.48519 .58475 m .48449 .58803 L .4831 .58454 L closepath p F P
0 g
s
.721 .433 .489 r
.47 .59007 m .46724 .58269 L .4831 .58454 L p F P
0 g
s
.721 .433 .489 r
.48374 .59165 m .47 .59007 L p .4831 .58454 L F P
0 g
s
.721 .433 .489 r
.4831 .58454 m .48449 .58803 L .48374 .59165 L p F P
0 g
s
.64 .368 .49 r
.57769 .58371 m .56961 .58446 L .5754 .59098 L p F P
0 g
s
.643 .368 .487 r
.55503 .59272 m .5754 .59098 L .56961 .58446 L p F P
0 g
s
.672 .728 .892 r
.52407 .48795 m .54218 .48183 L .54703 .48749 L p F P
0 g
s
.654 .756 .925 r
.54218 .48183 m .52407 .48795 L .51915 .48229 L p F P
0 g
s
.782 .546 .579 r
.41247 .5641 m .42469 .56721 L .42549 .55879 L p F P
0 g
s
.782 .546 .579 r
.42549 .55879 m .41331 .55567 L .41247 .5641 L p F P
0 g
s
.735 .693 .811 r
.43049 .49504 m .43222 .49382 L .42707 .48647 L p F P
0 g
s
.735 .693 .811 r
.42707 .48647 m .41953 .49138 L .43049 .49504 L p F P
0 g
s
.741 .664 .774 r
.40911 .49889 m .41953 .49138 L .43049 .49504 L p F P
0 g
s
.707 .719 .859 r
.45011 .48427 m .43222 .49382 L .42707 .48647 L p F P
0 g
s
.673 .719 .883 r
.54703 .48749 m .56523 .48127 L .57 .48719 L p F P
0 g
s
.66 .751 .918 r
.56523 .48127 m .54703 .48749 L .54218 .48183 L p F P
0 g
s
.777 .637 .707 r
.39507 .52995 m .39685 .53052 L .40359 .52021 L p F P
0 g
s
.777 .637 .707 r
.39087 .51891 m .39507 .52995 L p .40359 .52021 L F P
0 g
s
.777 .637 .707 r
.40359 .52021 m .39248 .51663 L .39087 .51891 L p F P
0 g
s
.62 .35 .486 r
.59774 .588 m .59857 .58085 L .57769 .58371 L p F P
0 g
s
.62 .35 .486 r
.57769 .58371 m .57679 .59085 L .59774 .588 L p F P
0 g
s
.64 .368 .49 r
.5754 .59098 m .57679 .59085 L .57769 .58371 L p F P
0 g
s
.627 .529 .723 r
.6689 .51342 m .66727 .5082 L .64868 .51351 L p F P
0 g
s
.627 .529 .723 r
.64868 .51351 m .65068 .51988 L .6689 .51342 L p F P
0 g
s
.633 .55 .743 r
.6463 .50676 m .64868 .51351 L .66727 .5082 L p F P
0 g
s
.617 .499 .696 r
.67189 .52483 m .6689 .51342 L .65068 .51988 L p F P
0 g
s
.617 .499 .696 r
.65068 .51988 m .65365 .53126 L .67189 .52483 L p F P
0 g
s
.674 .702 .867 r
.57 .48719 m .58829 .48079 L .593 .48726 L p F P
0 g
s
.668 .736 .901 r
.58829 .48079 m .57 .48719 L .56523 .48127 L p F P
0 g
s
.64 .572 .762 r
.64388 .50064 m .6463 .50676 L .66449 .50023 L p F P
0 g
s
.633 .55 .743 r
.66727 .5082 m .66449 .50023 L .6463 .50676 L p F P
0 g
s
.764 .5 .534 r
.43028 .57631 m .43851 .57797 L .43769 .57004 L p F P
0 g
s
.764 .5 .534 r
.43769 .57004 m .43122 .56873 L .43028 .57631 L p F P
0 g
s
.734 .442 .485 r
.45714 .58836 m .47 .59007 L .46724 .58269 L p F P
0 g
s
.734 .442 .485 r
.46724 .58269 m .45879 .58157 L .45714 .58836 L p F P
0 g
s
.672 .676 .845 r
.593 .48726 m .61137 .48077 L .61604 .48809 L p F P
0 g
s
.672 .711 .878 r
.61137 .48077 m .593 .48726 L .58829 .48079 L p F P
0 g
s
.648 .598 .784 r
.66246 .49503 m .64388 .50064 L .63917 .49027 L p F P
0 g
s
.64 .572 .762 r
.66449 .50023 m .66246 .49503 L .64388 .50064 L p F P
0 g
s
.606 .468 .667 r
.67236 .52705 m .67189 .52483 L .65365 .53126 L p F P
0 g
s
.606 .468 .667 r
.65365 .53126 m .65368 .53141 L .67236 .52705 L p F P
0 g
s
.602 .457 .656 r
.67388 .53501 m .67236 .52705 L .65368 .53141 L p F P
0 g
s
.602 .457 .656 r
.65368 .53141 m .65559 .54139 L .67388 .53501 L p F P
0 g
s
.593 .361 .534 r
.63833 .57248 m .63842 .56465 L .61891 .56928 L p F P
0 g
s
.593 .361 .534 r
.61891 .56928 m .61876 .5771 L .63833 .57248 L p F P
0 g
s
.614 .378 .536 r
.6082 .57908 m .61876 .5771 L .61891 .56928 L p F P
0 g
s
.714 .426 .488 r
.48449 .58803 m .48613 .59184 L .48374 .59165 L closepath p F P
0 g
s
.739 .677 .791 r
.41953 .49138 m .40911 .49889 L .40393 .49066 L p F P
0 g
s
.76 .677 .77 r
.40246 .50522 m .40911 .49889 L .40393 .49066 L p F P
0 g
s
.76 .677 .77 r
.40393 .49066 m .39191 .50141 L .40246 .50522 L p F P
0 g
s
.771 .664 .746 r
.38945 .5156 m .39248 .51663 L .40246 .50522 L p F P
0 g
s
.771 .664 .746 r
.38576 .50801 m .38945 .5156 L p .40246 .50522 L F P
0 g
s
.771 .664 .746 r
.40246 .50522 m .39191 .50141 L .38576 .50801 L p F P
0 g
s
.789 .583 .621 r
.39975 .55189 m .40147 .5524 L .40396 .54347 L p F P
0 g
s
.789 .583 .621 r
.40396 .54347 m .39824 .54177 L .39975 .55189 L p F P
0 g
s
.59 .39 .579 r
.65735 .55917 m .6568 .55065 L .63791 .55615 L p F P
0 g
s
.59 .39 .579 r
.63791 .55615 m .63842 .56465 L .65735 .55917 L p F P
0 g
s
.747 .455 .488 r
.4548 .58798 m .45714 .58836 L .45879 .58157 L p F P
0 g
s
.747 .455 .488 r
.45879 .58157 m .45236 .58051 L .4548 .58798 L p F P
0 g
s
.787 .614 .667 r
.39685 .53052 m .39507 .52995 L .39585 .53257 L closepath p F P
0 g
s
.665 .642 .817 r
.6391 .49014 m .63451 .48174 L .61604 .48809 L p F P
0 g
s
.669 .677 .849 r
.63451 .48174 m .61604 .48809 L .61137 .48077 L p F P
0 g
s
.775 .51 .535 r
.42538 .57518 m .43028 .57631 L .43122 .56873 L p F P
0 g
s
.775 .51 .535 r
.43122 .56873 m .42469 .56721 L .42538 .57518 L p F P
0 g
s
.787 .551 .579 r
.40063 .56083 m .41247 .5641 L .41331 .55567 L p F P
0 g
s
.787 .551 .579 r
.41331 .55567 m .40147 .5524 L .40063 .56083 L p F P
0 g
s
.791 .636 .689 r
.39087 .51891 m .3863 .52676 L .39507 .52995 L closepath p F P
0 g
s
.799 .619 .657 r
.39279 .53995 m .39585 .53257 L .39507 .52995 L p F P
0 g
s
.799 .619 .657 r
.38228 .53618 m .39279 .53995 L p .39507 .52995 L F P
0 g
s
.799 .619 .657 r
.39507 .52995 m .3863 .52676 L .38228 .53618 L p F P
0 g
s
.793 .61 .653 r
.39585 .53257 m .39279 .53995 L .39824 .54177 L closepath p F P
0 g
s
.598 .33 .483 r
.6082 .57908 m .59857 .58085 L .59774 .588 L p F P
0 g
s
.649 .336 .428 r
.54716 .59307 m .53239 .59358 L .53058 .59995 L p F P
0 g
s
.67 .356 .434 r
.53018 .59995 m .53058 .59995 L .53239 .59358 L p F P
0 g
s
.67 .356 .434 r
.53239 .59358 m .52407 .59354 L .53018 .59995 L p F P
0 g
s
.673 .353 .425 r
.50952 .59962 m .53018 .59995 L .52407 .59354 L p F P
0 g
s
.673 .353 .425 r
.50742 .59726 m .50952 .59962 L p .52407 .59354 L F P
0 g
s
.673 .353 .425 r
.52407 .59354 m .5087 .59328 L .50742 .59726 L p F P
0 g
s
.728 .697 .821 r
.41953 .49138 m .42707 .48647 L .42187 .47961 L p F P
0 g
s
.728 .697 .821 r
.42187 .47961 m .40829 .48779 L .41953 .49138 L p F P
0 g
s
.739 .677 .791 r
.40393 .49066 m .40829 .48779 L .41953 .49138 L p F P
0 g
s
.691 .372 .431 r
.5087 .59328 m .50742 .59726 L .50402 .59304 L closepath p F P
0 g
s
.754 .46 .485 r
.44087 .58545 m .4548 .58798 L .45236 .58051 L p F P
0 g
s
.754 .46 .485 r
.45236 .58051 m .43851 .57797 L .44087 .58545 L p F P
0 g
s
.781 .642 .709 r
.39248 .51663 m .38945 .5156 L .39087 .51891 L closepath p F P
0 g
s
.647 .337 .433 r
.55503 .59272 m .55358 .59834 L .54716 .59307 L closepath p F P
0 g
s
.649 .336 .428 r
.55337 .59917 m .55358 .59834 L .54716 .59307 L p F P
0 g
s
.649 .336 .428 r
.53058 .59995 m .55337 .59917 L p .54716 .59307 L F P
0 g
s
.69 .372 .433 r
.49122 .59854 m .48613 .59184 L .50402 .59304 L p F P
0 g
s
.69 .372 .433 r
.50669 .59955 m .49122 .59854 L p .50402 .59304 L F P
0 g
s
.69 .372 .433 r
.50402 .59304 m .50742 .59726 L .50669 .59955 L p F P
0 g
s
.683 .731 .887 r
.45011 .48427 m .46803 .47751 L .47312 .4832 L p F P
0 g
s
.663 .744 .91 r
.46803 .47751 m .45011 .48427 L .44496 .47803 L p F P
0 g
s
.707 .719 .859 r
.42707 .48647 m .44496 .47803 L .45011 .48427 L p F P
0 g
s
.799 .59 .619 r
.39048 .54883 m .39975 .55189 L .39824 .54177 L p F P
0 g
s
.799 .59 .619 r
.39824 .54177 m .39279 .53995 L .39048 .54883 L p F P
0 g
s
.796 .645 .695 r
.3863 .52676 m .39087 .51891 L .38945 .5156 L p F P
0 g
s
.782 .516 .534 r
.41311 .57208 m .42538 .57518 L .42469 .56721 L p F P
0 g
s
.782 .516 .534 r
.42469 .56721 m .41247 .5641 L .41311 .57208 L p F P
0 g
s
.665 .743 .908 r
.47312 .4832 m .49111 .47744 L .49613 .48267 L p F P
0 g
s
.638 .76 .936 r
.49111 .47744 m .47312 .4832 L .46803 .47751 L p F P
0 g
s
.624 .315 .426 r
.5754 .59098 m .55503 .59272 L .55358 .59834 L p F P
0 g
s
.587 .418 .62 r
.67513 .54429 m .67388 .53501 L .65559 .54139 L p F P
0 g
s
.587 .418 .62 r
.65559 .54139 m .6568 .55065 L .67513 .54429 L p F P
0 g
s
.648 .598 .784 r
.63917 .49027 m .65775 .48446 L .66246 .49503 L p F P
0 g
s
.655 .63 .813 r
.6391 .49014 m .63917 .49027 L .65775 .48446 L p F P
0 g
s
.693 .73 .879 r
.44496 .47803 m .42707 .48647 L .42187 .47961 L p F P
0 g
s
.654 .752 .922 r
.49613 .48267 m .5142 .47736 L .51915 .48229 L p F P
0 g
s
.624 .773 .952 r
.5142 .47736 m .49613 .48267 L .49111 .47744 L p F P
0 g
s
.657 .64 .821 r
.63451 .48174 m .6391 .49014 L .65723 .48343 L p F P
0 g
s
.655 .63 .813 r
.65775 .48446 m .65723 .48343 L .6391 .49014 L p F P
0 g
s
.787 .658 .721 r
.38576 .50801 m .38224 .51273 L .38945 .5156 L closepath p F P
0 g
s
.796 .645 .695 r
.37617 .52282 m .3863 .52676 L p .38945 .5156 L F P
0 g
s
.796 .645 .695 r
.38945 .5156 m .38224 .51273 L .37617 .52282 L p F P
0 g
s
.597 .331 .485 r
.61876 .5771 m .61808 .58381 L .6082 .57908 L closepath p F P
0 g
s
.598 .33 .483 r
.61803 .58429 m .61808 .58381 L .6082 .57908 L p F P
0 g
s
.598 .33 .483 r
.59774 .588 m .61803 .58429 L p .6082 .57908 L F P
0 g
s
.702 .377 .424 r
.48147 .59775 m .49122 .59854 L .48613 .59184 L p F P
0 g
s
.702 .377 .424 r
.48613 .59184 m .48374 .59165 L .48147 .59775 L p F P
0 g
s
.654 .756 .925 r
.51915 .48229 m .53731 .47699 L .54218 .48183 L p F P
0 g
s
.623 .782 .958 r
.53731 .47699 m .51915 .48229 L .5142 .47736 L p F P
0 g
s
.719 .395 .431 r
.47446 .59695 m .48147 .59775 L .48374 .59165 L p F P
0 g
s
.719 .395 .431 r
.48374 .59165 m .47 .59007 L .47446 .59695 L p F P
0 g
s
.66 .751 .918 r
.54218 .48183 m .56044 .47627 L .56523 .48127 L p F P
0 g
s
.636 .783 .952 r
.56044 .47627 m .54218 .48183 L .53731 .47699 L p F P
0 g
s
.805 .597 .62 r
.37992 .54508 m .39048 .54883 L .39279 .53995 L p F P
0 g
s
.805 .597 .62 r
.39279 .53995 m .38228 .53618 L .37992 .54508 L p F P
0 g
s
.668 .736 .901 r
.56523 .48127 m .58356 .47535 L .58829 .48079 L p F P
0 g
s
.654 .772 .936 r
.58356 .47535 m .56523 .48127 L .56044 .47627 L p F P
0 g
s
.621 .312 .425 r
.57679 .59085 m .57659 .59166 L .5754 .59098 L closepath p F P
0 g
s
.624 .315 .426 r
.57524 .59733 m .57659 .59166 L .5754 .59098 L p F P
0 g
s
.624 .315 .426 r
.55467 .59907 m .57524 .59733 L p .5754 .59098 L F P
0 g
s
.624 .315 .426 r
.55358 .59834 m .55467 .59907 L p .5754 .59098 L F P
0 g
s
.762 .691 .784 r
.39191 .50141 m .40393 .49066 L .40033 .48538 L p F P
0 g
s
.762 .691 .784 r
.38143 .49755 m .39191 .50141 L p .40033 .48538 L F P
0 g
s
.771 .665 .746 r
.38057 .4984 m .38143 .49755 L .39191 .50141 L p F P
0 g
s
.771 .665 .746 r
.39191 .50141 m .38576 .50801 L .38057 .4984 L p F P
0 g
s
.602 .294 .42 r
.59633 .59454 m .59774 .588 L .57679 .59085 L p F P
0 g
s
.602 .294 .42 r
.58662 .59586 m .59633 .59454 L p .57679 .59085 L F P
0 g
s
.602 .294 .42 r
.57679 .59085 m .57659 .59166 L .58662 .59586 L p F P
0 g
s
.761 .463 .481 r
.42835 .58292 m .44087 .58545 L .43851 .57797 L p F P
0 g
s
.761 .463 .481 r
.43851 .57797 m .43028 .57631 L .42835 .58292 L p F P
0 g
s
.793 .557 .579 r
.39986 .5606 m .40063 .56083 L .40147 .5524 L p F P
0 g
s
.793 .557 .579 r
.40147 .5524 m .39975 .55189 L .39986 .5606 L p F P
0 g
s
.734 .688 .807 r
.40829 .48779 m .40033 .48538 L .40393 .49066 L closepath p F P
0 g
s
.804 .625 .66 r
.37208 .53228 m .38228 .53618 L .3863 .52676 L p F P
0 g
s
.804 .625 .66 r
.3863 .52676 m .37617 .52282 L .37208 .53228 L p F P
0 g
s
.672 .711 .878 r
.58829 .48079 m .6067 .47458 L .61137 .48077 L p F P
0 g
s
.667 .748 .911 r
.6067 .47458 m .58829 .48079 L .58356 .47535 L p F P
0 g
s
.788 .667 .73 r
.38224 .51273 m .38576 .50801 L .38057 .4984 L p F P
0 g
s
.803 .565 .578 r
.38963 .55726 m .39986 .5606 L .39975 .55189 L p F P
0 g
s
.803 .565 .578 r
.39975 .55189 m .39048 .54883 L .38963 .55726 L p F P
0 g
s
.614 .52 .724 r
.68658 .50604 m .68609 .50445 L .66727 .5082 L p F P
0 g
s
.614 .52 .724 r
.66727 .5082 m .6689 .51342 L .68658 .50604 L p F P
0 g
s
.618 .54 .744 r
.66449 .50023 m .66727 .5082 L .68609 .50445 L p F P
0 g
s
.571 .344 .532 r
.65732 .567 m .65735 .55917 L .63842 .56465 L p F P
0 g
s
.571 .344 .532 r
.63842 .56465 m .63833 .57248 L .65732 .567 L p F P
0 g
s
.602 .489 .698 r
.68957 .51746 m .68658 .50604 L .6689 .51342 L p F P
0 g
s
.602 .489 .698 r
.6689 .51342 m .67189 .52483 L .68957 .51746 L p F P
0 g
s
.73 .692 .814 r
.40829 .48779 m .42187 .47961 L p .39869 .48305 L F P
0 g
s
.73 .692 .814 r
.39869 .48305 m .40033 .48538 L .40829 .48779 L p F P
0 g
s
.724 .392 .417 r
.45902 .59492 m .47446 .59695 L .47 .59007 L p F P
0 g
s
.724 .392 .417 r
.45623 .59042 m .45902 .59492 L p .47 .59007 L F P
0 g
s
.724 .392 .417 r
.47 .59007 m .45714 .58836 L .45623 .59042 L p F P
0 g
s
.601 .295 .423 r
.57659 .59166 m .58662 .59586 L .57524 .59733 L closepath p F P
0 g
s
.575 .312 .481 r
.63767 .57968 m .63833 .57248 L .61876 .5771 L p F P
0 g
s
.575 .312 .481 r
.61918 .58402 m .63767 .57968 L p .61876 .5771 L F P
0 g
s
.575 .312 .481 r
.61876 .5771 m .61808 .58381 L .61918 .58402 L p F P
0 g
s
.669 .677 .849 r
.61137 .48077 m .62987 .47449 L .63451 .48174 L p F P
0 g
s
.671 .714 .881 r
.62987 .47449 m .61137 .48077 L .6067 .47458 L p F P
0 g
s
.629 .564 .763 r
.66246 .49503 m .66449 .50023 L .68212 .49275 L p F P
0 g
s
.618 .54 .744 r
.68609 .50445 m .68212 .49275 L .66449 .50023 L p F P
0 g
s
.789 .521 .532 r
.40125 .56881 m .41311 .57208 L .41247 .5641 L p F P
0 g
s
.789 .521 .532 r
.41247 .5641 m .40063 .56083 L .40125 .56881 L p F P
0 g
s
.788 .667 .73 r
.38057 .4984 m .37253 .50861 L .38224 .51273 L p F P
0 g
s
.799 .652 .699 r
.36631 .51876 m .37617 .52282 L .38224 .51273 L p F P
0 g
s
.799 .652 .699 r
.38224 .51273 m .37253 .50861 L .36631 .51876 L p F P
0 g
s
.679 .362 .43 r
.50742 .59726 m .50952 .59962 L .50669 .59955 L closepath p F P
0 g
s
.772 .475 .484 r
.4275 .58273 m .42835 .58292 L .43028 .57631 L p F P
0 g
s
.772 .475 .484 r
.43028 .57631 m .42538 .57518 L .4275 .58273 L p F P
0 g
s
.569 .374 .578 r
.67574 .55282 m .67513 .54429 L .6568 .55065 L p F P
0 g
s
.569 .374 .578 r
.6568 .55065 m .65735 .55917 L .67574 .55282 L p F P
0 g
s
.638 .586 .78 r
.68123 .49041 m .66246 .49503 L .65775 .48446 L p F P
0 g
s
.629 .564 .763 r
.68212 .49275 m .68123 .49041 L .66246 .49503 L p F P
0 g
s
.585 .453 .667 r
.69137 .52627 m .68957 .51746 L .67189 .52483 L p F P
0 g
s
.585 .453 .667 r
.67189 .52483 m .67236 .52705 L .69137 .52627 L p F P
0 g
s
.657 .64 .821 r
.65723 .48343 m .65311 .47575 L .63451 .48174 L p F P
0 g
s
.665 .673 .848 r
.65311 .47575 m .63451 .48174 L .62987 .47449 L p F P
0 g
s
.738 .408 .423 r
.45714 .58836 m .45623 .59042 L .4548 .58798 L closepath p F P
0 g
s
.584 .444 .656 r
.69165 .52774 m .69137 .52627 L .67236 .52705 L p F P
0 g
s
.584 .444 .656 r
.67236 .52705 m .67388 .53501 L .69165 .52774 L p F P
0 g
s
.574 .273 .42 r
.6167 .59084 m .61803 .58429 L .59774 .588 L p F P
0 g
s
.574 .273 .42 r
.59774 .588 m .59633 .59454 L .6167 .59084 L p F P
0 g
s
.779 .48 .481 r
.41515 .57965 m .4275 .58273 L .42538 .57518 L p F P
0 g
s
.779 .48 .481 r
.42538 .57518 m .41311 .57208 L .41515 .57965 L p F P
0 g
s
.737 .408 .424 r
.44474 .5925 m .44087 .58545 L .4548 .58798 L p F P
0 g
s
.737 .408 .424 r
.45457 .59426 m .44474 .5925 L p .4548 .58798 L F P
0 g
s
.737 .408 .424 r
.4548 .58798 m .45623 .59042 L .45457 .59426 L p F P
0 g
s
.752 .698 .801 r
.39869 .48305 m .39732 .48407 L .40033 .48538 L closepath p F P
0 g
s
.762 .691 .784 r
.40033 .48538 m .39732 .48407 L .38143 .49755 L p F P
0 g
s
.663 .744 .91 r
.44496 .47803 m .46289 .4723 L .46803 .47751 L p F P
0 g
s
.638 .755 .933 r
.46289 .4723 m .44496 .47803 L .43977 .4722 L p F P
0 g
s
.693 .73 .879 r
.42187 .47961 m .43977 .4722 L .44496 .47803 L p F P
0 g
s
.677 .739 .898 r
.43977 .4722 m .42187 .47961 L .41662 .47315 L p F P
0 g
s
.73 .692 .814 r
.42187 .47961 m .41662 .47315 L .39869 .48305 L p F P
0 g
s
.811 .603 .621 r
.36968 .54118 m .37992 .54508 L .38228 .53618 L p F P
0 g
s
.811 .603 .621 r
.38228 .53618 m .37208 .53228 L .36968 .54118 L p F P
0 g
s
.638 .76 .936 r
.46803 .47751 m .48604 .47277 L .49111 .47744 L p F P
0 g
s
.602 .772 .961 r
.48604 .47277 m .46803 .47751 L .46289 .4723 L p F P
0 g
s
.81 .572 .578 r
.37903 .55352 m .38963 .55726 L .39048 .54883 L p F P
0 g
s
.81 .572 .578 r
.39048 .54883 m .37992 .54508 L .37903 .55352 L p F P
0 g
s
.759 .699 .796 r
.37966 .49686 m .38143 .49755 L .39732 .48407 L p F P
0 g
s
.77 .675 .759 r
.38143 .49755 m .37966 .49686 L .38057 .4984 L closepath p F P
0 g
s
.791 .677 .738 r
.37253 .50861 m .38057 .4984 L .37966 .49686 L p F P
0 g
s
.63 .322 .431 r
.55358 .59834 m .55467 .59907 L .55337 .59917 L closepath p F P
0 g
s
.631 .273 .346 r
.55103 .60493 m .55337 .59917 L .53058 .59995 L p F P
0 g
s
.631 .273 .346 r
.53985 .60531 m .55103 .60493 L p .53058 .59995 L F P
0 g
s
.631 .273 .346 r
.53058 .59995 m .53049 .60015 L .53985 .60531 L p F P
0 g
s
.647 .29 .353 r
.53058 .59995 m .53049 .60015 L .53018 .59995 L closepath p F P
0 g
s
.646 .292 .357 r
.51765 .60544 m .50952 .59962 L .53018 .59995 L p F P
0 g
s
.646 .292 .357 r
.52803 .6056 m .51765 .60544 L p .53018 .59995 L F P
0 g
s
.646 .292 .357 r
.53018 .59995 m .53049 .60015 L .52803 .6056 L p F P
0 g
s
.808 .631 .663 r
.36215 .52824 m .37208 .53228 L .37617 .52282 L p F P
0 g
s
.808 .631 .663 r
.37617 .52282 m .36631 .51876 L .36215 .52824 L p F P
0 g
s
.631 .275 .35 r
.53049 .60015 m .53985 .60531 L .52803 .6056 L closepath p F P
0 g
s
.658 .297 .349 r
.50391 .60505 m .51765 .60544 L .50952 .59962 L p F P
0 g
s
.658 .297 .349 r
.50952 .59962 m .50669 .59955 L .50391 .60505 L p F P
0 g
s
.679 .322 .361 r
.49824 .60468 m .50391 .60505 L .50669 .59955 L p F P
0 g
s
.679 .322 .361 r
.50669 .59955 m .49122 .59854 L .49824 .60468 L p F P
0 g
s
.624 .773 .952 r
.49111 .47744 m .50921 .47309 L .5142 .47736 L p F P
0 g
s
.577 .789 .979 r
.50921 .47309 m .49111 .47744 L .48604 .47277 L p F P
0 g
s
.748 .705 .811 r
.39732 .48407 m .39869 .48305 L .3934 .47594 L p F P
0 g
s
.748 .705 .811 r
.3934 .47594 m .38804 .47973 L .39732 .48407 L p F P
0 g
s
.759 .699 .796 r
.37531 .48986 m .37966 .49686 L p .39732 .48407 L F P
0 g
s
.759 .699 .796 r
.39732 .48407 m .38804 .47973 L .37531 .48986 L p F P
0 g
s
.781 .686 .759 r
.37531 .48986 m .37205 .49326 L .37966 .49686 L closepath p F P
0 g
s
.791 .677 .738 r
.36306 .50437 m .37253 .50861 L p .37966 .49686 L F P
0 g
s
.791 .677 .738 r
.37966 .49686 m .37205 .49326 L .36306 .50437 L p F P
0 g
s
.795 .526 .53 r
.39867 .56804 m .40125 .56881 L .40063 .56083 L p F P
0 g
s
.795 .526 .53 r
.40063 .56083 m .39986 .5606 L .39867 .56804 L p F P
0 g
s
.714 .726 .86 r
.41662 .47315 m .39869 .48305 L .3934 .47594 L p F P
0 g
s
.638 .586 .78 r
.65775 .48446 m .67651 .47937 L .68123 .49041 L p F P
0 g
s
.645 .623 .814 r
.65723 .48343 m .65775 .48446 L .67651 .47937 L p F P
0 g
s
.602 .252 .348 r
.55467 .59907 m .55337 .59917 L .55103 .60493 L p F P
0 g
s
.567 .404 .62 r
.69294 .53705 m .69165 .52774 L .67388 .53501 L p F P
0 g
s
.567 .404 .62 r
.67388 .53501 m .67513 .54429 L .69294 .53705 L p F P
0 g
s
.601 .257 .357 r
.57524 .59733 m .55467 .59907 L .56671 .60372 L p F P
0 g
s
.602 .252 .348 r
.55103 .60493 m .56671 .60372 L .55467 .59907 L p F P
0 g
s
.805 .536 .531 r
.39013 .56528 m .39867 .56804 L .39986 .5606 L p F P
0 g
s
.805 .536 .531 r
.39986 .5606 m .38963 .55726 L .39013 .56528 L p F P
0 g
s
.623 .782 .958 r
.5142 .47736 m .53241 .47292 L .53731 .47699 L p F P
0 g
s
.572 .804 .987 r
.53241 .47292 m .5142 .47736 L .50921 .47309 L p F P
0 g
s
.65 .635 .822 r
.65311 .47575 m .65723 .48343 L .67468 .47562 L p F P
0 g
s
.645 .623 .814 r
.67651 .47937 m .67468 .47562 L .65723 .48343 L p F P
0 g
s
.731 .401 .421 r
.45623 .59042 m .45902 .59492 L .45457 .59426 L closepath p F P
0 g
s
.683 .316 .345 r
.4808 .60329 m .49824 .60468 L .49122 .59854 L p F P
0 g
s
.683 .316 .345 r
.47915 .60174 m .4808 .60329 L p .49122 .59854 L F P
0 g
s
.683 .316 .345 r
.49122 .59854 m .48147 .59775 L .47915 .60174 L p F P
0 g
s
.636 .783 .952 r
.53731 .47699 m .55562 .47213 L .56044 .47627 L p F P
0 g
s
.594 .811 .983 r
.55562 .47213 m .53731 .47699 L .53241 .47292 L p F P
0 g
s
.802 .658 .703 r
.3567 .51458 m .36631 .51876 L .37253 .50861 L p F P
0 g
s
.802 .658 .703 r
.37253 .50861 m .36306 .50437 L .3567 .51458 L p F P
0 g
s
.751 .412 .408 r
.43127 .5898 m .44474 .5925 L .44087 .58545 L p F P
0 g
s
.751 .412 .408 r
.42797 .58362 m .43127 .5898 L p .44087 .58545 L F P
0 g
s
.751 .412 .408 r
.44087 .58545 m .42835 .58292 L .42797 .58362 L p F P
0 g
s
.547 .29 .477 r
.65672 .57421 m .65732 .567 L .63833 .57248 L p F P
0 g
s
.547 .29 .477 r
.63833 .57248 m .63767 .57968 L .65672 .57421 L p F P
0 g
s
.654 .772 .936 r
.56044 .47627 m .57883 .47085 L .58356 .47535 L p F P
0 g
s
.627 .808 .969 r
.57883 .47085 m .56044 .47627 L .55562 .47213 L p F P
0 g
s
.667 .748 .911 r
.58356 .47535 m .60203 .46942 L .6067 .47458 L p F P
0 g
s
.655 .788 .945 r
.60203 .46942 m .58356 .47535 L .57883 .47085 L p F P
0 g
s
.702 .338 .356 r
.48147 .59775 m .47915 .60174 L .47446 .59695 L closepath p F P
0 g
s
.787 .485 .477 r
.40326 .57639 m .41515 .57965 L .41311 .57208 L p F P
0 g
s
.787 .485 .477 r
.41311 .57208 m .40125 .56881 L .40326 .57639 L p F P
0 g
s
.547 .324 .529 r
.67576 .56067 m .67574 .55282 L .65735 .55917 L p F P
0 g
s
.547 .324 .529 r
.65735 .55917 m .65732 .567 L .67576 .56067 L p F P
0 g
s
.671 .714 .881 r
.6067 .47458 m .62524 .46837 L .62987 .47449 L p F P
0 g
s
.67 .754 .913 r
.62524 .46837 m .6067 .47458 L .60203 .46942 L p F P
0 g
s
.575 .314 .483 r
.61808 .58381 m .61918 .58402 L .61803 .58429 L closepath p F P
0 g
s
.572 .227 .346 r
.58662 .59586 m .57524 .59733 L .57308 .60319 L p F P
0 g
s
.601 .257 .357 r
.56671 .60372 m .57308 .60319 L .57524 .59733 L p F P
0 g
s
.546 .248 .413 r
.61918 .58402 m .61803 .58429 L .6167 .59084 L p F P
0 g
s
.701 .338 .357 r
.46504 .60135 m .45902 .59492 L .47446 .59695 L p F P
0 g
s
.701 .338 .357 r
.47839 .60306 m .46504 .60135 L p .47446 .59695 L F P
0 g
s
.701 .338 .357 r
.47446 .59695 m .47915 .60174 L .47839 .60306 L p F P
0 g
s
.665 .673 .848 r
.62987 .47449 m .64851 .46835 L .65311 .47575 L p F P
0 g
s
.671 .711 .878 r
.64851 .46835 m .62987 .47449 L .62524 .46837 L p F P
0 g
s
.546 .249 .415 r
.63767 .57968 m .63688 .58386 L .61918 .58402 L closepath p F P
0 g
s
.546 .248 .413 r
.63643 .58626 m .63688 .58386 L .61918 .58402 L p F P
0 g
s
.546 .248 .413 r
.6167 .59084 m .63643 .58626 L p .61918 .58402 L F P
0 g
s
.816 .61 .625 r
.36306 .5385 m .36968 .54118 L .37208 .53228 L p F P
0 g
s
.816 .61 .625 r
.36158 .53028 m .36306 .5385 L p .37208 .53228 L F P
0 g
s
.816 .61 .625 r
.37208 .53228 m .36215 .52824 L .36158 .53028 L p F P
0 g
s
.816 .578 .577 r
.36877 .54963 m .37903 .55352 L .37992 .54508 L p F P
0 g
s
.816 .578 .577 r
.37992 .54508 m .36968 .54118 L .36877 .54963 L p F P
0 g
s
.754 .689 .789 r
.38804 .47973 m .37531 .48986 L .36999 .48191 L p F P
0 g
s
.78 .693 .768 r
.37205 .49326 m .37531 .48986 L .36999 .48191 L p F P
0 g
s
.78 .693 .768 r
.36999 .48191 m .36311 .48879 L .37205 .49326 L p F P
0 g
s
.793 .683 .743 r
.35382 .50001 m .36306 .50437 L .37205 .49326 L p F P
0 g
s
.793 .683 .743 r
.37205 .49326 m .36311 .48879 L .35382 .50001 L p F P
0 g
s
.598 .507 .723 r
.68609 .50445 m .69088 .50395 L .68658 .50604 L closepath p F P
0 g
s
.6 .525 .742 r
.68212 .49275 m .68609 .50445 L .69088 .50395 L p F P
0 g
s
.588 .483 .702 r
.70673 .50916 m .68957 .51746 L .68658 .50604 L p F P
0 g
s
.588 .483 .702 r
.70523 .50327 m .70673 .50916 L p .68658 .50604 L F P
0 g
s
.588 .483 .702 r
.68658 .50604 m .69088 .50395 L .70523 .50327 L p F P
0 g
s
.571 .227 .348 r
.59633 .59454 m .59523 .59769 L .58662 .59586 L closepath p F P
0 g
s
.572 .227 .346 r
.5943 .60045 m .59523 .59769 L .58662 .59586 L p F P
0 g
s
.572 .227 .346 r
.57308 .60319 m .5943 .60045 L p .58662 .59586 L F P
0 g
s
.81 .64 .671 r
.36104 .52776 m .36215 .52824 L .36631 .51876 L p F P
0 g
s
.81 .64 .671 r
.35664 .51471 m .36104 .52776 L p .36631 .51876 L F P
0 g
s
.81 .64 .671 r
.36631 .51876 m .3567 .51458 L .35664 .51471 L p F P
0 g
s
.812 .542 .53 r
.37949 .56155 m .39013 .56528 L .38963 .55726 L p F P
0 g
s
.812 .542 .53 r
.38963 .55726 m .37903 .55352 L .37949 .56155 L p F P
0 g
s
.764 .426 .415 r
.42835 .58292 m .42797 .58362 L .4275 .58273 L closepath p F P
0 g
s
.546 .357 .576 r
.6936 .54559 m .69294 .53705 L .67513 .54429 L p F P
0 g
s
.546 .357 .576 r
.67513 .54429 m .67574 .55282 L .6936 .54559 L p F P
0 g
s
.764 .426 .414 r
.41857 .58682 m .41515 .57965 L .4275 .58273 L p F P
0 g
s
.764 .426 .414 r
.42532 .58849 m .41857 .58682 L p .4275 .58273 L F P
0 g
s
.764 .426 .414 r
.4275 .58273 m .42797 .58362 L .42532 .58849 L p F P
0 g
s
.677 .739 .898 r
.41662 .47315 m .43452 .46672 L .43977 .4722 L p F P
0 g
s
.657 .745 .915 r
.43452 .46672 m .41662 .47315 L .41133 .46701 L p F P
0 g
s
.714 .726 .86 r
.3934 .47594 m .41133 .46701 L .41662 .47315 L p F P
0 g
s
.65 .635 .822 r
.67468 .47562 m .67188 .47019 L .65311 .47575 L p F P
0 g
s
.66 .663 .841 r
.67188 .47019 m .65311 .47575 L .64851 .46835 L p F P
0 g
s
.616 .553 .761 r
.68123 .49041 m .69007 .48882 L .68212 .49275 L closepath p F P
0 g
s
.6 .525 .742 r
.70024 .48724 m .69007 .48882 L .68212 .49275 L p F P
0 g
s
.6 .525 .742 r
.70364 .4976 m .70024 .48724 L p .68212 .49275 L F P
0 g
s
.6 .525 .742 r
.69088 .50395 m .70364 .4976 L p .68212 .49275 L F P
0 g
s
.638 .755 .933 r
.43977 .4722 m .45771 .46748 L .46289 .4723 L p F P
0 g
s
.606 .761 .953 r
.45771 .46748 m .43977 .4722 L .43452 .46672 L p F P
0 g
s
.743 .709 .82 r
.38804 .47973 m .3934 .47594 L .38806 .46917 L p F P
0 g
s
.743 .709 .82 r
.38806 .46917 m .37885 .47532 L .38804 .47973 L p F P
0 g
s
.754 .689 .789 r
.36999 .48191 m .37885 .47532 L .38804 .47973 L p F P
0 g
s
.625 .571 .773 r
.69007 .48882 m .68123 .49041 L .67651 .47937 L p F P
0 g
s
.714 .34 .339 r
.45107 .59927 m .46504 .60135 L .45902 .59492 L p F P
0 g
s
.714 .34 .339 r
.45902 .59492 m .45457 .59426 L .45107 .59927 L p F P
0 g
s
.76 .422 .412 r
.42797 .58362 m .43127 .5898 L .42532 .58849 L closepath p F P
0 g
s
.703 .732 .874 r
.41133 .46701 m .3934 .47594 L .38806 .46917 L p F P
0 g
s
.602 .772 .961 r
.46289 .4723 m .48093 .46859 L .48604 .47277 L p F P
0 g
s
.548 .779 .984 r
.48093 .46859 m .46289 .4723 L .45771 .46748 L p F P
0 g
s
.562 .434 .664 r
.70885 .51948 m .70673 .50916 L .68957 .51746 L p F P
0 g
s
.562 .434 .664 r
.69386 .5267 m .70885 .51948 L p .68957 .51746 L F P
0 g
s
.562 .434 .664 r
.68957 .51746 m .69137 .52627 L .69386 .5267 L p F P
0 g
s
.544 .201 .338 r
.61479 .59679 m .6167 .59084 L .59633 .59454 L p F P
0 g
s
.544 .201 .338 r
.60517 .59852 m .61479 .59679 L p .59633 .59454 L F P
0 g
s
.544 .201 .338 r
.59633 .59454 m .59523 .59769 L .60517 .59852 L p F P
0 g
s
.794 .489 .472 r
.39626 .57431 m .40326 .57639 L .40125 .56881 L p F P
0 g
s
.794 .489 .472 r
.40125 .56881 m .39867 .56804 L .39626 .57431 L p F P
0 g
s
.803 .666 .712 r
.35656 .51451 m .3567 .51458 L .36306 .50437 L p F P
0 g
s
.803 .666 .712 r
.35144 .5036 m .35656 .51451 L p .36306 .50437 L F P
0 g
s
.803 .666 .712 r
.36306 .50437 m .35382 .50001 L .35144 .5036 L p F P
0 g
s
.731 .361 .35 r
.45016 .59911 m .45107 .59927 L .45457 .59426 L p F P
0 g
s
.731 .361 .35 r
.45457 .59426 m .44474 .5925 L .45016 .59911 L p F P
0 g
s
.588 .489 .709 r
.69088 .50395 m .70364 .4976 L .70523 .50327 L closepath p F P
0 g
s
.803 .5 .476 r
.39193 .57291 m .39626 .57431 L .39867 .56804 L p F P
0 g
s
.803 .5 .476 r
.39867 .56804 m .39013 .56528 L .39193 .57291 L p F P
0 g
s
.577 .789 .979 r
.48604 .47277 m .50418 .46943 L .50921 .47309 L p F P
0 g
s
.495 .793 .998 r
.50418 .46943 m .48604 .47277 L .48093 .46859 L p F P
0 g
s
.625 .571 .773 r
.69911 .48418 m .69007 .48882 L p .67651 .47937 L F P
0 g
s
.625 .571 .773 r
.67651 .47937 m .69547 .4752 L .69911 .48418 L p F P
0 g
s
.631 .61 .811 r
.67468 .47562 m .67651 .47937 L .69547 .4752 L p F P
0 g
s
.519 .266 .471 r
.67522 .56788 m .67576 .56067 L .65732 .567 L p F P
0 g
s
.519 .266 .471 r
.65732 .567 m .65672 .57421 L .67522 .56788 L p F P
0 g
s
.595 .192 .249 r
.53985 .60531 m .52803 .6056 L .52556 .60929 L p F P
0 g
s
.624 .226 .268 r
.52803 .6056 m .52556 .60929 L .51765 .60544 L closepath p F P
0 g
s
.572 .804 .987 r
.52816 .47006 m .53241 .47292 L p .50921 .47309 L F P
0 g
s
.572 .804 .987 r
.50921 .47309 m .52518 .47003 L .52816 .47006 L p F P
0 g
s
.488 .806 1 r
.52518 .47003 m .50921 .47309 L .50418 .46943 L p F P
0 g
s
.823 .584 .577 r
.36319 .54736 m .36877 .54963 L .36968 .54118 L p F P
0 g
s
.823 .584 .577 r
.36968 .54118 m .36306 .5385 L .36319 .54736 L p F P
0 g
s
.822 .617 .626 r
.36215 .52824 m .36104 .52776 L .36158 .53028 L closepath p F P
0 g
s
.623 .212 .244 r
.52475 .61053 m .52556 .60929 L .51765 .60544 L p F P
0 g
s
.623 .212 .244 r
.50787 .61007 m .52475 .61053 L p .51765 .60544 L F P
0 g
s
.623 .212 .244 r
.50231 .60713 m .50787 .61007 L p .51765 .60544 L F P
0 g
s
.623 .212 .244 r
.51765 .60544 m .50391 .60505 L .50231 .60713 L p F P
0 g
s
.516 .222 .406 r
.65571 .57996 m .65672 .57421 L .63767 .57968 L p F P
0 g
s
.516 .222 .406 r
.63767 .57968 m .63688 .58386 L .65571 .57996 L p F P
0 g
s
.78 .441 .412 r
.4066 .58358 m .41857 .58682 L .41515 .57965 L p F P
0 g
s
.78 .441 .412 r
.41515 .57965 m .40326 .57639 L .4066 .58358 L p F P
0 g
s
.739 .364 .343 r
.43653 .59644 m .45016 .59911 L .44474 .5925 L p F P
0 g
s
.739 .364 .343 r
.44474 .5925 m .43127 .5898 L .43653 .59644 L p F P
0 g
s
.564 .427 .653 r
.69137 .52627 m .69386 .5267 L .69165 .52774 L closepath p F P
0 g
s
.595 .201 .265 r
.55103 .60493 m .54884 .60855 L .53985 .60531 L closepath p F P
0 g
s
.595 .192 .249 r
.54799 .61001 m .54884 .60855 L .53985 .60531 L p F P
0 g
s
.595 .192 .249 r
.52849 .61048 m .54799 .61001 L p .53985 .60531 L F P
0 g
s
.595 .192 .249 r
.52556 .60929 m .52849 .61048 L p .53985 .60531 L F P
0 g
s
.649 .244 .262 r
.50391 .60505 m .50231 .60713 L .49824 .60468 L closepath p F P
0 g
s
.82 .548 .527 r
.36922 .55766 m .37949 .56155 L .37903 .55352 L p F P
0 g
s
.82 .548 .527 r
.37903 .55352 m .36877 .54963 L .36922 .55766 L p F P
0 g
s
.751 .698 .802 r
.37885 .47532 m .36999 .48191 L .36461 .47439 L p F P
0 g
s
.779 .699 .776 r
.36311 .48879 m .36999 .48191 L .36461 .47439 L p F P
0 g
s
.822 .641 .658 r
.35664 .51471 m .35292 .52393 L .36104 .52776 L closepath p F P
0 g
s
.831 .622 .619 r
.35988 .53711 m .36158 .53028 L .36104 .52776 L p F P
0 g
s
.831 .622 .619 r
.35065 .5328 m .35988 .53711 L p .36104 .52776 L F P
0 g
s
.831 .622 .619 r
.36104 .52776 m .35292 .52393 L .35065 .5328 L p F P
0 g
s
.594 .811 .983 r
.55088 .4689 m .55562 .47213 L p .53241 .47292 L F P
0 g
s
.594 .811 .983 r
.53241 .47292 m .55029 .46893 L .55088 .4689 L p F P
0 g
s
.595 .811 .982 r
.53241 .47292 m .55029 .46893 L .52816 .47006 L closepath p F P
0 g
s
.546 .389 .619 r
.70386 .5319 m .69294 .53705 L .69165 .52774 L p F P
0 g
s
.546 .389 .619 r
.69165 .52774 m .69386 .5267 L .70386 .5319 L p F P
0 g
s
.563 .165 .247 r
.56671 .60372 m .55103 .60493 L .54884 .60855 L p F P
0 g
s
.692 .327 .352 r
.47915 .60174 m .4808 .60329 L .47839 .60306 L closepath p F P
0 g
s
.67 .754 .913 r
.60203 .46942 m .62063 .46327 L .62524 .46837 L p F P
0 g
s
.664 .796 .945 r
.62063 .46327 m .60203 .46942 L .59735 .46522 L p F P
0 g
s
.655 .788 .945 r
.57883 .47085 m .59735 .46522 L .60203 .46942 L p F P
0 g
s
.627 .808 .969 r
.55562 .47213 m .57407 .46725 L .57883 .47085 L p F P
0 g
s
.613 .818 .979 r
.57252 .4664 m .57407 .46725 L .55562 .47213 L p F P
0 g
s
.613 .818 .979 r
.55562 .47213 m .55088 .4689 L .57252 .4664 L p F P
0 g
s
.63 .827 .976 r
.59735 .46522 m .57883 .47085 L .57407 .46725 L p F P
0 g
s
.816 .647 .674 r
.3567 .51458 m .35656 .51451 L .35664 .51471 L closepath p F P
0 g
s
.61 .545 .756 r
.69007 .48882 m .69911 .48418 L .70024 .48724 L closepath p F P
0 g
s
.649 .245 .265 r
.48956 .60893 m .4808 .60329 L .49824 .60468 L p F P
0 g
s
.649 .245 .265 r
.5003 .60977 m .48956 .60893 L p .49824 .60468 L F P
0 g
s
.649 .245 .265 r
.49824 .60468 m .50231 .60713 L .5003 .60977 L p F P
0 g
s
.779 .699 .776 r
.36461 .47439 m .35439 .4842 L .36311 .48879 L p F P
0 g
s
.794 .689 .749 r
.34804 .49712 m .35382 .50001 L .36311 .48879 L p F P
0 g
s
.794 .689 .749 r
.34614 .49385 m .34804 .49712 L p .36311 .48879 L F P
0 g
s
.794 .689 .749 r
.36311 .48879 m .35439 .4842 L .34614 .49385 L p F P
0 g
s
.671 .711 .878 r
.62524 .46837 m .64392 .46208 L .64851 .46835 L p F P
0 g
s
.675 .751 .908 r
.64392 .46208 m .62524 .46837 L .62063 .46327 L p F P
0 g
s
.828 .65 .661 r
.35292 .52393 m .35664 .51471 L .35656 .51451 L p F P
0 g
s
.818 .664 .693 r
.35144 .5036 m .34788 .51009 L .35656 .51451 L closepath p F P
0 g
s
.828 .65 .661 r
.34405 .51946 m .35292 .52393 L p .35656 .51451 L F P
0 g
s
.828 .65 .661 r
.35656 .51451 m .34788 .51009 L .34405 .51946 L p F P
0 g
s
.824 .613 .617 r
.36158 .53028 m .35988 .53711 L .36306 .5385 L closepath p F P
0 g
s
.641 .625 .819 r
.67188 .47019 m .67468 .47562 L .69162 .46687 L p F P
0 g
s
.631 .61 .811 r
.69547 .4752 m .69162 .46687 L .67468 .47562 L p F P
0 g
s
.521 .304 .526 r
.69367 .55345 m .6936 .54559 L .67574 .55282 L p F P
0 g
s
.521 .304 .526 r
.67574 .55282 m .67576 .56067 L .69367 .55345 L p F P
0 g
s
.737 .712 .827 r
.37885 .47532 m .38806 .46917 L .38268 .46266 L p F P
0 g
s
.737 .712 .827 r
.38268 .46266 m .36967 .47087 L .37885 .47532 L p F P
0 g
s
.751 .698 .802 r
.36461 .47439 m .36967 .47087 L .37885 .47532 L p F P
0 g
s
.545 .39 .621 r
.71022 .52886 m .70386 .5319 L .69386 .5267 L p F P
0 g
s
.545 .39 .621 r
.69386 .5267 m .70885 .51948 L .71022 .52886 L p F P
0 g
s
.66 .663 .841 r
.64851 .46835 m .66729 .46242 L .67188 .47019 L p F P
0 g
s
.67 .7 .869 r
.66729 .46242 m .64851 .46835 L .64392 .46208 L p F P
0 g
s
.812 .506 .472 r
.38123 .5692 m .39193 .57291 L .39013 .56528 L p F P
0 g
s
.812 .506 .472 r
.39013 .56528 m .37949 .56155 L .38123 .5692 L p F P
0 g
s
.563 .165 .247 r
.57023 .60836 m .57209 .60494 L .56671 .60372 L p F P
0 g
s
.563 .165 .247 r
.55297 .60967 m .57023 .60836 L p .56671 .60372 L F P
0 g
s
.563 .165 .247 r
.54884 .60855 m .55297 .60967 L p .56671 .60372 L F P
0 g
s
.562 .169 .255 r
.57308 .60319 m .57209 .60494 L .56671 .60372 L closepath p F P
0 g
s
.51 .174 .333 r
.63461 .59222 m .63643 .58626 L .6167 .59084 L p F P
0 g
s
.51 .174 .333 r
.6167 .59084 m .61479 .59679 L .63461 .59222 L p F P
0 g
s
.545 .206 .344 r
.59523 .59769 m .60517 .59852 L .5943 .60045 L closepath p F P
0 g
s
.66 .244 .244 r
.47438 .60749 m .48956 .60893 L .4808 .60329 L p F P
0 g
s
.66 .244 .244 r
.4808 .60329 m .47839 .60306 L .47438 .60749 L p F P
0 g
s
.657 .745 .915 r
.41133 .46701 m .42924 .4615 L .43452 .46672 L p F P
0 g
s
.635 .748 .93 r
.42924 .4615 m .41133 .46701 L .40599 .46111 L p F P
0 g
s
.703 .732 .874 r
.38806 .46917 m .40599 .46111 L .41133 .46701 L p F P
0 g
s
.534 .14 .24 r
.59162 .6057 m .5943 .60045 L .57308 .60319 L p F P
0 g
s
.534 .14 .24 r
.58479 .60657 m .59162 .6057 L p .57308 .60319 L F P
0 g
s
.534 .14 .24 r
.57308 .60319 m .57209 .60494 L .58479 .60657 L p F P
0 g
s
.807 .672 .714 r
.35382 .50001 m .34804 .49712 L .35144 .5036 L closepath p F P
0 g
s
.683 .273 .262 r
.4728 .60729 m .47438 .60749 L .47839 .60306 L p F P
0 g
s
.683 .273 .262 r
.47839 .60306 m .46504 .60135 L .4728 .60729 L p F P
0 g
s
.831 .59 .575 r
.35899 .54555 m .36319 .54736 L .36306 .5385 L p F P
0 g
s
.831 .59 .575 r
.36306 .5385 m .35988 .53711 L .35899 .54555 L p F P
0 g
s
.69 .737 .886 r
.40599 .46111 m .38806 .46917 L .38268 .46266 L p F P
0 g
s
.606 .761 .953 r
.43452 .46672 m .45249 .46299 L .45771 .46748 L p F P
0 g
s
.567 .761 .969 r
.45249 .46299 m .43452 .46672 L .42924 .4615 L p F P
0 g
s
.744 .359 .324 r
.42348 .59356 m .43653 .59644 L .43127 .5898 L p F P
0 g
s
.744 .359 .324 r
.42224 .59189 m .42348 .59356 L p .43127 .5898 L F P
0 g
s
.744 .359 .324 r
.43127 .5898 m .42532 .58849 L .42224 .59189 L p F P
0 g
s
.822 .674 .699 r
.34788 .51009 m .35144 .5036 L .34804 .49712 L p F P
0 g
s
.641 .625 .819 r
.69162 .46687 m .69082 .46524 L .67188 .47019 L p F P
0 g
s
.652 .646 .831 r
.69082 .46524 m .67188 .47019 L .66729 .46242 L p F P
0 g
s
.788 .44 .398 r
.39508 .58016 m .4066 .58358 L .40326 .57639 L p F P
0 g
s
.788 .44 .398 r
.39392 .57753 m .39508 .58016 L p .40326 .57639 L F P
0 g
s
.788 .44 .398 r
.40326 .57639 m .39626 .57431 L .39392 .57753 L p F P
0 g
s
.839 .598 .575 r
.34971 .54126 m .35899 .54555 L .35988 .53711 L p F P
0 g
s
.839 .598 .575 r
.35988 .53711 m .35065 .5328 L .34971 .54126 L p F P
0 g
s
.548 .779 .984 r
.47686 .46564 m .48093 .46859 L p .45771 .46748 L F P
0 g
s
.548 .779 .984 r
.45771 .46748 m .47354 .46519 L .47686 .46564 L p F P
0 g
s
.478 .767 .994 r
.47354 .46519 m .45771 .46748 L .45249 .46299 L p F P
0 g
s
.522 .339 .574 r
.70664 .53947 m .6936 .54559 L .69294 .53705 L p F P
0 g
s
.522 .339 .574 r
.69294 .53705 m .70386 .5319 L .70664 .53947 L p F P
0 g
s
.518 .227 .411 r
.65557 .58081 m .65571 .57996 L .63688 .58386 L p F P
0 g
s
.518 .227 .411 r
.63688 .58386 m .63643 .58626 L .65557 .58081 L p F P
0 g
s
.634 .227 .255 r
.50231 .60713 m .50787 .61007 L .5003 .60977 L closepath p F P
0 g
s
.757 .378 .336 r
.42532 .58849 m .42224 .59189 L .41857 .58682 L closepath p F P
0 g
s
.681 .252 .222 r
.45767 .60511 m .4728 .60729 L .46504 .60135 L p F P
0 g
s
.681 .252 .222 r
.45071 .59958 m .45767 .60511 L p .46504 .60135 L F P
0 g
s
.681 .252 .222 r
.46504 .60135 m .45107 .59927 L .45071 .59958 L p F P
0 g
s
.838 .63 .621 r
.34173 .52835 m .35065 .5328 L .35292 .52393 L p F P
0 g
s
.838 .63 .621 r
.35292 .52393 m .34405 .51946 L .34173 .52835 L p F P
0 g
s
.828 .554 .524 r
.36165 .55459 m .36922 .55766 L .36877 .54963 L p F P
0 g
s
.828 .554 .524 r
.36877 .54963 m .36319 .54736 L .36165 .55459 L p F P
0 g
s
.564 .474 .711 r
.72333 .49982 m .72017 .48816 L .70364 .4976 L p F P
0 g
s
.564 .474 .711 r
.71543 .50433 m .72333 .49982 L p .70364 .4976 L F P
0 g
s
.564 .474 .711 r
.70364 .4976 m .70523 .50327 L .71543 .50433 L p F P
0 g
s
.588 .513 .738 r
.70024 .48724 m .70364 .4976 L .72017 .48816 L p F P
0 g
s
.589 .533 .76 r
.69911 .48418 m .70024 .48724 L .71956 .48621 L p F P
0 g
s
.588 .513 .738 r
.72017 .48816 m .71956 .48621 L .70024 .48724 L p F P
0 g
s
.746 .706 .814 r
.36967 .47087 m .36461 .47439 L .35919 .46722 L p F P
0 g
s
.777 .705 .783 r
.35439 .4842 m .36461 .47439 L .35919 .46722 L p F P
0 g
s
.536 .145 .248 r
.57209 .60494 m .58479 .60657 L .57023 .60836 L closepath p F P
0 g
s
.497 .11 .237 r
.60517 .59852 m .5943 .60045 L .59162 .6057 L p F P
0 g
s
.822 .674 .699 r
.33936 .50545 m .34788 .51009 L p .34804 .49712 L F P
0 g
s
.834 .657 .663 r
.33547 .51485 m .34405 .51946 L .34788 .51009 L p F P
0 g
s
.834 .657 .663 r
.34788 .51009 m .33936 .50545 L .33547 .51485 L p F P
0 g
s
.822 .674 .699 r
.34804 .49712 m .34504 .49546 L .33936 .50545 L p F P
0 g
s
.811 .684 .723 r
.34614 .49385 m .34504 .49546 L .34804 .49712 L closepath p F P
0 g
s
.777 .705 .783 r
.35919 .46722 m .34591 .47949 L .35439 .4842 L p F P
0 g
s
.793 .688 .749 r
.34076 .48524 m .34591 .47949 L .35439 .4842 L p F P
0 g
s
.793 .688 .749 r
.35439 .4842 m .34614 .49385 L .34076 .48524 L p F P
0 g
s
.566 .462 .695 r
.70523 .50327 m .71543 .50433 L .70673 .50916 L closepath p F P
0 g
s
.609 .562 .776 r
.69547 .4752 m .69911 .48418 L .71551 .47452 L p F P
0 g
s
.589 .533 .76 r
.71956 .48621 m .71551 .47452 L .69911 .48418 L p F P
0 g
s
.821 .512 .467 r
.37092 .56532 m .38123 .5692 L .37949 .56155 L p F P
0 g
s
.821 .512 .467 r
.37949 .56155 m .36922 .55766 L .37092 .56532 L p F P
0 g
s
.495 .793 .998 r
.50364 .46911 m .50418 .46943 L p .48093 .46859 L F P
0 g
s
.495 .793 .998 r
.48093 .46859 m .48803 .46776 L .50364 .46911 L p F P
0 g
s
.531 .77 .985 r
.48093 .46859 m .48803 .46776 L .47686 .46564 L closepath p F P
0 g
s
.797 .453 .405 r
.39626 .57431 m .39392 .57753 L .39193 .57291 L closepath p F P
0 g
s
.483 .195 .399 r
.67451 .57206 m .67522 .56788 L .65672 .57421 L p F P
0 g
s
.483 .195 .399 r
.65672 .57421 m .65571 .57996 L .67451 .57206 L p F P
0 g
s
.732 .714 .834 r
.36967 .47087 m .38268 .46266 L .37725 .45635 L p F P
0 g
s
.732 .714 .834 r
.37725 .45635 m .36046 .4664 L .36967 .47087 L p F P
0 g
s
.746 .706 .814 r
.35919 .46722 m .36046 .4664 L .36967 .47087 L p F P
0 g
s
.758 .378 .334 r
.4113 .59038 m .4066 .58358 L .41857 .58682 L p F P
0 g
s
.758 .378 .334 r
.42121 .59302 m .4113 .59038 L p .41857 .58682 L F P
0 g
s
.758 .378 .334 r
.41857 .58682 m .42224 .59189 L .42121 .59302 L p F P
0 g
s
.605 .207 .261 r
.52556 .60929 m .52849 .61048 L .52475 .61053 L closepath p F P
0 g
s
.548 .425 .664 r
.72553 .51025 m .70885 .51948 L .70673 .50916 L p F P
0 g
s
.548 .425 .664 r
.72489 .50705 m .72553 .51025 L p .70673 .50916 L F P
0 g
s
.548 .425 .664 r
.70673 .50916 m .71543 .50433 L .72489 .50705 L p F P
0 g
s
.489 .241 .465 r
.69321 .56018 m .69367 .55345 L .67576 .56067 L p F P
0 g
s
.489 .241 .465 r
.69213 .56109 m .69321 .56018 L p .67576 .56067 L F P
0 g
s
.489 .241 .465 r
.67576 .56067 m .67522 .56788 L .69213 .56109 L p F P
0 g
s
.573 .179 .259 r
.54884 .60855 m .55297 .60967 L .54799 .61001 L closepath p F P
0 g
s
.701 .279 .24 r
.45107 .59927 m .45071 .59958 L .45016 .59911 L closepath p F P
0 g
s
.597 .809 .981 r
.55029 .46893 m .52816 .47006 L .52747 .46959 L p F P
0 g
s
.577 .803 .985 r
.52816 .47006 m .52747 .46959 L .52518 .47003 L closepath p F P
0 g
s
.488 .806 1 r
.50418 .46943 m .50557 .46926 L .52518 .47003 L p F P
0 g
s
.544 .83 .998 r
.52249 .46698 m .50557 .46926 L .52518 .47003 L p F P
0 g
s
.544 .83 .998 r
.52518 .47003 m .52747 .46959 L .52249 .46698 L p F P
0 g
s
.474 .141 .321 r
.65382 .58677 m .65557 .58081 L .63643 .58626 L p F P
0 g
s
.474 .141 .321 r
.63643 .58626 m .63461 .59222 L .65382 .58677 L p F P
0 g
s
.813 .692 .73 r
.34504 .49546 m .34614 .49385 L .34076 .48524 L p F P
0 g
s
.702 .278 .239 r
.44336 .60265 m .43653 .59644 L .45016 .59911 L p F P
0 g
s
.702 .278 .239 r
.44648 .60325 m .44336 .60265 L p .45016 .59911 L F P
0 g
s
.702 .278 .239 r
.45016 .59911 m .45071 .59958 L .44648 .60325 L p F P
0 g
s
.509 .796 .997 r
.50418 .46943 m .50557 .46926 L .50364 .46911 L closepath p F P
0 g
s
.835 .561 .525 r
.35935 .55361 m .36165 .55459 L .36319 .54736 L p F P
0 g
s
.835 .561 .525 r
.36319 .54736 m .35899 .54555 L .35935 .55361 L p F P
0 g
s
.675 .751 .908 r
.62063 .46327 m .63935 .45684 L .64392 .46208 L p F P
0 g
s
.676 .794 .937 r
.63935 .45684 m .62063 .46327 L .61601 .45915 L p F P
0 g
s
.664 .796 .945 r
.59735 .46522 m .61601 .45915 L .62063 .46327 L p F P
0 g
s
.67 .7 .869 r
.64392 .46208 m .66273 .45579 L .66729 .46242 L p F P
0 g
s
.678 .74 .897 r
.66273 .45579 m .64392 .46208 L .63935 .45684 L p F P
0 g
s
.813 .692 .73 r
.34076 .48524 m .3369 .49064 L .34504 .49546 L p F P
0 g
s
.826 .681 .703 r
.33113 .50067 m .33936 .50545 L .34504 .49546 L p F P
0 g
s
.826 .681 .703 r
.34504 .49546 m .3369 .49064 L .33113 .50067 L p F P
0 g
s
.609 .562 .776 r
.71551 .47452 m .71468 .47236 L .69547 .4752 L p F P
0 g
s
.611 .59 .805 r
.69162 .46687 m .69547 .4752 L .71468 .47236 L p F P
0 g
s
.799 .454 .403 r
.38423 .57649 m .38123 .5692 L .39193 .57291 L p F P
0 g
s
.799 .454 .403 r
.39257 .57935 m .38423 .57649 L p .39193 .57291 L F P
0 g
s
.799 .454 .403 r
.39193 .57291 m .39392 .57753 L .39257 .57935 L p F P
0 g
s
.693 .267 .231 r
.45071 .59958 m .45767 .60511 L .44648 .60325 L closepath p F P
0 g
s
.649 .835 .972 r
.61601 .45915 m .59735 .46522 L .59266 .46195 L p F P
0 g
s
.63 .827 .976 r
.57407 .46725 m .59266 .46195 L .59735 .46522 L p F P
0 g
s
.495 .108 .235 r
.61479 .59679 m .61399 .5984 L .60517 .59852 L closepath p F P
0 g
s
.497 .11 .237 r
.61225 .60208 m .61399 .5984 L .60517 .59852 L p F P
0 g
s
.497 .11 .237 r
.59162 .6057 m .61225 .60208 L p .60517 .59852 L F P
0 g
s
.514 .796 .997 r
.51746 .46505 m .52249 .46698 L .50557 .46926 L p F P
0 g
s
.514 .796 .997 r
.49911 .46637 m .51746 .46505 L p .50557 .46926 L F P
0 g
s
.514 .796 .997 r
.50557 .46926 m .50364 .46911 L .49911 .46637 L p F P
0 g
s
.507 .794 .997 r
.50364 .46911 m .49911 .46637 L .48803 .46776 L closepath p F P
0 g
s
.597 .809 .981 r
.52747 .46959 m .54589 .46637 L p .55029 .46893 L F P
0 g
s
.394 .808 .977 r
.54589 .46637 m .52747 .46959 L .52249 .46698 L p F P
0 g
s
.597 .81 .982 r
.55088 .4689 m .55077 .46882 L .55029 .46893 L closepath p F P
0 g
s
.597 .809 .981 r
.54589 .46637 m .55077 .46882 L .55029 .46893 L p F P
0 g
s
.612 .853 .989 r
.59262 .46193 m .59266 .46195 L .57407 .46725 L p F P
0 g
s
.612 .853 .989 r
.57407 .46725 m .57252 .4664 L .59262 .46193 L p F P
0 g
s
.599 .811 .981 r
.56929 .46457 m .57252 .4664 L .55088 .4689 L p F P
0 g
s
.599 .811 .981 r
.55088 .4689 m .55077 .46882 L .56929 .46457 L p F P
0 g
s
.482 .846 .991 r
.56929 .46457 m .55077 .46882 L .54589 .46637 L p F P
0 g
s
.635 .748 .93 r
.40599 .46111 m .42391 .45648 L .42924 .4615 L p F P
0 g
s
.611 .747 .942 r
.42391 .45648 m .40599 .46111 L .40061 .45539 L p F P
0 g
s
.69 .737 .886 r
.38268 .46266 m .40061 .45539 L .40599 .46111 L p F P
0 g
s
.652 .646 .831 r
.66729 .46242 m .68623 .45688 L .69082 .46524 L p F P
0 g
s
.664 .682 .857 r
.68623 .45688 m .66729 .46242 L .66273 .45579 L p F P
0 g
s
.677 .738 .897 r
.40061 .45539 m .38268 .46266 L .37725 .45635 L p F P
0 g
s
.549 .092 .122 r
.52849 .61048 m .52475 .61053 L .52063 .61465 L p F P
0 g
s
.586 .136 .15 r
.52035 .61464 m .52063 .61465 L .52475 .61053 L p F P
0 g
s
.586 .136 .15 r
.52475 .61053 m .50787 .61007 L .52035 .61464 L p F P
0 g
s
.554 .109 .148 r
.54799 .61001 m .52849 .61048 L .54333 .61434 L p F P
0 g
s
.549 .092 .122 r
.52063 .61465 m .54333 .61434 L .52849 .61048 L p F P
0 g
s
.846 .606 .575 r
.34076 .53682 m .34971 .54126 L .35065 .5328 L p F P
0 g
s
.846 .606 .575 r
.35065 .5328 m .34173 .52835 L .34076 .53682 L p F P
0 g
s
.492 .282 .521 r
.70275 .54921 m .69367 .55345 L .6936 .54559 L p F P
0 g
s
.492 .282 .521 r
.6936 .54559 m .70664 .53947 L .70275 .54921 L p F P
0 g
s
.843 .569 .523 r
.35003 .54933 m .35935 .55361 L .35899 .54555 L p F P
0 g
s
.843 .569 .523 r
.35899 .54555 m .34971 .54126 L .35003 .54933 L p F P
0 g
s
.579 .114 .113 r
.50076 .61388 m .52035 .61464 L .50787 .61007 L p F P
0 g
s
.579 .114 .113 r
.49716 .61243 m .50076 .61388 L p .50787 .61007 L F P
0 g
s
.579 .114 .113 r
.50787 .61007 m .5003 .60977 L .49716 .61243 L p F P
0 g
s
.534 .77 .984 r
.49398 .46383 m .49911 .46637 L .48803 .46776 L p F P
0 g
s
.534 .77 .984 r
.47577 .46485 m .49398 .46383 L p .48803 .46776 L F P
0 g
s
.534 .77 .984 r
.48803 .46776 m .47686 .46564 L .47577 .46485 L p F P
0 g
s
.522 .373 .621 r
.72693 .51965 m .72553 .51025 L .70885 .51948 L p F P
0 g
s
.522 .373 .621 r
.70885 .51948 m .71022 .52886 L .72693 .51965 L p F P
0 g
s
.512 .063 .12 r
.55297 .60967 m .54799 .61001 L .54418 .61432 L p F P
0 g
s
.554 .109 .148 r
.54333 .61434 m .54418 .61432 L .54799 .61001 L p F P
0 g
s
.845 .637 .622 r
.33312 .52376 m .34173 .52835 L .34405 .51946 L p F P
0 g
s
.845 .637 .622 r
.34405 .51946 m .33547 .51485 L .33312 .52376 L p F P
0 g
s
.567 .761 .969 r
.42924 .4615 m .44721 .45877 L .45249 .46299 L p F P
0 g
s
.512 .757 .984 r
.44721 .45877 m .42924 .4615 L .42391 .45648 L p F P
0 g
s
.613 .155 .141 r
.5003 .60977 m .49716 .61243 L .48956 .60893 L closepath p F P
0 g
s
.456 .069 .216 r
.63286 .59602 m .63461 .59222 L .61479 .59679 L p F P
0 g
s
.456 .069 .216 r
.61479 .59679 m .61399 .5984 L .63286 .59602 L p F P
0 g
s
.516 .074 .138 r
.57023 .60836 m .56743 .61183 L .55297 .60967 L closepath p F P
0 g
s
.512 .063 .12 r
.56666 .61281 m .56743 .61183 L .55297 .60967 L p F P
0 g
s
.512 .063 .12 r
.54418 .61432 m .56666 .61281 L p .55297 .60967 L F P
0 g
s
.519 .338 .575 r
.71092 .53743 m .70664 .53947 L .70386 .5319 L p F P
0 g
s
.519 .338 .575 r
.70386 .5319 m .71022 .52886 L .71092 .53743 L p F P
0 g
s
.775 .387 .32 r
.3997 .58698 m .4113 .59038 L .4066 .58358 L p F P
0 g
s
.775 .387 .32 r
.4066 .58358 m .39508 .58016 L .3997 .58698 L p F P
0 g
s
.829 .514 .457 r
.36098 .56129 m .37092 .56532 L .36922 .55766 L p F P
0 g
s
.829 .514 .457 r
.36012 .55726 m .36098 .56129 L p .36922 .55766 L F P
0 g
s
.829 .514 .457 r
.36922 .55766 m .36165 .55459 L .36012 .55726 L p F P
0 g
s
.72 .293 .233 r
.43014 .59981 m .44336 .60265 L .43653 .59644 L p F P
0 g
s
.72 .293 .233 r
.43653 .59644 m .42348 .59356 L .43014 .59981 L p F P
0 g
s
.629 .61 .813 r
.69082 .46524 m .69631 .46406 L .69162 .46687 L closepath p F P
0 g
s
.611 .59 .805 r
.70997 .46133 m .69631 .46406 L .69162 .46687 L p F P
0 g
s
.611 .59 .805 r
.71468 .47236 m .70997 .46133 L p .69162 .46687 L F P
0 g
s
.84 .665 .665 r
.32718 .5101 m .33547 .51485 L .33936 .50545 L p F P
0 g
s
.84 .665 .665 r
.33936 .50545 m .33113 .50067 L .32718 .5101 L p F P
0 g
s
.741 .713 .825 r
.36046 .4664 m .35724 .46476 L .35919 .46722 L closepath p F P
0 g
s
.78 .717 .793 r
.34591 .47949 m .35919 .46722 L .35724 .46476 L p F P
0 g
s
.604 .127 .094 r
.49579 .61361 m .49716 .61243 L .48956 .60893 L p F P
0 g
s
.604 .127 .094 r
.4832 .61246 m .49579 .61361 L p .48956 .60893 L F P
0 g
s
.604 .127 .094 r
.47385 .60786 m .4832 .61246 L p .48956 .60893 L F P
0 g
s
.604 .127 .094 r
.48956 .60893 m .47438 .60749 L .47385 .60786 L p F P
0 g
s
.78 .717 .793 r
.33767 .47465 m .34591 .47949 L p .35724 .46476 L F P
0 g
s
.794 .698 .759 r
.33531 .47717 m .33767 .47465 L .34591 .47949 L p F P
0 g
s
.794 .698 .759 r
.34591 .47949 m .34076 .48524 L .33531 .47717 L p F P
0 g
s
.599 .846 .991 r
.58795 .45968 m .59262 .46193 L .57252 .4664 L p F P
0 g
s
.599 .846 .991 r
.57252 .4664 m .56929 .46457 L .58795 .45968 L p F P
0 g
s
.737 .714 .83 r
.36046 .4664 m .37725 .45635 L p .35371 .46038 L F P
0 g
s
.737 .714 .83 r
.35371 .46038 m .35724 .46476 L .36046 .4664 L p F P
0 g
s
.64 .625 .82 r
.69631 .46406 m .69082 .46524 L .68623 .45688 L p F P
0 g
s
.478 .767 .994 r
.45249 .46299 m .45941 .46247 L .47354 .46519 L p F P
0 g
s
.43 .73 .989 r
.45941 .46247 m .45249 .46299 L .44721 .45877 L p F P
0 g
s
.471 .025 .109 r
.58479 .60657 m .57023 .60836 L .56743 .61183 L p F P
0 g
s
.815 .7 .737 r
.3369 .49064 m .34076 .48524 L .33531 .47717 L p F P
0 g
s
.797 .451 .401 r
.39392 .57753 m .39508 .58016 L .39257 .57935 L closepath p F P
0 g
s
.558 .778 .981 r
.47686 .46564 m .47577 .46485 L .47354 .46519 L closepath p F P
0 g
s
.754 .372 .331 r
.42224 .59189 m .42348 .59356 L .42121 .59302 L closepath p F P
0 g
s
.815 .466 .395 r
.37386 .57263 m .38423 .57649 L .38123 .5692 L p F P
0 g
s
.815 .466 .395 r
.38123 .5692 m .37092 .56532 L .37386 .57263 L p F P
0 g
s
.546 .427 .668 r
.71543 .50433 m .72333 .49982 L .72489 .50705 L closepath p F P
0 g
s
.542 .794 .991 r
.47056 .4615 m .45941 .46247 L .47354 .46519 L p F P
0 g
s
.542 .794 .991 r
.47354 .46519 m .47577 .46485 L .47056 .4615 L p F P
0 g
s
.486 .2 .405 r
.67412 .57447 m .67451 .57206 L .65571 .57996 L p F P
0 g
s
.486 .2 .405 r
.65571 .57996 m .65557 .58081 L .67412 .57447 L p F P
0 g
s
.634 .165 .122 r
.47438 .60749 m .47385 .60786 L .4728 .60729 L closepath p F P
0 g
s
.461 .079 .228 r
.63219 .59754 m .63286 .59602 L .61399 .5984 L p F P
0 g
s
.461 .079 .228 r
.61399 .5984 m .61225 .60208 L .63219 .59754 L p F P
0 g
s
.634 .165 .122 r
.46701 .6106 m .45767 .60511 L .4728 .60729 L p F P
0 g
s
.634 .165 .122 r
.46933 .61093 m .46701 .6106 L p .4728 .60729 L F P
0 g
s
.634 .165 .122 r
.4728 .60729 m .47385 .60786 L .46933 .61093 L p F P
0 g
s
.767 .721 .809 r
.35371 .46038 m .35229 .46151 L .35724 .46476 L closepath p F P
0 g
s
.78 .717 .793 r
.35724 .46476 m .35229 .46151 L .33767 .47465 L p F P
0 g
s
.831 .689 .706 r
.32318 .49575 m .33113 .50067 L .3369 .49064 L p F P
0 g
s
.831 .689 .706 r
.3369 .49064 m .32904 .48568 L .32318 .49575 L p F P
0 g
s
.815 .7 .737 r
.33531 .47717 m .32904 .48568 L .3369 .49064 L p F P
0 g
s
.446 .162 .387 r
.67522 .56788 m .67451 .57206 L .69213 .56109 L closepath p F P
0 g
s
.434 .105 .306 r
.67245 .58042 m .67412 .57447 L .65557 .58081 L p F P
0 g
s
.434 .105 .306 r
.65557 .58081 m .65382 .58677 L .67245 .58042 L p F P
0 g
s
.248 .715 .946 r
.49398 .46383 m .47577 .46485 L .47056 .4615 L p F P
0 g
s
.492 .318 .572 r
.72769 .52825 m .72693 .51965 L .71022 .52886 L p F P
0 g
s
.492 .318 .572 r
.71022 .52886 m .71092 .53743 L .72769 .52825 L p F P
0 g
s
.64 .625 .82 r
.70775 .45673 m .69631 .46406 L p .68623 .45688 L F P
0 g
s
.625 .608 .813 r
.69631 .46406 m .70775 .45673 L .70997 .46133 L closepath p F P
0 g
s
.471 .03 .117 r
.59162 .6057 m .59079 .6068 L .58479 .60657 L closepath p F P
0 g
s
.471 .025 .109 r
.58824 .61024 m .59079 .6068 L .58479 .60657 L p F P
0 g
s
.471 .025 .109 r
.57236 .61216 m .58824 .61024 L p .58479 .60657 L F P
0 g
s
.471 .025 .109 r
.56743 .61183 m .57236 .61216 L p .58479 .60657 L F P
0 g
s
.723 .284 .207 r
.41749 .59676 m .43014 .59981 L .42348 .59356 L p F P
0 g
s
.723 .284 .207 r
.41658 .59585 m .41749 .59676 L p .42348 .59356 L F P
0 g
s
.723 .284 .207 r
.42348 .59356 m .42121 .59302 L .41658 .59585 L p F P
0 g
s
.619 .145 .108 r
.47385 .60786 m .4832 .61246 L .46933 .61093 L closepath p F P
0 g
s
.836 .524 .461 r
.36165 .55459 m .36012 .55726 L .35935 .55361 L closepath p F P
0 g
s
.854 .613 .574 r
.33213 .53223 m .34076 .53682 L .34173 .52835 L p F P
0 g
s
.854 .613 .574 r
.34173 .52835 m .33312 .52376 L .33213 .53223 L p F P
0 g
s
.678 .74 .897 r
.63935 .45684 m .65819 .45019 L .66273 .45579 L p F P
0 g
s
.685 .781 .924 r
.65819 .45019 m .63935 .45684 L .63478 .45256 L p F P
0 g
s
.676 .794 .937 r
.61601 .45915 m .63478 .45256 L .63935 .45684 L p F P
0 g
s
.781 .384 .302 r
.38854 .5834 m .3997 .58698 L .39508 .58016 L p F P
0 g
s
.781 .384 .302 r
.38803 .58259 m .38854 .5834 L p .39508 .58016 L F P
0 g
s
.781 .384 .302 r
.39508 .58016 m .39257 .57935 L .38803 .58259 L p F P
0 g
s
.852 .576 .521 r
.34104 .54491 m .35003 .54933 L .34971 .54126 L p F P
0 g
s
.852 .576 .521 r
.34971 .54126 m .34076 .53682 L .34104 .54491 L p F P
0 g
s
.664 .682 .857 r
.66273 .45579 m .68168 .44969 L .68623 .45688 L p F P
0 g
s
.676 .72 .882 r
.68168 .44969 m .66273 .45579 L .65819 .45019 L p F P
0 g
s
.74 .308 .226 r
.42121 .59302 m .41658 .59585 L .4113 .59038 L closepath p F P
0 g
s
.429 0 .091 r
.60963 .60581 m .61225 .60208 L .59162 .6057 L p F P
0 g
s
.429 0 .091 r
.59162 .6057 m .59079 .6068 L .60963 .60581 L p F P
0 g
s
.677 .738 .897 r
.37725 .45635 m .39519 .44978 L .40061 .45539 L p F P
0 g
s
.664 .738 .905 r
.39519 .44978 m .37725 .45635 L .37178 .45018 L p F P
0 g
s
.737 .714 .83 r
.37725 .45635 m .37178 .45018 L .35371 .46038 L p F P
0 g
s
.852 .645 .623 r
.3248 .51902 m .33312 .52376 L .33547 .51485 L p F P
0 g
s
.852 .645 .623 r
.33547 .51485 m .32718 .5101 L .3248 .51902 L p F P
0 g
s
.668 .845 .967 r
.63021 .44922 m .63478 .45256 L .61601 .45915 L p F P
0 g
s
.668 .845 .967 r
.62837 .44988 m .63021 .44922 L p .61601 .45915 L F P
0 g
s
.668 .845 .967 r
.61601 .45915 m .61197 .45639 L .62837 .44988 L p F P
0 g
s
.649 .835 .972 r
.61197 .45639 m .61601 .45915 L p .59266 .46195 L F P
0 g
s
.611 .747 .942 r
.40061 .45539 m .41853 .45157 L .42391 .45648 L p F P
0 g
s
.586 .743 .951 r
.41853 .45157 m .40061 .45539 L .39519 .44978 L p F P
0 g
s
.839 .526 .459 r
.35154 .55705 m .35003 .54933 L .35935 .55361 L p F P
0 g
s
.839 .526 .459 r
.35838 .56016 m .35154 .55705 L p .35935 .55361 L F P
0 g
s
.839 .526 .459 r
.35935 .55361 m .36012 .55726 L .35838 .56016 L p F P
0 g
s
.456 .214 .457 r
.69367 .55345 m .69321 .56018 L .70275 .54921 L closepath p F P
0 g
s
.792 .401 .314 r
.39257 .57935 m .38803 .58259 L .38423 .57649 L closepath p F P
0 g
s
.416 .035 .206 r
.65182 .59132 m .65382 .58677 L .63461 .59222 L p F P
0 g
s
.416 .035 .206 r
.63461 .59222 m .63286 .59602 L .65182 .59132 L p F P
0 g
s
.43 .73 .989 r
.44721 .45877 m .44807 .45876 L .45941 .46247 L p F P
0 g
s
.468 .78 .998 r
.46531 .45845 m .44807 .45876 L .45941 .46247 L p F P
0 g
s
.468 .78 .998 r
.45941 .46247 m .47056 .4615 L .46531 .45845 L p F P
0 g
s
.156 .681 .873 r
.51746 .46505 m .49911 .46637 L .49398 .46383 L p F P
0 g
s
.638 .149 .076 r
.45231 .60824 m .46701 .6106 L .45767 .60511 L p F P
0 g
s
.638 .149 .076 r
.44524 .60387 m .45231 .60824 L p .45767 .60511 L F P
0 g
s
.638 .149 .076 r
.45767 .60511 m .44648 .60325 L .44524 .60387 L p F P
0 g
s
.567 .492 .731 r
.71956 .48621 m .72281 .48642 L .72017 .48816 L closepath p F P
0 g
s
.564 .508 .751 r
.71551 .47452 m .71956 .48621 L .72281 .48642 L p F P
0 g
s
.55 .459 .705 r
.73923 .48947 m .72333 .49982 L .72017 .48816 L p F P
0 g
s
.55 .459 .705 r
.72017 .48816 m .72281 .48642 L .73923 .48947 L p F P
0 g
s
.649 .835 .972 r
.59266 .46195 m .59447 .46137 L .61197 .45639 L p F P
0 g
s
.617 .878 .99 r
.59266 .46195 m .59447 .46137 L .59262 .46193 L closepath p F P
0 g
s
.64 .625 .82 r
.68623 .45688 m .70536 .45203 L .70775 .45673 L p F P
0 g
s
.653 .658 .842 r
.70536 .45203 m .68623 .45688 L .68168 .44969 L p F P
0 g
s
.621 .875 .989 r
.59447 .46137 m .59262 .46193 L .58795 .45968 L p F P
0 g
s
.845 .673 .668 r
.31919 .5052 m .32718 .5101 L .33113 .50067 L p F P
0 g
s
.845 .673 .668 r
.33113 .50067 m .32318 .49575 L .31919 .5052 L p F P
0 g
s
.78 .722 .798 r
.33001 .46986 m .33767 .47465 L .35229 .46151 L p F P
0 g
s
.795 .708 .768 r
.33767 .47465 m .33001 .46986 L .33531 .47717 L closepath p F P
0 g
s
.489 .278 .52 r
.71104 .54529 m .70275 .54921 L .70664 .53947 L p F P
0 g
s
.489 .278 .52 r
.70664 .53947 m .71092 .53743 L .71104 .54529 L p F P
0 g
s
.59 .542 .769 r
.71468 .47236 m .71911 .47208 L .71551 .47452 L closepath p F P
0 g
s
.564 .508 .751 r
.73424 .47199 m .71911 .47208 L .71551 .47452 L p F P
0 g
s
.564 .508 .751 r
.73603 .47747 m .73424 .47199 L p .71551 .47452 L F P
0 g
s
.564 .508 .751 r
.72281 .48642 m .73603 .47747 L p .71551 .47452 L F P
0 g
s
.766 .725 .815 r
.35229 .46151 m .35371 .46038 L .34819 .45376 L p F P
0 g
s
.766 .725 .815 r
.34819 .45376 m .34489 .4563 L .35229 .46151 L p F P
0 g
s
.78 .722 .798 r
.32979 .46958 m .33001 .46986 L p .35229 .46151 L F P
0 g
s
.78 .722 .798 r
.35229 .46151 m .34489 .4563 L .32979 .46958 L p F P
0 g
s
.824 .47 .386 r
.36388 .5686 m .37386 .57263 L .37092 .56532 L p F P
0 g
s
.824 .47 .386 r
.37092 .56532 m .36098 .56129 L .36388 .5686 L p F P
0 g
s
.819 .709 .744 r
.32904 .48568 m .33531 .47717 L .33001 .46986 L p F P
0 g
s
.512 .757 .984 r
.44636 .45812 m .44721 .45877 L p .42391 .45648 L F P
0 g
s
.512 .757 .984 r
.42391 .45648 m .43562 .45541 L .44636 .45812 L p F P
0 g
s
.473 .729 .982 r
.43562 .45541 m .42391 .45648 L .41853 .45157 L p F P
0 g
s
.723 .735 .86 r
.37178 .45018 m .35371 .46038 L .34819 .45376 L p F P
0 g
s
.648 .836 .973 r
.61197 .45639 m .61138 .45598 L .59447 .46137 L closepath p F P
0 g
s
.621 .875 .989 r
.60674 .45382 m .61138 .45598 L .59447 .46137 L p F P
0 g
s
.621 .875 .989 r
.58795 .45968 m .60674 .45382 L p .59447 .46137 L F P
0 g
s
.394 .808 .977 r
.52249 .46698 m .54097 .46473 L .54589 .46637 L p F P
0 g
s
.18 .707 .858 r
.54097 .46473 m .52249 .46698 L .51746 .46505 L p F P
0 g
s
.603 .556 .775 r
.71911 .47208 m .71468 .47236 L .70997 .46133 L p F P
0 g
s
.486 .866 .978 r
.58795 .45968 m .56929 .46457 L .56448 .46281 L p F P
0 g
s
.482 .846 .991 r
.54589 .46637 m .56448 .46281 L .56929 .46457 L p F P
0 g
s
.316 .792 .916 r
.56448 .46281 m .54589 .46637 L .54097 .46473 L p F P
0 g
s
.515 .406 .669 r
.73939 .48954 m .73923 .48947 L .72333 .49982 L p F P
0 g
s
.515 .406 .669 r
.7416 .49986 m .73939 .48954 L p .72333 .49982 L F P
0 g
s
.515 .406 .669 r
.72801 .50868 m .7416 .49986 L p .72333 .49982 L F P
0 g
s
.515 .406 .669 r
.72333 .49982 m .72489 .50705 L .72801 .50868 L p F P
0 g
s
.435 0 .104 r
.60903 .60669 m .60963 .60581 L .59079 .6068 L p F P
0 g
s
.435 0 .104 r
.59079 .6068 m .58824 .61024 L .60903 .60669 L p F P
0 g
s
.593 .132 .128 r
.49716 .61243 m .50076 .61388 L .49579 .61361 L closepath p F P
0 g
s
.741 .307 .221 r
.40568 .59342 m .3997 .58698 L .4113 .59038 L p F P
0 g
s
.741 .307 .221 r
.41578 .59631 m .40568 .59342 L p .4113 .59038 L F P
0 g
s
.741 .307 .221 r
.4113 .59038 m .41658 .59585 L .41578 .59631 L p F P
0 g
s
.549 .463 .71 r
.73936 .48939 m .73923 .48947 L .72281 .48642 L p F P
0 g
s
.549 .463 .71 r
.72281 .48642 m .73603 .47747 L .73936 .48939 L p F P
0 g
s
.664 .185 .104 r
.44648 .60325 m .44524 .60387 L .44336 .60265 L closepath p F P
0 g
s
.838 .524 .458 r
.36012 .55726 m .36098 .56129 L .35838 .56016 L closepath p F P
0 g
s
.451 .169 .393 r
.69213 .56109 m .67451 .57206 L .67412 .57447 L p F P
0 g
s
.664 .183 .1 r
.4384 .60561 m .43014 .59981 L .44336 .60265 L p F P
0 g
s
.664 .183 .1 r
.44068 .60609 m .4384 .60561 L p .44336 .60265 L F P
0 g
s
.664 .183 .1 r
.44336 .60265 m .44524 .60387 L .44068 .60609 L p F P
0 g
s
.835 .696 .71 r
.31553 .49068 m .32318 .49575 L .32904 .48568 L p F P
0 g
s
.835 .696 .71 r
.32904 .48568 m .32147 .48057 L .31553 .49068 L p F P
0 g
s
.819 .709 .744 r
.32147 .48057 m .32904 .48568 L p .33001 .46986 L F P
0 g
s
.794 .401 .309 r
.37804 .57957 m .37386 .57263 L .38423 .57649 L p F P
0 g
s
.794 .401 .309 r
.38741 .58301 m .37804 .57957 L p .38423 .57649 L F P
0 g
s
.794 .401 .309 r
.38423 .57649 m .38803 .58259 L .38741 .58301 L p F P
0 g
s
.457 .254 .515 r
.72786 .53612 m .72769 .52825 L .71092 .53743 L p F P
0 g
s
.457 .254 .515 r
.71092 .53743 m .71104 .54529 L .72786 .53612 L p F P
0 g
s
.445 .724 .985 r
.44721 .45877 m .44807 .45876 L .44636 .45812 L closepath p F P
0 g
s
.522 .402 .658 r
.72489 .50705 m .72801 .50868 L .72553 .51025 L closepath p F P
0 g
s
.388 0 .083 r
.6291 .60218 m .63219 .59754 L .61225 .60208 L p F P
0 g
s
.388 0 .083 r
.61974 .60429 m .6291 .60218 L p .61225 .60208 L F P
0 g
s
.388 0 .083 r
.61225 .60208 m .60963 .60581 L .61974 .60429 L p F P
0 g
s
.603 .556 .775 r
.73121 .46356 m .71911 .47208 L p .70997 .46133 L F P
0 g
s
.578 .524 .758 r
.71911 .47208 m .73121 .46356 L .73424 .47199 L closepath p F P
0 g
s
.861 .584 .517 r
.33238 .54033 m .34104 .54491 L .34076 .53682 L p F P
0 g
s
.861 .584 .517 r
.34076 .53682 m .33213 .53223 L .33238 .54033 L p F P
0 g
s
.862 .621 .573 r
.3238 .5275 m .33213 .53223 L .33312 .52376 L p F P
0 g
s
.862 .621 .573 r
.33312 .52376 m .3248 .51902 L .3238 .5275 L p F P
0 g
s
.448 .724 .985 r
.46117 .45625 m .46531 .45845 L .44807 .45876 L p F P
0 g
s
.448 .724 .985 r
.45824 .45557 m .46117 .45625 L p .44807 .45876 L F P
0 g
s
.448 .724 .985 r
.44189 .45475 m .45824 .45557 L p .44807 .45876 L F P
0 g
s
.448 .724 .985 r
.44807 .45876 m .44636 .45812 L .44189 .45475 L p F P
0 g
s
.484 .043 .125 r
.56743 .61183 m .57236 .61216 L .56666 .61281 L closepath p F P
0 g
s
.454 0 0 r
.54333 .61434 m .52063 .61465 L .52056 .61469 L p F P
0 g
s
.504 0 0 r
.52063 .61465 m .52056 .61469 L .52035 .61464 L closepath p F P
0 g
s
.505 0 0 r
.51534 .61784 m .50076 .61388 L .52035 .61464 L p F P
0 g
s
.505 0 0 r
.51556 .61785 m .51534 .61784 L p .52035 .61464 L F P
0 g
s
.505 0 0 r
.52035 .61464 m .52056 .61469 L .51556 .61785 L p F P
0 g
s
.454 0 0 r
.52056 .61469 m .53761 .61781 L p .54333 .61434 L F P
0 g
s
.472 0 0 r
.52056 .61469 m .53761 .61781 L .51556 .61785 L closepath p F P
0 g
s
.603 .556 .775 r
.70997 .46133 m .72941 .45901 L .73121 .46356 L p F P
0 g
s
.603 .597 .818 r
.70775 .45673 m .70997 .46133 L .72941 .45901 L p F P
0 g
s
.468 0 0 r
.54418 .61432 m .544 .61445 L .54333 .61434 L closepath p F P
0 g
s
.454 0 0 r
.53949 .61778 m .544 .61445 L .54333 .61434 L p F P
0 g
s
.454 0 0 r
.53761 .61781 m .53949 .61778 L p .54333 .61434 L F P
0 g
s
.854 .539 .455 r
.34251 .55264 m .35154 .55705 L .35003 .54933 L p F P
0 g
s
.854 .539 .455 r
.35003 .54933 m .34104 .54491 L .34251 .55264 L p F P
0 g
s
.427 0 0 r
.56267 .61613 m .56666 .61281 L .54418 .61432 L p F P
0 g
s
.427 0 0 r
.54418 .61432 m .544 .61445 L .56267 .61613 L p F P
0 g
s
.497 .356 .619 r
.73396 .51524 m .72693 .51965 L .72553 .51025 L p F P
0 g
s
.497 .356 .619 r
.72553 .51025 m .72801 .50868 L .73396 .51524 L p F P
0 g
s
.459 .218 .46 r
.71058 .55247 m .71104 .54529 L .70275 .54921 L p F P
0 g
s
.459 .218 .46 r
.69318 .56066 m .71058 .55247 L p .70275 .54921 L F P
0 g
s
.459 .218 .46 r
.70275 .54921 m .69321 .56018 L .69318 .56066 L p F P
0 g
s
.527 .757 .981 r
.44636 .45812 m .44189 .45475 L .43562 .45541 L closepath p F P
0 g
s
.859 .653 .623 r
.31679 .51413 m .3248 .51902 L .32718 .5101 L p F P
0 g
s
.859 .653 .623 r
.32718 .5101 m .31919 .5052 L .31679 .51413 L p F P
0 g
s
.653 .168 .088 r
.44524 .60387 m .45231 .60824 L .44068 .60609 L closepath p F P
0 g
s
.432 0 0 r
.56227 .61646 m .56267 .61613 L .544 .61445 L p F P
0 g
s
.432 0 0 r
.544 .61445 m .53949 .61778 L .56227 .61646 L p F P
0 g
s
.503 0 0 r
.49633 .61686 m .51534 .61784 L .50076 .61388 L p F P
0 g
s
.503 0 0 r
.49196 .61554 m .49633 .61686 L p .50076 .61388 L F P
0 g
s
.503 0 0 r
.50076 .61388 m .49579 .61361 L .49196 .61554 L p F P
0 g
s
.548 .032 0 r
.49579 .61361 m .49196 .61554 L .4832 .61246 L closepath p F P
0 g
s
.451 .169 .393 r
.67412 .57447 m .69212 .56722 L p .69213 .56109 L F P
0 g
s
.39 .065 .29 r
.69051 .57315 m .69212 .56722 L .67412 .57447 L p F P
0 g
s
.39 .065 .29 r
.67412 .57447 m .67245 .58042 L .69051 .57315 L p F P
0 g
s
.664 .738 .905 r
.37178 .45018 m .38973 .44423 L .39519 .44978 L p F P
0 g
s
.652 .737 .912 r
.38973 .44423 m .37178 .45018 L .36626 .4441 L p F P
0 g
s
.723 .735 .86 r
.34819 .45376 m .36626 .4441 L .37178 .45018 L p F P
0 g
s
.676 .72 .882 r
.65819 .45019 m .67716 .44352 L .68168 .44969 L p F P
0 g
s
.688 .76 .906 r
.67716 .44352 m .65819 .45019 L .65366 .44553 L p F P
0 g
s
.685 .781 .924 r
.63478 .45256 m .65366 .44553 L .65819 .45019 L p F P
0 g
s
.832 .472 .372 r
.35426 .56442 m .36388 .5686 L .36098 .56129 L p F P
0 g
s
.832 .472 .372 r
.35391 .56348 m .35426 .56442 L p .36098 .56129 L F P
0 g
s
.832 .472 .372 r
.36098 .56129 m .35838 .56016 L .35391 .56348 L p F P
0 g
s
.488 .242 .466 r
.69321 .56018 m .69213 .56109 L .69318 .56066 L closepath p F P
0 g
s
.451 .169 .393 r
.69212 .56722 m .69318 .56066 L .69213 .56109 L p F P
0 g
s
.653 .658 .842 r
.68168 .44969 m .70081 .44407 L .70536 .45203 L p F P
0 g
s
.668 .694 .865 r
.70081 .44407 m .68168 .44969 L .67716 .44352 L p F P
0 g
s
.756 .311 .197 r
.39441 .58986 m .40568 .59342 L .3997 .58698 L p F P
0 g
s
.756 .311 .197 r
.3997 .58698 m .38854 .5834 L .39441 .58986 L p F P
0 g
s
.806 .714 .763 r
.32979 .46958 m .32972 .46966 L .33001 .46986 L closepath p F P
0 g
s
.819 .709 .744 r
.33001 .46986 m .32972 .46966 L .32147 .48057 L p F P
0 g
s
.586 .743 .951 r
.39519 .44978 m .41312 .44673 L .41853 .45157 L p F P
0 g
s
.56 .738 .959 r
.41312 .44673 m .39519 .44978 L .38973 .44423 L p F P
0 g
s
.248 .715 .946 r
.49073 .46254 m .49398 .46383 L p .47056 .4615 L F P
0 g
s
.248 .715 .946 r
.47056 .4615 m .48483 .46175 L .49073 .46254 L p F P
0 g
s
.109 .629 .884 r
.48483 .46175 m .47056 .4615 L .46531 .45845 L p F P
0 g
s
.624 .618 .824 r
.70536 .45203 m .71754 .44965 L .70775 .45673 L closepath p F P
0 g
s
.603 .597 .818 r
.72473 .44839 m .71754 .44965 L .70775 .45673 L p F P
0 g
s
.603 .597 .818 r
.72941 .45901 m .72473 .44839 L p .70775 .45673 L F P
0 g
s
.69 .825 .948 r
.65366 .44553 m .63478 .45256 L .63021 .44922 L p F P
0 g
s
.852 .681 .67 r
.31149 .50016 m .31919 .5052 L .32318 .49575 L p F P
0 g
s
.852 .681 .67 r
.32318 .49575 m .31553 .49068 L .31149 .50016 L p F P
0 g
s
.778 .717 .795 r
.34489 .4563 m .32979 .46958 L .32422 .4625 L p F P
0 g
s
.808 .721 .769 r
.32972 .46966 m .32979 .46958 L .32422 .4625 L p F P
0 g
s
.682 .195 .087 r
.42555 .60261 m .4384 .60561 L .43014 .59981 L p F P
0 g
s
.682 .195 .087 r
.43014 .59981 m .41749 .59676 L .42555 .60261 L p F P
0 g
s
.808 .721 .769 r
.32422 .4625 m .32257 .46435 L .32972 .46966 L p F P
0 g
s
.822 .716 .748 r
.31419 .47532 m .32147 .48057 L .32972 .46966 L p F P
0 g
s
.822 .716 .748 r
.32972 .46966 m .32257 .46435 L .31419 .47532 L p F P
0 g
s
.384 0 0 r
.57236 .61216 m .56666 .61281 L .56267 .61613 L p F P
0 g
s
.367 0 .187 r
.67081 .5842 m .67245 .58042 L .65382 .58677 L p F P
0 g
s
.367 0 .187 r
.65382 .58677 m .65182 .59132 L .67081 .5842 L p F P
0 g
s
.493 .355 .622 r
.74309 .50935 m .73396 .51524 L .72801 .50868 L p F P
0 g
s
.493 .355 .622 r
.72801 .50868 m .7416 .49986 L .74309 .50935 L p F P
0 g
s
.403 .124 .373 r
.70957 .55902 m .71058 .55247 L .69318 .56066 L p F P
0 g
s
.403 .124 .373 r
.69318 .56066 m .69212 .56722 L .70957 .55902 L p F P
0 g
s
.422 .046 .218 r
.65149 .5921 m .65182 .59132 L .63286 .59602 L p F P
0 g
s
.422 .046 .218 r
.63286 .59602 m .63219 .59754 L .65149 .5921 L p F P
0 g
s
.669 .842 .966 r
.61197 .45639 m .61138 .45598 L .62837 .44988 L closepath p F P
0 g
s
.764 .729 .82 r
.34489 .4563 m .34819 .45376 L .34262 .44729 L p F P
0 g
s
.764 .729 .82 r
.34262 .44729 m .33773 .45096 L .34489 .4563 L p F P
0 g
s
.778 .717 .795 r
.32422 .4625 m .33773 .45096 L .34489 .4563 L p F P
0 g
s
.527 0 0 r
.4902 .61643 m .49196 .61554 L .4832 .61246 L p F P
0 g
s
.527 0 0 r
.47917 .61527 m .4902 .61643 L p .4832 .61246 L F P
0 g
s
.527 0 0 r
.46852 .61123 m .47917 .61527 L p .4832 .61246 L F P
0 g
s
.527 0 0 r
.4832 .61246 m .46933 .61093 L .46852 .61123 L p F P
0 g
s
.839 .484 .381 r
.35838 .56016 m .35391 .56348 L .35154 .55705 L closepath p F P
0 g
s
.717 .736 .866 r
.36626 .4441 m .34819 .45376 L .34262 .44729 L p F P
0 g
s
.39 0 0 r
.58824 .61024 m .5862 .61207 L .57236 .61216 L closepath p F P
0 g
s
.384 0 0 r
.58409 .61401 m .5862 .61207 L .57236 .61216 L p F P
0 g
s
.384 0 0 r
.56503 .61616 m .58409 .61401 L p .57236 .61216 L F P
0 g
s
.384 0 0 r
.56267 .61613 m .56503 .61616 L p .57236 .61216 L F P
0 g
s
.642 .888 .985 r
.62837 .44988 m .61138 .45598 L .60674 .45382 L p F P
0 g
s
.81 .409 .292 r
.36798 .57557 m .37804 .57957 L .37386 .57263 L p F P
0 g
s
.81 .409 .292 r
.37386 .57263 m .36388 .5686 L .36798 .57557 L p F P
0 g
s
.473 .729 .982 r
.41853 .45157 m .42499 .45138 L .43562 .45541 L p F P
0 g
s
.522 .762 .984 r
.43652 .45083 m .42499 .45138 L .43562 .45541 L p F P
0 g
s
.522 .762 .984 r
.43562 .45541 m .44189 .45475 L .43652 .45083 L p F P
0 g
s
.434 .699 .977 r
.42499 .45138 m .41853 .45157 L .41312 .44673 L p F P
0 g
s
.637 .63 .827 r
.71754 .44965 m .70536 .45203 L .70081 .44407 L p F P
0 g
s
.156 .681 .873 r
.51671 .46488 m .51746 .46505 L p .49398 .46383 L F P
0 g
s
.156 .681 .873 r
.49398 .46383 m .50082 .46386 L .51671 .46488 L p F P
0 g
s
.276 .728 .957 r
.49398 .46383 m .50082 .46386 L .49073 .46254 L closepath p F P
0 g
s
.568 .04 0 r
.46933 .61093 m .46852 .61123 L .46701 .6106 L closepath p F P
0 g
s
.84 .704 .713 r
.30817 .48547 m .31553 .49068 L .32147 .48057 L p F P
0 g
s
.84 .704 .713 r
.32147 .48057 m .31419 .47532 L .30817 .48547 L p F P
0 g
s
.463 .297 .569 r
.73583 .52316 m .72769 .52825 L .72693 .51965 L p F P
0 g
s
.463 .297 .569 r
.72693 .51965 m .73396 .51524 L .73583 .52316 L p F P
0 g
s
.736 .3 .216 r
.41658 .59585 m .41749 .59676 L .41578 .59631 L closepath p F P
0 g
s
.567 .037 0 r
.46315 .61319 m .45231 .60824 L .46701 .6106 L p F P
0 g
s
.567 .037 0 r
.46701 .6106 m .46852 .61123 L .46315 .61319 L p F P
0 g
s
.335 0 .061 r
.6485 .59673 m .65149 .5921 L .63219 .59754 L p F P
0 g
s
.335 0 .061 r
.63219 .59754 m .6291 .60218 L .6485 .59673 L p F P
0 g
s
.413 .178 .445 r
.72745 .5433 m .72786 .53612 L .71104 .54529 L p F P
0 g
s
.413 .178 .445 r
.71104 .54529 m .71058 .55247 L .72745 .5433 L p F P
0 g
s
.87 .591 .513 r
.32404 .5356 m .33238 .54033 L .33213 .53223 L p F P
0 g
s
.87 .591 .513 r
.33213 .53223 m .3238 .5275 L .32404 .5356 L p F P
0 g
s
.546 .894 .98 r
.60674 .45382 m .58795 .45968 L .58322 .45837 L p F P
0 g
s
.486 .866 .978 r
.56448 .46281 m .58322 .45837 L .58795 .45968 L p F P
0 g
s
.871 .629 .571 r
.31577 .52262 m .3238 .5275 L .3248 .51902 L p F P
0 g
s
.871 .629 .571 r
.3248 .51902 m .31679 .51413 L .31577 .52262 L p F P
0 g
s
.336 0 0 r
.60513 .61048 m .60903 .60669 L .58824 .61024 L p F P
0 g
s
.336 0 0 r
.58824 .61024 m .5862 .61207 L .60513 .61048 L p F P
0 g
s
.792 .398 .307 r
.38803 .58259 m .38854 .5834 L .38741 .58301 L closepath p F P
0 g
s
.863 .546 .449 r
.33382 .54807 m .34251 .55264 L .34104 .54491 L p F P
0 g
s
.863 .546 .449 r
.34104 .54491 m .33238 .54033 L .33382 .54807 L p F P
0 g
s
.676 .173 .043 r
.41328 .5994 m .42555 .60261 L .41749 .59676 L p F P
0 g
s
.676 .173 .043 r
.41093 .59759 m .41328 .5994 L p .41749 .59676 L F P
0 g
s
.676 .173 .043 r
.41749 .59676 m .41578 .59631 L .41093 .59759 L p F P
0 g
s
.18 .707 .858 r
.54047 .46466 m .54097 .46473 L p .51746 .46505 L F P
0 g
s
.18 .707 .858 r
.51746 .46505 m .51986 .46492 L .54047 .46466 L p F P
0 g
s
.248 .741 .915 r
.51746 .46505 m .51986 .46492 L .51671 .46488 L closepath p F P
0 g
s
.866 .662 .625 r
.31164 .51077 m .31679 .51413 L .31919 .5052 L p F P
0 g
s
.866 .662 .625 r
.30996 .50572 m .31164 .51077 L p .31919 .5052 L F P
0 g
s
.866 .662 .625 r
.31919 .5052 m .31149 .50016 L .30996 .50572 L p F P
0 g
s
.571 .051 0 r
.47917 .61527 m .46852 .61123 L .46315 .61319 L p F P
0 g
s
.757 .3 .165 r
.38361 .58613 m .39441 .58986 L .38854 .5834 L p F P
0 g
s
.757 .3 .165 r
.38221 .5845 m .38361 .58613 L p .38854 .5834 L F P
0 g
s
.757 .3 .165 r
.38854 .5834 m .38741 .58301 L .38221 .5845 L p F P
0 g
s
.428 .855 .944 r
.5832 .45837 m .58322 .45837 L .56448 .46281 L p F P
0 g
s
.428 .855 .944 r
.56448 .46281 m .56264 .46254 L .5832 .45837 L p F P
0 g
s
.316 .792 .916 r
.56264 .46254 m .56448 .46281 L p .54097 .46473 L F P
0 g
s
.699 .206 .072 r
.41578 .59631 m .41093 .59759 L .40568 .59342 L closepath p F P
0 g
s
.844 .485 .375 r
.34514 .56003 m .34251 .55264 L .35154 .55705 L p F P
0 g
s
.844 .485 .375 r
.35322 .56394 m .34514 .56003 L p .35154 .55705 L F P
0 g
s
.844 .485 .375 r
.35154 .55705 m .35391 .56348 L .35322 .56394 L p F P
0 g
s
.771 .323 .185 r
.38741 .58301 m .38221 .5845 L .37804 .57957 L closepath p F P
0 g
s
.316 .792 .916 r
.54097 .46473 m .54364 .46435 L .56264 .46254 L p F P
0 g
s
.306 .788 .908 r
.54097 .46473 m .54364 .46435 L .54047 .46466 L closepath p F P
0 g
s
.174 .643 .934 r
.45824 .45557 m .44189 .45475 L .43652 .45083 L p F P
0 g
s
.202 .72 .874 r
.54047 .46466 m .53601 .46395 L .51986 .46492 L closepath p F P
0 g
s
.264 .749 .925 r
.533 .46404 m .53601 .46395 L .51986 .46492 L p F P
0 g
s
.061 .622 .789 r
.51238 .46381 m .52424 .464 L .50829 .46336 L closepath p F P
0 g
s
.077 .634 .803 r
.52424 .464 m .50829 .46336 L .50725 .46323 L p F P
0 g
s
.077 .634 .803 r
.50725 .46323 m .51111 .46361 L p .52424 .464 L F P
0 g
s
.264 .749 .925 r
.51986 .46492 m .52424 .464 L .53077 .46419 L F
.51238 .46381 m .52424 .464 L p .51986 .46492 L F P
0 g
s
.077 .634 .803 r
.51111 .46361 m .52347 .46484 L p .52424 .464 L F P
0 g
s
.264 .749 .925 r
.52424 .464 m .533 .46404 L p .53077 .46419 L F P
0 g
s
.264 .749 .925 r
.51986 .46492 m .51671 .46488 L .51238 .46381 L p F P
0 g
s
.187 .699 .894 r
.51671 .46488 m .51238 .46381 L .50082 .46386 L closepath p F P
0 g
s
.395 0 .098 r
.60963 .60581 m .61974 .60429 L .60903 .60669 L closepath p F P
0 g
s
.557 .007 0 r
.46306 .61322 m .46315 .61319 L .45231 .60824 L p F P
0 g
s
.557 .007 0 r
.449 .61073 m .46306 .61322 L p .45231 .60824 L F P
0 g
s
.557 .007 0 r
.43974 .60629 m .449 .61073 L p .45231 .60824 L F P
0 g
s
.557 .007 0 r
.45231 .60824 m .44068 .60609 L .43974 .60629 L p F P
0 g
s
.322 .796 .919 r
.54364 .46435 m .54047 .46466 L .53601 .46395 L p F P
0 g
s
.652 .737 .912 r
.36626 .4441 m .38422 .43869 L .38973 .44423 L p F P
0 g
s
.641 .733 .916 r
.38422 .43869 m .36626 .4441 L .36071 .43807 L p F P
0 g
s
.717 .736 .866 r
.34262 .44729 m .36071 .43807 L .36626 .4441 L p F P
0 g
s
.858 .69 .673 r
.30622 .49645 m .31149 .50016 L .31553 .49068 L p F P
0 g
s
.858 .69 .673 r
.30466 .49358 m .30622 .49645 L p .31553 .49068 L F P
0 g
s
.858 .69 .673 r
.31553 .49068 m .30817 .48547 L .30466 .49358 L p F P
0 g
s
.778 .724 .803 r
.33773 .45096 m .32422 .4625 L .31858 .4557 L p F P
0 g
s
.81 .727 .774 r
.32257 .46435 m .32422 .4625 L .31858 .4557 L p F P
0 g
s
.434 .699 .977 r
.41312 .44673 m .4158 .44681 L .42499 .45138 L p F P
0 g
s
.472 .744 .988 r
.43111 .44694 m .4158 .44681 L .42499 .45138 L p F P
0 g
s
.472 .744 .988 r
.42499 .45138 m .43652 .45083 L .43111 .44694 L p F P
0 g
s
.53 .452 .712 r
.7547 .47763 m .73936 .48939 L .73603 .47747 L p F P
0 g
s
.53 .452 .712 r
.75439 .47646 m .7547 .47763 L p .73603 .47747 L F P
0 g
s
.53 .452 .712 r
.73603 .47747 m .74186 .47297 L .75439 .47646 L p F P
0 g
s
.552 .49 .74 r
.73424 .47199 m .74186 .47297 L .73603 .47747 L closepath p F P
0 g
s
.546 .505 .762 r
.73121 .46356 m .73424 .47199 L .74186 .47297 L p F P
0 g
s
.81 .727 .774 r
.31858 .4557 m .3157 .45888 L .32257 .46435 L p F P
0 g
s
.825 .723 .752 r
.30721 .46991 m .31419 .47532 L .32257 .46435 L p F P
0 g
s
.825 .723 .752 r
.32257 .46435 m .3157 .45888 L .30721 .46991 L p F P
0 g
s
.326 .797 .923 r
.56264 .46254 m .55964 .46202 L .54364 .46435 L closepath p F P
0 g
s
.322 .796 .919 r
.55964 .46202 m .54364 .46435 L p .55519 .46229 L F P
0 g
s
.322 .796 .919 r
.55048 .46264 m .55561 .46222 L p .54364 .46435 L F P
0 g
s
.13 .678 .777 r
.54961 .46358 m .54987 .46356 L p .55036 .46281 L F P
0 g
s
.13 .678 .777 r
.55048 .46264 m .55031 .46282 L .55036 .46281 L F
.55031 .46282 m .54961 .46358 L .55036 .46281 L F
.322 .796 .919 r
.55561 .46222 m .55611 .46219 L p .55519 .46229 L F P
0 g
s
.322 .796 .919 r
.55611 .46219 m .55964 .46202 L p .55519 .46229 L F P
0 g
s
.322 .796 .919 r
.53601 .46395 m .55048 .46264 L p .54364 .46435 L F P
0 g
s
.668 .694 .865 r
.67716 .44352 m .69629 .43715 L .70081 .44407 L p F P
0 g
s
.683 .732 .887 r
.69629 .43715 m .67716 .44352 L .67267 .43828 L p F P
0 g
s
.688 .76 .906 r
.65366 .44553 m .67267 .43828 L .67716 .44352 L p F P
0 g
s
.818 .411 .277 r
.35832 .5714 m .36798 .57557 L .36388 .5686 L p F P
0 g
s
.818 .411 .277 r
.36388 .5686 m .35426 .56442 L .35832 .5714 L p F P
0 g
s
.763 .733 .825 r
.33773 .45096 m .34262 .44729 L .33701 .44095 L p F P
0 g
s
.763 .733 .825 r
.33701 .44095 m .33085 .44548 L .33773 .45096 L p F P
0 g
s
.778 .724 .803 r
.31858 .4557 m .33085 .44548 L .33773 .45096 L p F P
0 g
s
.288 .733 .962 r
.50829 .46336 m .51238 .46381 L .50082 .46386 L p F P
0 g
s
.288 .733 .962 r
.5047 .46305 m .50829 .46336 L p .50082 .46386 L F P
0 g
s
0 .567 .753 r
.50829 .46336 m .50725 .46323 L .5047 .46305 L closepath p F P
0 g
s
.104 0 0 r
.5047 .46305 m .50725 .46323 L .50716 .46323 L p F P
0 g
s
.288 .733 .962 r
.50082 .46386 m .4901 .46199 L .5047 .46305 L F
.104 0 0 r
.50716 .46323 m .50206 .46328 L p .5047 .46305 L F P
0 g
s
.288 .733 .962 r
.48881 .46176 m .5047 .46305 L p .4901 .46199 L F P
0 g
s
.288 .733 .962 r
.50082 .46386 m .49073 .46254 L .48881 .46176 L p F P
0 g
s
.7 .802 .928 r
.67267 .43828 m .65366 .44553 L .64914 .44178 L p F P
0 g
s
.69 .825 .948 r
.63021 .44922 m .64914 .44178 L .65366 .44553 L p F P
0 g
s
.56 .738 .959 r
.40794 .44213 m .41312 .44673 L p .38973 .44423 L F P
0 g
s
.56 .738 .959 r
.38973 .44423 m .4074 .44192 L .40794 .44213 L p F P
0 g
s
.535 .727 .963 r
.4074 .44192 m .38973 .44423 L .38422 .43869 L p F P
0 g
s
.578 .542 .779 r
.72941 .45901 m .73702 .45888 L .73121 .46356 L closepath p F P
0 g
s
.546 .505 .762 r
.74926 .45955 m .73702 .45888 L .73121 .46356 L p F P
0 g
s
.546 .505 .762 r
.75123 .46549 m .74926 .45955 L p .73121 .46356 L F P
0 g
s
.546 .505 .762 r
.74186 .47297 m .75123 .46549 L p .73121 .46356 L F P
0 g
s
.712 .737 .87 r
.36071 .43807 m .34262 .44729 L .33701 .44095 L p F P
0 g
s
.526 .421 .677 r
.73923 .48947 m .73936 .48939 L .73939 .48954 L closepath p F P
0 g
s
.489 .397 .677 r
.75705 .48825 m .7547 .47763 L .73936 .48939 L p F P
0 g
s
.489 .397 .677 r
.74812 .49505 m .75705 .48825 L p .73936 .48939 L F P
0 g
s
.489 .397 .677 r
.73936 .48939 m .73939 .48954 L .74812 .49505 L p F P
0 g
s
.5 .394 .665 r
.73939 .48954 m .74812 .49505 L .7416 .49986 L closepath p F P
0 g
s
.637 .63 .827 r
.72321 .44532 m .71754 .44965 L p .70081 .44407 L F P
0 g
s
.637 .63 .827 r
.70081 .44407 m .72014 .43937 L .72321 .44532 L p F P
0 g
s
.653 .663 .847 r
.72014 .43937 m .70081 .44407 L .69629 .43715 L p F P
0 g
s
.28 0 0 r
.61974 .60429 m .60903 .60669 L .60513 .61048 L p F P
0 g
s
.458 .294 .569 r
.7439 .51799 m .73583 .52316 L .73396 .51524 L p F P
0 g
s
.458 .294 .569 r
.73396 .51524 m .74309 .50935 L .7439 .51799 L p F P
0 g
s
.644 .886 .985 r
.63021 .44922 m .62837 .44988 L .63016 .4492 L closepath p F P
0 g
s
.642 .888 .985 r
.62563 .44687 m .63016 .4492 L .62837 .44988 L p F P
0 g
s
.642 .888 .985 r
.60674 .45382 m .62563 .44687 L p .62837 .44988 L F P
0 g
s
.423 .228 .509 r
.73394 .53232 m .72786 .53612 L .72769 .52825 L p F P
0 g
s
.423 .228 .509 r
.72769 .52825 m .73583 .52316 L .73394 .53232 L p F P
0 g
s
.522 0 0 r
.49196 .61554 m .49633 .61686 L .4902 .61643 L closepath p F P
0 g
s
.311 0 .159 r
.68981 .57475 m .69051 .57315 L .67245 .58042 L p F P
0 g
s
.311 0 .159 r
.67245 .58042 m .67081 .5842 L .68981 .57475 L p F P
0 g
s
.698 .202 .062 r
.40171 .59593 m .39441 .58986 L .40568 .59342 L p F P
0 g
s
.698 .202 .062 r
.40875 .5981 m .40171 .59593 L p .40568 .59342 L F P
0 g
s
.698 .202 .062 r
.40568 .59342 m .41093 .59759 L .40875 .5981 L p F P
0 g
s
.593 .554 .78 r
.73702 .45888 m .72941 .45901 L .72473 .44839 L p F P
0 g
s
.618 .611 .822 r
.71754 .44965 m .72321 .44532 L .72473 .44839 L closepath p F P
0 g
s
.34 .021 .27 r
.70871 .56215 m .70957 .55902 L .69212 .56722 L p F P
0 g
s
.34 .021 .27 r
.6987 .5693 m .70871 .56215 L p .69212 .56722 L F P
0 g
s
.34 .021 .27 r
.69212 .56722 m .69051 .57315 L .6987 .5693 L p F P
0 g
s
.282 .73 .96 r
.49073 .46254 m .48881 .46176 L .48483 .46175 L closepath p F P
0 g
s
.375 .004 .2 r
.67018 .58573 m .67081 .5842 L .65182 .59132 L p F P
0 g
s
.375 .004 .2 r
.65182 .59132 m .65149 .5921 L .67018 .58573 L p F P
0 g
s
.402 .839 .943 r
.57846 .45815 m .5832 .45837 L .56264 .46254 L p F P
0 g
s
.402 .839 .943 r
.56264 .46254 m .55964 .46202 L .57846 .45815 L p F P
0 g
s
.593 .053 0 r
.44068 .60609 m .43974 .60629 L .4384 .60561 L closepath p F P
0 g
s
.67 .892 .978 r
.64767 .44087 m .64914 .44178 L .63021 .44922 L p F P
0 g
s
.67 .892 .978 r
.63021 .44922 m .63016 .4492 L .64767 .44087 L p F P
0 g
s
.109 .629 .884 r
.46531 .45845 m .47061 .45899 L .48483 .46175 L p F P
0 g
s
.231 .669 .956 r
.46531 .45845 m .47061 .45899 L .46117 .45625 L closepath p F P
0 g
s
.681 .891 .974 r
.64462 .43895 m .64767 .44087 L .63016 .4492 L p F P
0 g
s
.681 .891 .974 r
.63016 .4492 m .62563 .44687 L .64462 .43895 L p F P
0 g
s
.845 .712 .716 r
.30113 .48009 m .30817 .48547 L .31419 .47532 L p F P
0 g
s
.845 .712 .716 r
.31419 .47532 m .30721 .46991 L .30113 .48009 L p F P
0 g
s
.879 .599 .509 r
.316 .53073 m .32404 .5356 L .3238 .5275 L p F P
0 g
s
.879 .599 .509 r
.3238 .5275 m .31577 .52262 L .316 .53073 L p F P
0 g
s
.773 .321 .175 r
.37337 .58217 m .36798 .57557 L .37804 .57957 L p F P
0 g
s
.773 .321 .175 r
.38041 .58494 m .37337 .58217 L p .37804 .57957 L F P
0 g
s
.773 .321 .175 r
.37804 .57957 m .38221 .5845 L .38041 .58494 L p F P
0 g
s
.873 .553 .442 r
.32545 .54335 m .33382 .54807 L .33238 .54033 L p F P
0 g
s
.873 .553 .442 r
.33238 .54033 m .32404 .5356 L .32545 .54335 L p F P
0 g
s
.344 0 0 r
.60507 .61054 m .60513 .61048 L .5862 .61207 L p F P
0 g
s
.344 0 0 r
.5862 .61207 m .58409 .61401 L .60507 .61054 L p F P
0 g
s
.879 .638 .569 r
.3123 .52037 m .31577 .52262 L .31679 .51413 L p F P
0 g
s
.879 .638 .569 r
.31679 .51413 m .31164 .51077 L .3123 .52037 L p F P
0 g
s
.59 .046 0 r
.43422 .60735 m .42555 .60261 L .4384 .60561 L p F P
0 g
s
.59 .046 0 r
.4384 .60561 m .43974 .60629 L .43422 .60735 L p F P
0 g
s
.225 .712 .926 r
.48358 .46012 m .47061 .45899 L .48483 .46175 L p F P
0 g
s
.225 .712 .926 r
.48483 .46175 m .48881 .46176 L .48358 .46012 L p F P
0 g
s
.451 .69 .968 r
.41312 .44673 m .4158 .44681 L .40794 .44213 L closepath p F P
0 g
s
.274 0 .031 r
.66727 .59033 m .67018 .58573 L .65149 .5921 L p F P
0 g
s
.274 0 .031 r
.65149 .5921 m .6485 .59673 L .66727 .59033 L p F P
0 g
s
.858 .496 .364 r
.3364 .55548 m .34514 .56003 L .34251 .55264 L p F P
0 g
s
.858 .496 .364 r
.34251 .55264 m .33382 .54807 L .3364 .55548 L p F P
0 g
s
.358 .086 .358 r
.72732 .54411 m .72745 .5433 L .71058 .55247 L p F P
0 g
s
.358 .086 .358 r
.71735 .5548 m .72732 .54411 L p .71058 .55247 L F P
0 g
s
.358 .086 .358 r
.71058 .55247 m .70957 .55902 L .71735 .5548 L p F P
0 g
s
.874 .672 .626 r
.31149 .50016 m .30622 .49645 L .30996 .50572 L closepath p F P
0 g
s
.331 0 0 r
.53761 .61781 m .51556 .61785 L .5155 .61787 L p F P
0 g
s
.397 0 0 r
.51556 .61785 m .5155 .61787 L .51534 .61784 L closepath p F P
0 g
s
.395 0 0 r
.51039 .61962 m .49633 .61686 L .51534 .61784 L p F P
0 g
s
.395 0 0 r
.51534 .61784 m .5155 .61787 L .51039 .61962 L p F P
0 g
s
.359 0 0 r
.53949 .61778 m .53908 .61796 L .53761 .61781 L closepath p F P
0 g
s
.331 0 0 r
.5341 .62013 m .53908 .61796 L .53761 .61781 L p F P
0 g
s
.331 0 0 r
.5155 .61787 m .5341 .62013 L p .53761 .61781 L F P
0 g
s
.305 0 0 r
.55782 .61872 m .56227 .61646 L .53949 .61778 L p F P
0 g
s
.305 0 0 r
.53949 .61778 m .53908 .61796 L .55782 .61872 L p F P
0 g
s
.397 0 0 r
.5341 .62013 m .5155 .61787 L .51039 .61962 L p F P
0 g
s
.599 .065 0 r
.449 .61073 m .43974 .60629 L .43422 .60735 L p F P
0 g
s
.466 .337 .62 r
.75321 .50193 m .74309 .50935 L .7416 .49986 L p F P
0 g
s
.466 .337 .62 r
.7416 .49986 m .74812 .49505 L .75321 .50193 L p F P
0 g
s
.843 .484 .375 r
.35391 .56348 m .35426 .56442 L .35322 .56394 L closepath p F P
0 g
s
.28 0 0 r
.62528 .60606 m .62859 .60268 L .61974 .60429 L p F P
0 g
s
.28 0 0 r
.60601 .61033 m .62528 .60606 L p .61974 .60429 L F P
0 g
s
.28 0 0 r
.60513 .61048 m .60601 .61033 L p .61974 .60429 L F P
0 g
s
.275 0 0 r
.6291 .60218 m .62859 .60268 L .61974 .60429 L closepath p F P
0 g
s
.601 .919 .974 r
.62105 .44549 m .62563 .44687 L .60674 .45382 L p F P
0 g
s
.601 .919 .974 r
.62035 .44576 m .62105 .44549 L p .60674 .45382 L F P
0 g
s
.601 .919 .974 r
.60674 .45382 m .60276 .45284 L .62035 .44576 L p F P
0 g
s
.546 .894 .98 r
.60276 .45284 m .60674 .45382 L p .58322 .45837 L F P
0 g
s
.401 0 0 r
.56267 .61613 m .56503 .61616 L .56227 .61646 L closepath p F P
0 g
s
.353 0 0 r
.55782 .61872 m .53908 .61796 L .5341 .62013 L p F P
0 g
s
.45 .69 .968 r
.42566 .44299 m .43111 .44694 L .4158 .44681 L p F P
0 g
s
.45 .69 .968 r
.40766 .44188 m .42566 .44299 L p .4158 .44681 L F P
0 g
s
.45 .69 .968 r
.4158 .44681 m .40794 .44213 L .40766 .44188 L p F P
0 g
s
.528 .454 .716 r
.74186 .47297 m .75123 .46549 L .75439 .47646 L closepath p F P
0 g
s
.38 0 0 r
.50936 .61997 m .51039 .61962 L .49633 .61686 L p F P
0 g
s
.38 0 0 r
.49459 .619 m .50936 .61997 L p .49633 .61686 L F P
0 g
s
.38 0 0 r
.48673 .61727 m .49459 .619 L p .49633 .61686 L F P
0 g
s
.38 0 0 r
.49633 .61686 m .4902 .61643 L .48673 .61727 L p F P
0 g
s
.823 .406 .25 r
.34902 .56706 m .35832 .5714 L .35426 .56442 L p F P
0 g
s
.823 .406 .25 r
.34789 .56501 m .34902 .56706 L p .35426 .56442 L F P
0 g
s
.823 .406 .25 r
.35426 .56442 m .35322 .56394 L .34789 .56501 L p F P
0 g
s
.593 .554 .78 r
.7462 .45122 m .73702 .45888 L p .72473 .44839 L F P
0 g
s
.593 .554 .78 r
.72473 .44839 m .74443 .44679 L .7462 .45122 L p F P
0 g
s
.59 .597 .827 r
.72321 .44532 m .72473 .44839 L .74443 .44679 L p F P
0 g
s
.233 0 0 r
.5047 .46305 m .48881 .46176 L .48358 .46012 L p F P
0 g
s
.253 0 0 r
.56503 .61616 m .56227 .61646 L .55782 .61872 L p F P
0 g
s
.44 0 0 r
.4902 .61643 m .48673 .61727 L .47917 .61527 L closepath p F P
0 g
s
.863 .697 .675 r
.29911 .48461 m .30113 .48009 L .30817 .48547 L p F P
0 g
s
.863 .697 .675 r
.30817 .48547 m .30466 .49358 L .29911 .48461 L p F P
0 g
s
.778 .731 .81 r
.33085 .44548 m .31858 .4557 L .3129 .44914 L p F P
0 g
s
.812 .734 .778 r
.3157 .45888 m .31858 .4557 L .3129 .44914 L p F P
0 g
s
.832 .421 .265 r
.35322 .56394 m .34789 .56501 L .34514 .56003 L closepath p F P
0 g
s
.269 0 0 r
.58409 .61401 m .58151 .61547 L .56503 .61616 L closepath p F P
0 g
s
.253 0 0 r
.57906 .6169 m .58151 .61547 L .56503 .61616 L p F P
0 g
s
.253 0 0 r
.56282 .6186 m .57906 .6169 L p .56503 .61616 L F P
0 g
s
.253 0 0 r
.55782 .61872 m .56282 .6186 L p .56503 .61616 L F P
0 g
s
.238 .673 .958 r
.4807 .45944 m .48358 .46012 L .47061 .45899 L p F P
0 g
s
.238 .673 .958 r
.47416 .45817 m .4807 .45944 L p .47061 .45899 L F P
0 g
s
.238 .673 .958 r
.46 .45562 m .47416 .45817 L p .47061 .45899 L F P
0 g
s
.238 .673 .958 r
.47061 .45899 m .46117 .45625 L .46 .45562 L p F P
0 g
s
.71 .205 .031 r
.39076 .59223 m .40171 .59593 L .39441 .58986 L p F P
0 g
s
.71 .205 .031 r
.39441 .58986 m .38361 .58613 L .39076 .59223 L p F P
0 g
s
.812 .734 .778 r
.3129 .44914 m .30912 .45327 L .3157 .45888 L p F P
0 g
s
.829 .73 .755 r
.30053 .46434 m .30721 .46991 L .3157 .45888 L p F P
0 g
s
.829 .73 .755 r
.3157 .45888 m .30912 .45327 L .30053 .46434 L p F P
0 g
s
.562 .519 .765 r
.73702 .45888 m .7462 .45122 L .74926 .45955 L closepath p F P
0 g
s
.641 .733 .916 r
.36071 .43807 m .37868 .4331 L .38422 .43869 L p F P
0 g
s
.632 .729 .917 r
.37868 .4331 m .36071 .43807 L .35512 .43205 L p F P
0 g
s
.712 .737 .87 r
.33701 .44095 m .35512 .43205 L .36071 .43807 L p F P
0 g
s
.763 .737 .829 r
.33085 .44548 m .33701 .44095 L .33135 .4347 L p F P
0 g
s
.763 .737 .829 r
.33135 .4347 m .32426 .43984 L .33085 .44548 L p F P
0 g
s
.778 .731 .81 r
.3129 .44914 m .32426 .43984 L .33085 .44548 L p F P
0 g
s
.604 .062 0 r
.4228 .60483 m .41328 .5994 L .42555 .60261 L p F P
0 g
s
.604 .062 0 r
.43336 .6075 m .4228 .60483 L p .42555 .60261 L F P
0 g
s
.604 .062 0 r
.42555 .60261 m .43422 .60735 L .43336 .6075 L p F P
0 g
s
.616 .62 .832 r
.72014 .43937 m .73227 .43731 L .72321 .44532 L closepath p F P
0 g
s
.59 .597 .827 r
.73975 .43623 m .73227 .43731 L .72321 .44532 L p F P
0 g
s
.59 .597 .827 r
.74443 .44679 m .73975 .43623 L p .72321 .44532 L F P
0 g
s
.546 .894 .98 r
.58322 .45837 m .58391 .45816 L .60276 .45284 L p F P
0 g
s
.428 .868 .902 r
.58322 .45837 m .58391 .45816 L .5832 .45837 L closepath p F P
0 g
s
.873 .663 .616 r
.30996 .50572 m .30913 .50908 L .31164 .51077 L closepath p F P
0 g
s
.884 .642 .567 r
.30813 .51757 m .3123 .52037 L .31164 .51077 L p F P
0 g
s
.884 .642 .567 r
.31164 .51077 m .30913 .50908 L .30813 .51757 L p F P
0 g
s
.443 .874 .914 r
.58391 .45816 m .5832 .45837 L .57846 .45815 L p F P
0 g
s
.88 .673 .619 r
.30913 .50908 m .30996 .50572 L .30622 .49645 L p F P
0 g
s
.174 .643 .934 r
.43652 .45083 m .44606 .45205 L .45824 .45557 L p F P
0 g
s
.128 .592 .921 r
.44606 .45205 m .43652 .45083 L .43111 .44694 L p F P
0 g
s
.543 .894 .978 r
.60276 .45284 m .60208 .45266 L .58391 .45816 L closepath p F P
0 g
s
.443 .874 .914 r
.59741 .45261 m .60208 .45266 L .58391 .45816 L p F P
0 g
s
.443 .874 .914 r
.57846 .45815 m .59741 .45261 L p .58391 .45816 L F P
0 g
s
.205 0 0 r
.64765 .59759 m .6485 .59673 L .6291 .60218 L p F P
0 g
s
.205 0 0 r
.6291 .60218 m .62859 .60268 L .64765 .59759 L p F P
0 g
s
.571 .051 0 r
.46315 .61319 m .46332 .61325 L .47917 .61527 L p F P
0 g
s
.438 0 0 r
.47752 .61734 m .46332 .61325 L .47917 .61527 L p F P
0 g
s
.438 0 0 r
.48335 .61805 m .47752 .61734 L p .47917 .61527 L F P
0 g
s
.438 0 0 r
.47917 .61527 m .48673 .61727 L .48335 .61805 L p F P
0 g
s
.683 .732 .887 r
.67267 .43828 m .6918 .43116 L .69629 .43715 L p F P
0 g
s
.699 .77 .907 r
.6918 .43116 m .67267 .43828 L .66818 .43391 L p F P
0 g
s
.7 .802 .928 r
.64914 .44178 m .66818 .43391 L .67267 .43828 L p F P
0 g
s
.709 .737 .873 r
.35512 .43205 m .33701 .44095 L .33135 .4347 L p F P
0 g
s
.653 .663 .847 r
.69629 .43715 m .71561 .43152 L .72014 .43937 L p F P
0 g
s
.67 .698 .867 r
.71561 .43152 m .69629 .43715 L .6918 .43116 L p F P
0 g
s
.786 .327 .152 r
.36361 .57803 m .37337 .58217 L .36798 .57557 L p F P
0 g
s
.786 .327 .152 r
.36798 .57557 m .35832 .5714 L .36361 .57803 L p F P
0 g
s
.416 .221 .506 r
.7441 .52585 m .73394 .53232 L .73583 .52316 L p F P
0 g
s
.416 .221 .506 r
.73583 .52316 m .7439 .51799 L .7441 .52585 L p F P
0 g
s
.535 .727 .963 r
.38422 .43869 m .39767 .43746 L .4074 .44192 L p F P
0 g
s
.518 .709 .958 r
.39767 .43746 m .38422 .43869 L .37868 .4331 L p F P
0 g
s
.373 .145 .435 r
.72849 .54265 m .72745 .5433 L .72786 .53612 L p F P
0 g
s
.373 .145 .435 r
.72786 .53612 m .73394 .53232 L .72849 .54265 L p F P
0 g
s
.692 .192 .053 r
.41093 .59759 m .41328 .5994 L .40875 .5981 L closepath p F P
0 g
s
.867 .688 .657 r
.30466 .49358 m .30415 .49494 L .30622 .49645 L closepath p F P
0 g
s
.88 .673 .619 r
.30187 .50384 m .30913 .50908 L p .30622 .49645 L F P
0 g
s
.88 .673 .619 r
.30622 .49645 m .30415 .49494 L .30187 .50384 L p F P
0 g
s
.889 .607 .504 r
.3093 .52637 m .316 .53073 L .31577 .52262 L p F P
0 g
s
.889 .607 .504 r
.31577 .52262 m .3123 .52037 L .3093 .52637 L p F P
0 g
s
.236 .754 .81 r
.5772 .45841 m .55964 .46202 L p .57419 .45903 L F P
0 g
s
.236 .754 .81 r
.55964 .46202 m .55561 .46222 L .56663 .46028 L p F P
0 g
s
.236 .754 .81 r
.57419 .45903 m .57671 .45851 L .5772 .45841 L F
.56663 .46028 m .57671 .45851 L p .57419 .45903 L F P
0 g
s
.236 .754 .81 r
.55964 .46202 m .56663 .46028 L .57419 .45903 L F
0 0 0 r
.57367 .45908 m .57137 .46016 L .57762 .45841 L p F P
0 g
s
.218 .742 .811 r
.57367 .45908 m .57671 .45851 L .56932 .45981 L p F P
0 g
s
.236 .754 .81 r
.57671 .45851 m .57846 .45815 L .5772 .45841 L p F P
0 g
s
.253 .761 .744 r
.59635 .45289 m .59741 .45261 L .57846 .45815 L p F P
0 g
s
.253 .761 .744 r
.57846 .45815 m .57671 .45851 L .59635 .45289 L p F P
0 g
s
.257 .765 .757 r
.59635 .45289 m .57671 .45851 L p .59089 .45431 L F P
0 g
s
.257 .765 .757 r
.59271 .45377 m .59319 .45366 L p .59089 .45431 L F P
0 g
s
.257 .765 .757 r
.59319 .45366 m .59635 .45289 L p .59089 .45431 L F P
0 g
s
.257 .765 .757 r
.57671 .45851 m .57367 .45908 L .59271 .45377 L p F P
0 g
s
0 0 0 r
.57762 .45841 m .59121 .4546 L p .57848 .45785 L F P
0 g
s
0 0 0 r
.57367 .45908 m .57491 .45887 L .57848 .45785 L F
.57491 .45887 m .57762 .45841 L .57848 .45785 L F
.218 .742 .811 r
.56932 .45981 m .56663 .46028 L p .57367 .45908 L F P
0 g
s
.218 .742 .811 r
.56663 .46028 m .55561 .46222 L p .56125 .46124 L F P
0 g
s
.218 .742 .811 r
.56125 .46124 m .57367 .45908 L .56663 .46028 L F
0 0 0 r
.54987 .46356 m .56037 .4619 L p .55601 .46216 L F P
0 g
s
0 0 0 r
.55483 .46224 m .5533 .46264 L .55601 .46216 L F
.5533 .46264 m .54987 .46356 L .55601 .46216 L F
.113 .666 .759 r
.55561 .46222 m .55475 .46224 L .55048 .46264 L closepath p F P
0 g
s
0 0 0 r
.55475 .46224 m .55467 .46226 L p .55483 .46224 L F P
0 g
s
0 0 0 r
.55467 .46226 m .54987 .46356 L p .55483 .46224 L F P
0 g
s
0 0 0 r
.56037 .4619 m .57137 .46016 L p .56476 .46099 L F P
0 g
s
.218 .742 .811 r
.55561 .46222 m .55475 .46224 L .57367 .45908 L p F P
0 g
s
0 0 0 r
.55475 .46224 m .56037 .4619 L .56476 .46099 L F
.882 .559 .433 r
.31739 .53848 m .32545 .54335 L .32404 .5356 L p F P
0 g
s
.882 .559 .433 r
.32404 .5356 m .316 .53073 L .31739 .53848 L p F P
0 g
s
.426 .27 .565 r
.75492 .50994 m .7439 .51799 L .74309 .50935 L p F P
0 g
s
.426 .27 .565 r
.74309 .50935 m .75321 .50193 L .75492 .50994 L p F P
0 g
s
.318 0 .172 r
.68828 .5784 m .68981 .57475 L .67081 .5842 L p F P
0 g
s
.318 0 .172 r
.67081 .5842 m .67018 .58573 L .68828 .5784 L p F P
0 g
s
.851 .721 .719 r
.29439 .47456 m .30113 .48009 L .30721 .46991 L p F P
0 g
s
.851 .721 .719 r
.30721 .46991 m .30053 .46434 L .29439 .47456 L p F P
0 g
s
.219 0 0 r
.64479 .60061 m .64765 .59759 L .62859 .60268 L p F P
0 g
s
.219 0 0 r
.62859 .60268 m .62528 .60606 L .64479 .60061 L p F P
0 g
s
.201 0 0 r
.60052 .61335 m .60507 .61054 L .58409 .61401 L p F P
0 g
s
.201 0 0 r
.58409 .61401 m .58151 .61547 L .60052 .61335 L p F P
0 g
s
.771 .317 .171 r
.38221 .5845 m .38361 .58613 L .38041 .58494 L closepath p F P
0 g
s
.892 .651 .566 r
.30083 .51235 m .30813 .51757 L .30913 .50908 L p F P
0 g
s
.892 .651 .566 r
.30913 .50908 m .30187 .50384 L .30083 .51235 L p F P
0 g
s
.111 .665 .759 r
.53601 .46395 m .55048 .46264 L .533 .46404 L closepath p F P
0 g
s
.706 .878 .962 r
.6638 .43045 m .66818 .43391 L .64914 .44178 L p F P
0 g
s
.706 .878 .962 r
.64914 .44178 m .64767 .44087 L .6638 .43045 L p F P
0 g
s
.868 .501 .352 r
.32799 .55077 m .3364 .55548 L .33382 .54807 L p F P
0 g
s
.868 .501 .352 r
.33382 .54807 m .32545 .54335 L .32799 .55077 L p F P
0 g
s
.321 .72 .98 r
.46117 .45625 m .46 .45562 L .45824 .45557 L closepath p F P
0 g
s
.873 .697 .661 r
.30415 .49494 m .30466 .49358 L .29911 .48461 L p F P
0 g
s
.561 .028 0 r
.46315 .61319 m .46332 .61325 L .46306 .61322 L closepath p F P
0 g
s
.413 0 0 r
.46208 .61515 m .47752 .61734 L .46332 .61325 L p F P
0 g
s
.413 0 0 r
.45776 .61379 m .46208 .61515 L p .46332 .61325 L F P
0 g
s
.413 0 0 r
.46332 .61325 m .46306 .61322 L .45776 .61379 L p F P
0 g
s
.469 0 0 r
.46306 .61322 m .45776 .61379 L .449 .61073 L closepath p F P
0 g
s
.462 .335 .622 r
.75862 .49783 m .75321 .50193 L .74812 .49505 L p F P
0 g
s
.462 .335 .622 r
.74812 .49505 m .75705 .48825 L .75862 .49783 L p F P
0 g
s
.631 .629 .83 r
.73227 .43731 m .72014 .43937 L .71561 .43152 L p F P
0 g
s
.873 .697 .661 r
.29911 .48461 m .29721 .48954 L .30415 .49494 L p F P
0 g
s
.888 .682 .619 r
.2949 .49846 m .30187 .50384 L .30415 .49494 L p F P
0 g
s
.888 .682 .619 r
.30415 .49494 m .29721 .48954 L .2949 .49846 L p F P
0 g
s
.301 .718 .974 r
.45464 .45296 m .44606 .45205 L .45824 .45557 L p F P
0 g
s
.301 .718 .974 r
.45824 .45557 m .46 .45562 L .45464 .45296 L p F P
0 g
s
.57 .739 .955 r
.40794 .44213 m .40766 .44188 L .4074 .44192 L closepath p F P
0 g
s
.582 .017 0 r
.41086 .60147 m .4228 .60483 L .41328 .5994 L p F P
0 g
s
.582 .017 0 r
.40526 .59812 m .41086 .60147 L p .41328 .5994 L F P
0 g
s
.582 .017 0 r
.41328 .5994 m .40875 .5981 L .40526 .59812 L p F P
0 g
s
.836 .422 .254 r
.34015 .56255 m .3364 .55548 L .34514 .56003 L p F P
0 g
s
.836 .422 .254 r
.34554 .56532 m .34015 .56255 L p .34514 .56003 L F P
0 g
s
.836 .422 .254 r
.34514 .56003 m .34789 .56501 L .34554 .56532 L p F P
0 g
s
.245 0 .12 r
.69051 .57315 m .68981 .57475 L .6987 .5693 L closepath p F P
0 g
s
.571 .738 .955 r
.40216 .43697 m .39767 .43746 L .4074 .44192 L p F P
0 g
s
.571 .738 .955 r
.4074 .44192 m .40766 .44188 L .40216 .43697 L p F P
0 g
s
.314 .667 .974 r
.42566 .44299 m .40766 .44188 L .40216 .43697 L p F P
0 g
s
.697 .175 0 r
.38028 .58834 m .39076 .59223 L .38361 .58613 L p F P
0 g
s
.697 .175 0 r
.37639 .58489 m .38028 .58834 L p .38361 .58613 L F P
0 g
s
.697 .175 0 r
.38361 .58613 m .38041 .58494 L .37639 .58489 L p F P
0 g
s
.892 .612 .505 r
.30829 .5257 m .3093 .52637 L .3123 .52037 L p F P
0 g
s
.892 .612 .505 r
.3123 .52037 m .30813 .51757 L .30829 .5257 L p F P
0 g
s
.215 0 0 r
.47416 .45817 m .46 .45562 L .45464 .45296 L p F P
0 g
s
.205 0 0 r
.68595 .58209 m .68828 .5784 L .67018 .58573 L p F P
0 g
s
.205 0 0 r
.67571 .58691 m .68595 .58209 L p .67018 .58573 L F P
0 g
s
.205 0 0 r
.67018 .58573 m .66727 .59033 L .67571 .58691 L p F P
0 g
s
.68 .914 .974 r
.64462 .43895 m .62563 .44687 L .62105 .44549 L p F P
0 g
s
.706 .874 .96 r
.6637 .43037 m .6638 .43045 L .64767 .44087 L p F P
0 g
s
.706 .874 .96 r
.64767 .44087 m .64462 .43895 L .6637 .43037 L p F P
0 g
s
.279 0 .238 r
.70957 .55902 m .70871 .56215 L .71735 .5548 L closepath p F P
0 g
s
.87 .709 .68 r
.29346 .47661 m .29439 .47456 L .30113 .48009 L p F P
0 g
s
.87 .709 .68 r
.30113 .48009 m .29911 .48461 L .29346 .47661 L p F P
0 g
s
.779 .738 .816 r
.32426 .43984 m .3129 .44914 L .30715 .44281 L p F P
0 g
s
.814 .74 .782 r
.30912 .45327 m .3129 .44914 L .30715 .44281 L p F P
0 g
s
.615 .06 0 r
.40875 .5981 m .40526 .59812 L .40171 .59593 L closepath p F P
0 g
s
.718 .205 .003 r
.38041 .58494 m .37639 .58489 L .37337 .58217 L closepath p F P
0 g
s
.362 .134 .428 r
.74371 .533 m .72849 .54265 L .73394 .53232 L p F P
0 g
s
.362 .134 .428 r
.73394 .53232 m .7441 .52585 L .74371 .533 L p F P
0 g
s
.814 .74 .782 r
.30715 .44281 m .30283 .4475 L .30912 .45327 L p F P
0 g
s
.833 .737 .759 r
.29417 .45861 m .30053 .46434 L .30912 .45327 L p F P
0 g
s
.833 .737 .759 r
.30912 .45327 m .30283 .4475 L .29417 .45861 L p F P
0 g
s
.791 .325 .128 r
.35424 .57371 m .36361 .57803 L .35832 .5714 L p F P
0 g
s
.791 .325 .128 r
.35832 .5714 m .34902 .56706 L .35424 .57371 L p F P
0 g
s
.599 .065 0 r
.43422 .60735 m .4354 .60796 L .449 .61073 L p F P
0 g
s
.464 0 0 r
.44779 .61257 m .4354 .60796 L .449 .61073 L p F P
0 g
s
.464 0 0 r
.45524 .61403 m .44779 .61257 L p .449 .61073 L F P
0 g
s
.464 0 0 r
.449 .61073 m .45776 .61379 L .45524 .61403 L p F P
0 g
s
.295 0 0 r
.60513 .61048 m .60601 .61033 L .60507 .61054 L closepath p F P
0 g
s
.763 .741 .833 r
.32426 .43984 m .33135 .4347 L .32565 .42853 L p F P
0 g
s
.763 .741 .833 r
.32565 .42853 m .31798 .43404 L .32426 .43984 L p F P
0 g
s
.779 .738 .816 r
.30715 .44281 m .31798 .43404 L .32426 .43984 L p F P
0 g
s
.401 0 0 r
.48673 .61727 m .49459 .619 L .48335 .61805 L closepath p F P
0 g
s
.632 .729 .917 r
.35512 .43205 m .37311 .42743 L .37868 .4331 L p F P
0 g
s
.626 .724 .917 r
.37311 .42743 m .35512 .43205 L .34949 .42603 L p F P
0 g
s
.709 .737 .873 r
.33135 .4347 m .34949 .42603 L .35512 .43205 L p F P
0 g
s
.133 0 0 r
.60601 .61033 m .60507 .61054 L .60052 .61335 L p F P
0 g
s
.607 .917 .977 r
.60276 .45284 m .60208 .45266 L .62035 .44576 L closepath p F P
0 g
s
.134 0 0 r
.62528 .60606 m .62418 .60676 L .60601 .61033 L closepath p F P
0 g
s
.133 0 0 r
.62064 .60909 m .62418 .60676 L .60601 .61033 L p F P
0 g
s
.133 0 0 r
.60444 .61262 m .62064 .60909 L p .60601 .61033 L F P
0 g
s
.133 0 0 r
.60052 .61335 m .60444 .61262 L p .60601 .61033 L F P
0 g
s
.258 0 .136 r
.6987 .5693 m .68981 .57475 L .68828 .5784 L p F P
0 g
s
.488 .429 .717 r
.76809 .46553 m .75618 .46096 L .75123 .46549 L p F P
0 g
s
.488 .429 .717 r
.75546 .47696 m .76809 .46553 L p .75123 .46549 L F P
0 g
s
.488 .429 .717 r
.75123 .46549 m .75439 .47646 L .75546 .47696 L p F P
0 g
s
.532 .482 .746 r
.74926 .45955 m .75618 .46096 L .75123 .46549 L closepath p F P
0 g
s
.377 .192 .499 r
.75352 .519 m .7441 .52585 L .7439 .51799 L p F P
0 g
s
.377 .192 .499 r
.7439 .51799 m .75492 .50994 L .75352 .519 L p F P
0 g
s
.524 .497 .768 r
.7462 .45122 m .74926 .45955 L .75618 .46096 L p F P
0 g
s
.134 0 0 r
.66679 .59083 m .66727 .59033 L .6485 .59673 L p F P
0 g
s
.134 0 0 r
.6485 .59673 m .64765 .59759 L .66679 .59083 L p F P
0 g
s
.879 .707 .664 r
.29721 .48954 m .29911 .48461 L .29346 .47661 L p F P
0 g
s
.706 .737 .875 r
.34949 .42603 m .33135 .4347 L .32565 .42853 L p F P
0 g
s
.128 .592 .921 r
.43111 .44694 m .43566 .44787 L .44606 .45205 L p F P
0 g
s
.198 .66 .942 r
.44923 .45032 m .43566 .44787 L .44606 .45205 L p F P
0 g
s
.198 .66 .942 r
.44606 .45205 m .45464 .45296 L .44923 .45032 L p F P
0 g
s
.892 .561 .416 r
.30966 .53346 m .31739 .53848 L .316 .53073 L p F P
0 g
s
.892 .561 .416 r
.30846 .52667 m .30966 .53346 L p .316 .53073 L F P
0 g
s
.892 .561 .416 r
.316 .53073 m .3093 .52637 L .30846 .52667 L p F P
0 g
s
.67 .698 .867 r
.6918 .43116 m .71111 .42461 L .71561 .43152 L p F P
0 g
s
.688 .733 .885 r
.71111 .42461 m .6918 .43116 L .68734 .42601 L p F P
0 g
s
.699 .77 .907 r
.66818 .43391 m .68734 .42601 L .6918 .43116 L p F P
0 g
s
.901 .621 .501 r
.30097 .52049 m .30829 .5257 L .30813 .51757 L p F P
0 g
s
.901 .621 .501 r
.30813 .51757 m .30083 .51235 L .30097 .52049 L p F P
0 g
s
.501 .905 .91 r
.62035 .44576 m .60208 .45266 L .59741 .45261 L p F P
0 g
s
.499 .423 .701 r
.75439 .47646 m .75546 .47696 L .7547 .47763 L closepath p F P
0 g
s
.518 .709 .958 r
.37868 .4331 m .38924 .43249 L .39767 .43746 L p F P
0 g
s
.504 .694 .954 r
.38924 .43249 m .37868 .4331 L .37311 .42743 L p F P
0 g
s
.472 .378 .668 r
.76317 .48295 m .75705 .48825 L .7547 .47763 L p F P
0 g
s
.472 .378 .668 r
.7547 .47763 m .75546 .47696 L .76317 .48295 L p F P
0 g
s
.877 .506 .339 r
.31991 .54591 m .32799 .55077 L .32545 .54335 L p F P
0 g
s
.877 .506 .339 r
.32545 .54335 m .31739 .53848 L .31991 .54591 L p F P
0 g
s
.609 .05 0 r
.39947 .5979 m .39076 .59223 L .40171 .59593 L p F P
0 g
s
.609 .05 0 r
.39966 .59797 m .39947 .5979 L p .40171 .59593 L F P
0 g
s
.609 .05 0 r
.40171 .59593 m .40526 .59812 L .39966 .59797 L p F P
0 g
s
.301 .033 .329 r
.72745 .5433 m .72732 .54411 L .72849 .54265 L closepath p F P
0 g
s
.901 .66 .564 r
.29384 .50698 m .30083 .51235 L .30187 .50384 L p F P
0 g
s
.901 .66 .564 r
.30187 .50384 m .2949 .49846 L .29384 .50698 L p F P
0 g
s
.562 .537 .785 r
.74443 .44679 m .75054 .44703 L .7462 .45122 L closepath p F P
0 g
s
.524 .497 .768 r
.76463 .44889 m .75054 .44703 L .7462 .45122 L p F P
0 g
s
.524 .497 .768 r
.76567 .45199 m .76463 .44889 L p .7462 .45122 L F P
0 g
s
.524 .497 .768 r
.75618 .46096 m .76567 .45199 L p .7462 .45122 L F P
0 g
s
.856 .73 .722 r
.28799 .46886 m .29439 .47456 L .30053 .46434 L p F P
0 g
s
.856 .73 .722 r
.30053 .46434 m .29417 .45861 L .28799 .46886 L p F P
0 g
s
.589 .042 0 r
.43422 .60735 m .4354 .60796 L .43336 .6075 L closepath p F P
0 g
s
.078 .54 .902 r
.43566 .44787 m .43111 .44694 L .42566 .44299 L p F P
0 g
s
.233 0 0 r
.48358 .46012 m .48837 .46099 L .5047 .46305 L p F P
0 g
s
0 .497 .745 r
.48358 .46012 m .48837 .46099 L .4807 .45944 L closepath p F P
0 g
s
.715 .845 .944 r
.68288 .42162 m .68734 .42601 L .66818 .43391 L p F P
0 g
s
.715 .845 .944 r
.66419 .43015 m .68288 .42162 L p .66818 .43391 L F P
0 g
s
.715 .845 .944 r
.66818 .43391 m .6638 .43045 L .66419 .43015 L p F P
0 g
s
.335 .015 .266 r
.70871 .56215 m .6987 .5693 L .70799 .5649 L closepath p F P
0 g
s
.258 0 .136 r
.7058 .57009 m .70799 .5649 L .6987 .5693 L p F P
0 g
s
.258 0 .136 r
.68828 .5784 m .7058 .57009 L p .6987 .5693 L F P
0 g
s
.209 0 0 r
.60026 .61352 m .60052 .61335 L .58151 .61547 L p F P
0 g
s
.209 0 0 r
.58151 .61547 m .57906 .6169 L .60026 .61352 L p F P
0 g
s
.019 0 0 r
.533 .46404 m .531 .46405 L .52424 .464 L closepath p F P
0 g
s
.13 .678 .777 r
.55048 .46264 m .533 .46404 L .531 .46405 L p F P
0 g
s
.077 .634 .803 r
.52672 .46492 m .531 .46405 L .52424 .464 L p F P
0 g
s
.077 .634 .803 r
.52347 .46484 m .52672 .46492 L p .52424 .464 L F P
0 g
s
.631 .629 .83 r
.73781 .43229 m .73227 .43731 L p .71561 .43152 L F P
0 g
s
.631 .629 .83 r
.71561 .43152 m .73517 .42714 L .73781 .43229 L p F P
0 g
s
.649 .66 .847 r
.73517 .42714 m .71561 .43152 L .71111 .42461 L p F P
0 g
s
.397 0 0 r
.53379 .62026 m .5341 .62013 L p .51039 .61962 L F P
0 g
s
.397 0 0 r
.51039 .61962 m .5135 .62007 L .53379 .62026 L p F P
0 g
s
.37 0 0 r
.51039 .61962 m .5135 .62007 L .50936 .61997 L closepath p F P
0 g
s
.474 .389 .679 r
.77179 .47521 m .76317 .48295 L .75546 .47696 L p F P
0 g
s
.474 .389 .679 r
.76988 .46676 m .77179 .47521 L p .75546 .47696 L F P
0 g
s
.474 .389 .679 r
.75546 .47696 m .76809 .46553 L .76988 .46676 L p F P
0 g
s
.716 .198 0 r
.37025 .58428 m .36361 .57803 L .37337 .58217 L p F P
0 g
s
.716 .198 0 r
.371 .58459 m .37025 .58428 L p .37337 .58217 L F P
0 g
s
.716 .198 0 r
.37337 .58217 m .37639 .58489 L .371 .58459 L p F P
0 g
s
.55 .726 .956 r
.39663 .43193 m .38924 .43249 L .39767 .43746 L p F P
0 g
s
.55 .726 .956 r
.39767 .43746 m .40216 .43697 L .39663 .43193 L p F P
0 g
s
.31 .043 .337 r
.74287 .53861 m .74371 .533 L .72849 .54265 L p F P
0 g
s
.31 .043 .337 r
.74179 .54006 m .74287 .53861 L p .72849 .54265 L F P
0 g
s
.31 .043 .337 r
.72646 .54978 m .74179 .54006 L p .72849 .54265 L F P
0 g
s
.31 .043 .337 r
.72849 .54265 m .72732 .54411 L .72646 .54978 L p F P
0 g
s
.608 .608 .826 r
.73227 .43731 m .73781 .43229 L .73975 .43623 L closepath p F P
0 g
s
.835 .421 .254 r
.34789 .56501 m .34902 .56706 L .34554 .56532 L closepath p F P
0 g
s
.348 .074 .349 r
.72732 .54411 m .71735 .5548 L .72646 .54978 L closepath p F P
0 g
s
.578 .547 .783 r
.75054 .44703 m .74443 .44679 L .73975 .43623 L p F P
0 g
s
.849 .431 .238 r
.33169 .55786 m .34015 .56255 L .3364 .55548 L p F P
0 g
s
.849 .431 .238 r
.3364 .55548 m .32799 .55077 L .33169 .55786 L p F P
0 g
s
.428 0 0 r
.43453 .60964 m .44779 .61257 L .4354 .60796 L p F P
0 g
s
.428 0 0 r
.42868 .60732 m .43453 .60964 L p .4354 .60796 L F P
0 g
s
.428 0 0 r
.4354 .60796 m .43336 .6075 L .42868 .60732 L p F P
0 g
s
.879 .707 .664 r
.29346 .47661 m .29056 .48399 L .29721 .48954 L p F P
0 g
s
.896 .692 .619 r
.28822 .49292 m .2949 .49846 L .29721 .48954 L p F P
0 g
s
.896 .692 .619 r
.29721 .48954 m .29056 .48399 L .28822 .49292 L p F P
0 g
s
.104 0 0 r
.50206 .46328 m .48837 .46099 L .5047 .46305 L p F P
0 g
s
.147 0 0 r
.66364 .59417 m .66679 .59083 L .64765 .59759 L p F P
0 g
s
.147 0 0 r
.64765 .59759 m .64479 .60061 L .66364 .59417 L p F P
0 g
s
.274 0 0 r
.55782 .61872 m .56282 .6186 L .55695 .61918 L closepath p F P
0 g
s
.353 0 0 r
.55695 .61918 m .55782 .61872 L p .5341 .62013 L F P
0 g
s
.29 0 .25 r
.71735 .5548 m .70871 .56215 L .70799 .5649 L p F P
0 g
s
.353 0 0 r
.5341 .62013 m .53537 .6202 L .55695 .61918 L p F P
0 g
s
.328 0 0 r
.5341 .62013 m .53537 .6202 L .53379 .62026 L closepath p F P
0 g
s
.479 0 0 r
.43336 .6075 m .42868 .60732 L .4228 .60483 L closepath p F P
0 g
s
.29 0 .25 r
.72489 .5556 m .72646 .54978 L .71735 .5548 L p F P
0 g
s
.29 0 .25 r
.70799 .5649 m .72489 .5556 L p .71735 .5548 L F P
0 g
s
.13 .678 .777 r
.54987 .46356 m .55475 .46224 L .55048 .46264 L p F P
0 g
s
.13 .678 .777 r
.531 .46405 m .54961 .46358 L p .55048 .46264 L F P
0 g
s
.419 .266 .565 r
.75949 .50651 m .75492 .50994 L .75321 .50193 L p F P
0 g
s
.419 .266 .565 r
.75321 .50193 m .75862 .49783 L .75949 .50651 L p F P
0 g
s
.132 0 0 r
.53537 .6202 m .53379 .62026 L .52906 .62115 L p F P
0 g
s
.219 0 0 r
.53379 .62026 m .52906 .62115 L .5135 .62007 L closepath p F P
0 g
s
.169 0 0 r
.55695 .61918 m .55291 .62019 L .53537 .6202 L closepath p F P
0 g
s
.132 0 0 r
.55051 .62081 m .55291 .62019 L .53537 .6202 L p F P
0 g
s
.132 0 0 r
.53741 .62129 m .55051 .62081 L p .53537 .6202 L F P
0 g
s
.132 0 0 r
.52906 .62115 m .53741 .62129 L p .53537 .6202 L F P
0 g
s
.174 0 0 r
.52687 .62156 m .52906 .62115 L .5135 .62007 L p F P
0 g
s
.174 0 0 r
.51495 .62129 m .52687 .62156 L p .5135 .62007 L F P
0 g
s
.174 0 0 r
.50522 .62043 m .51495 .62129 L p .5135 .62007 L F P
0 g
s
.174 0 0 r
.5135 .62007 m .50936 .61997 L .50522 .62043 L p F P
0 g
s
.256 0 0 r
.50936 .61997 m .50522 .62043 L .49459 .619 L closepath p F P
0 g
s
.431 .314 .619 r
.76766 .49006 m .75862 .49783 L .75705 .48825 L p F P
0 g
s
.431 .314 .619 r
.75705 .48825 m .76317 .48295 L .76766 .49006 L p F P
0 g
s
.72 .889 .958 r
.6637 .43037 m .64462 .43895 L .6401 .43704 L p F P
0 g
s
.68 .914 .974 r
.62105 .44549 m .6401 .43704 L .64462 .43895 L p F P
0 g
s
.785 .302 .076 r
.34525 .56923 m .35424 .57371 L .34902 .56706 L p F P
0 g
s
.785 .302 .076 r
.3419 .56483 m .34525 .56923 L p .34902 .56706 L F P
0 g
s
.785 .302 .076 r
.34902 .56706 m .34554 .56532 L .3419 .56483 L p F P
0 g
s
.409 0 0 r
.52347 .46484 m .50725 .46323 L .50206 .46328 L p F P
0 g
s
.314 .667 .974 r
.42416 .44187 m .42566 .44299 L p .40216 .43697 L F P
0 g
s
.314 .667 .974 r
.40216 .43697 m .41701 .43864 L .42416 .44187 L p F P
0 g
s
.291 .637 .965 r
.41701 .43864 m .40216 .43697 L .39663 .43193 L p F P
0 g
s
.876 .72 .685 r
.28771 .46947 m .28799 .46886 L .29439 .47456 L p F P
0 g
s
.876 .72 .685 r
.29439 .47456 m .29346 .47661 L .28771 .46947 L p F P
0 g
s
.6 .038 0 r
.40526 .59812 m .41086 .60147 L .39966 .59797 L closepath p F P
0 g
s
.051 0 0 r
.64334 .60156 m .64479 .60061 L .62528 .60606 L p F P
0 g
s
.051 0 0 r
.62528 .60606 m .62418 .60676 L .64334 .60156 L p F P
0 g
s
.78 .745 .821 r
.31798 .43404 m .30715 .44281 L .30136 .43668 L p F P
0 g
s
.817 .746 .785 r
.30283 .4475 m .30715 .44281 L .30136 .43668 L p F P
0 g
s
.079 0 0 r
.56282 .6186 m .55695 .61918 L .55291 .62019 L p F P
0 g
s
.078 .54 .902 r
.42566 .44299 m .42649 .44322 L .43566 .44787 L p F P
0 g
s
.099 .593 .902 r
.43975 .44668 m .42649 .44322 L .43566 .44787 L p F P
0 g
s
.099 .593 .902 r
.44771 .44957 m .43975 .44668 L p .43566 .44787 L F P
0 g
s
.099 .593 .902 r
.43566 .44787 m .44923 .45032 L .44771 .44957 L p F P
0 g
s
0 .507 .756 r
.50111 .4634 m .50206 .46328 L .48837 .46099 L p F P
0 g
s
0 .507 .756 r
.48803 .46158 m .50111 .4634 L p .48837 .46099 L F P
0 g
s
0 .507 .756 r
.48837 .46099 m .4807 .45944 L .47829 .45884 L p F P
0 g
s
0 .523 .769 r
.4807 .45944 m .47829 .45884 L .47416 .45817 L closepath p F P
0 g
s
0 .507 .756 r
.47829 .45884 m .48803 .46158 L p .48837 .46099 L F P
0 g
s
.504 .441 .72 r
.7693 .46439 m .76809 .46553 L .75618 .46096 L p F P
0 g
s
.504 .441 .72 r
.75618 .46096 m .76567 .45199 L .7693 .46439 L p F P
0 g
s
.204 0 0 r
.5018 .62078 m .50522 .62043 L .49459 .619 L p F P
0 g
s
.204 0 0 r
.49566 .62029 m .5018 .62078 L p .49459 .619 L F P
0 g
s
.204 0 0 r
.48144 .6181 m .49566 .62029 L p .49459 .619 L F P
0 g
s
.204 0 0 r
.49459 .619 m .48335 .61805 L .48144 .6181 L p F P
0 g
s
.817 .746 .785 r
.30136 .43668 m .29684 .44156 L .30283 .4475 L p F P
0 g
s
.837 .744 .762 r
.28813 .45272 m .29417 .45861 L .30283 .4475 L p F P
0 g
s
.837 .744 .762 r
.30283 .4475 m .29684 .44156 L .28813 .45272 L p F P
0 g
s
.886 .717 .667 r
.29056 .48399 m .29346 .47661 L .28771 .46947 L p F P
0 g
s
0 0 0 r
.57137 .46016 m .57367 .45908 L .55475 .46224 L p F P
0 g
s
.713 .194 0 r
.37639 .58489 m .38028 .58834 L .371 .58459 L closepath p F P
0 g
s
.895 .569 .422 r
.3093 .52637 m .30846 .52667 L .30829 .5257 L closepath p F P
0 g
s
.105 0 0 r
.57906 .6169 m .57675 .61759 L .56282 .6186 L closepath p F P
0 g
s
.079 0 0 r
.57299 .61875 m .57675 .61759 L .56282 .6186 L p F P
0 g
s
.079 0 0 r
.56581 .61944 m .57299 .61875 L p .56282 .6186 L F P
0 g
s
.079 0 0 r
.55291 .62019 m .56581 .61944 L p .56282 .6186 L F P
0 g
s
.619 .056 0 r
.3888 .59406 m .39947 .5979 L .39076 .59223 L p F P
0 g
s
.619 .056 0 r
.39076 .59223 m .38028 .58834 L .3888 .59406 L p F P
0 g
s
.764 .745 .835 r
.31798 .43404 m .32565 .42853 L .3199 .42241 L p F P
0 g
s
.764 .745 .835 r
.3199 .42241 m .31202 .42807 L .31798 .43404 L p F P
0 g
s
.78 .745 .821 r
.30136 .43668 m .31202 .42807 L .31798 .43404 L p F P
0 g
s
.578 .547 .783 r
.76037 .43727 m .75054 .44703 L p .73975 .43623 L F P
0 g
s
.578 .547 .783 r
.73975 .43623 m .75976 .43573 L .76037 .43727 L p F P
0 g
s
.571 .589 .832 r
.73781 .43229 m .73975 .43623 L .75976 .43573 L p F P
0 g
s
.102 0 0 r
.531 .46405 m .54961 .46358 L .52672 .46492 L closepath p F P
0 g
s
.542 .508 .767 r
.75054 .44703 m .76037 .43727 L .76463 .44889 L closepath p F P
0 g
s
.626 .724 .917 r
.34949 .42603 m .36749 .42164 L .37311 .42743 L p F P
0 g
s
.622 .719 .916 r
.36749 .42164 m .34949 .42603 L .34382 .41997 L p F P
0 g
s
.706 .737 .875 r
.32565 .42853 m .34382 .41997 L .34949 .42603 L p F P
0 g
s
.316 .099 .416 r
.74918 .52903 m .74371 .533 L .7441 .52585 L p F P
0 g
s
.316 .099 .416 r
.7441 .52585 m .75352 .519 L .74918 .52903 L p F P
0 g
s
.278 0 0 r
.48335 .61805 m .48144 .6181 L .47752 .61734 L closepath p F P
0 g
s
.798 .323 .099 r
.34554 .56532 m .3419 .56483 L .34015 .56255 L closepath p F P
0 g
s
.469 0 0 r
.42198 .60646 m .41086 .60147 L .4228 .60483 L p F P
0 g
s
.469 0 0 r
.42404 .60702 m .42198 .60646 L p .4228 .60483 L F P
0 g
s
.469 0 0 r
.4228 .60483 m .42868 .60732 L .42404 .60702 L p F P
0 g
s
.215 0 0 r
.45464 .45296 m .46139 .45483 L .47416 .45817 L p F P
0 g
s
.261 0 0 r
.46139 .45483 m .45464 .45296 L .44923 .45032 L p F P
0 g
s
.902 .574 .415 r
.30215 .52777 m .30097 .52049 L .30829 .5257 L p F P
0 g
s
.902 .574 .415 r
.30829 .5257 m .30846 .52667 L .30215 .52777 L p F P
0 g
s
.434 0 0 r
.45776 .61379 m .46208 .61515 L .45524 .61403 L closepath p F P
0 g
s
.123 0 0 r
.70509 .57116 m .7058 .57009 L .68828 .5784 L p F P
0 g
s
.123 0 0 r
.68828 .5784 m .68595 .58209 L .70509 .57116 L p F P
0 g
s
.911 .63 .497 r
.29394 .51513 m .30097 .52049 L .30083 .51235 L p F P
0 g
s
.911 .63 .497 r
.30083 .51235 m .29384 .50698 L .29394 .51513 L p F P
0 g
s
.705 .736 .875 r
.34382 .41997 m .32565 .42853 L .3199 .42241 L p F P
0 g
s
.173 0 .088 r
.72413 .55732 m .72489 .5556 L .70799 .5649 L p F P
0 g
s
.173 0 .088 r
.7112 .56712 m .72413 .55732 L p .70799 .5649 L F P
0 g
s
.173 0 .088 r
.70799 .5649 m .7058 .57009 L .7112 .56712 L p F P
0 g
s
.885 .51 .324 r
.31215 .54089 m .31991 .54591 L .31739 .53848 L p F P
0 g
s
.885 .51 .324 r
.31739 .53848 m .30966 .53346 L .31215 .54089 L p F P
0 g
s
.727 .206 0 r
.36076 .57999 m .37025 .58428 L .36361 .57803 L p F P
0 g
s
.727 .206 0 r
.36361 .57803 m .35424 .57371 L .36076 .57999 L p F P
0 g
s
.268 0 0 r
.47611 .61815 m .46208 .61515 L .47752 .61734 L p F P
0 g
s
.268 0 0 r
.47752 .61734 m .48144 .6181 L .47611 .61815 L p F P
0 g
s
.902 .577 .421 r
.30966 .53346 m .30846 .52667 L .30215 .52777 L p F P
0 g
s
.51 .908 .918 r
.62105 .44549 m .62035 .44576 L .62103 .44549 L closepath p F P
0 g
s
.501 .905 .91 r
.61645 .4452 m .62103 .44549 L .62035 .44576 L p F P
0 g
s
.501 .905 .91 r
.59741 .45261 m .61645 .4452 L p .62035 .44576 L F P
0 g
s
.91 .67 .562 r
.28713 .50145 m .29384 .50698 L .2949 .49846 L p F P
0 g
s
.91 .67 .562 r
.2949 .49846 m .28822 .49292 L .28713 .50145 L p F P
0 g
s
.504 .694 .954 r
.37311 .42743 m .38169 .42717 L .38924 .43249 L p F P
0 g
s
.532 .712 .955 r
.39107 .42669 m .38169 .42717 L .38924 .43249 L p F P
0 g
s
.532 .712 .955 r
.38924 .43249 m .39663 .43193 L .39107 .42669 L p F P
0 g
s
.586 .94 .925 r
.63838 .43671 m .6401 .43704 L .62105 .44549 L p F P
0 g
s
.586 .94 .925 r
.62105 .44549 m .62103 .44549 L .63838 .43671 L p F P
0 g
s
.612 .947 .933 r
.63557 .43611 m .63838 .43671 L .62103 .44549 L p F P
0 g
s
.612 .947 .933 r
.62103 .44549 m .61645 .4452 L .63557 .43611 L p F P
0 g
s
.604 .615 .836 r
.73517 .42714 m .74348 .42605 L .73781 .43229 L closepath p F P
0 g
s
.571 .589 .832 r
.75507 .42493 m .74348 .42605 L .73781 .43229 L p F P
0 g
s
.571 .589 .832 r
.75976 .43573 m .75507 .42493 L p .73781 .43229 L F P
0 g
s
.862 .739 .725 r
.28191 .46299 m .28799 .46886 L .29417 .45861 L p F P
0 g
s
.862 .739 .725 r
.29417 .45861 m .28813 .45272 L .28191 .46299 L p F P
0 g
s
.025 0 0 r
.59583 .61502 m .60026 .61352 L .57906 .6169 L p F P
0 g
s
.025 0 0 r
.57906 .6169 m .57675 .61759 L .59583 .61502 L p F P
0 g
s
.649 .66 .847 r
.71111 .42461 m .73064 .41916 L .73517 .42714 L p F P
0 g
s
.667 .693 .865 r
.73064 .41916 m .71111 .42461 L .70664 .41854 L p F P
0 g
s
.688 .733 .885 r
.68734 .42601 m .70664 .41854 L .71111 .42461 L p F P
0 g
s
.706 .768 .901 r
.70664 .41854 m .68734 .42601 L .68288 .42162 L p F P
0 g
s
.065 0 0 r
.64028 .60364 m .64334 .60156 L .62418 .60676 L p F P
0 g
s
.065 0 0 r
.62418 .60676 m .62064 .60909 L .64028 .60364 L p F P
0 g
s
.495 .682 .949 r
.38169 .42717 m .37311 .42743 L .36749 .42164 L p F P
0 g
s
.856 .433 .219 r
.32356 .55301 m .33169 .55786 L .32799 .55077 L p F P
0 g
s
.856 .433 .219 r
.32799 .55077 m .31991 .54591 L .32356 .55301 L p F P
0 g
s
.05 0 0 r
.66727 .59033 m .66679 .59083 L .67571 .58691 L closepath p F P
0 g
s
.383 .24 .56 r
.76926 .49814 m .75949 .50651 L .75862 .49783 L p F P
0 g
s
.383 .24 .56 r
.75862 .49783 m .76766 .49006 L .76926 .49814 L p F P
0 g
s
0 .495 .725 r
.47295 .45781 m .46212 .45502 L p .47416 .45817 L F P
0 g
s
0 .495 .725 r
.46212 .45502 m .46139 .45483 L .46217 .45504 L p F P
0 g
s
0 .495 .725 r
.46217 .45504 m .47416 .45817 L p .46212 .45502 L F P
0 g
s
.239 0 0 r
.46139 .45483 m .47295 .45781 L .47167 .4576 L p F P
0 g
s
.261 0 0 r
.44923 .45032 m .45049 .4508 L .46139 .45483 L p F P
0 g
s
.239 0 0 r
.46196 .455 m .45049 .4508 L .46139 .45483 L p F P
0 g
s
0 .39 .747 r
.45087 .45098 m .46121 .45473 L p .45049 .4508 L F P
0 g
s
0 .39 .747 r
.46121 .45473 m .46196 .455 L .46127 .45475 L p F P
0 g
s
0 .39 .747 r
.46127 .45475 m .45049 .4508 L p .46121 .45473 L F P
0 g
s
0 .495 .725 r
.47416 .45817 m .47829 .45884 L .47295 .45781 L p F P
0 g
s
.886 .717 .667 r
.28771 .46947 m .28419 .47828 L .29056 .48399 L p F P
0 g
s
.904 .702 .619 r
.28182 .48723 m .28822 .49292 L .29056 .48399 L p F P
0 g
s
.904 .702 .619 r
.29056 .48399 m .28419 .47828 L .28182 .48723 L p F P
0 g
s
.208 0 .207 r
.72961 .55261 m .72489 .5556 L .72646 .54978 L p F P
0 g
s
.208 0 .207 r
.72646 .54978 m .74179 .54006 L .72961 .55261 L p F P
0 g
s
.366 .183 .495 r
.75972 .51436 m .75352 .519 L .75492 .50994 L p F P
0 g
s
.366 .183 .495 r
.75492 .50994 m .75949 .50651 L .75972 .51436 L p F P
0 g
s
.067 0 0 r
.67571 .58691 m .66679 .59083 L .66364 .59417 L p F P
0 g
s
.129 .552 .922 r
.42566 .44299 m .42649 .44322 L .42416 .44187 L closepath p F P
0 g
s
.798 .318 .076 r
.33591 .56361 m .33169 .55786 L .34015 .56255 L p F P
0 g
s
.798 .318 .076 r
.34015 .56255 m .3419 .56483 L .33591 .56361 L p F P
0 g
s
.714 .842 .943 r
.6638 .43045 m .6637 .43037 L .66419 .43015 L closepath p F P
0 g
s
.704 .886 .964 r
.66419 .43015 m .6637 .43037 L .65922 .42769 L p F P
0 g
s
.72 .889 .958 r
.6401 .43704 m .65922 .42769 L .6637 .43037 L p F P
0 g
s
.226 0 0 r
.4749 .61813 m .47611 .61815 L .46208 .61515 L p F P
0 g
s
.226 0 0 r
.46325 .6163 m .4749 .61813 L p .46208 .61515 L F P
0 g
s
.226 0 0 r
.45232 .61376 m .46325 .6163 L p .46208 .61515 L F P
0 g
s
.226 0 0 r
.46208 .61515 m .45524 .61403 L .45232 .61376 L p F P
0 g
s
.275 0 0 r
.49566 .62029 m .48144 .6181 L .47611 .61815 L p F P
0 g
s
.715 .844 .944 r
.68288 .42162 m .66419 .43015 L .67905 .41849 L closepath p F P
0 g
s
.704 .886 .964 r
.67842 .41797 m .67905 .41849 L .66419 .43015 L p F P
0 g
s
.704 .886 .964 r
.65922 .42769 m .67842 .41797 L p .66419 .43015 L F P
0 g
s
.425 .312 .621 r
.77344 .48489 m .76766 .49006 L .76317 .48295 L p F P
0 g
s
.425 .312 .621 r
.76317 .48295 m .77179 .47521 L .77344 .48489 L p F P
0 g
s
.129 .553 .922 r
.42997 .44218 m .43975 .44668 L .42649 .44322 L p F P
0 g
s
.129 .553 .922 r
.42016 .43891 m .42997 .44218 L p .42649 .44322 L F P
0 g
s
.129 .553 .922 r
.42649 .44322 m .42416 .44187 L .42016 .43891 L p F P
0 g
s
.577 0 0 r
.37862 .59003 m .3888 .59406 L .38028 .58834 L p F P
0 g
s
.577 0 0 r
.37056 .58449 m .37862 .59003 L p .38028 .58834 L F P
0 g
s
.577 0 0 r
.38028 .58834 m .371 .58459 L .37056 .58449 L p F P
0 g
s
.62 .62 .83 r
.74348 .42605 m .73517 .42714 L .73064 .41916 L p F P
0 g
s
.422 0 0 r
.41034 .60295 m .42198 .60646 L .41086 .60147 L p F P
0 g
s
.422 0 0 r
.39956 .59795 m .41034 .60295 L p .41086 .60147 L F P
0 g
s
.422 0 0 r
.41086 .60147 m .39966 .59797 L .39956 .59795 L p F P
0 g
s
.883 .731 .688 r
.28185 .46312 m .28191 .46299 L .28799 .46886 L p F P
0 g
s
.883 .731 .688 r
.28799 .46886 m .28771 .46947 L .28185 .46312 L p F P
0 g
s
.151 0 0 r
.60052 .61335 m .60444 .61262 L .60026 .61352 L closepath p F P
0 g
s
.472 0 0 r
.48803 .46158 m .47829 .45884 L .47295 .45781 L p F P
0 g
s
.295 0 0 r
.45524 .61403 m .45232 .61376 L .44779 .61257 L closepath p F P
0 g
s
.893 .726 .669 r
.28419 .47828 m .28771 .46947 L .28185 .46312 L p F P
0 g
s
.783 .752 .825 r
.30136 .43668 m .31202 .42807 L .3064 .42192 L p F P
0 g
s
.783 .752 .825 r
.3064 .42192 m .2955 .43075 L .30136 .43668 L p F P
0 g
s
.821 .753 .788 r
.29114 .43547 m .2955 .43075 L .30136 .43668 L p F P
0 g
s
.821 .753 .788 r
.30136 .43668 m .29684 .44156 L .29114 .43547 L p F P
0 g
s
0 0 0 r
.66259 .59486 m .66364 .59417 L .64479 .60061 L p F P
0 g
s
0 0 0 r
.64479 .60061 m .64334 .60156 L .66259 .59486 L p F P
0 g
s
.347 .818 .754 r
.61477 .44554 m .61645 .4452 L .59741 .45261 L p F P
0 g
s
.347 .818 .754 r
.59741 .45261 m .59635 .45289 L .61477 .44554 L p F P
0 g
s
.447 0 0 r
.42868 .60732 m .43453 .60964 L .42404 .60702 L closepath p F P
0 g
s
.35 .681 .979 r
.42416 .44187 m .42016 .43891 L .41701 .43864 L closepath p F P
0 g
s
.291 .637 .965 r
.39663 .43193 m .40825 .43376 L .41701 .43864 L p F P
0 g
s
.281 .612 .956 r
.40825 .43376 m .39663 .43193 L .39107 .42669 L p F P
0 g
s
0 0 0 r
.60444 .61262 m .60026 .61352 L .59583 .61502 L p F P
0 g
s
.239 0 0 r
.47167 .4576 m .46196 .455 L p .46139 .45483 L F P
0 g
s
.841 .752 .765 r
.29114 .43547 m .29684 .44156 L .28813 .45272 L p F P
0 g
s
.725 .198 0 r
.35168 .57553 m .36076 .57999 L .35424 .57371 L p F P
0 g
s
.725 .198 0 r
.35424 .57371 m .34525 .56923 L .35168 .57553 L p F P
0 g
s
.207 0 0 r
.68595 .58209 m .67571 .58691 L .68542 .58296 L closepath p F P
0 g
s
.067 0 0 r
.68189 .58667 m .68542 .58296 L .67571 .58691 L p F P
0 g
s
.067 0 0 r
.68099 .58708 m .68189 .58667 L p .67571 .58691 L F P
0 g
s
.067 0 0 r
.66364 .59417 m .68099 .58708 L p .67571 .58691 L F P
0 g
s
.805 .333 .099 r
.34525 .56923 m .3419 .56483 L .33591 .56361 L p F P
0 g
s
.765 .749 .838 r
.3199 .42241 m .31202 .42807 L .3064 .42192 L p F P
0 g
s
.195 0 0 r
.50522 .62043 m .51495 .62129 L .5018 .62078 L closepath p F P
0 g
s
.912 .585 .411 r
.29517 .52294 m .29394 .51513 L .30097 .52049 L p F P
0 g
s
.912 .585 .411 r
.30152 .52776 m .29517 .52294 L p .30097 .52049 L F P
0 g
s
.912 .585 .411 r
.30097 .52049 m .30215 .52777 L .30152 .52776 L p F P
0 g
s
.622 .719 .916 r
.34382 .41997 m .36185 .41571 L .36749 .42164 L p F P
0 g
s
.621 .714 .913 r
.36185 .41571 m .34382 .41997 L .33811 .41386 L p F P
0 g
s
.705 .736 .875 r
.3199 .42241 m .33811 .41386 L .34382 .41997 L p F P
0 g
s
.902 .577 .421 r
.30215 .52777 m .30223 .52829 L .30966 .53346 L p F P
0 g
s
.894 .514 .307 r
.30471 .53572 m .31215 .54089 L .30966 .53346 L p F P
0 g
s
.894 .514 .307 r
.30966 .53346 m .30223 .52829 L .30471 .53572 L p F P
0 g
s
.921 .639 .491 r
.28721 .50962 m .29394 .51513 L .29384 .50698 L p F P
0 g
s
.921 .639 .491 r
.29384 .50698 m .28713 .50145 L .28721 .50962 L p F P
0 g
s
0 0 0 r
.62064 .60909 m .61966 .60944 L .60444 .61262 L closepath p F P
0 g
s
0 0 0 r
.61506 .61114 m .61966 .60944 L .60444 .61262 L p F P
0 g
s
0 0 0 r
.59583 .61502 m .61506 .61114 L p .60444 .61262 L F P
0 g
s
.28 0 0 r
.44684 .61314 m .43453 .60964 L .44779 .61257 L p F P
0 g
s
.28 0 0 r
.44779 .61257 m .45232 .61376 L .44684 .61314 L p F P
0 g
s
.033 0 0 r
.59446 .6155 m .59583 .61502 L .57675 .61759 L p F P
0 g
s
.033 0 0 r
.57675 .61759 m .57299 .61875 L .59446 .6155 L p F P
0 g
s
.237 0 .309 r
.74371 .533 m .74287 .53861 L .74918 .52903 L closepath p F P
0 g
s
.495 .682 .949 r
.36749 .42164 m .37479 .42156 L .38169 .42717 L p F P
0 g
s
.519 .699 .951 r
.38547 .42121 m .37479 .42156 L .38169 .42717 L p F P
0 g
s
.519 .699 .951 r
.38169 .42717 m .39107 .42669 L .38547 .42121 L p F P
0 g
s
.323 .151 .486 r
.76821 .50713 m .75972 .51436 L .75949 .50651 L p F P
0 g
s
.323 .151 .486 r
.75949 .50651 m .76926 .49814 L .76821 .50713 L p F P
0 g
s
.705 .736 .875 r
.33236 .40771 m .31411 .41636 L .3199 .42241 L p F P
0 g
s
.705 .736 .875 r
.3199 .42241 m .33811 .41386 L .33236 .40771 L p F P
0 g
s
.765 .749 .838 r
.3064 .42192 m .31411 .41636 L .3199 .42241 L p F P
0 g
s
.694 .957 .949 r
.65473 .42583 m .65922 .42769 L .6401 .43704 L p F P
0 g
s
.694 .957 .949 r
.65198 .42731 m .65473 .42583 L p .6401 .43704 L F P
0 g
s
.694 .957 .949 r
.6401 .43704 m .63838 .43671 L .65198 .42731 L p F P
0 g
s
.153 0 0 r
.52906 .62115 m .53741 .62129 L .52687 .62156 L closepath p F P
0 g
s
.862 .433 .197 r
.31576 .548 m .32356 .55301 L .31991 .54591 L p F P
0 g
s
.862 .433 .197 r
.31991 .54591 m .31215 .54089 L .31576 .548 L p F P
0 g
s
.919 .68 .56 r
.28071 .49577 m .28713 .50145 L .28822 .49292 L p F P
0 g
s
.919 .68 .56 r
.28822 .49292 m .28182 .48723 L .28071 .49577 L p F P
0 g
s
.098 0 0 r
.55291 .62019 m .56581 .61944 L .55051 .62081 L closepath p F P
0 g
s
.375 .837 .776 r
.60954 .44763 m .59635 .45289 L p .61184 .44606 L F P
0 g
s
.375 .837 .776 r
.59635 .45289 m .59271 .45377 L .61184 .44606 L p F P
0 g
s
0 0 0 r
.60965 .44712 m .61184 .44606 L .59271 .45377 L p F P
0 g
s
.404 .832 .676 r
.61184 .44606 m .60965 .44712 L .61394 .44463 L p F P
0 g
s
.404 .832 .676 r
.61394 .44463 m .62652 .43738 L p .61184 .44606 L F P
0 g
s
.375 .837 .776 r
.61184 .44606 m .61477 .44554 L .60954 .44763 L p F P
0 g
s
.301 .083 .407 r
.75934 .52146 m .74918 .52903 L .75352 .519 L p F P
0 g
s
.301 .083 .407 r
.75352 .519 m .75972 .51436 L .75934 .52146 L p F P
0 g
s
.868 .748 .728 r
.28241 .44665 m .28813 .45272 L .28191 .46299 L p F P
0 g
s
.841 .752 .765 r
.28813 .45272 m .28241 .44665 L .29114 .43547 L p F P
0 g
s
.667 .693 .865 r
.70664 .41854 m .72615 .41204 L .73064 .41916 L p F P
0 g
s
.686 .726 .88 r
.72615 .41204 m .70664 .41854 L .70219 .4132 L p F P
0 g
s
.706 .768 .901 r
.68288 .42162 m .70219 .4132 L .70664 .41854 L p F P
0 g
s
.62 .62 .83 r
.75144 .41741 m .74348 .42605 L p .73064 .41916 L F P
0 g
s
.594 .598 .826 r
.74348 .42605 m .75144 .41741 L .75507 .42493 L closepath p F P
0 g
s
.465 0 0 r
.39966 .59797 m .39956 .59795 L .39947 .5979 L closepath p F P
0 g
s
.491 .672 .945 r
.37479 .42156 m .36749 .42164 L .36185 .41571 L p F P
0 g
s
.47 .389 .683 r
.76809 .46553 m .7693 .46439 L .76988 .46676 L closepath p F P
0 g
s
.446 0 0 r
.39386 .5966 m .3888 .59406 L .39947 .5979 L p F P
0 g
s
.446 0 0 r
.39947 .5979 m .39956 .59795 L .39386 .5966 L p F P
0 g
s
.473 0 0 r
.41034 .60295 m .39956 .59795 L .39386 .5966 L p F P
0 g
s
.606 .036 0 r
.371 .58459 m .37056 .58449 L .37025 .58428 L closepath p F P
0 g
s
.132 0 0 r
.70295 .57454 m .70509 .57116 L .68595 .58209 L p F P
0 g
s
.132 0 0 r
.68595 .58209 m .68542 .58296 L .70295 .57454 L p F P
0 g
s
0 0 0 r
.59121 .4546 m .59271 .45377 L .57367 .45908 L p F P
0 g
s
.507 .469 .749 r
.76463 .44889 m .76768 .44979 L .76567 .45199 L closepath p F P
0 g
s
.478 .426 .72 r
.77811 .45486 m .7693 .46439 L .76567 .45199 L p F P
0 g
s
.478 .426 .72 r
.76567 .45199 m .76768 .44979 L .77811 .45486 L p F P
0 g
s
.409 0 0 r
.50206 .46328 m .50426 .46373 L .52347 .46484 L p F P
0 g
s
.335 0 0 r
.50206 .46328 m .50426 .46373 L .50111 .4634 L closepath p F P
0 g
s
.805 .325 .064 r
.32841 .55976 m .32356 .55301 L .33169 .55786 L p F P
0 g
s
.805 .325 .064 r
.33403 .56308 m .32841 .55976 L p .33169 .55786 L F P
0 g
s
.805 .325 .064 r
.33169 .55786 m .33591 .56361 L .33403 .56308 L p F P
0 g
s
.364 .678 .977 r
.41463 .43459 m .40825 .43376 L .41701 .43864 L p F P
0 g
s
.364 .678 .977 r
.41701 .43864 m .42016 .43891 L .41463 .43459 L p F P
0 g
s
.496 .481 .77 r
.76037 .43727 m .76463 .44889 L .76768 .44979 L p F P
0 g
s
.592 .018 0 r
.36473 .58284 m .36076 .57999 L .37025 .58428 L p F P
0 g
s
.592 .018 0 r
.37025 .58428 m .37056 .58449 L .36473 .58284 L p F P
0 g
s
0 .386 .743 r
.44923 .45032 m .45049 .4508 L .44771 .44957 L closepath p F P
0 g
s
.893 .726 .669 r
.28185 .46312 m .27811 .47242 L .28419 .47828 L p F P
0 g
s
.912 .712 .619 r
.27572 .48138 m .28182 .48723 L .28419 .47828 L p F P
0 g
s
.912 .712 .619 r
.28419 .47828 m .27811 .47242 L .27572 .48138 L p F P
0 g
s
.087 0 0 r
.54961 .46358 m .52672 .46492 L .52593 .46507 L p F P
0 g
s
.235 0 0 r
.52672 .46492 m .52593 .46507 L .52347 .46484 L closepath p F P
0 g
s
0 0 0 r
.65921 .59716 m .66259 .59486 L .64334 .60156 L p F P
0 g
s
0 0 0 r
.64334 .60156 m .64028 .60364 L .65921 .59716 L p F P
0 g
s
.322 0 0 r
.51952 .4668 m .50426 .46373 L .52347 .46484 L p F P
0 g
s
.322 0 0 r
.52126 .46688 m .51952 .4668 L p .52347 .46484 L F P
0 g
s
.322 0 0 r
.52347 .46484 m .52593 .46507 L .52126 .46688 L p F P
0 g
s
.614 .046 0 r
.37862 .59003 m .37056 .58449 L .36473 .58284 L p F P
0 g
s
.727 .846 .938 r
.69775 .40853 m .70219 .4132 L .68288 .42162 L p F P
0 g
s
.727 .846 .938 r
.68083 .41681 m .69775 .40853 L p .68288 .42162 L F P
0 g
s
.727 .846 .938 r
.68288 .42162 m .67905 .41849 L .68083 .41681 L p F P
0 g
s
.62 .62 .83 r
.73064 .41916 m .75046 .41546 L .75144 .41741 L p F P
0 g
s
.638 .649 .844 r
.75046 .41546 m .73064 .41916 L .72615 .41204 L p F P
0 g
s
.418 .355 .68 r
.78514 .46112 m .77811 .45486 L .7693 .46439 L p F P
0 g
s
.418 .355 .68 r
.77518 .47175 m .78514 .46112 L p .7693 .46439 L F P
0 g
s
.418 .355 .68 r
.7693 .46439 m .76988 .46676 L .77518 .47175 L p F P
0 g
s
.026 0 0 r
.7058 .57009 m .70509 .57116 L .7112 .56712 L closepath p F P
0 g
s
0 .39 .747 r
.44378 .44762 m .45087 .45098 L p .45049 .4508 L F P
0 g
s
0 .39 .747 r
.45049 .4508 m .44771 .44957 L .44378 .44762 L p F P
0 g
s
.291 0 0 r
.46325 .6163 m .45232 .61376 L .44684 .61314 L p F P
0 g
s
.438 .357 .668 r
.76988 .46676 m .77518 .47175 L .77179 .47521 L closepath p F P
0 g
s
.229 0 0 r
.44541 .61293 m .44684 .61314 L .43453 .60964 L p F P
0 g
s
.229 0 0 r
.43584 .61065 m .44541 .61293 L p .43453 .60964 L F P
0 g
s
.229 0 0 r
.42309 .60681 m .43584 .61065 L p .43453 .60964 L F P
0 g
s
.229 0 0 r
.43453 .60964 m .42404 .60702 L .42309 .60681 L p F P
0 g
s
.541 .526 .788 r
.75976 .43573 m .76151 .43593 L .76037 .43727 L closepath p F P
0 g
s
.496 .481 .77 r
.77687 .43929 m .76151 .43593 L .76037 .43727 L p F P
0 g
s
.496 .481 .77 r
.76768 .44979 m .77687 .43929 L p .76037 .43727 L F P
0 g
s
.326 0 0 r
.50114 .46535 m .51952 .4668 L .50426 .46373 L p F P
0 g
s
.326 0 0 r
.49681 .46393 m .50114 .46535 L p .50426 .46373 L F P
0 g
s
.326 0 0 r
.50426 .46373 m .50111 .4634 L .49681 .46393 L p F P
0 g
s
0 0 0 r
.70119 .57631 m .70295 .57454 L .68542 .58296 L p F P
0 g
s
0 0 0 r
.68542 .58296 m .68189 .58667 L .70119 .57631 L p F P
0 g
s
.124 0 0 r
.54987 .46356 m .54982 .46357 L .54961 .46358 L closepath p F P
0 g
s
.087 0 0 r
.54501 .46604 m .54982 .46357 L .54961 .46358 L p F P
0 g
s
.087 0 0 r
.54416 .46609 m .54501 .46604 L p .54961 .46358 L F P
0 g
s
.087 0 0 r
.52593 .46507 m .54416 .46609 L p .54961 .46358 L F P
0 g
s
.007 0 0 r
.56884 .4613 m .57137 .46016 L .54987 .46356 L p F P
0 g
s
.007 0 0 r
.54987 .46356 m .54982 .46357 L .56884 .4613 L p F P
0 g
s
.373 .233 .559 r
.77437 .49361 m .76926 .49814 L .76766 .49006 L p F P
0 g
s
.373 .233 .559 r
.76766 .49006 m .77344 .48489 L .77437 .49361 L p F P
0 g
s
.554 .55 .804 r
.76151 .43593 m .75976 .43573 L .75507 .42493 L p F P
0 g
s
.186 0 0 r
.56682 .46286 m .56884 .4613 L .54982 .46357 L p F P
0 g
s
.186 0 0 r
.54982 .46357 m .54501 .46604 L .56682 .46286 L p F P
0 g
s
.387 0 0 r
.50111 .4634 m .49681 .46393 L .48803 .46158 L closepath p F P
0 g
s
.287 0 0 r
.52593 .46507 m .54416 .46609 L .52126 .46688 L closepath p F P
0 g
s
0 0 0 r
.63892 .60414 m .64028 .60364 L .62064 .60909 L p F P
0 g
s
0 0 0 r
.62064 .60909 m .61966 .60944 L .63892 .60414 L p F P
0 g
s
.697 .955 .951 r
.63838 .43671 m .63557 .43611 L .65198 .42731 L closepath p F P
0 g
s
.805 .333 .099 r
.33591 .56361 m .33663 .56458 L .34525 .56923 L p F P
0 g
s
.719 .186 0 r
.34299 .5709 m .35168 .57553 L .34525 .56923 L p F P
0 g
s
.719 .186 0 r
.34525 .56923 m .33663 .56458 L .34299 .5709 L p F P
0 g
s
0 .425 .822 r
.42997 .44218 m .42016 .43891 L .41463 .43459 L p F P
0 g
s
.486 .443 .735 r
.78301 .44936 m .77811 .45486 L .76768 .44979 L p F P
0 g
s
.486 .443 .735 r
.78047 .44076 m .78301 .44936 L p .76768 .44979 L F P
0 g
s
.486 .443 .735 r
.76768 .44979 m .77687 .43929 L .78047 .44076 L p F P
0 g
s
.868 .748 .728 r
.28191 .46299 m .27617 .45694 L .28241 .44665 L p F P
0 g
s
.891 .742 .69 r
.28185 .46312 m .28191 .46299 L .27617 .45694 L p F P
0 g
s
.891 .742 .69 r
.27617 .45694 m .27589 .45755 L .28185 .46312 L p F P
0 g
s
.9 .736 .67 r
.27233 .4664 m .27589 .45755 L .28185 .46312 L p F P
0 g
s
.9 .736 .67 r
.28185 .46312 m .27811 .47242 L .27233 .4664 L p F P
0 g
s
.024 .54 .866 r
.44771 .44957 m .44378 .44762 L .43975 .44668 L closepath p F P
0 g
s
.081 0 .028 r
.72489 .5556 m .72413 .55732 L .72961 .55261 L closepath p F P
0 g
s
.248 0 .317 r
.75838 .52782 m .75934 .52146 L .74918 .52903 L p F P
0 g
s
.248 0 .317 r
.74275 .53944 m .75838 .52782 L p .74918 .52903 L F P
0 g
s
.248 0 .317 r
.74918 .52903 m .74287 .53861 L .74275 .53944 L p F P
0 g
s
.516 .914 .83 r
.63182 .43619 m .63557 .43611 L .61645 .4452 L p F P
0 g
s
.516 .914 .83 r
.61645 .4452 m .61477 .44554 L .63182 .43619 L p F P
0 g
s
.787 .759 .828 r
.2955 .43075 m .3064 .42192 L .3011 .4156 L p F P
0 g
s
.787 .759 .828 r
.3011 .4156 m .28959 .42503 L .2955 .43075 L p F P
0 g
s
.825 .76 .791 r
.28575 .42921 m .28959 .42503 L .2955 .43075 L p F P
0 g
s
.825 .76 .791 r
.2955 .43075 m .29114 .43547 L .28575 .42921 L p F P
0 g
s
.554 .55 .804 r
.75507 .42493 m .76986 .42561 L .76151 .43593 L p F P
0 g
s
.531 .517 .785 r
.77914 .4366 m .77687 .43929 L .76151 .43593 L p F P
0 g
s
.531 .517 .785 r
.77549 .42643 m .77914 .4366 L p .76151 .43593 L F P
0 g
s
.531 .517 .785 r
.76151 .43593 m .76986 .42561 L .77549 .42643 L p F P
0 g
s
.027 0 0 r
.52687 .62156 m .52397 .62152 L .51495 .62129 L closepath p F P
0 g
s
.063 .627 .751 r
.53741 .62129 m .52687 .62156 L .52397 .62152 L p F P
0 g
s
.912 .584 .411 r
.30215 .52777 m .30223 .52829 L .30152 .52776 L closepath p F P
0 g
s
.024 .595 .755 r
.51882 .6214 m .52397 .62152 L .51495 .62129 L p F P
0 g
s
.024 .595 .755 r
.50001 .62064 m .51882 .6214 L p .51495 .62129 L F P
0 g
s
.024 .595 .755 r
.51495 .62129 m .5018 .62078 L .50001 .62064 L p F P
0 g
s
0 0 0 r
.55051 .62081 m .54795 .62091 L .53741 .62129 L closepath p F P
0 g
s
.063 .627 .751 r
.54292 .6211 m .54795 .62091 L .53741 .62129 L p F P
0 g
s
.063 .627 .751 r
.52397 .62152 m .54292 .6211 L p .53741 .62129 L F P
0 g
s
.923 .594 .4 r
.28841 .51744 m .29517 .52294 L .29394 .51513 L p F P
0 g
s
.923 .594 .4 r
.29394 .51513 m .28721 .50962 L .28841 .51744 L p F P
0 g
s
.846 .76 .768 r
.28575 .42921 m .29114 .43547 L .28241 .44665 L p F P
0 g
s
.899 .51 .275 r
.29758 .5304 m .30471 .53572 L .30223 .52829 L p F P
0 g
s
.899 .51 .275 r
.29602 .52555 m .29758 .5304 L p .30223 .52829 L F P
0 g
s
.899 .51 .275 r
.30223 .52829 m .30152 .52776 L .29602 .52555 L p F P
0 g
s
.391 .289 .618 r
.77922 .47902 m .77344 .48489 L .77179 .47521 L p F P
0 g
s
.391 .289 .618 r
.77179 .47521 m .77518 .47175 L .77922 .47902 L p F P
0 g
s
.751 .886 .941 r
.67842 .41797 m .65922 .42769 L .65473 .42583 L p F P
0 g
s
.044 0 0 r
.7112 .56712 m .70509 .57116 L .70295 .57454 L p F P
0 g
s
.767 .753 .84 r
.31411 .41636 m .3064 .42192 L .3011 .4156 L p F P
0 g
s
.281 .612 .956 r
.39107 .42669 m .4004 .42851 L .40825 .43376 L p F P
0 g
s
.279 .593 .948 r
.4004 .42851 m .39107 .42669 L .38547 .42121 L p F P
0 g
s
.93 .648 .485 r
.28077 .50395 m .28721 .50962 L .28713 .50145 L p F P
0 g
s
.93 .648 .485 r
.28713 .50145 m .28071 .49577 L .28077 .50395 L p F P
0 g
s
.112 .665 .754 r
.56581 .61944 m .55051 .62081 L .54795 .62091 L p F P
0 g
s
.472 0 0 r
.47295 .45781 m .47456 .45846 L .48803 .46158 L p F P
0 g
s
.421 0 0 r
.48569 .46288 m .47456 .45846 L .48803 .46158 L p F P
0 g
s
.421 0 0 r
.49465 .46441 m .48569 .46288 L p .48803 .46158 L F P
0 g
s
.421 0 0 r
.48803 .46158 m .49681 .46393 L .49465 .46441 L p F P
0 g
s
.06 0 0 r
.5018 .62078 m .50001 .62064 L .49566 .62029 L closepath p F P
0 g
s
0 0 0 r
.66364 .59417 m .66259 .59486 L .68099 .58708 L closepath p F P
0 g
s
.621 .714 .913 r
.33811 .41386 m .35617 .40962 L .36185 .41571 L p F P
0 g
s
.622 .71 .909 r
.35047 .40337 m .33236 .40771 L .33811 .41386 L p F P
0 g
s
.622 .71 .909 r
.33811 .41386 m .35617 .40962 L .35047 .40337 L p F P
0 g
s
.903 .52 .29 r
.30152 .52776 m .29602 .52555 L .29517 .52294 L closepath p F P
0 g
s
.45 0 0 r
.38811 .59502 m .37862 .59003 L .3888 .59406 L p F P
0 g
s
.45 0 0 r
.3888 .59406 m .39386 .5966 L .38811 .59502 L p F P
0 g
s
.491 .672 .945 r
.36185 .41571 m .36841 .41571 L .37479 .42156 L p F P
0 g
s
.512 .686 .946 r
.37984 .41546 m .36841 .41571 L .37479 .42156 L p F P
0 g
s
.512 .686 .946 r
.37479 .42156 m .38547 .42121 L .37984 .41546 L p F P
0 g
s
.249 .044 .393 r
.76464 .51696 m .75934 .52146 L .75972 .51436 L p F P
0 g
s
.249 .044 .393 r
.75972 .51436 m .76821 .50713 L .76464 .51696 L p F P
0 g
s
.866 .433 .172 r
.30829 .54284 m .31576 .548 L .31215 .54089 L p F P
0 g
s
.866 .433 .172 r
.31215 .54089 m .30471 .53572 L .30829 .54284 L p F P
0 g
s
0 0 0 r
.63892 .60414 m .61966 .60944 L .61506 .61114 L p F P
0 g
s
.288 0 0 r
.42404 .60702 m .42309 .60681 L .42198 .60646 L closepath p F P
0 g
s
.275 0 0 r
.47611 .61815 m .4786 .61858 L .49566 .62029 L p F P
0 g
s
0 .537 .717 r
.49475 .62014 m .4786 .61858 L .49566 .62029 L p F P
0 g
s
0 .537 .717 r
.49566 .62029 m .50001 .62064 L .49475 .62014 L p F P
0 g
s
.155 0 .07 r
.72413 .55732 m .7112 .56712 L .7227 .56069 L closepath p F P
0 g
s
.044 0 0 r
.72046 .56406 m .7227 .56069 L .7112 .56712 L p F P
0 g
s
.044 0 0 r
.71539 .56756 m .72046 .56406 L p .7112 .56712 L F P
0 g
s
.044 0 0 r
.70295 .57454 m .71539 .56756 L p .7112 .56712 L F P
0 g
s
.706 .736 .874 r
.32658 .40151 m .30827 .41038 L .31411 .41636 L p F P
0 g
s
.706 .736 .874 r
.31411 .41636 m .33236 .40771 L .32658 .40151 L p F P
0 g
s
.767 .753 .84 r
.3011 .4156 m .30827 .41038 L .31411 .41636 L p F P
0 g
s
.233 0 0 r
.47611 .61815 m .4786 .61858 L .4749 .61813 L closepath p F P
0 g
s
.929 .69 .557 r
.27459 .48994 m .28071 .49577 L .28182 .48723 L p F P
0 g
s
.929 .69 .557 r
.28182 .48723 m .27572 .48138 L .27459 .48994 L p F P
0 g
s
.286 .024 .329 r
.74287 .53861 m .74179 .54006 L .74275 .53944 L closepath p F P
0 g
s
.594 .021 0 r
.35886 .58089 m .35168 .57553 L .36076 .57999 L p F P
0 g
s
.594 .021 0 r
.36076 .57999 m .36473 .58284 L .35886 .58089 L p F P
0 g
s
.265 0 0 r
.41748 .60539 m .41034 .60295 L .42198 .60646 L p F P
0 g
s
.265 0 0 r
.42198 .60646 m .42309 .60681 L .41748 .60539 L p F P
0 g
s
.184 0 .183 r
.74116 .54514 m .72961 .55261 L .74179 .54006 L p F P
0 g
s
.184 0 .183 r
.74179 .54006 m .74275 .53944 L .74116 .54514 L p F P
0 g
s
.546 .573 .833 r
.75144 .41741 m .75507 .42493 L .76986 .42561 L p F P
0 g
s
.338 .651 .969 r
.40907 .42995 m .4004 .42851 L .40825 .43376 L p F P
0 g
s
.338 .651 .969 r
.40825 .43376 m .41463 .43459 L .40907 .42995 L p F P
0 g
s
0 0 0 r
.58799 .4563 m .59121 .4546 L .57137 .46016 L p F P
0 g
s
0 0 0 r
.57137 .46016 m .56884 .4613 L .58799 .4563 L p F P
0 g
s
.08 .64 .716 r
.57299 .61875 m .57192 .61884 L .56581 .61944 L closepath p F P
0 g
s
.112 .665 .754 r
.56702 .61924 m .57192 .61884 L .56581 .61944 L p F P
0 g
s
.112 .665 .754 r
.54795 .62091 m .56702 .61924 L p .56581 .61944 L F P
0 g
s
.809 .325 .033 r
.32055 .55477 m .32841 .55976 L .32356 .55301 L p F P
0 g
s
.809 .325 .033 r
.32356 .55301 m .31576 .548 L .32055 .55477 L p F P
0 g
s
.048 .55 .881 r
.43828 .44472 m .42997 .44218 L .43975 .44668 L p F P
0 g
s
.048 .55 .881 r
.43975 .44668 m .44378 .44762 L .43828 .44472 L p F P
0 g
s
.846 .76 .768 r
.28241 .44665 m .27702 .4404 L .28575 .42921 L p F P
0 g
s
.874 .758 .731 r
.27702 .4404 m .28241 .44665 L .27617 .45694 L p F P
0 g
s
.098 0 .046 r
.72961 .55261 m .72413 .55732 L .7227 .56069 L p F P
0 g
s
.4 0 0 r
.47295 .45781 m .47456 .45846 L .47167 .4576 L closepath p F P
0 g
s
.115 0 .157 r
.75832 .52802 m .75838 .52782 L .74275 .53944 L p F P
0 g
s
.115 0 .157 r
.7488 .53948 m .75832 .52802 L p .74275 .53944 L F P
0 g
s
.115 0 .157 r
.74275 .53944 m .74116 .54514 L .7488 .53948 L p F P
0 g
s
.098 0 .046 r
.73958 .54868 m .74116 .54514 L .72961 .55261 L p F P
0 g
s
.098 0 .046 r
.73534 .55251 m .73958 .54868 L p .72961 .55261 L F P
0 g
s
.098 0 .046 r
.7227 .56069 m .73534 .55251 L p .72961 .55261 L F P
0 g
s
.289 0 0 r
.43584 .61065 m .42309 .60681 L .41748 .60539 L p F P
0 g
s
.493 .666 .939 r
.36841 .41571 m .36185 .41571 L .35617 .40962 L p F P
0 g
s
.686 .726 .88 r
.70219 .4132 m .72168 .40566 L .72615 .41204 L p F P
0 g
s
.706 .757 .891 r
.72168 .40566 m .70219 .4132 L .69775 .40853 L p F P
0 g
s
.162 .701 .76 r
.59108 .61588 m .59446 .6155 L .57299 .61875 L p F P
0 g
s
.162 .701 .76 r
.57299 .61875 m .57192 .61884 L .59108 .61588 L p F P
0 g
s
.638 .649 .844 r
.72615 .41204 m .74592 .40713 L .75046 .41546 L p F P
0 g
s
.658 .68 .86 r
.74592 .40713 m .72615 .41204 L .72168 .40566 L p F P
0 g
s
.806 .325 .065 r
.33591 .56361 m .33663 .56458 L .33403 .56308 L closepath p F P
0 g
s
0 .567 .775 r
.49248 .61989 m .49475 .62014 L .4786 .61858 L p F P
0 g
s
0 .567 .775 r
.48297 .61879 m .49248 .61989 L p .4786 .61858 L F P
0 g
s
0 .567 .775 r
.47074 .61741 m .48297 .61879 L p .4786 .61858 L F P
0 g
s
0 .567 .775 r
.4786 .61858 m .4749 .61813 L .47074 .61741 L p F P
0 g
s
.92 .722 .618 r
.27233 .4664 m .27811 .47242 L .27572 .48138 L p F P
0 g
s
0 0 0 r
.68099 .58708 m .66259 .59486 L .65921 .59716 L p F P
0 g
s
.535 .924 .844 r
.63103 .43619 m .63182 .43619 L .61477 .44554 L p F P
0 g
s
.535 .924 .844 r
.61477 .44554 m .61184 .44606 L .63103 .43619 L p F P
0 g
s
0 0 0 r
.61505 .61115 m .61506 .61114 L .59583 .61502 L p F P
0 g
s
0 0 0 r
.59583 .61502 m .59446 .6155 L .61505 .61115 L p F P
0 g
s
0 .502 .723 r
.4749 .61813 m .47074 .61741 L .46325 .6163 L closepath p F P
0 g
s
.048 0 0 r
.51882 .6214 m .50001 .62064 L .49475 .62014 L p F P
0 g
s
.395 0 0 r
.47254 .45959 m .48569 .46288 L .47456 .45846 L p F P
0 g
s
.395 0 0 r
.46755 .45693 m .47254 .45959 L p .47456 .45846 L F P
0 g
s
.395 0 0 r
.47456 .45846 m .47167 .4576 L .46755 .45693 L p F P
0 g
s
.387 .291 .624 r
.78745 .4703 m .77922 .47902 L .77518 .47175 L p F P
0 g
s
.387 .291 .624 r
.78612 .46276 m .78745 .4703 L p .77518 .47175 L F P
0 g
s
.387 .291 .624 r
.77518 .47175 m .78514 .46112 L .78612 .46276 L p F P
0 g
s
.726 .844 .937 r
.67905 .41849 m .67842 .41797 L .68083 .41681 L closepath p F P
0 g
s
.333 .205 .553 r
.78075 .48717 m .77437 .49361 L .77344 .48489 L p F P
0 g
s
.333 .205 .553 r
.77344 .48489 m .77922 .47902 L .78075 .48717 L p F P
0 g
s
.308 .138 .481 r
.77463 .50146 m .76821 .50713 L .76926 .49814 L p F P
0 g
s
.308 .138 .481 r
.76926 .49814 m .77437 .49361 L .77463 .50146 L p F P
0 g
s
.688 .143 0 r
.33467 .5661 m .34299 .5709 L .33663 .56458 L p F P
0 g
s
.688 .143 0 r
.32994 .5613 m .33467 .5661 L p .33663 .56458 L F P
0 g
s
.688 .143 0 r
.33663 .56458 m .33403 .56308 L .32994 .5613 L p F P
0 g
s
0 0 0 r
.59271 .45377 m .59121 .4546 L .60965 .44712 L p F P
0 g
s
.623 .958 .905 r
.65198 .42731 m .63557 .43611 L .63182 .43619 L p F P
0 g
s
.337 0 0 r
.47167 .4576 m .46755 .45693 L .46196 .455 L closepath p F P
0 g
s
0 0 0 r
.65386 .59914 m .65827 .59749 L .65779 .59766 L p F P
0 g
s
0 0 0 r
.65779 .59766 m .63892 .60414 L p .65386 .59914 L F P
0 g
s
.299 .777 .681 r
.65386 .59914 m .65385 .59914 L .65385 .59914 L p F P
0 g
s
0 0 0 r
.65902 .59722 m .64028 .60364 L p .65827 .59749 L F P
0 g
s
0 0 0 r
.64028 .60364 m .63892 .60414 L .65827 .59749 L p F P
0 g
s
0 0 0 r
.65921 .59716 m .67369 .59116 L p .68099 .58708 L F P
0 g
s
.299 .777 .681 r
.65385 .59914 m .6721 .59144 L p .65386 .59914 L F P
0 g
s
.294 .775 .683 r
.65827 .59749 m .65386 .59914 L p .65495 .5987 L F P
0 g
s
.294 .775 .683 r
.67369 .59116 m .65827 .59749 L p .65495 .5987 L F P
0 g
s
0 0 0 r
.65827 .59749 m .65921 .59716 L .65902 .59722 L p F P
0 g
s
.721 .881 .955 r
.68083 .41681 m .67842 .41797 L .67397 .41507 L p F P
0 g
s
.751 .886 .941 r
.65473 .42583 m .67397 .41507 L .67842 .41797 L p F P
0 g
s
.586 .603 .837 r
.75046 .41546 m .75298 .41527 L .75144 .41741 L closepath p F P
0 g
s
.546 .573 .833 r
.77072 .4148 m .75298 .41527 L .75144 .41741 L p F P
0 g
s
.546 .573 .833 r
.77341 .42117 m .77072 .4148 L p .75144 .41741 L F P
0 g
s
.546 .573 .833 r
.76986 .42561 m .77341 .42117 L p .75144 .41741 L F P
0 g
s
.12 .67 .721 r
.59108 .61588 m .57192 .61884 L .56702 .61924 L p F P
0 g
s
.006 0 0 r
.54292 .6211 m .52397 .62152 L .51882 .6214 L p F P
0 g
s
.447 0 0 r
.45087 .45098 m .44378 .44762 L .43828 .44472 L p F P
0 g
s
.473 0 0 r
.39386 .5966 m .39925 .59923 L .41034 .60295 L p F P
0 g
s
.466 0 0 r
.39925 .59923 m .39386 .5966 L .38811 .59502 L p F P
0 g
s
.614 .046 0 r
.36473 .58284 m .36889 .58581 L .37862 .59003 L p F P
0 g
s
.448 0 0 r
.37873 .59115 m .36889 .58581 L .37862 .59003 L p F P
0 g
s
.448 0 0 r
.38736 .59478 m .37873 .59115 L p .37862 .59003 L F P
0 g
s
.448 0 0 r
.37862 .59003 m .38811 .59502 L .38736 .59478 L p F P
0 g
s
.874 .758 .731 r
.27617 .45694 m .27076 .45072 L .27702 .4404 L p F P
0 g
s
.899 .753 .69 r
.27589 .45755 m .27617 .45694 L .27076 .45072 L p F P
0 g
s
0 0 0 r
.56702 .61924 m .54795 .62091 L .54292 .6211 L p F P
0 g
s
.748 .883 .941 r
.68083 .41681 m .69775 .40853 L .69331 .40448 L p F P
0 g
s
.748 .883 .941 r
.69331 .40448 m .69183 .40529 L .68083 .41681 L p F P
0 g
s
.721 .881 .955 r
.67397 .41507 m .69183 .40529 L .68083 .41681 L p F P
0 g
s
.899 .753 .69 r
.27076 .45072 m .26981 .45278 L .27589 .45755 L p F P
0 g
s
.908 .746 .67 r
.26683 .46022 m .26981 .45278 L .27589 .45755 L p F P
0 g
s
.908 .746 .67 r
.27589 .45755 m .27233 .4664 L .26683 .46022 L p F P
0 g
s
.291 0 0 r
.44684 .61314 m .44897 .61367 L .46325 .6163 L p F P
0 g
s
0 .514 .742 r
.46533 .61635 m .44897 .61367 L .46325 .6163 L p F P
0 g
s
0 .514 .742 r
.46325 .6163 m .47074 .61741 L .46533 .61635 L p F P
0 g
s
.708 .171 0 r
.33403 .56308 m .32994 .5613 L .32841 .55976 L closepath p F P
0 g
s
.267 0 0 r
.41183 .60378 m .39925 .59923 L .41034 .60295 L p F P
0 g
s
.267 0 0 r
.41034 .60295 m .41748 .60539 L .41183 .60378 L p F P
0 g
s
.61 .041 0 r
.36889 .58581 m .36473 .58284 L .35886 .58089 L p F P
0 g
s
.601 .628 .85 r
.75298 .41527 m .75046 .41546 L .74592 .40713 L p F P
0 g
s
.909 .523 .272 r
.28992 .5222 m .28841 .51744 L .29517 .52294 L p F P
0 g
s
.909 .523 .272 r
.29517 .52294 m .29602 .52555 L .28992 .5222 L p F P
0 g
s
.932 .602 .388 r
.28195 .51178 m .28841 .51744 L .28721 .50962 L p F P
0 g
s
.932 .602 .388 r
.28721 .50962 m .28077 .50395 L .28195 .51178 L p F P
0 g
s
.793 .767 .83 r
.28959 .42503 m .3011 .4156 L .29611 .4091 L p F P
0 g
s
.793 .767 .83 r
.29611 .4091 m .28361 .41954 L .28959 .42503 L p F P
0 g
s
.829 .766 .793 r
.28066 .42278 m .28361 .41954 L .28959 .42503 L p F P
0 g
s
.829 .766 .793 r
.28959 .42503 m .28575 .42921 L .28066 .42278 L p F P
0 g
s
0 .425 .822 r
.41463 .43459 m .42131 .43725 L .42997 .44218 L p F P
0 g
s
0 .401 .823 r
.42131 .43725 m .41463 .43459 L .40907 .42995 L p F P
0 g
s
.869 .431 .145 r
.30114 .53752 m .30829 .54284 L .30471 .53572 L p F P
0 g
s
.869 .431 .145 r
.30471 .53572 m .29758 .5304 L .30114 .53752 L p F P
0 g
s
.94 .657 .477 r
.27463 .49813 m .28077 .50395 L .28071 .49577 L p F P
0 g
s
.94 .657 .477 r
.28071 .49577 m .27459 .48994 L .27463 .49813 L p F P
0 g
s
.85 .768 .77 r
.28066 .42278 m .28575 .42921 L .27702 .4404 L p F P
0 g
s
.226 .746 .778 r
.61038 .61173 m .61505 .61115 L .59446 .6155 L p F P
0 g
s
.226 .746 .778 r
.59446 .6155 m .59108 .61588 L .61038 .61173 L p F P
0 g
s
.591 .019 0 r
.35074 .57682 m .34299 .5709 L .35168 .57553 L p F P
0 g
s
.591 .019 0 r
.35747 .58034 m .35074 .57682 L p .35168 .57553 L F P
0 g
s
.591 .019 0 r
.35168 .57553 m .35886 .58089 L .35747 .58034 L p F P
0 g
s
.493 .666 .939 r
.35617 .40962 m .3625 .40964 L .36841 .41571 L p F P
0 g
s
.51 .675 .939 r
.37419 .4094 m .3625 .40964 L .36841 .41571 L p F P
0 g
s
.51 .675 .939 r
.36841 .41571 m .37984 .41546 L .37419 .4094 L p F P
0 g
s
.77 .758 .841 r
.30827 .41038 m .3011 .4156 L .29611 .4091 L p F P
0 g
s
0 .496 .857 r
.43265 .44143 m .42131 .43725 L .42997 .44218 L p F P
0 g
s
0 .496 .857 r
.43288 .44154 m .43265 .44143 L p .42997 .44218 L F P
0 g
s
0 .496 .857 r
.42997 .44218 m .43828 .44472 L .43288 .44154 L p F P
0 g
s
.623 .707 .905 r
.34473 .39696 m .32658 .40151 L .33236 .40771 L p F P
0 g
s
.623 .707 .905 r
.33236 .40771 m .35047 .40337 L .34473 .39696 L p F P
0 g
s
.279 .593 .948 r
.38547 .42121 m .39329 .42295 L .4004 .42851 L p F P
0 g
s
.286 .581 .941 r
.39329 .42295 m .38547 .42121 L .37984 .41546 L p F P
0 g
s
.469 0 0 r
.49681 .46393 m .50114 .46535 L .49465 .46441 L closepath p F P
0 g
s
.249 0 0 r
.44684 .61314 m .44897 .61367 L .44541 .61293 L closepath p F P
0 g
s
.601 .628 .85 r
.74592 .40713 m .75979 .40531 L .75298 .41527 L p F P
0 g
s
.572 .578 .821 r
.76607 .40472 m .75979 .40531 L .75298 .41527 L p F P
0 g
s
.572 .578 .821 r
.75298 .41527 m .77072 .4148 L .76607 .40472 L p F P
0 g
s
.324 .627 .96 r
.40348 .42491 m .39329 .42295 L .4004 .42851 L p F P
0 g
s
.324 .627 .96 r
.4004 .42851 m .40907 .42995 L .40348 .42491 L p F P
0 g
s
.336 0 0 r
.46121 .45563 m .45087 .45098 L .46196 .455 L p F P
0 g
s
.336 0 0 r
.46283 .45614 m .46121 .45563 L p .46196 .455 L F P
0 g
s
.336 0 0 r
.46196 .455 m .46755 .45693 L .46283 .45614 L p F P
0 g
s
.155 0 .273 r
.75863 .52761 m .75838 .52782 L .75934 .52146 L p F P
0 g
s
.155 0 .273 r
.75934 .52146 m .76464 .51696 L .75863 .52761 L p F P
0 g
s
.43 .361 .679 r
.7857 .46049 m .78514 .46112 L .77811 .45486 L p F P
0 g
s
.43 .361 .679 r
.77811 .45486 m .78301 .44936 L .7857 .46049 L p F P
0 g
s
.807 .318 0 r
.31304 .54961 m .32055 .55477 L .31576 .548 L p F P
0 g
s
.807 .318 0 r
.31576 .548 m .30829 .54284 L .31304 .54961 L p F P
0 g
s
.92 .722 .618 r
.27572 .48138 m .26991 .47538 L .27233 .4664 L p F P
0 g
s
.938 .7 .553 r
.26991 .47538 m .27572 .48138 L .27459 .48994 L p F P
0 g
s
0 0 0 r
.70295 .57454 m .70119 .57631 L .71539 .56756 L closepath p F P
0 g
s
.709 .737 .873 r
.32076 .39528 m .30238 .40446 L .30827 .41038 L p F P
0 g
s
.709 .737 .873 r
.30827 .41038 m .32658 .40151 L .32076 .39528 L p F P
0 g
s
.77 .758 .841 r
.29611 .4091 m .30238 .40446 L .30827 .41038 L p F P
0 g
s
0 0 0 r
.60722 .44822 m .60529 .44975 L .60862 .44776 L p F P
0 g
s
0 0 0 r
.60722 .44822 m .60965 .44712 L .60575 .4487 L p F P
0 g
s
.417 .843 .691 r
.62647 .43739 m .62652 .43738 L .60965 .44712 L p F P
0 g
s
.417 .843 .691 r
.60965 .44712 m .60722 .44822 L .62647 .43739 L p F P
0 g
s
0 0 0 r
.62205 .43974 m .62647 .43739 L .60785 .44786 L p F P
0 g
s
0 0 0 r
.60785 .44786 m .60722 .44822 L p .61456 .44402 L F P
0 g
s
0 0 0 r
.61456 .44402 m .62205 .43974 L .60785 .44786 L F
.404 .832 .676 r
.62652 .43738 m .63103 .43619 L .61184 .44606 L p F P
0 g
s
0 0 0 r
.60862 .44776 m .62205 .43974 L p .60722 .44822 L F P
0 g
s
0 0 0 r
.62191 .43981 m .62205 .43974 L .62168 .43996 L p F P
0 g
s
0 0 0 r
.62168 .43996 m .60529 .44975 L p .62191 .43981 L F P
0 g
s
0 0 0 r
.62191 .43981 m .61817 .44293 L p .62225 .43959 L F P
0 g
s
.551 .907 .704 r
.62205 .43974 m .62191 .43981 L .62261 .4393 L closepath p F P
0 g
s
0 0 0 r
.62261 .4393 m .62191 .43981 L p .62225 .43959 L F P
0 g
s
0 0 0 r
.60529 .44975 m .60257 .45186 L .62186 .43984 L p F P
0 g
s
0 0 0 r
.62186 .43984 m .62191 .43981 L p .62181 .43987 L F P
0 g
s
0 0 0 r
.60529 .44975 m .62186 .43984 L .62181 .43987 L F
.60575 .4487 m .59121 .4546 L p .60722 .44822 L F P
0 g
s
0 0 0 r
.59121 .4546 m .58799 .4563 L .60722 .44822 L p F P
0 g
s
.129 0 0 r
.58681 .45734 m .58799 .4563 L .56884 .4613 L p F P
0 g
s
.129 0 0 r
.56884 .4613 m .56682 .46286 L .58681 .45734 L p F P
0 g
s
0 0 0 r
.65337 .59931 m .65386 .59914 L p .63892 .60414 L F P
0 g
s
0 0 0 r
.63892 .60414 m .63483 .60569 L .65337 .59931 L p F P
0 g
s
0 0 0 r
.63483 .60569 m .63892 .60414 L p .61506 .61114 L F P
0 g
s
.91 .527 .279 r
.29758 .5304 m .29602 .52555 L .28992 .5222 L p F P
0 g
s
0 0 0 r
.7227 .56069 m .72046 .56406 L .73534 .55251 L closepath p F P
0 g
s
.691 .957 .948 r
.65473 .42583 m .65198 .42731 L .65428 .42573 L closepath p F P
0 g
s
.623 .958 .905 r
.65024 .42484 m .65428 .42573 L .65198 .42731 L p F P
0 g
s
.623 .958 .905 r
.63539 .43362 m .65024 .42484 L p .65198 .42731 L F P
0 g
s
.623 .958 .905 r
.63182 .43619 m .63539 .43362 L p .65198 .42731 L F P
0 g
s
.227 .022 .38 r
.77426 .5085 m .76464 .51696 L .76821 .50713 L p F P
0 g
s
.227 .022 .38 r
.76821 .50713 m .77463 .50146 L .77426 .5085 L p F P
0 g
s
.06 0 0 r
.68189 .58667 m .68099 .58708 L .68184 .58673 L closepath p F P
0 g
s
0 0 0 r
.67768 .58944 m .68184 .58673 L .68099 .58708 L p F P
0 g
s
0 0 0 r
.67369 .59116 m .67768 .58944 L p .68099 .58708 L F P
0 g
s
0 .547 .803 r
.46426 .61611 m .46533 .61635 L .44897 .61367 L p F P
0 g
s
0 .547 .803 r
.45304 .61388 m .46426 .61611 L p .44897 .61367 L F P
0 g
s
0 .547 .803 r
.44133 .61178 m .45304 .61388 L p .44897 .61367 L F P
0 g
s
0 .547 .803 r
.44897 .61367 m .44541 .61293 L .44133 .61178 L p F P
0 g
s
.881 .768 .733 r
.27195 .43398 m .27702 .4404 L .27076 .45072 L p F P
0 g
s
.85 .768 .77 r
.27702 .4404 m .27195 .43398 L .28066 .42278 L p F P
0 g
s
.26 .104 .47 r
.77996 .49611 m .77463 .50146 L .77437 .49361 L p F P
0 g
s
.26 .104 .47 r
.77437 .49361 m .78075 .48717 L .77996 .49611 L p F P
0 g
s
0 0 0 r
.69937 .57819 m .70119 .57631 L .68189 .58667 L p F P
0 g
s
0 0 0 r
.68189 .58667 m .68184 .58673 L .69937 .57819 L p F P
0 g
s
.279 0 0 r
.54416 .46609 m .52126 .46688 L .52081 .46705 L p F P
0 g
s
.404 0 0 r
.52126 .46688 m .52081 .46705 L .51952 .4668 L closepath p F P
0 g
s
.497 .661 .934 r
.35705 .40335 m .35047 .40337 L .35617 .40962 L p F P
0 g
s
.497 .661 .934 r
.35617 .40962 m .3625 .40964 L .35705 .40335 L p F P
0 g
s
.449 0 0 r
.51367 .4694 m .50114 .46535 L .51952 .4668 L p F P
0 g
s
.449 0 0 r
.51637 .46959 m .51367 .4694 L p .51952 .4668 L F P
0 g
s
.449 0 0 r
.51952 .4668 m .52081 .46705 L .51637 .46959 L p F P
0 g
s
.658 .68 .86 r
.72168 .40566 m .74142 .3996 L .74592 .40713 L p F P
0 g
s
.677 .709 .872 r
.74142 .3996 m .72168 .40566 L .71723 .39992 L p F P
0 g
s
.706 .757 .891 r
.69775 .40853 m .71723 .39992 L .72168 .40566 L p F P
0 g
s
0 0 0 r
.69712 .57955 m .69937 .57819 L .68184 .58673 L p F P
0 g
s
0 0 0 r
.68184 .58673 m .67768 .58944 L .69712 .57955 L p F P
0 g
s
.741 .967 .934 r
.66951 .41283 m .67397 .41507 L .65473 .42583 L p F P
0 g
s
.741 .967 .934 r
.66701 .4144 m .66951 .41283 L p .65473 .42583 L F P
0 g
s
.741 .967 .934 r
.65473 .42583 m .65428 .42573 L .66701 .4144 L p F P
0 g
s
.695 .154 0 r
.32396 .55828 m .32055 .55477 L .32841 .55976 L p F P
0 g
s
.695 .154 0 r
.32841 .55976 m .32994 .5613 L .32396 .55828 L p F P
0 g
s
.929 .733 .617 r
.26683 .46022 m .27233 .4664 L .26991 .47538 L p F P
0 g
s
0 .49 .758 r
.44541 .61293 m .44133 .61178 L .43584 .61065 L closepath p F P
0 g
s
.32 0 0 r
.54501 .46604 m .54485 .46612 L .54416 .46609 L closepath p F P
0 g
s
.279 0 0 r
.54074 .46934 m .54485 .46612 L .54416 .46609 L p F P
0 g
s
.279 0 0 r
.53615 .46948 m .54074 .46934 L p .54416 .46609 L F P
0 g
s
.279 0 0 r
.52081 .46705 m .53615 .46948 L p .54416 .46609 L F P
0 g
s
.214 0 0 r
.56397 .465 m .56682 .46286 L .54501 .46604 L p F P
0 g
s
.214 0 0 r
.54501 .46604 m .54485 .46612 L .56397 .465 L p F P
0 g
s
.483 .445 .738 r
.77687 .43929 m .77914 .4366 L .78047 .44076 L closepath p F P
0 g
s
.426 0 0 r
.52081 .46705 m .53615 .46948 L .51637 .46959 L closepath p F P
0 g
s
.466 0 0 r
.38811 .59502 m .38867 .59531 L .39925 .59923 L p F P
0 g
s
.263 0 0 r
.40103 .59993 m .38867 .59531 L .39925 .59923 L p F P
0 g
s
.263 0 0 r
.4118 .60377 m .40103 .59993 L p .39925 .59923 L F P
0 g
s
.263 0 0 r
.39925 .59923 m .41183 .60378 L .4118 .60377 L p F P
0 g
s
.727 .786 .899 r
.71723 .39992 m .69775 .40853 L .69331 .40448 L p F P
0 g
s
.61 .041 0 r
.35886 .58089 m .35957 .58142 L .36889 .58581 L p F P
0 g
s
.421 0 0 r
.36927 .58679 m .37873 .59115 L .36889 .58581 L p F P
0 g
s
.421 0 0 r
.36889 .58581 m .35957 .58142 L .36927 .58679 L p F P
0 g
s
.742 .964 .937 r
.65428 .42573 m .65024 .42484 L .66701 .4144 L closepath p F P
0 g
s
.327 0 0 r
.5628 .4663 m .56397 .465 L .54485 .46612 L p F P
0 g
s
.327 0 0 r
.54485 .46612 m .54074 .46934 L .5628 .4663 L p F P
0 g
s
.319 .196 .551 r
.78842 .47906 m .78075 .48717 L .77922 .47902 L p F P
0 g
s
.319 .196 .551 r
.77922 .47902 m .78745 .4703 L .78842 .47906 L p F P
0 g
s
.53 .518 .786 r
.76986 .42561 m .77341 .42117 L .77549 .42643 L closepath p F P
0 g
s
0 .519 .731 r
.48297 .61879 m .47074 .61741 L .46533 .61635 L p F P
0 g
s
.465 0 0 r
.49652 .46749 m .51367 .4694 L .50114 .46535 L p F P
0 g
s
.465 0 0 r
.4915 .46509 m .49652 .46749 L p .50114 .46535 L F P
0 g
s
.465 0 0 r
.50114 .46535 m .49465 .46441 L .4915 .46509 L p F P
0 g
s
0 0 0 r
.74116 .54514 m .73958 .54868 L .7488 .53948 L closepath p F P
0 g
s
.62 .632 .841 r
.75979 .40531 m .74592 .40713 L .74142 .3996 L p F P
0 g
s
.71 .175 0 r
.33467 .5661 m .32994 .5613 L .32396 .55828 L p F P
0 g
s
.289 0 0 r
.41748 .60539 m .42354 .60733 L .43584 .61065 L p F P
0 g
s
.275 0 0 r
.42354 .60733 m .41748 .60539 L .41183 .60378 L p F P
0 g
s
.502 0 0 r
.49465 .46441 m .4915 .46509 L .48569 .46288 L closepath p F P
0 g
s
0 0 0 r
.61506 .61114 m .61555 .61101 L .63483 .60569 L p F P
0 g
s
0 0 0 r
.61506 .61114 m .61555 .61101 L .61505 .61115 L closepath p F P
0 g
s
.301 .796 .802 r
.61555 .61101 m .61505 .61115 L .61038 .61173 L p F P
0 g
s
.447 0 0 r
.43828 .44472 m .44123 .44641 L .45087 .45098 L p F P
0 g
s
.433 0 0 r
.45027 .4515 m .46121 .45563 L .45087 .45098 L p F P
0 g
s
.433 0 0 r
.45087 .45098 m .44123 .44641 L .45027 .4515 L p F P
0 g
s
.296 .792 .797 r
.63483 .60569 m .63441 .60574 L .61555 .61101 L closepath p F P
0 g
s
.301 .796 .802 r
.62981 .60634 m .63441 .60574 L .61555 .61101 L p F P
0 g
s
.301 .796 .802 r
.61038 .61173 m .62981 .60634 L p .61555 .61101 L F P
0 g
s
.574 .005 0 r
.34232 .57205 m .35074 .57682 L .34299 .5709 L p F P
0 g
s
.574 .005 0 r
.34299 .5709 m .33467 .5661 L .34232 .57205 L p F P
0 g
s
.881 .768 .733 r
.27076 .45072 m .26569 .44432 L .27195 .43398 L p F P
0 g
s
.909 .764 .689 r
.26981 .45278 m .27076 .45072 L .26569 .44432 L p F P
0 g
s
.916 .529 .256 r
.28384 .51787 m .28195 .51178 L .28841 .51744 L p F P
0 g
s
.916 .529 .256 r
.28841 .51744 m .28992 .5222 L .28384 .51787 L p F P
0 g
s
.507 0 0 r
.46755 .45693 m .47254 .45959 L .46283 .45614 L closepath p F P
0 g
s
0 .425 .842 r
.42396 .43645 m .43265 .44143 L .42131 .43725 L p F P
0 g
s
0 .425 .842 r
.42131 .43725 m .41351 .43196 L .42396 .43645 L p F P
0 g
s
0 .401 .823 r
.40907 .42995 m .41351 .43196 L .42131 .43725 L p F P
0 g
s
.94 .608 .374 r
.27579 .50597 m .28195 .51178 L .28077 .50395 L p F P
0 g
s
.94 .608 .374 r
.28077 .50395 m .27463 .49813 L .27579 .50597 L p F P
0 g
s
0 .505 .782 r
.43578 .61004 m .42354 .60733 L .43584 .61065 L p F P
0 g
s
0 .505 .782 r
.43584 .61065 m .44133 .61178 L .43578 .61004 L p F P
0 g
s
.304 .782 .693 r
.65921 .59716 m .65827 .59749 L .67369 .59116 L closepath p F P
0 g
s
.91 .527 .279 r
.28992 .5222 m .29077 .52492 L .29758 .5304 L p F P
0 g
s
.87 .427 .114 r
.29431 .53204 m .30114 .53752 L .29758 .5304 L p F P
0 g
s
.87 .427 .114 r
.29758 .5304 m .29077 .52492 L .29431 .53204 L p F P
0 g
s
.116 0 .241 r
.77152 .5163 m .75863 .52761 L .76464 .51696 L p F P
0 g
s
.116 0 .241 r
.77361 .51246 m .77152 .5163 L p .76464 .51696 L F P
0 g
s
.116 0 .241 r
.76464 .51696 m .77426 .5085 L .77361 .51246 L p F P
0 g
s
.424 .408 .737 r
.7939 .43467 m .78431 .42929 L .77914 .4366 L p F P
0 g
s
.424 .408 .737 r
.78666 .44459 m .7939 .43467 L p .77914 .4366 L F P
0 g
s
.424 .408 .737 r
.77914 .4366 m .78047 .44076 L .78666 .44459 L p F P
0 g
s
.487 .472 .766 r
.77549 .42643 m .78431 .42929 L .77914 .4366 L closepath p F P
0 g
s
.444 .404 .72 r
.78047 .44076 m .78666 .44459 L .78301 .44936 L closepath p F P
0 g
s
.909 .764 .689 r
.26569 .44432 m .2636 .44889 L .26981 .45278 L p F P
0 g
s
.916 .757 .67 r
.26162 .45388 m .2636 .44889 L .26981 .45278 L p F P
0 g
s
.916 .757 .67 r
.26981 .45278 m .26683 .46022 L .26162 .45388 L p F P
0 g
s
.938 .7 .553 r
.27459 .48994 m .26876 .48395 L .26991 .47538 L p F P
0 g
s
.949 .667 .469 r
.26876 .48395 m .27459 .48994 L .27463 .49813 L p F P
0 g
s
.8 .776 .831 r
.28361 .41954 m .29611 .4091 L .29143 .40243 L p F P
0 g
s
.8 .776 .831 r
.29143 .40243 m .27756 .41429 L .28361 .41954 L p F P
0 g
s
.834 .773 .795 r
.27587 .41618 m .27756 .41429 L .28361 .41954 L p F P
0 g
s
.834 .773 .795 r
.28361 .41954 m .28066 .42278 L .27587 .41618 L p F P
0 g
s
.515 .667 .931 r
.37419 .4094 m .3625 .40964 L .35705 .40335 L p F P
0 g
s
.048 0 0 r
.51845 .62139 m .51882 .6214 L p .49475 .62014 L F P
0 g
s
.048 0 0 r
.49475 .62014 m .50038 .62045 L .51845 .62139 L p F P
0 g
s
.006 .579 .758 r
.49475 .62014 m .50038 .62045 L .49248 .61989 L closepath p F P
0 g
s
.286 .581 .941 r
.37984 .41546 m .38679 .41712 L .39329 .42295 L p F P
0 g
s
.323 .608 .951 r
.39786 .41942 m .38679 .41712 L .39329 .42295 L p F P
0 g
s
.323 .608 .951 r
.39329 .42295 m .40348 .42491 L .39786 .41942 L p F P
0 g
s
0 0 0 r
.71539 .56756 m .70119 .57631 L .69937 .57819 L p F P
0 g
s
.671 .971 .91 r
.63182 .43619 m .63103 .43619 L .63539 .43362 L closepath p F P
0 g
s
.517 0 0 r
.48211 .46461 m .47254 .45959 L .48569 .46288 L p F P
0 g
s
.517 0 0 r
.48857 .46595 m .48211 .46461 L p .48569 .46288 L F P
0 g
s
.517 0 0 r
.48569 .46288 m .4915 .46509 L .48857 .46595 L p F P
0 g
s
.137 0 0 r
.58324 .46041 m .58681 .45734 L .56682 .46286 L p F P
0 g
s
.137 0 0 r
.56682 .46286 m .56397 .465 L .58324 .46041 L p F P
0 g
s
.855 .776 .773 r
.27587 .41618 m .28066 .42278 L .27195 .43398 L p F P
0 g
s
.627 .705 .901 r
.33896 .3904 m .32076 .39528 L .32658 .40151 L p F P
0 g
s
.627 .705 .901 r
.32658 .40151 m .34473 .39696 L .33896 .3904 L p F P
0 g
s
.395 .339 .676 r
.79298 .4511 m .7857 .46049 L .78301 .44936 L p F P
0 g
s
.395 .339 .676 r
.78301 .44936 m .78666 .44459 L .79298 .4511 L p F P
0 g
s
.801 .309 0 r
.30586 .5443 m .31304 .54961 L .30829 .54284 L p F P
0 g
s
.801 .309 0 r
.30829 .54284 m .30114 .53752 L .30586 .5443 L p F P
0 g
s
.738 .917 .953 r
.69183 .40529 m .67397 .41507 L .66951 .41283 L p F P
0 g
s
0 .387 .827 r
.41351 .43196 m .40907 .42995 L .40348 .42491 L p F P
0 g
s
.774 .762 .842 r
.30238 .40446 m .29611 .4091 L .29143 .40243 L p F P
0 g
s
0 .219 .623 r
.43828 .44472 m .44123 .44641 L .43288 .44154 L closepath p F P
0 g
s
.302 .574 .935 r
.38679 .41712 m .37984 .41546 L .37419 .4094 L p F P
0 g
s
.221 .743 .775 r
.6083 .612 m .61038 .61173 L .59108 .61588 L p F P
0 g
s
.221 .743 .775 r
.59108 .61588 m .58747 .61628 L .6083 .612 L p F P
0 g
s
.12 .67 .721 r
.58747 .61628 m .59108 .61588 L p .56702 .61924 L F P
0 g
s
.472 .484 .788 r
.77341 .42117 m .77549 .42643 L .78431 .42929 L p F P
0 g
s
.433 0 0 r
.38811 .59502 m .38867 .59531 L .38736 .59478 L closepath p F P
0 g
s
.929 .733 .617 r
.26991 .47538 m .26439 .46922 L .26683 .46022 L p F P
0 g
s
.947 .711 .549 r
.26439 .46922 m .26991 .47538 L .26876 .48395 L p F P
0 g
s
.713 .739 .872 r
.31489 .38904 m .29644 .39865 L .30238 .40446 L p F P
0 g
s
.713 .739 .872 r
.30238 .40446 m .32076 .39528 L .31489 .38904 L p F P
0 g
s
.774 .762 .842 r
.29143 .40243 m .29644 .39865 L .30238 .40446 L p F P
0 g
s
.587 .014 0 r
.35886 .58089 m .35957 .58142 L .35747 .58034 L closepath p F P
0 g
s
0 .384 .724 r
.39074 .59586 m .40103 .59993 L .38867 .59531 L p F P
0 g
s
0 .384 .724 r
.38235 .59259 m .39074 .59586 L p .38867 .59531 L F P
0 g
s
0 .384 .724 r
.38867 .59531 m .38736 .59478 L .38235 .59259 L p F P
0 g
s
.006 0 0 r
.54273 .62111 m .54292 .6211 L p .51882 .6214 L F P
0 g
s
.006 0 0 r
.51882 .6214 m .52004 .62139 L .54273 .62111 L p F P
0 g
s
.042 .611 .749 r
.51882 .6214 m .52004 .62139 L .51845 .62139 L closepath p F P
0 g
s
.17 0 .363 r
.77696 .5058 m .77426 .5085 L .77463 .50146 L p F P
0 g
s
.17 0 .363 r
.77463 .50146 m .77996 .49611 L .77696 .5058 L p F P
0 g
s
.12 .67 .721 r
.56702 .61924 m .57692 .61779 L .58747 .61628 L p F P
0 g
s
.154 .696 .759 r
.56702 .61924 m .57692 .61779 L .56565 .61934 L closepath p F P
0 g
s
0 0 0 r
.56565 .61934 m .56702 .61924 L p .54292 .6211 L F P
0 g
s
.526 .532 .804 r
.77072 .4148 m .77696 .41564 L .77341 .42117 L closepath p F P
0 g
s
.472 .484 .788 r
.79108 .41943 m .77696 .41564 L .77341 .42117 L p F P
0 g
s
.472 .484 .788 r
.78431 .42929 m .79108 .41943 L p .77341 .42117 L F P
0 g
s
.555 .93 .81 r
.63539 .43362 m .63103 .43619 L .62652 .43738 L p F P
0 g
s
.688 .149 0 r
.31796 .55481 m .31304 .54961 L .32055 .55477 L p F P
0 g
s
.688 .149 0 r
.32055 .55477 m .32396 .55828 L .31796 .55481 L p F P
0 g
s
.378 .288 .626 r
.78514 .46112 m .7857 .46049 L .78612 .46276 L closepath p F P
0 g
s
.355 0 0 r
.36026 .58224 m .36927 .58679 L .35957 .58142 L p F P
0 g
s
.355 0 0 r
.35298 .5781 m .36026 .58224 L p .35957 .58142 L F P
0 g
s
.355 0 0 r
.35957 .58142 m .35747 .58034 L .35298 .5781 L p F P
0 g
s
0 .339 .685 r
.38736 .59478 m .38235 .59259 L .37873 .59115 L closepath p F P
0 g
s
0 0 0 r
.54292 .6211 m .54384 .62103 L .56565 .61934 L p F P
0 g
s
.093 .65 .75 r
.54292 .6211 m .54384 .62103 L .54273 .62111 L closepath p F P
0 g
s
.016 0 .093 r
.75838 .52782 m .75832 .52802 L .75863 .52761 L closepath p F P
0 g
s
.196 .716 .87 r
.54273 .62111 m .53784 .62038 L .52004 .62139 L closepath p F P
0 g
s
.236 .736 .903 r
.53316 .61964 m .53784 .62038 L .52004 .62139 L p F P
0 g
s
.236 .736 .903 r
.53116 .61963 m .53316 .61964 L p .52004 .62139 L F P
0 g
s
.236 .736 .903 r
.51362 .62042 m .53116 .61963 L p .52004 .62139 L F P
0 g
s
.236 .736 .903 r
.52004 .62139 m .51845 .62139 L .51362 .62042 L p F P
0 g
s
.156 .683 .868 r
.51845 .62139 m .51362 .62042 L .50038 .62045 L closepath p F P
0 g
s
.504 .657 .928 r
.35207 .39682 m .34473 .39696 L .35047 .40337 L p F P
0 g
s
.504 .657 .928 r
.35047 .40337 m .35705 .40335 L .35207 .39682 L p F P
0 g
s
.032 0 .107 r
.76321 .52775 m .77152 .5163 L .75863 .52761 L p F P
0 g
s
.032 0 .107 r
.75676 .53339 m .76321 .52775 L p .75863 .52761 L F P
0 g
s
.032 0 .107 r
.75863 .52761 m .75832 .52802 L .75676 .53339 L p F P
0 g
s
.855 .776 .773 r
.27195 .43398 m .2672 .42739 L .27587 .41618 L p F P
0 g
s
.887 .778 .735 r
.2672 .42739 m .27195 .43398 L .26569 .44432 L p F P
0 g
s
.079 0 .125 r
.75832 .52802 m .7488 .53948 L .75676 .53339 L closepath p F P
0 g
s
.277 .769 .903 r
.54384 .62103 m .54273 .62111 L .53784 .62038 L p F P
0 g
s
.006 0 0 r
.72046 .56406 m .71539 .56756 L .71984 .56502 L closepath p F P
0 g
s
0 0 0 r
.71656 .56817 m .71984 .56502 L .71539 .56756 L p F P
0 g
s
0 0 0 r
.71411 .56973 m .71656 .56817 L p .71539 .56756 L F P
0 g
s
0 0 0 r
.69937 .57819 m .71411 .56973 L p .71539 .56756 L F P
0 g
s
.245 .753 .876 r
.56565 .61934 m .56206 .61895 L .54384 .62103 L closepath p F P
0 g
s
.277 .769 .903 r
.55705 .61837 m .56206 .61895 L .54384 .62103 L p F P
0 g
s
.277 .769 .903 r
.53784 .62038 m .55705 .61837 L p .54384 .62103 L F P
0 g
s
.677 .709 .872 r
.71723 .39992 m .73694 .39274 L .74142 .3996 L p F P
0 g
s
.697 .737 .882 r
.73694 .39274 m .71723 .39992 L .71279 .39475 L p F P
0 g
s
.727 .786 .899 r
.69331 .40448 m .71279 .39475 L .71723 .39992 L p F P
0 g
s
.311 .242 .616 r
.79675 .45851 m .79298 .4511 L .7857 .46049 L p F P
0 g
s
.311 .242 .616 r
.78893 .4685 m .79675 .45851 L p .7857 .46049 L F P
0 g
s
.311 .242 .616 r
.7857 .46049 m .78612 .46276 L .78893 .4685 L p F P
0 g
s
.239 .086 .462 r
.78871 .4869 m .77996 .49611 L .78075 .48717 L p F P
0 g
s
.239 .086 .462 r
.78075 .48717 m .78842 .47906 L .78871 .4869 L p F P
0 g
s
.674 .972 .91 r
.65024 .42484 m .63539 .43362 L .64755 .42479 L closepath p F P
0 g
s
.555 .93 .81 r
.64575 .42473 m .64755 .42479 L .63539 .43362 L p F P
0 g
s
.555 .93 .81 r
.62669 .43724 m .64575 .42473 L p .63539 .43362 L F P
0 g
s
.555 .93 .81 r
.62652 .43738 m .62669 .43724 L p .63539 .43362 L F P
0 g
s
0 0 0 r
.60529 .44975 m .60722 .44822 L .58799 .4563 L p F P
0 g
s
0 0 0 r
.58799 .4563 m .58681 .45734 L .60529 .44975 L p F P
0 g
s
.937 .744 .616 r
.26162 .45388 m .26683 .46022 L .26439 .46922 L p F P
0 g
s
0 .504 .769 r
.45304 .61388 m .44133 .61178 L .43578 .61004 L p F P
0 g
s
.275 0 0 r
.41183 .60378 m .41186 .60378 L .42354 .60733 L p F P
0 g
s
0 .502 .791 r
.42749 .60746 m .41186 .60378 L .42354 .60733 L p F P
0 g
s
0 .502 .791 r
.43254 .60893 m .42749 .60746 L p .42354 .60733 L F P
0 g
s
0 .502 .791 r
.42354 .60733 m .43578 .61004 L .43254 .60893 L p F P
0 g
s
.917 .532 .261 r
.29077 .52492 m .28992 .5222 L .28384 .51787 L p F P
0 g
s
0 0 0 r
.73534 .55251 m .72046 .56406 L .71984 .56502 L p F P
0 g
s
.394 0 0 r
.35747 .58034 m .35298 .5781 L .35074 .57682 L closepath p F P
0 g
s
.202 .706 .906 r
.50838 .6193 m .51362 .62042 L .50038 .62045 L p F P
0 g
s
.202 .706 .906 r
.48944 .6191 m .50838 .6193 L p .50038 .62045 L F P
0 g
s
.202 .706 .906 r
.50038 .62045 m .49248 .61989 L .48944 .6191 L p F P
0 g
s
.62 .632 .841 r
.76368 .39997 m .75979 .40531 L p .74142 .3996 L F P
0 g
s
.62 .632 .841 r
.74142 .3996 m .76149 .39577 L .76368 .39997 L p F P
0 g
s
.639 .659 .853 r
.76149 .39577 m .74142 .3996 L .73694 .39274 L p F P
0 g
s
0 .217 .62 r
.4408 .44682 m .45027 .4515 L .44123 .44641 L p F P
0 g
s
0 .217 .62 r
.44123 .44641 m .43288 .44154 L .43274 .44146 L p F P
0 g
s
0 .217 .62 r
.43274 .44146 m .4408 .44682 L p .44123 .44641 L F P
0 g
s
.344 .258 .613 r
.78612 .46276 m .78893 .4685 L .78745 .4703 L closepath p F P
0 g
s
.507 0 0 r
.46954 .46107 m .48211 .46461 L .47254 .45959 L p F P
0 g
s
.507 0 0 r
.46209 .45602 m .46954 .46107 L p .47254 .45959 L F P
0 g
s
.507 0 0 r
.47254 .45959 m .46283 .45614 L .46209 .45602 L p F P
0 g
s
.541 .554 .817 r
.77696 .41564 m .77072 .4148 L .76607 .40472 L p F P
0 g
s
.127 .656 .872 r
.49248 .61989 m .48944 .6191 L .48297 .61879 L closepath p F P
0 g
s
0 0 0 r
.75505 .53696 m .75676 .53339 L .7488 .53948 L p F P
0 g
s
0 0 0 r
.75203 .54012 m .75505 .53696 L p .7488 .53948 L F P
0 g
s
0 0 0 r
.73896 .5501 m .75203 .54012 L p .7488 .53948 L F P
0 g
s
0 0 0 r
.7488 .53948 m .73958 .54868 L .73896 .5501 L p F P
0 g
s
.71 .175 0 r
.32396 .55828 m .3267 .56114 L .33467 .5661 L p F P
0 g
s
.55 0 0 r
.33429 .5671 m .34232 .57205 L .33467 .5661 L p F P
0 g
s
.55 0 0 r
.33467 .5661 m .3267 .56114 L .33429 .5671 L p F P
0 g
s
.59 .609 .839 r
.75979 .40531 m .76368 .39997 L .76607 .40472 L closepath p F P
0 g
s
.75 .867 .933 r
.69331 .40448 m .69183 .40529 L .69283 .40411 L closepath p F P
0 g
s
.738 .917 .953 r
.68887 .40102 m .69283 .40411 L .69183 .40529 L p F P
0 g
s
.738 .917 .953 r
.66951 .41283 m .68887 .40102 L p .69183 .40529 L F P
0 g
s
.05 0 .01 r
.73958 .54868 m .73534 .55251 L .73896 .5501 L closepath p F P
0 g
s
0 0 0 r
.73605 .55425 m .73896 .5501 L .73534 .55251 L p F P
0 g
s
0 0 0 r
.71984 .56502 m .73605 .55425 L p .73534 .55251 L F P
0 g
s
0 .404 .841 r
.41629 .43105 m .42396 .43645 L .41351 .43196 L p F P
0 g
s
0 .404 .841 r
.41351 .43196 m .40643 .42637 L .41629 .43105 L p F P
0 g
s
0 .387 .827 r
.40348 .42491 m .40643 .42637 L .41351 .43196 L p F P
0 g
s
.325 .803 .905 r
.57692 .61779 m .56565 .61934 L .56206 .61895 L p F P
0 g
s
.753 .867 .932 r
.70835 .39008 m .71279 .39475 L .69331 .40448 L p F P
0 g
s
.753 .867 .932 r
.70071 .39441 m .70835 .39008 L p .69331 .40448 L F P
0 g
s
.753 .867 .932 r
.69331 .40448 m .69283 .40411 L .70071 .39441 L p F P
0 g
s
.374 .84 .825 r
.63483 .60569 m .63441 .60574 L .65337 .59931 L closepath p F P
0 g
s
.57 .024 0 r
.4915 .46509 m .49652 .46749 L .48857 .46595 L closepath p F P
0 g
s
.921 .533 .235 r
.2778 .51251 m .27579 .50597 L .28195 .51178 L p F P
0 g
s
.921 .533 .235 r
.28195 .51178 m .28384 .51787 L .2778 .51251 L p F P
0 g
s
0 .519 .731 r
.46533 .61635 m .46722 .61659 L .48297 .61879 L p F P
0 g
s
.144 .664 .886 r
.48409 .6176 m .46722 .61659 L .48297 .61879 L p F P
0 g
s
.144 .664 .886 r
.48297 .61879 m .48944 .6191 L .48409 .6176 L p F P
0 g
s
.396 .347 .686 r
.79851 .44361 m .79298 .4511 L .78666 .44459 L p F P
0 g
s
.396 .347 .686 r
.79706 .43768 m .79851 .44361 L p .78666 .44459 L F P
0 g
s
.396 .347 .686 r
.78666 .44459 m .7939 .43467 L .79706 .43768 L p F P
0 g
s
.949 .667 .469 r
.27463 .49813 m .26878 .49215 L .26876 .48395 L p F P
0 g
s
.948 .615 .359 r
.26878 .49215 m .27463 .49813 L .27579 .50597 L p F P
0 g
s
.917 .532 .261 r
.28384 .51787 m .28427 .51927 L .29077 .52492 L p F P
0 g
s
.868 .422 .081 r
.2878 .5264 m .29431 .53204 L .29077 .52492 L p F P
0 g
s
.868 .422 .081 r
.29077 .52492 m .28427 .51927 L .2878 .5264 L p F P
0 g
s
0 0 0 r
.73592 .55437 m .73605 .55425 L .71984 .56502 L p F P
0 g
s
0 0 0 r
.71984 .56502 m .71656 .56817 L .73592 .55437 L p F P
0 g
s
.887 .778 .735 r
.26569 .44432 m .26095 .43773 L .2672 .42739 L p F P
0 g
s
.919 .777 .687 r
.2636 .44889 m .26569 .44432 L .26095 .43773 L p F P
0 g
s
.751 .865 .931 r
.69283 .40411 m .68887 .40102 L .70071 .39441 L closepath p F P
0 g
s
0 0 0 r
.69937 .57819 m .69712 .57955 L .71411 .56973 L closepath p F P
0 g
s
.694 .977 .908 r
.66701 .4144 m .65024 .42484 L .64755 .42479 L p F P
0 g
s
.374 .84 .825 r
.65337 .59931 m .63441 .60574 L .62981 .60634 L p F P
0 g
s
0 0 0 r
.60257 .45186 m .60529 .44975 L .58681 .45734 L p F P
0 g
s
0 0 0 r
.58681 .45734 m .58324 .46041 L .60257 .45186 L p F P
0 g
s
.302 .574 .935 r
.37419 .4094 m .38086 .41103 L .38679 .41712 L p F P
0 g
s
.333 .593 .941 r
.39223 .41343 m .38086 .41103 L .38679 .41712 L p F P
0 g
s
.333 .593 .941 r
.38679 .41712 m .39786 .41942 L .39223 .41343 L p F P
0 g
s
0 0 0 r
.67768 .58944 m .67369 .59116 L .67744 .5896 L closepath p F P
0 g
s
.294 .775 .683 r
.67337 .591 m .67744 .5896 L .67369 .59116 L p F P
0 g
s
.294 .775 .683 r
.65386 .59914 m .67337 .591 L p .67369 .59116 L F P
0 g
s
.947 .711 .549 r
.26876 .48395 m .26323 .4778 L .26439 .46922 L p F P
0 g
s
.958 .676 .459 r
.26323 .4778 m .26876 .48395 L .26878 .49215 L p F P
0 g
s
0 .36 .719 r
.37655 .58981 m .36927 .58679 L .37873 .59115 L p F P
0 g
s
0 .36 .719 r
.37873 .59115 m .38235 .59259 L .37655 .58981 L p F P
0 g
s
.792 .298 0 r
.299 .53883 m .30586 .5443 L .30114 .53752 L p F P
0 g
s
.792 .298 0 r
.30114 .53752 m .29431 .53204 L .299 .53883 L p F P
0 g
s
.701 .166 0 r
.3267 .56114 m .32396 .55828 L .31796 .55481 L p F P
0 g
s
.302 .792 .886 r
.58747 .61628 m .58626 .61619 L .57692 .61779 L closepath p F P
0 g
s
.325 .803 .905 r
.58137 .61575 m .58626 .61619 L .57692 .61779 L p F P
0 g
s
.325 .803 .905 r
.56206 .61895 m .58137 .61575 L p .57692 .61779 L F P
0 g
s
.527 .662 .922 r
.36852 .40304 m .35705 .40335 L .35207 .39682 L p F P
0 g
s
.515 .667 .931 r
.35705 .40335 m .36852 .40304 L .37419 .4094 L p F P
0 g
s
.274 .164 .542 r
.7904 .4767 m .78842 .47906 L .78745 .4703 L p F P
0 g
s
.274 .164 .542 r
.78745 .4703 m .78893 .4685 L .7904 .4767 L p F P
0 g
s
0 .552 .783 r
.46533 .61635 m .46722 .61659 L .46426 .61611 L closepath p F P
0 g
s
.634 .704 .897 r
.33316 .38373 m .31489 .38904 L .32076 .39528 L p F P
0 g
s
.634 .704 .897 r
.32076 .39528 m .33896 .3904 L .33316 .38373 L p F P
0 g
s
.808 .785 .832 r
.27756 .41429 m .29143 .40243 L .28704 .39559 L p F P
0 g
s
.808 .785 .832 r
.28704 .39559 m .27145 .40933 L .27756 .41429 L p F P
0 g
s
.839 .781 .795 r
.27137 .40941 m .27145 .40933 L .27756 .41429 L p F P
0 g
s
.839 .781 .795 r
.27756 .41429 m .27587 .41618 L .27137 .40941 L p F P
0 g
s
.86 .784 .774 r
.27137 .40941 m .27587 .41618 L .2672 .42739 L p F P
0 g
s
.234 0 0 r
.41183 .60378 m .41186 .60378 L .4118 .60377 L closepath p F P
0 g
s
.321 .571 .929 r
.37548 .40468 m .36852 .40304 L .37419 .4094 L p F P
0 g
s
.321 .571 .929 r
.37419 .4094 m .38086 .41103 L .37548 .40468 L p F P
0 g
s
.005 .535 .848 r
.41608 .60376 m .42749 .60746 L .41186 .60378 L p F P
0 g
s
.005 .535 .848 r
.40615 .6013 m .41608 .60376 L p .41186 .60378 L F P
0 g
s
.005 .535 .848 r
.41186 .60378 m .4118 .60377 L .40615 .6013 L p F P
0 g
s
0 .491 .814 r
.4118 .60377 m .40615 .6013 L .40103 .59993 L closepath p F P
0 g
s
0 0 0 r
.73662 .55382 m .73605 .55425 L .73896 .5501 L p F P
0 g
s
0 0 0 r
.73896 .5501 m .75203 .54012 L .73662 .55382 L p F P
0 g
s
.423 0 0 r
.53615 .46948 m .51637 .46959 L .51562 .47002 L p F P
0 g
s
.52 0 0 r
.51637 .46959 m .51562 .47002 L .51367 .4694 L closepath p F P
0 g
s
.361 0 0 r
.34708 .57484 m .34232 .57205 L .35074 .57682 L p F P
0 g
s
.361 0 0 r
.35074 .57682 m .35298 .5781 L .34708 .57484 L p F P
0 g
s
.425 0 0 r
.46283 .45614 m .46209 .45602 L .46121 .45563 L closepath p F P
0 g
s
.459 .438 .748 r
.79562 .43218 m .7939 .43467 L .78431 .42929 L p F P
0 g
s
.459 .438 .748 r
.79172 .41972 m .79562 .43218 L p .78431 .42929 L F P
0 g
s
.459 .438 .748 r
.78431 .42929 m .79108 .41943 L .79172 .41972 L p F P
0 g
s
0 0 0 r
.69712 .57955 m .67768 .58944 L p .68641 .58513 L F P
0 g
s
0 0 0 r
.67768 .58944 m .67744 .5896 L .69497 .5809 L p F P
0 g
s
.402 .845 .736 r
.67337 .591 m .69293 .58152 L p .67773 .58945 L F P
0 g
s
.402 .845 .736 r
.67744 .5896 m .6774 .58962 L p .67773 .58945 L F P
0 g
s
.402 .845 .736 r
.6774 .58962 m .67337 .591 L p .67773 .58945 L F P
0 g
s
0 0 0 r
.69497 .5809 m .69524 .58073 L p .68641 .58513 L F P
0 g
s
0 0 0 r
.69524 .58073 m .69712 .57955 L p .68641 .58513 L F P
0 g
s
.455 0 0 r
.54074 .46934 m .53981 .47005 L .53615 .46948 L closepath p F P
0 g
s
.423 0 0 r
.53689 .4732 m .53981 .47005 L .53615 .46948 L p F P
0 g
s
.423 0 0 r
.52693 .47329 m .53689 .4732 L p .53615 .46948 L F P
0 g
s
.423 0 0 r
.51562 .47002 m .52693 .47329 L p .53615 .46948 L F P
0 g
s
.779 .767 .842 r
.29644 .39865 m .29143 .40243 L .28704 .39559 L p F P
0 g
s
.538 .041 .024 r
.50682 .47236 m .49652 .46749 L .51367 .4694 L p F P
0 g
s
.538 .041 .024 r
.51186 .47287 m .50682 .47236 L p .51367 .4694 L F P
0 g
s
.538 .041 .024 r
.51367 .4694 m .51562 .47002 L .51186 .47287 L p F P
0 g
s
.919 .777 .687 r
.26095 .43773 m .25726 .44598 L .2636 .44889 L p F P
0 g
s
.924 .767 .668 r
.25671 .44737 m .25726 .44598 L .2636 .44889 L p F P
0 g
s
.924 .767 .668 r
.2636 .44889 m .26162 .45388 L .25671 .44737 L p F P
0 g
s
.26 0 0 r
.58293 .4608 m .58324 .46041 L .56397 .465 L p F P
0 g
s
.26 0 0 r
.56397 .465 m .5628 .4663 L .58293 .4608 L p F P
0 g
s
.367 0 0 r
.55918 .47029 m .5628 .4663 L .54074 .46934 L p F P
0 g
s
.367 0 0 r
.55823 .47041 m .55918 .47029 L p .54074 .46934 L F P
0 g
s
.367 0 0 r
.54074 .46934 m .53981 .47005 L .55823 .47041 L p F P
0 g
s
.541 .554 .817 r
.76607 .40472 m .783 .40593 L .77696 .41564 L p F P
0 g
s
.53 .577 .847 r
.76368 .39997 m .76607 .40472 L .783 .40593 L p F P
0 g
s
.132 0 .339 r
.787 .49527 m .77696 .5058 L .77996 .49611 L p F P
0 g
s
.132 0 .339 r
.78851 .49019 m .787 .49527 L p .77996 .49611 L F P
0 g
s
.132 0 .339 r
.77996 .49611 m .78871 .4869 L .78851 .49019 L p F P
0 g
s
0 .384 .836 r
.40643 .42637 m .40348 .42491 L .39786 .41942 L p F P
0 g
s
.512 .516 .797 r
.79143 .41888 m .79108 .41943 L .77696 .41564 L p F P
0 g
s
.512 .516 .797 r
.78681 .40663 m .79143 .41888 L p .77696 .41564 L F P
0 g
s
.512 .516 .797 r
.77696 .41564 m .783 .40593 L .78681 .40663 L p F P
0 g
s
.937 .744 .616 r
.26439 .46922 m .25917 .46289 L .26162 .45388 L p F P
0 g
s
.956 .722 .543 r
.25917 .46289 m .26439 .46922 L .26323 .4778 L p F P
0 g
s
.676 .14 0 r
.31184 .55072 m .30586 .5443 L .31304 .54961 L p F P
0 g
s
.676 .14 0 r
.31244 .55116 m .31184 .55072 L p .31304 .54961 L F P
0 g
s
.676 .14 0 r
.31304 .54961 m .31796 .55481 L .31244 .55116 L p F P
0 g
s
.183 .678 .919 r
.48068 .61657 m .48409 .6176 L .46722 .61659 L p F P
0 g
s
.183 .678 .919 r
.47503 .61569 m .48068 .61657 L p .46722 .61659 L F P
0 g
s
.183 .678 .919 r
.45988 .61459 m .47503 .61569 L p .46722 .61659 L F P
0 g
s
.183 .678 .919 r
.46722 .61659 m .46426 .61611 L .45988 .61459 L p F P
0 g
s
.411 0 0 r
.45659 .45491 m .45027 .4515 L .46121 .45563 L p F P
0 g
s
.411 0 0 r
.46121 .45563 m .46209 .45602 L .45659 .45491 L p F P
0 g
s
.719 .742 .87 r
.30898 .3828 m .29044 .39295 L .29644 .39865 L p F P
0 g
s
.719 .742 .87 r
.29644 .39865 m .31489 .38904 L .30898 .3828 L p F P
0 g
s
.779 .767 .842 r
.28704 .39559 m .29044 .39295 L .29644 .39865 L p F P
0 g
s
.402 .845 .736 r
.69293 .58152 m .69497 .5809 L .67744 .5896 L p F P
0 g
s
.373 .833 .909 r
.60564 .61181 m .6083 .612 L .58747 .61628 L p F P
0 g
s
.373 .833 .909 r
.58747 .61628 m .58626 .61619 L .60564 .61181 L p F P
0 g
s
.114 .632 .888 r
.46426 .61611 m .45988 .61459 L .45304 .61388 L closepath p F P
0 g
s
.256 .152 .539 r
.79825 .46672 m .7904 .4767 L .78893 .4685 L p F P
0 g
s
.256 .152 .539 r
.78893 .4685 m .79675 .45851 L .79825 .46672 L p F P
0 g
s
0 .45 .822 r
.43288 .44154 m .43274 .44146 L .43265 .44143 L closepath p F P
0 g
s
.515 .655 .922 r
.34763 .39004 m .33896 .3904 L .34473 .39696 L p F P
0 g
s
.515 .655 .922 r
.34473 .39696 m .35207 .39682 L .34763 .39004 L p F P
0 g
s
.686 .153 0 r
.46954 .46107 m .46209 .45602 L .45659 .45491 L p F P
0 g
s
.295 .792 .798 r
.62825 .60655 m .62981 .60634 L .61038 .61173 L p F P
0 g
s
.295 .792 .798 r
.61038 .61173 m .6083 .612 L .62825 .60655 L p F P
0 g
s
.497 0 0 r
.42717 .43774 m .42158 .4334 L p .42425 .43544 L F P
0 g
s
0 .473 .857 r
.42973 .43975 m .43265 .44143 L p .42717 .43774 L F P
0 g
s
0 .473 .857 r
.43265 .44143 m .43274 .44146 L .42717 .43774 L p F P
0 g
s
.523 0 0 r
.4408 .44682 m .43274 .44146 L .42717 .43774 L p F P
0 g
s
.523 0 0 r
.42717 .43774 m .43246 .4417 L .4408 .44682 L p F P
0 g
s
.497 0 0 r
.43246 .4417 m .42717 .43774 L p .42425 .43544 L F P
0 g
s
0 .473 .857 r
.42717 .43774 m .42396 .43645 L .42973 .43975 L p F P
0 g
s
.05 0 .218 r
.77426 .5085 m .77361 .51246 L .77696 .5058 L closepath p F P
0 g
s
.757 .952 .939 r
.66951 .41283 m .66701 .4144 L .66886 .41261 L closepath p F P
0 g
s
.694 .977 .908 r
.66505 .4113 m .66886 .41261 L .66701 .4144 L p F P
0 g
s
.694 .977 .908 r
.65273 .4199 m .66505 .4113 L p .66701 .4144 L F P
0 g
s
.694 .977 .908 r
.64755 .42479 m .65273 .4199 L p .66701 .4144 L F P
0 g
s
.525 .026 .013 r
.51562 .47002 m .52693 .47329 L .51186 .47287 L closepath p F P
0 g
s
.152 .675 .879 r
.50838 .6193 m .48944 .6191 L .48409 .6176 L p F P
0 g
s
0 .346 .7 r
.39074 .59586 m .38235 .59259 L .37655 .58981 L p F P
0 g
s
.781 .954 .928 r
.68441 .39808 m .68887 .40102 L .66951 .41283 L p F P
0 g
s
.781 .954 .928 r
.67718 .40306 m .68441 .39808 L p .66951 .41283 L F P
0 g
s
.781 .954 .928 r
.66951 .41283 m .66886 .41261 L .67718 .40306 L p F P
0 g
s
.893 .788 .737 r
.26277 .42062 m .2672 .42739 L .26095 .43773 L p F P
0 g
s
.86 .784 .774 r
.2672 .42739 m .26277 .42062 L .27137 .40941 L p F P
0 g
s
.639 .659 .853 r
.73694 .39274 m .75697 .38767 L .76149 .39577 L p F P
0 g
s
.659 .686 .865 r
.75697 .38767 m .73694 .39274 L .73249 .38645 L p F P
0 g
s
.697 .737 .882 r
.71279 .39475 m .73249 .38645 L .73694 .39274 L p F P
0 g
s
.386 0 0 r
.36026 .58224 m .35298 .5781 L .34708 .57484 L p F P
0 g
s
.569 .024 0 r
.49109 .46991 m .50682 .47236 L .49652 .46749 L p F P
0 g
s
.569 .024 0 r
.48612 .46666 m .49109 .46991 L p .49652 .46749 L F P
0 g
s
.569 .024 0 r
.49652 .46749 m .48857 .46595 L .48612 .46666 L p F P
0 g
s
.946 .755 .614 r
.25671 .44737 m .26162 .45388 L .25917 .46289 L p F P
0 g
s
.717 .762 .888 r
.73249 .38645 m .71279 .39475 L .70835 .39008 L p F P
0 g
s
.701 .166 0 r
.31796 .55481 m .31909 .55601 L .3267 .56114 L p F P
0 g
s
.521 0 0 r
.32662 .56199 m .33429 .5671 L .3267 .56114 L p F P
0 g
s
.521 0 0 r
.3267 .56114 m .31909 .55601 L .32662 .56199 L p F P
0 g
s
.421 0 .021 r
.53981 .47005 m .55823 .47041 L .53689 .4732 L closepath p F P
0 g
s
.575 .609 .849 r
.76149 .39577 m .76588 .39552 L .76368 .39997 L closepath p F P
0 g
s
.53 .577 .847 r
.78208 .39555 m .76588 .39552 L .76368 .39997 L p F P
0 g
s
.53 .577 .847 r
.7851 .40246 m .78208 .39555 L p .76368 .39997 L F P
0 g
s
.53 .577 .847 r
.783 .40593 m .7851 .40246 L p .76368 .39997 L F P
0 g
s
.922 .534 .238 r
.28427 .51927 m .28384 .51787 L .2778 .51251 L p F P
0 g
s
0 .398 .845 r
.40949 .42529 m .41629 .43105 L .40643 .42637 L p F P
0 g
s
0 .398 .845 r
.40643 .42637 m .39996 .42051 L .40949 .42529 L p F P
0 g
s
0 .384 .836 r
.39786 .41942 m .39996 .42051 L .40643 .42637 L p F P
0 g
s
.361 .827 .902 r
.60564 .61181 m .58626 .61619 L .58137 .61575 L p F P
0 g
s
.189 .708 .877 r
.53116 .61963 m .51362 .62042 L .50838 .6193 L p F P
0 g
s
.78 .951 .929 r
.66886 .41261 m .66505 .4113 L .67718 .40306 L closepath p F P
0 g
s
.273 0 0 r
.57959 .46501 m .58293 .4608 L .5628 .4663 L p F P
0 g
s
.273 0 0 r
.5628 .4663 m .55918 .47029 L .57959 .46501 L p F P
0 g
s
0 0 0 r
.75676 .53339 m .75505 .53696 L .76321 .52775 L closepath p F P
0 g
s
0 .504 .769 r
.43578 .61004 m .43981 .61082 L .45304 .61388 L p F P
0 g
s
.135 .64 .903 r
.45438 .61251 m .43981 .61082 L .45304 .61388 L p F P
0 g
s
.135 .64 .903 r
.45304 .61388 m .45988 .61459 L .45438 .61251 L p F P
0 g
s
.586 .045 0 r
.48857 .46595 m .48612 .46666 L .48211 .46461 L closepath p F P
0 g
s
0 .363 .737 r
.37071 .58673 m .36026 .58224 L .36927 .58679 L p F P
0 g
s
0 .363 .737 r
.36927 .58679 m .37655 .58981 L .37071 .58673 L p F P
0 g
s
.29 .783 .884 r
.58137 .61575 m .56206 .61895 L .55705 .61837 L p F P
0 g
s
.948 .615 .359 r
.27579 .50597 m .26994 .5 L .26878 .49215 L p F P
0 g
s
.924 .534 .208 r
.2778 .51251 m .27579 .50597 L .26994 .5 L p F P
0 g
s
.27 .763 .903 r
.55673 .61833 m .55705 .61837 L .53784 .62038 L p F P
0 g
s
.27 .763 .903 r
.53784 .62038 m .53316 .61964 L .55673 .61833 L p F P
0 g
s
.186 .048 .448 r
.78979 .48561 m .78871 .4869 L .78842 .47906 L p F P
0 g
s
.186 .048 .448 r
.78842 .47906 m .7904 .4767 L .78979 .48561 L p F P
0 g
s
0 .506 .837 r
.40044 .59858 m .39074 .59586 L .40103 .59993 L p F P
0 g
s
0 .506 .837 r
.40103 .59993 m .40615 .6013 L .40044 .59858 L p F P
0 g
s
.922 .534 .238 r
.2778 .51251 m .27809 .51347 L .28427 .51927 L p F P
0 g
s
.863 .415 .044 r
.28161 .52059 m .2878 .5264 L .28427 .51927 L p F P
0 g
s
.863 .415 .044 r
.28427 .51927 m .27809 .51347 L .28161 .52059 L p F P
0 g
s
.062 0 .227 r
.78193 .5057 m .787 .49527 L .77696 .5058 L p F P
0 g
s
.062 0 .227 r
.77325 .51473 m .78193 .5057 L p .77696 .5058 L F P
0 g
s
.062 0 .227 r
.77696 .5058 m .77361 .51246 L .77325 .51473 L p F P
0 g
s
0 .534 .816 r
.43578 .61004 m .43981 .61082 L .43254 .60893 L closepath p F P
0 g
s
.958 .676 .459 r
.26878 .49215 m .26324 .486 L .26323 .4778 L p F P
0 g
s
.955 .621 .341 r
.26324 .486 m .26878 .49215 L .26994 .5 L p F P
0 g
s
0 0 0 r
.71411 .56973 m .69712 .57955 L .69497 .5809 L p F P
0 g
s
.741 .985 .904 r
.64755 .42479 m .64575 .42473 L .65273 .4199 L closepath p F P
0 g
s
.592 .63 .859 r
.76588 .39552 m .76149 .39577 L .75697 .38767 L p F P
0 g
s
.469 0 0 r
.44918 .45221 m .4408 .44682 L .45027 .4515 L p F P
0 g
s
.469 0 0 r
.45325 .45398 m .44918 .45221 L p .45027 .4515 L F P
0 g
s
.469 0 0 r
.45027 .4515 m .45659 .45491 L .45325 .45398 L p F P
0 g
s
0 0 0 r
.65386 .59914 m .65337 .59931 L .65385 .59914 L closepath p F P
0 g
s
.374 .84 .825 r
.64935 .59967 m .65385 .59914 L .65337 .59931 L p F P
0 g
s
.374 .84 .825 r
.62981 .60634 m .64935 .59967 L p .65337 .59931 L F P
0 g
s
.778 .284 0 r
.29247 .53319 m .299 .53883 L .29431 .53204 L p F P
0 g
s
.778 .284 0 r
.29431 .53204 m .2878 .5264 L .29247 .53319 L p F P
0 g
s
.356 .587 .931 r
.39223 .41343 m .38086 .41103 L .37548 .40468 L p F P
0 g
s
.299 .777 .681 r
.6721 .59144 m .67337 .591 L .65386 .59914 L p F P
0 g
s
.455 .886 .851 r
.66896 .59173 m .6721 .59144 L .65385 .59914 L p F P
0 g
s
.455 .886 .851 r
.65385 .59914 m .64935 .59967 L .66896 .59173 L p F P
0 g
s
.893 .788 .737 r
.26095 .43773 m .25652 .43097 L .26277 .42062 L p F P
0 g
s
.925 .786 .688 r
.25652 .43097 m .26095 .43773 L .25726 .44598 L p F P
0 g
s
.59 .054 0 r
.47782 .46659 m .46954 .46107 L .48211 .46461 L p F P
0 g
s
.59 .054 0 r
.48266 .4678 m .47782 .46659 L p .48211 .46461 L F P
0 g
s
.59 .054 0 r
.48211 .46461 m .48612 .46666 L .48266 .4678 L p F P
0 g
s
.322 .249 .617 r
.80039 .4536 m .79675 .45851 L .79298 .4511 L p F P
0 g
s
.322 .249 .617 r
.79298 .4511 m .79851 .44361 L .80039 .4536 L p F P
0 g
s
0 .217 .628 r
.34115 .57121 m .33429 .5671 L .34232 .57205 L p F P
0 g
s
0 .217 .628 r
.34232 .57205 m .34708 .57484 L .34115 .57121 L p F P
0 g
s
.956 .722 .543 r
.26323 .4778 m .25799 .47148 L .25917 .46289 L p F P
0 g
s
.966 .685 .448 r
.25799 .47148 m .26323 .4778 L .26324 .486 L p F P
0 g
s
.623 .958 .828 r
.62652 .43738 m .62647 .43739 L .62669 .43724 L closepath p F P
0 g
s
.749 .89 .942 r
.70071 .39441 m .68887 .40102 L .68441 .39808 L p F P
0 g
s
.463 .859 .671 r
.62669 .43724 m .62647 .43739 L .62205 .43974 L p F P
0 g
s
.646 .968 .847 r
.64575 .42473 m .62669 .43724 L .64194 .42542 L closepath p F P
0 g
s
.463 .859 .671 r
.64123 .42554 m .64194 .42542 L .62669 .43724 L p F P
0 g
s
.463 .859 .671 r
.62261 .4393 m .64123 .42554 L p .62669 .43724 L F P
0 g
s
.463 .859 .671 r
.62205 .43974 m .62261 .4393 L p .62669 .43724 L F P
0 g
s
.642 .705 .893 r
.32732 .37696 m .30898 .3828 L .31489 .38904 L p F P
0 g
s
.642 .705 .893 r
.31489 .38904 m .33316 .38373 L .32732 .37696 L p F P
0 g
s
.432 .867 .919 r
.62515 .60632 m .62825 .60655 L .6083 .612 L p F P
0 g
s
.432 .867 .919 r
.6083 .612 m .60564 .61181 L .62515 .60632 L p F P
0 g
s
.541 .66 .913 r
.36282 .39638 m .35207 .39682 L .34763 .39004 L p F P
0 g
s
.527 .662 .922 r
.35207 .39682 m .36282 .39638 L .36852 .40304 L p F P
0 g
s
.344 .568 .922 r
.37067 .39807 m .36282 .39638 L .36852 .40304 L p F P
0 g
s
.344 .568 .922 r
.36852 .40304 m .37548 .40468 L .37067 .39807 L p F P
0 g
s
.656 .127 0 r
.30495 .54525 m .31184 .55072 L .30586 .5443 L p F P
0 g
s
.656 .127 0 r
.30586 .5443 m .299 .53883 L .30495 .54525 L p F P
0 g
s
.1 0 .24 r
.77361 .51246 m .77152 .5163 L .77325 .51473 L closepath p F P
0 g
s
0 .447 .857 r
.42158 .4334 m .41629 .43105 L .42396 .43645 L p F P
0 g
s
0 .07 .548 r
.42158 .4334 m .41596 .42834 L p .41896 .43094 L F P
0 g
s
.497 0 0 r
.42158 .4334 m .42502 .43621 L .43246 .4417 L p F P
0 g
s
0 .07 .548 r
.42502 .43621 m .42158 .4334 L p .41896 .43094 L F P
0 g
s
0 .447 .857 r
.42396 .43645 m .42546 .43705 L p .42158 .4334 L F P
0 g
s
0 .447 .857 r
.42546 .43705 m .42717 .43774 L .42158 .4334 L p F P
0 g
s
.805 .779 .828 r
.27145 .40933 m .27121 .40915 L p .28292 .38859 L F P
0 g
s
.805 .779 .828 r
.28292 .38859 m .28704 .39559 L .27145 .40933 L p F P
0 g
s
.846 .789 .796 r
.27145 .40933 m .27137 .40941 L .27121 .40915 L closepath p F P
0 g
s
.159 .027 .439 r
.79768 .47566 m .78979 .48561 L .7904 .4767 L p F P
0 g
s
.159 .027 .439 r
.7904 .4767 m .79825 .46672 L .79768 .47566 L p F P
0 g
s
.866 .792 .776 r
.27121 .40915 m .27137 .40941 L .26277 .42062 L p F P
0 g
s
.679 .144 0 r
.31796 .55481 m .31909 .55601 L .31244 .55116 L closepath p F P
0 g
s
.805 .779 .828 r
.27121 .40915 m .2677 .40227 L .28292 .38859 L p F P
0 g
s
.84 .798 .81 r
.2677 .40227 m .27121 .40915 L .26523 .40489 L closepath p F P
0 g
s
.866 .792 .776 r
.25864 .41367 m .26523 .40489 L .27121 .40915 L p F P
0 g
s
.866 .792 .776 r
.26277 .42062 m .25864 .41367 L p .27121 .40915 L F P
0 g
s
.946 .755 .614 r
.25917 .46289 m .25425 .45639 L .25671 .44737 L p F P
0 g
s
.965 .733 .537 r
.25425 .45639 m .25917 .46289 L .25799 .47148 L p F P
0 g
s
.784 .772 .842 r
.29044 .39295 m .28704 .39559 L .28292 .38859 L p F P
0 g
s
.004 .393 .848 r
.39996 .42051 m .39786 .41942 L .39223 .41343 L p F P
0 g
s
.592 .63 .859 r
.75697 .38767 m .77037 .38619 L .76588 .39552 L p F P
0 g
s
.559 .579 .831 r
.77743 .38573 m .77037 .38619 L .76588 .39552 L p F P
0 g
s
.559 .579 .831 r
.76588 .39552 m .78208 .39555 L .77743 .38573 L p F P
0 g
s
.176 .652 .931 r
.45027 .61084 m .45438 .61251 L .43981 .61082 L p F P
0 g
s
.176 .652 .931 r
.44696 .61001 m .45027 .61084 L p .43981 .61082 L F P
0 g
s
.176 .652 .931 r
.43018 .60787 m .44696 .61001 L p .43981 .61082 L F P
0 g
s
.176 .652 .931 r
.43981 .61082 m .43254 .60893 L .43018 .60787 L p F P
0 g
s
.726 .746 .868 r
.30303 .37662 m .28439 .38741 L .29044 .39295 L p F P
0 g
s
.726 .746 .868 r
.29044 .39295 m .30898 .3828 L .30303 .37662 L p F P
0 g
s
.784 .772 .842 r
.28292 .38859 m .28439 .38741 L .29044 .39295 L p F P
0 g
s
.53 .654 .914 r
.34386 .38294 m .33316 .38373 L .33896 .3904 L p F P
0 g
s
.53 .654 .914 r
.33896 .3904 m .34763 .39004 L .34386 .38294 L p F P
0 g
s
0 0 .05 r
.77157 .52012 m .76321 .52775 L .77152 .5163 L p F P
0 g
s
0 0 .05 r
.77152 .5163 m .77325 .51473 L .77157 .52012 L p F P
0 g
s
.14 .65 .899 r
.47503 .61569 m .45988 .61459 L .45438 .61251 L p F P
0 g
s
0 0 0 r
.71656 .56817 m .71411 .56973 L .71624 .56849 L closepath p F P
0 g
s
0 0 0 r
.7125 .57055 m .71624 .56849 L .71411 .56973 L p F P
0 g
s
0 0 0 r
.70732 .57364 m .7125 .57055 L p .71411 .56973 L F P
0 g
s
0 0 0 r
.69497 .5809 m .70732 .57364 L p .71411 .56973 L F P
0 g
s
0 .504 .829 r
.41608 .60376 m .40615 .6013 L .40044 .59858 L p F P
0 g
s
.446 0 0 r
.31932 .5567 m .32662 .56199 L .31909 .55601 L p F P
0 g
s
.446 0 0 r
.31194 .5508 m .31932 .5567 L p .31909 .55601 L F P
0 g
s
.446 0 0 r
.31909 .55601 m .31244 .55116 L .31194 .5508 L p F P
0 g
s
.753 .834 .914 r
.70835 .39008 m .70071 .39441 L .70484 .38675 L closepath p F P
0 g
s
.749 .89 .942 r
.7039 .38585 m .70484 .38675 L .70071 .39441 L p F P
0 g
s
.749 .89 .942 r
.68441 .39808 m .7039 .38585 L p .70071 .39441 L F P
0 g
s
.132 0 0 r
.60146 .45314 m .60257 .45186 L .58324 .46041 L p F P
0 g
s
.132 0 0 r
.58324 .46041 m .58293 .4608 L .60146 .45314 L p F P
0 g
s
0 0 0 r
.73592 .55437 m .71656 .56817 L p .72973 .55925 L F P
0 g
s
0 0 0 r
.73245 .5574 m .73592 .55437 L p .72973 .55925 L F P
0 g
s
0 0 0 r
.71656 .56817 m .71624 .56849 L .73236 .55747 L p F P
0 g
s
.454 .851 .656 r
.7125 .57055 m .73204 .55762 L p .71984 .56601 L F P
0 g
s
.454 .851 .656 r
.71624 .56849 m .71611 .56855 L p .71984 .56601 L F P
0 g
s
.454 .851 .656 r
.71611 .56855 m .7125 .57055 L p .71984 .56601 L F P
0 g
s
0 0 0 r
.73236 .55747 m .73245 .5574 L p .72973 .55925 L F P
0 g
s
.389 .346 .69 r
.7939 .43467 m .79562 .43218 L .79706 .43768 L closepath p F P
0 g
s
.659 .686 .865 r
.73249 .38645 m .75247 .3802 L .75697 .38767 L p F P
0 g
s
.678 .711 .873 r
.75247 .3802 m .73249 .38645 L .72803 .38064 L p F P
0 g
s
.717 .762 .888 r
.70835 .39008 m .72803 .38064 L .73249 .38645 L p F P
0 g
s
.925 .786 .688 r
.25726 .44598 m .2554 .44546 L p .25652 .43097 L F P
0 g
s
.933 .778 .666 r
.25726 .44598 m .25671 .44737 L .2554 .44546 L closepath p F P
0 g
s
.374 .841 .824 r
.64735 .59991 m .64935 .59967 L .62981 .60634 L p F P
0 g
s
.374 .841 .824 r
.62981 .60634 m .62825 .60655 L .64735 .59991 L p F P
0 g
s
.671 .976 .847 r
.65273 .4199 m .64575 .42473 L .64194 .42542 L p F P
0 g
s
0 .346 .7 r
.37655 .58981 m .38096 .59159 L .39074 .59586 L p F P
0 g
s
0 .505 .849 r
.39468 .5956 m .38096 .59159 L .39074 .59586 L p F P
0 g
s
0 .505 .849 r
.39074 .59586 m .40044 .59858 L .39468 .5956 L p F P
0 g
s
.647 .128 0 r
.48612 .46666 m .49109 .46991 L .48266 .4678 L closepath p F P
0 g
s
.686 .153 0 r
.45659 .45491 m .45889 .45682 L .46954 .46107 L p F P
0 g
s
.688 .155 0 r
.466 .46274 m .47782 .46659 L .46954 .46107 L p F P
0 g
s
.688 .155 0 r
.46954 .46107 m .45889 .45682 L .466 .46274 L p F P
0 g
s
.9 .798 .739 r
.25864 .41367 m .26277 .42062 L .25652 .43097 L p F P
0 g
s
.386 0 0 r
.34708 .57484 m .35167 .57751 L .36026 .58224 L p F P
0 g
s
0 .369 .757 r
.36288 .58244 m .35167 .57751 L .36026 .58224 L p F P
0 g
s
0 .369 .757 r
.36888 .58566 m .36288 .58244 L p .36026 .58224 L F P
0 g
s
0 .369 .757 r
.36026 .58224 m .37071 .58673 L .36888 .58566 L p F P
0 g
s
.021 .404 .855 r
.40347 .4192 m .40949 .42529 L .39996 .42051 L p F P
0 g
s
.021 .404 .855 r
.39996 .42051 m .39405 .41439 L .40347 .4192 L p F P
0 g
s
.004 .393 .848 r
.39223 .41343 m .39405 .41439 L .39996 .42051 L p F P
0 g
s
.954 .767 .611 r
.2554 .44546 m .25671 .44737 L .25425 .45639 L p F P
0 g
s
0 0 .019 r
.77475 .51683 m .77157 .52012 L .77325 .51473 L p F P
0 g
s
0 0 .019 r
.77325 .51473 m .78193 .5057 L .77475 .51683 L p F P
0 g
s
.113 0 0 r
.59802 .4571 m .60146 .45314 L .58293 .4608 L p F P
0 g
s
.113 0 0 r
.58293 .4608 m .57959 .46501 L .59802 .4571 L p F P
0 g
s
.119 .614 .907 r
.43254 .60893 m .43018 .60787 L .42749 .60746 L closepath p F P
0 g
s
.454 .851 .656 r
.73204 .55762 m .73236 .55747 L .71624 .56849 L p F P
0 g
s
0 0 0 r
.77051 .5221 m .77157 .52012 L .76321 .52775 L p F P
0 g
s
0 0 0 r
.76472 .52888 m .77051 .5221 L p .76321 .52775 L F P
0 g
s
0 0 0 r
.75449 .53816 m .76472 .52888 L p .76321 .52775 L F P
0 g
s
0 0 0 r
.76321 .52775 m .75505 .53696 L .75449 .53816 L p F P
0 g
s
.77 .974 .919 r
.66505 .4113 m .65273 .4199 L .66147 .4106 L closepath p F P
0 g
s
.671 .976 .847 r
.66057 .41042 m .66147 .4106 L .65273 .4199 L p F P
0 g
s
.671 .976 .847 r
.64376 .42357 m .66057 .41042 L p .65273 .4199 L F P
0 g
s
.671 .976 .847 r
.64194 .42542 m .64376 .42357 L p .65273 .4199 L F P
0 g
s
.924 .535 .211 r
.27223 .50749 m .2718 .50609 L .2778 .51251 L p F P
0 g
s
.924 .535 .211 r
.2778 .51251 m .27809 .51347 L .27223 .50749 L p F P
0 g
s
.924 .534 .208 r
.26994 .5 m .2718 .50609 L .2778 .51251 L p F P
0 g
s
.511 0 0 r
.4401 .44733 m .44918 .45221 L .4408 .44682 L p F P
0 g
s
.511 0 0 r
.4408 .44682 m .43246 .4417 L .4401 .44733 L p F P
0 g
s
.742 .832 .92 r
.72358 .37524 m .72803 .38064 L .70835 .39008 L p F P
0 g
s
.742 .832 .92 r
.70631 .38457 m .72358 .37524 L p .70835 .39008 L F P
0 g
s
.742 .832 .92 r
.70835 .39008 m .70484 .38675 L .70631 .38457 L p F P
0 g
s
0 .202 .611 r
.35167 .57751 m .34708 .57484 L .34115 .57121 L p F P
0 g
s
0 .357 .728 r
.38096 .59159 m .37655 .58981 L .37071 .58673 L p F P
0 g
s
.611 .632 .848 r
.77037 .38619 m .75697 .38767 L .75247 .3802 L p F P
0 g
s
.07 0 .319 r
.78871 .4869 m .78851 .49019 L .78979 .48561 L closepath p F P
0 g
s
0 0 0 r
.73605 .55425 m .73592 .55437 L .73662 .55382 L closepath p F P
0 g
s
.455 .44 .753 r
.79108 .41943 m .79143 .41888 L .79172 .41972 L closepath p F P
0 g
s
.511 .518 .799 r
.783 .40593 m .7851 .40246 L .78681 .40663 L closepath p F P
0 g
s
.543 .079 .103 r
.53689 .4732 m .53472 .47553 L .52693 .47329 L closepath p F P
0 g
s
.525 .026 .013 r
.53331 .47748 m .53472 .47553 L .52693 .47329 L p F P
0 g
s
.525 .026 .013 r
.51739 .47722 m .53331 .47748 L p .52693 .47329 L F P
0 g
s
.525 .026 .013 r
.51035 .47402 m .51739 .47722 L p .52693 .47329 L F P
0 g
s
.525 .026 .013 r
.52693 .47329 m .51186 .47287 L .51035 .47402 L p F P
0 g
s
.42 0 .02 r
.55823 .47041 m .53689 .4732 L .53472 .47553 L p F P
0 g
s
.152 .675 .879 r
.50799 .61921 m .50838 .6193 L p .48409 .6176 L F P
0 g
s
.152 .675 .879 r
.48409 .6176 m .49138 .61776 L .50799 .61921 L p F P
0 g
s
.198 .696 .915 r
.48409 .6176 m .49138 .61776 L .48068 .61657 L closepath p F P
0 g
s
.492 .897 .778 r
.69497 .5809 m .69293 .58152 L .70732 .57364 L closepath p F P
0 g
s
.955 .621 .341 r
.26994 .5 m .26438 .49386 L .26324 .486 L p F P
0 g
s
.922 .53 .175 r
.2718 .50609 m .26994 .5 L .26438 .49386 L p F P
0 g
s
.854 .406 .005 r
.27223 .50749 m .27809 .51347 L .28161 .52059 L p F P
0 g
s
0 0 0 r
.73662 .55382 m .73592 .55437 L .73236 .55747 L p F P
0 g
s
0 0 0 r
.75149 .54206 m .73662 .55382 L .75203 .54012 L p F P
0 g
s
0 0 0 r
.75144 .5421 m .75149 .54206 L .73662 .55382 L p F P
0 g
s
0 0 0 r
.73358 .55651 m .75144 .5421 L p .73662 .55382 L F P
0 g
s
0 0 0 r
.73236 .55747 m .73358 .55651 L p .73662 .55382 L F P
0 g
s
0 0 0 r
.75505 .53696 m .75203 .54012 L .75449 .53816 L closepath p F P
0 g
s
.598 .112 .073 r
.51186 .47287 m .51035 .47402 L .50682 .47236 L closepath p F P
0 g
s
.406 .392 .731 r
.79172 .41972 m .79969 .42514 L .79562 .43218 L closepath p F P
0 g
s
.381 .394 .748 r
.79143 .41888 m .79172 .41972 L .79969 .42514 L p F P
0 g
s
.402 .844 .731 r
.6896 .58254 m .69293 .58152 L .67337 .591 L p F P
0 g
s
.402 .844 .731 r
.67337 .591 m .6721 .59144 L .6896 .58254 L p F P
0 g
s
.457 .465 .779 r
.78681 .40663 m .79596 .41011 L .79143 .41888 L closepath p F P
0 g
s
.381 .394 .748 r
.80477 .41577 m .79596 .41011 L .79143 .41888 L p F P
0 g
s
.381 .394 .748 r
.79969 .42514 m .80477 .41577 L p .79143 .41888 L F P
0 g
s
.651 .093 0 r
.45659 .45491 m .45889 .45682 L .45325 .45398 L closepath p F P
0 g
s
0 .229 .656 r
.33519 .56722 m .32662 .56199 L .33429 .5671 L p F P
0 g
s
0 .229 .656 r
.33429 .5671 m .34115 .57121 L .33519 .56722 L p F P
0 g
s
0 0 0 r
.75203 .54012 m .75449 .53816 L .75149 .54206 L p F P
0 g
s
.313 .296 .68 r
.80554 .43184 m .79969 .42514 L .79562 .43218 L p F P
0 g
s
.313 .296 .68 r
.79999 .44127 m .80554 .43184 L p .79562 .43218 L F P
0 g
s
.313 .296 .68 r
.79562 .43218 m .79706 .43768 L .79999 .44127 L p F P
0 g
s
.144 .623 .922 r
.42456 .60514 m .41608 .60376 L .42749 .60746 L p F P
0 g
s
.144 .623 .922 r
.42749 .60746 m .43018 .60787 L .42456 .60514 L p F P
0 g
s
.966 .685 .448 r
.26324 .486 m .25799 .4797 L .25799 .47148 L p F P
0 g
s
.96 .626 .321 r
.25799 .4797 m .26324 .486 L .26438 .49386 L p F P
0 g
s
.429 .865 .918 r
.62515 .60632 m .60564 .61181 L .60083 .61145 L p F P
0 g
s
.361 .827 .902 r
.58137 .61575 m .60083 .61145 L .60564 .61181 L p F P
0 g
s
.759 .267 0 r
.28627 .52739 m .29247 .53319 L .2878 .5264 L p F P
0 g
s
.759 .267 0 r
.2878 .5264 m .28161 .52059 L .28627 .52739 L p F P
0 g
s
.925 .786 .688 r
.2554 .44546 m .25223 .44064 L .25652 .43097 L p F P
0 g
s
.955 .775 .621 r
.25223 .44064 m .2554 .44546 L .25055 .44631 L closepath p F P
0 g
s
.954 .767 .611 r
.24963 .44972 m .25055 .44631 L .2554 .44546 L p F P
0 g
s
.954 .767 .611 r
.25425 .45639 m .24963 .44972 L p .2554 .44546 L F P
0 g
s
.602 .137 .121 r
.49956 .47547 m .49109 .46991 L .50682 .47236 L p F P
0 g
s
.602 .137 .121 r
.50763 .47655 m .49956 .47547 L p .50682 .47236 L F P
0 g
s
.602 .137 .121 r
.50682 .47236 m .51035 .47402 L .50763 .47655 L p F P
0 g
s
.762 .973 .923 r
.67718 .40306 m .66505 .4113 L .66147 .4106 L p F P
0 g
s
.388 .586 .921 r
.38657 .40694 m .37548 .40468 L .37067 .39807 L p F P
0 g
s
.356 .587 .931 r
.37548 .40468 m .38657 .40694 L .39223 .41343 L p F P
0 g
s
.08 0 .324 r
.79515 .48527 m .79768 .47566 L .78979 .48561 L p F P
0 g
s
.08 0 .324 r
.78831 .49384 m .79515 .48527 L p .78979 .48561 L F P
0 g
s
.08 0 .324 r
.78979 .48561 m .78851 .49019 L .78831 .49384 L p F P
0 g
s
.237 .14 .536 r
.80143 .46244 m .79825 .46672 L .79675 .45851 L p F P
0 g
s
.237 .14 .536 r
.79675 .45851 m .80039 .4536 L .80143 .46244 L p F P
0 g
s
.346 .306 .67 r
.79706 .43768 m .79999 .44127 L .79851 .44361 L closepath p F P
0 g
s
.493 .897 .929 r
.64477 .59968 m .64735 .59991 L .62825 .60655 L p F P
0 g
s
.493 .897 .929 r
.62825 .60655 m .62515 .60632 L .64477 .59968 L p F P
0 g
s
.008 .434 .864 r
.41596 .42834 m .40949 .42529 L .41629 .43105 L p F P
0 g
s
.008 .434 .864 r
.41629 .43105 m .42158 .4334 L .41596 .42834 L p F P
0 g
s
.651 .708 .889 r
.32145 .37015 m .30303 .37662 L .30898 .3828 L p F P
0 g
s
.651 .708 .889 r
.30898 .3828 m .32732 .37696 L .32145 .37015 L p F P
0 g
s
.965 .733 .537 r
.25799 .47148 m .25306 .465 L .25425 .45639 L p F P
0 g
s
.974 .694 .436 r
.25306 .465 m .25799 .47148 L .25799 .4797 L p F P
0 g
s
.373 .57 .915 r
.36649 .39116 m .35709 .38944 L .36282 .39638 L p F P
0 g
s
.373 .57 .915 r
.36282 .39638 m .37067 .39807 L .36649 .39116 L p F P
0 g
s
.541 .66 .913 r
.34763 .39004 m .35709 .38944 L .36282 .39638 L p F P
0 g
s
.9 .798 .739 r
.25652 .43097 m .25242 .42403 L .25864 .41367 L p F P
0 g
s
.934 .798 .687 r
.25242 .42403 m .25652 .43097 L .25223 .44064 L p F P
0 g
s
.628 .105 0 r
.29839 .53962 m .30495 .54525 L .299 .53883 L p F P
0 g
s
.628 .105 0 r
.299 .53883 m .29247 .53319 L .29839 .53962 L p F P
0 g
s
.189 .708 .877 r
.50838 .6193 m .5095 .61926 L .53116 .61963 L p F P
0 g
s
.23 .728 .911 r
.50838 .6193 m .5095 .61926 L .50799 .61921 L closepath p F P
0 g
s
.39 .811 .971 r
.55199 .617 m .55673 .61833 L .53316 .61964 L p F P
0 g
s
.39 .811 .971 r
.53316 .61964 m .53271 .6195 L .55199 .617 L p F P
0 g
s
.335 .782 .958 r
.53316 .61964 m .53271 .6195 L .53116 .61963 L closepath p F P
0 g
s
.347 .785 .965 r
.52753 .61784 m .5095 .61926 L .53116 .61963 L p F P
0 g
s
.347 .785 .965 r
.53116 .61963 m .53271 .6195 L .52753 .61784 L p F P
0 g
s
.376 .834 .915 r
.60013 .61139 m .60083 .61145 L .58137 .61575 L p F P
0 g
s
.376 .834 .915 r
.58137 .61575 m .57898 .61553 L .60013 .61139 L p F P
0 g
s
.29 .783 .884 r
.57898 .61553 m .58137 .61575 L p .55705 .61837 L F P
0 g
s
.557 .66 .905 r
.35709 .38944 m .34763 .39004 L .34386 .38294 L p F P
0 g
s
.439 .475 .8 r
.7851 .40246 m .78681 .40663 L .79596 .41011 L p F P
0 g
s
.139 .627 .916 r
.44696 .61001 m .43018 .60787 L .42456 .60514 L p F P
0 g
s
.368 .785 .977 r
.5223 .61608 m .52753 .61784 L .5095 .61926 L p F P
0 g
s
.368 .785 .977 r
.50309 .61741 m .5223 .61608 L p .5095 .61926 L F P
0 g
s
.368 .785 .977 r
.5095 .61926 m .50799 .61921 L .50309 .61741 L p F P
0 g
s
.305 .751 .962 r
.50799 .61921 m .50309 .61741 L .49138 .61776 L closepath p F P
0 g
s
0 0 0 r
.75166 .54191 m .75149 .54206 L .75449 .53816 L p F P
0 g
s
0 0 0 r
.75449 .53816 m .76472 .52888 L .75166 .54191 L p F P
0 g
s
.276 .218 .61 r
.80347 .4488 m .80039 .4536 L .79851 .44361 L p F P
0 g
s
.276 .218 .61 r
.79851 .44361 m .79999 .44127 L .80347 .4488 L p F P
0 g
s
.793 .918 .923 r
.68441 .39808 m .67718 .40306 L .68161 .39655 L closepath p F P
0 g
s
.762 .973 .923 r
.67995 .39563 m .68161 .39655 L .67718 .40306 L p F P
0 g
s
.762 .973 .923 r
.66323 .40841 m .67995 .39563 L p .67718 .40306 L F P
0 g
s
.762 .973 .923 r
.66147 .4106 m .66323 .40841 L p .67718 .40306 L F P
0 g
s
.375 .805 .966 r
.55199 .617 m .53271 .6195 L .52753 .61784 L p F P
0 g
s
.421 0 .02 r
.55918 .47029 m .55905 .47043 L .55823 .47041 L closepath p F P
0 g
s
.42 0 .02 r
.55607 .47498 m .55905 .47043 L .55823 .47041 L p F P
0 g
s
.42 0 .02 r
.54246 .4765 m .55607 .47498 L p .55823 .47041 L F P
0 g
s
.42 0 .02 r
.53472 .47553 m .54246 .4765 L p .55823 .47041 L F P
0 g
s
.654 .098 0 r
.45596 .45822 m .466 .46274 L .45889 .45682 L p F P
0 g
s
.654 .098 0 r
.45103 .45337 m .45596 .45822 L p .45889 .45682 L F P
0 g
s
.654 .098 0 r
.45889 .45682 m .45325 .45398 L .45103 .45337 L p F P
0 g
s
.29 .783 .884 r
.55705 .61837 m .5591 .61805 L .57898 .61553 L p F P
0 g
s
.322 .798 .911 r
.55705 .61837 m .5591 .61805 L .55673 .61833 L closepath p F P
0 g
s
.279 0 0 r
.57845 .46644 m .57959 .46501 L .55918 .47029 L p F P
0 g
s
.279 0 0 r
.55918 .47029 m .55905 .47043 L .57845 .46644 L p F P
0 g
s
.111 0 .335 r
.78851 .49019 m .787 .49527 L .78831 .49384 L closepath p F P
0 g
s
.474 0 0 r
.31244 .55116 m .31194 .5508 L .31184 .55072 L closepath p F P
0 g
s
.052 .404 .858 r
.38868 .40802 m .38657 .40694 L .39223 .41343 L p F P
0 g
s
.052 .404 .858 r
.39223 .41343 m .39405 .41439 L .38868 .40802 L p F P
0 g
s
.548 .654 .905 r
.34099 .37544 m .32732 .37696 L .33316 .38373 L p F P
0 g
s
.548 .654 .905 r
.33316 .38373 m .34386 .38294 L .34099 .37544 L p F P
0 g
s
0 .357 .728 r
.37071 .58673 m .37166 .58712 L .38096 .59159 L p F P
0 g
s
.001 .506 .861 r
.38551 .59129 m .37166 .58712 L .38096 .59159 L p F P
0 g
s
.001 .506 .861 r
.39416 .59531 m .38551 .59129 L p .38096 .59159 L F P
0 g
s
.001 .506 .861 r
.38096 .59159 m .39468 .5956 L .39416 .59531 L p F P
0 g
s
.502 .528 .816 r
.78208 .39555 m .78773 .39659 L .7851 .40246 L closepath p F P
0 g
s
.439 .475 .8 r
.80056 .40082 m .78773 .39659 L .7851 .40246 L p F P
0 g
s
.439 .475 .8 r
.79596 .41011 m .80056 .40082 L p .7851 .40246 L F P
0 g
s
.364 0 .082 r
.57657 .46969 m .57845 .46644 L .55905 .47043 L p F P
0 g
s
.364 0 .082 r
.55905 .47043 m .55607 .47498 L .57657 .46969 L p F P
0 g
s
.649 .131 0 r
.4853 .47247 m .49956 .47547 L .49109 .46991 L p F P
0 g
s
.649 .131 0 r
.48067 .46847 m .4853 .47247 L p .49109 .46991 L F P
0 g
s
.649 .131 0 r
.49109 .46991 m .48266 .4678 L .48067 .46847 L p F P
0 g
s
.973 .744 .53 r
.24963 .44972 m .25425 .45639 L .25306 .465 L p F P
0 g
s
.528 .921 .873 r
.68864 .58259 m .6896 .58254 L .6721 .59144 L p F P
0 g
s
.528 .921 .873 r
.6721 .59144 m .66896 .59173 L .68864 .58259 L p F P
0 g
s
.811 .785 .829 r
.2677 .40227 m .26435 .39495 L p .28046 .38398 L F P
0 g
s
.811 .785 .829 r
.28046 .38398 m .28292 .38859 L .2677 .40227 L p F P
0 g
s
.852 .81 .809 r
.26523 .40489 m .2677 .40227 L .26435 .39495 L p F P
0 g
s
0 0 0 r
.61817 .44293 m .62191 .43981 L .60257 .45186 L p F P
0 g
s
0 0 0 r
.60257 .45186 m .60146 .45314 L .61817 .44293 L p F P
0 g
s
.439 .84 .976 r
.5591 .61805 m .55673 .61833 L .55199 .617 L p F P
0 g
s
0 .099 .559 r
.30513 .5454 m .31184 .55072 L p .30593 .54603 L F P
0 g
s
0 .099 .559 r
.31184 .55072 m .31194 .5508 L .30593 .54603 L p F P
0 g
s
0 .102 .577 r
.30593 .54603 m .2999 .54082 L p .31054 .5497 L F P
0 g
s
.457 0 0 r
.30593 .54603 m .31239 .55124 L .31932 .5567 L p F P
0 g
s
0 .102 .577 r
.31239 .55124 m .30593 .54603 L p .31054 .5497 L F P
0 g
s
0 .099 .559 r
.30593 .54603 m .30495 .54525 L .30513 .5454 L p F P
0 g
s
.791 .778 .842 r
.28439 .38741 m .28292 .38859 L .28046 .38398 L closepath p F P
0 g
s
.794 .918 .922 r
.69944 .38202 m .7039 .38585 L .68441 .39808 L p F P
0 g
s
.794 .918 .922 r
.68418 .39272 m .69944 .38202 L p .68441 .39808 L F P
0 g
s
.794 .918 .922 r
.68441 .39808 m .68161 .39655 L .68418 .39272 L p F P
0 g
s
.852 .81 .809 r
.26435 .39495 m .25892 .40094 L .26523 .40489 L p F P
0 g
s
.875 .804 .776 r
.25482 .40654 m .25892 .40094 L .26523 .40489 L p F P
0 g
s
.875 .804 .776 r
.26523 .40489 m .25864 .41367 L .25482 .40654 L p F P
0 g
s
.457 0 0 r
.31932 .5567 m .31194 .5508 L .30593 .54603 L p F P
0 g
s
.757 .777 .869 r
.29702 .37053 m .30303 .37662 L .28439 .38741 L p F P
0 g
s
.757 .777 .869 r
.27958 .38122 m .29702 .37053 L p .28439 .38741 L F P
0 g
s
.757 .777 .869 r
.28439 .38741 m .28046 .38398 L .27958 .38122 L p F P
0 g
s
.421 .838 .966 r
.57898 .61553 m .57643 .61488 L .5591 .61805 L closepath p F P
0 g
s
.439 .84 .976 r
.57144 .61354 m .57643 .61488 L .5591 .61805 L p F P
0 g
s
.439 .84 .976 r
.55199 .617 m .57144 .61354 L p .5591 .61805 L F P
0 g
s
.598 .132 .118 r
.51035 .47402 m .51739 .47722 L .50763 .47655 L closepath p F P
0 g
s
0 .202 .611 r
.34115 .57121 m .34348 .57261 L .35167 .57751 L p F P
0 g
s
0 .379 .786 r
.35458 .57756 m .36288 .58244 L .35167 .57751 L p F P
0 g
s
0 .379 .786 r
.35167 .57751 m .34348 .57261 L .35458 .57756 L p F P
0 g
s
.339 .758 .977 r
.49775 .61534 m .50309 .61741 L .49138 .61776 L p F P
0 g
s
.339 .758 .977 r
.47869 .61574 m .49775 .61534 L p .49138 .61776 L F P
0 g
s
.339 .758 .977 r
.49138 .61776 m .48068 .61657 L .47869 .61574 L p F P
0 g
s
.492 0 0 r
.43219 .442 m .4401 .44733 L .43246 .4417 L p F P
0 g
s
.492 0 0 r
.43246 .4417 m .42502 .43621 L .43219 .442 L p F P
0 g
s
.678 .711 .873 r
.72803 .38064 m .74798 .37325 L .75247 .3802 L p F P
0 g
s
.698 .734 .879 r
.74798 .37325 m .72803 .38064 L .72358 .37524 L p F P
0 g
s
.456 .886 .85 r
.66562 .59205 m .66896 .59173 L .64935 .59967 L p F P
0 g
s
.456 .886 .85 r
.64935 .59967 m .64735 .59991 L .66562 .59205 L p F P
0 g
s
0 .504 .829 r
.40044 .59858 m .40528 .59984 L .41608 .60376 L p F P
0 g
s
.151 .62 .928 r
.41889 .6022 m .40528 .59984 L .41608 .60376 L p F P
0 g
s
.151 .62 .928 r
.41608 .60376 m .42456 .60514 L .41889 .6022 L p F P
0 g
s
.067 .415 .864 r
.38868 .40802 m .39405 .41439 L .40347 .4192 L p F P
0 g
s
.26 .211 .611 r
.80908 .43937 m .80347 .4488 L .79999 .44127 L p F P
0 g
s
.26 .211 .611 r
.79999 .44127 m .80554 .43184 L .80908 .43937 L p F P
0 g
s
0 0 .166 r
.78722 .49988 m .78193 .5057 L .787 .49527 L p F P
0 g
s
0 0 .166 r
.787 .49527 m .78831 .49384 L .78722 .49988 L p F P
0 g
s
.486 .893 .773 r
.70732 .57364 m .69293 .58152 L .6896 .58254 L p F P
0 g
s
.611 .632 .848 r
.77412 .37922 m .77037 .38619 L p .75247 .3802 L F P
0 g
s
.611 .632 .848 r
.75247 .3802 m .77285 .3768 L .77412 .37922 L p F P
0 g
s
.63 .656 .857 r
.77285 .3768 m .75247 .3802 L .74798 .37325 L p F P
0 g
s
.924 .534 .18 r
.26669 .50135 m .26585 .49863 L .2718 .50609 L p F P
0 g
s
.924 .534 .18 r
.2718 .50609 m .27223 .50749 L .26669 .50135 L p F P
0 g
s
.922 .53 .175 r
.26438 .49386 m .26585 .49863 L .2718 .50609 L p F P
0 g
s
.741 .831 .92 r
.70484 .38675 m .7039 .38585 L .70631 .38457 L closepath p F P
0 g
s
.517 .549 .828 r
.78773 .39659 m .78208 .39555 L .77743 .38573 L p F P
0 g
s
.281 .725 .962 r
.48068 .61657 m .47869 .61574 L .47503 .61569 L closepath p F P
0 g
s
.648 .13 0 r
.48266 .4678 m .48067 .46847 L .47782 .46659 L closepath p F P
0 g
s
.906 .808 .739 r
.25482 .40654 m .25864 .41367 L .25242 .42403 L p F P
0 g
s
0 .51 .85 r
.40528 .59984 m .40044 .59858 L .39468 .5956 L p F P
0 g
s
.497 .061 .141 r
.53472 .47553 m .54246 .4765 L .53331 .47748 L closepath p F P
0 g
s
.934 .798 .687 r
.25223 .44064 m .24811 .43372 L .25242 .42403 L p F P
0 g
s
.963 .788 .618 r
.24811 .43372 m .25223 .44064 L .25055 .44631 L p F P
0 g
s
.14 .65 .899 r
.45438 .61251 m .46049 .61302 L .47503 .61569 L p F P
0 g
s
.184 .666 .928 r
.45438 .61251 m .46049 .61302 L .45027 .61084 L closepath p F P
0 g
s
.537 0 0 r
.45325 .45398 m .45103 .45337 L .44918 .45221 L closepath p F P
0 g
s
.578 .608 .847 r
.77037 .38619 m .77412 .37922 L .77743 .38573 L closepath p F P
0 g
s
0 .242 .684 r
.32832 .56225 m .31932 .5567 L .32662 .56199 L p F P
0 g
s
0 .242 .684 r
.33309 .56567 m .32832 .56225 L p .32662 .56199 L F P
0 g
s
0 .242 .684 r
.32662 .56199 m .33519 .56722 L .33309 .56567 L p F P
0 g
s
.183 .103 .524 r
.80492 .45705 m .80143 .46244 L .80039 .4536 L p F P
0 g
s
.183 .103 .524 r
.80039 .4536 m .80347 .4488 L .80492 .45705 L p F P
0 g
s
.84 .394 0 r
.26669 .50135 m .27223 .50749 L .27574 .51462 L p F P
0 g
s
.854 .406 .005 r
.28161 .52059 m .27574 .51462 L .27223 .50749 L p F P
0 g
s
.298 .728 .97 r
.47325 .61332 m .46049 .61302 L .47503 .61569 L p F P
0 g
s
.298 .728 .97 r
.47503 .61569 m .47869 .61574 L .47325 .61332 L p F P
0 g
s
.96 .626 .321 r
.26438 .49386 m .25913 .48755 L .25799 .4797 L p F P
0 g
s
.916 .523 .135 r
.26585 .49863 m .26438 .49386 L .25913 .48755 L p F P
0 g
s
0 0 .139 r
.79071 .49553 m .78722 .49988 L .78831 .49384 L p F P
0 g
s
0 0 .139 r
.78831 .49384 m .79515 .48527 L .79071 .49553 L p F P
0 g
s
.129 .003 .427 r
.80172 .47023 m .79768 .47566 L .79825 .46672 L p F P
0 g
s
.129 .003 .427 r
.79825 .46672 m .80143 .46244 L .80172 .47023 L p F P
0 g
s
.476 .864 .975 r
.59596 .61034 m .60013 .61139 L .57898 .61553 L p F P
0 g
s
.476 .864 .975 r
.57898 .61553 m .57643 .61488 L .59596 .61034 L p F P
0 g
s
0 0 0 r
.61732 .44362 m .61817 .44293 L .60146 .45314 L p F P
0 g
s
0 0 0 r
.59872 .45666 m .61732 .44362 L p .60146 .45314 L F P
0 g
s
0 0 0 r
.60146 .45314 m .59802 .4571 L .59872 .45666 L p F P
0 g
s
.647 .127 0 r
.47324 .46868 m .466 .46274 L .47782 .46659 L p F P
0 g
s
.647 .127 0 r
.47671 .46972 m .47324 .46868 L p .47782 .46659 L F P
0 g
s
.647 .127 0 r
.47782 .46659 m .48067 .46847 L .47671 .46972 L p F P
0 g
s
.735 .248 0 r
.27574 .51462 m .28161 .52059 L .28627 .52739 L p F P
0 g
s
.612 .945 .762 r
.64123 .42554 m .62261 .4393 L .6371 .42716 L closepath p F P
0 g
s
0 0 0 r
.6367 .42731 m .6371 .42716 L .62261 .4393 L p F P
0 g
s
0 0 0 r
.62104 .4405 m .6367 .42731 L p .62261 .4393 L F P
0 g
s
0 0 0 r
.61817 .44293 m .62104 .4405 L p .62261 .4393 L F P
0 g
s
0 .219 .645 r
.34348 .57261 m .34115 .57121 L .33519 .56722 L p F P
0 g
s
.742 .851 .931 r
.70631 .38457 m .7039 .38585 L .69944 .38202 L p F P
0 g
s
.974 .694 .436 r
.25799 .4797 m .25305 .47322 L .25306 .465 L p F P
0 g
s
.962 .629 .292 r
.25913 .48755 m .25799 .4797 L .25305 .47322 L p F P
0 g
s
.731 .991 .85 r
.64194 .42542 m .64123 .42554 L .64376 .42357 L closepath p F P
0 g
s
0 .383 .768 r
.37071 .58673 m .37166 .58712 L .36888 .58566 L closepath p F P
0 g
s
0 0 0 r
.77157 .52012 m .77051 .5221 L .77475 .51683 L closepath p F P
0 g
s
.054 .432 .872 r
.41033 .42249 m .40347 .4192 L .40949 .42529 L p F P
0 g
s
.054 .432 .872 r
.40949 .42529 m .41596 .42834 L .41033 .42249 L p F P
0 g
s
.768 .854 .915 r
.70631 .38457 m .72358 .37524 L .71911 .37016 L p F P
0 g
s
.768 .854 .915 r
.71911 .37016 m .71154 .37478 L .70631 .38457 L p F P
0 g
s
.742 .851 .931 r
.69944 .38202 m .71154 .37478 L .70631 .38457 L p F P
0 g
s
.407 .574 .905 r
.36308 .38391 m .35135 .38225 L .35709 .38944 L p F P
0 g
s
.407 .574 .905 r
.35709 .38944 m .36649 .39116 L .36308 .38391 L p F P
0 g
s
.557 .66 .905 r
.34386 .38294 m .35135 .38225 L .35709 .38944 L p F P
0 g
s
.421 .588 .911 r
.38091 .39995 m .37067 .39807 L .36649 .39116 L p F P
0 g
s
.388 .586 .921 r
.37067 .39807 m .38091 .39995 L .38657 .40694 L p F P
0 g
s
.338 .317 .689 r
.8099 .42395 m .80554 .43184 L .79969 .42514 L p F P
0 g
s
.338 .317 .689 r
.80896 .42033 m .8099 .42395 L p .79969 .42514 L F P
0 g
s
.338 .317 .689 r
.79969 .42514 m .80477 .41577 L .80896 .42033 L p F P
0 g
s
.491 0 0 r
.44545 .45115 m .4401 .44733 L .44918 .45221 L p F P
0 g
s
.491 0 0 r
.44918 .45221 m .45103 .45337 L .44545 .45115 L p F P
0 g
s
.5 .899 .933 r
.64477 .59968 m .62515 .60632 L .62043 .60596 L p F P
0 g
s
.429 .865 .918 r
.60083 .61145 m .62043 .60596 L .62515 .60632 L p F P
0 g
s
.594 .081 0 r
.29218 .53382 m .29839 .53962 L .29247 .53319 L p F P
0 g
s
.594 .081 0 r
.29247 .53319 m .28627 .52739 L .29218 .53382 L p F P
0 g
s
.663 .713 .886 r
.31553 .36333 m .29702 .37053 L .30303 .37662 L p F P
0 g
s
.663 .713 .886 r
.30303 .37662 m .32145 .37015 L .31553 .36333 L p F P
0 g
s
.378 .805 .625 r
.7125 .57055 m .70732 .57364 L .71177 .57097 L closepath p F P
0 g
s
.486 .893 .773 r
.70833 .57179 m .71177 .57097 L .70732 .57364 L p F P
0 g
s
.486 .893 .773 r
.69495 .57931 m .70833 .57179 L p .70732 .57364 L F P
0 g
s
.486 .893 .773 r
.6896 .58254 m .69495 .57931 L p .70732 .57364 L F P
0 g
s
.066 .531 .897 r
.37651 .58666 m .38551 .59129 L .37166 .58712 L p F P
0 g
s
.066 .531 .897 r
.36486 .58307 m .37651 .58666 L p .37166 .58712 L F P
0 g
s
.066 .531 .897 r
.37166 .58712 m .36888 .58566 L .36486 .58307 L p F P
0 g
s
.764 .781 .867 r
.27958 .38122 m .28046 .38398 L .27826 .3821 L closepath p F P
0 g
s
.811 .785 .829 r
.26435 .39495 m .27826 .3821 L .28046 .38398 L p F P
0 g
s
0 0 0 r
.78418 .50649 m .77475 .51683 L .78193 .5057 L p F P
0 g
s
0 0 0 r
.78588 .50374 m .78418 .50649 L p .78193 .5057 L F P
0 g
s
0 0 0 r
.78193 .5057 m .78722 .49988 L .78588 .50374 L p F P
0 g
s
.11 0 0 r
.5979 .45724 m .59802 .4571 L .57959 .46501 L p F P
0 g
s
.11 0 0 r
.57959 .46501 m .57845 .46644 L .5979 .45724 L p F P
0 g
s
.973 .744 .53 r
.25306 .465 m .24843 .45834 L .24963 .44972 L p F P
0 g
s
.98 .702 .421 r
.24843 .45834 m .25306 .465 L .25305 .47322 L p F P
0 g
s
.963 .788 .618 r
.25055 .44631 m .24821 .44746 L p .24811 .43372 L F P
0 g
s
.964 .778 .604 r
.25055 .44631 m .24963 .44972 L .24821 .44746 L closepath p F P
0 g
s
.311 .743 .97 r
.49775 .61534 m .47869 .61574 L .47325 .61332 L p F P
0 g
s
.795 .973 .91 r
.66147 .4106 m .66057 .41042 L .66323 .40841 L closepath p F P
0 g
s
.906 .808 .739 r
.25242 .42403 m .24863 .41691 L .25482 .40654 L p F P
0 g
s
.941 .809 .686 r
.24863 .41691 m .25242 .42403 L .24811 .43372 L p F P
0 g
s
.64 .956 .766 r
.64376 .42357 m .64123 .42554 L .6371 .42716 L p F P
0 g
s
.551 .922 .937 r
.66449 .59192 m .66562 .59205 L .64735 .59991 L p F P
0 g
s
.551 .922 .937 r
.64735 .59991 m .64477 .59968 L .66449 .59192 L p F P
0 g
s
.464 .855 .653 r
.72801 .55951 m .73204 .55762 L .7125 .57055 L p F P
0 g
s
.464 .855 .653 r
.72668 .56042 m .72801 .55951 L p .7125 .57055 L F P
0 g
s
.464 .855 .653 r
.7125 .57055 m .71177 .57097 L .72668 .56042 L p F P
0 g
s
0 .51 .85 r
.39468 .5956 m .39504 .5957 L .40528 .59984 L p F P
0 g
s
.161 .617 .933 r
.41237 .59886 m .39504 .5957 L .40528 .59984 L p F P
0 g
s
.161 .617 .933 r
.41415 .59955 m .41237 .59886 L p .40528 .59984 L F P
0 g
s
.161 .617 .933 r
.40528 .59984 m .41889 .6022 L .41415 .59955 L p F P
0 g
s
.517 .549 .828 r
.77743 .38573 m .79159 .38747 L .78773 .39659 L p F P
0 g
s
.478 .504 .807 r
.80195 .39783 m .80056 .40082 L .78773 .39659 L p F P
0 g
s
.478 .504 .807 r
.79864 .3893 m .80195 .39783 L p .78773 .39659 L F P
0 g
s
.478 .504 .807 r
.78773 .39659 m .79159 .38747 L .79864 .3893 L p F P
0 g
s
.415 .42 .756 r
.80668 .41201 m .80477 .41577 L .79596 .41011 L p F P
0 g
s
.415 .42 .756 r
.80358 .4025 m .80668 .41201 L p .79596 .41011 L F P
0 g
s
.415 .42 .756 r
.79596 .41011 m .80056 .40082 L .80358 .4025 L p F P
0 g
s
.567 .654 .894 r
.3395 .36736 m .32145 .37015 L .32732 .37696 L p F P
0 g
s
.567 .654 .894 r
.32732 .37696 m .34099 .37544 L .3395 .36736 L p F P
0 g
s
.793 .916 .922 r
.68161 .39655 m .67995 .39563 L .68418 .39272 L closepath p F P
0 g
s
.574 .662 .897 r
.35135 .38225 m .34386 .38294 L .34099 .37544 L p F P
0 g
s
.731 .985 .784 r
.64376 .42357 m .66057 .41042 L .65607 .41018 L p F P
0 g
s
.731 .985 .784 r
.65607 .41018 m .65378 .41221 L .64376 .42357 L p F P
0 g
s
.64 .956 .766 r
.63803 .42615 m .65378 .41221 L .64376 .42357 L p F P
0 g
s
.64 .956 .766 r
.6371 .42716 m .63803 .42615 L p .64376 .42357 L F P
0 g
s
0 .219 .645 r
.33519 .56722 m .33569 .56752 L .34348 .57261 L p F P
0 g
s
0 .392 .809 r
.3467 .57249 m .35458 .57756 L .34348 .57261 L p F P
0 g
s
0 .392 .809 r
.34348 .57261 m .33569 .56752 L .3467 .57249 L p F P
0 g
s
.105 .418 .865 r
.38387 .40139 m .38091 .39995 L .38657 .40694 L p F P
0 g
s
.105 .418 .865 r
.38657 .40694 m .38868 .40802 L .38387 .40139 L p F P
0 g
s
.751 .233 0 r
.45596 .45822 m .45103 .45337 L .44545 .45115 L p F P
0 g
s
.323 .728 .98 r
.46777 .61073 m .47325 .61332 L .46049 .61302 L p F P
0 g
s
.323 .728 .98 r
.44884 .61012 m .46777 .61073 L p .46049 .61302 L F P
0 g
s
.323 .728 .98 r
.46049 .61302 m .45027 .61084 L .44884 .61012 L p F P
0 g
s
0 .118 .594 r
.2999 .54082 m .29839 .53962 L .30495 .54525 L p F P
0 g
s
0 .118 .594 r
.30495 .54525 m .30593 .54603 L .2999 .54082 L p F P
0 g
s
.499 .065 .145 r
.54246 .4765 m .53331 .47748 L .53 .48216 L p F P
0 g
s
.603 .178 .209 r
.52809 .48213 m .53 .48216 L .53331 .47748 L p F P
0 g
s
.603 .178 .209 r
.53331 .47748 m .51739 .47722 L .52809 .48213 L p F P
0 g
s
.504 .569 .855 r
.77412 .37922 m .77743 .38573 L .79159 .38747 L p F P
0 g
s
.708 .212 .061 r
.48067 .46847 m .4853 .47247 L .47671 .46972 L closepath p F P
0 g
s
.027 .504 .879 r
.36888 .58566 m .36486 .58307 L .36288 .58244 L closepath p F P
0 g
s
.6 .135 .122 r
.50809 .48108 m .52809 .48213 L .51739 .47722 L p F P
0 g
s
.6 .135 .122 r
.50501 .47902 m .50809 .48108 L p .51739 .47722 L F P
0 g
s
.6 .135 .122 r
.51739 .47722 m .50763 .47655 L .50501 .47902 L p F P
0 g
s
.439 .869 .925 r
.62028 .60594 m .62043 .60596 L .60083 .61145 L p F P
0 g
s
.439 .869 .925 r
.60083 .61145 m .60013 .61139 L .62028 .60594 L p F P
0 g
s
0 .07 .548 r
.41596 .42834 m .41836 .43039 L .42502 .43621 L p F P
0 g
s
0 .072 .55 r
.42525 .43627 m .43219 .442 L .42502 .43621 L p F P
0 g
s
0 .072 .55 r
.42502 .43621 m .41836 .43039 L .42525 .43627 L p F P
0 g
s
.981 .754 .521 r
.24821 .44746 m .24963 .44972 L .24843 .45834 L p F P
0 g
s
.139 .627 .916 r
.42456 .60514 m .43473 .60655 L .44696 .61001 L p F P
0 g
s
.16 .629 .929 r
.43473 .60655 m .42456 .60514 L .41889 .6022 L p F P
0 g
s
.341 .772 .97 r
.5223 .61608 m .50309 .61741 L .49775 .61534 L p F P
0 g
s
.534 .924 .873 r
.68426 .5828 m .68864 .58259 L .66896 .59173 L p F P
0 g
s
.534 .924 .873 r
.67405 .58764 m .68426 .5828 L p .66896 .59173 L F P
0 g
s
.534 .924 .873 r
.66896 .59173 m .66562 .59205 L .67405 .58764 L p F P
0 g
s
.653 .2 .164 r
.50763 .47655 m .50501 .47902 L .49956 .47547 L closepath p F P
0 g
s
.503 .075 .16 r
.55607 .47498 m .55409 .47801 L .54246 .4765 L closepath p F P
0 g
s
.499 .065 .145 r
.55311 .47995 m .55409 .47801 L .54246 .4765 L p F P
0 g
s
.499 .065 .145 r
.53 .48216 m .55311 .47995 L p .54246 .4765 L F P
0 g
s
.771 .988 .894 r
.66323 .40841 m .66057 .41042 L .65607 .41018 L p F P
0 g
s
.919 .529 .144 r
.26146 .49504 m .25995 .49017 L .26585 .49863 L p F P
0 g
s
.919 .529 .144 r
.26585 .49863 m .26669 .50135 L .26146 .49504 L p F P
0 g
s
.916 .523 .135 r
.25913 .48755 m .25995 .49017 L .26585 .49863 L p F P
0 g
s
.777 .791 .865 r
.27826 .3821 m .27958 .38122 L .27736 .37337 L p F P
0 g
s
.777 .791 .865 r
.27736 .37337 m .27206 .37712 L .27826 .3821 L p F P
0 g
s
.821 .802 .833 r
.26127 .38745 m .27206 .37712 L .27826 .3821 L p F P
0 g
s
.821 .802 .833 r
.27826 .3821 m .26435 .39495 L .26127 .38745 L p F P
0 g
s
.865 .825 .807 r
.25892 .40094 m .26435 .39495 L .26127 .38745 L p F P
0 g
s
.733 .219 0 r
.46227 .46448 m .47324 .46868 L .466 .46274 L p F P
0 g
s
.733 .219 0 r
.466 .46274 m .45596 .45822 L .46227 .46448 L p F P
0 g
s
.771 .988 .894 r
.65607 .41018 m .6704 .39798 L .66323 .40841 L p F P
0 g
s
.819 .988 .878 r
.66323 .40841 m .67995 .39563 L .67547 .3936 L p F P
0 g
s
.819 .988 .878 r
.67547 .3936 m .6704 .39798 L .66323 .40841 L p F P
0 g
s
.75 .775 .873 r
.29702 .37053 m .27958 .38122 L .27736 .37337 L p F P
0 g
s
0 0 0 r
.775 .51832 m .78418 .50649 L .77475 .51683 L p F P
0 g
s
0 0 0 r
.76919 .52463 m .775 .51832 L p .77475 .51683 L F P
0 g
s
0 0 0 r
.77475 .51683 m .77051 .5221 L .76919 .52463 L p F P
0 g
s
.555 .912 .717 r
.73236 .55747 m .73204 .55762 L .73358 .55651 L closepath p F P
0 g
s
.586 .943 .817 r
.71177 .57097 m .70833 .57179 L .72668 .56042 L closepath p F P
0 g
s
.067 0 .409 r
.8045 .46596 m .80172 .47023 L .80143 .46244 L p F P
0 g
s
.067 0 .409 r
.80143 .46244 m .80492 .45705 L .8045 .46596 L p F P
0 g
s
.63 .656 .857 r
.74798 .37325 m .76831 .36863 L .77285 .3768 L p F P
0 g
s
.649 .68 .866 r
.76831 .36863 m .74798 .37325 L .74351 .36673 L p F P
0 g
s
.698 .734 .879 r
.72358 .37524 m .74351 .36673 L .74798 .37325 L p F P
0 g
s
.157 .085 .518 r
.81056 .44764 m .80492 .45705 L .80347 .4488 L p F P
0 g
s
.157 .085 .518 r
.80347 .4488 m .80908 .43937 L .81056 .44764 L p F P
0 g
s
.472 .862 .974 r
.59596 .61034 m .57643 .61488 L .57144 .61354 L p F P
0 g
s
.119 .428 .87 r
.38387 .40139 m .38868 .40802 L .39821 .41278 L p F P
0 g
s
.067 .415 .864 r
.40347 .4192 m .39821 .41278 L .38868 .40802 L p F P
0 g
s
.524 .887 .977 r
.61563 .60475 m .62028 .60594 L .60013 .61139 L p F P
0 g
s
.524 .887 .977 r
.60013 .61139 m .59596 .61034 L .61563 .60475 L p F P
0 g
s
.375 .805 .966 r
.52753 .61784 m .54687 .61548 L .55199 .617 L p F P
0 g
s
.378 .803 .97 r
.54687 .61548 m .52753 .61784 L .5223 .61608 L p F P
0 g
s
0 0 .28 r
.80127 .47705 m .79515 .48527 L .79768 .47566 L p F P
0 g
s
0 0 .28 r
.79768 .47566 m .80172 .47023 L .80127 .47705 L p F P
0 g
s
.865 .825 .807 r
.26127 .38745 m .2525 .39755 L .25892 .40094 L p F P
0 g
s
.884 .814 .774 r
.25131 .39923 m .2525 .39755 L .25892 .40094 L p F P
0 g
s
.884 .814 .774 r
.25892 .40094 m .25482 .40654 L .25131 .39923 L p F P
0 g
s
.716 .754 .882 r
.74351 .36673 m .72358 .37524 L .71911 .37016 L p F P
0 g
s
.652 .211 .19 r
.49229 .47858 m .4853 .47247 L .49956 .47547 L p F P
0 g
s
.652 .211 .19 r
.50359 .48054 m .49229 .47858 L p .49956 .47547 L F P
0 g
s
.652 .211 .19 r
.49956 .47547 m .50501 .47902 L .50359 .48054 L p F P
0 g
s
.419 .833 .97 r
.57144 .61354 m .55199 .617 L .54687 .61548 L p F P
0 g
s
.221 0 .038 r
.59508 .46176 m .5979 .45724 L .57845 .46644 L p F P
0 g
s
.221 0 .038 r
.57845 .46644 m .57657 .46969 L .59508 .46176 L p F P
0 g
s
0 0 0 r
.77051 .5221 m .76472 .52888 L .76919 .52463 L closepath p F P
0 g
s
0 .258 .716 r
.32133 .5568 m .32832 .56225 L .31932 .5567 L p F P
0 g
s
0 .258 .716 r
.31932 .5567 m .31239 .55124 L .32133 .5568 L p F P
0 g
s
.551 .91 .713 r
.73358 .55651 m .73204 .55762 L .72801 .55951 L p F P
0 g
s
.272 .699 .967 r
.45027 .61084 m .44884 .61012 L .44696 .61001 L closepath p F P
0 g
s
.473 .835 .58 r
.75144 .5421 m .73358 .55651 L .74765 .54495 L closepath p F P
0 g
s
.551 .91 .713 r
.74761 .54496 m .74765 .54495 L .73358 .55651 L p F P
0 g
s
.551 .91 .713 r
.72801 .55951 m .74761 .54496 L p .73358 .55651 L F P
0 g
s
.377 0 .089 r
.57372 .47465 m .57657 .46969 L .55607 .47498 L p F P
0 g
s
.377 0 .089 r
.57206 .47506 m .57372 .47465 L p .55607 .47498 L F P
0 g
s
.377 0 .089 r
.55607 .47498 m .55409 .47801 L .57206 .47506 L p F P
0 g
s
.789 .936 .927 r
.68418 .39272 m .67995 .39563 L .67547 .3936 L p F P
0 g
s
.963 .788 .618 r
.24821 .44746 m .24543 .44284 L .24811 .43372 L p F P
0 g
s
.984 .76 .519 r
.24543 .44284 m .24821 .44746 L .24606 .45458 L p F P
0 g
s
.981 .754 .521 r
.24843 .45834 m .24606 .45458 L .24821 .44746 L p F P
0 g
s
0 0 0 r
.76318 .53101 m .75166 .54191 L .76472 .52888 L p F P
0 g
s
0 0 0 r
.76698 .52709 m .76318 .53101 L p .76472 .52888 L F P
0 g
s
0 0 0 r
.76472 .52888 m .76919 .52463 L .76698 .52709 L p F P
0 g
s
.488 0 0 r
.43957 .44779 m .43219 .442 L .4401 .44733 L p F P
0 g
s
.488 0 0 r
.44038 .44829 m .43957 .44779 L p .4401 .44733 L F P
0 g
s
.488 0 0 r
.4401 .44733 m .44545 .45115 L .44038 .44829 L p F P
0 g
s
.941 .809 .686 r
.24811 .43372 m .24432 .42661 L .24863 .41691 L p F P
0 g
s
.971 .799 .612 r
.24432 .42661 m .24811 .43372 L .24543 .44284 L p F P
0 g
s
.913 .819 .74 r
.25131 .39923 m .25482 .40654 L .24863 .41691 L p F P
0 g
s
.555 .604 .857 r
.77285 .3768 m .77486 .37678 L .77412 .37922 L closepath p F P
0 g
s
.504 .569 .855 r
.79387 .37801 m .77486 .37678 L .77412 .37922 L p F P
0 g
s
.504 .569 .855 r
.79473 .37996 m .79387 .37801 L p .77412 .37922 L F P
0 g
s
.504 .569 .855 r
.79159 .38747 m .79473 .37996 L p .77412 .37922 L F P
0 g
s
.291 .702 .973 r
.44327 .60714 m .43473 .60655 L .44696 .61001 L p F P
0 g
s
.291 .702 .973 r
.44696 .61001 m .44884 .61012 L .44327 .60714 L p F P
0 g
s
.82 .379 0 r
.26146 .49504 m .26669 .50135 L .27019 .50849 L p F P
0 g
s
.84 .394 0 r
.27574 .51462 m .27019 .50849 L .26669 .50135 L p F P
0 g
s
.821 .928 .904 r
.68418 .39272 m .69944 .38202 L .69497 .37848 L p F P
0 g
s
.821 .928 .904 r
.69497 .37848 m .68928 .38295 L .68418 .39272 L p F P
0 g
s
.789 .936 .927 r
.67547 .3936 m .68928 .38295 L .68418 .39272 L p F P
0 g
s
.528 .866 .6 r
.75149 .54206 m .75144 .5421 L .75166 .54191 L closepath p F P
0 g
s
.521 .86 .593 r
.75166 .54191 m .75144 .5421 L .74765 .54495 L p F P
0 g
s
.521 .86 .593 r
.74777 .54483 m .76318 .53101 L .75166 .54191 L p F P
0 g
s
.521 .86 .593 r
.74765 .54495 m .74777 .54483 L p .75166 .54191 L F P
0 g
s
.962 .629 .292 r
.25468 .48173 m .25913 .48755 L p .25305 .47322 L F P
0 g
s
.909 .518 .103 r
.25468 .48173 m .25995 .49017 L .25913 .48755 L closepath p F P
0 g
s
.594 .949 .89 r
.6896 .58254 m .68864 .58259 L .69495 .57931 L closepath p F P
0 g
s
.704 .226 0 r
.27019 .50849 m .27574 .51462 L .28039 .52142 L p F P
0 g
s
.735 .248 0 r
.28627 .52739 m .28039 .52142 L .27574 .51462 L p F P
0 g
s
0 .108 .614 r
.41836 .43039 m .41596 .42834 L .41033 .42249 L p F P
0 g
s
.059 .515 .894 r
.35898 .57899 m .35458 .57756 L .36288 .58244 L p F P
0 g
s
.059 .515 .894 r
.36288 .58244 m .36486 .58307 L .35898 .57899 L p F P
0 g
s
.442 .578 .894 r
.36062 .37623 m .34557 .37486 L .35135 .38225 L p F P
0 g
s
.442 .578 .894 r
.35135 .38225 m .36308 .38391 L .36062 .37623 L p F P
0 g
s
.574 .662 .897 r
.34099 .37544 m .34557 .37486 L .35135 .38225 L p F P
0 g
s
.03 .527 .876 r
.39468 .5956 m .39504 .5957 L .39416 .59531 L closepath p F P
0 g
s
.122 .444 .88 r
.41033 .42249 m .40347 .4192 L .39821 .41278 L p F P
0 g
s
.208 .626 .951 r
.40243 .59456 m .41237 .59886 L .39504 .5957 L p F P
0 g
s
.208 .626 .951 r
.38891 .59199 m .40243 .59456 L p .39504 .5957 L F P
0 g
s
.208 .626 .951 r
.39504 .5957 m .39416 .59531 L .38891 .59199 L p F P
0 g
s
.98 .702 .421 r
.25305 .47322 m .24842 .46657 L .24843 .45834 L p F P
0 g
s
.959 .625 .253 r
.25412 .48056 m .25305 .47322 L .24842 .46657 L p F P
0 g
s
.962 .629 .292 r
.25305 .47322 m .25412 .48056 L .25468 .48173 L p F P
0 g
s
.298 .713 .974 r
.46777 .61073 m .44884 .61012 L .44327 .60714 L p F P
0 g
s
.555 .055 0 r
.28039 .52142 m .28627 .52739 L .29218 .53382 L p F P
0 g
s
.165 .6 .937 r
.39416 .59531 m .38891 .59199 L .38551 .59129 L closepath p F P
0 g
s
.571 .625 .867 r
.77486 .37678 m .77285 .3768 L .76831 .36863 L p F P
0 g
s
.566 .926 .945 r
.66449 .59192 m .64477 .59968 L .64013 .59925 L p F P
0 g
s
.5 .899 .933 r
.62043 .60596 m .64013 .59925 L .64477 .59968 L p F P
0 g
s
0 .245 .687 r
.33519 .56722 m .33569 .56752 L .33309 .56567 L closepath p F P
0 g
s
0 0 0 r
.78722 .49988 m .78588 .50374 L .79071 .49553 L closepath p F P
0 g
s
.454 .592 .9 r
.37522 .3925 m .36649 .39116 L .36308 .38391 L p F P
0 g
s
.421 .588 .911 r
.36649 .39116 m .37522 .3925 L .38091 .39995 L p F P
0 g
s
.675 .72 .883 r
.30957 .35657 m .29095 .36457 L .29702 .37053 L p F P
0 g
s
.675 .72 .883 r
.29702 .37053 m .31553 .36333 L .30957 .35657 L p F P
0 g
s
.75 .775 .873 r
.27736 .37337 m .29095 .36457 L .29702 .37053 L p F P
0 g
s
.244 .203 .611 r
.81194 .4342 m .80908 .43937 L .80554 .43184 L p F P
0 g
s
.244 .203 .611 r
.80554 .43184 m .8099 .42395 L .81194 .4342 L p F P
0 g
s
.711 .218 .068 r
.47948 .47504 m .49229 .47858 L .4853 .47247 L p F P
0 g
s
.711 .218 .068 r
.47515 .47024 m .47948 .47504 L p .4853 .47247 L F P
0 g
s
.711 .218 .068 r
.4853 .47247 m .47671 .46972 L .47515 .47024 L p F P
0 g
s
0 .426 .846 r
.33924 .56723 m .3467 .57249 L .33569 .56752 L p F P
0 g
s
0 .426 .846 r
.32922 .56266 m .33924 .56723 L p .33569 .56752 L F P
0 g
s
0 .426 .846 r
.33569 .56752 m .33309 .56567 L .32922 .56266 L p F P
0 g
s
.048 .511 .889 r
.37651 .58666 m .36486 .58307 L .35898 .57899 L p F P
0 g
s
.765 .87 .925 r
.71154 .37478 m .69944 .38202 L .69497 .37848 L p F P
0 g
s
.168 .438 .871 r
.37969 .39447 m .37522 .3925 L .38091 .39995 L p F P
0 g
s
.168 .438 .871 r
.38091 .39995 m .38387 .40139 L .37969 .39447 L p F P
0 g
s
.585 .66 .889 r
.33393 .35971 m .31553 .36333 L .32145 .37015 L p F P
0 g
s
.585 .66 .889 r
.33948 .36693 m .33393 .35971 L p .32145 .37015 L F P
0 g
s
.585 .66 .889 r
.32145 .37015 m .3395 .36736 L .33948 .36693 L p F P
0 g
s
.571 .625 .867 r
.76831 .36863 m .77703 .36809 L .77486 .37678 L p F P
0 g
s
.534 .567 .835 r
.78921 .3681 m .77703 .36809 L .77486 .37678 L p F P
0 g
s
.534 .567 .835 r
.77486 .37678 m .79387 .37801 L .78921 .3681 L p F P
0 g
s
.985 .709 .403 r
.24606 .45458 m .24843 .45834 L .24842 .46657 L p F P
0 g
s
.596 .949 .892 r
.69495 .57931 m .68864 .58259 L .68426 .5828 L p F P
0 g
s
.751 .233 0 r
.44545 .45115 m .44728 .4532 L .45596 .45822 L p F P
0 g
s
.756 .241 0 r
.45295 .45967 m .46227 .46448 L .45596 .45822 L p F P
0 g
s
.756 .241 0 r
.45596 .45822 m .44728 .4532 L .45295 .45967 L p F P
0 g
s
.896 .499 .069 r
.25995 .49017 m .26146 .49504 L p .25419 .48108 L F P
0 g
s
.896 .499 .069 r
.25419 .48108 m .25468 .48173 L .25995 .49017 L p F P
0 g
s
0 0 .072 r
.79805 .48574 m .79071 .49553 L .79515 .48527 L p F P
0 g
s
0 0 .072 r
.80085 .47907 m .79805 .48574 L p .79515 .48527 L F P
0 g
s
0 0 .072 r
.79515 .48527 m .80127 .47705 L .80085 .47907 L p F P
0 g
s
0 .138 .629 r
.29386 .53516 m .29218 .53382 L .29839 .53962 L p F P
0 g
s
0 .138 .629 r
.29839 .53962 m .2999 .54082 L .29386 .53516 L p F P
0 g
s
.913 .819 .74 r
.24863 .41691 m .24515 .4096 L .25131 .39923 L p F P
0 g
s
.948 .821 .685 r
.24515 .4096 m .24863 .41691 L .24432 .42661 L p F P
0 g
s
0 .108 .614 r
.41033 .42249 m .41239 .42427 L .41836 .43039 L p F P
0 g
s
0 .108 .614 r
.41919 .43018 m .42525 .43627 L .41836 .43039 L p F P
0 g
s
0 .108 .614 r
.41836 .43039 m .41239 .42427 L .41919 .43018 L p F P
0 g
s
0 0 0 r
.59802 .4571 m .5979 .45724 L .59872 .45666 L closepath p F P
0 g
s
.591 .666 .89 r
.34557 .37486 m .34099 .37544 L .3395 .36736 L p F P
0 g
s
.027 0 .392 r
.81016 .45657 m .8045 .46596 L .80492 .45705 L p F P
0 g
s
.027 0 .392 r
.80492 .45705 m .81056 .44764 L .81016 .45657 L p F P
0 g
s
.311 .743 .97 r
.49447 .61399 m .49775 .61534 L p .47325 .61332 L F P
0 g
s
.311 .743 .97 r
.47325 .61332 m .48808 .61315 L .49447 .61399 L p F P
0 g
s
.324 .741 .977 r
.48808 .61315 m .47325 .61332 L .46777 .61073 L p F P
0 g
s
.16 .629 .929 r
.41889 .6022 m .42321 .60283 L .43473 .60655 L p F P
0 g
s
.297 .697 .975 r
.43765 .60395 m .42321 .60283 L .43473 .60655 L p F P
0 g
s
.297 .697 .975 r
.43473 .60655 m .44327 .60714 L .43765 .60395 L p F P
0 g
s
.532 .919 .807 r
.70833 .57179 m .69495 .57931 L .70628 .57229 L closepath p F P
0 g
s
.596 .949 .892 r
.70406 .57227 m .70628 .57229 L .69495 .57931 L p F P
0 g
s
.596 .949 .892 r
.68426 .5828 m .70406 .57227 L p .69495 .57931 L F P
0 g
s
0 .405 .83 r
.33309 .56567 m .32922 .56266 L .32832 .56225 L closepath p F P
0 g
s
.039 0 0 r
.59872 .45666 m .5979 .45724 L .59508 .46176 L p F P
0 g
s
.656 .216 .194 r
.50501 .47902 m .50809 .48108 L .50359 .48054 L closepath p F P
0 g
s
0 0 0 r
.61732 .44362 m .59872 .45666 L .61468 .4467 L closepath p F P
0 g
s
.039 0 0 r
.61272 .44899 m .61468 .4467 L .59872 .45666 L p F P
0 g
s
.039 0 0 r
.60488 .45531 m .61272 .44899 L p .59872 .45666 L F P
0 g
s
.039 0 0 r
.59508 .46176 m .60488 .45531 L p .59872 .45666 L F P
0 g
s
0 0 .256 r
.80229 .4755 m .80127 .47705 L .80172 .47023 L p F P
0 g
s
0 0 .256 r
.80172 .47023 m .8045 .46596 L .80229 .4755 L p F P
0 g
s
.329 .315 .692 r
.80477 .41577 m .80668 .41201 L .80896 .42033 L closepath p F P
0 g
s
0 0 0 r
.76919 .52463 m .76698 .52709 L .775 .51832 L closepath p F P
0 g
s
.466 .823 .554 r
.61817 .44293 m .61732 .44362 L .62104 .4405 L closepath p F P
0 g
s
.502 .9 .935 r
.63945 .59918 m .64013 .59925 L .62043 .60596 L p F P
0 g
s
.502 .9 .935 r
.62043 .60596 m .62028 .60594 L .63945 .59918 L p F P
0 g
s
.971 .799 .612 r
.24543 .44284 m .24162 .43575 L .24432 .42661 L p F P
0 g
s
.991 .771 .509 r
.24162 .43575 m .24543 .44284 L .24418 .45148 L p F P
0 g
s
.984 .76 .519 r
.24606 .45458 m .24418 .45148 L .24543 .44284 L p F P
0 g
s
.786 .842 .894 r
.71154 .37478 m .71911 .37016 L .71463 .36533 L p F P
0 g
s
.786 .842 .894 r
.71463 .36533 m .71369 .36597 L .71154 .37478 L p F P
0 g
s
.765 .87 .925 r
.69497 .37848 m .71369 .36597 L .71154 .37478 L p F P
0 g
s
0 .102 .577 r
.2999 .54082 m .3058 .54561 L .31239 .55124 L p F P
0 g
s
0 .127 .617 r
.3058 .54561 m .2999 .54082 L .29386 .53516 L p F P
0 g
s
.649 .68 .866 r
.74351 .36673 m .76379 .36095 L .76831 .36863 L p F P
0 g
s
.667 .701 .872 r
.76379 .36095 m .74351 .36673 L .73903 .36054 L p F P
0 g
s
.716 .754 .882 r
.71911 .37016 m .73903 .36054 L .74351 .36673 L p F P
0 g
s
.571 .906 .977 r
.63542 .59808 m .63945 .59918 L .62028 .60594 L p F P
0 g
s
.571 .906 .977 r
.62028 .60594 m .61563 .60475 L .63542 .59808 L p F P
0 g
s
.695 .195 .049 r
.47671 .46972 m .47515 .47024 L .47324 .46868 L closepath p F P
0 g
s
.212 0 .035 r
.59321 .46476 m .59508 .46176 L .57657 .46969 L p F P
0 g
s
.212 0 .035 r
.57518 .474 m .59321 .46476 L p .57657 .46969 L F P
0 g
s
.212 0 .035 r
.57657 .46969 m .57372 .47465 L .57518 .474 L p F P
0 g
s
0 .276 .743 r
.31472 .55117 m .32133 .5568 L .31239 .55124 L p F P
0 g
s
0 .276 .743 r
.31239 .55124 m .3058 .54561 L .31472 .55117 L p F P
0 g
s
.605 .941 .942 r
.66562 .59205 m .66449 .59192 L .67405 .58764 L closepath p F P
0 g
s
.183 .448 .876 r
.37969 .39447 m .38387 .40139 L .39375 .40602 L p F P
0 g
s
.119 .428 .87 r
.39821 .41278 m .39375 .40602 L .38387 .40139 L p F P
0 g
s
.791 .805 .864 r
.27206 .37712 m .27736 .37337 L .27513 .36544 L p F P
0 g
s
.791 .805 .864 r
.27513 .36544 m .26578 .37249 L .27206 .37712 L p F P
0 g
s
.83 .81 .831 r
.25845 .37978 m .26578 .37249 L .27206 .37712 L p F P
0 g
s
.83 .81 .831 r
.27206 .37712 m .26127 .38745 L .25845 .37978 L p F P
0 g
s
.423 .031 .188 r
.55409 .47801 m .57206 .47506 L .55311 .47995 L closepath p F P
0 g
s
.457 0 0 r
.43232 .44216 m .43957 .44779 L .43219 .442 L p F P
0 g
s
.457 0 0 r
.43219 .442 m .42525 .43627 L .43232 .44216 L p F P
0 g
s
.195 .638 .946 r
.41889 .6022 m .42321 .60283 L .41415 .59955 L closepath p F P
0 g
s
.478 .505 .807 r
.79159 .38747 m .79473 .37996 L .79864 .3893 L closepath p F P
0 g
s
.864 .823 .806 r
.25845 .37978 m .26127 .38745 L .2525 .39755 L p F P
0 g
s
.715 .186 0 r
.44545 .45115 m .44728 .4532 L .44038 .44829 L closepath p F P
0 g
s
.411 .421 .76 r
.80056 .40082 m .80195 .39783 L .80358 .4025 L closepath p F P
0 g
s
.19 .604 .944 r
.38309 .58807 m .37651 .58666 L .38551 .59129 L p F P
0 g
s
.19 .604 .944 r
.38551 .59129 m .38891 .59199 L .38309 .58807 L p F P
0 g
s
.759 .78 .87 r
.29095 .36457 m .27736 .37337 L .27513 .36544 L p F P
0 g
s
.734 .77 .882 r
.73903 .36054 m .71911 .37016 L .71463 .36533 L p F P
0 g
s
.694 .184 .02 r
.46869 .47076 m .46227 .46448 L .47324 .46868 L p F P
0 g
s
.694 .184 .02 r
.47044 .4714 m .46869 .47076 L p .47324 .46868 L F P
0 g
s
.694 .184 .02 r
.47324 .46868 m .47515 .47024 L .47044 .4714 L p F P
0 g
s
.341 .772 .97 r
.52108 .61564 m .5223 .61608 L p .49775 .61534 L F P
0 g
s
.341 .772 .97 r
.49775 .61534 m .50587 .61484 L .52108 .61564 L p F P
0 g
s
.37 .776 .983 r
.49775 .61534 m .50587 .61484 L .49447 .61399 L closepath p F P
0 g
s
.079 .516 .902 r
.35306 .57459 m .3467 .57249 L .35458 .57756 L p F P
0 g
s
.079 .516 .902 r
.35458 .57756 m .35898 .57899 L .35306 .57459 L p F P
0 g
s
.551 .123 .181 r
.55047 .48535 m .55311 .47995 L .53 .48216 L p F P
0 g
s
.551 .123 .181 r
.54162 .48615 m .55047 .48535 L p .53 .48216 L F P
0 g
s
.551 .123 .181 r
.53 .48216 m .52955 .48281 L .54162 .48615 L p F P
0 g
s
.605 .182 .214 r
.53 .48216 m .52955 .48281 L .52809 .48213 L closepath p F P
0 g
s
.604 .206 .261 r
.51646 .48682 m .50809 .48108 L .52809 .48213 L p F P
0 g
s
.604 .206 .261 r
.52702 .4873 m .51646 .48682 L p .52809 .48213 L F P
0 g
s
.604 .206 .261 r
.52809 .48213 m .52955 .48281 L .52702 .4873 L p F P
0 g
s
.525 .886 .978 r
.61563 .60475 m .59596 .61034 L .59104 .60905 L p F P
0 g
s
.472 .862 .974 r
.57144 .61354 m .59104 .60905 L .59596 .61034 L p F P
0 g
s
.476 .584 .883 r
.35808 .36799 m .33977 .36732 L .34557 .37486 L p F P
0 g
s
.476 .584 .883 r
.35965 .37031 m .35808 .36799 L p .34557 .37486 L F P
0 g
s
.476 .584 .883 r
.34557 .37486 m .36062 .37623 L .35965 .37031 L p F P
0 g
s
.591 .666 .89 r
.3395 .36736 m .33977 .36732 L .34557 .37486 L p F P
0 g
s
0 0 0 r
.79181 .49664 m .79805 .48574 L .79071 .49553 L p F P
0 g
s
0 0 0 r
.78544 .50503 m .79181 .49664 L p .79071 .49553 L F P
0 g
s
0 0 0 r
.79071 .49553 m .78588 .50374 L .78544 .50503 L p F P
0 g
s
.986 .709 .389 r
.24418 .45148 m .24606 .45458 L .24785 .46567 L p F P
0 g
s
.985 .709 .403 r
.24842 .46657 m .24785 .46567 L .24606 .45458 L p F P
0 g
s
.962 .629 .291 r
.25412 .48056 m .25419 .48108 L .25468 .48173 L closepath p F P
0 g
s
.714 .98 .776 r
.6371 .42716 m .6367 .42731 L .63803 .42615 L closepath p F P
0 g
s
.587 .64 .87 r
.77703 .36809 m .76831 .36863 L .76379 .36095 L p F P
0 g
s
0 0 0 r
.62104 .4405 m .61732 .44362 L .61468 .4467 L p F P
0 g
s
.584 .942 .815 r
.72668 .56042 m .70833 .57179 L .70628 .57229 L p F P
0 g
s
.962 .631 .265 r
.24964 .47441 m .24857 .46754 L .25412 .48056 L p F P
0 g
s
.962 .631 .265 r
.25412 .48056 m .25419 .48108 L .24964 .47441 L p F P
0 g
s
.959 .625 .253 r
.24842 .46657 m .24857 .46754 L .25412 .48056 L p F P
0 g
s
.896 .499 .069 r
.26146 .49504 m .25657 .48855 L .25419 .48108 L p F P
0 g
s
.795 .362 0 r
.25657 .48855 m .26146 .49504 L .26497 .50217 L p F P
0 g
s
.82 .379 0 r
.27019 .50849 m .26497 .50217 L .26146 .49504 L p F P
0 g
s
.864 .823 .806 r
.2525 .39755 m .25018 .39657 L p .25845 .37978 L F P
0 g
s
.894 .825 .772 r
.2525 .39755 m .25131 .39923 L .25018 .39657 L closepath p F P
0 g
s
.582 .909 .668 r
.6367 .42731 m .62104 .4405 L .63281 .4297 L closepath p F P
0 g
s
0 0 0 r
.63215 .43009 m .63281 .4297 L .62104 .4405 L p F P
0 g
s
0 0 0 r
.6206 .44133 m .63215 .43009 L p .62104 .4405 L F P
0 g
s
0 0 0 r
.61468 .4467 m .6206 .44133 L p .62104 .4405 L F P
0 g
s
.668 .201 0 r
.26497 .50217 m .27019 .50849 L .27485 .51528 L p F P
0 g
s
.704 .226 0 r
.28039 .52142 m .27485 .51528 L .27019 .50849 L p F P
0 g
s
0 .152 .673 r
.40709 .41786 m .4047 .41581 L .41033 .42249 L p F P
0 g
s
0 .152 .673 r
.41033 .42249 m .41239 .42427 L .40709 .41786 L p F P
0 g
s
.122 .444 .88 r
.39821 .41278 m .4047 .41581 L .41033 .42249 L p F P
0 g
s
.948 .821 .685 r
.24432 .42661 m .24084 .41931 L .24515 .4096 L p F P
0 g
s
.978 .811 .608 r
.24084 .41931 m .24432 .42661 L .24162 .43575 L p F P
0 g
s
.378 .803 .97 r
.54558 .61507 m .54687 .61548 L p .5223 .61608 L F P
0 g
s
.378 .803 .97 r
.5223 .61608 m .52662 .61558 L .54558 .61507 L p F P
0 g
s
.405 .806 .983 r
.5223 .61608 m .52662 .61558 L .52108 .61564 L closepath p F P
0 g
s
.89 .503 .051 r
.24964 .47441 m .25419 .48108 L .25657 .48855 L p F P
0 g
s
.658 .221 .2 r
.49971 .4848 m .51646 .48682 L .50809 .48108 L p F P
0 g
s
.658 .221 .2 r
.50809 .48108 m .50359 .48054 L .49971 .4848 L p F P
0 g
s
.92 .83 .74 r
.25018 .39657 m .25131 .39923 L .24515 .4096 L p F P
0 g
s
.485 .863 .981 r
.59004 .60877 m .59104 .60905 L .57144 .61354 L p F P
0 g
s
.485 .863 .981 r
.57144 .61354 m .56848 .6127 L .59004 .60877 L p F P
0 g
s
.419 .833 .97 r
.56848 .6127 m .57144 .61354 L p .54687 .61548 L F P
0 g
s
.558 .156 .236 r
.52955 .48281 m .54162 .48615 L .52702 .4873 L closepath p F P
0 g
s
.201 .464 .883 r
.4047 .41581 m .39821 .41278 L .39375 .40602 L p F P
0 g
s
.609 .941 .945 r
.67405 .58764 m .66449 .59192 L .65993 .59136 L p F P
0 g
s
.566 .926 .945 r
.64013 .59925 m .65993 .59136 L .66449 .59192 L p F P
0 g
s
.609 .921 .674 r
.63803 .42615 m .6367 .42731 L .63281 .4297 L p F P
0 g
s
.802 .998 .852 r
.64706 .41508 m .63803 .42615 L .65378 .41221 L p F P
0 g
s
.609 .921 .674 r
.63415 .4281 m .64706 .41508 L .63803 .42615 L p F P
0 g
s
.609 .921 .674 r
.63281 .4297 m .63415 .4281 L p .63803 .42615 L F P
0 g
s
.419 .833 .97 r
.54687 .61548 m .55395 .61426 L .56848 .6127 L p F P
0 g
s
.444 .836 .982 r
.54687 .61548 m .55395 .61426 L .54558 .61507 L closepath p F P
0 g
s
.695 .268 .228 r
.49936 .48475 m .49971 .4848 L .50359 .48054 L p F P
0 g
s
.695 .268 .228 r
.50359 .48054 m .49229 .47858 L .49936 .48475 L p F P
0 g
s
.555 .055 0 r
.29218 .53382 m .2863 .52784 L .28039 .52142 L p F P
0 g
s
0 0 .488 r
.27485 .51528 m .28039 .52142 L .2863 .52784 L p F P
0 g
s
.722 .195 0 r
.44491 .45436 m .45295 .45967 L .44728 .4532 L p F P
0 g
s
.722 .195 0 r
.43983 .44799 m .44491 .45436 L p .44728 .4532 L F P
0 g
s
.722 .195 0 r
.44728 .4532 m .44038 .44829 L .43983 .44799 L p F P
0 g
s
0 .418 .848 r
.32323 .55767 m .32133 .5568 L .32832 .56225 L p F P
0 g
s
0 .418 .848 r
.32832 .56225 m .32922 .56266 L .32323 .55767 L p F P
0 g
s
.802 .998 .849 r
.65607 .41018 m .65378 .41221 L .65524 .41025 L closepath p F P
0 g
s
.802 .998 .852 r
.65154 .41054 m .64706 .41508 L p .65378 .41221 L F P
0 g
s
.802 .998 .852 r
.65378 .41221 m .65524 .41025 L .65154 .41054 L p F P
0 g
s
.784 .997 .855 r
.6704 .39798 m .65607 .41018 L .65524 .41025 L p F P
0 g
s
.236 .461 .873 r
.37624 .38721 m .36953 .38464 L .37522 .3925 L p F P
0 g
s
.236 .461 .873 r
.37522 .3925 m .37969 .39447 L .37624 .38721 L p F P
0 g
s
.454 .592 .9 r
.36308 .38391 m .36953 .38464 L .37522 .3925 L p F P
0 g
s
.76 .282 .105 r
.47515 .47024 m .47948 .47504 L .47044 .4714 L closepath p F P
0 g
s
.13 .067 .511 r
.81306 .44313 m .81056 .44764 L .80908 .43937 L p F P
0 g
s
.13 .067 .511 r
.80908 .43937 m .81194 .4342 L .81306 .44313 L p F P
0 g
s
.956 .625 .232 r
.24785 .46567 m .24857 .46754 L .24842 .46657 L closepath p F P
0 g
s
.351 .366 .735 r
.80358 .4025 m .80885 .40666 L .80668 .41201 L closepath p F P
0 g
s
.235 .253 .675 r
.81429 .41353 m .80885 .40666 L .80668 .41201 L p F P
0 g
s
.235 .253 .675 r
.81056 .42251 m .81429 .41353 L p .80668 .41201 L F P
0 g
s
.235 .253 .675 r
.80668 .41201 m .80896 .42033 L .81056 .42251 L p F P
0 g
s
.324 .695 .98 r
.432 .60053 m .43765 .60395 L .42321 .60283 L p F P
0 g
s
.324 .695 .98 r
.41319 .59894 m .432 .60053 L p .42321 .60283 L F P
0 g
s
.324 .695 .98 r
.42321 .60283 m .41415 .59955 L .41319 .59894 L p F P
0 g
s
.189 .609 .945 r
.40243 .59456 m .38891 .59199 L .38309 .58807 L p F P
0 g
s
.319 .363 .75 r
.80195 .39783 m .80358 .4025 L .80885 .40666 L p F P
0 g
s
.427 .038 .196 r
.57206 .47506 m .55311 .47995 L .55047 .48535 L p F P
0 g
s
.689 .729 .881 r
.30355 .34991 m .28482 .35882 L .29095 .36457 L p F P
0 g
s
.689 .729 .881 r
.29095 .36457 m .30957 .35657 L .30355 .34991 L p F P
0 g
s
.759 .78 .87 r
.27513 .36544 m .28482 .35882 L .29095 .36457 L p F P
0 g
s
0 0 0 r
.78588 .50374 m .78418 .50649 L .78544 .50503 L closepath p F P
0 g
s
.602 .67 .888 r
.32806 .35208 m .30957 .35657 L .31553 .36333 L p F P
0 g
s
.602 .67 .888 r
.31553 .36333 m .33393 .35971 L .32806 .35208 L p F P
0 g
s
.84 .95 .89 r
.67547 .3936 m .6704 .39798 L .67302 .39271 L closepath p F P
0 g
s
.784 .997 .855 r
.67096 .39193 m .67302 .39271 L .6704 .39798 L p F P
0 g
s
.784 .997 .855 r
.66071 .40183 m .67096 .39193 L p .6704 .39798 L F P
0 g
s
.784 .997 .855 r
.65524 .41025 m .66071 .40183 L p .6704 .39798 L F P
0 g
s
0 .412 .842 r
.33924 .56723 m .32922 .56266 L .32323 .55767 L p F P
0 g
s
.412 .446 .785 r
.79864 .3893 m .80401 .39184 L .80195 .39783 L closepath p F P
0 g
s
.319 .363 .75 r
.81207 .39777 m .80401 .39184 L .80195 .39783 L p F P
0 g
s
.319 .363 .75 r
.80885 .40666 m .81207 .39777 L p .80195 .39783 L F P
0 g
s
.813 .952 .91 r
.68928 .38295 m .67547 .3936 L .67302 .39271 L p F P
0 g
s
0 0 .226 r
.80799 .46612 m .80229 .4755 L .8045 .46596 L p F P
0 g
s
0 0 .226 r
.8045 .46596 m .81016 .45657 L .80799 .46612 L p F P
0 g
s
.948 .613 .202 r
.24857 .46754 m .24964 .47441 L p .2442 .45971 L F P
0 g
s
.948 .613 .202 r
.2442 .45971 m .24785 .46567 L .24857 .46754 L p F P
0 g
s
.485 .598 .891 r
.36953 .38464 m .36308 .38391 L .36062 .37623 L p F P
0 g
s
.986 .709 .389 r
.24785 .46567 m .2442 .45971 L .24418 .45148 L p F P
0 g
s
0 .162 .663 r
.29386 .53516 m .29218 .53382 L .2863 .52784 L p F P
0 g
s
.298 .713 .974 r
.46481 .60924 m .46777 .61073 L p .44327 .60714 L F P
0 g
s
.298 .713 .974 r
.44327 .60714 m .45863 .60777 L .46481 .60924 L p F P
0 g
s
.313 .71 .979 r
.45863 .60777 m .44327 .60714 L .43765 .60395 L p F P
0 g
s
.485 .819 .999 r
.52662 .61558 m .52108 .61564 L .51702 .61372 L p F P
0 g
s
.437 .798 .996 r
.52108 .61564 m .51702 .61372 L .50587 .61484 L closepath p F P
0 g
s
0 0 0 r
.78288 .50919 m .775 .51832 L .78418 .50649 L p F P
0 g
s
0 0 0 r
.78418 .50649 m .78544 .50503 L .78288 .50919 L p F P
0 g
s
.278 .268 .669 r
.80896 .42033 m .81056 .42251 L .8099 .42395 L closepath p F P
0 g
s
.468 .822 .997 r
.54558 .61507 m .5417 .61337 L .52662 .61558 L closepath p F P
0 g
s
.485 .819 .999 r
.53649 .61095 m .5417 .61337 L .52662 .61558 L p F P
0 g
s
.485 .819 .999 r
.51702 .61372 m .53649 .61095 L p .52662 .61558 L F P
0 g
s
.048 .511 .889 r
.35898 .57899 m .36799 .58183 L .37651 .58666 L p F P
0 g
s
.075 .516 .9 r
.36799 .58183 m .35898 .57899 L .35306 .57459 L p F P
0 g
s
0 .152 .674 r
.40709 .41786 m .41239 .42427 L .41919 .43018 L p F P
0 g
s
.991 .771 .509 r
.24418 .45148 m .24033 .44441 L .24162 .43575 L p F P
0 g
s
.987 .716 .37 r
.24033 .44441 m .24418 .45148 L .2442 .45971 L p F P
0 g
s
.514 .842 .998 r
.55395 .61426 m .54558 .61507 L .5417 .61337 L p F P
0 g
s
.744 .314 .229 r
.48528 .48162 m .49936 .48475 L .49229 .47858 L p F P
0 g
s
.744 .314 .229 r
.49229 .47858 m .47948 .47504 L .48528 .48162 L p F P
0 g
s
.189 .165 .599 r
.81385 .43014 m .81194 .4342 L .8099 .42395 L p F P
0 g
s
.189 .165 .599 r
.8099 .42395 m .81056 .42251 L .81385 .43014 L p F P
0 g
s
.514 .891 .703 r
.72801 .55951 m .72668 .56042 L .72776 .55963 L closepath p F P
0 g
s
.584 .942 .815 r
.72387 .56024 m .72776 .55963 L .72668 .56042 L p F P
0 g
s
.584 .942 .815 r
.71509 .56583 m .72387 .56024 L p .72668 .56042 L F P
0 g
s
.584 .942 .815 r
.70628 .57229 m .71509 .56583 L p .72668 .56042 L F P
0 g
s
.826 .997 .843 r
.65524 .41025 m .65154 .41054 L .66071 .40183 L closepath p F P
0 g
s
.819 .886 .892 r
.69497 .37848 m .68928 .38295 L .69146 .3759 L closepath p F P
0 g
s
.813 .952 .91 r
.69046 .37516 m .69146 .3759 L .68928 .38295 L p F P
0 g
s
.813 .952 .91 r
.67534 .38823 m .69046 .37516 L p .68928 .38295 L F P
0 g
s
.813 .952 .91 r
.67302 .39271 m .67534 .38823 L p .68928 .38295 L F P
0 g
s
.864 .823 .806 r
.25018 .39657 m .24848 .39159 L .25845 .37978 L p F P
0 g
s
.907 .842 .769 r
.24848 .39159 m .25018 .39657 L .2459 .39535 L closepath p F P
0 g
s
.92 .83 .74 r
.242 .4021 m .2459 .39535 L .25018 .39657 L p F P
0 g
s
.92 .83 .74 r
.24515 .4096 m .242 .4021 L p .25018 .39657 L F P
0 g
s
.556 .933 .89 r
.68426 .5828 m .67405 .58764 L .68304 .58285 L closepath p F P
0 g
s
.609 .941 .945 r
.6798 .58232 m .68304 .58285 L .67405 .58764 L p F P
0 g
s
.609 .941 .945 r
.65993 .59136 m .6798 .58232 L p .67405 .58764 L F P
0 g
s
.585 .924 .717 r
.74362 .54636 m .74761 .54496 L .72801 .55951 L p F P
0 g
s
.585 .924 .717 r
.74032 .54889 m .74362 .54636 L p .72801 .55951 L F P
0 g
s
.585 .924 .717 r
.72801 .55951 m .72776 .55963 L .74032 .54889 L p F P
0 g
s
.457 .795 .999 r
.5117 .61105 m .51702 .61372 L .50587 .61484 L p F P
0 g
s
.457 .795 .999 r
.49236 .61291 m .5117 .61105 L p .50587 .61484 L F P
0 g
s
.457 .795 .999 r
.50587 .61484 m .49447 .61399 L .49236 .61291 L p F P
0 g
s
.764 .261 .009 r
.45866 .46619 m .46869 .47076 L .46227 .46448 L p F P
0 g
s
.764 .261 .009 r
.46227 .46448 m .45295 .45967 L .45866 .46619 L p F P
0 g
s
.39 .452 .804 r
.79473 .37996 m .79864 .3893 L .80401 .39184 L p F P
0 g
s
.787 .884 .916 r
.71369 .36597 m .69497 .37848 L .69146 .3759 L p F P
0 g
s
.955 .833 .683 r
.242 .4021 m .24515 .4096 L .24084 .41931 L p F P
0 g
s
0 0 0 r
.78363 .5082 m .78288 .50919 L .78544 .50503 L p F P
0 g
s
0 0 0 r
.78544 .50503 m .79181 .49664 L .78363 .5082 L p F P
0 g
s
.501 .845 .996 r
.56848 .6127 m .56639 .61185 L .55395 .61426 L closepath p F P
0 g
s
.514 .842 .998 r
.56128 .60962 m .56639 .61185 L .55395 .61426 L p F P
0 g
s
.514 .842 .998 r
.5417 .61337 m .56128 .60962 L p .55395 .61426 L F P
0 g
s
.671 .976 .848 r
.72776 .55963 m .72387 .56024 L .74032 .54889 L closepath p F P
0 g
s
.564 .926 .942 r
.65769 .59106 m .65993 .59136 L .64013 .59925 L p F P
0 g
s
.564 .926 .942 r
.64013 .59925 m .63945 .59918 L .65769 .59106 L p F P
0 g
s
0 .127 .617 r
.29386 .53516 m .29958 .53981 L .3058 .54561 L p F P
0 g
s
0 .151 .653 r
.29371 .53382 m .28781 .52904 L .29386 .53516 L p F P
0 g
s
0 .151 .653 r
.29386 .53516 m .29958 .53981 L .29371 .53382 L p F P
0 g
s
0 .162 .663 r
.2863 .52784 m .28781 .52904 L .29386 .53516 L p F P
0 g
s
.41 .773 .995 r
.49447 .61399 m .49236 .61291 L .48808 .61315 L closepath p F P
0 g
s
.204 .602 .947 r
.37725 .58386 m .36799 .58183 L .37651 .58666 L p F P
0 g
s
.204 .602 .947 r
.37651 .58666 m .38309 .58807 L .37725 .58386 L p F P
0 g
s
0 0 0 r
.78252 .50951 m .78288 .50919 L .775 .51832 L p F P
0 g
s
0 0 0 r
.77256 .52069 m .78252 .50951 L p .775 .51832 L F P
0 g
s
0 0 0 r
.775 .51832 m .76698 .52709 L .76602 .52817 L p F P
0 g
s
0 0 0 r
.76602 .52817 m .77256 .52069 L p .775 .51832 L F P
0 g
s
.587 .64 .87 r
.76379 .36095 m .7795 .35922 L .77703 .36809 L p F P
0 g
s
.552 .594 .85 r
.78459 .35892 m .7795 .35922 L .77703 .36809 L p F P
0 g
s
.552 .594 .85 r
.77703 .36809 m .78921 .3681 L .78459 .35892 L p F P
0 g
s
.667 .701 .872 r
.73903 .36054 m .75929 .35368 L .76379 .36095 L p F P
0 g
s
.684 .72 .876 r
.75929 .35368 m .73903 .36054 L .73454 .35462 L p F P
0 g
s
.734 .77 .882 r
.71463 .36533 m .73454 .35462 L .73903 .36054 L p F P
0 g
s
0 .294 .767 r
.30849 .54535 m .31472 .55117 L .3058 .54561 L p F P
0 g
s
0 .294 .767 r
.3058 .54561 m .29958 .53981 L .30849 .54535 L p F P
0 g
s
0 .119 .622 r
.42616 .4361 m .43232 .44216 L .42525 .43627 L p F P
0 g
s
0 .119 .622 r
.42525 .43627 m .41919 .43018 L .42616 .4361 L p F P
0 g
s
.165 .154 .599 r
.81763 .42116 m .81385 .43014 L .81056 .42251 L p F P
0 g
s
.165 .154 .599 r
.81056 .42251 m .81429 .41353 L .81763 .42116 L p F P
0 g
s
0 0 .044 r
.80127 .47705 m .80085 .47907 L .80229 .4755 L closepath p F P
0 g
s
.101 .517 .908 r
.34712 .56987 m .33924 .56723 L .3467 .57249 L p F P
0 g
s
.101 .517 .908 r
.3467 .57249 m .35306 .57459 L .34712 .56987 L p F P
0 g
s
.978 .811 .608 r
.24162 .43575 m .23812 .42847 L .24084 .41931 L p F P
0 g
s
.996 .782 .499 r
.23812 .42847 m .24162 .43575 L .24033 .44441 L p F P
0 g
s
.591 .665 .89 r
.33948 .36693 m .33977 .36732 L .3395 .36736 L closepath p F P
0 g
s
.663 .97 .905 r
.70628 .57229 m .70406 .57227 L .71509 .56583 L closepath p F P
0 g
s
.655 .961 .768 r
.74765 .54495 m .74761 .54496 L .74777 .54483 L closepath p F P
0 g
s
0 0 0 r
.76698 .52709 m .76318 .53101 L .76602 .52817 L closepath p F P
0 g
s
.284 .673 .972 r
.41415 .59955 m .41319 .59894 L .41237 .59886 L closepath p F P
0 g
s
.507 .629 .905 r
.33977 .36732 m .35808 .36799 L p .33667 .35971 L F P
0 g
s
.507 .629 .905 r
.33667 .35971 m .33948 .36693 L .33977 .36732 L p F P
0 g
s
.658 .962 .77 r
.74777 .54483 m .74761 .54496 L .74362 .54636 L p F P
0 g
s
.324 .741 .977 r
.46777 .61073 m .47264 .6107 L .48808 .61315 L p F P
0 g
s
.423 .772 .996 r
.48694 .60996 m .47264 .6107 L .48808 .61315 L p F P
0 g
s
.423 .772 .996 r
.48808 .61315 m .49236 .61291 L .48694 .60996 L p F P
0 g
s
.614 .922 .671 r
.75857 .53412 m .74777 .54483 L .76318 .53101 L p F P
0 g
s
.658 .962 .77 r
.74362 .54636 m .75857 .53412 L .74777 .54483 L p F P
0 g
s
.253 .472 .877 r
.37624 .38721 m .37969 .39447 L .39018 .39886 L p F P
0 g
s
.183 .448 .876 r
.39375 .40602 m .39018 .39886 L .37969 .39447 L p F P
0 g
s
.35 .743 .985 r
.46777 .61073 m .47264 .6107 L .46481 .60924 L closepath p F P
0 g
s
.614 .922 .671 r
.76322 .52982 m .75857 .53412 L p .76318 .53101 L F P
0 g
s
.614 .922 .671 r
.76318 .53101 m .76602 .52817 L .76322 .52982 L p F P
0 g
s
.508 .629 .905 r
.33393 .35971 m .33667 .35971 L .33948 .36693 L closepath p F P
0 g
s
.605 .643 .861 r
.7795 .35922 m .76379 .36095 L .75929 .35368 L p F P
0 g
s
.615 .921 .975 r
.6553 .59035 m .65769 .59106 L .63945 .59918 L p F P
0 g
s
.615 .921 .975 r
.63945 .59918 m .63542 .59808 L .6553 .59035 L p F P
0 g
s
.543 .862 .996 r
.58606 .60712 m .59004 .60877 L .56848 .6127 L p F P
0 g
s
.543 .862 .996 r
.56848 .6127 m .56639 .61185 L .58606 .60712 L p F P
0 g
s
.616 .956 .894 r
.69972 .5722 m .70406 .57227 L .68426 .5828 L p F P
0 g
s
.616 .956 .894 r
.69876 .57272 m .69972 .5722 L p .68426 .5828 L F P
0 g
s
.616 .956 .894 r
.68426 .5828 m .68304 .58285 L .69876 .57272 L p F P
0 g
s
.806 .82 .862 r
.26578 .37249 m .27513 .36544 L .27294 .35742 L p F P
0 g
s
.806 .82 .862 r
.27294 .35742 m .2594 .36832 L .26578 .37249 L p F P
0 g
s
.84 .819 .828 r
.2559 .37194 m .2594 .36832 L .26578 .37249 L p F P
0 g
s
.84 .819 .828 r
.26578 .37249 m .25845 .37978 L .2559 .37194 L p F P
0 g
s
.302 .673 .975 r
.40745 .59512 m .40243 .59456 L .41237 .59886 L p F P
0 g
s
.302 .673 .975 r
.41237 .59886 m .41319 .59894 L .40745 .59512 L p F P
0 g
s
.464 .512 .823 r
.79387 .37801 m .79517 .37836 L .79473 .37996 L closepath p F P
0 g
s
.39 .452 .804 r
.8067 .38304 m .79517 .37836 L .79473 .37996 L p F P
0 g
s
.39 .452 .804 r
.80401 .39184 m .8067 .38304 L p .79473 .37996 L F P
0 g
s
.536 0 0 r
.44038 .44829 m .43983 .44799 L .43957 .44779 L closepath p F P
0 g
s
0 0 .048 r
.8041 .47627 m .80799 .46612 L .80229 .4755 L p F P
0 g
s
0 0 .048 r
.80007 .48284 m .8041 .47627 L p .80229 .4755 L F P
0 g
s
0 0 .048 r
.80229 .4755 m .80085 .47907 L .80007 .48284 L p F P
0 g
s
.872 .832 .804 r
.2559 .37194 m .25845 .37978 L .24848 .39159 L p F P
0 g
s
0 0 0 r
.59508 .46176 m .59321 .46476 L .60488 .45531 L closepath p F P
0 g
s
.784 .831 .889 r
.71463 .36533 m .71369 .36597 L .71391 .36459 L closepath p F P
0 g
s
.787 .884 .916 r
.71013 .36072 m .71391 .36459 L .71369 .36597 L p F P
0 g
s
.787 .884 .916 r
.69236 .3738 m .71013 .36072 L p .71369 .36597 L F P
0 g
s
.787 .884 .916 r
.69146 .3759 m .69236 .3738 L p .71369 .36597 L F P
0 g
s
.307 .682 .977 r
.432 .60053 m .41319 .59894 L .40745 .59512 L p F P
0 g
s
0 .2 .724 r
.4025 .41113 m .39906 .40834 L .4047 .41581 L p F P
0 g
s
0 .2 .724 r
.4047 .41581 m .40709 .41786 L .4025 .41113 L p F P
0 g
s
.201 .464 .883 r
.39375 .40602 m .39906 .40834 L .4047 .41581 L p F P
0 g
s
.757 .826 .906 r
.73004 .34889 m .73454 .35462 L .71463 .36533 L p F P
0 g
s
.757 .826 .906 r
.71704 .35668 m .73004 .34889 L p .71463 .36533 L F P
0 g
s
.757 .826 .906 r
.71463 .36533 m .71391 .36459 L .71704 .35668 L p F P
0 g
s
.067 .024 .494 r
.81529 .43845 m .81306 .44313 L .81194 .4342 L p F P
0 g
s
.067 .024 .494 r
.81194 .4342 m .81385 .43014 L .81529 .43845 L p F P
0 g
s
.577 .906 .979 r
.63542 .59808 m .61563 .60475 L .61079 .60346 L p F P
0 g
s
.525 .886 .978 r
.59104 .60905 m .61079 .60346 L .61563 .60475 L p F P
0 g
s
0 .136 .634 r
.43232 .44216 m .4342 .4437 L .42856 .4381 L p F P
0 g
s
.703 .209 0 r
.4342 .4437 m .42856 .4381 L p .43236 .44238 L F P
0 g
s
.703 .209 0 r
.43791 .44864 m .4342 .4437 L p .43236 .44238 L F P
0 g
s
.44 0 0 r
.4342 .4437 m .43232 .44216 L .43558 .44469 L p F P
0 g
s
.44 0 0 r
.43558 .44469 m .43957 .44779 L p .4342 .4437 L F P
0 g
s
.44 0 0 r
.43957 .44779 m .43983 .44799 L .4342 .4437 L p F P
0 g
s
.304 .482 .869 r
.37371 .37955 m .36381 .37644 L .36953 .38464 L p F P
0 g
s
.304 .482 .869 r
.36953 .38464 m .37624 .38721 L .37371 .37955 L p F P
0 g
s
.485 .598 .891 r
.36062 .37623 m .36381 .37644 L .36953 .38464 L p F P
0 g
s
.4 0 .136 r
.57372 .47465 m .57363 .47481 L .57206 .47506 L closepath p F P
0 g
s
.427 .038 .196 r
.57132 .48023 m .57363 .47481 L .57206 .47506 L p F P
0 g
s
.427 .038 .196 r
.55047 .48535 m .57132 .48023 L p .57206 .47506 L F P
0 g
s
.259 .275 .686 r
.81762 .40461 m .81429 .41353 L .80885 .40666 L p F P
0 g
s
.259 .275 .686 r
.80885 .40666 m .81207 .39777 L .81762 .40461 L p F P
0 g
s
.764 .29 .117 r
.47384 .47756 m .48528 .48162 L .47948 .47504 L p F P
0 g
s
.764 .29 .117 r
.46958 .47163 m .47384 .47756 L p .47948 .47504 L F P
0 g
s
.764 .29 .117 r
.47948 .47504 m .47044 .4714 L .46958 .47163 L p F P
0 g
s
.477 .534 .836 r
.79517 .37836 m .79387 .37801 L .78921 .3681 L p F P
0 g
s
0 0 .373 r
.81333 .45086 m .81016 .45657 L .81056 .44764 L p F P
0 g
s
0 0 .373 r
.81056 .44764 m .81306 .44313 L .81333 .45086 L p F P
0 g
s
.89 .503 .051 r
.25657 .48855 m .25201 .48188 L .24964 .47441 L p F P
0 g
s
.763 .34 0 r
.25201 .48188 m .25657 .48855 L .26007 .49568 L p F P
0 g
s
.795 .362 0 r
.26497 .50217 m .26007 .49568 L .25657 .48855 L p F P
0 g
s
.756 .249 0 r
.44491 .45436 m .43983 .44799 L .4342 .4437 L p F P
0 g
s
.769 .787 .867 r
.28482 .35882 m .27513 .36544 L .27294 .35742 L p F P
0 g
s
.625 .173 0 r
.26007 .49568 m .26497 .50217 L .26963 .50896 L p F P
0 g
s
.668 .201 0 r
.27485 .51528 m .26963 .50896 L .26497 .50217 L p F P
0 g
s
.835 .949 .894 r
.67302 .39271 m .67096 .39193 L .67534 .38823 L closepath p F P
0 g
s
0 .425 .859 r
.31722 .55231 m .31472 .55117 L .32133 .5568 L p F P
0 g
s
0 .425 .859 r
.32133 .5568 m .32323 .55767 L .31722 .55231 L p F P
0 g
s
.217 0 .044 r
.57372 .47465 m .57363 .47481 L .57518 .474 L closepath p F P
0 g
s
.274 .483 .88 r
.39906 .40834 m .39375 .40602 L .39018 .39886 L p F P
0 g
s
.445 .788 .998 r
.5117 .61105 m .49236 .61291 L .48694 .60996 L p F P
0 g
s
.948 .613 .202 r
.24964 .47441 m .24541 .46755 L .2442 .45971 L p F P
0 g
s
.87 .492 .01 r
.24541 .46755 m .24964 .47441 L .25201 .48188 L p F P
0 g
s
.308 0 .169 r
.57518 .474 m .57363 .47481 L .57132 .48023 L p F P
0 g
s
0 0 .06 r
.80085 .47907 m .79805 .48574 L .80007 .48284 L closepath p F P
0 g
s
0 0 .531 r
.26963 .50896 m .27485 .51528 L .28077 .52169 L p F P
0 g
s
0 0 .488 r
.2863 .52784 m .28077 .52169 L .27485 .51528 L p F P
0 g
s
.477 .534 .836 r
.78921 .3681 m .79711 .36974 L .79517 .37836 L p F P
0 g
s
.423 .479 .813 r
.80915 .37424 m .8067 .38304 L .79517 .37836 L p F P
0 g
s
.423 .479 .813 r
.79517 .37836 m .79711 .36974 L .80915 .37424 L p F P
0 g
s
0 0 0 r
.61468 .4467 m .61272 .44899 L .6206 .44133 L closepath p F P
0 g
s
.756 .826 .906 r
.71391 .36459 m .71013 .36072 L .71704 .35668 L closepath p F P
0 g
s
.955 .833 .683 r
.24084 .41931 m .23769 .41183 L .242 .4021 L p F P
0 g
s
.985 .823 .602 r
.23769 .41183 m .24084 .41931 L .23812 .42847 L p F P
0 g
s
.271 0 .116 r
.59321 .46476 m .57518 .474 L .59229 .46669 L closepath p F P
0 g
s
.308 0 .169 r
.58981 .47208 m .59229 .46669 L .57518 .474 L p F P
0 g
s
.308 0 .169 r
.57132 .48023 m .58981 .47208 L p .57518 .474 L F P
0 g
s
.346 .383 .757 r
.815 .38889 m .81207 .39777 L .80401 .39184 L p F P
0 g
s
.346 .383 .757 r
.80401 .39184 m .8067 .38304 L .815 .38889 L p F P
0 g
s
.62 .68 .885 r
.32214 .3445 m .30355 .34991 L .30957 .35657 L p F P
0 g
s
.62 .68 .885 r
.30957 .35657 m .32806 .35208 L .32214 .3445 L p F P
0 g
s
.439 .766 .997 r
.48147 .60682 m .48694 .60996 L .47264 .6107 L p F P
0 g
s
.439 .766 .997 r
.46225 .60773 m .48147 .60682 L p .47264 .6107 L F P
0 g
s
.439 .766 .997 r
.47264 .6107 m .46481 .60924 L .46225 .60773 L p F P
0 g
s
.911 .852 .771 r
.24616 .38369 m .24848 .39159 L .2459 .39535 L p F P
0 g
s
.872 .832 .804 r
.24848 .39159 m .24616 .38369 L .2559 .37194 L p F P
0 g
s
.56 .161 .242 r
.54162 .48615 m .52702 .4873 L .52429 .49224 L p F P
0 g
s
.648 .256 .289 r
.52702 .4873 m .52429 .49224 L .51646 .48682 L closepath p F P
0 g
s
.534 .886 .982 r
.61043 .60335 m .61079 .60346 L .59104 .60905 L p F P
0 g
s
.534 .886 .982 r
.59104 .60905 m .59004 .60877 L .61043 .60335 L p F P
0 g
s
.668 .942 .677 r
.76602 .52817 m .76322 .52982 L .77256 .52069 L closepath p F P
0 g
s
.987 .716 .37 r
.2442 .45971 m .24033 .45265 L .24033 .44441 L p F P
0 g
s
.945 .62 .188 r
.24033 .45265 m .2442 .45971 L .24541 .46755 L p F P
0 g
s
.777 .27 0 r
.45015 .46104 m .45866 .46619 L .45295 .45967 L p F P
0 g
s
.777 .27 0 r
.45295 .45967 m .44491 .45436 L .45015 .46104 L p F P
0 g
s
.661 .955 .946 r
.68304 .58285 m .6798 .58232 L .69876 .57272 L closepath p F P
0 g
s
.704 .739 .879 r
.29748 .34343 m .27862 .35332 L .28482 .35882 L p F P
0 g
s
.704 .739 .879 r
.28482 .35882 m .30355 .34991 L .29748 .34343 L p F P
0 g
s
.769 .787 .867 r
.27294 .35742 m .27862 .35332 L .28482 .35882 L p F P
0 g
s
.474 .814 .999 r
.53649 .61095 m .51702 .61372 L .5117 .61105 L p F P
0 g
s
.663 .23 .211 r
.52412 .49262 m .52429 .49224 L .51646 .48682 L p F P
0 g
s
.663 .23 .211 r
.50592 .49115 m .52412 .49262 L p .51646 .48682 L F P
0 g
s
.663 .23 .211 r
.49959 .48494 m .50592 .49115 L p .51646 .48682 L F P
0 g
s
.663 .23 .211 r
.51646 .48682 m .49971 .4848 L .49959 .48494 L p F P
0 g
s
0 .412 .842 r
.32323 .55767 m .33219 .56179 L .33924 .56723 L p F P
0 g
s
0 .421 .856 r
.33219 .56179 m .32323 .55767 L .31722 .55231 L p F P
0 g
s
0 .187 .695 r
.28781 .52904 m .2863 .52784 L .28077 .52169 L p F P
0 g
s
.189 .609 .945 r
.38309 .58807 m .39306 .59003 L .40243 .59456 L p F P
0 g
s
.21 .608 .95 r
.39306 .59003 m .38309 .58807 L .37725 .58386 L p F P
0 g
s
.911 .852 .771 r
.2459 .39535 m .2392 .39453 L p .24616 .38369 L F P
0 g
s
.93 .843 .736 r
.2459 .39535 m .242 .4021 L .2392 .39453 L closepath p F P
0 g
s
.545 .859 .997 r
.58606 .60712 m .56639 .61185 L .56128 .60962 L p F P
0 g
s
0 .201 .725 r
.4025 .41113 m .40709 .41786 L .41398 .42372 L p F P
0 g
s
0 .152 .674 r
.41919 .43018 m .41398 .42372 L .40709 .41786 L p F P
0 g
s
.509 .838 .999 r
.56128 .60962 m .5417 .61337 L .53649 .61095 L p F P
0 g
s
.562 .175 .266 r
.55047 .48535 m .54906 .48829 L .54162 .48615 L closepath p F P
0 g
s
.56 .161 .242 r
.54801 .49105 m .54906 .48829 L .54162 .48615 L p F P
0 g
s
.56 .161 .242 r
.525 .49258 m .54801 .49105 L p .54162 .48615 L F P
0 g
s
.56 .161 .242 r
.52429 .49224 m .525 .49258 L p .54162 .48615 L F P
0 g
s
.395 .745 .993 r
.46481 .60924 m .46225 .60773 L .45863 .60777 L closepath p F P
0 g
s
.075 .516 .9 r
.35306 .57459 m .35994 .57681 L .36799 .58183 L p F P
0 g
s
.219 .599 .949 r
.37136 .57936 m .35994 .57681 L .36799 .58183 L p F P
0 g
s
.219 .599 .949 r
.36799 .58183 m .37725 .58386 L .37136 .57936 L p F P
0 g
s
.488 .594 .885 r
.35965 .37031 m .36381 .37644 L .36062 .37623 L closepath p F P
0 g
s
.102 .519 .909 r
.35994 .57681 m .35306 .57459 L .34712 .56987 L p F P
0 g
s
0 0 0 r
.7981 .48763 m .79181 .49664 L .79805 .48574 L p F P
0 g
s
0 0 0 r
.79805 .48574 m .80007 .48284 L .7981 .48763 L p F P
0 g
s
.622 .945 .946 r
.67527 .58154 m .6798 .58232 L .65993 .59136 L p F P
0 g
s
.622 .945 .946 r
.67315 .58253 m .67527 .58154 L p .65993 .59136 L F P
0 g
s
.622 .945 .946 r
.65993 .59136 m .65769 .59106 L .67315 .58253 L p F P
0 g
s
.665 .97 .906 r
.71509 .56583 m .70406 .57227 L .69972 .5722 L p F P
0 g
s
.996 .782 .499 r
.24033 .44441 m .23681 .43715 L .23812 .42847 L p F P
0 g
s
.986 .721 .35 r
.23681 .43715 m .24033 .44441 L .24033 .45265 L p F P
0 g
s
.801 .884 .906 r
.69146 .3759 m .69046 .37516 L .69236 .3738 L closepath p F P
0 g
s
.581 .877 .993 r
.60588 .60141 m .61043 .60335 L .59004 .60877 L p F P
0 g
s
.581 .877 .993 r
.59004 .60877 m .58606 .60712 L .60588 .60141 L p F P
0 g
s
.313 .71 .979 r
.43765 .60395 m .44608 .60435 L .45863 .60777 L p F P
0 g
s
.329 .707 .982 r
.44608 .60435 m .43765 .60395 L .432 .60053 L p F P
0 g
s
.45 .063 .212 r
.56894 .48592 m .57132 .48023 L .55047 .48535 L p F P
0 g
s
.45 .063 .212 r
.56614 .48658 m .56894 .48592 L p .55047 .48535 L F P
0 g
s
.45 .063 .212 r
.55047 .48535 m .54906 .48829 L .56614 .48658 L p F P
0 g
s
0 .175 .685 r
.2882 .52766 m .28175 .52247 L .28781 .52904 L p F P
0 g
s
0 .175 .685 r
.28781 .52904 m .29371 .53382 L .2882 .52766 L p F P
0 g
s
0 .187 .695 r
.28077 .52169 m .28175 .52247 L .28781 .52904 L p F P
0 g
s
.734 .245 .077 r
.47044 .4714 m .46958 .47163 L .46869 .47076 L closepath p F P
0 g
s
.123 .518 .913 r
.34115 .56482 m .33219 .56179 L .33924 .56723 L p F P
0 g
s
.123 .518 .913 r
.33924 .56723 m .34712 .56987 L .34115 .56482 L p F P
0 g
s
0 .171 .692 r
.41398 .42372 m .41919 .43018 L .42616 .4361 L p F P
0 g
s
0 .31 .787 r
.29371 .53382 m .29958 .53981 L .30849 .54535 L p F P
0 g
s
.029 0 .484 r
.8191 .42948 m .81529 .43845 L .81385 .43014 L p F P
0 g
s
.029 0 .484 r
.81385 .43014 m .81763 .42116 L .8191 .42948 L p F P
0 g
s
.312 .668 .974 r
.40168 .59105 m .39306 .59003 L .40243 .59456 L p F P
0 g
s
.312 .668 .974 r
.40243 .59456 m .40745 .59512 L .40168 .59105 L p F P
0 g
s
.513 .62 .895 r
.33468 .35166 m .32806 .35208 L .33393 .35971 L p F P
0 g
s
.513 .62 .895 r
.33393 .35971 m .33667 .35971 L .33468 .35166 L p F P
0 g
s
.697 .273 .237 r
.49971 .4848 m .49959 .48494 L .49936 .48475 L closepath p F P
0 g
s
.695 .276 .247 r
.49109 .48827 m .48528 .48162 L .49936 .48475 L p F P
0 g
s
.695 .276 .247 r
.49597 .48932 m .49109 .48827 L p .49936 .48475 L F P
0 g
s
.695 .276 .247 r
.49936 .48475 m .49959 .48494 L .49597 .48932 L p F P
0 g
s
.493 .552 .845 r
.79711 .36974 m .78921 .3681 L .78459 .35892 L p F P
0 g
s
.684 .72 .876 r
.73454 .35462 m .75478 .34672 L .75929 .35368 L p F P
0 g
s
.7 .735 .878 r
.75478 .34672 m .73454 .35462 L .73004 .34889 L p F P
0 g
s
.696 .955 .691 r
.63281 .4297 m .63215 .43009 L .63415 .4281 L closepath p F P
0 g
s
.71 .295 .258 r
.49959 .48494 m .50592 .49115 L .49597 .48932 L closepath p F P
0 g
s
.733 .227 .023 r
.46395 .47218 m .45866 .46619 L .46869 .47076 L p F P
0 g
s
.733 .227 .023 r
.46869 .47076 m .46958 .47163 L .46395 .47218 L p F P
0 g
s
.408 .743 .993 r
.45668 .60427 m .44608 .60435 L .45863 .60777 L p F P
0 g
s
.408 .743 .993 r
.45863 .60777 m .46225 .60773 L .45668 .60427 L p F P
0 g
s
.832 .959 .893 r
.67534 .38823 m .67096 .39193 L .66641 .39052 L p F P
0 g
s
.877 .983 .831 r
.66071 .40183 m .67096 .39193 L .66641 .39052 L p F P
0 g
s
.962 .845 .681 r
.2392 .39453 m .242 .4021 L .23769 .41183 L p F P
0 g
s
.605 .643 .861 r
.78144 .35299 m .7795 .35922 L p .75929 .35368 L F P
0 g
s
.605 .643 .861 r
.75929 .35368 m .78002 .35037 L .78144 .35299 L p F P
0 g
s
.623 .662 .868 r
.78002 .35037 m .75929 .35368 L .75478 .34672 L p F P
0 g
s
0 0 .349 r
.815 .44736 m .81333 .45086 L .81306 .44313 L p F P
0 g
s
0 0 .349 r
.81306 .44313 m .81529 .43845 L .815 .44736 L p F P
0 g
s
.863 .946 .869 r
.67534 .38823 m .69046 .37516 L .68593 .37201 L p F P
0 g
s
.863 .946 .869 r
.68593 .37201 m .67871 .37895 L .67534 .38823 L p F P
0 g
s
.832 .959 .893 r
.66641 .39052 m .67871 .37895 L .67534 .38823 L p F P
0 g
s
.877 .983 .831 r
.66641 .39052 m .66472 .39236 L .66071 .40183 L p F P
0 g
s
.801 1 .82 r
.65304 .40498 m .66472 .39236 L .66071 .40183 L p F P
0 g
s
.801 1 .82 r
.64969 .41091 m .65304 .40498 L p .66071 .40183 L F P
0 g
s
.801 1 .82 r
.66071 .40183 m .65154 .41054 L .64969 .41091 L p F P
0 g
s
0 0 .186 r
.81278 .45746 m .80799 .46612 L .81016 .45657 L p F P
0 g
s
0 0 .186 r
.81016 .45657 m .81333 .45086 L .81278 .45746 L p F P
0 g
s
.825 1 .812 r
.65154 .41054 m .64706 .41508 L .64969 .41091 L closepath p F P
0 g
s
.374 .534 .887 r
.36381 .37644 m .37371 .37955 L p .35892 .3682 L F P
0 g
s
.374 .534 .887 r
.35892 .3682 m .35965 .37031 L .36381 .37644 L p F P
0 g
s
.802 .893 .909 r
.69236 .3738 m .69046 .37516 L .68593 .37201 L p F P
0 g
s
.826 1 .814 r
.64179 .41746 m .63415 .4281 L .64706 .41508 L p F P
0 g
s
.826 1 .814 r
.64699 .41142 m .64179 .41746 L p .64706 .41508 L F P
0 g
s
.826 1 .814 r
.64706 .41508 m .64969 .41091 L .64699 .41142 L p F P
0 g
s
0 .257 .768 r
.3987 .40405 m .39341 .40013 L .39906 .40834 L p F P
0 g
s
0 .257 .768 r
.39906 .40834 m .4025 .41113 L .3987 .40405 L p F P
0 g
s
.274 .483 .88 r
.39018 .39886 m .39341 .40013 L .39906 .40834 L p F P
0 g
s
.634 .964 .848 r
.72387 .56024 m .71509 .56583 L .72206 .56051 L closepath p F P
0 g
s
.665 .97 .906 r
.71963 .56029 m .72206 .56051 L .71509 .56583 L p F P
0 g
s
.665 .97 .906 r
.69972 .5722 m .71963 .56029 L p .71509 .56583 L F P
0 g
s
.826 .894 .89 r
.69236 .3738 m .71013 .36072 L .7056 .35621 L p F P
0 g
s
.826 .894 .89 r
.7056 .35621 m .69521 .36465 L .69236 .3738 L p F P
0 g
s
.802 .893 .909 r
.68593 .37201 m .69521 .36465 L .69236 .3738 L p F P
0 g
s
.111 0 .042 r
.60488 .45531 m .59321 .46476 L .59229 .46669 L p F P
0 g
s
.823 .387 .202 r
.47384 .47756 m .46958 .47163 L .46395 .47218 L p F P
0 g
s
.985 .823 .602 r
.23812 .42847 m .23496 .421 L .23769 .41183 L p F P
0 g
s
.999 .791 .486 r
.23496 .421 m .23812 .42847 L .23681 .43715 L p F P
0 g
s
0 .136 .634 r
.42856 .4381 m .42616 .4361 L .43232 .44216 L p F P
0 g
s
.381 .513 .865 r
.38767 .39125 m .37624 .38721 L .37371 .37955 L p F P
0 g
s
.253 .472 .877 r
.39018 .39886 m .38767 .39125 L .37624 .38721 L p F P
0 g
s
.555 .622 .873 r
.35232 .35939 m .33667 .35971 L .33468 .35166 L p F P
0 g
s
.507 .629 .905 r
.35808 .36799 m .35232 .35939 L .33667 .35971 L p F P
0 g
s
.588 .884 .586 r
.63119 .42973 m .64179 .41746 L .63415 .4281 L p F P
0 g
s
.588 .884 .586 r
.62889 .43281 m .63119 .42973 L p .63415 .4281 L F P
0 g
s
.588 .884 .586 r
.63415 .4281 m .63215 .43009 L .62889 .43281 L p F P
0 g
s
.612 .837 .453 r
.79048 .49856 m .78363 .5082 L .79181 .49664 L p F P
0 g
s
.612 .837 .453 r
.79181 .49664 m .7981 .48763 L .79788 .48791 L p F P
0 g
s
.612 .837 .453 r
.79788 .48791 m .79048 .49856 L p .79181 .49664 L F P
0 g
s
.567 .874 .58 r
.63215 .43009 m .6206 .44133 L .62889 .43281 L closepath p F P
0 g
s
0 0 0 r
.79847 .48702 m .7981 .48763 L .80007 .48284 L p F P
0 g
s
0 0 0 r
.80007 .48284 m .8041 .47627 L .79847 .48702 L p F P
0 g
s
0 0 0 r
.61272 .44899 m .60488 .45531 L .61147 .45091 L closepath p F P
0 g
s
.111 0 .042 r
.6085 .45552 m .61147 .45091 L .60488 .45531 L p F P
0 g
s
.111 0 .042 r
.59229 .46669 m .6085 .45552 L p .60488 .45531 L F P
0 g
s
.57 .619 .862 r
.7795 .35922 m .78144 .35299 L .78459 .35892 L closepath p F P
0 g
s
.031 .432 .868 r
.31118 .54659 m .30849 .54535 L .31472 .55117 L p F P
0 g
s
.031 .432 .868 r
.31472 .55117 m .31722 .55231 L .31118 .54659 L p F P
0 g
s
.626 .919 .977 r
.6553 .59035 m .63542 .59808 L .63065 .59672 L p F P
0 g
s
.577 .906 .979 r
.61079 .60346 m .63065 .59672 L .63542 .59808 L p F P
0 g
s
.425 .758 .995 r
.48147 .60682 m .46225 .60773 L .45668 .60427 L p F P
0 g
s
0 0 0 r
.62758 .4339 m .62889 .43281 L .6206 .44133 L p F P
0 g
s
0 0 0 r
.6204 .44208 m .62758 .4339 L p .6206 .44133 L F P
0 g
s
0 0 0 r
.61147 .45091 m .6204 .44208 L p .6206 .44133 L F P
0 g
s
0 0 0 r
.6206 .44133 m .61272 .44899 L .61147 .45091 L p F P
0 g
s
.672 .976 .848 r
.74032 .54889 m .72387 .56024 L .72206 .56051 L p F P
0 g
s
.142 .142 .598 r
.821 .41225 m .81763 .42116 L .81429 .41353 L p F P
0 g
s
.142 .142 .598 r
.81429 .41353 m .81762 .40461 L .821 .41225 L p F P
0 g
s
.801 .806 .855 r
.2594 .36832 m .25403 .36531 L p .27088 .34929 L F P
0 g
s
.801 .806 .855 r
.27088 .34929 m .27294 .35742 L .2594 .36832 L p F P
0 g
s
.85 .829 .826 r
.2594 .36832 m .2559 .37194 L .25403 .36531 L closepath p F P
0 g
s
.763 .34 0 r
.26007 .49568 m .25552 .48901 L .25201 .48188 L p F P
0 g
s
.625 .173 0 r
.26963 .50896 m .26476 .50246 L .26007 .49568 L p F P
0 g
s
0 0 .407 r
.25552 .48901 m .26007 .49568 L .26476 .50246 L p F P
0 g
s
.87 .492 .01 r
.25201 .48188 m .24778 .47503 L .24541 .46755 L p F P
0 g
s
.723 .315 0 r
.24778 .47503 m .25201 .48188 L .25552 .48901 L p F P
0 g
s
.307 .682 .977 r
.42961 .599 m .432 .60053 L p .40745 .59512 L F P
0 g
s
.307 .682 .977 r
.40745 .59512 m .42349 .59659 L .42961 .599 L p F P
0 g
s
.322 .678 .977 r
.42349 .59659 m .40745 .59512 L .40168 .59105 L p F P
0 g
s
.756 .249 0 r
.4342 .4437 m .43791 .44864 L .44491 .45436 L p F P
0 g
s
.764 .26 0 r
.44289 .4554 m .45015 .46104 L .44491 .45436 L p F P
0 g
s
.764 .26 0 r
.44491 .45436 m .43791 .44864 L .44289 .4554 L p F P
0 g
s
.879 .841 .804 r
.25403 .36531 m .2559 .37194 L .24616 .38369 L p F P
0 g
s
.655 .902 .572 r
.78288 .50919 m .78252 .50951 L .78363 .5082 L closepath p F P
0 g
s
.757 .832 .909 r
.71704 .35668 m .71013 .36072 L .7056 .35621 L p F P
0 g
s
.783 .363 .251 r
.4787 .48451 m .49109 .48827 L .48528 .48162 L p F P
0 g
s
.783 .363 .251 r
.48528 .48162 m .47384 .47756 L .4787 .48451 L p F P
0 g
s
.637 .691 .883 r
.31617 .33703 m .29748 .34343 L .30355 .34991 L p F P
0 g
s
.637 .691 .883 r
.30355 .34991 m .32214 .3445 L .31617 .33703 L p F P
0 g
s
0 .045 .587 r
.27558 .51536 m .26963 .50896 L .26476 .50246 L p F P
0 g
s
0 0 .531 r
.28077 .52169 m .27558 .51536 L .26963 .50896 L p F P
0 g
s
.945 .62 .188 r
.24541 .46755 m .24153 .4605 L .24033 .45265 L p F P
0 g
s
.844 .476 0 r
.24153 .4605 m .24541 .46755 L .24778 .47503 L p F P
0 g
s
.339 .502 .873 r
.39341 .40013 m .39018 .39886 L .38767 .39125 L p F P
0 g
s
.654 .931 .971 r
.65769 .59106 m .6553 .59035 L .67315 .58253 L closepath p F P
0 g
s
.78 .794 .864 r
.27862 .35332 m .27294 .35742 L .27088 .34929 L p F P
0 g
s
.475 .117 .278 r
.54906 .48829 m .56614 .48658 L .54801 .49105 L closepath p F P
0 g
s
.656 .902 .572 r
.78048 .51075 m .79048 .49856 L .78363 .5082 L p F P
0 g
s
.656 .902 .572 r
.77944 .51222 m .78048 .51075 L p .78363 .5082 L F P
0 g
s
.656 .902 .572 r
.78363 .5082 m .78252 .50951 L .77944 .51222 L p F P
0 g
s
.329 .707 .982 r
.432 .60053 m .43428 .60065 L .44608 .60435 L p F P
0 g
s
.414 .737 .992 r
.45108 .60059 m .43428 .60065 L .44608 .60435 L p F P
0 g
s
.414 .737 .992 r
.44608 .60435 m .45668 .60427 L .45108 .60059 L p F P
0 g
s
.102 .519 .909 r
.34712 .56987 m .35235 .57158 L .35994 .57681 L p F P
0 g
s
.235 .596 .95 r
.36545 .57456 m .35235 .57158 L .35994 .57681 L p F P
0 g
s
.235 .596 .95 r
.35994 .57681 m .37136 .57936 L .36545 .57456 L p F P
0 g
s
.663 .954 .948 r
.69876 .57272 m .6798 .58232 L .67527 .58154 L p F P
0 g
s
.629 .891 .568 r
.78252 .50951 m .77256 .52069 L .77944 .51222 L closepath p F P
0 g
s
.962 .845 .681 r
.23769 .41183 m .23487 .40415 L p .2392 .39453 L F P
0 g
s
.99 .835 .595 r
.23487 .40415 m .23769 .41183 L .23496 .421 L p F P
0 g
s
.445 .788 .998 r
.48694 .60996 m .50633 .60822 L .5117 .61105 L p F P
0 g
s
.457 .783 .998 r
.50633 .60822 m .48694 .60996 L .48147 .60682 L p F P
0 g
s
0 .212 .724 r
.28175 .52247 m .28077 .52169 L .27558 .51536 L p F P
0 g
s
0 .421 .856 r
.31722 .55231 m .32555 .55616 L .33219 .56179 L p F P
0 g
s
.028 .431 .867 r
.32555 .55616 m .31722 .55231 L .31118 .54659 L p F P
0 g
s
.034 0 .014 r
.6081 .45616 m .6085 .45552 L .59229 .46669 L p F P
0 g
s
.034 0 .014 r
.59593 .46781 m .6081 .45616 L p .59229 .46669 L F P
0 g
s
.034 0 .014 r
.59229 .46669 m .58981 .47208 L .59593 .46781 L p F P
0 g
s
.776 .824 .89 r
.71704 .35668 m .73004 .34889 L .72551 .34329 L p F P
0 g
s
.776 .824 .89 r
.72551 .34329 m .71833 .34802 L .71704 .35668 L p F P
0 g
s
.757 .832 .909 r
.7056 .35621 m .71833 .34802 L .71704 .35668 L p F P
0 g
s
.72 .752 .877 r
.29134 .33719 m .27234 .34817 L .27862 .35332 L p F P
0 g
s
.72 .752 .877 r
.27862 .35332 m .29748 .34343 L .29134 .33719 L p F P
0 g
s
.78 .794 .864 r
.27088 .34929 m .27234 .34817 L .27862 .35332 L p F P
0 g
s
.583 .905 .981 r
.62968 .59643 m .63065 .59672 L .61079 .60346 L p F P
0 g
s
.583 .905 .981 r
.61079 .60346 m .61043 .60335 L .62968 .59643 L p F P
0 g
s
.493 .552 .845 r
.78459 .35892 m .79885 .36111 L .79711 .36974 L p F P
0 g
s
.478 .57 .869 r
.78144 .35299 m .78459 .35892 L .79885 .36111 L p F P
0 g
s
.374 .534 .887 r
.35808 .36799 m .35892 .3682 L .35965 .37031 L closepath p F P
0 g
s
.286 0 .164 r
.58849 .475 m .58981 .47208 L .57132 .48023 L p F P
0 g
s
.286 0 .164 r
.57137 .48482 m .58849 .475 L p .57132 .48023 L F P
0 g
s
.286 0 .164 r
.57132 .48023 m .56894 .48592 L .57137 .48482 L p F P
0 g
s
.264 .289 .7 r
.81909 .4002 m .81762 .40461 L .81207 .39777 L p F P
0 g
s
.264 .289 .7 r
.81627 .39032 m .81909 .4002 L p .81207 .39777 L F P
0 g
s
.264 .289 .7 r
.81207 .39777 m .815 .38889 L .81627 .39032 L p F P
0 g
s
.638 .955 .769 r
.74362 .54636 m .74032 .54889 L .74282 .54665 L closepath p F P
0 g
s
.672 .976 .848 r
.73952 .5468 m .74282 .54665 L .74032 .54889 L p F P
0 g
s
.672 .976 .848 r
.72918 .55413 m .73952 .5468 L p .74032 .54889 L F P
0 g
s
.672 .976 .848 r
.72206 .56051 m .72918 .55413 L p .74032 .54889 L F P
0 g
s
.986 .721 .35 r
.24033 .45265 m .23679 .44541 L .23681 .43715 L p F P
0 g
s
.93 .614 .154 r
.23679 .44541 m .24033 .45265 L .24153 .4605 L p F P
0 g
s
.21 .608 .95 r
.37725 .58386 m .38424 .58527 L .39306 .59003 L p F P
0 g
s
.321 .662 .973 r
.39587 .58671 m .38424 .58527 L .39306 .59003 L p F P
0 g
s
.321 .662 .973 r
.39306 .59003 m .40168 .59105 L .39587 .58671 L p F P
0 g
s
.759 .25 0 r
.45544 .46776 m .45015 .46104 L .45866 .46619 L p F P
0 g
s
.759 .25 0 r
.46315 .47205 m .45544 .46776 L p .45866 .46619 L F P
0 g
s
.759 .25 0 r
.45866 .46619 m .46395 .47218 L .46315 .47205 L p F P
0 g
s
.673 .967 .771 r
.75857 .53412 m .74362 .54636 L .74282 .54665 L p F P
0 g
s
.879 .841 .804 r
.24616 .38369 m .2441 .37561 L p .25403 .36531 L F P
0 g
s
.924 .863 .762 r
.2441 .37561 m .24616 .38369 L .23917 .39441 L p F P
0 g
s
.911 .852 .771 r
.2392 .39453 m .23917 .39441 L .24616 .38369 L p F P
0 g
s
0 0 0 r
.80925 .46703 m .8041 .47627 L .80799 .46612 L p F P
0 g
s
0 0 0 r
.8126 .45815 m .80925 .46703 L p .80799 .46612 L F P
0 g
s
0 0 0 r
.80799 .46612 m .81278 .45746 L .8126 .45815 L p F P
0 g
s
0 .26 .77 r
.3987 .40405 m .4025 .41113 L .40966 .41689 L p F P
0 g
s
0 .201 .725 r
.41398 .42372 m .40966 .41689 L .4025 .41113 L p F P
0 g
s
.44 .5 .824 r
.80974 .3718 m .80915 .37424 L .79711 .36974 L p F P
0 g
s
.44 .5 .824 r
.80626 .36341 m .80974 .3718 L p .79711 .36974 L F P
0 g
s
.44 .5 .824 r
.79711 .36974 m .79885 .36111 L .80626 .36341 L p F P
0 g
s
.23 .607 .952 r
.38424 .58527 m .37725 .58386 L .37136 .57936 L p F P
0 g
s
0 0 .325 r
.81885 .43841 m .815 .44736 L .81529 .43845 L p F P
0 g
s
0 0 .325 r
.81529 .43845 m .8191 .42948 L .81885 .43841 L p F P
0 g
s
.617 .889 .989 r
.62582 .59471 m .62968 .59643 L .61043 .60335 L p F P
0 g
s
.617 .889 .989 r
.61043 .60335 m .60588 .60141 L .62582 .59471 L p F P
0 g
s
.844 .999 .806 r
.64969 .41091 m .64699 .41142 L .65304 .40498 L closepath p F P
0 g
s
.668 .942 .677 r
.77886 .51245 m .77944 .51222 L .77256 .52069 L p F P
0 g
s
.668 .942 .677 r
.76741 .52394 m .77886 .51245 L p .77256 .52069 L F P
0 g
s
.668 .942 .677 r
.76193 .53058 m .76741 .52394 L p .77256 .52069 L F P
0 g
s
.668 .942 .677 r
.77256 .52069 m .76322 .52982 L .76193 .53058 L p F P
0 g
s
0 .199 .714 r
.28306 .5213 m .27569 .51544 L .28175 .52247 L p F P
0 g
s
0 .199 .714 r
.28175 .52247 m .2882 .52766 L .28306 .5213 L p F P
0 g
s
0 .212 .724 r
.27558 .51536 m .27569 .51544 L .28175 .52247 L p F P
0 g
s
.603 .226 .3 r
.52429 .49224 m .525 .49258 L .52412 .49262 L closepath p F P
0 g
s
.545 .627 .884 r
.33423 .34296 m .32214 .3445 L .32806 .35208 L p F P
0 g
s
.545 .627 .884 r
.32806 .35208 m .33468 .35166 L .33423 .34296 L p F P
0 g
s
.147 .52 .916 r
.33515 .55942 m .32555 .55616 L .33219 .56179 L p F P
0 g
s
.147 .52 .916 r
.33219 .56179 m .34115 .56482 L .33515 .55942 L p F P
0 g
s
.364 .407 .773 r
.8154 .38749 m .815 .38889 L .8067 .38304 L p F P
0 g
s
.364 .407 .773 r
.81113 .37544 m .8154 .38749 L p .8067 .38304 L F P
0 g
s
.364 .407 .773 r
.8067 .38304 m .80915 .37424 L .81113 .37544 L p F P
0 g
s
.636 .931 .674 r
.76322 .52982 m .75857 .53412 L .76193 .53058 L closepath p F P
0 g
s
.673 .967 .771 r
.7593 .53114 m .76193 .53058 L .75857 .53412 L p F P
0 g
s
.673 .967 .771 r
.75087 .53823 m .7593 .53114 L p .75857 .53412 L F P
0 g
s
.673 .967 .771 r
.74282 .54665 m .75087 .53823 L p .75857 .53412 L F P
0 g
s
.474 .814 .999 r
.5117 .61105 m .53122 .60839 L .53649 .61095 L p F P
0 g
s
.488 .809 1 r
.53122 .60839 m .5117 .61105 L .50633 .60822 L p F P
0 g
s
.129 .522 .915 r
.35235 .57158 m .34712 .56987 L .34115 .56482 L p F P
0 g
s
.585 .874 .994 r
.60588 .60141 m .58606 .60712 L .58103 .60492 L p F P
0 g
s
.545 .859 .997 r
.56128 .60962 m .58103 .60492 L .58606 .60712 L p F P
0 g
s
.386 .528 .876 r
.35694 .3602 m .35232 .35939 L .35808 .36799 L p F P
0 g
s
.386 .528 .876 r
.35808 .36799 m .35892 .3682 L .35694 .3602 L p F P
0 g
s
.607 .235 .311 r
.525 .49258 m .52412 .49262 L .52155 .4984 L p F P
0 g
s
.683 .317 .347 r
.51236 .49767 m .52155 .4984 L .52412 .49262 L p F P
0 g
s
.683 .317 .347 r
.52412 .49262 m .50592 .49115 L .51236 .49767 L p F P
0 g
s
.604 .248 .338 r
.54801 .49105 m .525 .49258 L .53535 .49782 L p F P
0 g
s
.607 .235 .311 r
.52155 .4984 m .53535 .49782 L .525 .49258 L p F P
0 g
s
0 .324 .804 r
.2882 .52766 m .29371 .53382 L .30263 .53936 L p F P
0 g
s
0 .31 .787 r
.30849 .54535 m .30263 .53936 L .29371 .53382 L p F P
0 g
s
0 .226 .745 r
.40966 .41689 m .41398 .42372 L .42105 .4296 L p F P
0 g
s
0 .171 .692 r
.42616 .4361 m .42105 .4296 L .41398 .42372 L p F P
0 g
s
.067 .314 .797 r
.39584 .39656 m .38776 .39128 L .39341 .40013 L p F P
0 g
s
.067 .314 .797 r
.39341 .40013 m .3987 .40405 L .39584 .39656 L p F P
0 g
s
.339 .502 .873 r
.38767 .39125 m .38776 .39128 L .39341 .40013 L p F P
0 g
s
.623 .662 .868 r
.75478 .34672 m .77546 .34234 L .78002 .35037 L p F P
0 g
s
.639 .681 .873 r
.77546 .34234 m .75478 .34672 L .75026 .34001 L p F P
0 g
s
.7 .735 .878 r
.73004 .34889 m .75026 .34001 L .75478 .34672 L p F P
0 g
s
0 0 0 r
.60957 .45446 m .6085 .45552 L .61147 .45091 L p F P
0 g
s
0 0 0 r
.61147 .45091 m .6204 .44208 L .60957 .45446 L p F P
0 g
s
.999 .791 .486 r
.23681 .43715 m .23364 .4297 L .23496 .421 L p F P
0 g
s
.981 .723 .325 r
.23364 .4297 m .23681 .43715 L .23679 .44541 L p F P
0 g
s
0 0 .158 r
.81307 .45687 m .81278 .45746 L .81333 .45086 L p F P
0 g
s
0 0 .158 r
.81333 .45086 m .815 .44736 L .81307 .45687 L p F P
0 g
s
.509 .838 .999 r
.53649 .61095 m .55614 .60727 L .56128 .60962 L p F P
0 g
s
.517 .834 .999 r
.55614 .60727 m .53649 .61095 L .53122 .60839 L p F P
0 g
s
.546 .857 .997 r
.58103 .60492 m .56128 .60962 L .55614 .60727 L p F P
0 g
s
.461 .542 .853 r
.37235 .37138 m .35892 .3682 L .35694 .3602 L p F P
0 g
s
.374 .534 .887 r
.37371 .37955 m .37235 .37138 L .35892 .3682 L p F P
0 g
s
.35 .706 .985 r
.432 .60053 m .43428 .60065 L .42961 .599 L closepath p F P
0 g
s
.721 .98 .913 r
.72206 .56051 m .71963 .56029 L .72918 .55413 L closepath p F P
0 g
s
.715 .748 .878 r
.75026 .34001 m .73004 .34889 L .72551 .34329 L p F P
0 g
s
.74 .992 .868 r
.74282 .54665 m .73952 .5468 L .75087 .53823 L closepath p F P
0 g
s
.823 .387 .202 r
.46395 .47218 m .46433 .47279 L .47384 .47756 L p F P
0 g
s
.827 .397 .218 r
.46856 .47996 m .4787 .48451 L .47384 .47756 L p F P
0 g
s
.827 .397 .218 r
.47384 .47756 m .46433 .47279 L .46856 .47996 L p F P
0 g
s
.713 .302 .267 r
.49656 .4951 m .51236 .49767 L .50592 .49115 L p F P
0 g
s
.713 .302 .267 r
.49407 .49172 m .49656 .4951 L p .50592 .49115 L F P
0 g
s
.713 .302 .267 r
.50592 .49115 m .49597 .48932 L .49407 .49172 L p F P
0 g
s
0 .201 .718 r
.42856 .4381 m .42616 .4361 L .42105 .4296 L p F P
0 g
s
.48 .127 .289 r
.56614 .48658 m .54801 .49105 L .5458 .49713 L p F P
0 g
s
.604 .248 .338 r
.53535 .49782 m .5458 .49713 L .54801 .49105 L p F P
0 g
s
.955 .862 .708 r
.23917 .39441 m .2392 .39453 L .2391 .39455 L closepath p F P
0 g
s
.962 .845 .681 r
.23487 .40415 m .2391 .39455 L .2392 .39453 L p F P
0 g
s
.924 .863 .762 r
.23917 .39441 m .2372 .38632 L .2441 .37561 L p F P
0 g
s
.96 .874 .706 r
.2372 .38632 m .23917 .39441 L .2391 .39455 L p F P
0 g
s
.96 .874 .706 r
.2391 .39455 m .23268 .39718 L p .2372 .38632 L F P
0 g
s
.969 .858 .676 r
.2391 .39455 m .23487 .40415 L .23268 .39718 L closepath p F P
0 g
s
.535 .606 .871 r
.78002 .35037 m .78162 .3504 L .78144 .35299 L closepath p F P
0 g
s
.478 .57 .869 r
.80047 .35245 m .78162 .3504 L .78144 .35299 L p F P
0 g
s
.478 .57 .869 r
.79885 .36111 m .80047 .35245 L p .78144 .35299 L F P
0 g
s
.658 .929 .972 r
.67315 .58253 m .6553 .59035 L .65062 .58887 L p F P
0 g
s
.626 .919 .977 r
.63065 .59672 m .65062 .58887 L .6553 .59035 L p F P
0 g
s
.434 .731 .989 r
.44543 .59669 m .45108 .60059 L .43428 .60065 L p F P
0 g
s
.434 .731 .989 r
.4263 .59668 m .44543 .59669 L p .43428 .60065 L F P
0 g
s
.434 .731 .989 r
.43428 .60065 m .42961 .599 L .4263 .59668 L p F P
0 g
s
.063 .439 .876 r
.31118 .54659 m .30849 .54535 L .30263 .53936 L p F P
0 g
s
.639 .962 .912 r
.69972 .5722 m .69876 .57272 L .69955 .5722 L closepath p F P
0 g
s
.663 .954 .948 r
.69528 .57121 m .69955 .5722 L .69876 .57272 L p F P
0 g
s
.663 .954 .948 r
.67527 .58154 m .69528 .57121 L p .69876 .57272 L F P
0 g
s
0 0 0 r
.80371 .47778 m .79847 .48702 L .8041 .47627 L p F P
0 g
s
0 0 0 r
.8041 .47627 m .80925 .46703 L .80371 .47778 L p F P
0 g
s
0 0 .471 r
.82246 .42058 m .8191 .42948 L .81763 .42116 L p F P
0 g
s
0 0 .471 r
.81763 .42116 m .821 .41225 L .82246 .42058 L p F P
0 g
s
.703 .209 0 r
.42856 .4381 m .43183 .44254 L .43791 .44864 L p F P
0 g
s
.714 .222 0 r
.43673 .44933 m .44289 .4554 L .43791 .44864 L p F P
0 g
s
.714 .222 0 r
.43791 .44864 m .43183 .44254 L .43673 .44933 L p F P
0 g
s
.687 .975 .908 r
.71532 .55985 m .71963 .56029 L .69972 .5722 L p F P
0 g
s
.687 .975 .908 r
.71402 .56064 m .71532 .55985 L p .69972 .5722 L F P
0 g
s
.687 .975 .908 r
.69972 .5722 m .69955 .5722 L .71402 .56064 L p F P
0 g
s
.99 .835 .595 r
.23496 .421 m .23214 .41334 L .23487 .40415 L p F P
0 g
s
.999 .799 .47 r
.23214 .41334 m .23496 .421 L .23364 .4297 L p F P
0 g
s
.429 .53 .859 r
.38211 .38195 m .37371 .37955 L .37235 .37138 L p F P
0 g
s
.381 .513 .865 r
.38763 .39106 m .38767 .39125 L p .37371 .37955 L F P
0 g
s
.381 .513 .865 r
.37371 .37955 m .38211 .38195 L .38763 .39106 L p F P
0 g
s
.71 .96 .945 r
.69955 .5722 m .69528 .57121 L .71402 .56064 L closepath p F P
0 g
s
.579 .634 .87 r
.34653 .35072 m .33468 .35166 L .33423 .34296 L p F P
0 g
s
.555 .622 .873 r
.33468 .35166 m .34653 .35072 L .35232 .35939 L p F P
0 g
s
.821 .896 .895 r
.69521 .36465 m .68593 .37201 L .68135 .36887 L p F P
0 g
s
.88 .916 .847 r
.67871 .37895 m .68593 .37201 L .68135 .36887 L p F P
0 g
s
.732 .327 .281 r
.49597 .48932 m .49407 .49172 L .49109 .48827 L closepath p F P
0 g
s
.801 .806 .855 r
.25403 .36531 m .25382 .36385 L .27088 .34929 L p F P
0 g
s
.849 .846 .84 r
.25382 .36385 m .25403 .36531 L .2529 .36476 L closepath p F P
0 g
s
.879 .841 .804 r
.2441 .37561 m .2529 .36476 L .25403 .36531 L p F P
0 g
s
.755 .993 .809 r
.76193 .53058 m .7593 .53114 L .76741 .52394 L closepath p F P
0 g
s
.88 .916 .847 r
.68135 .36887 m .68 .37031 L .67871 .37895 L p F P
0 g
s
.856 .962 .872 r
.66776 .38315 m .68 .37031 L .67871 .37895 L p F P
0 g
s
.856 .962 .872 r
.66533 .39022 m .66776 .38315 L p .67871 .37895 L F P
0 g
s
.856 .962 .872 r
.67871 .37895 m .66641 .39052 L .66533 .39022 L p F P
0 g
s
.656 .704 .883 r
.31015 .32976 m .29134 .33719 L .29748 .34343 L p F P
0 g
s
.656 .704 .883 r
.29748 .34343 m .31617 .33703 L .31015 .32976 L p F P
0 g
s
.548 .624 .879 r
.78162 .3504 m .78002 .35037 L .77546 .34234 L p F P
0 g
s
.723 .315 0 r
.25552 .48901 m .25131 .48216 L .24778 .47503 L p F P
0 g
s
0 0 .454 r
.25131 .48216 m .25552 .48901 L .26023 .49578 L p F P
0 g
s
0 0 .407 r
.26476 .50246 m .26023 .49578 L .25552 .48901 L p F P
0 g
s
.887 .953 .842 r
.66641 .39052 m .66472 .39236 L .66533 .39022 L closepath p F P
0 g
s
.425 .758 .995 r
.45668 .60427 m .47596 .60349 L .48147 .60682 L p F P
0 g
s
.44 .751 .994 r
.47596 .60349 m .45668 .60427 L .45108 .60059 L p F P
0 g
s
.129 .522 .915 r
.34115 .56482 m .34521 .56615 L .35235 .57158 L p F P
0 g
s
.252 .593 .949 r
.35951 .56943 m .34521 .56615 L .35235 .57158 L p F P
0 g
s
.252 .593 .949 r
.35235 .57158 m .36545 .57456 L .35951 .56943 L p F P
0 g
s
.886 .953 .843 r
.65658 .39563 m .65304 .40498 L .66472 .39236 L p F P
0 g
s
.886 .953 .843 r
.66183 .38925 m .65658 .39563 L p .66472 .39236 L F P
0 g
s
.886 .953 .843 r
.66472 .39236 m .66533 .39022 L .66183 .38925 L p F P
0 g
s
.844 .476 0 r
.24778 .47503 m .2439 .46799 L .24153 .4605 L p F P
0 g
s
.676 .286 0 r
.2439 .46799 m .24778 .47503 L .25131 .48216 L p F P
0 g
s
.23 .607 .952 r
.37136 .57936 m .37595 .58031 L .38424 .58527 L p F P
0 g
s
.332 .657 .971 r
.39003 .5821 m .37595 .58031 L .38424 .58527 L p F P
0 g
s
.332 .657 .971 r
.38424 .58527 m .39587 .58671 L .39003 .5821 L p F P
0 g
s
.394 .713 .987 r
.42961 .599 m .4263 .59668 L .42349 .59659 L closepath p F P
0 g
s
0 0 .118 r
.81696 .44792 m .81307 .45687 L .815 .44736 L p F P
0 g
s
0 0 .118 r
.815 .44736 m .81885 .43841 L .81696 .44792 L p F P
0 g
s
.839 .873 .868 r
.69521 .36465 m .7056 .35621 L .70104 .35171 L p F P
0 g
s
.839 .873 .868 r
.70104 .35171 m .69607 .35612 L .69521 .36465 L p F P
0 g
s
.821 .896 .895 r
.68135 .36887 m .69607 .35612 L .69521 .36465 L p F P
0 g
s
0 .082 .628 r
.26965 .50763 m .26476 .50246 L .26023 .49578 L p F P
0 g
s
0 .045 .587 r
.27518 .51482 m .27558 .51536 L p .26476 .50246 L F P
0 g
s
0 .045 .587 r
.26476 .50246 m .26965 .50763 L .27518 .51482 L p F P
0 g
s
.776 .274 0 r
.44789 .46223 m .45544 .46776 L .45015 .46104 L p F P
0 g
s
.776 .274 0 r
.45015 .46104 m .44289 .4554 L .44789 .46223 L p F P
0 g
s
.322 .678 .977 r
.40168 .59105 m .41362 .5922 L .42349 .59659 L p F P
0 g
s
.337 .673 .977 r
.41362 .5922 m .40168 .59105 L .39587 .58671 L p F P
0 g
s
0 .201 .718 r
.42105 .4296 m .42293 .43114 L .42856 .4381 L p F P
0 g
s
.625 .162 0 r
.43161 .44283 m .42664 .43607 L p .42686 .43636 L F P
0 g
s
.625 .162 0 r
.43673 .44933 m .43161 .44283 L p .42686 .43636 L F P
0 g
s
.621 .162 0 r
.44163 .45618 m .4366 .44965 L .43161 .44283 L p F P
0 g
s
0 0 .506 r
.43161 .44283 m .4366 .44965 L p .4364 .44935 L F P
0 g
s
.611 .148 0 r
.42856 .4381 m .43183 .44254 L .42664 .43607 L p F P
0 g
s
.625 .162 0 r
.42664 .43607 m .43183 .44254 L .43673 .44933 L p F P
0 g
s
.621 .162 0 r
.43161 .44283 m .43673 .44933 L .44163 .45618 L p F P
0 g
s
0 0 .506 r
.4276 .43588 m .43161 .44283 L p .4364 .44935 L F P
0 g
s
0 0 .486 r
.42664 .43607 m .43161 .44283 L p .43096 .44188 L F P
0 g
s
.611 .148 0 r
.42324 .43152 m .42856 .4381 L p .42664 .43607 L F P
0 g
s
0 0 .486 r
.42237 .42921 m .42664 .43607 L p .43096 .44188 L F P
0 g
s
.611 .148 0 r
.42664 .43607 m .42293 .43114 L .42324 .43152 L p F P
0 g
s
.734 .326 .277 r
.48352 .49156 m .4787 .48451 L .49109 .48827 L p F P
0 g
s
.734 .326 .277 r
.49225 .49395 m .48352 .49156 L p .49109 .48827 L F P
0 g
s
.734 .326 .277 r
.49109 .48827 m .49407 .49172 L .49225 .49395 L p F P
0 g
s
.548 .624 .879 r
.77546 .34234 m .78174 .3422 L .78162 .3504 L p F P
0 g
s
.517 .597 .873 r
.80069 .35097 m .80047 .35245 L .78162 .3504 L p F P
0 g
s
.517 .597 .873 r
.79684 .34308 m .80069 .35097 L p .78162 .3504 L F P
0 g
s
.517 .597 .873 r
.78162 .3504 m .78174 .3422 L .79684 .34308 L p F P
0 g
s
.93 .614 .154 r
.24153 .4605 m .23799 .45327 L .23679 .44541 L p F P
0 g
s
.809 .455 0 r
.23799 .45327 m .24153 .4605 L .2439 .46799 L p F P
0 g
s
.774 .837 .9 r
.71833 .34802 m .7056 .35621 L .70104 .35171 L p F P
0 g
s
.028 .431 .867 r
.31118 .54659 m .31931 .55034 L .32555 .55616 L p F P
0 g
s
.062 .438 .875 r
.31347 .54432 m .30513 .5405 L .31118 .54659 L p F P
0 g
s
.062 .438 .875 r
.31118 .54659 m .31931 .55034 L .31347 .54432 L p F P
0 g
s
.063 .439 .876 r
.30263 .53936 m .30513 .5405 L .31118 .54659 L p F P
0 g
s
.685 .924 .609 r
.62889 .43281 m .62758 .4339 L .63119 .42973 L closepath p F P
0 g
s
.815 .819 .853 r
.25382 .36385 m .25295 .35521 L p .27036 .34669 L F P
0 g
s
.815 .819 .853 r
.27036 .34669 m .27088 .34929 L .25382 .36385 L p F P
0 g
s
.867 .864 .834 r
.2529 .36476 m .25382 .36385 L .25295 .35521 L p F P
0 g
s
.867 .864 .834 r
.25295 .35521 m .24623 .36231 L .2529 .36476 L p F P
0 g
s
.889 .858 .804 r
.24234 .36734 m .24623 .36231 L .2529 .36476 L p F P
0 g
s
.889 .858 .804 r
.2529 .36476 m .2441 .37561 L .24234 .36734 L p F P
0 g
s
.44 .544 .866 r
.35627 .35164 m .34653 .35072 L .35232 .35939 L p F P
0 g
s
.44 .544 .866 r
.35232 .35939 m .35694 .3602 L .35627 .35164 L p F P
0 g
s
0 .229 .742 r
.27518 .51482 m .27569 .51544 L .27558 .51536 L closepath p F P
0 g
s
.353 .497 .863 r
.38763 .39106 m .38776 .39128 L .38767 .39125 L closepath p F P
0 g
s
.628 .919 .977 r
.64784 .58795 m .65062 .58887 L .63065 .59672 L p F P
0 g
s
.628 .919 .977 r
.63065 .59672 m .62968 .59643 L .64784 .58795 L p F P
0 g
s
.826 .999 .788 r
.64657 .40772 m .65658 .39563 L .65304 .40498 L p F P
0 g
s
.826 .999 .788 r
.64449 .41213 m .64657 .40772 L p .65304 .40498 L F P
0 g
s
.826 .999 .788 r
.65304 .40498 m .64699 .41142 L .64449 .41213 L p F P
0 g
s
.193 .402 .838 r
.38776 .39128 m .39584 .39656 L p .38507 .3836 L F P
0 g
s
.193 .402 .838 r
.38507 .3836 m .38763 .39106 L .38776 .39128 L p F P
0 g
s
0 .252 .759 r
.27569 .51544 m .28306 .5213 L p .27078 .50884 L F P
0 g
s
0 .252 .759 r
.27078 .50884 m .27518 .51482 L .27569 .51544 L p F P
0 g
s
.574 .632 .872 r
.33483 .33347 m .31617 .33703 L .32214 .3445 L p F P
0 g
s
.574 .632 .872 r
.33578 .33486 m .33483 .33347 L p .32214 .3445 L F P
0 g
s
.574 .632 .872 r
.32214 .3445 m .33423 .34296 L .33578 .33486 L p F P
0 g
s
.662 .858 .464 r
.7981 .48763 m .79788 .48791 L .79847 .48702 L closepath p F P
0 g
s
.194 .402 .839 r
.38211 .38195 m .38507 .3836 L .38763 .39106 L closepath p F P
0 g
s
.117 .129 .595 r
.82143 .41093 m .821 .41225 L .81762 .40461 L p F P
0 g
s
.117 .129 .595 r
.81762 .40461 m .81909 .4002 L .82143 .41093 L p F P
0 g
s
0 .04 .582 r
.26965 .50763 m .27078 .50884 L .27518 .51482 L closepath p F P
0 g
s
.793 .806 .863 r
.27234 .34817 m .27088 .34929 L .27036 .34669 L closepath p F P
0 g
s
.856 .997 .777 r
.64699 .41142 m .64179 .41746 L .64449 .41213 L closepath p F P
0 g
s
.171 .521 .918 r
.32914 .55367 m .31931 .55034 L .32555 .55616 L p F P
0 g
s
.171 .521 .918 r
.32555 .55616 m .33515 .55942 L .32914 .55367 L p F P
0 g
s
.836 .377 .118 r
.46395 .47218 m .46433 .47279 L .46315 .47205 L closepath p F P
0 g
s
.765 .806 .885 r
.28512 .33127 m .29134 .33719 L .27234 .34817 L p F P
0 g
s
.765 .806 .885 r
.27062 .34037 m .28512 .33127 L p .27234 .34817 L F P
0 g
s
.765 .806 .885 r
.27234 .34817 m .27036 .34669 L .27062 .34037 L p F P
0 g
s
.665 .86 .467 r
.79642 .48912 m .80371 .47778 L .79847 .48702 L p F P
0 g
s
.665 .86 .467 r
.79522 .49123 m .79642 .48912 L p .79847 .48702 L F P
0 g
s
.665 .86 .467 r
.79847 .48702 m .79788 .48791 L .79522 .49123 L p F P
0 g
s
.994 .846 .585 r
.23268 .39718 m .23487 .40415 L .23214 .41334 L p F P
0 g
s
.645 .852 .463 r
.79788 .48791 m .79048 .49856 L .79522 .49123 L closepath p F P
0 g
s
.074 .321 .8 r
.39584 .39656 m .3987 .40405 L .40635 .40963 L p F P
0 g
s
0 .26 .77 r
.40966 .41689 m .40635 .40963 L .3987 .40405 L p F P
0 g
s
.875 .956 .855 r
.66533 .39022 m .66183 .38925 L .66776 .38315 L closepath p F P
0 g
s
.981 .723 .325 r
.23679 .44541 m .23361 .43796 L .23364 .4297 L p F P
0 g
s
.909 .604 .115 r
.23361 .43796 m .23679 .44541 L .23799 .45327 L p F P
0 g
s
.457 .783 .998 r
.50474 .60733 m .50633 .60822 L p .48147 .60682 L F P
0 g
s
.457 .783 .998 r
.48147 .60682 m .49291 .60583 L .50474 .60733 L p F P
0 g
s
.472 .778 .997 r
.49291 .60583 m .48147 .60682 L .47596 .60349 L p F P
0 g
s
.249 .605 .953 r
.37595 .58031 m .37136 .57936 L .36545 .57456 L p F P
0 g
s
.84 .387 .133 r
.46007 .47479 m .46856 .47996 L .46433 .47279 L p F P
0 g
s
.84 .387 .133 r
.45829 .47139 m .46007 .47479 L p .46433 .47279 L F P
0 g
s
.84 .387 .133 r
.46433 .47279 m .46315 .47205 L .45829 .47139 L p F P
0 g
s
.468 .098 .254 r
.56894 .48592 m .56877 .48634 L .56614 .48658 L closepath p F P
0 g
s
.48 .127 .289 r
.56696 .49216 m .56877 .48634 L .56614 .48658 L p F P
0 g
s
.48 .127 .289 r
.5458 .49713 m .56696 .49216 L p .56614 .48658 L F P
0 g
s
.723 .979 .915 r
.72918 .55413 m .71963 .56029 L .71532 .55985 L p F P
0 g
s
.856 .997 .777 r
.63726 .41959 m .63119 .42973 L .64179 .41746 L p F P
0 g
s
.856 .997 .777 r
.6424 .41271 m .63726 .41959 L p .64179 .41746 L F P
0 g
s
.856 .997 .777 r
.64179 .41746 m .64449 .41213 L .6424 .41271 L p F P
0 g
s
0 .338 .817 r
.28306 .5213 m .2882 .52766 L .29716 .53317 L p F P
0 g
s
0 .324 .804 r
.30263 .53936 m .29716 .53317 L .2882 .52766 L p F P
0 g
s
.155 .525 .919 r
.34521 .56615 m .34115 .56482 L .33515 .55942 L p F P
0 g
s
.407 .709 .985 r
.42058 .59244 m .41362 .5922 L .42349 .59659 L p F P
0 g
s
.407 .709 .985 r
.42349 .59659 m .4263 .59668 L .42058 .59244 L p F P
0 g
s
.639 .681 .873 r
.75026 .34001 m .77091 .33464 L .77546 .34234 L p F P
0 g
s
.654 .697 .877 r
.77091 .33464 m .75026 .34001 L .74573 .33348 L p F P
0 g
s
.715 .748 .878 r
.72551 .34329 m .74573 .33348 L .75026 .34001 L p F P
0 g
s
.788 .816 .874 r
.71833 .34802 m .72551 .34329 L .72095 .33773 L p F P
0 g
s
.788 .816 .874 r
.72095 .33773 m .71797 .33988 L .71833 .34802 L p F P
0 g
s
.774 .837 .9 r
.70104 .35171 m .71797 .33988 L .71833 .34802 L p F P
0 g
s
.93 .873 .76 r
.24234 .36734 m .2441 .37561 L .2372 .38632 L p F P
0 g
s
.649 .899 .983 r
.64587 .58703 m .64784 .58795 L .62968 .59643 L p F P
0 g
s
.649 .899 .983 r
.62968 .59643 m .62582 .59471 L .64587 .58703 L p F P
0 g
s
.295 0 .178 r
.56894 .48592 m .56877 .48634 L .57137 .48482 L closepath p F P
0 g
s
.089 .332 .807 r
.41705 .42265 m .40966 .41689 L .40635 .40963 L p F P
0 g
s
0 .226 .745 r
.42105 .4296 m .41705 .42265 L .40966 .41689 L p F P
0 g
s
.637 .945 .954 r
.67527 .58154 m .67315 .58253 L .67498 .58149 L closepath p F P
0 g
s
.658 .929 .972 r
.67066 .57996 m .67498 .58149 L .67315 .58253 L p F P
0 g
s
.658 .929 .972 r
.65062 .58887 m .67066 .57996 L p .67315 .58253 L F P
0 g
s
.041 0 .023 r
.58981 .47208 m .58849 .475 L .59593 .46781 L closepath p F P
0 g
s
.787 .295 .035 r
.46315 .47205 m .45829 .47139 L .45544 .46776 L closepath p F P
0 g
s
.623 .886 .989 r
.62582 .59471 m .60588 .60141 L .60092 .5992 L p F P
0 g
s
.585 .874 .994 r
.58103 .60492 m .60092 .5992 L .60588 .60141 L p F P
0 g
s
.249 .285 .704 r
.815 .38889 m .8154 .38749 L .81627 .39032 L closepath p F P
0 g
s
.439 .5 .825 r
.8015 .3527 m .80047 .35245 L .79885 .36111 L p F P
0 g
s
.439 .5 .825 r
.79885 .36111 m .80626 .36341 L .8015 .3527 L p F P
0 g
s
.68 .957 .948 r
.69118 .57022 m .69528 .57121 L .67527 .58154 L p F P
0 g
s
.68 .957 .948 r
.67527 .58154 m .67498 .58149 L .69118 .57022 L p F P
0 g
s
.36 .031 .266 r
.57137 .48482 m .56877 .48634 L .56696 .49216 L p F P
0 g
s
.488 .809 1 r
.53096 .60825 m .53122 .60839 L p .50633 .60822 L F P
0 g
s
.488 .809 1 r
.50633 .60822 m .51065 .60764 L .53096 .60825 L p F P
0 g
s
.501 .804 .999 r
.50633 .60822 m .51065 .60764 L .50474 .60733 L closepath p F P
0 g
s
0 0 0 r
.81278 .45746 m .8126 .45815 L .81307 .45687 L closepath p F P
0 g
s
.717 .987 .875 r
.73952 .5468 m .72918 .55413 L .73679 .54691 L closepath p F P
0 g
s
.723 .979 .915 r
.73533 .54663 m .73679 .54691 L .72918 .55413 L p F P
0 g
s
.723 .979 .915 r
.71532 .55985 m .73533 .54663 L p .72918 .55413 L F P
0 g
s
.728 .757 .876 r
.74573 .33348 m .72551 .34329 L .72095 .33773 L p F P
0 g
s
.589 .857 .516 r
.62855 .43127 m .63726 .41959 L .63119 .42973 L p F P
0 g
s
.589 .857 .516 r
.62523 .43634 m .62855 .43127 L p .63119 .42973 L F P
0 g
s
.589 .857 .516 r
.63119 .42973 m .62758 .4339 L .62523 .43634 L p F P
0 g
s
.999 .799 .47 r
.23364 .4297 m .23081 .42204 L .23214 .41334 L p F P
0 g
s
.971 .722 .296 r
.23081 .42204 m .23364 .4297 L .23361 .43796 L p F P
0 g
s
0 .276 .78 r
.42293 .43114 m .42105 .4296 L .41705 .42265 L p F P
0 g
s
.325 0 .216 r
.58849 .475 m .57137 .48482 L .58752 .47776 L closepath p F P
0 g
s
.36 .031 .266 r
.58546 .48382 m .58752 .47776 L .57137 .48482 L p F P
0 g
s
.36 .031 .266 r
.56696 .49216 m .58546 .48382 L p .57137 .48482 L F P
0 g
s
.775 .814 .883 r
.27062 .34037 m .27036 .34669 L .26595 .34354 L closepath p F P
0 g
s
.815 .819 .853 r
.25295 .35521 m .26595 .34354 L .27036 .34669 L p F P
0 g
s
.695 .934 .965 r
.69078 .57006 m .69118 .57022 L .67498 .58149 L p F P
0 g
s
.695 .934 .965 r
.67498 .58149 m .67066 .57996 L .69078 .57006 L p F P
0 g
s
.356 .408 .778 r
.80915 .37424 m .80974 .3718 L .81113 .37544 L closepath p F P
0 g
s
.758 .961 .662 r
.78675 .50126 m .78048 .51075 L .79048 .49856 L p F P
0 g
s
.758 .961 .662 r
.79439 .49173 m .78675 .50126 L p .79048 .49856 L F P
0 g
s
.758 .961 .662 r
.79048 .49856 m .79522 .49123 L .79439 .49173 L p F P
0 g
s
0 0 .293 r
.82219 .42954 m .81885 .43841 L .8191 .42948 L p F P
0 g
s
0 0 .293 r
.8191 .42948 m .82246 .42058 L .82219 .42954 L p F P
0 g
s
.591 .871 .994 r
.59774 .5977 m .60092 .5992 L .58103 .60492 L p F P
0 g
s
.591 .871 .994 r
.58103 .60492 m .57705 .60309 L .59774 .5977 L p F P
0 g
s
.546 .857 .997 r
.57705 .60309 m .58103 .60492 L p .55614 .60727 L F P
0 g
s
.422 .722 .987 r
.44543 .59669 m .4263 .59668 L .42058 .59244 L p F P
0 g
s
.757 .357 .294 r
.49407 .49172 m .49656 .4951 L .49225 .49395 L closepath p F P
0 g
s
.764 .983 .737 r
.77944 .51222 m .77886 .51245 L .78048 .51075 L closepath p F P
0 g
s
.61 .242 .319 r
.53535 .49782 m .52155 .4984 L .51901 .5043 L p F P
0 g
s
.684 .321 .352 r
.51876 .50428 m .51901 .5043 L .52155 .4984 L p F P
0 g
s
.684 .321 .352 r
.52155 .4984 m .51236 .49767 L .51876 .50428 L p F P
0 g
s
.497 .56 .851 r
.37075 .3623 m .35694 .3602 L .35627 .35164 L p F P
0 g
s
.461 .542 .853 r
.37234 .36509 m .37235 .37138 L p .35694 .3602 L F P
0 g
s
.461 .542 .853 r
.35694 .3602 m .37075 .3623 L .37234 .36509 L p F P
0 g
s
.82 .407 .261 r
.47268 .48723 m .48352 .49156 L .4787 .48451 L p F P
0 g
s
.82 .407 .261 r
.4787 .48451 m .46856 .47996 L .47268 .48723 L p F P
0 g
s
0 0 0 r
.81349 .458 m .81696 .44792 L .81307 .45687 L p F P
0 g
s
0 0 0 r
.81135 .46286 m .81349 .458 L p .81307 .45687 L F P
0 g
s
0 0 0 r
.81307 .45687 m .8126 .45815 L .81135 .46286 L p F P
0 g
s
.581 .853 .513 r
.62758 .4339 m .6204 .44208 L .62523 .43634 L closepath p F P
0 g
s
.517 .834 .999 r
.55485 .60664 m .55614 .60727 L p .53122 .60839 L F P
0 g
s
.517 .834 .999 r
.53122 .60839 m .53233 .60818 L .55485 .60664 L p F P
0 g
s
.532 .827 .999 r
.53122 .60839 m .53233 .60818 L .53096 .60825 L closepath p F P
0 g
s
.277 .339 .747 r
.81113 .37544 m .81681 .38032 L .8154 .38749 L closepath p F P
0 g
s
.126 .203 .674 r
.82195 .38733 m .81681 .38032 L .8154 .38749 L p F P
0 g
s
.126 .203 .674 r
.82019 .39587 m .82195 .38733 L p .8154 .38749 L F P
0 g
s
.126 .203 .674 r
.8154 .38749 m .81627 .39032 L .82019 .39587 L p F P
0 g
s
.182 .225 .672 r
.81627 .39032 m .82019 .39587 L .81909 .4002 L closepath p F P
0 g
s
.546 .857 .997 r
.55614 .60727 m .56624 .60489 L .57705 .60309 L p F P
0 g
s
.561 .85 .997 r
.55614 .60727 m .56624 .60489 L .55485 .60664 L closepath p F P
0 g
s
.096 .447 .881 r
.30513 .5405 m .30263 .53936 L .29716 .53317 L p F P
0 g
s
0 0 0 r
.8126 .45815 m .80925 .46703 L .81135 .46286 L closepath p F P
0 g
s
.607 .254 .345 r
.5458 .49713 m .54396 .50235 L .53535 .49782 L closepath p F P
0 g
s
.61 .242 .319 r
.54367 .50337 m .54396 .50235 L .53535 .49782 L p F P
0 g
s
.61 .242 .319 r
.51901 .5043 m .54367 .50337 L p .53535 .49782 L F P
0 g
s
.742 .992 .87 r
.75087 .53823 m .73952 .5468 L .73679 .54691 L p F P
0 g
s
.562 .637 .883 r
.78174 .3422 m .77546 .34234 L .77091 .33464 L p F P
0 g
s
.57 .819 .992 r
.53233 .60818 m .53096 .60825 L .52591 .60512 L p F P
0 g
s
.537 .807 .996 r
.53096 .60825 m .52591 .60512 L .51065 .60764 L closepath p F P
0 g
s
.728 .367 .367 r
.50149 .50218 m .51876 .50428 L .51236 .49767 L p F P
0 g
s
.728 .367 .367 r
.51236 .49767 m .49656 .4951 L .50149 .50218 L p F P
0 g
s
.562 .826 .995 r
.55485 .60664 m .55093 .60432 L .53233 .60818 L closepath p F P
0 g
s
.57 .819 .992 r
.54568 .601 m .55093 .60432 L .53233 .60818 L p F P
0 g
s
.57 .819 .992 r
.52591 .60512 m .54568 .601 L p .53233 .60818 L F P
0 g
s
.577 .85 .508 r
.61984 .44298 m .60957 .45446 L .6204 .44208 L p F P
0 g
s
.577 .85 .508 r
.6204 .44208 m .62523 .43634 L .62297 .43873 L p F P
0 g
s
.577 .85 .508 r
.62297 .43873 m .61984 .44298 L p .6204 .44208 L F P
0 g
s
.249 .605 .953 r
.36545 .57456 m .36816 .57512 L .37595 .58031 L p F P
0 g
s
.343 .652 .969 r
.38415 .57719 m .36816 .57512 L .37595 .58031 L p F P
0 g
s
.343 .652 .969 r
.37595 .58031 m .39003 .5821 L .38415 .57719 L p F P
0 g
s
.242 .403 .824 r
.38359 .37547 m .37644 .37224 L .38211 .38195 L p F P
0 g
s
.242 .403 .824 r
.38211 .38195 m .38507 .3836 L .38359 .37547 L p F P
0 g
s
.429 .53 .859 r
.37235 .37138 m .37644 .37224 L .38211 .38195 L p F P
0 g
s
.504 .154 .305 r
.56505 .49855 m .56696 .49216 L .5458 .49713 L p F P
0 g
s
.504 .154 .305 r
.54804 .50235 m .56505 .49855 L p .5458 .49713 L F P
0 g
s
.504 .154 .305 r
.5458 .49713 m .54396 .50235 L .54804 .50235 L p F P
0 g
s
.546 .801 .992 r
.52056 .60159 m .52591 .60512 L .51065 .60764 L p F P
0 g
s
.546 .801 .992 r
.50091 .60486 m .52056 .60159 L p .51065 .60764 L F P
0 g
s
.546 .801 .992 r
.51065 .60764 m .50474 .60733 L .50091 .60486 L p F P
0 g
s
.155 .525 .919 r
.33515 .55942 m .33851 .56052 L .34521 .56615 L p F P
0 g
s
.269 .59 .947 r
.35354 .56398 m .33851 .56052 L .34521 .56615 L p F P
0 g
s
.269 .59 .947 r
.34521 .56615 m .35951 .56943 L .35354 .56398 L p F P
0 g
s
0 0 0 r
.6085 .45552 m .6081 .45616 L .60957 .45446 L closepath p F P
0 g
s
.045 .081 .575 r
.82335 .40359 m .82143 .41093 L .81909 .4002 L p F P
0 g
s
.045 .081 .575 r
.81909 .4002 m .82019 .39587 L .82335 .40359 L p F P
0 g
s
.93 .873 .76 r
.2372 .38632 m .23552 .37804 L .24234 .36734 L p F P
0 g
s
.971 .884 .688 r
.23552 .37804 m .2372 .38632 L .23245 .39624 L p F P
0 g
s
.96 .874 .706 r
.23268 .39718 m .23245 .39624 L .2372 .38632 L p F P
0 g
s
.768 .985 .741 r
.77503 .51393 m .78675 .50126 L .78048 .51075 L p F P
0 g
s
.768 .985 .741 r
.78048 .51075 m .77886 .51245 L .77503 .51393 L p F P
0 g
s
.237 .332 .759 r
.80974 .3718 m .81113 .37544 L .81681 .38032 L p F P
0 g
s
.725 .232 0 r
.44163 .45618 m .44789 .46223 L .44289 .4554 L p F P
0 g
s
.725 .232 0 r
.44289 .4554 m .43673 .44933 L .44163 .45618 L p F P
0 g
s
.734 .97 .711 r
.76741 .52394 m .77886 .51245 L .77503 .51393 L p F P
0 g
s
.486 .556 .852 r
.35749 .34227 m .3407 .34205 L .34653 .35072 L p F P
0 g
s
.486 .556 .852 r
.34653 .35072 m .35627 .35164 L .35749 .34227 L p F P
0 g
s
.579 .634 .87 r
.33423 .34296 m .3407 .34205 L .34653 .35072 L p F P
0 g
s
.736 .99 .816 r
.7593 .53114 m .75087 .53823 L .75674 .53165 L closepath p F P
0 g
s
.742 .992 .87 r
.75526 .53153 m .75674 .53165 L .75087 .53823 L p F P
0 g
s
.742 .992 .87 r
.73998 .54336 m .75526 .53153 L p .75087 .53823 L F P
0 g
s
.742 .992 .87 r
.73679 .54691 m .73998 .54336 L p .75087 .53823 L F P
0 g
s
.51 .787 .995 r
.50474 .60733 m .50091 .60486 L .49291 .60583 L closepath p F P
0 g
s
0 0 .499 r
.42237 .42921 m .41731 .42285 L .42293 .43114 L p F P
0 g
s
0 0 .499 r
.42293 .43114 m .42664 .43607 L .42237 .42921 L p F P
0 g
s
0 .276 .78 r
.41705 .42265 m .41731 .42285 L .42293 .43114 L p F P
0 g
s
.675 .72 .883 r
.30406 .32274 m .28512 .33127 L .29134 .33719 L p F P
0 g
s
.675 .72 .883 r
.29134 .33719 m .31015 .32976 L .30406 .32274 L p F P
0 g
s
.758 .994 .812 r
.76741 .52394 m .7593 .53114 L .75674 .53165 L p F P
0 g
s
0 .065 .614 r
.26634 .50212 m .26361 .49928 L .26965 .50763 L p F P
0 g
s
0 .065 .614 r
.26965 .50763 m .27078 .50884 L .26634 .50212 L p F P
0 g
s
0 .082 .628 r
.26023 .49578 m .26361 .49928 L .26965 .50763 L p F P
0 g
s
.994 .846 .585 r
.23214 .41334 m .22967 .40546 L p .23268 .39718 L F P
0 g
s
.997 .805 .451 r
.22967 .40546 m .23214 .41334 L .23081 .42204 L p F P
0 g
s
.353 .429 .8 r
.80626 .36341 m .81055 .36573 L .80974 .3718 L closepath p F P
0 g
s
.237 .332 .759 r
.81809 .37186 m .81055 .36573 L .80974 .3718 L p F P
0 g
s
.237 .332 .759 r
.81681 .38032 m .81809 .37186 L p .80974 .3718 L F P
0 g
s
.734 .97 .711 r
.77503 .51393 m .77485 .51412 L .76741 .52394 L p F P
0 g
s
.758 .994 .812 r
.75949 .52809 m .77485 .51412 L .76741 .52394 L p F P
0 g
s
.758 .994 .812 r
.75674 .53165 m .75949 .52809 L p .76741 .52394 L F P
0 g
s
.676 .286 0 r
.25131 .48216 m .24746 .4751 L .2439 .46799 L p F P
0 g
s
0 0 .521 r
.25607 .48891 m .25131 .48216 L .24746 .4751 L p F P
0 g
s
0 0 .454 r
.26023 .49578 m .25607 .48891 L .25131 .48216 L p F P
0 g
s
.592 .837 .991 r
.56624 .60489 m .55485 .60664 L .55093 .60432 L p F P
0 g
s
0 0 0 r
.61135 .45462 m .61984 .44298 L .60957 .45446 L p F P
0 g
s
0 0 0 r
.60586 .46061 m .61135 .45462 L p .60957 .45446 L F P
0 g
s
0 0 0 r
.60957 .45446 m .6081 .45616 L .60586 .46061 L p F P
0 g
s
.433 .527 .854 r
.37234 .36509 m .37644 .37224 L .37235 .37138 L closepath p F P
0 g
s
.598 .652 .875 r
.32891 .3251 m .31015 .32976 L .31617 .33703 L p F P
0 g
s
.598 .652 .875 r
.31617 .33703 m .33483 .33347 L .32891 .3251 L p F P
0 g
s
.668 .929 .972 r
.66601 .57823 m .67066 .57996 L .65062 .58887 L p F P
0 g
s
.668 .929 .972 r
.65868 .58153 m .66601 .57823 L p .65062 .58887 L F P
0 g
s
.668 .929 .972 r
.65062 .58887 m .64784 .58795 L .65868 .58153 L p F P
0 g
s
.094 .445 .88 r
.30804 .53811 m .29906 .53403 L .30513 .5405 L p F P
0 g
s
.094 .445 .88 r
.30513 .5405 m .31347 .54432 L .30804 .53811 L p F P
0 g
s
.096 .447 .881 r
.29716 .53317 m .29906 .53403 L .30513 .5405 L p F P
0 g
s
0 .118 .664 r
.26361 .49928 m .26023 .49578 L .25607 .48891 L p F P
0 g
s
0 0 0 r
.6081 .45616 m .59593 .46781 L .60586 .46061 L closepath p F P
0 g
s
.809 .455 0 r
.2439 .46799 m .24037 .46075 L .23799 .45327 L p F P
0 g
s
0 0 .325 r
.24037 .46075 m .2439 .46799 L .24746 .4751 L p F P
0 g
s
.337 .673 .977 r
.39587 .58671 m .40438 .58756 L .41362 .5922 L p F P
0 g
s
.352 .668 .975 r
.40438 .58756 m .39587 .58671 L .39003 .5821 L p F P
0 g
s
.166 0 .149 r
.60345 .46551 m .60586 .46061 L .59593 .46781 L p F P
0 g
s
.166 0 .149 r
.60274 .46633 m .60345 .46551 L p .59593 .46781 L F P
0 g
s
.166 0 .149 r
.58752 .47776 m .60274 .46633 L p .59593 .46781 L F P
0 g
s
.166 0 .149 r
.59593 .46781 m .58849 .475 L .58752 .47776 L p F P
0 g
s
.44 .751 .994 r
.47526 .60304 m .47596 .60349 L p .45108 .60059 L F P
0 g
s
.44 .751 .994 r
.45108 .60059 m .4639 .6001 L .47526 .60304 L p F P
0 g
s
.454 .746 .991 r
.4639 .6001 m .45108 .60059 L .44543 .59669 L p F P
0 g
s
.768 .257 0 r
.45262 .46863 m .44789 .46223 L .45544 .46776 L p F P
0 g
s
.768 .257 0 r
.45544 .46776 m .45829 .47139 L .45262 .46863 L p F P
0 g
s
.414 .703 .981 r
.41481 .58794 m .40438 .58756 L .41362 .5922 L p F P
0 g
s
.414 .703 .981 r
.41362 .5922 m .42058 .59244 L .41481 .58794 L p F P
0 g
s
0 0 .457 r
.82265 .41999 m .82246 .42058 L .821 .41225 L p F P
0 g
s
0 0 .457 r
.821 .41225 m .82143 .41093 L .82265 .41999 L p F P
0 g
s
.579 .638 .873 r
.33578 .33486 m .3407 .34205 L .33423 .34296 L closepath p F P
0 g
s
.866 .995 .773 r
.64449 .41213 m .6424 .41271 L .64657 .40772 L closepath p F P
0 g
s
.472 .778 .997 r
.47596 .60349 m .47713 .60339 L .49291 .60583 L p F P
0 g
s
.519 .781 .992 r
.49546 .60111 m .47713 .60339 L .49291 .60583 L p F P
0 g
s
.519 .781 .992 r
.49291 .60583 m .50091 .60486 L .49546 .60111 L p F P
0 g
s
.76 .365 .306 r
.48857 .49873 m .50149 .50218 L .49656 .4951 L p F P
0 g
s
.76 .365 .306 r
.49656 .4951 m .49225 .49395 L .48857 .49873 L p F P
0 g
s
.838 .894 .879 r
.69607 .35612 m .68135 .36887 L .68007 .36798 L p F P
0 g
s
.874 .889 .842 r
.68135 .36887 m .68 .37031 L .68007 .36798 L closepath p F P
0 g
s
0 .241 .755 r
.26634 .50212 m .27078 .50884 L .27829 .51476 L p F P
0 g
s
0 .252 .759 r
.28306 .5213 m .27829 .51476 L .27078 .50884 L p F P
0 g
s
.196 .522 .918 r
.32914 .55366 m .31931 .55034 L .31347 .54432 L p F P
0 g
s
.873 .889 .842 r
.66914 .37444 m .66776 .38315 L .68 .37031 L p F P
0 g
s
.873 .889 .842 r
.67674 .36567 m .66914 .37444 L p .68 .37031 L F P
0 g
s
.873 .889 .842 r
.68 .37031 m .68007 .36798 L .67674 .36567 L p F P
0 g
s
.712 .959 .946 r
.71402 .56064 m .69528 .57121 L .69118 .57022 L p F P
0 g
s
.909 .604 .115 r
.23799 .45327 m .23481 .44583 L .23361 .43796 L p F P
0 g
s
.766 .428 0 r
.23481 .44583 m .23799 .45327 L .24037 .46075 L p F P
0 g
s
.653 .799 .351 r
.8083 .46867 m .80371 .47778 L .80925 .46703 L p F P
0 g
s
.653 .799 .351 r
.80961 .46601 m .8083 .46867 L p .80925 .46703 L F P
0 g
s
.653 .799 .351 r
.80925 .46703 m .81135 .46286 L .80961 .46601 L p F P
0 g
s
.847 .855 .849 r
.69607 .35612 m .70104 .35171 L .69644 .34715 L p F P
0 g
s
.847 .855 .849 r
.69644 .34715 m .69553 .34802 L .69607 .35612 L p F P
0 g
s
.838 .894 .879 r
.68109 .36167 m .69553 .34802 L .69607 .35612 L p F P
0 g
s
.838 .894 .879 r
.68007 .36798 m .68109 .36167 L p .69607 .35612 L F P
0 g
s
.562 .637 .883 r
.77091 .33464 m .78172 .33399 L .78174 .3422 L p F P
0 g
s
.522 .588 .862 r
.79221 .33407 m .78172 .33399 L .78174 .3422 L p F P
0 g
s
.522 .588 .862 r
.78174 .3422 m .79684 .34308 L .79221 .33407 L p F P
0 g
s
.789 .838 .889 r
.71797 .33988 m .70104 .35171 L .69644 .34715 L p F P
0 g
s
.248 .408 .826 r
.38359 .37547 m .38507 .3836 L .39416 .38857 L p F P
0 g
s
.193 .402 .838 r
.39584 .39656 m .39416 .38857 L .38507 .3836 L p F P
0 g
s
.994 .863 .595 r
.23245 .39624 m .23268 .39718 L .23175 .39836 L closepath p F P
0 g
s
.994 .846 .585 r
.22967 .40546 m .23175 .39836 L .23268 .39718 L p F P
0 g
s
.365 .449 .815 r
.81055 .36573 m .80626 .36341 L .8015 .3527 L p F P
0 g
s
.585 .844 .994 r
.57705 .60309 m .57595 .60247 L .56624 .60489 L closepath p F P
0 g
s
.592 .837 .991 r
.57081 .59935 m .57595 .60247 L .56624 .60489 L p F P
0 g
s
.592 .837 .991 r
.55093 .60432 m .57081 .59935 L p .56624 .60489 L F P
0 g
s
0 0 .429 r
.82479 .41195 m .82265 .41999 L .82143 .41093 L p F P
0 g
s
0 0 .429 r
.82143 .41093 m .82335 .40359 L .82479 .41195 L p F P
0 g
s
.764 .371 .309 r
.48833 .49866 m .48857 .49873 L .49225 .49395 L p F P
0 g
s
.764 .371 .309 r
.49225 .49395 m .48352 .49156 L .48833 .49866 L p F P
0 g
s
.875 .956 .855 r
.65813 .3869 m .66914 .37444 L .66776 .38315 L p F P
0 g
s
.875 .956 .855 r
.65783 .38812 m .65813 .3869 L p .66776 .38315 L F P
0 g
s
.875 .956 .855 r
.66776 .38315 m .66183 .38925 L .65783 .38812 L p F P
0 g
s
0 0 .066 r
.82031 .43908 m .81696 .44792 L .81885 .43841 L p F P
0 g
s
0 0 .066 r
.81885 .43841 m .82219 .42954 L .82031 .43908 L p F P
0 g
s
.858 .435 .218 r
.46376 .4822 m .47268 .48723 L .46856 .47996 L p F P
0 g
s
.858 .435 .218 r
.46856 .47996 m .46007 .47479 L .46376 .4822 L p F P
0 g
s
.654 .697 .877 r
.74573 .33348 m .76636 .3272 L .77091 .33464 L p F P
0 g
s
.667 .71 .88 r
.76636 .3272 m .74573 .33348 L .74118 .32705 L p F P
0 g
s
.728 .757 .876 r
.72095 .33773 m .74118 .32705 L .74573 .33348 L p F P
0 g
s
.269 .603 .953 r
.36816 .57512 m .36545 .57456 L .35951 .56943 L p F P
0 g
s
.831 .842 .855 r
.26595 .34354 m .25295 .35521 L .25218 .34645 L p F P
0 g
s
.867 .865 .835 r
.25218 .34645 m .25295 .35521 L .24623 .36231 L p F P
0 g
s
.181 .527 .921 r
.33851 .56052 m .33515 .55942 L .32914 .55367 L p F P
0 g
s
.012 .358 .831 r
.29207 .5268 m .28306 .5213 L .27829 .51476 L p F P
0 g
s
0 .338 .817 r
.29716 .53317 m .29207 .5268 L .28306 .5213 L p F P
0 g
s
.907 .943 .818 r
.66183 .38925 m .65658 .39563 L .65783 .38812 L closepath p F P
0 g
s
.795 .834 .882 r
.26595 .34354 m .27062 .34037 L .2707 .33124 L p F P
0 g
s
.795 .834 .882 r
.2707 .33124 m .25945 .33956 L .26595 .34354 L p F P
0 g
s
.831 .842 .855 r
.25218 .34645 m .25945 .33956 L .26595 .34354 L p F P
0 g
s
.288 .415 .817 r
.40425 .40186 m .39584 .39656 L .39416 .38857 L p F P
0 g
s
.074 .321 .8 r
.40635 .40963 m .40425 .40186 L .39584 .39656 L p F P
0 g
s
.971 .722 .296 r
.23361 .43796 m .23078 .43032 L .23081 .42204 L p F P
0 g
s
.88 .588 .071 r
.23078 .43032 m .23361 .43796 L .23481 .44583 L p F P
0 g
s
.657 .893 .981 r
.64587 .58703 m .62582 .59471 L .62093 .59244 L p F P
0 g
s
.623 .886 .989 r
.60092 .5992 m .62093 .59244 L .62582 .59471 L p F P
0 g
s
.971 .884 .688 r
.23245 .39624 m .23078 .38798 L .23552 .37804 L p F P
0 g
s
.994 .872 .584 r
.23078 .38798 m .23245 .39624 L .23175 .39836 L p F P
0 g
s
.867 .865 .835 r
.24623 .36231 m .24132 .36124 L p .25218 .34645 L F P
0 g
s
.902 .871 .797 r
.24623 .36231 m .24234 .36734 L .24132 .36124 L closepath p F P
0 g
s
.484 .773 .995 r
.47596 .60349 m .47713 .60339 L .47526 .60304 L closepath p F P
0 g
s
.352 .482 .851 r
.37644 .37224 m .38359 .37547 L p .37203 .36275 L F P
0 g
s
.352 .482 .851 r
.37203 .36275 m .37234 .36509 L .37644 .37224 L p F P
0 g
s
.009 .063 .57 r
.82516 .39505 m .82335 .40359 L .82019 .39587 L p F P
0 g
s
.009 .063 .57 r
.82019 .39587 m .82195 .38733 L .82516 .39505 L p F P
0 g
s
.758 .797 .885 r
.28512 .33127 m .27062 .34037 L .2707 .33124 L p F P
0 g
s
.206 .381 .817 r
.4117 .41341 m .40635 .40963 L .40425 .40186 L p F P
0 g
s
.089 .332 .807 r
.41677 .42193 m .41705 .42265 L p .40635 .40963 L F P
0 g
s
.089 .332 .807 r
.40635 .40963 m .4117 .41341 L .41677 .42193 L p F P
0 g
s
.849 .892 .868 r
.68007 .36798 m .67674 .36567 L .68109 .36167 L closepath p F P
0 g
s
.907 .943 .818 r
.64937 .39859 m .64657 .40772 L .65658 .39563 L p F P
0 g
s
.907 .943 .818 r
.6572 .38794 m .64937 .39859 L p .65658 .39563 L F P
0 g
s
.907 .943 .818 r
.65658 .39563 m .65783 .38812 L .6572 .38794 L p F P
0 g
s
.532 .776 .987 r
.48996 .59712 m .49546 .60111 L .47713 .60339 L p F P
0 g
s
.532 .776 .987 r
.4704 .59958 m .48996 .59712 L p .47713 .60339 L F P
0 g
s
.532 .776 .987 r
.47713 .60339 m .47526 .60304 L .4704 .59958 L p F P
0 g
s
.784 .802 .867 r
.72095 .33773 m .71797 .33988 L .7166 .33244 L closepath p F P
0 g
s
.789 .838 .889 r
.71636 .33216 m .7166 .33244 L .71797 .33988 L p F P
0 g
s
.789 .838 .889 r
.69644 .34715 m .71636 .33216 L p .71797 .33988 L F P
0 g
s
.994 .872 .584 r
.23175 .39836 m .22897 .40278 L p .23078 .38798 L F P
0 g
s
.997 .856 .569 r
.23175 .39836 m .22967 .40546 L .22897 .40278 L closepath p F P
0 g
s
.576 .649 .885 r
.78172 .33399 m .77091 .33464 L .76636 .3272 L p F P
0 g
s
.615 .854 .989 r
.5959 .59664 m .59774 .5977 L .57705 .60309 L p F P
0 g
s
.615 .854 .989 r
.57705 .60309 m .57595 .60247 L .5959 .59664 L p F P
0 g
s
.34 .019 .266 r
.58376 .48903 m .58546 .48382 L .56696 .49216 L p F P
0 g
s
.34 .019 .266 r
.57966 .49178 m .58376 .48903 L p .56696 .49216 L F P
0 g
s
.34 .019 .266 r
.56696 .49216 m .56505 .49855 L .57966 .49178 L p F P
0 g
s
.493 .76 .99 r
.47526 .60304 m .4704 .59958 L .4639 .6001 L closepath p F P
0 g
s
.936 .885 .757 r
.24132 .36124 m .24234 .36734 L .23552 .37804 L p F P
0 g
s
.741 .791 .893 r
.7366 .32067 m .74118 .32705 L .72095 .33773 L p F P
0 g
s
.741 .791 .893 r
.71666 .332 m .7366 .32067 L p .72095 .33773 L F P
0 g
s
.741 .791 .893 r
.72095 .33773 m .7166 .33244 L .71666 .332 L p F P
0 g
s
.042 .3 .79 r
.41677 .42193 m .41731 .42285 L .41705 .42265 L closepath p F P
0 g
s
.269 .603 .953 r
.35951 .56943 m .36088 .56972 L .36816 .57512 L p F P
0 g
s
.355 .646 .965 r
.37824 .57199 m .36088 .56972 L .36816 .57512 L p F P
0 g
s
.355 .646 .965 r
.36816 .57512 m .38415 .57719 L .37824 .57199 L p F P
0 g
s
.536 .618 .881 r
.3407 .34205 m .35749 .34227 L p .33572 .33344 L F P
0 g
s
.536 .618 .881 r
.33572 .33344 m .33578 .33486 L .3407 .34205 L p F P
0 g
s
.69 .899 .54 r
.62523 .43634 m .62297 .43873 L .62855 .43127 L closepath p F P
0 g
s
0 .08 .639 r
.41731 .42285 m .42237 .42921 L p .41353 .41546 L F P
0 g
s
0 .08 .639 r
.41353 .41546 m .41677 .42193 L .41731 .42285 L p F P
0 g
s
.873 .435 .134 r
.46007 .47479 m .45829 .47139 L .45262 .46863 L p F P
0 g
s
.76 .911 .53 r
.80112 .48001 m .79642 .48912 L .80371 .47778 L p F P
0 g
s
.76 .911 .53 r
.80371 .47778 m .8083 .46867 L .80112 .48001 L p F P
0 g
s
.087 0 .126 r
.59234 .47867 m .58546 .48382 L .58752 .47776 L p F P
0 g
s
.087 0 .126 r
.58752 .47776 m .60274 .46633 L .59234 .47867 L p F P
0 g
s
0 .1 .65 r
.26228 .49521 m .25759 .49044 L .26361 .49928 L p F P
0 g
s
0 .1 .65 r
.26361 .49928 m .26634 .50212 L .26228 .49521 L p F P
0 g
s
0 .118 .664 r
.25607 .48891 m .25759 .49044 L .26361 .49928 L p F P
0 g
s
.128 .454 .885 r
.29906 .53403 m .29716 .53317 L .29207 .5268 L p F P
0 g
s
.627 .883 .988 r
.61707 .59056 m .62093 .59244 L .60092 .5992 L p F P
0 g
s
.627 .883 .988 r
.60092 .5992 m .59774 .5977 L .61707 .59056 L p F P
0 g
s
.811 .412 .297 r
.47672 .49459 m .48833 .49866 L .48352 .49156 L p F P
0 g
s
.811 .412 .297 r
.48352 .49156 m .47268 .48723 L .47672 .49459 L p F P
0 g
s
.555 .793 .988 r
.52056 .60159 m .50091 .60486 L .49546 .60111 L p F P
0 g
s
.422 .722 .987 r
.42058 .59244 m .43975 .59255 L .44543 .59669 L p F P
0 g
s
.435 .715 .983 r
.43975 .59255 m .42058 .59244 L .41481 .58794 L p F P
0 g
s
.766 .979 .914 r
.73679 .54691 m .73533 .54663 L .73998 .54336 L closepath p F P
0 g
s
.997 .805 .451 r
.23081 .42204 m .22834 .41418 L .22967 .40546 L p F P
0 g
s
.955 .717 .262 r
.22834 .41418 m .23081 .42204 L .23078 .43032 L p F P
0 g
s
.143 .218 .682 r
.82331 .37885 m .82195 .38733 L .81681 .38032 L p F P
0 g
s
.143 .218 .682 r
.81681 .38032 m .81809 .37186 L .82331 .37885 L p F P
0 g
s
.709 .974 .922 r
.71532 .55985 m .71402 .56064 L .71501 .55981 L closepath p F P
0 g
s
.712 .959 .946 r
.71091 .55852 m .71501 .55981 L .71402 .56064 L p F P
0 g
s
.712 .959 .946 r
.6924 .56919 m .71091 .55852 L p .71402 .56064 L F P
0 g
s
.712 .959 .946 r
.69118 .57022 m .6924 .56919 L p .71402 .56064 L F P
0 g
s
0 .09 .646 r
.4117 .41341 m .41353 .41546 L .41677 .42193 L closepath p F P
0 g
s
.79 .966 .66 r
.79522 .49123 m .79439 .49173 L .79642 .48912 L closepath p F P
0 g
s
.457 .526 .84 r
.80047 .35245 m .80069 .35097 L .8015 .3527 L closepath p F P
0 g
s
.181 .527 .921 r
.32914 .55367 m .33226 .55469 L .33851 .56052 L p F P
0 g
s
.286 .587 .944 r
.34754 .55819 m .33226 .55469 L .33851 .56052 L p F P
0 g
s
.286 .587 .944 r
.33851 .56052 m .35354 .56398 L .34754 .55819 L p F P
0 g
s
.745 .981 .913 r
.73104 .54572 m .73533 .54663 L .71532 .55985 L p F P
0 g
s
.745 .981 .913 r
.72501 .54979 m .73104 .54572 L p .71532 .55985 L F P
0 g
s
.745 .981 .913 r
.71532 .55985 m .71501 .55981 L .72501 .54979 L p F P
0 g
s
.858 .996 .764 r
.64072 .41026 m .64937 .39859 L .64657 .40772 L p F P
0 g
s
.858 .996 .764 r
.63945 .41367 m .64072 .41026 L p .64657 .40772 L F P
0 g
s
.858 .996 .764 r
.64657 .40772 m .6424 .41271 L .63945 .41367 L p F P
0 g
s
.678 .904 .975 r
.64784 .58795 m .64587 .58703 L .65868 .58153 L closepath p F P
0 g
s
.707 .927 .964 r
.69078 .57006 m .67066 .57996 L .66601 .57823 L p F P
0 g
s
.516 .187 .348 r
.54396 .50235 m .54804 .50235 L .54367 .50337 L closepath p F P
0 g
s
.261 .351 .767 r
.819 .36345 m .81809 .37186 L .81055 .36573 L p F P
0 g
s
.261 .351 .767 r
.81055 .36573 m .81129 .35738 L .819 .36345 L p F P
0 g
s
.365 .449 .815 r
.8015 .3527 m .81129 .35738 L .81055 .36573 L p F P
0 g
s
.698 .816 .363 r
.81135 .46286 m .80961 .46601 L .81349 .458 L closepath p F P
0 g
s
.579 .811 .987 r
.54568 .601 m .52591 .60512 L .52056 .60159 L p F P
0 g
s
.621 .846 .985 r
.5959 .59664 m .57595 .60247 L .57081 .59935 L p F P
0 g
s
.338 .454 .832 r
.80069 .35097 m .8015 .3527 L .81129 .35738 L p F P
0 g
s
.66 .302 .354 r
.5419 .5101 m .54367 .50337 L .51901 .5043 L p F P
0 g
s
.66 .302 .354 r
.52599 .51068 m .5419 .5101 L p .51901 .5043 L F P
0 g
s
.66 .302 .354 r
.51901 .5043 m .51894 .50448 L .52599 .51068 L p F P
0 g
s
.687 .331 .366 r
.51901 .5043 m .51894 .50448 L .51876 .50428 L closepath p F P
0 g
s
.749 .957 .94 r
.71501 .55981 m .71091 .55852 L .72501 .54979 L closepath p F P
0 g
s
.352 .668 .975 r
.39003 .5821 m .39574 .58267 L .40438 .58756 L p F P
0 g
s
.422 .696 .978 r
.40901 .58319 m .39574 .58267 L .40438 .58756 L p F P
0 g
s
.422 .696 .978 r
.40438 .58756 m .41481 .58794 L .40901 .58319 L p F P
0 g
s
.529 .578 .848 r
.36504 .35228 m .35627 .35164 L .35749 .34227 L p F P
0 g
s
.497 .56 .851 r
.35627 .35164 m .36504 .35228 L .37075 .3623 L p F P
0 g
s
.678 .333 .381 r
.50624 .50939 m .50149 .50218 L .51876 .50428 L p F P
0 g
s
.678 .333 .381 r
.51679 .51063 m .50624 .50939 L p .51876 .50428 L F P
0 g
s
.678 .333 .381 r
.51876 .50428 m .51894 .50448 L .51679 .51063 L p F P
0 g
s
.892 .988 .747 r
.6424 .41271 m .63726 .41959 L .63945 .41367 L closepath p F P
0 g
s
.6 .829 .987 r
.57081 .59935 m .55093 .60432 L .54568 .601 L p F P
0 g
s
.653 .306 .372 r
.51894 .50448 m .52599 .51068 L .51679 .51063 L closepath p F P
0 g
s
.619 .669 .876 r
.32294 .31697 m .30406 .32274 L .31015 .32976 L p F P
0 g
s
.619 .669 .876 r
.31015 .32976 m .32891 .3251 L .32294 .31697 L p F P
0 g
s
.694 .737 .884 r
.2979 .31607 m .27882 .32576 L .28512 .33127 L p F P
0 g
s
.694 .737 .884 r
.28512 .33127 m .30406 .32274 L .2979 .31607 L p F P
0 g
s
.758 .797 .885 r
.2707 .33124 m .27882 .32576 L .28512 .33127 L p F P
0 g
s
.351 .481 .851 r
.37075 .3623 m .37203 .36275 L .37234 .36509 L closepath p F P
0 g
s
.79 .993 .879 r
.75674 .53165 m .75526 .53153 L .75949 .52809 L closepath p F P
0 g
s
.722 .223 0 r
.4466 .46308 m .44163 .45618 L .44789 .46223 L p F P
0 g
s
.722 .223 0 r
.44989 .46618 m .4466 .46308 L p .44789 .46223 L F P
0 g
s
.722 .223 0 r
.44789 .46223 m .45262 .46863 L .44989 .46618 L p F P
0 g
s
0 0 .261 r
.82284 .42757 m .82219 .42954 L .82246 .42058 L p F P
0 g
s
0 0 .261 r
.82246 .42058 m .82265 .41999 L .82284 .42757 L p F P
0 g
s
.126 .451 .883 r
.30303 .5317 m .29297 .5272 L .29906 .53403 L p F P
0 g
s
.126 .451 .883 r
.29906 .53403 m .30804 .53811 L .30303 .5317 L p F P
0 g
s
.128 .454 .885 r
.29207 .5268 m .29297 .5272 L .29906 .53403 L p F P
0 g
s
.427 .519 .85 r
.79684 .34308 m .80075 .34419 L .80069 .35097 L closepath p F P
0 g
s
.338 .454 .832 r
.8117 .34907 m .80075 .34419 L .80069 .35097 L p F P
0 g
s
.338 .454 .832 r
.81129 .35738 m .8117 .34907 L p .80069 .35097 L F P
0 g
s
0 0 0 r
.81687 .44917 m .81349 .458 L .81696 .44792 L p F P
0 g
s
0 0 0 r
.81696 .44792 m .82031 .43908 L .81687 .44917 L p F P
0 g
s
.522 .201 .363 r
.54804 .50235 m .54367 .50337 L .5419 .5101 L p F P
0 g
s
0 0 .229 r
.82464 .42089 m .82284 .42757 L .82265 .41999 L p F P
0 g
s
0 0 .229 r
.82265 .41999 m .82479 .41195 L .82464 .42089 L p F P
0 g
s
.936 .885 .757 r
.23552 .37804 m .23417 .36956 L p .24132 .36124 L F P
0 g
s
.974 .894 .683 r
.23417 .36956 m .23552 .37804 L .23078 .38798 L p F P
0 g
s
.796 .969 .665 r
.79215 .49196 m .80112 .48001 L .79642 .48912 L p F P
0 g
s
.796 .969 .665 r
.79134 .49352 m .79215 .49196 L p .79642 .48912 L F P
0 g
s
.796 .969 .665 r
.79642 .48912 m .79439 .49173 L .79134 .49352 L p F P
0 g
s
.892 .988 .746 r
.63297 .42165 m .62855 .43127 L .63726 .41959 L p F P
0 g
s
.892 .988 .746 r
.63776 .41423 m .63297 .42165 L p .63726 .41959 L F P
0 g
s
.892 .988 .746 r
.63726 .41959 m .63945 .41367 L .63776 .41423 L p F P
0 g
s
0 0 .325 r
.24746 .4751 m .24397 .46785 L .24037 .46075 L p F P
0 g
s
0 0 .57 r
.2516 .48085 m .24746 .4751 L .24397 .46785 L p F P
0 g
s
0 0 .521 r
.25347 .48406 m .25607 .48891 L p .24746 .4751 L F P
0 g
s
0 0 .521 r
.24746 .4751 m .2516 .48085 L .25347 .48406 L p F P
0 g
s
.454 .746 .991 r
.44543 .59669 m .45174 .59644 L .4639 .6001 L p F P
0 g
s
.502 .754 .986 r
.46481 .59538 m .45174 .59644 L .4639 .6001 L p F P
0 g
s
.502 .754 .986 r
.4639 .6001 m .4704 .59958 L .46481 .59538 L p F P
0 g
s
0 .134 .679 r
.25347 .48406 m .25759 .49044 L .25607 .48891 L closepath p F P
0 g
s
.37 .474 .836 r
.3719 .35396 m .36504 .35228 L .37075 .3623 L p F P
0 g
s
.37 .474 .836 r
.37075 .3623 m .37203 .36275 L .3719 .35396 L p F P
0 g
s
.991 .808 .427 r
.22897 .40278 m .22967 .40546 L .22834 .41418 L p F P
0 g
s
.221 .524 .918 r
.32309 .54756 m .31347 .54432 L .30804 .53811 L p F P
0 g
s
.196 .522 .918 r
.31347 .54432 m .32309 .54756 L .32914 .55366 L p F P
0 g
s
.783 .967 .667 r
.79439 .49173 m .78675 .50126 L .79134 .49352 L closepath p F P
0 g
s
.366 .664 .971 r
.39574 .58267 m .39003 .5821 L .38415 .57719 L p F P
0 g
s
.873 .435 .134 r
.45262 .46863 m .45286 .46913 L .46007 .47479 L p F P
0 g
s
.88 .449 .157 r
.45631 .47662 m .46376 .4822 L .46007 .47479 L p F P
0 g
s
.88 .449 .157 r
.46007 .47479 m .45286 .46913 L .45631 .47662 L p F P
0 g
s
.766 .428 0 r
.24037 .46075 m .23722 .4533 L .23481 .44583 L p F P
0 g
s
0 0 .409 r
.24397 .46785 m .24037 .46075 L .23722 .4533 L p F P
0 g
s
.518 .185 .342 r
.56505 .49855 m .56387 .5027 L .54804 .50235 L closepath p F P
0 g
s
.522 .201 .363 r
.56331 .50522 m .56387 .5027 L .54804 .50235 L p F P
0 g
s
.522 .201 .363 r
.5419 .5101 m .56331 .50522 L p .54804 .50235 L F P
0 g
s
0 0 0 r
.60586 .46061 m .60345 .46551 L .61135 .45462 L closepath p F P
0 g
s
.769 .976 .916 r
.73998 .54336 m .73533 .54663 L .73104 .54572 L p F P
0 g
s
.765 .38 .326 r
.49212 .50619 m .50624 .50939 L .50149 .50218 L p F P
0 g
s
.765 .38 .326 r
.48847 .49887 m .49212 .50619 L p .50149 .50218 L F P
0 g
s
.765 .38 .326 r
.50149 .50218 m .48857 .49873 L .48847 .49887 L p F P
0 g
s
.469 .742 .988 r
.45174 .59644 m .44543 .59669 L .43975 .59255 L p F P
0 g
s
0 .259 .769 r
.26228 .49521 m .26634 .50212 L .27391 .50802 L p F P
0 g
s
0 .241 .755 r
.27829 .51476 m .27391 .50802 L .26634 .50212 L p F P
0 g
s
.449 .495 .815 r
.38364 .36669 m .37203 .36275 L .3719 .35396 L p F P
0 g
s
.352 .482 .851 r
.38359 .37547 m .38364 .36669 L .37203 .36275 L p F P
0 g
s
.773 .994 .875 r
.73998 .54336 m .75526 .53153 L .75111 .53111 L p F P
0 g
s
.773 .994 .875 r
.75111 .53111 m .74843 .53324 L .73998 .54336 L p F P
0 g
s
.769 .976 .916 r
.73104 .54572 m .74843 .53324 L .73998 .54336 L p F P
0 g
s
.535 .617 .881 r
.33483 .33347 m .33572 .33344 L .33578 .33486 L closepath p F P
0 g
s
.88 .588 .071 r
.23481 .44583 m .232 .43818 L .23078 .43032 L p F P
0 g
s
.675 .368 0 r
.23722 .4533 m .23481 .44583 L .232 .43818 L p F P
0 g
s
.667 .71 .88 r
.74118 .32705 m .7618 .31995 L .76636 .3272 L p F P
0 g
s
.679 .72 .881 r
.7618 .31995 m .74118 .32705 L .7366 .32067 L p F P
0 g
s
.206 .528 .921 r
.32645 .54865 m .32309 .54756 L .32914 .55366 L p F P
0 g
s
.206 .528 .921 r
.32914 .55366 m .33226 .55469 L .32645 .54865 L p F P
0 g
s
.682 .9 .974 r
.65868 .58153 m .64587 .58703 L .64106 .58466 L p F P
0 g
s
.657 .893 .981 r
.62093 .59244 m .64106 .58466 L .64587 .58703 L p F P
0 g
s
0 .143 .686 r
.41102 .40783 m .4061 .403 L .4117 .41341 L p F P
0 g
s
0 .143 .686 r
.4117 .41341 m .41353 .41546 L .41102 .40783 L p F P
0 g
s
.206 .381 .817 r
.40425 .40186 m .4061 .403 L .4117 .41341 L p F P
0 g
s
.789 .989 .745 r
.79068 .49362 m .79134 .49352 L .78675 .50126 L p F P
0 g
s
.789 .989 .745 r
.78058 .50476 m .79068 .49362 L p .78675 .50126 L F P
0 g
s
.789 .989 .745 r
.77496 .51396 m .78058 .50476 L p .78675 .50126 L F P
0 g
s
.789 .989 .745 r
.78675 .50126 m .77503 .51393 L .77496 .51396 L p F P
0 g
s
.855 .445 .257 r
.46732 .48972 m .47672 .49459 L .47268 .48723 L p F P
0 g
s
.855 .445 .257 r
.47268 .48723 m .46376 .4822 L .46732 .48972 L p F P
0 g
s
.288 .6 .951 r
.36088 .56972 m .35951 .56943 L .35354 .56398 L p F P
0 g
s
.806 .836 .874 r
.71174 .32653 m .71636 .33216 L .69644 .34715 L p F P
0 g
s
.806 .836 .874 r
.69526 .33975 m .71174 .32653 L p .69644 .34715 L F P
0 g
s
.806 .836 .874 r
.69644 .34715 m .69517 .34586 L .69526 .33975 L p F P
0 g
s
.842 .839 .842 r
.69644 .34715 m .69553 .34802 L .69517 .34586 L closepath p F P
0 g
s
.842 .838 .842 r
.68108 .35334 m .68109 .36167 L .69553 .34802 L p F P
0 g
s
.842 .838 .842 r
.69179 .34245 m .68108 .35334 L p .69553 .34802 L F P
0 g
s
.842 .838 .842 r
.69553 .34802 m .69517 .34586 L .69179 .34245 L p F P
0 g
s
0 .169 .706 r
.25759 .49044 m .26228 .49521 L p .2523 .48182 L F P
0 g
s
0 .169 .706 r
.2523 .48182 m .25347 .48406 L .25759 .49044 L p F P
0 g
s
0 0 .409 r
.82662 .40342 m .82479 .41195 L .82335 .40359 L p F P
0 g
s
0 0 .409 r
.82335 .40359 m .82516 .39505 L .82662 .40342 L p F P
0 g
s
.056 .372 .839 r
.28688 .51992 m .27829 .51476 L .27391 .50802 L p F P
0 g
s
.012 .358 .831 r
.28903 .52255 m .29207 .5268 L p .27829 .51476 L F P
0 g
s
.012 .358 .831 r
.27829 .51476 m .28688 .51992 L .28903 .52255 L p F P
0 g
s
.537 .611 .874 r
.33611 .32424 m .32891 .3251 L .33483 .33347 L p F P
0 g
s
.537 .611 .874 r
.33483 .33347 m .33572 .33344 L .33611 .32424 L p F P
0 g
s
.576 .649 .885 r
.76636 .3272 m .78161 .32573 L .78172 .33399 L p F P
0 g
s
.538 .609 .872 r
.7876 .3255 m .78161 .32573 L .78172 .33399 L p F P
0 g
s
.538 .609 .872 r
.78172 .33399 m .79221 .33407 L .7876 .3255 L p F P
0 g
s
.621 .85 .475 r
.62578 .43286 m .63297 .42165 L .62855 .43127 L p F P
0 g
s
.621 .85 .475 r
.62175 .4402 m .62578 .43286 L p .62855 .43127 L F P
0 g
s
.621 .85 .475 r
.62855 .43127 m .62297 .43873 L .62175 .4402 L p F P
0 g
s
.848 .885 .866 r
.67206 .36225 m .68108 .35334 L .68109 .36167 L p F P
0 g
s
.848 .885 .866 r
.68109 .36167 m .67674 .36567 L .67206 .36225 L p F P
0 g
s
.904 .899 .811 r
.66914 .37444 m .67674 .36567 L .67206 .36225 L p F P
0 g
s
.723 .934 .958 r
.69118 .57022 m .69078 .57006 L .6924 .56919 L closepath p F P
0 g
s
.409 .473 .815 r
.39402 .37993 m .38359 .37547 L .38364 .36669 L p F P
0 g
s
.248 .408 .826 r
.39416 .38857 m .39402 .37993 L .38359 .37547 L p F P
0 g
s
.794 .991 .882 r
.75949 .52809 m .75526 .53153 L .75111 .53111 L p F P
0 g
s
.588 .659 .887 r
.78161 .32573 m .76636 .3272 L .7618 .31995 L p F P
0 g
s
.575 .611 .851 r
.35353 .33238 m .33572 .33344 L .33611 .32424 L p F P
0 g
s
.536 .618 .881 r
.35803 .34009 m .35353 .33238 L .33572 .33344 L p F P
0 g
s
.536 .618 .881 r
.35749 .34227 m .35803 .34009 L p .33572 .33344 L F P
0 g
s
.642 .862 .983 r
.61599 .58992 m .61707 .59056 L .59774 .5977 L p F P
0 g
s
.642 .862 .983 r
.59774 .5977 m .5959 .59664 L .61599 .58992 L p F P
0 g
s
.919 .899 .791 r
.24116 .35877 m .24132 .36124 L .23936 .36121 L closepath p F P
0 g
s
.936 .885 .757 r
.23417 .36956 m .23936 .36121 L .24132 .36124 L p F P
0 g
s
.867 .865 .835 r
.24132 .36124 m .24116 .35877 L .25218 .34645 L p F P
0 g
s
.803 .999 .845 r
.76634 .51842 m .75949 .52809 L .77485 .51412 L p F P
0 g
s
.794 .991 .882 r
.75111 .53111 m .76634 .51842 L .75949 .52809 L p F P
0 g
s
.772 .987 .748 r
.77503 .51393 m .77485 .51412 L .77496 .51396 L closepath p F P
0 g
s
.803 .999 .845 r
.77104 .51403 m .76634 .51842 L p .77485 .51412 L F P
0 g
s
.803 .999 .845 r
.77485 .51412 m .77496 .51396 L .77104 .51403 L p F P
0 g
s
.288 .6 .951 r
.35354 .56398 m .35411 .5641 L .36088 .56972 L p F P
0 g
s
.367 .641 .96 r
.3723 .56647 m .35411 .5641 L .36088 .56972 L p F P
0 g
s
.367 .641 .96 r
.36088 .56972 m .37824 .57199 L .3723 .56647 L p F P
0 g
s
.994 .872 .584 r
.22897 .40278 m .22783 .39727 L .23078 .38798 L p F P
0 g
s
.981 .811 .405 r
.22783 .39727 m .22897 .40278 L .22743 .41066 L p F P
0 g
s
.991 .808 .427 r
.22834 .41418 m .22743 .41066 L .22897 .40278 L p F P
0 g
s
.439 .537 .86 r
.80075 .34419 m .79684 .34308 L .79221 .33407 L p F P
0 g
s
.827 .999 .834 r
.77496 .51396 m .77104 .51403 L .78058 .50476 L closepath p F P
0 g
s
.726 .93 .958 r
.6924 .56919 m .69078 .57006 L .6862 .56811 L p F P
0 g
s
.707 .927 .964 r
.66601 .57823 m .6862 .56811 L .69078 .57006 L p F P
0 g
s
.955 .717 .262 r
.23078 .43032 m .22833 .42245 L .22834 .41418 L p F P
0 g
s
.805 .538 0 r
.232 .43818 m .23078 .43032 L .22833 .42245 L p F P
0 g
s
.359 .448 .816 r
.40051 .39189 m .39416 .38857 L .39402 .37993 L p F P
0 g
s
.288 .415 .817 r
.40388 .39858 m .40425 .40186 L p .39416 .38857 L F P
0 g
s
.288 .415 .817 r
.39416 .38857 m .40051 .39189 L .40388 .39858 L p F P
0 g
s
.538 .767 .982 r
.48996 .59712 m .4704 .59958 L .46481 .59538 L p F P
0 g
s
.707 .823 .371 r
.81186 .45981 m .81687 .44917 L .81349 .458 L p F P
0 g
s
.707 .823 .371 r
.80903 .46704 m .81186 .45981 L p .81349 .458 L F P
0 g
s
.707 .823 .371 r
.81349 .458 m .80961 .46601 L .80903 .46704 L p F P
0 g
s
.816 .86 .881 r
.25945 .33956 m .2707 .33124 L .27053 .32212 L p F P
0 g
s
.816 .86 .881 r
.27053 .32212 m .25282 .33632 L .25945 .33956 L p F P
0 g
s
.845 .854 .85 r
.25161 .33754 m .25282 .33632 L .25945 .33956 L p F P
0 g
s
.845 .854 .85 r
.25945 .33956 m .25218 .34645 L .25161 .33754 L p F P
0 g
s
.904 .899 .811 r
.67206 .36225 m .66889 .36623 L .66914 .37444 L p F P
0 g
s
.902 .898 .813 r
.65922 .37825 m .65813 .3869 L .66914 .37444 L p F P
0 g
s
.902 .898 .813 r
.66914 .37444 m .66889 .36623 L .65922 .37825 L p F P
0 g
s
.73 .958 .945 r
.6924 .56919 m .71091 .55852 L .70645 .55705 L p F P
0 g
s
.73 .958 .945 r
.70645 .55705 m .70526 .55775 L .6924 .56919 L p F P
0 g
s
.726 .93 .958 r
.6862 .56811 m .70526 .55775 L .6924 .56919 L p F P
0 g
s
.88 .876 .827 r
.25161 .33754 m .25218 .34645 L .24116 .35877 L p F P
0 g
s
.631 .855 .478 r
.62297 .43873 m .61984 .44298 L .62175 .4402 L closepath p F P
0 g
s
.892 .95 .837 r
.65783 .38812 m .6572 .38794 L .65813 .3869 L closepath p F P
0 g
s
.741 .791 .893 r
.7166 .33244 m .71636 .33216 L .71666 .332 L closepath p F P
0 g
s
.974 .894 .683 r
.23078 .38798 m .22945 .3795 L .23417 .36956 L p F P
0 g
s
.993 .877 .562 r
.22945 .3795 m .23078 .38798 L .22783 .39727 L p F P
0 g
s
.235 .382 .808 r
.40388 .39858 m .4061 .403 L .40425 .40186 L closepath p F P
0 g
s
.366 .664 .971 r
.38415 .57719 m .38768 .57755 L .39574 .58267 L p F P
0 g
s
.429 .69 .973 r
.40317 .57817 m .38768 .57755 L .39574 .58267 L p F P
0 g
s
.429 .69 .973 r
.39574 .58267 m .40901 .58319 L .40317 .57817 L p F P
0 g
s
0 0 .011 r
.82204 .43375 m .82031 .43908 L .82219 .42954 L p F P
0 g
s
0 0 .011 r
.82219 .42954 m .82284 .42757 L .82204 .43375 L p F P
0 g
s
.66 .891 .981 r
.6362 .58216 m .64106 .58466 L .62093 .59244 L p F P
0 g
s
.66 .891 .981 r
.62586 .58619 m .6362 .58216 L p .62093 .59244 L F P
0 g
s
.66 .891 .981 r
.62093 .59244 m .61707 .59056 L .62586 .58619 L p F P
0 g
s
.741 .79 .892 r
.71666 .332 m .71636 .33216 L .71174 .32653 L p F P
0 g
s
.757 .797 .885 r
.71666 .332 m .7366 .32067 L .73199 .31429 L p F P
0 g
s
.757 .797 .885 r
.73199 .31429 m .71679 .32354 L .71666 .332 L p F P
0 g
s
.741 .79 .892 r
.71174 .32653 m .71679 .32354 L .71666 .332 L p F P
0 g
s
.304 .584 .941 r
.34754 .55819 m .33226 .55469 L .32645 .54865 L p F P
0 g
s
.469 .742 .988 r
.43975 .59255 m .44026 .59253 L .45174 .59644 L p F P
0 g
s
.509 .748 .981 r
.45918 .59093 m .44026 .59253 L .45174 .59644 L p F P
0 g
s
.509 .748 .981 r
.45174 .59644 m .46481 .59538 L .45918 .59093 L p F P
0 g
s
.806 .836 .874 r
.69517 .34586 m .69179 .34245 L .69526 .33975 L closepath p F P
0 g
s
0 .135 .681 r
.41102 .40783 m .41353 .41546 L .41918 .4219 L p F P
0 g
s
0 .08 .639 r
.42237 .42921 m .41918 .4219 L .41353 .41546 L p F P
0 g
s
.152 .457 .885 r
.28903 .52255 m .29297 .5272 L .29207 .5268 L closepath p F P
0 g
s
0 .038 .607 r
.41918 .4219 m .42237 .42921 L .4276 .43588 L p F P
0 g
s
0 0 .486 r
.43161 .44283 m .4276 .43588 L .42237 .42921 L p F P
0 g
s
.766 .381 .326 r
.48857 .49873 m .48847 .49887 L .48833 .49866 L closepath p F P
0 g
s
.434 .496 .824 r
.3738 .34433 m .3593 .34226 L .36504 .35228 L p F P
0 g
s
.434 .496 .824 r
.36504 .35228 m .3719 .35396 L .3738 .34433 L p F P
0 g
s
.529 .578 .848 r
.35749 .34227 m .3593 .34226 L .36504 .35228 L p F P
0 g
s
0 .043 .563 r
.82654 .38658 m .82516 .39505 L .82195 .38733 L p F P
0 g
s
0 .043 .563 r
.82195 .38733 m .82331 .37885 L .82654 .38658 L p F P
0 g
s
.625 .848 .468 r
.61843 .44435 m .61135 .45462 L .61984 .44298 L p F P
0 g
s
.625 .848 .468 r
.61984 .44298 m .62175 .4402 L .61843 .44435 L p F P
0 g
s
.776 .382 .308 r
.4807 .50204 m .47672 .49459 L .48833 .49866 L p F P
0 g
s
.776 .382 .308 r
.48474 .50342 m .4807 .50204 L p .48833 .49866 L F P
0 g
s
.776 .382 .308 r
.48833 .49866 m .48847 .49887 L .48474 .50342 L p F P
0 g
s
.348 .032 .28 r
.56505 .49855 m .56387 .5027 L .57966 .49178 L closepath p F P
0 g
s
.435 .715 .983 r
.43916 .5921 m .43975 .59255 L p .41481 .58794 L F P
0 g
s
.435 .715 .983 r
.41481 .58794 m .43038 .58805 L .43916 .5921 L p F P
0 g
s
.446 .708 .978 r
.43038 .58805 m .41481 .58794 L .40901 .58319 L p F P
0 g
s
.809 .428 .334 r
.48847 .49887 m .49212 .50619 L .48474 .50342 L closepath p F P
0 g
s
.772 .806 .88 r
.27882 .32576 m .2707 .33124 L .27053 .32212 L p F P
0 g
s
.892 .944 .837 r
.65251 .38644 m .65922 .37825 L .65813 .3869 L p F P
0 g
s
.892 .944 .837 r
.65813 .3869 m .6572 .38794 L .65251 .38644 L p F P
0 g
s
.175 .47 .891 r
.29297 .5272 m .30303 .5317 L p .28738 .52022 L F P
0 g
s
.175 .47 .891 r
.28738 .52022 m .28903 .52255 L .29297 .5272 L p F P
0 g
s
.94 .945 .762 r
.64937 .39859 m .6572 .38794 L .65251 .38644 L p F P
0 g
s
.555 .793 .988 r
.49546 .60111 m .51516 .59779 L .52056 .60159 L p F P
0 g
s
.567 .784 .981 r
.51516 .59779 m .49546 .60111 L .48996 .59712 L p F P
0 g
s
.88 .876 .827 r
.24116 .35877 m .24095 .34974 L .25161 .33754 L p F P
0 g
s
.922 .909 .791 r
.24095 .34974 m .24116 .35877 L .23936 .36121 L p F P
0 g
s
.64 .688 .879 r
.3169 .30916 m .2979 .31607 L .30406 .32274 L p F P
0 g
s
.64 .688 .879 r
.30406 .32274 m .32294 .31697 L .3169 .30916 L p F P
0 g
s
0 0 .52 r
.2516 .48085 m .2523 .48182 L .25347 .48406 L closepath p F P
0 g
s
.58 .128 0 r
.4466 .46308 m .44163 .45618 L .4366 .44965 L p F P
0 g
s
.678 .922 .973 r
.66601 .57823 m .65868 .58153 L .66483 .57776 L closepath p F P
0 g
s
.682 .9 .974 r
.66128 .57589 m .66483 .57776 L .65868 .58153 L p F P
0 g
s
.682 .9 .974 r
.64106 .58466 m .66128 .57589 L p .65868 .58153 L F P
0 g
s
.931 .706 .223 r
.22743 .41066 m .22834 .41418 L .22833 .42245 L p F P
0 g
s
.096 0 .139 r
.58546 .48382 m .58376 .48903 L .59234 .47867 L closepath p F P
0 g
s
.647 .853 .979 r
.61599 .58992 m .5959 .59664 L .59083 .59348 L p F P
0 g
s
.621 .846 .985 r
.57081 .59935 m .59083 .59348 L .5959 .59664 L p F P
0 g
s
.922 .909 .791 r
.23936 .36121 m .23333 .36225 L p .24095 .34974 L F P
0 g
s
.945 .9 .75 r
.23936 .36121 m .23417 .36956 L .23333 .36225 L closepath p F P
0 g
s
.091 .29 .771 r
.4061 .403 m .41102 .40783 L p .40282 .39377 L F P
0 g
s
.091 .29 .771 r
.40282 .39377 m .40388 .39858 L .4061 .403 L p F P
0 g
s
.439 .537 .86 r
.79221 .33407 m .80047 .33604 L .80075 .34419 L p F P
0 g
s
.363 .471 .836 r
.81177 .3408 m .8117 .34907 L .80075 .34419 L p F P
0 g
s
.363 .471 .836 r
.80075 .34419 m .80047 .33604 L .81177 .3408 L p F P
0 g
s
.863 .418 .031 r
.45262 .46863 m .45286 .46913 L .44989 .46618 L closepath p F P
0 g
s
.694 .818 .368 r
.80961 .46601 m .8083 .46867 L .80903 .46704 L closepath p F P
0 g
s
.892 .988 .746 r
.63945 .41367 m .63776 .41423 L .64072 .41026 L closepath p F P
0 g
s
.123 .212 .685 r
.8243 .37042 m .82331 .37885 L .81809 .37186 L p F P
0 g
s
.123 .212 .685 r
.81809 .37186 m .819 .36345 L .8243 .37042 L p F P
0 g
s
0 0 0 r
.82297 .43038 m .82204 .43375 L .82284 .42757 L p F P
0 g
s
0 0 0 r
.82284 .42757 m .82464 .42089 L .82297 .43038 L p F P
0 g
s
.579 .811 .987 r
.52056 .60159 m .54039 .59741 L .54568 .601 L p F P
0 g
s
.591 .801 .98 r
.54039 .59741 m .52056 .60159 L .51516 .59779 L p F P
0 g
s
.715 .757 .885 r
.29166 .30982 m .27241 .32076 L .27882 .32576 L p F P
0 g
s
.715 .757 .885 r
.27882 .32576 m .2979 .31607 L .29166 .30982 L p F P
0 g
s
.772 .806 .88 r
.27053 .32212 m .27241 .32076 L .27882 .32576 L p F P
0 g
s
.873 .436 .059 r
.45007 .47057 m .45631 .47662 L .45286 .46913 L p F P
0 g
s
.873 .436 .059 r
.44696 .46359 m .45007 .47057 L p .45286 .46913 L F P
0 g
s
.873 .436 .059 r
.45286 .46913 m .44989 .46618 L .44696 .46359 L p F P
0 g
s
0 0 .549 r
.24896 .47452 m .24568 .47013 L .2516 .48085 L p F P
0 g
s
0 0 .549 r
.2516 .48085 m .2523 .48182 L .24896 .47452 L p F P
0 g
s
0 0 .57 r
.24397 .46785 m .24568 .47013 L .2516 .48085 L p F P
0 g
s
.627 .837 .981 r
.59083 .59348 m .57081 .59935 L .56562 .59598 L p F P
0 g
s
.6 .829 .987 r
.54568 .601 m .56562 .59598 L .57081 .59935 L p F P
0 g
s
.254 .355 .774 r
.81957 .35509 m .819 .36345 L .81129 .35738 L p F P
0 g
s
.254 .355 .774 r
.81129 .35738 m .8117 .34907 L .81957 .35509 L p F P
0 g
s
.643 .321 .411 r
.5419 .5101 m .52599 .51068 L .5329 .51727 L p F P
0 g
s
.657 .317 .385 r
.51467 .51717 m .5329 .51727 L .52599 .51068 L p F P
0 g
s
.657 .317 .385 r
.52599 .51068 m .51679 .51063 L .51467 .51717 L p F P
0 g
s
.716 .379 .406 r
.51083 .51673 m .51467 .51717 L .51679 .51063 L p F P
0 g
s
.716 .379 .406 r
.51679 .51063 m .50624 .50939 L .51083 .51673 L p F P
0 g
s
.61 .819 .981 r
.56562 .59598 m .54568 .601 L .54039 .59741 L p F P
0 g
s
.812 .943 .587 r
.80516 .47104 m .80112 .48001 L .8083 .46867 L p F P
0 g
s
.812 .943 .587 r
.80615 .46941 m .80516 .47104 L p .8083 .46867 L F P
0 g
s
.812 .943 .587 r
.8083 .46867 m .80903 .46704 L .80615 .46941 L p F P
0 g
s
0 0 0 r
.61832 .44448 m .61843 .44435 L .61135 .45462 L p F P
0 g
s
0 0 0 r
.61189 .45521 m .61832 .44448 L p .61135 .45462 L F P
0 g
s
0 0 0 r
.6033 .46588 m .61189 .45521 L p .61135 .45462 L F P
0 g
s
0 0 0 r
.61135 .45462 m .60345 .46551 L .6033 .46588 L p F P
0 g
s
.245 .526 .916 r
.31703 .54109 m .30804 .53811 L .30303 .5317 L p F P
0 g
s
.221 .524 .918 r
.30804 .53811 m .31703 .54109 L .32309 .54756 L p F P
0 g
s
.751 .954 .941 r
.72501 .54979 m .71091 .55852 L .70645 .55705 L p F P
0 g
s
.94 .945 .762 r
.65251 .38644 m .65008 .3901 L .64937 .39859 L p F P
0 g
s
.94 .945 .761 r
.64261 .4014 m .64072 .41026 L .64937 .39859 L p F P
0 g
s
.94 .945 .761 r
.64937 .39859 m .65008 .3901 L .64261 .4014 L p F P
0 g
s
.094 .293 .773 r
.40051 .39189 m .40282 .39377 L .40388 .39858 L closepath p F P
0 g
s
.538 .222 .38 r
.56188 .51233 m .56331 .50522 L .5419 .5101 L p F P
0 g
s
.538 .222 .38 r
.5419 .5101 m .54021 .51701 L .56188 .51233 L p F P
0 g
s
.643 .321 .411 r
.5329 .51727 m .54021 .51701 L .5419 .5101 L p F P
0 g
s
.884 .464 .196 r
.45961 .48423 m .46732 .48972 L .46376 .4822 L p F P
0 g
s
.884 .464 .196 r
.46376 .4822 m .45631 .47662 L .45961 .48423 L p F P
0 g
s
.71 .929 .963 r
.68157 .56606 m .6862 .56811 L .66601 .57823 L p F P
0 g
s
.71 .929 .963 r
.67703 .56837 m .68157 .56606 L p .66601 .57823 L F P
0 g
s
.71 .929 .963 r
.66601 .57823 m .66483 .57776 L .67703 .56837 L p F P
0 g
s
.718 .887 .496 r
.61855 .44412 m .61843 .44435 L .62175 .4402 L p F P
0 g
s
.718 .887 .496 r
.62175 .4402 m .62578 .43286 L .61855 .44412 L p F P
0 g
s
.379 .658 .967 r
.38768 .57755 m .38415 .57719 L .37824 .57199 L p F P
0 g
s
0 .162 .702 r
.24896 .47452 m .2523 .48182 L .2586 .48809 L p F P
0 g
s
0 .169 .706 r
.26228 .49521 m .2586 .48809 L .2523 .48182 L p F P
0 g
s
0 0 .409 r
.24208 .4633 m .24397 .46785 L p .23722 .4533 L F P
0 g
s
0 .012 .586 r
.24208 .4633 m .24568 .47013 L .24397 .46785 L closepath p F P
0 g
s
.569 .617 .861 r
.3395 .3138 m .32294 .31697 L .32891 .3251 L p F P
0 g
s
.569 .617 .861 r
.32891 .3251 m .33611 .32424 L .3395 .3138 L p F P
0 g
s
.528 .582 .853 r
.35803 .34009 m .3593 .34226 L .35749 .34227 L closepath p F P
0 g
s
0 0 .188 r
.82649 .41237 m .82464 .42089 L .82479 .41195 L p F P
0 g
s
0 0 .188 r
.82479 .41195 m .82662 .40342 L .82649 .41237 L p F P
0 g
s
.763 .424 .41 r
.49563 .51387 m .51083 .51673 L .50624 .50939 L p F P
0 g
s
.763 .424 .41 r
.50624 .50939 m .49212 .50619 L .49563 .51387 L p F P
0 g
s
.45 .552 .868 r
.80047 .33604 m .79221 .33407 L .7876 .3255 L p F P
0 g
s
.229 .529 .919 r
.3211 .5424 m .31703 .54109 L .32309 .54756 L p F P
0 g
s
.229 .529 .919 r
.32309 .54756 m .32645 .54865 L .3211 .5424 L p F P
0 g
s
0 .276 .78 r
.2586 .48809 m .26228 .49521 L .26992 .50108 L p F P
0 g
s
0 .259 .769 r
.27391 .50802 m .26992 .50108 L .26228 .49521 L p F P
0 g
s
.675 .368 0 r
.23476 .4465 m .23722 .4533 L p .232 .43818 L F P
0 g
s
0 0 .428 r
.23476 .4465 m .23984 .45831 L .23722 .4533 L closepath p F P
0 g
s
0 0 .409 r
.23722 .4533 m .23984 .45831 L .24208 .4633 L p F P
0 g
s
.478 .736 .984 r
.43975 .59255 m .44026 .59253 L .43916 .5921 L closepath p F P
0 g
s
.976 .905 .675 r
.23333 .36225 m .23417 .36956 L .22945 .3795 L p F P
0 g
s
.679 .72 .881 r
.7366 .32067 m .75723 .31284 L .7618 .31995 L p F P
0 g
s
.689 .729 .881 r
.75723 .31284 m .7366 .32067 L .73199 .31429 L p F P
0 g
s
.838 .944 .583 r
.80903 .46704 m .80615 .46941 L .81186 .45981 L closepath p F P
0 g
s
.993 .877 .562 r
.22783 .39727 m .22649 .38882 L .22945 .3795 L p F P
0 g
s
.967 .809 .381 r
.22649 .38882 m .22783 .39727 L .22645 .40602 L p F P
0 g
s
.981 .811 .405 r
.22743 .41066 m .22645 .40602 L .22783 .39727 L p F P
0 g
s
.701 .76 .262 r
.8197 .44045 m .81687 .44917 L .82031 .43908 L p F P
0 g
s
.701 .76 .262 r
.8209 .43679 m .8197 .44045 L p .82031 .43908 L F P
0 g
s
.701 .76 .262 r
.82031 .43908 m .82204 .43375 L .8209 .43679 L p F P
0 g
s
.525 .744 .975 r
.45351 .58622 m .45918 .59093 L .44026 .59253 L p F P
0 g
s
.525 .744 .975 r
.43403 .5879 m .45351 .58622 L p .44026 .59253 L F P
0 g
s
.525 .744 .975 r
.44026 .59253 m .43916 .5921 L .43403 .5879 L p F P
0 g
s
.306 .597 .947 r
.35411 .5641 m .35354 .56398 L .34754 .55819 L p F P
0 g
s
.016 .36 .833 r
.28688 .51992 m .28738 .52022 L .28903 .52255 L closepath p F P
0 g
s
.498 .567 .856 r
.3593 .34226 m .3738 .34433 L p .35898 .33272 L F P
0 g
s
.498 .567 .856 r
.35898 .33272 m .35803 .34009 L .3593 .34226 L p F P
0 g
s
.588 .659 .887 r
.7618 .31995 m .7815 .3174 L .78161 .32573 L p F P
0 g
s
.601 .664 .883 r
.7815 .3174 m .7618 .31995 L .75723 .31284 L p F P
0 g
s
.849 .452 .291 r
.47077 .49735 m .4807 .50204 L .47672 .49459 L p F P
0 g
s
.849 .452 .291 r
.47672 .49459 m .46732 .48972 L .47077 .49735 L p F P
0 g
s
.484 .727 .979 r
.43916 .5921 m .43403 .5879 L .43038 .58805 L closepath p F P
0 g
s
.899 .685 .174 r
.22645 .40602 m .22743 .41066 L .22784 .42054 L p F P
0 g
s
.931 .706 .223 r
.22833 .42245 m .22784 .42054 L .22743 .41066 L p F P
0 g
s
0 0 .016 r
.60345 .46551 m .60274 .46633 L .6033 .46588 L closepath p F P
0 g
s
.306 .597 .947 r
.34754 .55819 m .34785 .55825 L .35411 .5641 L p F P
0 g
s
.379 .635 .955 r
.36633 .56064 m .34785 .55825 L .35411 .5641 L p F P
0 g
s
.379 .635 .955 r
.35411 .5641 m .3723 .56647 L .36633 .56064 L p F P
0 g
s
0 0 .039 r
.60106 .47163 m .59234 .47867 L .60274 .46633 L p F P
0 g
s
0 0 .039 r
.60274 .46633 m .6033 .46588 L .60106 .47163 L p F P
0 g
s
.169 .307 .762 r
.40239 .38524 m .39491 .3803 L .40051 .39189 L p F P
0 g
s
.169 .307 .762 r
.40051 .39189 m .40282 .39377 L .40239 .38524 L p F P
0 g
s
.359 .448 .816 r
.39402 .37993 m .39491 .3803 L .40051 .39189 L p F P
0 g
s
.744 .249 0 r
.44989 .46618 m .44696 .46359 L .4466 .46308 L closepath p F P
0 g
s
.096 .386 .845 r
.28079 .51206 m .27391 .50802 L .26992 .50108 L p F P
0 g
s
.056 .372 .839 r
.27391 .50802 m .28079 .51206 L .28688 .51992 L p F P
0 g
s
.894 .988 .749 r
.63505 .41275 m .64261 .4014 L .64072 .41026 L p F P
0 g
s
.894 .988 .749 r
.63438 .41529 m .63505 .41275 L p .64072 .41026 L F P
0 g
s
.894 .988 .749 r
.64072 .41026 m .63776 .41423 L .63438 .41529 L p F P
0 g
s
.805 .538 0 r
.23023 .43245 m .232 .43818 L p .22833 .42245 L F P
0 g
s
.675 .368 0 r
.232 .43818 m .23415 .44468 L .23476 .4465 L p F P
0 g
s
0 0 .24 r
.23023 .43245 m .23415 .44468 L .232 .43818 L closepath p F P
0 g
s
.709 .902 .965 r
.66483 .57776 m .66128 .57589 L .67703 .56837 L closepath p F P
0 g
s
.854 .984 .701 r
.79633 .48297 m .79215 .49196 L .80112 .48001 L p F P
0 g
s
.854 .984 .701 r
.80112 .48001 m .80516 .47104 L .79633 .48297 L p F P
0 g
s
.76 .973 .923 r
.73104 .54572 m .72501 .54979 L .72919 .54529 L closepath p F P
0 g
s
.751 .954 .941 r
.72668 .54426 m .72919 .54529 L .72501 .54979 L p F P
0 g
s
.751 .954 .941 r
.70645 .55705 m .72668 .54426 L p .72501 .54979 L F P
0 g
s
.396 .1 .34 r
.57966 .49178 m .56387 .5027 L .56331 .50522 L p F P
0 g
s
0 0 0 r
.60539 .46628 m .60106 .47163 L .6033 .46588 L p F P
0 g
s
0 0 0 r
.6033 .46588 m .61189 .45521 L .60539 .46628 L p F P
0 g
s
.379 .658 .967 r
.37824 .57199 m .38022 .57219 L .38768 .57755 L p F P
0 g
s
.437 .683 .968 r
.3973 .57287 m .38022 .57219 L .38768 .57755 L p F P
0 g
s
.437 .683 .968 r
.38768 .57755 m .40317 .57817 L .3973 .57287 L p F P
0 g
s
.497 .566 .856 r
.35353 .33238 m .35898 .33272 L .35803 .34009 L closepath p F P
0 g
s
.804 .828 .87 r
.69526 .33975 m .69179 .34245 L .68709 .3375 L p F P
0 g
s
.865 .853 .828 r
.68108 .35334 m .69179 .34245 L .68709 .3375 L p F P
0 g
s
.487 .521 .817 r
.38368 .35661 m .3719 .35396 L .3738 .34433 L p F P
0 g
s
.449 .495 .815 r
.38502 .35944 m .38364 .36669 L p .3719 .35396 L F P
0 g
s
.449 .495 .815 r
.3719 .35396 m .38368 .35661 L .38502 .35944 L p F P
0 g
s
.847 .998 .78 r
.79134 .49352 m .79068 .49362 L .79215 .49196 L closepath p F P
0 g
s
.818 .828 .857 r
.69526 .33975 m .71174 .32653 L .70707 .32074 L p F P
0 g
s
.818 .828 .857 r
.70707 .32074 m .69414 .3317 L .69526 .33975 L p F P
0 g
s
.804 .828 .87 r
.68709 .3375 m .69414 .3317 L .69526 .33975 L p F P
0 g
s
.553 .628 .88 r
.783 .31728 m .7815 .3174 L .78161 .32573 L p F P
0 g
s
.553 .628 .88 r
.78161 .32573 m .7876 .3255 L .783 .31728 L p F P
0 g
s
.928 .973 .724 r
.63776 .41423 m .63297 .42165 L .63438 .41529 L closepath p F P
0 g
s
0 .058 .623 r
.24568 .47013 m .24896 .47452 L p .24092 .46037 L F P
0 g
s
0 .058 .623 r
.24092 .46037 m .24208 .4633 L .24568 .47013 L p F P
0 g
s
.692 .893 .97 r
.66128 .57589 m .64106 .58466 L .6362 .58216 L p F P
0 g
s
.779 .975 .915 r
.74843 .53324 m .73104 .54572 L .72919 .54529 L p F P
0 g
s
.857 .871 .849 r
.66744 .35837 m .67978 .34539 L .68108 .35334 L p F P
0 g
s
.857 .871 .849 r
.66745 .35857 m .66744 .35837 L p .68108 .35334 L F P
0 g
s
.857 .871 .849 r
.68108 .35334 m .67206 .36225 L .66745 .35857 L p F P
0 g
s
.865 .853 .828 r
.68709 .3375 m .67978 .34539 L .68108 .35334 L p F P
0 g
s
0 0 .383 r
.828 .39496 m .82662 .40342 L .82516 .39505 L p F P
0 g
s
0 0 .383 r
.82516 .39505 m .82654 .38658 L .828 .39496 L p F P
0 g
s
.322 .582 .936 r
.34152 .55206 m .32645 .54865 L .3211 .5424 L p F P
0 g
s
.304 .584 .941 r
.32645 .54865 m .34152 .55206 L .34754 .55819 L p F P
0 g
s
.666 .869 .976 r
.61707 .59056 m .61599 .58992 L .62586 .58619 L closepath p F P
0 g
s
.05 .368 .837 r
.28313 .51343 m .28079 .51206 L .28688 .51992 L p F P
0 g
s
.05 .368 .837 r
.28688 .51992 m .28738 .52022 L .28313 .51343 L p F P
0 g
s
.538 .767 .982 r
.46481 .59538 m .48442 .59285 L .48996 .59712 L p F P
0 g
s
.549 .759 .975 r
.48442 .59285 m .46481 .59538 L .45918 .59093 L p F P
0 g
s
.201 0 .233 r
.59885 .47749 m .60106 .47163 L .59234 .47867 L p F P
0 g
s
.201 0 .233 r
.58349 .49005 m .59885 .47749 L p .59234 .47867 L F P
0 g
s
.201 0 .233 r
.59234 .47867 m .58376 .48903 L .58349 .49005 L p F P
0 g
s
.892 .864 .805 r
.67206 .36225 m .66889 .36623 L .66745 .35857 L closepath p F P
0 g
s
.409 .473 .815 r
.38502 .35944 m .3893 .36848 L .38364 .36669 L closepath p F P
0 g
s
.409 .473 .815 r
.39415 .3787 m .39402 .37993 L p .38364 .36669 L F P
0 g
s
.409 .473 .815 r
.38364 .36669 m .3893 .36848 L .39415 .3787 L p F P
0 g
s
.787 .527 0 r
.22784 .42054 m .22895 .42618 L .22833 .42245 L closepath p F P
0 g
s
.805 .538 0 r
.22833 .42245 m .22895 .42618 L .23023 .43245 L p F P
0 g
s
.182 .461 .884 r
.28313 .51343 m .28738 .52022 L .29844 .52508 L p F P
0 g
s
.175 .47 .891 r
.30303 .5317 m .29844 .52508 L .28738 .52022 L p F P
0 g
s
.751 .789 .884 r
.71679 .32354 m .71174 .32653 L .70707 .32074 L p F P
0 g
s
.812 .44 .352 r
.4841 .50975 m .49563 .51387 L .49212 .50619 L p F P
0 g
s
.812 .44 .352 r
.48277 .50613 m .4841 .50975 L p .49212 .50619 L F P
0 g
s
.812 .44 .352 r
.49212 .50619 m .48474 .50342 L .48277 .50613 L p F P
0 g
s
.892 .864 .805 r
.65867 .3701 m .65922 .37825 L .66889 .36623 L p F P
0 g
s
.892 .864 .805 r
.66733 .35848 m .65867 .3701 L p .66889 .36623 L F P
0 g
s
.892 .864 .805 r
.66889 .36623 m .66745 .35857 L .66733 .35848 L p F P
0 g
s
.852 .998 .786 r
.78681 .49411 m .79633 .48297 L .79215 .49196 L p F P
0 g
s
.852 .998 .786 r
.79215 .49196 m .79068 .49362 L .78681 .49411 L p F P
0 g
s
.599 .63 .853 r
.3477 .32272 m .33611 .32424 L .3395 .3138 L p F P
0 g
s
.575 .611 .851 r
.33611 .32424 m .3477 .32272 L .35353 .33238 L p F P
0 g
s
.661 .708 .882 r
.31079 .30176 m .29166 .30982 L .2979 .31607 L p F P
0 g
s
.661 .708 .882 r
.2979 .31607 m .3169 .30916 L .31079 .30176 L p F P
0 g
s
.839 .997 .77 r
.78058 .50476 m .79068 .49362 L .78681 .49411 L p F P
0 g
s
0 .038 .607 r
.4276 .43588 m .42487 .42841 L .41918 .4219 L p F P
0 g
s
0 .155 .692 r
.43287 .4426 m .4276 .43588 L .42487 .42841 L p F P
0 g
s
0 0 .506 r
.4366 .44965 m .43287 .4426 L .4276 .43588 L p F P
0 g
s
0 .135 .681 r
.41918 .4219 m .41732 .41405 L .41102 .40783 L p F P
0 g
s
0 .158 .692 r
.41732 .41405 m .41918 .4219 L .42487 .42841 L p F P
0 g
s
.363 .05 .294 r
.58376 .48903 m .57966 .49178 L .58349 .49005 L closepath p F P
0 g
s
.396 .1 .34 r
.58187 .49678 m .58349 .49005 L .57966 .49178 L p F P
0 g
s
.396 .1 .34 r
.56331 .50522 m .58187 .49678 L p .57966 .49178 L F P
0 g
s
.363 .447 .813 r
.39415 .3787 m .39491 .3803 L .39402 .37993 L closepath p F P
0 g
s
.446 .708 .978 r
.40901 .58319 m .42132 .58327 L .43038 .58805 L p F P
0 g
s
.456 .702 .973 r
.42132 .58327 m .40901 .58319 L .40317 .57817 L p F P
0 g
s
.091 .29 .771 r
.41102 .40783 m .40993 .39962 L .40282 .39377 L p F P
0 g
s
.061 .238 .733 r
.40993 .39962 m .41102 .40783 L .41732 .41405 L p F P
0 g
s
.167 .306 .762 r
.40239 .38524 m .40282 .39377 L .40993 .39962 L p F P
0 g
s
.58 .128 0 r
.44406 .4597 m .4466 .46308 L p .4366 .44965 L F P
0 g
s
.58 .128 0 r
.44132 .45606 m .44406 .4597 L p .442 .45693 L F P
0 g
s
.58 .128 0 r
.4366 .44965 m .44132 .45606 L p .442 .45693 L F P
0 g
s
.718 .317 0 r
.44132 .45606 m .44156 .45655 L .44111 .45578 L p F P
0 g
s
0 .018 .587 r
.43572 .44622 m .44132 .45606 L p .43677 .44882 L F P
0 g
s
0 .018 .587 r
.43287 .4426 m .43572 .44622 L p .43677 .44882 L F P
0 g
s
.718 .317 0 r
.43748 .44963 m .43572 .44622 L .43601 .44674 L p F P
0 g
s
.718 .317 0 r
.43601 .44674 m .44132 .45606 L p .43748 .44963 L F P
0 g
s
0 .018 .587 r
.44132 .45606 m .4366 .44965 L .43287 .4426 L p F P
0 g
s
.741 .343 0 r
.44114 .45705 m .43748 .44963 L p .43816 .45093 L F P
0 g
s
.741 .343 0 r
.44499 .46406 m .44114 .45705 L p .43816 .45093 L F P
0 g
s
.741 .356 0 r
.44467 .46459 m .44114 .45705 L p .44168 .45816 L F P
0 g
s
.741 .356 0 r
.44827 .47167 m .44467 .46459 L p .44168 .45816 L F P
0 g
s
.737 .366 0 r
.44808 .47223 m .44467 .46459 L p .44511 .46556 L F P
0 g
s
.737 .366 0 r
.45142 .4794 m .44808 .47223 L p .44511 .46556 L F P
0 g
s
.834 .404 0 r
.44696 .46359 m .45007 .47057 L p .44156 .45655 L F P
0 g
s
.834 .404 0 r
.45007 .47057 m .44499 .46406 L .44156 .45655 L p F P
0 g
s
.854 .434 0 r
.44499 .46406 m .45007 .47057 L .45329 .47821 L p F P
0 g
s
.854 .434 0 r
.45329 .47821 m .44827 .47167 L .44499 .46406 L p F P
0 g
s
.866 .453 .004 r
.44827 .47167 m .45329 .47821 L .45635 .48596 L p F P
0 g
s
.741 .356 0 r
.44114 .45705 m .44499 .46406 L .44827 .47167 L p F P
0 g
s
.866 .453 .004 r
.45635 .48596 m .45142 .4794 L .44827 .47167 L p F P
0 g
s
.737 .366 0 r
.44467 .46459 m .44827 .47167 L .45142 .4794 L p F P
0 g
s
.73 .374 0 r
.44808 .47223 m .45142 .4794 L .45441 .48725 L p F P
0 g
s
0 0 .534 r
.44808 .47223 m .44673 .46429 L p .45107 .47894 L F P
0 g
s
0 0 .534 r
.45138 .47997 m .44808 .47223 L p .45107 .47894 L F P
0 g
s
0 0 .422 r
.44467 .46459 m .44808 .47223 L p .44768 .47107 L F P
0 g
s
.834 .404 0 r
.44156 .45655 m .44406 .4597 L .44696 .46359 L p F P
0 g
s
.817 .381 0 r
.44132 .45606 m .44156 .45655 L .44406 .4597 L closepath p F P
0 g
s
.741 .343 0 r
.43748 .44963 m .44156 .45655 L .44499 .46406 L p F P
0 g
s
0 0 .422 r
.44279 .45683 m .44467 .46459 L p .44768 .47107 L F P
0 g
s
0 0 .406 r
.44114 .45705 m .44467 .46459 L p .44414 .46322 L F P
0 g
s
.718 .317 0 r
.44111 .45578 m .43748 .44963 L p .44132 .45606 L F P
0 g
s
0 0 .406 r
.43879 .44945 m .44114 .45705 L p .44414 .46322 L F P
0 g
s
0 0 .394 r
.43748 .44963 m .44114 .45705 L p .44046 .45548 L F P
0 g
s
0 0 .394 r
.43471 .44217 m .43748 .44963 L p .44046 .45548 L F P
0 g
s
0 0 .475 r
.43572 .44622 m .43748 .44963 L p .43485 .44409 L F P
0 g
s
0 0 .475 r
.43052 .43499 m .43572 .44622 L .43485 .44409 L F
.731 .927 .956 r
.70526 .55775 m .6862 .56811 L .68157 .56606 L p F P
0 g
s
.928 .972 .72 r
.62858 .42374 m .62578 .43286 L .63297 .42165 L p F P
0 g
s
.928 .972 .72 r
.63305 .41572 m .62858 .42374 L p .63297 .42165 L F P
0 g
s
.928 .972 .72 r
.63297 .42165 m .63438 .41529 L .63305 .41572 L p F P
0 g
s
.811 .841 .873 r
.25282 .33632 m .25158 .33586 L p .27061 .31953 L F P
0 g
s
.811 .841 .873 r
.27061 .31953 m .27053 .32212 L .25282 .33632 L p F P
0 g
s
.86 .872 .846 r
.25282 .33632 m .25161 .33754 L .25158 .33586 L closepath p F P
0 g
s
.976 .905 .675 r
.22945 .3795 m .22848 .37081 L p .23333 .36225 L F P
0 g
s
.988 .883 .547 r
.22848 .37081 m .22945 .3795 L .22649 .38882 L p F P
0 g
s
.889 .891 .825 r
.25158 .33586 m .25161 .33754 L .24095 .34974 L p F P
0 g
s
.763 .789 .874 r
.71679 .32354 m .73199 .31429 L .72735 .30786 L p F P
0 g
s
.763 .789 .874 r
.72735 .30786 m .71538 .31555 L .71679 .32354 L p F P
0 g
s
.751 .789 .884 r
.70707 .32074 m .71538 .31555 L .71679 .32354 L p F P
0 g
s
.791 .989 .888 r
.75111 .53111 m .74843 .53324 L .75017 .531 L closepath p F P
0 g
s
.779 .975 .915 r
.74687 .52989 m .75017 .531 L .74843 .53324 L p F P
0 g
s
.779 .975 .915 r
.73365 .5396 m .74687 .52989 L p .74843 .53324 L F P
0 g
s
.779 .975 .915 r
.72919 .54529 m .73365 .5396 L p .74843 .53324 L F P
0 g
s
0 0 .411 r
.23984 .45831 m .24092 .46037 L .24208 .4633 L closepath p F P
0 g
s
.388 .102 .353 r
.58034 .50368 m .58187 .49678 L .56331 .50522 L p F P
0 g
s
.388 .102 .353 r
.56331 .50522 m .56188 .51233 L .58034 .50368 L p F P
0 g
s
.806 .99 .881 r
.76634 .51842 m .75111 .53111 L .75017 .531 L p F P
0 g
s
.816 .886 .46 r
.81474 .4511 m .81186 .45981 L .81687 .44917 L p F P
0 g
s
.816 .886 .46 r
.81687 .44917 m .8197 .44045 L .81474 .4511 L p F P
0 g
s
.671 .86 .972 r
.62586 .58619 m .61599 .58992 L .61099 .58672 L p F P
0 g
s
.647 .853 .979 r
.59083 .59348 m .61099 .58672 L .61599 .58992 L p F P
0 g
s
.607 .156 0 r
.44406 .4597 m .44696 .46359 L .4466 .46308 L closepath p F P
0 g
s
.31 .415 .807 r
.39491 .3803 m .40239 .38524 L p .39434 .37105 L F P
0 g
s
.31 .415 .807 r
.39434 .37105 m .39415 .3787 L .39491 .3803 L p F P
0 g
s
.567 .784 .981 r
.48996 .59712 m .50972 .59366 L .51516 .59779 L p F P
0 g
s
.588 .77 .966 r
.50972 .59366 m .48996 .59712 L .48442 .59285 L p F P
0 g
s
0 0 0 r
.82484 .42188 m .82297 .43038 L .82464 .42089 L p F P
0 g
s
0 0 0 r
.82464 .42089 m .82649 .41237 L .82484 .42188 L p F P
0 g
s
.839 .997 .77 r
.78681 .49411 m .78552 .49557 L .78058 .50476 L p F P
0 g
s
.831 .998 .837 r
.77191 .50908 m .78552 .49557 L .78058 .50476 L p F P
0 g
s
.831 .998 .837 r
.76917 .51402 m .77191 .50908 L p .78058 .50476 L F P
0 g
s
.831 .998 .837 r
.78058 .50476 m .77104 .51403 L .76917 .51402 L p F P
0 g
s
0 .036 .565 r
.82719 .38097 m .82654 .38658 L .82331 .37885 L p F P
0 g
s
0 .036 .565 r
.82506 .37217 m .82719 .38097 L p .82331 .37885 L F P
0 g
s
0 .036 .565 r
.82331 .37885 m .8243 .37042 L .82506 .37217 L p F P
0 g
s
.889 .463 .106 r
.45329 .47821 m .45961 .48423 L .45631 .47662 L p F P
0 g
s
.889 .463 .106 r
.45631 .47662 m .45007 .47057 L .45329 .47821 L p F P
0 g
s
.31 .415 .807 r
.3893 .36848 m .39434 .37105 L .39415 .3787 L closepath p F P
0 g
s
.819 .998 .843 r
.77104 .51403 m .76634 .51842 L .76917 .51402 L closepath p F P
0 g
s
.899 .685 .174 r
.22784 .42054 m .22648 .41429 L .22645 .40602 L p F P
0 g
s
.726 .48 0 r
.22648 .41429 m .22784 .42054 L .22895 .42618 L p F P
0 g
s
.806 .99 .881 r
.76695 .51346 m .76917 .51402 L .76634 .51842 L p F P
0 g
s
.806 .99 .881 r
.75502 .52363 m .76695 .51346 L p .76634 .51842 L F P
0 g
s
.806 .99 .881 r
.75017 .531 m .75502 .52363 L p .76634 .51842 L F P
0 g
s
.596 .637 .862 r
.3359 .30433 m .3169 .30916 L .32294 .31697 L p F P
0 g
s
.596 .637 .862 r
.34058 .31144 m .3359 .30433 L p .32294 .31697 L F P
0 g
s
.596 .637 .862 r
.32294 .31697 m .3395 .3138 L .34058 .31144 L p F P
0 g
s
.505 .547 .833 r
.36248 .3223 m .3477 .32272 L .35353 .33238 L p F P
0 g
s
.505 .547 .833 r
.35353 .33238 m .35898 .33272 L .36248 .3223 L p F P
0 g
s
0 0 .483 r
.23984 .45831 m .24092 .46037 L p .23447 .44564 L F P
0 g
s
0 0 .483 r
.23447 .44564 m .23476 .4465 L .23984 .45831 L p F P
0 g
s
.45 .552 .868 r
.7876 .3255 m .79986 .32795 L .80047 .33604 L p F P
0 g
s
.461 .567 .876 r
.79986 .32795 m .7876 .3255 L .783 .31728 L p F P
0 g
s
.905 .923 .818 r
.64972 .38191 m .65867 .3701 L .65922 .37825 L p F P
0 g
s
.905 .923 .818 r
.64965 .38526 m .64972 .38191 L p .65922 .37825 L F P
0 g
s
.905 .923 .818 r
.65922 .37825 m .65251 .38644 L .64965 .38526 L p F P
0 g
s
.491 .721 .974 r
.42827 .58299 m .42132 .58327 L .43038 .58805 L p F P
0 g
s
.491 .721 .974 r
.43038 .58805 m .43403 .5879 L .42827 .58299 L p F P
0 g
s
.12 0 .218 r
.59879 .47767 m .59885 .47749 L .58349 .49005 L p F P
0 g
s
.12 0 .218 r
.59173 .48872 m .59879 .47767 L p .58349 .49005 L F P
0 g
s
.12 0 .218 r
.58349 .49005 m .58187 .49678 L .59173 .48872 L p F P
0 g
s
.788 .823 .879 r
.27241 .32076 m .27053 .32212 L .27061 .31953 L closepath p F P
0 g
s
.967 .809 .381 r
.22645 .40602 m .22508 .39759 L .22649 .38882 L p F P
0 g
s
.866 .669 .138 r
.22508 .39759 m .22645 .40602 L .22648 .41429 L p F P
0 g
s
.37 .485 .846 r
.81157 .33551 m .81177 .3408 L .80047 .33604 L p F P
0 g
s
.37 .485 .846 r
.80988 .33181 m .81157 .33551 L p .80047 .33604 L F P
0 g
s
.37 .485 .846 r
.80047 .33604 m .79986 .32795 L .80988 .33181 L p F P
0 g
s
.651 .845 .974 r
.61099 .58672 m .59083 .59348 L .58571 .59007 L p F P
0 g
s
.627 .837 .981 r
.56562 .59598 m .58571 .59007 L .59083 .59348 L p F P
0 g
s
.591 .801 .98 r
.51516 .59779 m .53505 .59346 L .54039 .59741 L p F P
0 g
s
.615 .782 .962 r
.53505 .59346 m .51516 .59779 L .50972 .59366 L p F P
0 g
s
.811 .841 .873 r
.25158 .33586 m .25258 .32793 L p .27061 .31953 L F P
0 g
s
.865 .899 .855 r
.25258 .32793 m .25158 .33586 L .24598 .33449 L closepath p F P
0 g
s
.889 .891 .825 r
.24097 .34054 m .24598 .33449 L .25158 .33586 L p F P
0 g
s
.889 .891 .825 r
.24095 .34974 m .24097 .34054 L p .25158 .33586 L F P
0 g
s
.765 .823 .898 r
.28532 .3041 m .29166 .30982 L .27241 .32076 L p F P
0 g
s
.765 .823 .898 r
.27256 .31206 m .28532 .3041 L p .27241 .32076 L F P
0 g
s
.765 .823 .898 r
.27241 .32076 m .27061 .31953 L .27256 .31206 L p F P
0 g
s
.74 .774 .275 r
.82204 .43375 m .8209 .43679 L .82297 .43038 L closepath p F P
0 g
s
.886 .477 .233 r
.46277 .49195 m .47077 .49735 L .46732 .48972 L p F P
0 g
s
.886 .477 .233 r
.46732 .48972 m .45961 .48423 L .46277 .49195 L p F P
0 g
s
.268 .527 .913 r
.31095 .53427 m .30303 .5317 L .29844 .52508 L p F P
0 g
s
.245 .526 .916 r
.30303 .5317 m .31095 .53427 L .31703 .54109 L p F P
0 g
s
.935 .921 .774 r
.24097 .34054 m .24095 .34974 L .23329 .36081 L p F P
0 g
s
.922 .909 .791 r
.23333 .36225 m .23329 .36081 L .24095 .34974 L p F P
0 g
s
.726 .48 0 r
.22895 .42618 m .22964 .43029 L p .22648 .41429 L F P
0 g
s
.797 .532 0 r
.22895 .42618 m .22964 .43029 L .23023 .43245 L closepath p F P
0 g
s
.799 .422 .343 r
.48474 .50342 m .48277 .50613 L .4807 .50204 L closepath p F P
0 g
s
.132 .235 .705 r
.82436 .36946 m .8243 .37042 L .819 .36345 L p F P
0 g
s
.132 .235 .705 r
.81965 .35518 m .82436 .36946 L p .819 .36345 L F P
0 g
s
.132 .235 .705 r
.819 .36345 m .81957 .35509 L .81965 .35518 L p F P
0 g
s
.251 .529 .916 r
.31621 .53593 m .31095 .53427 L .31703 .54109 L p F P
0 g
s
.251 .529 .916 r
.31703 .54109 m .3211 .5424 L .31621 .53593 L p F P
0 g
s
.392 .653 .962 r
.38022 .57219 m .37824 .57199 L .3723 .56647 L p F P
0 g
s
.778 .948 .931 r
.72919 .54529 m .72668 .54426 L .73365 .5396 L closepath p F P
0 g
s
.647 .332 .424 r
.54021 .51701 m .53878 .5235 L .5329 .51727 L closepath p F P
0 g
s
.662 .332 .404 r
.53867 .52414 m .53878 .5235 L .5329 .51727 L p F P
0 g
s
.662 .332 .404 r
.51524 .52419 m .53867 .52414 L p .5329 .51727 L F P
0 g
s
.662 .332 .404 r
.51347 .52138 m .51524 .52419 L p .5329 .51727 L F P
0 g
s
.662 .332 .404 r
.5329 .51727 m .51467 .51717 L .51347 .52138 L p F P
0 g
s
.635 .825 .974 r
.58571 .59007 m .56562 .59598 L .56039 .59229 L p F P
0 g
s
.61 .819 .981 r
.54039 .59741 m .56039 .59229 L .56562 .59598 L p F P
0 g
s
.624 .804 .969 r
.56039 .59229 m .54039 .59741 L .53505 .59346 L p F P
0 g
s
.718 .389 .421 r
.51467 .51717 m .51347 .52138 L .51083 .51673 L closepath p F P
0 g
s
.27 .38 .791 r
.81957 .35496 m .81957 .35509 L .8117 .34907 L p F P
0 g
s
.27 .38 .791 r
.8147 .3428 m .81957 .35496 L p .8117 .34907 L F P
0 g
s
.27 .38 .791 r
.8117 .34907 m .81177 .3408 L .8147 .3428 L p F P
0 g
s
.556 .247 .399 r
.56058 .51965 m .56188 .51233 L .54021 .51701 L p F P
0 g
s
.556 .247 .399 r
.54015 .52382 m .56058 .51965 L p .54021 .51701 L F P
0 g
s
.556 .247 .399 r
.54021 .51701 m .53878 .5235 L .54015 .52382 L p F P
0 g
s
.806 .965 .909 r
.75017 .531 m .74687 .52989 L .75502 .52363 L closepath p F P
0 g
s
.933 .904 .771 r
.65251 .38644 m .65008 .3901 L .64965 .38526 L closepath p F P
0 g
s
.878 .947 .589 r
.62261 .4346 m .61855 .44412 L .62578 .43286 L p F P
0 g
s
.878 .947 .589 r
.62578 .43286 m .62858 .42374 L .62261 .4346 L p F P
0 g
s
.712 .387 .427 r
.49881 .52173 m .49563 .51387 L .51083 .51673 L p F P
0 g
s
.712 .387 .427 r
.51277 .52401 m .49881 .52173 L p .51083 .51673 L F P
0 g
s
.712 .387 .427 r
.51083 .51673 m .51347 .52138 L .51277 .52401 L p F P
0 g
s
.612 .676 .887 r
.77841 .30938 m .75723 .31284 L .75263 .30582 L p F P
0 g
s
.689 .729 .881 r
.73199 .31429 m .75263 .30582 L .75723 .31284 L p F P
0 g
s
.601 .664 .883 r
.78136 .31444 m .7815 .3174 L p .75723 .31284 L F P
0 g
s
.601 .664 .883 r
.75723 .31284 m .77841 .30938 L .78136 .31444 L p F P
0 g
s
.697 .735 .88 r
.75263 .30582 m .73199 .31429 L .72735 .30786 L p F P
0 g
s
0 .058 .623 r
.24896 .47452 m .24603 .46699 L .24092 .46037 L p F P
0 g
s
0 .183 .716 r
.24603 .46699 m .24896 .47452 L .25533 .48076 L p F P
0 g
s
0 .162 .702 r
.2586 .48809 m .25533 .48076 L .24896 .47452 L p F P
0 g
s
0 0 .226 r
.23415 .44468 m .23447 .44564 L .23476 .4465 L closepath p F P
0 g
s
0 0 .305 r
.23415 .44468 m .23447 .44564 L p .22964 .43029 L F P
0 g
s
0 0 .305 r
.22964 .43029 m .23023 .43245 L .23415 .44468 L p F P
0 g
s
.323 .594 .943 r
.34209 .55218 m .34152 .55206 L .34754 .55819 L p F P
0 g
s
.323 .594 .943 r
.34754 .55819 m .34785 .55825 L .34209 .55218 L p F P
0 g
s
0 0 .483 r
.24092 .46037 m .23835 .45264 L .23447 .44564 L p F P
0 g
s
0 .056 .622 r
.23835 .45264 m .24092 .46037 L .24603 .46699 L p F P
0 g
s
.967 .926 .7 r
.23329 .36081 m .23333 .36225 L .23212 .36299 L closepath p F P
0 g
s
.976 .905 .675 r
.22848 .37081 m .23212 .36299 L .23333 .36225 L p F P
0 g
s
.525 .735 .97 r
.45351 .58622 m .43403 .5879 L .42827 .58299 L p F P
0 g
s
.391 .63 .949 r
.36633 .56064 m .34785 .55825 L .34209 .55218 L p F P
0 g
s
.392 .653 .962 r
.3723 .56647 m .37334 .56658 L .38022 .57219 L p F P
0 g
s
.446 .677 .962 r
.3914 .56729 m .37334 .56658 L .38022 .57219 L p F P
0 g
s
.446 .677 .962 r
.38022 .57219 m .3973 .57287 L .3914 .56729 L p F P
0 g
s
.667 .883 .978 r
.6362 .58216 m .62586 .58619 L .63499 .58149 L closepath p F P
0 g
s
.671 .86 .972 r
.63127 .57905 m .63499 .58149 L .62586 .58619 L p F P
0 g
s
.671 .86 .972 r
.61099 .58672 m .63127 .57905 L p .62586 .58619 L F P
0 g
s
.934 .904 .771 r
.64255 .39313 m .64261 .4014 L .65008 .3901 L p F P
0 g
s
.934 .904 .771 r
.64775 .38448 m .64255 .39313 L p .65008 .3901 L F P
0 g
s
.934 .904 .771 r
.65008 .3901 m .64965 .38526 L .64775 .38448 L p F P
0 g
s
.035 .305 .794 r
.26634 .49392 m .2586 .48809 L .25533 .48076 L p F P
0 g
s
0 .276 .78 r
.26992 .50108 m .26634 .49392 L .2586 .48809 L p F P
0 g
s
.82 .427 .308 r
.4741 .50507 m .47077 .49735 L .4807 .50204 L p F P
0 g
s
.82 .427 .308 r
.48072 .50801 m .4741 .50507 L p .4807 .50204 L F P
0 g
s
.82 .427 .308 r
.4807 .50204 m .48277 .50613 L .48072 .50801 L p F P
0 g
s
.381 .457 .814 r
.3893 .36848 m .39434 .37105 L p .38531 .35722 L F P
0 g
s
.381 .457 .814 r
.38531 .35722 m .38502 .35944 L .3893 .36848 L p F P
0 g
s
.711 .897 .963 r
.67703 .56837 m .66128 .57589 L .65649 .57324 L p F P
0 g
s
.692 .893 .97 r
.6362 .58216 m .65649 .57324 L .66128 .57589 L p F P
0 g
s
.847 .949 .593 r
.8082 .4623 m .81474 .4511 L .81186 .45981 L p F P
0 g
s
.847 .949 .593 r
.80565 .4698 m .8082 .4623 L p .81186 .45981 L F P
0 g
s
.847 .949 .593 r
.81186 .45981 m .80615 .46941 L .80565 .4698 L p F P
0 g
s
.74 .948 .947 r
.70645 .55705 m .70526 .55775 L .70612 .55693 L closepath p F P
0 g
s
.731 .927 .956 r
.7019 .55479 m .70612 .55693 L .70526 .55775 L p F P
0 g
s
.731 .927 .956 r
.68157 .56606 m .7019 .55479 L p .70526 .55775 L F P
0 g
s
0 0 .305 r
.23447 .44564 m .23228 .43769 L .22964 .43029 L p F P
0 g
s
0 0 .496 r
.23228 .43769 m .23447 .44564 L .23835 .45264 L p F P
0 g
s
.776 .834 .897 r
.27256 .31206 m .27061 .31953 L .26588 .31653 L closepath p F P
0 g
s
.811 .841 .873 r
.25258 .32793 m .26588 .31653 L .27061 .31953 L p F P
0 g
s
.09 .38 .842 r
.2793 .50642 m .2747 .5038 L .28079 .51206 L p F P
0 g
s
.09 .38 .842 r
.28079 .51206 m .28313 .51343 L .2793 .50642 L p F P
0 g
s
.096 .386 .845 r
.26992 .50108 m .2747 .5038 L .28079 .51206 L p F P
0 g
s
0 0 .139 r
.82786 .40394 m .82649 .41237 L .82662 .40342 L p F P
0 g
s
0 0 .139 r
.82662 .40342 m .828 .39496 L .82786 .40394 L p F P
0 g
s
.766 .952 .936 r
.72224 .54232 m .72668 .54426 L .70645 .55705 L p F P
0 g
s
.766 .952 .936 r
.71441 .54737 m .72224 .54232 L p .70645 .55705 L F P
0 g
s
.766 .952 .936 r
.70645 .55705 m .70612 .55693 L .71441 .54737 L p F P
0 g
s
.133 .398 .848 r
.2747 .5038 m .26992 .50108 L .26634 .49392 L p F P
0 g
s
.935 .921 .774 r
.23329 .36081 m .23344 .35158 L .24097 .34054 L p F P
0 g
s
.965 .935 .693 r
.23344 .35158 m .23329 .36081 L .23212 .36299 L p F P
0 g
s
.988 .883 .547 r
.22649 .38882 m .22552 .38014 L .22848 .37081 L p F P
0 g
s
.947 .804 .352 r
.22552 .38014 m .22649 .38882 L .22508 .39759 L p F P
0 g
s
.545 .564 .825 r
.37234 .33333 m .35898 .33272 L .36248 .3223 L p F P
0 g
s
.498 .567 .856 r
.37543 .33962 m .37234 .33333 L .35898 .33272 L p F P
0 g
s
.498 .567 .856 r
.3738 .34433 m .37543 .33962 L p .35898 .33272 L F P
0 g
s
.756 .923 .945 r
.70612 .55693 m .7019 .55479 L .71441 .54737 L closepath p F P
0 g
s
.756 .784 .289 r
.82172 .43192 m .82484 .42188 L .82297 .43038 L p F P
0 g
s
.756 .784 .289 r
.82023 .4385 m .82172 .43192 L p .82297 .43038 L F P
0 g
s
.756 .784 .289 r
.82297 .43038 m .8209 .43679 L .82023 .4385 L p F P
0 g
s
.705 .876 .479 r
.61843 .44435 m .61832 .44448 L .61855 .44412 L closepath p F P
0 g
s
.726 .48 0 r
.22964 .43029 m .22784 .42211 L .22648 .41429 L p F P
0 g
s
0 0 .333 r
.22784 .42211 m .22964 .43029 L .23228 .43769 L p F P
0 g
s
.81 .818 .857 r
.69414 .3317 m .68709 .3375 L .68233 .33221 L p F P
0 g
s
.865 .833 .814 r
.67978 .34539 m .68709 .3375 L .68233 .33221 L p F P
0 g
s
.339 .58 .931 r
.33547 .54559 m .3211 .5424 L .31621 .53593 L p F P
0 g
s
.322 .582 .936 r
.3211 .5424 m .33547 .54559 L .34152 .55206 L p F P
0 g
s
.965 .935 .693 r
.23212 .36299 m .2282 .36634 L p .23344 .35158 L F P
0 g
s
.978 .916 .659 r
.23212 .36299 m .22848 .37081 L .2282 .36634 L closepath p F P
0 g
s
.672 .853 .448 r
.61666 .44548 m .62261 .4346 L .61855 .44412 L p F P
0 g
s
.672 .853 .448 r
.61524 .44875 m .61666 .44548 L p .61855 .44412 L F P
0 g
s
.672 .853 .448 r
.61855 .44412 m .61832 .44448 L .61524 .44875 L p F P
0 g
s
.714 .87 .461 r
.61832 .44448 m .61189 .45521 L .61524 .44875 L closepath p F P
0 g
s
.834 .979 .88 r
.76917 .51402 m .76695 .51346 L .77191 .50908 L closepath p F P
0 g
s
.82 .813 .844 r
.69414 .3317 m .70707 .32074 L .70235 .31475 L p F P
0 g
s
.82 .813 .844 r
.70235 .31475 m .69194 .32398 L .69414 .3317 L p F P
0 g
s
.81 .818 .857 r
.68233 .33221 m .69194 .32398 L .69414 .3317 L p F P
0 g
s
.538 .568 .833 r
.36082 .31135 m .34183 .31333 L .3477 .32272 L p F P
0 g
s
.538 .568 .833 r
.36446 .31815 m .36082 .31135 L p .3477 .32272 L F P
0 g
s
.538 .568 .833 r
.3477 .32272 m .36248 .3223 L .36446 .31815 L p F P
0 g
s
.599 .63 .853 r
.3395 .3138 m .34183 .31333 L .3477 .32272 L p F P
0 g
s
.814 .478 .419 r
.48663 .51782 m .49881 .52173 L .49563 .51387 L p F P
0 g
s
.814 .478 .419 r
.49563 .51387 m .4841 .50975 L .48663 .51782 L p F P
0 g
s
.549 .759 .975 r
.45918 .59093 m .47884 .58828 L .48442 .59285 L p F P
0 g
s
.564 .748 .964 r
.47884 .58828 m .45918 .59093 L .45351 .58622 L p F P
0 g
s
.568 .645 .886 r
.7815 .3174 m .78136 .31444 L .783 .31728 L closepath p F P
0 g
s
.38 .456 .813 r
.38368 .35661 m .38531 .35722 L .38502 .35944 L closepath p F P
0 g
s
.865 .833 .814 r
.68233 .33221 m .67745 .33775 L .67978 .34539 L p F P
0 g
s
.861 .831 .816 r
.66603 .35042 m .66744 .35837 L .67978 .34539 L p F P
0 g
s
.861 .831 .816 r
.67978 .34539 m .67745 .33775 L .66603 .35042 L p F P
0 g
s
0 0 0 r
.59897 .47735 m .59885 .47749 L .60106 .47163 L p F P
0 g
s
0 0 0 r
.60106 .47163 m .60539 .46628 L .59897 .47735 L p F P
0 g
s
.952 .93 .74 r
.63591 .40418 m .63505 .41275 L .64261 .4014 L p F P
0 g
s
.952 .93 .74 r
.64261 .4014 m .64255 .39313 L .63591 .40418 L p F P
0 g
s
.84 .949 .594 r
.80615 .46941 m .80516 .47104 L .80565 .4698 L closepath p F P
0 g
s
.758 .785 .876 r
.71538 .31555 m .70707 .32074 L .70235 .31475 L p F P
0 g
s
.92 .977 .728 r
.63438 .41529 m .63305 .41572 L .63505 .41275 L closepath p F P
0 g
s
.207 .464 .882 r
.2793 .50642 m .28313 .51343 L .2943 .51824 L p F P
0 g
s
.182 .461 .884 r
.29844 .52508 m .2943 .51824 L .28313 .51343 L p F P
0 g
s
.683 .731 .886 r
.30459 .29483 m .28532 .3041 L .29166 .30982 L p F P
0 g
s
.683 .731 .886 r
.29166 .30982 m .31079 .30176 L .30459 .29483 L p F P
0 g
s
.694 .889 .969 r
.65166 .57045 m .65649 .57324 L .6362 .58216 L p F P
0 g
s
.694 .889 .969 r
.65051 .57096 m .65166 .57045 L p .6362 .58216 L F P
0 g
s
.694 .889 .969 r
.6362 .58216 m .63499 .58149 L .65051 .57096 L p F P
0 g
s
.88 .989 .734 r
.79983 .47413 m .79633 .48297 L .80516 .47104 L p F P
0 g
s
.88 .989 .734 r
.80241 .47052 m .79983 .47413 L p .80516 .47104 L F P
0 g
s
.88 .989 .734 r
.80516 .47104 m .80565 .4698 L .80241 .47052 L p F P
0 g
s
.456 .702 .973 r
.40317 .57817 m .41295 .57822 L .42132 .58327 L p F P
0 g
s
.497 .715 .969 r
.42248 .57782 m .41295 .57822 L .42132 .58327 L p F P
0 g
s
.497 .715 .969 r
.42132 .58327 m .42827 .58299 L .42248 .57782 L p F P
0 g
s
.466 .696 .967 r
.41295 .57822 m .40317 .57817 L .3973 .57287 L p F P
0 g
s
.461 .567 .876 r
.783 .31728 m .79891 .3199 L .79986 .32795 L p F P
0 g
s
.446 .58 .893 r
.78136 .31444 m .783 .31728 L .79891 .3199 L p F P
0 g
s
.398 .447 .795 r
.38797 .34729 m .37802 .34485 L .38368 .35661 L p F P
0 g
s
.398 .447 .795 r
.38368 .35661 m .38531 .35722 L .38797 .34729 L p F P
0 g
s
.487 .521 .817 r
.3738 .34433 m .37802 .34485 L .38368 .35661 L p F P
0 g
s
.864 .87 .841 r
.66745 .35857 m .66733 .35848 L .66744 .35837 L closepath p F P
0 g
s
0 0 .354 r
.82854 .39025 m .828 .39496 L .82654 .38658 L p F P
0 g
s
0 0 .354 r
.82654 .38658 m .82719 .38097 L .82854 .39025 L p F P
0 g
s
.619 .662 .869 r
.3299 .29577 m .31079 .30176 L .3169 .30916 L p F P
0 g
s
.619 .662 .869 r
.3169 .30916 m .3359 .30433 L .3299 .29577 L p F P
0 g
s
0 .155 .692 r
.43094 .43605 m .43287 .4426 L p .42487 .42841 L F P
0 g
s
0 .09 .646 r
.43094 .43605 m .43572 .44622 L .43287 .4426 L closepath p F P
0 g
s
.858 .854 .836 r
.66254 .35422 m .66603 .35042 L .66744 .35837 L p F P
0 g
s
.858 .854 .836 r
.66744 .35837 m .66733 .35848 L .66254 .35422 L p F P
0 g
s
.911 .864 .781 r
.65867 .3701 m .66733 .35848 L .66254 .35422 L p F P
0 g
s
.485 .525 .823 r
.37543 .33962 m .37802 .34485 L .3738 .34433 L closepath p F P
0 g
s
.699 .374 .423 r
.51347 .52138 m .51524 .52419 L .51277 .52401 L closepath p F P
0 g
s
0 .158 .692 r
.42487 .42841 m .42373 .42029 L .41732 .41405 L p F P
0 g
s
.097 .25 .733 r
.43015 .43438 m .42487 .42841 L .42373 .42029 L p F P
0 g
s
0 .155 .692 r
.42487 .42841 m .43015 .43438 L .43094 .43605 L p F P
0 g
s
.856 .485 .344 r
.48277 .50613 m .4841 .50975 L .48072 .50801 L closepath p F P
0 g
s
.866 .669 .138 r
.22648 .41429 m .2251 .40587 L .22508 .39759 L p F P
0 g
s
0 0 .13 r
.2251 .40587 m .22648 .41429 L .22784 .42211 L p F P
0 g
s
.78 .943 .931 r
.73365 .5396 m .72668 .54426 L .72224 .54232 L p F P
0 g
s
.39 .114 .37 r
.57905 .51018 m .58034 .50368 L .56188 .51233 L p F P
0 g
s
.39 .114 .37 r
.57767 .51141 m .57905 .51018 L p .56188 .51233 L F P
0 g
s
.39 .114 .37 r
.56188 .51233 m .56058 .51965 L .57767 .51141 L p F P
0 g
s
.061 .238 .733 r
.41732 .41405 m .41717 .4055 L .40993 .39962 L p F P
0 g
s
.224 .319 .752 r
.42373 .42029 m .41732 .41405 L .41717 .4055 L p F P
0 g
s
.899 .48 .139 r
.45635 .48596 m .46277 .49195 L .45961 .48423 L p F P
0 g
s
.899 .48 .139 r
.45961 .48423 m .45329 .47821 L .45635 .48596 L p F P
0 g
s
.717 .919 .962 r
.68157 .56606 m .67703 .56837 L .68049 .56555 L closepath p F P
0 g
s
.711 .897 .963 r
.67687 .56339 m .68049 .56555 L .67703 .56837 L p F P
0 g
s
.711 .897 .963 r
.65649 .57324 m .67687 .56339 L p .67703 .56837 L F P
0 g
s
.768 .782 .865 r
.71538 .31555 m .72735 .30786 L .72267 .30133 L p F P
0 g
s
.768 .782 .865 r
.72267 .30133 m .71292 .30787 L .71538 .31555 L p F P
0 g
s
.758 .785 .876 r
.70235 .31475 m .71292 .30787 L .71538 .31555 L p F P
0 g
s
.748 .782 .287 r
.8209 .43679 m .8197 .44045 L .82023 .4385 L closepath p F P
0 g
s
.588 .77 .966 r
.50596 .59052 m .50972 .59366 L p .48442 .59285 L F P
0 g
s
.588 .77 .966 r
.48442 .59285 m .50124 .58963 L .50596 .59052 L p F P
0 g
s
.614 .758 .948 r
.50124 .58963 m .48442 .59285 L .47884 .58828 L p F P
0 g
s
.167 .306 .762 r
.40993 .39962 m .41071 .39065 L .40239 .38524 L p F P
0 g
s
.312 .369 .76 r
.41717 .4055 m .40993 .39962 L .41071 .39065 L p F P
0 g
s
.895 .985 .724 r
.80565 .4698 m .80241 .47052 L .8082 .4623 L closepath p F P
0 g
s
.273 .529 .913 r
.31178 .52924 m .30485 .52711 L .31095 .53427 L p F P
0 g
s
.273 .529 .913 r
.31095 .53427 m .31621 .53593 L .31178 .52924 L p F P
0 g
s
.268 .527 .913 r
.29844 .52508 m .30485 .52711 L .31095 .53427 L p F P
0 g
s
.465 .47 .779 r
.39661 .36136 m .38531 .35722 L .38797 .34729 L p F P
0 g
s
.381 .457 .814 r
.39434 .37105 m .39661 .36136 L .38531 .35722 L p F P
0 g
s
.915 .918 .803 r
.64965 .38526 m .64775 .38448 L .64972 .38191 L closepath p F P
0 g
s
.31 .415 .807 r
.40239 .38524 m .404 .37588 L .39434 .37105 L p F P
0 g
s
.377 .408 .767 r
.41071 .39065 m .40239 .38524 L .404 .37588 L p F P
0 g
s
.798 .967 .912 r
.73365 .5396 m .74687 .52989 L .74256 .52834 L p F P
0 g
s
.798 .967 .912 r
.74256 .52834 m .7405 .52987 L .73365 .5396 L p F P
0 g
s
.78 .943 .931 r
.72224 .54232 m .7405 .52987 L .73365 .5396 L p F P
0 g
s
.426 .441 .773 r
.404 .37588 m .39434 .37105 L .39661 .36136 L p F P
0 g
s
.674 .851 .967 r
.63127 .57905 m .61099 .58672 L .60594 .58327 L p F P
0 g
s
.651 .845 .974 r
.58571 .59007 m .60594 .58327 L .61099 .58672 L p F P
0 g
s
.885 .487 .267 r
.46578 .49978 m .4741 .50507 L .47077 .49735 L p F P
0 g
s
.885 .487 .267 r
.47077 .49735 m .46277 .49195 L .46578 .49978 L p F P
0 g
s
.703 .859 .444 r
.6111 .45627 m .60539 .46628 L .61189 .45521 L p F P
0 g
s
.703 .859 .444 r
.61362 .45109 m .6111 .45627 L p .61189 .45521 L F P
0 g
s
.703 .859 .444 r
.61189 .45521 m .61524 .44875 L .61362 .45109 L p F P
0 g
s
.979 .885 .525 r
.2282 .36634 m .22848 .37081 L .22552 .38014 L p F P
0 g
s
.692 .865 .964 r
.63499 .58149 m .63127 .57905 L .65051 .57096 L closepath p F P
0 g
s
.743 .924 .951 r
.69729 .55235 m .7019 .55479 L .68157 .56606 L p F P
0 g
s
.743 .924 .951 r
.68866 .55721 m .69729 .55235 L p .68157 .56606 L F P
0 g
s
.743 .924 .951 r
.68157 .56606 m .68049 .56555 L .68866 .55721 L p F P
0 g
s
.507 .616 .895 r
.77841 .30938 m .78009 .30945 L .78136 .31444 L closepath p F P
0 g
s
.446 .58 .893 r
.79761 .3119 m .78009 .30945 L .78136 .31444 L p F P
0 g
s
.446 .58 .893 r
.79891 .3199 m .79761 .3119 L p .78136 .31444 L F P
0 g
s
.928 .972 .741 r
.6292 .41529 m .63591 .40418 L .63505 .41275 L p F P
0 g
s
.928 .972 .741 r
.62902 .41663 m .6292 .41529 L p .63505 .41275 L F P
0 g
s
.928 .972 .741 r
.63505 .41275 m .63305 .41572 L .62902 .41663 L p F P
0 g
s
.867 .996 .786 r
.78929 .48668 m .79983 .47413 L .79633 .48297 L p F P
0 g
s
.867 .996 .786 r
.7862 .49416 m .78929 .48668 L p .79633 .48297 L F P
0 g
s
.867 .996 .786 r
.79633 .48297 m .78681 .49411 L .7862 .49416 L p F P
0 g
s
.289 .528 .909 r
.30485 .52711 m .29844 .52508 L .2943 .51824 L p F P
0 g
s
.404 .647 .956 r
.37334 .56658 m .3723 .56647 L .36633 .56064 L p F P
0 g
s
0 .012 .555 r
.8243 .37042 m .82436 .36946 L .82506 .37217 L closepath p F P
0 g
s
.137 0 .24 r
.58486 .5 m .58034 .50368 L .58187 .49678 L p F P
0 g
s
.137 0 .24 r
.58187 .49678 m .59173 .48872 L .58486 .5 L p F P
0 g
s
.71 .676 .131 r
.82622 .41346 m .82484 .42188 L .82649 .41237 L p F P
0 g
s
.71 .676 .131 r
.82649 .41237 m .82786 .40394 L .82622 .41346 L p F P
0 g
s
.615 .782 .962 r
.53261 .5914 m .53505 .59346 L p .50972 .59366 L F P
0 g
s
.615 .782 .962 r
.50972 .59366 m .52073 .59103 L .53261 .5914 L p F P
0 g
s
.615 .782 .961 r
.50972 .59366 m .52073 .59103 L .50596 .59052 L closepath p F P
0 g
s
.865 .916 .515 r
.81705 .4425 m .81474 .4511 L .8197 .44045 L p F P
0 g
s
.865 .916 .515 r
.8176 .44126 m .81705 .4425 L p .8197 .44045 L F P
0 g
s
.865 .916 .515 r
.8197 .44045 m .82023 .4385 L .8176 .44126 L p F P
0 g
s
.128 .391 .844 r
.27591 .49919 m .26859 .49517 L .2747 .5038 L p F P
0 g
s
.128 .391 .844 r
.2747 .5038 m .2793 .50642 L .27591 .49919 L p F P
0 g
s
.133 .398 .848 r
.26634 .49392 m .26859 .49517 L .2747 .5038 L p F P
0 g
s
.556 .262 .423 r
.53878 .5235 m .54015 .52382 L .53867 .52414 L closepath p F P
0 g
s
.371 .484 .845 r
.80516 .32199 m .79891 .3199 L .79986 .32795 L p F P
0 g
s
.371 .484 .845 r
.79986 .32795 m .80988 .33181 L .80516 .32199 L p F P
0 g
s
.911 .864 .781 r
.66254 .35422 m .65684 .36233 L .65867 .3701 L p F P
0 g
s
.91 .864 .782 r
.64863 .37391 m .64972 .38191 L .65867 .3701 L p F P
0 g
s
.91 .864 .782 r
.65867 .3701 m .65684 .36233 L .64863 .37391 L p F P
0 g
s
.612 .676 .887 r
.75263 .30582 m .77381 .3017 L .77841 .30938 L p F P
0 g
s
.62 .687 .891 r
.77381 .3017 m .75263 .30582 L .74801 .29884 L p F P
0 g
s
.697 .735 .88 r
.72735 .30786 m .74801 .29884 L .75263 .30582 L p F P
0 g
s
.831 .87 .874 r
.26588 .31653 m .25258 .32793 L .25384 .31811 L p F P
0 g
s
.866 .899 .855 r
.25384 .31811 m .25258 .32793 L .24598 .33449 L p F P
0 g
s
.599 .641 .864 r
.34058 .31144 m .34183 .31333 L .3395 .3138 L closepath p F P
0 g
s
.957 .947 .705 r
.63305 .41572 m .62858 .42374 L .62902 .41663 L closepath p F P
0 g
s
.338 .59 .938 r
.33685 .54587 m .33547 .54559 L .34152 .55206 L p F P
0 g
s
.338 .59 .938 r
.34152 .55206 m .34209 .55218 L .33685 .54587 L p F P
0 g
s
.404 .647 .956 r
.36633 .56064 m .36706 .56071 L .37334 .56658 L p F P
0 g
s
.454 .67 .956 r
.38546 .56141 m .36706 .56071 L .37334 .56658 L p F P
0 g
s
.454 .67 .956 r
.37334 .56658 m .3914 .56729 L .38546 .56141 L p F P
0 g
s
.655 .833 .968 r
.60594 .58327 m .58571 .59007 L .58054 .58631 L p F P
0 g
s
.635 .825 .974 r
.56039 .59229 m .58054 .58631 L .58571 .59007 L p F P
0 g
s
.866 .899 .855 r
.24598 .33449 m .24122 .33417 L p .25384 .31811 L F P
0 g
s
.904 .911 .817 r
.24598 .33449 m .24097 .34054 L .24122 .33417 L closepath p F P
0 g
s
.808 .961 .909 r
.75502 .52363 m .74687 .52989 L .74256 .52834 L p F P
0 g
s
.704 .739 .879 r
.74801 .29884 m .72735 .30786 L .72267 .30133 L p F P
0 g
s
.676 .384 .471 r
.53867 .52414 m .51524 .52419 L .51909 .5319 L p F P
0 g
s
.704 .394 .449 r
.51121 .53133 m .51909 .5319 L .51524 .52419 L p F P
0 g
s
.704 .394 .449 r
.51524 .52419 m .51277 .52401 L .51121 .53133 L p F P
0 g
s
.567 .286 .449 r
.54015 .52382 m .53867 .52414 L .53757 .53185 L p F P
0 g
s
.676 .384 .471 r
.51909 .5319 m .53757 .53185 L .53867 .52414 L p F P
0 g
s
.799 .864 .897 r
.26588 .31653 m .27256 .31206 L .27466 .30187 L p F P
0 g
s
.799 .864 .897 r
.27466 .30187 m .25921 .31321 L .26588 .31653 L p F P
0 g
s
.831 .87 .874 r
.25384 .31811 m .25921 .31321 L .26588 .31653 L p F P
0 g
s
.624 .804 .969 r
.55637 .5891 m .56039 .59229 L p .53505 .59346 L F P
0 g
s
.624 .804 .969 r
.53505 .59346 m .54691 .59029 L .55637 .5891 L p F P
0 g
s
.63 .788 .958 r
.53505 .59346 m .54691 .59029 L .53261 .5914 L closepath p F P
0 g
s
.947 .804 .352 r
.22508 .39759 m .22411 .38892 L .22552 .38014 L p F P
0 g
s
.824 .646 .097 r
.22411 .38892 m .22508 .39759 L .2251 .40587 L p F P
0 g
s
.012 .143 .656 r
.81965 .35518 m .8244 .36223 L .82436 .36946 L closepath p F P
0 g
s
0 0 .483 r
.82745 .37004 m .8244 .36223 L .82436 .36946 L p F P
0 g
s
0 0 .483 r
.82737 .37822 m .82745 .37004 L p .82436 .36946 L F P
0 g
s
0 0 .483 r
.82436 .36946 m .82506 .37217 L .82737 .37822 L p F P
0 g
s
.404 .625 .943 r
.36033 .55449 m .34209 .55218 L .33685 .54587 L p F P
0 g
s
.391 .63 .949 r
.34209 .55218 m .36033 .55449 L .36633 .56064 L p F P
0 g
s
.746 .437 .461 r
.50154 .52979 m .51121 .53133 L .51277 .52401 L p F P
0 g
s
.746 .437 .461 r
.51277 .52401 m .49881 .52173 L .50154 .52979 L p F P
0 g
s
.479 .522 .824 r
.37802 .34485 m .38797 .34729 L p .37726 .33401 L F P
0 g
s
.479 .522 .824 r
.37726 .33401 m .37543 .33962 L .37802 .34485 L p F P
0 g
s
.644 .808 .962 r
.57755 .58381 m .58054 .58631 L .56039 .59229 L p F P
0 g
s
.644 .808 .962 r
.56039 .59229 m .55637 .5891 L .57755 .58381 L p F P
0 g
s
.86 .997 .791 r
.78681 .49411 m .78552 .49557 L .7862 .49416 L closepath p F P
0 g
s
.568 .28 .438 r
.56058 .51965 m .54015 .52382 L .5535 .52844 L p F P
0 g
s
.567 .286 .449 r
.53757 .53185 m .5535 .52844 L .54015 .52382 L p F P
0 g
s
.859 .499 .368 r
.4772 .51295 m .48663 .51782 L .4841 .50975 L p F P
0 g
s
.859 .499 .368 r
.47701 .51225 m .4772 .51295 L p .4841 .50975 L F P
0 g
s
.859 .499 .368 r
.4841 .50975 m .48072 .50801 L .47701 .51225 L p F P
0 g
s
.104 .225 .706 r
.81957 .35509 m .81957 .35496 L .81965 .35518 L closepath p F P
0 g
s
0 .112 .646 r
.81957 .35496 m .81965 .35518 L .8244 .36223 L p F P
0 g
s
.855 .984 .854 r
.77633 .50002 m .77191 .50908 L .78552 .49557 L p F P
0 g
s
.855 .984 .854 r
.78279 .49346 m .77633 .50002 L p .78552 .49557 L F P
0 g
s
.855 .984 .854 r
.78552 .49557 m .7862 .49416 L .78279 .49346 L p F P
0 g
s
.146 .286 .751 r
.8147 .3428 m .81914 .347 L .81957 .35496 L closepath p F P
0 g
s
0 .112 .646 r
.82403 .35413 m .81914 .347 L .81957 .35496 L p F P
0 g
s
0 .112 .646 r
.8244 .36223 m .82403 .35413 L p .81957 .35496 L F P
0 g
s
.525 .735 .97 r
.42827 .58299 m .44779 .58125 L .45351 .58622 L p F P
0 g
s
.532 .728 .964 r
.44779 .58125 m .42827 .58299 L .42248 .57782 L p F P
0 g
s
.829 .981 .881 r
.75502 .52363 m .76695 .51346 L .76277 .51227 L p F P
0 g
s
.829 .981 .881 r
.76277 .51227 m .76044 .51431 L .75502 .52363 L p F P
0 g
s
.808 .961 .909 r
.74256 .52834 m .76044 .51431 L .75502 .52363 L p F P
0 g
s
0 0 .516 r
.82506 .37217 m .82737 .37822 L .82719 .38097 L closepath p F P
0 g
s
.256 .379 .796 r
.81177 .3408 m .81157 .33551 L .8147 .3428 L closepath p F P
0 g
s
.587 .636 .867 r
.34183 .31333 m .36082 .31135 L p .34335 .30308 L F P
0 g
s
.587 .636 .867 r
.34335 .30308 m .34058 .31144 L .34183 .31333 L p F P
0 g
s
.734 .896 .952 r
.68049 .56555 m .67687 .56339 L .68866 .55721 L closepath p F P
0 g
s
.939 .932 .768 r
.24122 .33417 m .24097 .34054 L .23344 .35158 L p F P
0 g
s
0 .056 .622 r
.24603 .46699 m .24351 .45925 L .23835 .45264 L p F P
0 g
s
0 .204 .728 r
.24351 .45925 m .24603 .46699 L .25249 .4732 L p F P
0 g
s
0 .183 .716 r
.25533 .48076 m .25249 .4732 L .24603 .46699 L p F P
0 g
s
.836 .975 .882 r
.77191 .50908 m .76695 .51346 L .76277 .51227 L p F P
0 g
s
.836 .975 .882 r
.76277 .51227 m .77633 .50002 L .77191 .50908 L p F P
0 g
s
0 0 .475 r
.43052 .43499 m .43094 .43605 L .43572 .44622 L p F P
0 g
s
.759 .813 .895 r
.28532 .3041 m .27256 .31206 L .27466 .30187 L p F P
0 g
s
0 0 .496 r
.23835 .45264 m .23619 .44469 L .23228 .43769 L p F P
0 g
s
0 .082 .64 r
.23619 .44469 m .23835 .45264 L .24351 .45925 L p F P
0 g
s
.082 .325 .802 r
.2625 .48601 m .25533 .48076 L .25249 .4732 L p F P
0 g
s
.035 .305 .794 r
.26393 .4883 m .26634 .49392 L p .25533 .48076 L F P
0 g
s
.035 .305 .794 r
.25533 .48076 m .2625 .48601 L .26393 .4883 L p F P
0 g
s
.884 .913 .512 r
.82023 .4385 m .8176 .44126 L .82172 .43192 L closepath p F P
0 g
s
.91 .896 .802 r
.64292 .38184 m .64863 .37391 L .64972 .38191 L p F P
0 g
s
.91 .896 .802 r
.64972 .38191 m .64775 .38448 L .64292 .38184 L p F P
0 g
s
0 0 0 r
.60612 .46688 m .59897 .47735 L .60539 .46628 L p F P
0 g
s
0 0 0 r
.60539 .46628 m .6111 .45627 L .60612 .46688 L p F P
0 g
s
.477 .52 .823 r
.37234 .33333 m .37726 .33401 L .37543 .33962 L closepath p F P
0 g
s
.586 .635 .866 r
.3359 .30433 m .34335 .30308 L .34058 .31144 L closepath p F P
0 g
s
.869 .982 .843 r
.7862 .49416 m .78279 .49346 L .78929 .48668 L closepath p F P
0 g
s
.958 .946 .699 r
.62386 .42596 m .62261 .4346 L .62858 .42374 L p F P
0 g
s
.958 .946 .699 r
.62828 .41682 m .62386 .42596 L p .62858 .42374 L F P
0 g
s
.958 .946 .699 r
.62858 .42374 m .62902 .41663 L .62828 .41682 L p F P
0 g
s
.95 .885 .733 r
.64255 .39313 m .64775 .38448 L .64292 .38184 L p F P
0 g
s
0 0 .333 r
.23228 .43769 m .2305 .42951 L .22784 .42211 L p F P
0 g
s
0 0 .523 r
.2305 .42951 m .23228 .43769 L .23619 .44469 L p F P
0 g
s
.835 .462 .347 r
.48072 .50801 m .47701 .51225 L .4741 .50507 L closepath p F P
0 g
s
.153 .4 .846 r
.26393 .4883 m .26859 .49517 L .26634 .49392 L closepath p F P
0 g
s
.721 .887 .957 r
.67687 .56339 m .65649 .57324 L .65166 .57045 L p F P
0 g
s
.466 .696 .967 r
.3973 .57287 m .40526 .57289 L .41295 .57822 L p F P
0 g
s
.503 .708 .963 r
.41665 .5724 m .40526 .57289 L .41295 .57822 L p F P
0 g
s
.503 .708 .963 r
.41295 .57822 m .42248 .57782 L .41665 .5724 L p F P
0 g
s
.356 .578 .925 r
.3294 .53879 m .31621 .53593 L .31178 .52924 L p F P
0 g
s
.339 .58 .931 r
.31621 .53593 m .3294 .53879 L .33547 .54559 L p F P
0 g
s
.703 .574 .707 r
.52016 .87367 m .54473 .87338 L .52868 .88764 L p F P
0 g
s
.703 .574 .707 r
.52868 .88764 m .52461 .88769 L .52016 .87367 L p F P
0 g
s
.703 .591 .727 r
.54473 .87338 m .52016 .87367 L .52009 .87346 L p F P
0 g
s
.715 .581 .704 r
.51986 .87366 m .52016 .87367 L .52461 .88769 L p F P
0 g
s
.714 .596 .723 r
.52016 .87367 m .52009 .87346 L .51986 .87366 L closepath p F P
0 g
s
.715 .581 .704 r
.52461 .88769 m .50623 .88728 L .51986 .87366 L p F P
0 g
s
.718 .587 .708 r
.49865 .87296 m .51986 .87366 L .50623 .88728 L p F P
0 g
s
.713 .595 .723 r
.5145 .85875 m .49865 .87296 L .51986 .87366 L p F P
0 g
s
.713 .595 .723 r
.51473 .85876 m .5145 .85875 L p .51986 .87366 L F P
0 g
s
.713 .595 .723 r
.51986 .87366 m .52009 .87346 L .51473 .85876 L p F P
0 g
s
.703 .591 .727 r
.52009 .87346 m .53847 .85872 L p .54473 .87338 L F P
0 g
s
.706 .592 .725 r
.52009 .87346 m .53847 .85872 L .51473 .85876 L closepath p F P
0 g
s
.703 .557 .687 r
.52549 .89098 m .52868 .88764 L .52461 .88769 L closepath p F P
0 g
s
.715 .57 .69 r
.52461 .88769 m .52549 .89098 L .51683 .90081 L p F P
0 g
s
.715 .57 .69 r
.50623 .88728 m .52461 .88769 L p .51683 .90081 L F P
0 g
s
.805 .487 .451 r
.48872 .52609 m .50154 .52979 L .49881 .52173 L p F P
0 g
s
.805 .487 .451 r
.49881 .52173 m .48663 .51782 L .48872 .52609 L p F P
0 g
s
0 0 .314 r
.82878 .38663 m .82854 .39025 L .82719 .38097 L p F P
0 g
s
0 0 .314 r
.82719 .38097 m .82737 .37822 L .82878 .38663 L p F P
0 g
s
.7 .557 .689 r
.52868 .88764 m .54991 .88722 L p .54113 .90069 L F P
0 g
s
.7 .557 .689 r
.52549 .89098 m .52868 .88764 L p .54113 .90069 L F P
0 g
s
.7 .569 .704 r
.54991 .88722 m .52868 .88764 L .54473 .87338 L p F P
0 g
s
0 0 .086 r
.82856 .39757 m .82786 .40394 L .828 .39496 L p F P
0 g
s
0 0 .086 r
.828 .39496 m .82854 .39025 L .82856 .39757 L p F P
0 g
s
.515 .627 .9 r
.78009 .30945 m .77841 .30938 L .77381 .3017 L p F P
0 g
s
.906 .964 .645 r
.81058 .45371 m .8082 .4623 L .81474 .4511 L p F P
0 g
s
.906 .964 .645 r
.81474 .4511 m .81705 .4425 L .81058 .45371 L p F P
0 g
s
.7 .557 .689 r
.54113 .90069 m .5282 .90095 L .52549 .89098 L p F P
0 g
s
.711 .563 .685 r
.5282 .90095 m .52549 .89098 L .51683 .90081 L closepath p F P
0 g
s
.7 .569 .704 r
.54473 .87338 m .54565 .87337 L .54991 .88722 L p F P
0 g
s
.701 .585 .723 r
.54565 .87337 m .54546 .87282 L .54473 .87338 L closepath p F P
0 g
s
.703 .591 .727 r
.5405 .85869 m .54546 .87282 L .54473 .87338 L p F P
0 g
s
.703 .591 .727 r
.53847 .85872 m .5405 .85869 L p .54473 .87338 L F P
0 g
s
.688 .562 .707 r
.54565 .87337 m .57 .87199 L p .55533 .88691 L F P
0 g
s
.688 .562 .707 r
.55533 .88691 m .54991 .88722 L .54565 .87337 L p F P
0 g
s
.692 .581 .726 r
.56548 .85878 m .57 .87199 L .54565 .87337 L p F P
0 g
s
.692 .581 .726 r
.54565 .87337 m .54546 .87282 L .56548 .85878 L p F P
0 g
s
.812 .806 .845 r
.69194 .32398 m .68233 .33221 L .67752 .32651 L p F P
0 g
s
.862 .815 .802 r
.67745 .33775 m .68233 .33221 L .67752 .32651 L p F P
0 g
s
.692 .58 .725 r
.56504 .85748 m .56548 .85878 L .54546 .87282 L p F P
0 g
s
.692 .58 .725 r
.54546 .87282 m .5405 .85869 L .56504 .85748 L p F P
0 g
s
.758 .918 .943 r
.71441 .54737 m .7019 .55479 L .69729 .55235 L p F P
0 g
s
.715 .57 .69 r
.5001 .89448 m .50623 .88728 L p .51683 .90081 L F P
0 g
s
.719 .571 .688 r
.5001 .89448 m .50623 .88728 L .498 .887 L closepath p F P
0 g
s
.718 .587 .708 r
.49469 .87705 m .49865 .87296 L p .50623 .88728 L F P
0 g
s
.718 .587 .708 r
.50623 .88728 m .498 .887 L .49469 .87705 L p F P
0 g
s
.965 .935 .693 r
.2282 .36634 m .22825 .36174 L .23344 .35158 L p F P
0 g
s
.96 .893 .51 r
.22825 .36174 m .2282 .36634 L .22505 .37256 L p F P
0 g
s
.979 .885 .525 r
.22552 .38014 m .22505 .37256 L .2282 .36634 L p F P
0 g
s
.687 .545 .687 r
.55088 .89093 m .55533 .88691 L .54991 .88722 L closepath p F P
0 g
s
.7 .557 .689 r
.54991 .88722 m .55088 .89093 L .54113 .90069 L p F P
0 g
s
.641 .685 .876 r
.32382 .2877 m .30459 .29483 L .31079 .30176 L p F P
0 g
s
.641 .685 .876 r
.31079 .30176 m .3299 .29577 L .32382 .2877 L p F P
0 g
s
.819 .8 .834 r
.69194 .32398 m .70235 .31475 L .69759 .30851 L p F P
0 g
s
.819 .8 .834 r
.69759 .30851 m .68884 .31651 L .69194 .32398 L p F P
0 g
s
.812 .806 .845 r
.67752 .32651 m .68884 .31651 L .69194 .32398 L p F P
0 g
s
.564 .748 .964 r
.47384 .58391 m .47884 .58828 L p .45351 .58622 L F P
0 g
s
.564 .748 .964 r
.45351 .58622 m .47265 .58344 L .47384 .58391 L p F P
0 g
s
.581 .741 .952 r
.47265 .58344 m .45351 .58622 L .44779 .58125 L p F P
0 g
s
.637 .78 .95 r
.54691 .59029 m .53261 .5914 L .52966 .58877 L p F P
0 g
s
.625 .776 .953 r
.53261 .5914 m .52966 .58877 L .52073 .59103 L closepath p F P
0 g
s
.097 .273 .754 r
.81157 .33551 m .8147 .3428 L .81914 .347 L p F P
0 g
s
.919 .791 .316 r
.22505 .37256 m .22552 .38014 L .22411 .38892 L p F P
0 g
s
.722 .589 .706 r
.49469 .87705 m .49865 .87296 L .49326 .87271 L closepath p F P
0 g
s
.721 .604 .726 r
.49402 .85784 m .5145 .85875 L .49865 .87296 L p F P
0 g
s
.721 .604 .726 r
.48926 .86225 m .49402 .85784 L p .49865 .87296 L F P
0 g
s
.721 .604 .726 r
.49865 .87296 m .49326 .87271 L .48926 .86225 L p F P
0 g
s
.762 .78 .867 r
.71292 .30787 m .70235 .31475 L .69759 .30851 L p F P
0 g
s
.725 .575 .686 r
.498 .887 m .4863 .88625 L p .49558 .90013 L F P
0 g
s
.725 .575 .686 r
.49558 .90013 m .5001 .89448 L .498 .887 L p F P
0 g
s
.728 .593 .704 r
.498 .887 m .49469 .87705 L .4863 .88625 L closepath p F P
0 g
s
.862 .815 .802 r
.67752 .32651 m .67426 .33034 L .67745 .33775 L p F P
0 g
s
.859 .814 .804 r
.66344 .34283 m .66603 .35042 L .67745 .33775 L p F P
0 g
s
.859 .814 .804 r
.67745 .33775 m .67426 .33034 L .66344 .34283 L p F P
0 g
s
.684 .544 .689 r
.55088 .89093 m .55533 .88691 L p .57053 .89927 L F P
0 g
s
.684 .544 .689 r
.57053 .89927 m .55337 .90035 L .55088 .89093 L p F P
0 g
s
.697 .552 .686 r
.55337 .90035 m .55088 .89093 L .54113 .90069 L closepath p F P
0 g
s
.706 .607 .744 r
.53847 .85872 m .51473 .85876 L .51467 .85861 L p F P
0 g
s
.716 .612 .74 r
.51473 .85876 m .51467 .85861 L .5145 .85875 L closepath p F P
0 g
s
.716 .612 .74 r
.50924 .84543 m .49402 .85784 L .5145 .85875 L p F P
0 g
s
.716 .612 .74 r
.5145 .85875 m .51467 .85861 L .50924 .84543 L p F P
0 g
s
.684 .544 .689 r
.55533 .88691 m .57413 .88573 L p .57053 .89927 L F P
0 g
s
.686 .559 .705 r
.57413 .88573 m .57089 .87496 L .55533 .88691 L closepath p F P
0 g
s
.688 .562 .707 r
.57 .87199 m .57089 .87496 L .55533 .88691 L p F P
0 g
s
.706 .607 .744 r
.51467 .85861 m .53466 .84392 L p .53847 .85872 L F P
0 g
s
.709 .604 .737 r
.53466 .84392 m .51467 .85861 L .50924 .84543 L p F P
0 g
s
.487 .503 .799 r
.38304 .32271 m .3666 .32213 L .37234 .33333 L p F P
0 g
s
.487 .503 .799 r
.37234 .33333 m .37726 .33401 L .38304 .32271 L p F P
0 g
s
.545 .564 .825 r
.36248 .3223 m .3666 .32213 L .37234 .33333 L p F P
0 g
s
.703 .601 .74 r
.5405 .85869 m .54006 .85759 L .53847 .85872 L closepath p F P
0 g
s
.706 .607 .744 r
.53466 .84392 m .54006 .85759 L .53847 .85872 L p F P
0 g
s
.699 .539 .668 r
.53091 .9131 m .54113 .90069 L .5282 .90095 L closepath p F P
0 g
s
.706 .544 .666 r
.5282 .90095 m .51683 .90081 L p .53057 .91355 L F P
0 g
s
.706 .544 .666 r
.53057 .91355 m .53091 .9131 L .5282 .90095 L p F P
0 g
s
.515 .627 .9 r
.77381 .3017 m .77773 .30178 L .78009 .30945 L p F P
0 g
s
.467 .594 .896 r
.79599 .30428 m .79761 .3119 L .78009 .30945 L p F P
0 g
s
.467 .594 .896 r
.79581 .30395 m .79599 .30428 L p .78009 .30945 L F P
0 g
s
.467 .594 .896 r
.78009 .30945 m .77773 .30178 L .79581 .30395 L p F P
0 g
s
0 0 .13 r
.22784 .42211 m .22647 .4137 L .2251 .40587 L p F P
0 g
s
0 0 .369 r
.22647 .4137 m .22784 .42211 L .2305 .42951 L p F P
0 g
s
.694 .597 .743 r
.56009 .8446 m .56504 .85748 L .5405 .85869 L p F P
0 g
s
.694 .597 .743 r
.5405 .85869 m .54006 .85759 L .56009 .8446 L p F P
0 g
s
.732 .601 .71 r
.49326 .87271 m .49469 .87705 L .4863 .88625 L p F P
0 g
s
.474 .69 .961 r
.40526 .57289 m .3973 .57287 L .3914 .56729 L p F P
0 g
s
.732 .601 .71 r
.47963 .87167 m .49326 .87271 L p .4863 .88625 L F P
0 g
s
.73 .609 .722 r
.49326 .87271 m .48926 .86225 L .47963 .87167 L closepath p F P
0 g
s
.626 .775 .952 r
.52423 .5832 m .52966 .58877 L .52073 .59103 L p F P
0 g
s
.626 .775 .952 r
.50423 .589 m .52423 .5832 L p .52073 .59103 L F P
0 g
s
.626 .775 .952 r
.52073 .59103 m .50596 .59052 L .50423 .589 L p F P
0 g
s
.939 .932 .768 r
.23344 .35158 m .2339 .34213 L p .24122 .33417 L F P
0 g
s
.965 .939 .666 r
.2339 .34213 m .23344 .35158 L .22825 .36174 L p F P
0 g
s
.695 .592 .737 r
.56009 .8446 m .54006 .85759 L .53466 .84392 L p F P
0 g
s
0 0 .492 r
.43015 .43438 m .43052 .43499 L .43094 .43605 L closepath p F P
0 g
s
.706 .756 .891 r
.2983 .28848 m .27887 .29902 L .28532 .3041 L p F P
0 g
s
.706 .756 .891 r
.28532 .3041 m .30459 .29483 L .2983 .28848 L p F P
0 g
s
.759 .813 .895 r
.27466 .30187 m .27887 .29902 L .28532 .3041 L p F P
0 g
s
.706 .544 .666 r
.51683 .90081 m .50782 .91325 L .53057 .91355 L p F P
0 g
s
.715 .552 .668 r
.50179 .90046 m .51683 .90081 L .50782 .91325 L p F P
0 g
s
.715 .57 .69 r
.51683 .90081 m .50179 .90046 L .5001 .89448 L p F P
0 g
s
.248 .472 .879 r
.2906 .51117 m .2793 .50642 L .27591 .49919 L p F P
0 g
s
.207 .464 .882 r
.2943 .51824 m .2906 .51117 L .2793 .50642 L p F P
0 g
s
.851 .838 .369 r
.82312 .42351 m .82172 .43192 L .82484 .42188 L p F P
0 g
s
.851 .838 .369 r
.82484 .42188 m .82622 .41346 L .82312 .42351 L p F P
0 g
s
.725 .576 .686 r
.50179 .90046 m .5001 .89448 L .49558 .90013 L closepath p F P
0 g
s
.7 .541 .669 r
.54113 .90069 m .55337 .90035 L p .53101 .91355 L F P
0 g
s
.7 .541 .669 r
.53101 .91355 m .53091 .9131 L .54113 .90069 L p F P
0 g
s
.294 .529 .908 r
.30784 .52232 m .29874 .5196 L .30485 .52711 L p F P
0 g
s
.294 .529 .908 r
.30485 .52711 m .31178 .52924 L .30784 .52232 L p F P
0 g
s
.289 .528 .909 r
.2943 .51824 m .29874 .5196 L .30485 .52711 L p F P
0 g
s
0 0 .568 r
.42885 .42708 m .42461 .42116 L .43015 .43438 L p F P
0 g
s
0 0 .568 r
.43015 .43438 m .43052 .43499 L .42885 .42708 L p F P
0 g
s
.097 .25 .733 r
.42373 .42029 m .42461 .42116 L .43015 .43438 L p F P
0 g
s
.907 .497 .173 r
.45926 .49383 m .46578 .49978 L .46277 .49195 L p F P
0 g
s
.907 .497 .173 r
.46277 .49195 m .45635 .48596 L .45926 .49383 L p F P
0 g
s
.602 .767 .959 r
.50596 .59052 m .50423 .589 L .50124 .58963 L closepath p F P
0 g
s
.715 .552 .668 r
.50782 .91325 m .50472 .91318 L .50179 .90046 L p F P
0 g
s
.726 .559 .665 r
.49558 .90013 m .50179 .90046 L .50472 .91318 L p F P
0 g
s
0 0 .475 r
.43748 .44963 m .43471 .44217 L .43052 .43499 L p F P
0 g
s
.185 .419 .854 r
.26859 .49517 m .27591 .49919 L p .26322 .48653 L F P
0 g
s
.185 .419 .854 r
.26322 .48653 m .26393 .4883 L .26859 .49517 L p F P
0 g
s
.682 .526 .668 r
.55337 .90035 m .57053 .89927 L .55752 .91276 L p F P
0 g
s
.682 .526 .668 r
.55752 .91276 m .5561 .91285 L .55337 .90035 L p F P
0 g
s
.7 .541 .669 r
.55337 .90035 m .5561 .91285 L .53101 .91355 L p F P
0 g
s
.95 .885 .733 r
.64292 .38184 m .64098 .38532 L .64255 .39313 L p F P
0 g
s
.951 .886 .731 r
.63497 .39617 m .63591 .40418 L .64255 .39313 L p F P
0 g
s
.951 .886 .731 r
.64255 .39313 m .64098 .38532 L .63497 .39617 L p F P
0 g
s
.725 .575 .686 r
.4863 .88625 m .47649 .89888 L .49558 .90013 L p F P
0 g
s
.734 .585 .689 r
.46977 .88494 m .4863 .88625 L .47649 .89888 L p F P
0 g
s
.732 .601 .71 r
.46922 .88338 m .47963 .87167 L p .4863 .88625 L F P
0 g
s
.732 .601 .71 r
.4863 .88625 m .46977 .88494 L .46922 .88338 L p F P
0 g
s
.635 .792 .958 r
.55637 .5891 m .5551 .58802 L .54691 .59029 L closepath p F P
0 g
s
.637 .78 .95 r
.54977 .58271 m .5551 .58802 L .54691 .59029 L p F P
0 g
s
.637 .78 .95 r
.52966 .58877 m .54977 .58271 L p .54691 .59029 L F P
0 g
s
0 0 0 r
.59885 .47749 m .59879 .47767 L .59897 .47735 L closepath p F P
0 g
s
.675 .551 .706 r
.57089 .87496 m .57617 .87139 L .57 .87199 L closepath p F P
0 g
s
.677 .568 .726 r
.57617 .87139 m .57 .87199 L .56548 .85878 L p F P
0 g
s
.405 .14 .395 r
.5644 .52486 m .55945 .52724 L .56058 .51965 L p F P
0 g
s
.405 .14 .395 r
.56058 .51965 m .57767 .51141 L .5644 .52486 L p F P
0 g
s
.568 .28 .438 r
.5535 .52844 m .55945 .52724 L .56058 .51965 L p F P
0 g
s
.726 .559 .665 r
.50472 .91318 m .48769 .91228 L .49558 .90013 L p F P
0 g
s
.73 .566 .669 r
.47649 .89888 m .49558 .90013 L .48769 .91228 L p F P
0 g
s
.725 .606 .725 r
.48926 .86225 m .49402 .85784 L .48743 .85745 L closepath p F P
0 g
s
.723 .621 .744 r
.50816 .84279 m .50924 .84543 L .49402 .85784 L p F P
0 g
s
.723 .621 .744 r
.49234 .8419 m .50816 .84279 L p .49402 .85784 L F P
0 g
s
.723 .621 .744 r
.4838 .84907 m .49234 .8419 L p .49402 .85784 L F P
0 g
s
.723 .621 .744 r
.49402 .85784 m .48743 .85745 L .4838 .84907 L p F P
0 g
s
0 0 .058 r
.60134 .47747 m .60612 .46688 L .59897 .47735 L p F P
0 g
s
0 0 .058 r
.59695 .4838 m .60134 .47747 L p .59897 .47735 L F P
0 g
s
0 0 .058 r
.59897 .47735 m .59879 .47767 L .59695 .4838 L p F P
0 g
s
.734 .618 .728 r
.48743 .85745 m .48926 .86225 L .47963 .87167 L p F P
0 g
s
.673 .551 .708 r
.57089 .87496 m .57617 .87139 L p .58998 .88411 L F P
0 g
s
.673 .551 .708 r
.58998 .88411 m .57413 .88573 L .57089 .87496 L p F P
0 g
s
.543 .573 .835 r
.36446 .31815 m .3666 .32213 L .36248 .3223 L closepath p F P
0 g
s
.695 .856 .959 r
.65051 .57096 m .63127 .57905 L .62629 .57556 L p F P
0 g
s
.674 .851 .967 r
.60594 .58327 m .62629 .57556 L .63127 .57905 L p F P
0 g
s
0 0 .552 r
.42885 .42708 m .43052 .43499 L .43471 .44217 L p F P
0 g
s
0 0 .102 r
.59879 .47767 m .59173 .48872 L .59695 .4838 L closepath p F P
0 g
s
.858 .833 .821 r
.65767 .34933 m .66344 .34283 L .66603 .35042 L p F P
0 g
s
.858 .833 .821 r
.66603 .35042 m .66254 .35422 L .65767 .34933 L p F P
0 g
s
.737 .603 .708 r
.46922 .88338 m .47963 .87167 L .46461 .87027 L closepath p F P
0 g
s
.734 .618 .728 r
.47554 .85639 m .48743 .85745 L p .47963 .87167 L F P
0 g
s
.734 .618 .728 r
.46377 .86821 m .47554 .85639 L p .47963 .87167 L F P
0 g
s
.734 .618 .728 r
.47963 .87167 m .46461 .87027 L .46377 .86821 L p F P
0 g
s
.77 .776 .858 r
.71292 .30787 m .72267 .30133 L .71795 .29468 L p F P
0 g
s
.77 .776 .858 r
.71795 .29468 m .70966 .30042 L .71292 .30787 L p F P
0 g
s
.762 .78 .867 r
.69759 .30851 m .70966 .30042 L .71292 .30787 L p F P
0 g
s
.671 .533 .688 r
.57634 .8943 m .58998 .88411 L .57413 .88573 L closepath p F P
0 g
s
.684 .544 .689 r
.57413 .88573 m .57634 .8943 L .57053 .89927 L p F P
0 g
s
.757 .878 .461 r
.61524 .44875 m .61362 .45109 L .61666 .44548 L closepath p F P
0 g
s
.677 .568 .726 r
.56548 .85878 m .56801 .85721 L p .57617 .87139 L F P
0 g
s
.679 .569 .724 r
.56548 .85878 m .56801 .85721 L .56504 .85748 L closepath p F P
0 g
s
.904 .835 .768 r
.65684 .36233 m .66254 .35422 L .65767 .34933 L p F P
0 g
s
.68 .586 .743 r
.56801 .85721 m .56504 .85748 L .56009 .8446 L p F P
0 g
s
.772 .938 .936 r
.72224 .54232 m .71441 .54737 L .71941 .54101 L closepath p F P
0 g
s
.758 .918 .943 r
.71773 .54002 m .71941 .54101 L .71441 .54737 L p F P
0 g
s
.758 .918 .943 r
.69729 .55235 m .71773 .54002 L p .71441 .54737 L F P
0 g
s
0 0 .278 r
.82889 .37846 m .82878 .38663 L .82737 .37822 L p F P
0 g
s
0 0 .278 r
.82737 .37822 m .82745 .37004 L .82889 .37846 L p F P
0 g
s
.938 .942 .601 r
.61886 .43655 m .61666 .44548 L .62261 .4346 L p F P
0 g
s
.938 .942 .601 r
.62261 .4346 m .62386 .42596 L .61886 .43655 L p F P
0 g
s
.87 .475 .287 r
.46861 .50774 m .46578 .49978 L .4741 .50507 L p F P
0 g
s
.87 .475 .287 r
.47647 .51244 m .46861 .50774 L p .4741 .50507 L F P
0 g
s
.87 .475 .287 r
.4741 .50507 m .47701 .51225 L .47647 .51244 L p F P
0 g
s
.61 .768 .955 r
.47884 .58828 m .48804 .58619 L .47384 .58391 L closepath p F P
0 g
s
.614 .758 .948 r
.47884 .58828 m .48804 .58619 L .50124 .58963 L p F P
0 g
s
.732 .625 .74 r
.48743 .85745 m .4838 .84907 L .47554 .85639 L closepath p F P
0 g
s
.608 .749 .945 r
.49871 .58364 m .48804 .58619 L .50124 .58963 L p F P
0 g
s
.608 .749 .945 r
.50124 .58963 m .50423 .589 L .49871 .58364 L p F P
0 g
s
.224 .319 .752 r
.42376 .41896 m .42373 .42029 L p .41717 .4055 L F P
0 g
s
.139 .262 .729 r
.42376 .41896 m .42461 .42116 L .42373 .42029 L closepath p F P
0 g
s
.673 .551 .708 r
.57617 .87139 m .59338 .86965 L p .58998 .88411 L F P
0 g
s
.675 .566 .724 r
.59338 .86965 m .59099 .86257 L .57617 .87139 L closepath p F P
0 g
s
.677 .568 .726 r
.58854 .85523 m .59099 .86257 L .57617 .87139 L p F P
0 g
s
.677 .568 .726 r
.56801 .85721 m .58854 .85523 L p .57617 .87139 L F P
0 g
s
.695 .592 .737 r
.55912 .84206 m .56009 .8446 L p .53466 .84392 L F P
0 g
s
.695 .592 .737 r
.53466 .84392 m .53601 .84301 L .55912 .84206 L p F P
0 g
s
.697 .598 .741 r
.53466 .84392 m .53601 .84301 L .53432 .84306 L closepath p F P
0 g
s
.709 .604 .737 r
.53432 .84306 m .53466 .84392 L p .50924 .84543 L F P
0 g
s
.678 .582 .741 r
.58854 .85523 m .5856 .84741 L .56801 .85721 L closepath p F P
0 g
s
.68 .586 .743 r
.58281 .83995 m .5856 .84741 L .56801 .85721 L p F P
0 g
s
.68 .586 .743 r
.56541 .84153 m .58281 .83995 L p .56801 .85721 L F P
0 g
s
.68 .586 .743 r
.56009 .8446 m .56541 .84153 L p .56801 .85721 L F P
0 g
s
.708 .546 .667 r
.53101 .91355 m .53091 .9131 L .53057 .91355 L closepath p F P
0 g
s
.709 .604 .737 r
.50924 .84543 m .51259 .84289 L .53432 .84306 L p F P
0 g
s
.712 .61 .741 r
.50924 .84543 m .51259 .84289 L .50816 .84279 L closepath p F P
0 g
s
.415 .642 .95 r
.36137 .55459 m .36033 .55449 L .36633 .56064 L p F P
0 g
s
.415 .642 .95 r
.36633 .56064 m .36706 .56071 L .36137 .55459 L p F P
0 g
s
.097 .273 .754 r
.81829 .33898 m .81124 .33267 L .81157 .33551 L p F P
0 g
s
.097 .273 .754 r
.81914 .347 m .81829 .33898 L p .81157 .33551 L F P
0 g
s
.252 .395 .813 r
.80988 .33181 m .81124 .33267 L .81157 .33551 L closepath p F P
0 g
s
.696 .613 .759 r
.53601 .84301 m .53432 .84306 L .52924 .83156 L p F P
0 g
s
.708 .618 .755 r
.53432 .84306 m .52924 .83156 L .51259 .84289 L closepath p F P
0 g
s
.693 .518 .645 r
.53101 .91355 m .5561 .91285 L p .54938 .92503 L F P
0 g
s
.693 .518 .645 r
.54938 .92503 m .53304 .92548 L .53101 .91355 L p F P
0 g
s
.706 .526 .643 r
.53057 .91355 m .53101 .91355 L .53304 .92548 L p F P
0 g
s
.706 .526 .643 r
.53304 .92548 m .52383 .92544 L .53057 .91355 L p F P
0 g
s
.71 .532 .646 r
.50782 .91325 m .53057 .91355 L .52383 .92544 L p F P
0 g
s
.694 .608 .756 r
.55912 .84206 m .55471 .83171 L .53601 .84301 L closepath p F P
0 g
s
.696 .613 .759 r
.55209 .82557 m .55471 .83171 L .53601 .84301 L p F P
0 g
s
.696 .613 .759 r
.53813 .82601 m .55209 .82557 L p .53601 .84301 L F P
0 g
s
.696 .613 .759 r
.52924 .83156 m .53813 .82601 L p .53601 .84301 L F P
0 g
s
.901 .985 .731 r
.80248 .46549 m .81058 .45371 L .8082 .4623 L p F P
0 g
s
.901 .985 .731 r
.80095 .47079 m .80248 .46549 L p .8082 .4623 L F P
0 g
s
.901 .985 .731 r
.8082 .4623 m .80241 .47052 L .80095 .47079 L p F P
0 g
s
.824 .646 .097 r
.2251 .40587 m .22414 .39721 L .22411 .38892 L p F P
0 g
s
0 0 .174 r
.22414 .39721 m .2251 .40587 L .22647 .4137 L p F P
0 g
s
.587 .615 .848 r
.34909 .29123 m .3299 .29577 L .3359 .30433 L p F P
0 g
s
.587 .615 .848 r
.34972 .29229 m .34909 .29123 L p .3359 .30433 L F P
0 g
s
.587 .615 .848 r
.3359 .30433 m .34335 .30308 L .34972 .29229 L p F P
0 g
s
.65 .796 .953 r
.57532 .58181 m .57755 .58381 L .55637 .5891 L p F P
0 g
s
.65 .796 .953 r
.55637 .5891 m .5551 .58802 L .57532 .58181 L p F P
0 g
s
.62 .687 .891 r
.74801 .29884 m .7692 .29418 L .77381 .3017 L p F P
0 g
s
.627 .695 .893 r
.7692 .29418 m .74801 .29884 L .74336 .29186 L p F P
0 g
s
.704 .739 .879 r
.72267 .30133 m .74336 .29186 L .74801 .29884 L p F P
0 g
s
.353 .587 .932 r
.33213 .53933 m .3294 .53879 L .33547 .54559 L p F P
0 g
s
.353 .587 .932 r
.33547 .54559 m .33685 .54587 L .33213 .53933 L p F P
0 g
s
.71 .625 .76 r
.52691 .82626 m .52924 .83156 L .51259 .84289 L p F P
0 g
s
.71 .625 .76 r
.51421 .82601 m .52691 .82626 L p .51259 .84289 L F P
0 g
s
.71 .625 .76 r
.50379 .83331 m .51421 .82601 L p .51259 .84289 L F P
0 g
s
.71 .625 .76 r
.51259 .84289 m .50816 .84279 L .50379 .83331 L p F P
0 g
s
.68 .523 .666 r
.57053 .89927 m .57751 .89879 L .58017 .91121 L p F P
0 g
s
.68 .523 .666 r
.58017 .91121 m .55752 .91276 L .57053 .89927 L p F P
0 g
s
.682 .541 .687 r
.57751 .89879 m .57634 .8943 L .57053 .89927 L closepath p F P
0 g
s
.72 .629 .755 r
.50816 .84279 m .50379 .83331 L .49234 .8419 L closepath p F P
0 g
s
.461 .664 .95 r
.38546 .56141 m .36706 .56071 L .36137 .55459 L p F P
0 g
s
.71 .532 .646 r
.50547 .91754 m .50782 .91325 L p .52383 .92544 L F P
0 g
s
.713 .533 .644 r
.50547 .91754 m .50782 .91325 L .50472 .91318 L closepath p F P
0 g
s
.672 .535 .69 r
.57751 .89879 m .57634 .8943 L .58998 .88411 L p F P
0 g
s
.312 .369 .76 r
.41754 .40293 m .41717 .4055 L p .41071 .39065 L F P
0 g
s
.239 .321 .747 r
.41754 .40293 m .41909 .40704 L .41717 .4055 L closepath p F P
0 g
s
.224 .319 .752 r
.41717 .4055 m .41909 .40704 L .42376 .41896 L p F P
0 g
s
.72 .538 .643 r
.50472 .91318 m .48769 .91228 L p .50164 .925 L F P
0 g
s
.72 .538 .643 r
.50164 .925 m .50547 .91754 L .50472 .91318 L p F P
0 g
s
.734 .585 .689 r
.47649 .89888 m .47385 .89867 L .46977 .88494 L p F P
0 g
s
.743 .59 .686 r
.46804 .88476 m .46977 .88494 L .47385 .89867 L p F P
0 g
s
.741 .605 .707 r
.46977 .88494 m .46922 .88338 L .46804 .88476 L closepath p F P
0 g
s
.31 .53 .904 r
.29874 .5196 m .2943 .51824 L .2906 .51117 L p F P
0 g
s
.741 .605 .707 r
.46804 .88476 m .46922 .88338 L .46461 .87027 L p F P
0 g
s
.73 .566 .669 r
.47462 .90187 m .47649 .89888 L p .48769 .91228 L F P
0 g
s
.734 .568 .667 r
.47462 .90187 m .47649 .89888 L .47385 .89867 L closepath p F P
0 g
s
.786 .939 .928 r
.7405 .52987 m .72224 .54232 L .71941 .54101 L p F P
0 g
s
.743 .59 .686 r
.47385 .89867 m .45923 .89713 L .46804 .88476 L p F P
0 g
s
.748 .6 .692 r
.45156 .88279 m .46804 .88476 L .45923 .89713 L p F P
0 g
s
.741 .605 .707 r
.46209 .86997 m .45156 .88279 L .46804 .88476 L p F P
0 g
s
.741 .605 .707 r
.46461 .87027 m .46209 .86997 L p .46804 .88476 L F P
0 g
s
.676 .841 .962 r
.62629 .57556 m .60594 .58327 L .60084 .5795 L p F P
0 g
s
.655 .833 .968 r
.58054 .58631 m .60084 .5795 L .60594 .58327 L p F P
0 g
s
.672 .724 .888 r
.52423 .5832 m .50423 .589 L .49871 .58364 L p F P
0 g
s
.047 .2 .701 r
.42461 .42116 m .42885 .42708 L p .4234 .41181 L F P
0 g
s
.047 .2 .701 r
.4234 .41181 m .42376 .41896 L .42461 .42116 L p F P
0 g
s
.666 .514 .668 r
.57751 .89879 m .60075 .89633 L p .5927 .90989 L F P
0 g
s
.666 .514 .668 r
.5927 .90989 m .58017 .91121 L .57751 .89879 L p F P
0 g
s
.672 .535 .69 r
.59743 .88332 m .60075 .89633 L .57751 .89879 L p F P
0 g
s
.672 .535 .69 r
.58998 .88411 m .59743 .88332 L p .57751 .89879 L F P
0 g
s
.708 .742 .878 r
.74336 .29186 m .72267 .30133 L .71795 .29468 L p F P
0 g
s
.679 .505 .644 r
.55635 .91436 m .55752 .91276 L .5561 .91285 L closepath p F P
0 g
s
.693 .518 .645 r
.5561 .91285 m .55635 .91436 L .54938 .92503 L p F P
0 g
s
.739 .617 .722 r
.47554 .85639 m .46377 .86821 L .45828 .85473 L p F P
0 g
s
.739 .617 .722 r
.45828 .85473 m .45846 .85454 L .47554 .85639 L p F P
0 g
s
.732 .626 .74 r
.47405 .84036 m .45846 .85454 L .47554 .85639 L p F P
0 g
s
.732 .626 .74 r
.4803 .84102 m .47405 .84036 L p .47554 .85639 L F P
0 g
s
.732 .626 .74 r
.47554 .85639 m .4838 .84907 L .4803 .84102 L p F P
0 g
s
.682 .586 .742 r
.56009 .8446 m .56541 .84153 L .55912 .84206 L closepath p F P
0 g
s
.864 .535 .426 r
.47895 .52134 m .48872 .52609 L .48663 .51782 L p F P
0 g
s
.864 .535 .426 r
.48663 .51782 m .4772 .51295 L .47895 .52134 L p F P
0 g
s
.681 .404 .496 r
.53757 .53185 m .51909 .5319 L .52187 .54004 L p F P
0 g
s
.711 .419 .48 r
.51007 .53916 m .52187 .54004 L .51909 .5319 L p F P
0 g
s
.711 .419 .48 r
.51909 .5319 m .51121 .53133 L .51007 .53916 L p F P
0 g
s
.157 0 .266 r
.58034 .50368 m .57905 .51018 L .58486 .5 L closepath p F P
0 g
s
.739 .571 .666 r
.47385 .89867 m .45923 .89713 L p .46923 .91087 L F P
0 g
s
.739 .571 .666 r
.46923 .91087 m .47462 .90187 L .47385 .89867 L p F P
0 g
s
.677 .505 .645 r
.55752 .91276 m .58017 .91121 L p .58064 .92318 L F P
0 g
s
.677 .505 .645 r
.55635 .91436 m .55752 .91276 L p .58064 .92318 L F P
0 g
s
.579 .315 .48 r
.5535 .52844 m .53757 .53185 L .53679 .53999 L p F P
0 g
s
.681 .404 .496 r
.52187 .54004 m .53679 .53999 L .53757 .53185 L p F P
0 g
s
.056 .208 .706 r
.41909 .40704 m .4234 .41181 L .42376 .41896 L closepath p F P
0 g
s
.726 .623 .743 r
.4838 .84907 m .49234 .8419 L .4803 .84102 L closepath p F P
0 g
s
.415 .621 .936 r
.35431 .54802 m .33685 .54587 L .33213 .53933 L p F P
0 g
s
.404 .625 .943 r
.33685 .54587 m .35431 .54802 L .36033 .55449 L p F P
0 g
s
.377 .408 .767 r
.41156 .38716 m .41071 .39065 L p .404 .37588 L F P
0 g
s
.314 .369 .759 r
.41156 .38716 m .41357 .39249 L .41071 .39065 L closepath p F P
0 g
s
.312 .369 .76 r
.41071 .39065 m .41357 .39249 L .41754 .40293 L p F P
0 g
s
.919 .947 .8 r
.24171 .33096 m .24122 .33417 L .23887 .33461 L closepath p F P
0 g
s
.939 .932 .768 r
.2339 .34213 m .23887 .33461 L .24122 .33417 L p F P
0 g
s
.866 .899 .855 r
.24122 .33417 m .24171 .33096 L .25384 .31811 L p F P
0 g
s
.682 .602 .76 r
.56541 .84153 m .55912 .84206 L .55471 .83171 L p F P
0 g
s
.743 .621 .724 r
.46461 .87027 m .46377 .86821 L .46209 .86997 L closepath p F P
0 g
s
.904 .835 .768 r
.65767 .34933 m .65394 .35487 L .65684 .36233 L p F P
0 g
s
.903 .835 .768 r
.64621 .3663 m .64863 .37391 L .65684 .36233 L p F P
0 g
s
.903 .835 .768 r
.65684 .36233 m .65394 .35487 L .64621 .3663 L p F P
0 g
s
.677 .505 .645 r
.58064 .92318 m .55809 .92473 L .55635 .91436 L p F P
0 g
s
.69 .514 .643 r
.55809 .92473 m .55635 .91436 L .54938 .92503 L closepath p F P
0 g
s
.527 .523 .795 r
.39133 .33578 m .37726 .33401 L .38304 .32271 L p F P
0 g
s
.479 .522 .824 r
.39236 .33828 m .39133 .33578 L .37726 .33401 L p F P
0 g
s
.479 .522 .824 r
.38797 .34729 m .39236 .33828 L p .37726 .33401 L F P
0 g
s
0 0 .485 r
.82711 .36194 m .82745 .37004 L .8244 .36223 L p F P
0 g
s
0 0 .485 r
.8244 .36223 m .82403 .35413 L .82711 .36194 L p F P
0 g
s
.381 .506 .859 r
.80047 .31274 m .79761 .3119 L .79891 .3199 L p F P
0 g
s
.381 .506 .859 r
.79891 .3199 m .80516 .32199 L .80047 .31274 L p F P
0 g
s
.255 .41 .825 r
.81124 .33267 m .80988 .33181 L .80516 .32199 L p F P
0 g
s
.73 .566 .669 r
.48769 .91228 m .47696 .91158 L .47462 .90187 L p F P
0 g
s
.74 .572 .666 r
.47696 .91158 m .47462 .90187 L .46923 .91087 L closepath p F P
0 g
s
.724 .637 .761 r
.50021 .82554 m .50379 .83331 L .49234 .8419 L p F P
0 g
s
.724 .637 .761 r
.49366 .82508 m .50021 .82554 L p .49234 .8419 L F P
0 g
s
.724 .637 .761 r
.47831 .83691 m .49366 .82508 L p .49234 .8419 L F P
0 g
s
.724 .637 .761 r
.49234 .8419 m .4803 .84102 L .47831 .83691 L p F P
0 g
s
.71 .532 .646 r
.52383 .92544 m .50682 .92522 L .50547 .91754 L p F P
0 g
s
.721 .539 .644 r
.50682 .92522 m .50547 .91754 L .50164 .925 L closepath p F P
0 g
s
.672 .727 .892 r
.54977 .58271 m .52966 .58877 L .52423 .5832 L p F P
0 g
s
.736 .89 .95 r
.68866 .55721 m .67687 .56339 L .67211 .56041 L p F P
0 g
s
.721 .887 .957 r
.65166 .57045 m .67211 .56041 L .67687 .56339 L p F P
0 g
s
.743 .622 .725 r
.46209 .86997 m .46377 .86821 L .45828 .85473 L p F P
0 g
s
.544 .574 .835 r
.3666 .32213 m .38304 .32271 L p .36794 .31103 L F P
0 g
s
.544 .574 .835 r
.36794 .31103 m .36446 .31815 L .3666 .32213 L p F P
0 g
s
0 0 .055 r
.8287 .39561 m .82856 .39757 L .82854 .39025 L p F P
0 g
s
0 0 .055 r
.82854 .39025 m .82878 .38663 L .8287 .39561 L p F P
0 g
s
.747 .455 .487 r
.50354 .53817 m .51007 .53916 L .51121 .53133 L p F P
0 g
s
.747 .455 .487 r
.51121 .53133 m .50154 .52979 L .50354 .53817 L p F P
0 g
s
.671 .549 .707 r
.59743 .88332 m .59642 .87997 L .58998 .88411 L closepath p F P
0 g
s
.673 .551 .708 r
.59338 .86965 m .59642 .87997 L .58998 .88411 L p F P
0 g
s
.75 .617 .712 r
.44617 .86782 m .46209 .86997 L .45156 .88279 L p F P
0 g
s
.743 .622 .725 r
.45828 .85473 m .44617 .86782 L .46209 .86997 L p F P
0 g
s
.897 .986 .734 r
.80241 .47052 m .79983 .47413 L .80095 .47079 L closepath p F P
0 g
s
.72 .538 .643 r
.48769 .91228 m .48184 .92394 L .50164 .925 L p F P
0 g
s
.73 .548 .646 r
.47696 .91158 m .48769 .91228 L .48184 .92394 L p F P
0 g
s
.532 .728 .964 r
.42248 .57782 m .44204 .57602 L .44779 .58125 L p F P
0 g
s
.538 .721 .958 r
.44204 .57602 m .42248 .57782 L .41665 .5724 L p F P
0 g
s
.66 .807 .953 r
.59692 .57623 m .60084 .5795 L .58054 .58631 L p F P
0 g
s
.66 .807 .953 r
.58054 .58631 m .57755 .58381 L .59692 .57623 L p F P
0 g
s
.958 .907 .725 r
.62897 .40706 m .6292 .41529 L .63591 .40418 L p F P
0 g
s
.958 .907 .725 r
.63591 .40418 m .63497 .39617 L .62897 .40706 L p F P
0 g
s
.426 .441 .773 r
.40553 .37131 m .404 .37588 L p .39661 .36136 L F P
0 g
s
.373 .409 .77 r
.40553 .37131 m .40805 .37786 L .404 .37588 L closepath p F P
0 g
s
.377 .408 .767 r
.404 .37588 m .40805 .37786 L .41156 .38716 L p F P
0 g
s
.965 .939 .666 r
.22825 .36174 m .22875 .35231 L .2339 .34213 L p F P
0 g
s
.943 .889 .487 r
.22875 .35231 m .22825 .36174 L .22506 .37118 L p F P
0 g
s
.96 .893 .51 r
.22505 .37256 m .22506 .37118 L .22825 .36174 L p F P
0 g
s
0 0 .133 r
.59515 .49032 m .58486 .5 L .59173 .48872 L p F P
0 g
s
0 0 .133 r
.59173 .48872 m .59695 .4838 L .59515 .49032 L p F P
0 g
s
.66 .76 .924 r
.57532 .58181 m .5551 .58802 L .54977 .58271 L p F P
0 g
s
.681 .599 .757 r
.58281 .83995 m .58022 .83375 L .56541 .84153 L closepath p F P
0 g
s
.682 .602 .76 r
.57603 .82365 m .58022 .83375 L .56541 .84153 L p F P
0 g
s
.682 .602 .76 r
.56838 .8243 m .57603 .82365 L p .56541 .84153 L F P
0 g
s
.682 .602 .76 r
.55471 .83171 m .56838 .8243 L p .56541 .84153 L F P
0 g
s
.789 .734 .207 r
.82712 .40513 m .82622 .41346 L .82786 .40394 L p F P
0 g
s
.789 .734 .207 r
.82795 .40013 m .82712 .40513 L p .82786 .40394 L F P
0 g
s
.789 .734 .207 r
.82786 .40394 m .82856 .39757 L .82795 .40013 L p F P
0 g
s
.659 .54 .708 r
.59642 .87997 m .59338 .86965 L .61591 .86641 L p F P
0 g
s
.664 .559 .727 r
.61122 .85225 m .61591 .86641 L .59338 .86965 L p F P
0 g
s
.664 .559 .727 r
.59338 .86965 m .59099 .86257 L .61122 .85225 L p F P
0 g
s
.46 .476 .788 r
.39236 .33828 m .39694 .34936 L .38797 .34729 L closepath p F P
0 g
s
.465 .47 .779 r
.39921 .3551 m .39661 .36136 L p .38797 .34729 L F P
0 g
s
.465 .47 .779 r
.38797 .34729 m .39694 .34936 L .39921 .3551 L p F P
0 g
s
.421 .445 .779 r
.39921 .3551 m .40251 .36342 L .39661 .36136 L closepath p F P
0 g
s
.426 .441 .773 r
.39661 .36136 m .40251 .36342 L .40553 .37131 L p F P
0 g
s
.896 .919 .525 r
.81856 .43409 m .82312 .42351 L .82172 .43192 L p F P
0 g
s
.896 .919 .525 r
.81724 .44161 m .81856 .43409 L p .82172 .43192 L F P
0 g
s
.896 .919 .525 r
.82172 .43192 m .8176 .44126 L .81724 .44161 L p F P
0 g
s
.663 .558 .726 r
.61115 .85204 m .61122 .85225 L .59099 .86257 L p F P
0 g
s
.663 .558 .726 r
.59099 .86257 m .58854 .85523 L .61115 .85204 L p F P
0 g
s
.699 .615 .758 r
.52924 .83156 m .53813 .82601 L .52691 .82626 L closepath p F P
0 g
s
.041 .308 .796 r
.2625 .48601 m .26322 .48653 L .26393 .4883 L closepath p F P
0 g
s
.891 .982 .812 r
.79229 .47796 m .78929 .48668 L .79983 .47413 L p F P
0 g
s
.891 .982 .812 r
.79852 .47037 m .79229 .47796 L p .79983 .47413 L F P
0 g
s
.891 .982 .812 r
.79983 .47413 m .80095 .47079 L .79852 .47037 L p F P
0 g
s
.474 .69 .961 r
.3914 .56729 m .39827 .56729 L .40526 .57289 L p F P
0 g
s
.508 .702 .957 r
.41078 .56672 m .39827 .56729 L .40526 .57289 L p F P
0 g
s
.508 .702 .957 r
.40526 .57289 m .41665 .5724 L .41078 .56672 L p F P
0 g
s
0 .116 .651 r
.82323 .3461 m .82403 .35413 L .81914 .347 L p F P
0 g
s
0 .116 .651 r
.81914 .347 m .81829 .33898 L .82323 .3461 L p F P
0 g
s
.667 .576 .744 r
.60584 .83766 m .61115 .85204 L .58854 .85523 L p F P
0 g
s
.667 .576 .744 r
.58854 .85523 m .5856 .84741 L .60584 .83766 L p F P
0 g
s
.714 .627 .759 r
.50379 .83331 m .51421 .82601 L .50021 .82554 L closepath p F P
0 g
s
.659 .54 .708 r
.61591 .86641 m .61665 .86896 L .59642 .87997 L p F P
0 g
s
.66 .542 .71 r
.59743 .88332 m .59642 .87997 L .61665 .86896 L p F P
0 g
s
.206 .3 .74 r
.41909 .40704 m .4234 .41181 L p .41821 .39644 L F P
0 g
s
.206 .3 .74 r
.41821 .39644 m .41754 .40293 L .41909 .40704 L p F P
0 g
s
.732 .641 .757 r
.4803 .84102 m .47831 .83691 L .47405 .84036 L closepath p F P
0 g
s
.73 .548 .646 r
.48184 .92394 m .47919 .92377 L .47696 .91158 L p F P
0 g
s
.74 .555 .643 r
.46923 .91087 m .47696 .91158 L .47919 .92377 L p F P
0 g
s
.255 .41 .825 r
.80516 .32199 m .80988 .32476 L .81124 .33267 L p F P
0 g
s
.116 .294 .768 r
.81704 .33104 m .81829 .33898 L .81124 .33267 L p F P
0 g
s
.116 .294 .768 r
.81124 .33267 m .80988 .32476 L .81704 .33104 L p F P
0 g
s
.655 .522 .69 r
.59743 .88332 m .6199 .88005 L p .61266 .89459 L F P
0 g
s
.655 .522 .69 r
.61266 .89459 m .60075 .89633 L .59743 .88332 L p F P
0 g
s
.66 .542 .71 r
.61665 .86896 m .6199 .88005 L .59743 .88332 L p F P
0 g
s
.773 .888 .475 r
.61392 .44715 m .61886 .43655 L .61666 .44548 L p F P
0 g
s
.773 .888 .475 r
.61207 .45327 m .61392 .44715 L p .61666 .44548 L F P
0 g
s
.773 .888 .475 r
.61666 .44548 m .61362 .45109 L .61207 .45327 L p F P
0 g
s
.919 .791 .316 r
.22411 .38892 m .22361 .38061 L .22505 .37256 L p F P
0 g
s
.771 .614 .049 r
.22361 .38061 m .22411 .38892 L .22414 .39721 L p F P
0 g
s
.522 .636 .904 r
.77773 .30178 m .77381 .3017 L .7692 .29418 L p F P
0 g
s
.691 .497 .62 r
.53304 .92548 m .54938 .92503 L .54435 .93655 L p F P
0 g
s
.691 .497 .62 r
.54435 .93655 m .53434 .93682 L .53304 .92548 L p F P
0 g
s
.704 .506 .618 r
.52383 .92544 m .53304 .92548 L .53434 .93682 L p F P
0 g
s
.21 .303 .742 r
.41357 .39249 m .41821 .39644 L .41754 .40293 L closepath p F P
0 g
s
.704 .506 .618 r
.53434 .93682 m .51953 .93676 L .52383 .92544 L p F P
0 g
s
.708 .511 .62 r
.50682 .92522 m .52383 .92544 L .51953 .93676 L p F P
0 g
s
.543 .572 .834 r
.36082 .31135 m .36794 .31103 L .36446 .31815 L closepath p F P
0 g
s
.847 .888 .868 r
.25921 .31321 m .25384 .31811 L .25483 .3117 L closepath p F P
0 g
s
.881 .917 .846 r
.25483 .3117 m .25384 .31811 L .24171 .33096 L p F P
0 g
s
.797 .85 .891 r
.25921 .31321 m .25483 .3117 L p .27574 .29693 L F P
0 g
s
.797 .85 .891 r
.27574 .29693 m .27466 .30187 L .25921 .31321 L p F P
0 g
s
.739 .571 .666 r
.45923 .89713 m .45223 .90906 L .46923 .91087 L p F P
0 g
s
.749 .583 .669 r
.44392 .89527 m .45923 .89713 L .45223 .90906 L p F P
0 g
s
.748 .6 .692 r
.44357 .89417 m .45156 .88279 L p .45923 .89713 L F P
0 g
s
.748 .6 .692 r
.45923 .89713 m .44392 .89527 L .44357 .89417 L p F P
0 g
s
.662 .493 .646 r
.58192 .92156 m .5927 .90989 L .58017 .91121 L closepath p F P
0 g
s
.677 .505 .645 r
.58017 .91121 m .58192 .92156 L .58064 .92318 L p F P
0 g
s
.804 .956 .914 r
.74256 .52834 m .7405 .52987 L .7417 .528 L closepath p F P
0 g
s
.786 .939 .928 r
.73815 .52605 m .7417 .528 L .7405 .52987 L p F P
0 g
s
.786 .939 .928 r
.72169 .53749 m .73815 .52605 L p .7405 .52987 L F P
0 g
s
.786 .939 .928 r
.71941 .54101 m .72169 .53749 L p .7405 .52987 L F P
0 g
s
0 .082 .64 r
.24351 .45925 m .24144 .45126 L .23619 .44469 L p F P
0 g
s
.034 .249 .75 r
.25009 .46541 m .24351 .45925 L .24144 .45126 L p F P
0 g
s
0 .204 .728 r
.25249 .4732 m .25009 .46541 L .24351 .45925 L p F P
0 g
s
.684 .603 .759 r
.55471 .83171 m .56838 .8243 L .55209 .82557 L closepath p F P
0 g
s
.796 .5 .487 r
.49013 .53466 m .50354 .53817 L .50154 .52979 L p F P
0 g
s
.796 .5 .487 r
.50154 .52979 m .48872 .52609 L .49013 .53466 L p F P
0 g
s
.667 .575 .743 r
.60553 .83683 m .60584 .83766 L .5856 .84741 L p F P
0 g
s
.667 .575 .743 r
.5856 .84741 m .58281 .83995 L .60553 .83683 L p F P
0 g
s
.708 .511 .62 r
.51953 .93676 m .50813 .93661 L .50682 .92522 L p F P
0 g
s
.72 .519 .618 r
.50164 .925 m .50682 .92522 L .50813 .93661 L p F P
0 g
s
.122 .342 .808 r
.25645 .47599 m .25249 .4732 L .25009 .46541 L p F P
0 g
s
.082 .325 .802 r
.25249 .4732 m .25645 .47599 L .2625 .48601 L p F P
0 g
s
.623 .764 .947 r
.49315 .57766 m .49871 .58364 L .48804 .58619 L p F P
0 g
s
.623 .764 .947 r
.47321 .58334 m .49315 .57766 L p .48804 .58619 L F P
0 g
s
.623 .764 .947 r
.48804 .58619 m .47384 .58391 L .47321 .58334 L p F P
0 g
s
.816 .956 .907 r
.76044 .51431 m .74256 .52834 L .7417 .528 L p F P
0 g
s
.072 .315 .796 r
.26061 .47889 m .25645 .47599 L .2625 .48601 L p F P
0 g
s
.072 .315 .796 r
.2625 .48601 m .26322 .48653 L .26061 .47889 L p F P
0 g
s
.743 .623 .726 r
.45828 .85473 m .45846 .85454 L .45819 .8545 L closepath p F P
0 g
s
.74 .637 .745 r
.4575 .83834 m .47405 .84036 L .45846 .85454 L p F P
0 g
s
.74 .637 .745 r
.45274 .84279 m .4575 .83834 L p .45846 .85454 L F P
0 g
s
.74 .637 .745 r
.45846 .85454 m .45819 .8545 L .45274 .84279 L p F P
0 g
s
.753 .602 .691 r
.44357 .89417 m .45156 .88279 L .43937 .88111 L closepath p F P
0 g
s
.75 .617 .712 r
.43812 .87781 m .44617 .86782 L p .45156 .88279 L F P
0 g
s
.75 .617 .712 r
.45156 .88279 m .43937 .88111 L .43812 .87781 L p F P
0 g
s
.752 .634 .73 r
.45819 .8545 m .45828 .85473 L .44617 .86782 L p F P
0 g
s
.945 .96 .718 r
.62902 .41663 m .62828 .41682 L .6292 .41529 L closepath p F P
0 g
s
.698 .629 .776 r
.53813 .82601 m .52691 .82626 L .52382 .81992 L p F P
0 g
s
.709 .634 .771 r
.52691 .82626 m .52382 .81992 L .51421 .82601 L closepath p F P
0 g
s
.752 .634 .73 r
.44303 .85222 m .45819 .8545 L p .44617 .86782 L F P
0 g
s
.748 .64 .741 r
.45819 .8545 m .45274 .84279 L .44303 .85222 L closepath p F P
0 g
s
.733 .642 .758 r
.47279 .82561 m .4575 .83834 L .47405 .84036 L p F P
0 g
s
.733 .642 .758 r
.47405 .84036 m .47831 .83691 L .47279 .82561 L p F P
0 g
s
.687 .493 .618 r
.54938 .92503 m .55809 .92473 L .5594 .93603 L p F P
0 g
s
.687 .493 .618 r
.5594 .93603 m .54435 .93655 L .54938 .92503 L p F P
0 g
s
0 0 .523 r
.23619 .44469 m .23448 .43649 L .2305 .42951 L p F P
0 g
s
0 .136 .672 r
.24144 .45126 m .23619 .44469 L .23448 .43649 L p F P
0 g
s
.72 .519 .618 r
.50813 .93661 m .49786 .93618 L .50164 .925 L p F P
0 g
s
.724 .525 .621 r
.48184 .92394 m .50164 .925 L .49786 .93618 L p F P
0 g
s
.74 .555 .643 r
.47919 .92377 m .46398 .92237 L .46923 .91087 L p F P
0 g
s
.745 .563 .648 r
.45223 .90906 m .46923 .91087 L .46398 .92237 L p F P
0 g
s
.728 .636 .756 r
.49366 .82508 m .47831 .83691 L .47279 .82561 L p F P
0 g
s
.711 .64 .776 r
.51837 .80879 m .52382 .81992 L .51421 .82601 L p F P
0 g
s
.711 .64 .776 r
.49832 .82184 m .51837 .80879 L p .51421 .82601 L F P
0 g
s
.711 .64 .776 r
.51421 .82601 m .50021 .82554 L .49832 .82184 L p F P
0 g
s
.696 .624 .772 r
.55209 .82557 m .54931 .81966 L .53813 .82601 L closepath p F P
0 g
s
.698 .629 .776 r
.54391 .80818 m .54931 .81966 L .53813 .82601 L p F P
0 g
s
.698 .629 .776 r
.52382 .81992 m .54391 .80818 L p .53813 .82601 L F P
0 g
s
.907 .863 .785 r
.63828 .37783 m .64621 .3663 L .64863 .37391 L p F P
0 g
s
.907 .863 .785 r
.63848 .37858 m .63828 .37783 L p .64863 .37391 L F P
0 g
s
.907 .863 .785 r
.64863 .37391 m .64292 .38184 L .63848 .37858 L p F P
0 g
s
.371 .576 .919 r
.32331 .53166 m .31178 .52924 L .30784 .52232 L p F P
0 g
s
.356 .578 .925 r
.31178 .52924 m .32331 .53166 L .3294 .53879 L p F P
0 g
s
.589 .619 .849 r
.34972 .29229 m .35499 .30104 L .34335 .30308 L closepath p F P
0 g
s
.587 .636 .867 r
.36082 .31135 m .35499 .30104 L .34335 .30308 L p F P
0 g
s
.663 .71 .883 r
.31766 .28019 m .2983 .28848 L .30459 .29483 L p F P
0 g
s
.663 .71 .883 r
.30459 .29483 m .32382 .2877 L .31766 .28019 L p F P
0 g
s
.67 .593 .761 r
.60048 .82447 m .60553 .83683 L .58281 .83995 L p F P
0 g
s
.67 .593 .761 r
.58281 .83995 m .58022 .83375 L .60048 .82447 L p F P
0 g
s
.673 .483 .62 r
.55809 .92473 m .58064 .92318 L .5745 .935 L p F P
0 g
s
.673 .483 .62 r
.5745 .935 m .5594 .93603 L .55809 .92473 L p F P
0 g
s
.872 .978 .845 r
.77992 .49115 m .79229 .47796 L .78929 .48668 L p F P
0 g
s
.872 .978 .845 r
.77939 .49263 m .77992 .49115 L p .78929 .48668 L F P
0 g
s
.872 .978 .845 r
.78929 .48668 m .78279 .49346 L .77939 .49263 L p F P
0 g
s
.314 .529 .902 r
.30439 .51516 m .2926 .51177 L .29874 .5196 L p F P
0 g
s
.314 .529 .902 r
.29874 .5196 m .30784 .52232 L .30439 .51516 L p F P
0 g
s
.31 .53 .904 r
.2906 .51117 m .2926 .51177 L .29874 .5196 L p F P
0 g
s
.313 .368 .759 r
.41357 .39249 m .41821 .39644 L p .41305 .38102 L F P
0 g
s
.313 .368 .759 r
.41305 .38102 m .41156 .38716 L .41357 .39249 L p F P
0 g
s
.747 .911 .948 r
.69729 .55235 m .68866 .55721 L .69446 .55076 L closepath p F P
0 g
s
.736 .89 .95 r
.69262 .54953 m .69446 .55076 L .68866 .55721 L p F P
0 g
s
.736 .89 .95 r
.67211 .56041 m .69262 .54953 L p .68866 .55721 L F P
0 g
s
.192 .41 .845 r
.26061 .47889 m .26322 .48653 L .27298 .49173 L p F P
0 g
s
.185 .419 .854 r
.27591 .49919 m .27298 .49173 L .26322 .48653 L p F P
0 g
s
.651 .502 .668 r
.60196 .90206 m .61266 .89459 L .60075 .89633 L closepath p F P
0 g
s
.666 .514 .668 r
.60075 .89633 m .60196 .90206 L .5927 .90989 L p F P
0 g
s
.918 .954 .798 r
.24359 .32084 m .24171 .33096 L .23887 .33461 L p F P
0 g
s
.881 .917 .846 r
.24171 .33096 m .24359 .32084 L p .25483 .3117 L F P
0 g
s
.684 .618 .776 r
.56838 .8243 m .55209 .82557 L .54931 .81966 L p F P
0 g
s
.721 .644 .772 r
.50021 .82554 m .49832 .82184 L .49366 .82508 L closepath p F P
0 g
s
.811 .792 .834 r
.68884 .31651 m .67752 .32651 L .67265 .32035 L p F P
0 g
s
.857 .799 .793 r
.67426 .33034 m .67752 .32651 L .67265 .32035 L p F P
0 g
s
.866 .979 .85 r
.78279 .49346 m .77633 .50002 L .77939 .49263 L closepath p F P
0 g
s
.83 .902 .49 r
.61362 .45109 m .6111 .45627 L .61207 .45327 L closepath p F P
0 g
s
.755 .62 .71 r
.43812 .87781 m .44617 .86782 L .43355 .86586 L closepath p F P
0 g
s
.752 .634 .73 r
.43261 .8637 m .44303 .85222 L p .44617 .86782 L F P
0 g
s
.752 .634 .73 r
.44617 .86782 m .43355 .86586 L .43261 .8637 L p F P
0 g
s
.699 .879 .965 r
.65166 .57045 m .65051 .57096 L .65142 .5703 L closepath p F P
0 g
s
.695 .856 .959 r
.64675 .56694 m .65142 .5703 L .65051 .57096 L p F P
0 g
s
.695 .856 .959 r
.62629 .57556 m .64675 .56694 L p .65051 .57096 L F P
0 g
s
.581 .741 .952 r
.44779 .58125 m .46335 .57867 L .47265 .58344 L p F P
0 g
s
.596 .738 .944 r
.46335 .57867 m .44779 .58125 L .44204 .57602 L p F P
0 g
s
.817 .788 .825 r
.68884 .31651 m .69759 .30851 L .69278 .30199 L p F P
0 g
s
.817 .788 .825 r
.69278 .30199 m .68498 .30924 L .68884 .31651 L p F P
0 g
s
.811 .792 .834 r
.67265 .32035 m .68498 .30924 L .68884 .31651 L p F P
0 g
s
.764 .772 .86 r
.70966 .30042 m .69759 .30851 L .69278 .30199 L p F P
0 g
s
.314 .369 .76 r
.40805 .37786 m .41305 .38102 L .41156 .38716 L closepath p F P
0 g
s
0 0 .369 r
.2305 .42951 m .22917 .42109 L .22647 .4137 L p F P
0 g
s
0 .001 .569 r
.23448 .43649 m .2305 .42951 L .22917 .42109 L p F P
0 g
s
.482 .683 .955 r
.39827 .56729 m .3914 .56729 L .38546 .56141 L p F P
0 g
s
.836 .97 .886 r
.76277 .51227 m .76044 .51431 L .76167 .51192 L closepath p F P
0 g
s
.816 .956 .907 r
.75849 .51033 m .76167 .51192 L .76044 .51431 L p F P
0 g
s
.816 .956 .907 r
.74563 .52061 m .75849 .51033 L p .76044 .51431 L F P
0 g
s
.816 .956 .907 r
.7417 .528 m .74563 .52061 L p .76044 .51431 L F P
0 g
s
.579 .315 .48 r
.55873 .53536 m .559 .53184 L .5535 .52844 L p F P
0 g
s
.579 .315 .48 r
.53679 .53999 m .55873 .53536 L p .5535 .52844 L F P
0 g
s
.582 .312 .473 r
.55945 .52724 m .559 .53184 L .5535 .52844 L closepath p F P
0 g
s
.845 .969 .879 r
.77633 .50002 m .76277 .51227 L .76167 .51192 L p F P
0 g
s
.951 .943 .735 r
.62342 .41706 m .62897 .40706 L .6292 .41529 L p F P
0 g
s
.951 .943 .735 r
.6292 .41529 m .62828 .41682 L .62342 .41706 L p F P
0 g
s
.878 .473 .027 r
.45142 .4794 m .45635 .48596 L .45926 .49383 L p F P
0 g
s
.845 .969 .879 r
.77868 .49232 m .77939 .49263 L .77633 .50002 L p F P
0 g
s
.845 .969 .879 r
.76456 .50532 m .77868 .49232 L p .77633 .50002 L F P
0 g
s
.845 .969 .879 r
.76167 .51192 m .76456 .50532 L p .77633 .50002 L F P
0 g
s
.243 0 .328 r
.59414 .49453 m .59515 .49032 L .58486 .5 L p F P
0 g
s
.243 0 .328 r
.59238 .49856 m .59414 .49453 L p .58486 .5 L F P
0 g
s
.243 0 .328 r
.57895 .51082 m .59238 .49856 L p .58486 .5 L F P
0 g
s
.243 0 .328 r
.58486 .5 m .57905 .51018 L .57895 .51082 L p F P
0 g
s
.723 .884 .955 r
.6673 .55727 m .67211 .56041 L .65166 .57045 L p F P
0 g
s
.723 .884 .955 r
.66274 .55951 m .6673 .55727 L p .65166 .57045 L F P
0 g
s
.723 .884 .955 r
.65166 .57045 m .65142 .5703 L .66274 .55951 L p F P
0 g
s
.857 .799 .793 r
.67265 .32035 m .67032 .32313 L .67426 .33034 L p F P
0 g
s
.855 .798 .795 r
.65983 .33553 m .66344 .34283 L .67426 .33034 L p F P
0 g
s
.855 .798 .795 r
.67426 .33034 m .67032 .32313 L .65983 .33553 L p F P
0 g
s
.728 .636 .756 r
.47279 .82561 m .47548 .82349 L .49366 .82508 L p F P
0 g
s
.722 .646 .773 r
.49283 .81114 m .47548 .82349 L .49366 .82508 L p F P
0 g
s
.722 .646 .773 r
.49366 .82508 m .49832 .82184 L .49283 .81114 L p F P
0 g
s
.664 .495 .647 r
.5927 .90989 m .6034 .90872 L p .58218 .92307 L F P
0 g
s
.664 .495 .647 r
.58218 .92307 m .58192 .92156 L .5927 .90989 L p F P
0 g
s
.664 .512 .667 r
.6034 .90872 m .60196 .90206 L .5927 .90989 L closepath p F P
0 g
s
.918 .954 .798 r
.23887 .33461 m .23442 .33638 L p .24359 .32084 L F P
0 g
s
.943 .947 .753 r
.23887 .33461 m .2339 .34213 L .23442 .33638 L closepath p F P
0 g
s
.67 .593 .76 r
.59892 .82062 m .60048 .82447 L .58022 .83375 L p F P
0 g
s
.67 .593 .76 r
.58022 .83375 m .57603 .82365 L .59892 .82062 L p F P
0 g
s
.87 .768 .265 r
.22506 .37118 m .22505 .37256 L .22361 .38061 L p F P
0 g
s
.777 .831 .894 r
.27887 .29902 m .27466 .30187 L .27574 .29693 L closepath p F P
0 g
s
.724 .525 .621 r
.47989 .92978 m .48184 .92394 L p .49786 .93618 L F P
0 g
s
.729 .528 .62 r
.47989 .92978 m .48184 .92394 L .47919 .92377 L closepath p F P
0 g
s
.914 .515 .21 r
.46197 .50183 m .46861 .50774 L .46578 .49978 L p F P
0 g
s
.914 .515 .21 r
.46578 .49978 m .45926 .49383 L .46197 .50183 L p F P
0 g
s
0 0 .004 r
.82884 .38744 m .8287 .39561 L .82878 .38663 L p F P
0 g
s
0 0 .004 r
.82878 .38663 m .82889 .37846 L .82884 .38744 L p F P
0 g
s
.522 .636 .904 r
.7692 .29418 m .77499 .29418 L .77773 .30178 L p F P
0 g
s
.471 .589 .89 r
.79117 .29569 m .77499 .29418 L .77773 .30178 L p F P
0 g
s
.471 .589 .89 r
.77773 .30178 m .79581 .30395 L .79117 .29569 L p F P
0 g
s
.804 .928 .917 r
.7417 .528 m .73815 .52605 L .74563 .52061 L closepath p F P
0 g
s
.98 .909 .653 r
.62386 .42596 m .62828 .41682 L .62342 .41706 L p F P
0 g
s
.701 .627 .771 r
.54391 .80818 m .52382 .81992 L .51837 .80879 L p F P
0 g
s
.714 .86 .951 r
.65142 .5703 m .64675 .56694 L .66274 .55951 L closepath p F P
0 g
s
.652 .504 .669 r
.6034 .90872 m .60196 .90206 L .61266 .89459 L p F P
0 g
s
.734 .532 .619 r
.47919 .92377 m .46398 .92237 L p .47821 .93507 L F P
0 g
s
.734 .532 .619 r
.47821 .93507 m .47989 .92978 L .47919 .92377 L p F P
0 g
s
.933 .847 .734 r
.64292 .38184 m .64098 .38532 L .63848 .37858 L closepath p F P
0 g
s
.893 .919 .526 r
.8176 .44126 m .81705 .4425 L .81724 .44161 L closepath p F P
0 g
s
0 0 .394 r
.44114 .45705 m .43879 .44945 L .43471 .44217 L p F P
0 g
s
.715 .639 .771 r
.51837 .80879 m .49832 .82184 L .49283 .81114 L p F P
0 g
s
.611 .644 .859 r
.34311 .28201 m .32382 .2877 L .3299 .29577 L p F P
0 g
s
.611 .644 .859 r
.3299 .29577 m .34909 .29123 L .34311 .28201 L p F P
0 g
s
.546 .555 .815 r
.37423 .29864 m .35499 .30104 L .36082 .31135 L p F P
0 g
s
.546 .555 .815 r
.37508 .30039 m .37423 .29864 L p .36082 .31135 L F P
0 g
s
.546 .555 .815 r
.36082 .31135 m .36794 .31103 L .37508 .30039 L p F P
0 g
s
.388 .418 .771 r
.40805 .37786 m .41305 .38102 L p .40759 .3657 L F P
0 g
s
.388 .418 .771 r
.40759 .3657 m .40553 .37131 L .40805 .37786 L p F P
0 g
s
.902 .54 .342 r
.47701 .51225 m .4772 .51295 L .47647 .51244 L closepath p F P
0 g
s
.749 .583 .669 r
.45223 .90906 m .44732 .90847 L .44392 .89527 L p F P
0 g
s
.758 .588 .666 r
.44292 .89512 m .44392 .89527 L .44732 .90847 L p F P
0 g
s
.756 .604 .689 r
.44392 .89527 m .44357 .89417 L .44292 .89512 L closepath p F P
0 g
s
.756 .604 .689 r
.44292 .89512 m .44357 .89417 L .43937 .88111 L p F P
0 g
s
.756 .604 .689 r
.43937 .88111 m .43597 .88056 L p .44292 .89512 L F P
0 g
s
.758 .621 .708 r
.43937 .88111 m .43812 .87781 L .43597 .88056 L closepath p F P
0 g
s
.274 .477 .875 r
.28647 .50349 m .27591 .49919 L .27298 .49173 L p F P
0 g
s
.248 .472 .879 r
.28839 .50618 m .2906 .51117 L p .27591 .49919 L F P
0 g
s
.248 .472 .879 r
.27591 .49919 m .28647 .50349 L .28839 .50618 L p F P
0 g
s
.757 .831 .908 r
.2919 .28281 m .2983 .28848 L .27887 .29902 L p F P
0 g
s
.757 .831 .908 r
.27837 .29094 m .2919 .28281 L p .27887 .29902 L F P
0 g
s
.757 .831 .908 r
.27887 .29902 m .27574 .29693 L .27837 .29094 L p F P
0 g
s
.758 .588 .666 r
.44732 .90847 m .4365 .9069 L .44292 .89512 L p F P
0 g
s
.764 .594 .668 r
.42799 .89272 m .44292 .89512 L .4365 .9069 L p F P
0 g
s
.756 .604 .689 r
.43597 .88056 m .42799 .89272 L .44292 .89512 L p F P
0 g
s
.927 .967 .678 r
.81238 .44524 m .81058 .45371 L .81705 .4425 L p F P
0 g
s
.927 .967 .678 r
.81394 .44246 m .81238 .44524 L p .81705 .4425 L F P
0 g
s
.927 .967 .678 r
.81705 .4425 m .81724 .44161 L .81394 .44246 L p F P
0 g
s
.902 .978 .801 r
.80095 .47079 m .79852 .47037 L .80248 .46549 L closepath p F P
0 g
s
.581 .749 .957 r
.47384 .58391 m .47321 .58334 L .47265 .58344 L closepath p F P
0 g
s
.684 .618 .776 r
.54931 .81966 m .56948 .80934 L p .56838 .8243 L F P
0 g
s
.687 .616 .772 r
.56948 .80934 m .54931 .81966 L .54391 .80818 L p F P
0 g
s
.768 .913 .937 r
.71315 .53713 m .71773 .54002 L .69729 .55235 L p F P
0 g
s
.768 .913 .937 r
.69721 .54692 m .71315 .53713 L p .69729 .55235 L F P
0 g
s
.768 .913 .937 r
.69729 .55235 m .69446 .55076 L .69721 .54692 L p F P
0 g
s
.675 .503 .645 r
.58218 .92307 m .58192 .92156 L .58064 .92318 L closepath p F P
0 g
s
.758 .622 .708 r
.43597 .88056 m .43812 .87781 L .43355 .86586 L p F P
0 g
s
.683 .614 .773 r
.57603 .82365 m .57485 .82107 L .56838 .8243 L closepath p F P
0 g
s
.684 .618 .776 r
.56948 .80934 m .57485 .82107 L .56838 .8243 L p F P
0 g
s
.43 .185 .439 r
.55945 .52724 m .559 .53184 L .5644 .52486 L closepath p F P
0 g
s
.66 .795 .947 r
.59568 .57513 m .59692 .57623 L .57755 .58381 L p F P
0 g
s
.66 .795 .947 r
.57755 .58381 m .57532 .58181 L .59568 .57513 L p F P
0 g
s
.257 .424 .837 r
.80988 .32476 m .80516 .32199 L .80047 .31274 L p F P
0 g
s
.744 .64 .744 r
.45274 .84279 m .4575 .83834 L .45017 .8373 L closepath p F P
0 g
s
.74 .653 .763 r
.47154 .82307 m .47279 .82561 L .4575 .83834 L p F P
0 g
s
.74 .653 .763 r
.45913 .82137 m .47154 .82307 L p .4575 .83834 L F P
0 g
s
.74 .653 .763 r
.44717 .83155 m .45913 .82137 L p .4575 .83834 L F P
0 g
s
.74 .653 .763 r
.4575 .83834 m .45017 .8373 L .44717 .83155 L p F P
0 g
s
.745 .563 .648 r
.44888 .91651 m .45223 .90906 L p .46398 .92237 L F P
0 g
s
.75 .566 .646 r
.44888 .91651 m .45223 .90906 L .44732 .90847 L closepath p F P
0 g
s
.905 .56 .378 r
.47125 .5159 m .47895 .52134 L .4772 .51295 L p F P
0 g
s
.905 .56 .378 r
.4772 .51295 m .47647 .51244 L .47125 .5159 L p F P
0 g
s
.67 .479 .618 r
.58064 .92318 m .58218 .92307 L .5835 .93434 L p F P
0 g
s
.67 .479 .618 r
.5835 .93434 m .5745 .935 L .58064 .92318 L p F P
0 g
s
.749 .642 .742 r
.44303 .85222 m .45274 .84279 L .45017 .8373 L p F P
0 g
s
0 0 .552 r
.43471 .44217 m .43366 .43403 L .42885 .42708 L p F P
0 g
s
0 0 .561 r
.43366 .43403 m .43471 .44217 L .43879 .44945 L p F P
0 g
s
.821 .892 .47 r
.60894 .45794 m .60612 .46688 L .6111 .45627 L p F P
0 g
s
.821 .892 .47 r
.6111 .45627 m .61207 .45327 L .60894 .45794 L p F P
0 g
s
.368 .583 .926 r
.32794 .53254 m .32331 .53166 L .3294 .53879 L p F P
0 g
s
.368 .583 .926 r
.3294 .53879 m .33213 .53933 L .32794 .53254 L p F P
0 g
s
.388 .418 .771 r
.40251 .36342 m .40759 .3657 L .40553 .37131 L closepath p F P
0 g
s
.655 .469 .619 r
.5835 .93434 m .58218 .92307 L .60539 .92055 L p F P
0 g
s
.664 .495 .647 r
.6034 .90872 m .60539 .92055 L .58218 .92307 L p F P
0 g
s
.425 .636 .943 r
.3563 .54821 m .35431 .54802 L .36033 .55449 L p F P
0 g
s
.425 .636 .943 r
.36033 .55449 m .36137 .55459 L .3563 .54821 L p F P
0 g
s
0 0 .174 r
.22647 .4137 m .22555 .40503 L .22414 .39721 L p F P
0 g
s
0 0 .44 r
.22917 .42109 m .22647 .4137 L .22555 .40503 L p F P
0 g
s
.776 .912 .932 r
.71941 .54101 m .71773 .54002 L .72169 .53749 L closepath p F P
0 g
s
.644 .529 .708 r
.61665 .86896 m .62752 .86422 L .61591 .86641 L closepath p F P
0 g
s
.648 .548 .728 r
.62752 .86422 m .61591 .86641 L .61122 .85225 L p F P
0 g
s
.767 .614 .689 r
.42156 .87799 m .43597 .88056 L .42799 .89272 L p F P
0 g
s
.758 .622 .708 r
.43109 .86542 m .42156 .87799 L .43597 .88056 L p F P
0 g
s
.758 .622 .708 r
.43355 .86586 m .43109 .86542 L p .43597 .88056 L F P
0 g
s
.585 .739 .949 r
.46756 .57789 m .46335 .57867 L .47265 .58344 L p F P
0 g
s
.585 .739 .949 r
.47265 .58344 m .47321 .58334 L .46756 .57789 L p F P
0 g
s
.943 .889 .487 r
.22506 .37118 m .22555 .36177 L .22875 .35231 L p F P
0 g
s
.829 .745 .225 r
.22555 .36177 m .22506 .37118 L .22362 .37999 L p F P
0 g
s
.87 .768 .265 r
.22361 .38061 m .22362 .37999 L .22506 .37118 L p F P
0 g
s
.934 .847 .732 r
.6326 .3886 m .63497 .39617 L .64098 .38532 L p F P
0 g
s
.934 .847 .732 r
.638 .37823 m .6326 .3886 L p .64098 .38532 L F P
0 g
s
.934 .847 .732 r
.64098 .38532 m .63848 .37858 L .638 .37823 L p F P
0 g
s
.771 .77 .853 r
.70966 .30042 m .71795 .29468 L .71319 .28787 L p F P
0 g
s
.771 .77 .853 r
.71319 .28787 m .70571 .29315 L .70966 .30042 L p F P
0 g
s
.764 .772 .86 r
.69278 .30199 m .70571 .29315 L .70966 .30042 L p F P
0 g
s
.757 .635 .725 r
.44303 .85222 m .43261 .8637 L .42704 .85118 L p F P
0 g
s
.757 .635 .725 r
.42704 .85118 m .42837 .84967 L .44303 .85222 L p F P
0 g
s
.749 .642 .742 r
.44219 .83595 m .42837 .84967 L .44303 .85222 L p F P
0 g
s
.749 .642 .742 r
.45017 .8373 m .44219 .83595 L p .44303 .85222 L F P
0 g
s
.854 .81 .806 r
.65274 .34369 m .65983 .33553 L .66344 .34283 L p F P
0 g
s
.854 .81 .806 r
.66344 .34283 m .65767 .34933 L .65274 .34369 L p F P
0 g
s
.645 .531 .71 r
.6199 .88005 m .61665 .86896 L .62752 .86422 L p F P
0 g
s
.652 .504 .669 r
.61266 .89459 m .6232 .89304 L p .6034 .90872 L F P
0 g
s
.654 .521 .69 r
.6232 .89304 m .62217 .88901 L .61266 .89459 L closepath p F P
0 g
s
.655 .522 .69 r
.6199 .88005 m .62217 .88901 L .61266 .89459 L p F P
0 g
s
.645 .48 .646 r
.60539 .92055 m .6034 .90872 L .62585 .90542 L p F P
0 g
s
.652 .504 .669 r
.6232 .89304 m .62585 .90542 L .6034 .90872 L p F P
0 g
s
.898 .863 .418 r
.82402 .41521 m .82312 .42351 L .82622 .41346 L p F P
0 g
s
.898 .863 .418 r
.82622 .41346 m .82712 .40513 L .82402 .41521 L p F P
0 g
s
.667 .725 .892 r
.49315 .57766 m .47321 .58334 L .46756 .57789 L p F P
0 g
s
.879 .51 .342 r
.47117 .51586 m .47125 .5159 L .47647 .51244 L p F P
0 g
s
.879 .51 .342 r
.47647 .51244 m .46861 .50774 L .47117 .51586 L p F P
0 g
s
.627 .695 .893 r
.74336 .29186 m .76457 .28677 L .7692 .29418 L p F P
0 g
s
.632 .702 .896 r
.76457 .28677 m .74336 .29186 L .73868 .28487 L p F P
0 g
s
.708 .742 .878 r
.71795 .29468 m .73868 .28487 L .74336 .29186 L p F P
0 g
s
.648 .548 .728 r
.61122 .85225 m .61217 .85185 L p .62752 .86422 L F P
0 g
s
.648 .547 .726 r
.61122 .85225 m .61217 .85185 L .61115 .85204 L closepath p F P
0 g
s
.652 .566 .746 r
.61217 .85185 m .61115 .85204 L .60584 .83766 L p F P
0 g
s
.937 .961 .667 r
.81724 .44161 m .81394 .44246 L .81856 .43409 L closepath p F P
0 g
s
.672 .609 .777 r
.59513 .81218 m .59892 .82062 L .57603 .82365 L p F P
0 g
s
.672 .609 .777 r
.57603 .82365 m .57485 .82107 L .59513 .81218 L p F P
0 g
s
.732 .643 .76 r
.47279 .82561 m .47548 .82349 L .47154 .82307 L closepath p F P
0 g
s
.686 .472 .59 r
.53434 .93682 m .54435 .93655 L .54231 .94736 L p F P
0 g
s
.686 .472 .59 r
.54231 .94736 m .53489 .94756 L .53434 .93682 L p F P
0 g
s
.7 .483 .589 r
.51953 .93676 m .53434 .93682 L .53489 .94756 L p F P
0 g
s
.754 .568 .645 r
.44732 .90847 m .4365 .9069 L p .44714 .92052 L F P
0 g
s
.754 .568 .645 r
.44714 .92052 m .44888 .91651 L .44732 .90847 L p F P
0 g
s
.648 .548 .728 r
.61217 .85185 m .63294 .84793 L p .62752 .86422 L F P
0 g
s
.651 .565 .745 r
.63294 .84793 m .63162 .84432 L .61217 .85185 L closepath p F P
0 g
s
.652 .566 .746 r
.62739 .83273 m .63162 .84432 L .61217 .85185 L p F P
0 g
s
.652 .566 .746 r
.61001 .836 m .62739 .83273 L p .61217 .85185 L F P
0 g
s
.652 .566 .746 r
.60584 .83766 m .61001 .836 L p .61217 .85185 L F P
0 g
s
.7 .483 .589 r
.53489 .94756 m .51775 .94749 L .51953 .93676 L p F P
0 g
s
.704 .487 .59 r
.50813 .93661 m .51953 .93676 L .51775 .94749 L p F P
0 g
s
.469 .658 .943 r
.37949 .55524 m .36137 .55459 L .3563 .54821 L p F P
0 g
s
.461 .664 .95 r
.36137 .55459 m .37949 .55524 L .38546 .56141 L p F P
0 g
s
.728 .656 .778 r
.49047 .8066 m .49283 .81114 L .47548 .82349 L p F P
0 g
s
.728 .656 .778 r
.48039 .80557 m .49047 .8066 L p .47548 .82349 L F P
0 g
s
.728 .656 .778 r
.46724 .81516 m .48039 .80557 L p .47548 .82349 L F P
0 g
s
.728 .656 .778 r
.47548 .82349 m .47154 .82307 L .46724 .81516 L p F P
0 g
s
0 0 .019 r
.59676 .48803 m .59515 .49032 L .59695 .4838 L p F P
0 g
s
0 0 .019 r
.59695 .4838 m .60134 .47747 L .59676 .48803 L p F P
0 g
s
.696 .847 .955 r
.64675 .56694 m .62629 .57556 L .62126 .5718 L p F P
0 g
s
.676 .841 .962 r
.60084 .5795 m .62126 .5718 L .62629 .57556 L p F P
0 g
s
.639 .511 .69 r
.62217 .88901 m .6199 .88005 L .64165 .87594 L p F P
0 g
s
.645 .531 .71 r
.63767 .8623 m .64165 .87594 L .6199 .88005 L p F P
0 g
s
.645 .531 .71 r
.62752 .86422 m .63767 .8623 L p .6199 .88005 L F P
0 g
s
.759 .637 .727 r
.43355 .86586 m .43261 .8637 L .43109 .86542 L closepath p F P
0 g
s
.047 .2 .701 r
.42885 .42708 m .42917 .41836 L .4234 .41181 L p F P
0 g
s
.01 .135 .647 r
.42917 .41836 m .42885 .42708 L .43366 .43403 L p F P
0 g
s
.704 .487 .59 r
.51775 .94749 m .50863 .94738 L .50813 .93661 L p F P
0 g
s
.717 .497 .589 r
.49786 .93618 m .50813 .93661 L .50863 .94738 L p F P
0 g
s
.959 .944 .649 r
.23442 .33638 m .2339 .34213 L .22875 .35231 L p F P
0 g
s
.442 .457 .78 r
.40251 .36342 m .40759 .3657 L p .40134 .35065 L F P
0 g
s
.442 .457 .78 r
.40134 .35065 m .39921 .3551 L .40251 .36342 L p F P
0 g
s
.858 .55 .468 r
.4801 .52998 m .49013 .53466 L .48872 .52609 L p F P
0 g
s
.858 .55 .468 r
.48872 .52609 m .47895 .52134 L .4801 .52998 L p F P
0 g
s
.831 .942 .897 r
.76167 .51192 m .75849 .51033 L .76456 .50532 L closepath p F P
0 g
s
.895 .81 .758 r
.65394 .35487 m .65767 .34933 L .65274 .34369 L p F P
0 g
s
.683 .469 .589 r
.54435 .93655 m .5594 .93603 L .55999 .94675 L p F P
0 g
s
.683 .469 .589 r
.55999 .94675 m .54231 .94736 L .54435 .93655 L p F P
0 g
s
.734 .532 .619 r
.46398 .92237 m .46055 .93345 L .47821 .93507 L p F P
0 g
s
.745 .542 .62 r
.44973 .92086 m .46398 .92237 L .46055 .93345 L p F P
0 g
s
.745 .563 .648 r
.46398 .92237 m .44973 .92086 L .44888 .91651 L p F P
0 g
s
.724 .525 .621 r
.49786 .93618 m .48054 .93526 L .47989 .92978 L p F P
0 g
s
.735 .533 .619 r
.48054 .93526 m .47989 .92978 L .47821 .93507 L closepath p F P
0 g
s
.688 .434 .533 r
.53679 .53999 m .52187 .54004 L .5227 .54887 L p F P
0 g
s
.719 .456 .527 r
.50965 .54787 m .5227 .54887 L .52187 .54004 L p F P
0 g
s
.719 .456 .527 r
.52187 .54004 m .51007 .53916 L .50965 .54787 L p F P
0 g
s
.672 .607 .773 r
.59513 .81218 m .57485 .82107 L .56948 .80934 L p F P
0 g
s
.748 .656 .759 r
.45017 .8373 m .44717 .83155 L .44219 .83595 L closepath p F P
0 g
s
.597 .359 .526 r
.5586 .54422 m .55873 .53536 L .53679 .53999 L p F P
0 g
s
.597 .359 .526 r
.53679 .53999 m .53657 .54882 L .5586 .54422 L p F P
0 g
s
.688 .434 .533 r
.5227 .54887 m .53657 .54882 L .53679 .53999 L p F P
0 g
s
.76 .639 .728 r
.43109 .86542 m .43261 .8637 L .42704 .85118 L p F P
0 g
s
0 0 .237 r
.82856 .37037 m .82889 .37846 L .82745 .37004 L p F P
0 g
s
0 0 .237 r
.82745 .37004 m .82711 .36194 L .82856 .37037 L p F P
0 g
s
.736 .659 .774 r
.47154 .82307 m .46724 .81516 L .45913 .82137 L closepath p F P
0 g
s
.711 .743 .877 r
.73868 .28487 m .71795 .29468 L .71319 .28787 L p F P
0 g
s
.116 .332 .801 r
.25848 .471 m .2504 .46562 L .25645 .47599 L p F P
0 g
s
.116 .332 .801 r
.25645 .47599 m .26061 .47889 L .25848 .471 L p F P
0 g
s
.122 .342 .808 r
.25009 .46541 m .2504 .46562 L .25645 .47599 L p F P
0 g
s
.696 .694 .844 r
.49871 .58364 m .51877 .57647 L .51836 .57586 L p F P
0 g
s
.696 .694 .844 r
.49315 .57766 m .49871 .58364 L p .51836 .57586 L F P
0 g
s
.672 .724 .888 r
.49871 .58364 m .51877 .57647 L .52423 .5832 L p F P
0 g
s
.769 .632 .709 r
.41715 .86269 m .43109 .86542 L .42156 .87799 L p F P
0 g
s
.76 .639 .728 r
.42704 .85118 m .41715 .86269 L .43109 .86542 L p F P
0 g
s
.403 .129 .38 r
.57905 .51018 m .57767 .51141 L .57895 .51082 L closepath p F P
0 g
s
.423 .164 .414 r
.57799 .51854 m .5644 .52486 L .57767 .51141 L p F P
0 g
s
.423 .164 .414 r
.57767 .51141 m .57895 .51082 L .57799 .51854 L p F P
0 g
s
.717 .497 .589 r
.50863 .94738 m .49625 .94685 L .49786 .93618 L p F P
0 g
s
.722 .501 .59 r
.48054 .93526 m .49786 .93618 L .49625 .94685 L p F P
0 g
s
.668 .457 .59 r
.5594 .93603 m .5745 .935 L .57205 .94594 L p F P
0 g
s
.668 .457 .59 r
.57205 .94594 m .55999 .94675 L .5594 .93603 L p F P
0 g
s
.652 .565 .744 r
.60584 .83766 m .61001 .836 L .60553 .83683 L closepath p F P
0 g
s
.321 .526 .899 r
.28839 .50618 m .2926 .51177 L .2906 .51117 L closepath p F P
0 g
s
.655 .583 .762 r
.61001 .836 m .60553 .83683 L .60048 .82447 L p F P
0 g
s
.426 .616 .93 r
.34826 .54124 m .33213 .53933 L .32794 .53254 L p F P
0 g
s
.415 .621 .936 r
.33213 .53933 m .34826 .54124 L .35431 .54802 L p F P
0 g
s
.64 .513 .692 r
.6232 .89304 m .62217 .88901 L .64257 .8796 L p F P
0 g
s
.639 .511 .69 r
.64165 .87594 m .64257 .8796 L .62217 .88901 L p F P
0 g
s
.206 .3 .74 r
.4234 .41181 m .4252 .40248 L .41821 .39644 L p F P
0 g
s
.17 .238 .691 r
.4252 .40248 m .4234 .41181 L .42917 .41836 L p F P
0 g
s
.672 .727 .892 r
.52423 .5832 m .54439 .5761 L .54977 .58271 L p F P
0 g
s
.69 .676 .832 r
.52423 .5832 m .54439 .5761 L .5438 .57516 L p F P
0 g
s
.69 .676 .832 r
.51877 .57647 m .52423 .5832 L p .5438 .57516 L F P
0 g
s
.98 .909 .653 r
.62342 .41706 m .62302 .41796 L .62386 .42596 L p F P
0 g
s
.982 .908 .645 r
.61864 .42836 m .61886 .43655 L .62386 .42596 L p F P
0 g
s
.982 .908 .645 r
.62386 .42596 m .62302 .41796 L .61864 .42836 L p F P
0 g
s
.441 .456 .779 r
.39694 .34936 m .40134 .35065 L .39921 .3551 L closepath p F P
0 g
s
.817 .742 .219 r
.82856 .39757 m .82795 .40013 L .8287 .39561 L closepath p F P
0 g
s
.749 .484 .53 r
.5041 .54708 m .50965 .54787 L .51007 .53916 L p F P
0 g
s
.749 .484 .53 r
.51007 .53916 m .50354 .53817 L .5041 .54708 L p F P
0 g
s
.17 0 .336 r
.58857 .50894 m .57799 .51854 L .57895 .51082 L p F P
0 g
s
.17 0 .336 r
.57895 .51082 m .59238 .49856 L .58857 .50894 L p F P
0 g
s
.701 .627 .771 r
.5437 .80774 m .54391 .80818 L p .51837 .80879 L F P
0 g
s
.701 .627 .771 r
.51837 .80879 m .51967 .80801 L .5437 .80774 L p F P
0 g
s
.704 .634 .776 r
.51837 .80879 m .51967 .80801 L .51798 .80801 L closepath p F P
0 g
s
.715 .639 .771 r
.51798 .80801 m .51837 .80879 L p .49283 .81114 L F P
0 g
s
.755 .569 .645 r
.44973 .92086 m .44888 .91651 L .44714 .92052 L closepath p F P
0 g
s
.457 .218 .462 r
.57735 .5267 m .57799 .51854 L .5644 .52486 L p F P
0 g
s
.457 .218 .462 r
.55873 .53536 m .57735 .5267 L p .5644 .52486 L F P
0 g
s
.457 .218 .462 r
.5644 .52486 m .559 .53184 L .55873 .53536 L p F P
0 g
s
.895 .81 .758 r
.65274 .34369 m .65013 .34767 L .65394 .35487 L p F P
0 g
s
.894 .81 .758 r
.64265 .35903 m .64621 .3663 L .65394 .35487 L p F P
0 g
s
.894 .81 .758 r
.65394 .35487 m .65013 .34767 L .64265 .35903 L p F P
0 g
s
.538 .721 .958 r
.41665 .5724 m .43626 .57052 L .44204 .57602 L p F P
0 g
s
.543 .715 .952 r
.43626 .57052 m .41665 .5724 L .41078 .56672 L p F P
0 g
s
.675 .817 .951 r
.61618 .56769 m .62126 .5718 L .60084 .5795 L p F P
0 g
s
.675 .817 .951 r
.60402 .57216 m .61618 .56769 L p .60084 .5795 L F P
0 g
s
.675 .817 .951 r
.60084 .5795 m .59692 .57623 L .60402 .57216 L p F P
0 g
s
.482 .683 .955 r
.38546 .56141 m .39197 .5614 L .39827 .56729 L p F P
0 g
s
.513 .696 .951 r
.40488 .56079 m .39197 .5614 L .39827 .56729 L p F P
0 g
s
.513 .696 .951 r
.39827 .56729 m .41078 .56672 L .40488 .56079 L p F P
0 g
s
.634 .49 .67 r
.62585 .90542 m .6232 .89304 L .64494 .88893 L p F P
0 g
s
.64 .513 .692 r
.64257 .8796 m .64494 .88893 L .6232 .89304 L p F P
0 g
s
.771 .614 .049 r
.22414 .39721 m .22375 .39031 L .22361 .38061 L p F P
0 g
s
0 0 .221 r
.22375 .39031 m .22414 .39721 L .22555 .40503 L p F P
0 g
s
.699 .641 .788 r
.5437 .80774 m .53849 .79768 L .51967 .80801 L closepath p F P
0 g
s
.702 .647 .792 r
.53353 .78816 m .53849 .79768 L .51967 .80801 L p F P
0 g
s
.702 .647 .792 r
.53142 .78815 m .53353 .78816 L p .51967 .80801 L F P
0 g
s
.702 .647 .792 r
.5129 .79858 m .53142 .78815 L p .51967 .80801 L F P
0 g
s
.702 .647 .792 r
.51967 .80801 m .51798 .80801 L .5129 .79858 L p F P
0 g
s
.715 .639 .771 r
.49283 .81114 m .49884 .80713 L .51798 .80801 L p F P
0 g
s
.712 .652 .788 r
.51798 .80801 m .5129 .79858 L .49884 .80713 L closepath p F P
0 g
s
.66 .76 .924 r
.54977 .58271 m .57003 .57624 L .57532 .58181 L p F P
0 g
s
.668 .706 .875 r
.54977 .58271 m .57003 .57624 L .56582 .57056 L p F P
0 g
s
.668 .706 .875 r
.54439 .5761 m .54977 .58271 L p .56582 .57056 L F P
0 g
s
.926 .973 .748 r
.80438 .45701 m .80248 .46549 L .81058 .45371 L p F P
0 g
s
.926 .973 .748 r
.81058 .45371 m .81238 .44524 L .80438 .45701 L p F P
0 g
s
.687 .616 .772 r
.56799 .80609 m .56948 .80934 L p .54391 .80818 L F P
0 g
s
.687 .616 .772 r
.54391 .80818 m .54488 .80767 L .56799 .80609 L p F P
0 g
s
.689 .622 .776 r
.54391 .80818 m .54488 .80767 L .5437 .80774 L closepath p F P
0 g
s
.391 .525 .872 r
.79761 .3119 m .79599 .30428 L .80047 .31274 L closepath p F P
0 g
s
.718 .646 .776 r
.49283 .81114 m .49884 .80713 L .49047 .8066 L closepath p F P
0 g
s
.688 .636 .792 r
.54488 .80767 m .5437 .80774 L .53849 .79768 L p F P
0 g
s
.722 .501 .59 r
.49625 .94685 m .481 .94605 L .48054 .93526 L p F P
0 g
s
.734 .51 .589 r
.47821 .93507 m .48054 .93526 L .481 .94605 L p F P
0 g
s
.483 .489 .788 r
.39694 .34936 m .40134 .35065 L p .39359 .33615 L F P
0 g
s
.483 .489 .788 r
.39359 .33615 m .39236 .33828 L .39694 .34936 L p F P
0 g
s
.754 .568 .645 r
.4365 .9069 m .43171 .91829 L .44714 .92052 L p F P
0 g
s
.765 .582 .649 r
.42164 .90449 m .4365 .9069 L .43171 .91829 L p F P
0 g
s
.764 .594 .668 r
.4365 .9069 m .42164 .90449 L .42799 .89272 L p F P
0 g
s
.769 .602 .672 r
.41368 .89014 m .42799 .89272 L .42164 .90449 L p F P
0 g
s
.767 .614 .689 r
.42799 .89272 m .41368 .89014 L .42156 .87799 L p F P
0 g
s
.659 .768 .93 r
.59568 .57513 m .57532 .58181 L .57003 .57624 L p F P
0 g
s
.527 .644 .907 r
.77499 .29418 m .7692 .29418 L .76457 .28677 L p F P
0 g
s
.686 .631 .789 r
.56799 .80609 m .5641 .79833 L .54488 .80767 L closepath p F P
0 g
s
.688 .636 .792 r
.55871 .78761 m .5641 .79833 L .54488 .80767 L p F P
0 g
s
.688 .636 .792 r
.53849 .79768 m .55871 .78761 L p .54488 .80767 L F P
0 g
s
.654 .582 .762 r
.62739 .83273 m .62624 .82989 L .61001 .836 L closepath p F P
0 g
s
.655 .583 .762 r
.62089 .8166 m .62624 .82989 L .61001 .836 L p F P
0 g
s
.655 .583 .762 r
.60048 .82447 m .62089 .8166 L p .61001 .836 L F P
0 g
s
.797 .85 .891 r
.25483 .3117 m .25599 .30786 L p .27574 .29693 L F P
0 g
s
.851 .918 .877 r
.25599 .30786 m .25483 .3117 L .25234 .31118 L closepath p F P
0 g
s
.881 .917 .846 r
.24359 .32084 m .25234 .31118 L .25483 .3117 L p F P
0 g
s
.757 .655 .749 r
.42797 .83324 m .44219 .83595 L .42837 .84967 L p F P
0 g
s
.749 .658 .76 r
.44157 .82095 m .42797 .83324 L .44219 .83595 L p F P
0 g
s
.749 .658 .76 r
.44219 .83595 m .44717 .83155 L .44157 .82095 L p F P
0 g
s
0 0 .462 r
.82633 .35391 m .82711 .36194 L .82403 .35413 L p F P
0 g
s
0 0 .462 r
.82403 .35413 m .82323 .3461 L .82633 .35391 L p F P
0 g
s
.832 .894 .473 r
.60899 .45778 m .60894 .45794 L .61207 .45327 L p F P
0 g
s
.832 .894 .473 r
.61207 .45327 m .61392 .44715 L .60899 .45778 L p F P
0 g
s
.648 .548 .728 r
.63294 .84793 m .63704 .86041 L .62752 .86422 L p F P
0 g
s
.647 .548 .729 r
.63767 .8623 m .63704 .86041 L .62752 .86422 L closepath p F P
0 g
s
.746 .654 .759 r
.45913 .82137 m .44717 .83155 L .44157 .82095 L p F P
0 g
s
.734 .51 .589 r
.481 .94605 m .47672 .94571 L .47821 .93507 L p F P
0 g
s
.739 .515 .589 r
.46055 .93345 m .47821 .93507 L .47672 .94571 L p F P
0 g
s
.745 .542 .62 r
.46055 .93345 m .45114 .93247 L .44973 .92086 L p F P
0 g
s
.755 .55 .618 r
.44714 .92052 m .44973 .92086 L .45114 .93247 L p F P
0 g
s
.665 .454 .589 r
.5745 .935 m .5835 .93434 L .58414 .94506 L p F P
0 g
s
.665 .454 .589 r
.58414 .94506 m .57205 .94594 L .5745 .935 L p F P
0 g
s
.789 .521 .532 r
.49035 .54367 m .5041 .54708 L .50354 .53817 L p F P
0 g
s
.789 .521 .532 r
.50354 .53817 m .49013 .53466 L .49035 .54367 L p F P
0 g
s
.313 .368 .759 r
.41821 .39644 m .42158 .38643 L .41305 .38102 L p F P
0 g
s
.378 .363 .716 r
.4252 .40248 m .41821 .39644 L .42158 .38643 L p F P
0 g
s
.777 .905 .93 r
.72169 .53749 m .71773 .54002 L .71315 .53713 L p F P
0 g
s
.343 .539 .901 r
.2926 .51177 m .30439 .51516 L p .28742 .50386 L F P
0 g
s
.343 .539 .901 r
.28742 .50386 m .28839 .50618 L .2926 .51177 L p F P
0 g
s
.95 .861 .718 r
.62704 .39935 m .62897 .40706 L .63497 .39617 L p F P
0 g
s
.95 .861 .718 r
.63497 .39617 m .6326 .3886 L .62704 .39935 L p F P
0 g
s
.768 .844 .909 r
.27837 .29094 m .27574 .29693 L .27229 .29482 L closepath p F P
0 g
s
.797 .85 .891 r
.25599 .30786 m .27229 .29482 L .27574 .29693 L p F P
0 g
s
.746 .654 .759 r
.44157 .82095 m .4439 .81892 L .45913 .82137 L p F P
0 g
s
.737 .661 .775 r
.46166 .80503 m .4439 .81892 L .45913 .82137 L p F P
0 g
s
.737 .661 .775 r
.45913 .82137 m .46724 .81516 L .46166 .80503 L p F P
0 g
s
.639 .457 .62 r
.60539 .92055 m .62787 .91726 L p .61749 .93027 L F P
0 g
s
.639 .457 .62 r
.61749 .93027 m .60675 .93183 L .60539 .92055 L p F P
0 g
s
.645 .48 .646 r
.62585 .90542 m .62787 .91726 L .60539 .92055 L p F P
0 g
s
.655 .469 .619 r
.60539 .92055 m .60675 .93183 L .5835 .93434 L p F P
0 g
s
.549 .559 .817 r
.37508 .30039 m .37998 .31039 L .36794 .31103 L closepath p F P
0 g
s
.544 .574 .835 r
.38454 .3203 m .37998 .31039 L .36794 .31103 L p F P
0 g
s
.544 .574 .835 r
.38304 .32271 m .38454 .3203 L p .36794 .31103 L F P
0 g
s
.762 .642 .729 r
.42704 .85118 m .42837 .84967 L .42617 .84925 L closepath p F P
0 g
s
.757 .655 .749 r
.42141 .8399 m .42797 .83324 L p .42837 .84967 L F P
0 g
s
.757 .655 .749 r
.42837 .84967 m .42617 .84925 L .42141 .8399 L p F P
0 g
s
.715 .659 .793 r
.50741 .78848 m .5129 .79858 L .49884 .80713 L p F P
0 g
s
.715 .659 .793 r
.4873 .801 m .50741 .78848 L p .49884 .80713 L F P
0 g
s
.715 .659 .793 r
.49884 .80713 m .49047 .8066 L .4873 .801 L p F P
0 g
s
.755 .55 .618 r
.45114 .93247 m .44398 .93153 L .44714 .92052 L p F P
0 g
s
.761 .555 .619 r
.43171 .91829 m .44714 .92052 L .44398 .93153 L p F P
0 g
s
.771 .621 .693 r
.40776 .87523 m .42156 .87799 L .41368 .89014 L p F P
0 g
s
.769 .632 .709 r
.42156 .87799 m .40776 .87523 L .41715 .86269 L p F P
0 g
s
.743 .879 .943 r
.69262 .54953 m .67211 .56041 L .6673 .55727 L p F P
0 g
s
.807 .873 .436 r
.60516 .46807 m .60134 .47747 L .60612 .46688 L p F P
0 g
s
.807 .873 .436 r
.60886 .45808 m .60516 .46807 L p .60612 .46688 L F P
0 g
s
.807 .873 .436 r
.60612 .46688 m .60894 .45794 L .60886 .45808 L p F P
0 g
s
.592 .62 .849 r
.35499 .30104 m .37423 .29864 L p .35055 .29096 L F P
0 g
s
.592 .62 .849 r
.35055 .29096 m .34972 .29229 L .35499 .30104 L p F P
0 g
s
.765 .643 .727 r
.41715 .86269 m .42704 .85118 L .42617 .84925 L p F P
0 g
s
.656 .583 .761 r
.62088 .81656 m .62089 .8166 L .60048 .82447 L p F P
0 g
s
.656 .583 .761 r
.60048 .82447 m .59892 .82062 L .62088 .81656 L p F P
0 g
s
.797 .929 .921 r
.72169 .53749 m .73815 .52605 L .73368 .52344 L p F P
0 g
s
.797 .929 .921 r
.73368 .52344 m .72702 .52815 L .72169 .53749 L p F P
0 g
s
.777 .905 .93 r
.71315 .53713 m .72702 .52815 L .72169 .53749 L p F P
0 g
s
0 .101 .645 r
.82203 .33814 m .82323 .3461 L .81829 .33898 L p F P
0 g
s
0 .101 .645 r
.81829 .33898 m .81704 .33104 L .82203 .33814 L p F P
0 g
s
.257 .424 .837 r
.80047 .31274 m .80812 .31692 L .80988 .32476 L p F P
0 g
s
.096 .293 .772 r
.81537 .32317 m .81704 .33104 L .80988 .32476 L p F P
0 g
s
.096 .293 .772 r
.80988 .32476 m .80812 .31692 L .81537 .32317 L p F P
0 g
s
.839 .756 .241 r
.82736 .39695 m .82884 .38744 L .8287 .39561 L p F P
0 g
s
.839 .756 .241 r
.82724 .4029 m .82736 .39695 L p .8287 .39561 L F P
0 g
s
.839 .756 .241 r
.8287 .39561 m .82795 .40013 L .82724 .4029 L p F P
0 g
s
.649 .442 .59 r
.58414 .94506 m .5835 .93434 L .60675 .93183 L p F P
0 g
s
.672 .607 .773 r
.59112 .80322 m .59513 .81218 L p .56948 .80934 L F P
0 g
s
.672 .607 .773 r
.56948 .80934 m .57994 .80464 L .59112 .80322 L p F P
0 g
s
.674 .611 .777 r
.56948 .80934 m .57994 .80464 L .56799 .80609 L closepath p F P
0 g
s
.765 .643 .727 r
.42617 .84925 m .41478 .8468 L p .41715 .86269 L F P
0 g
s
.763 .657 .745 r
.42617 .84925 m .42141 .8399 L .41478 .8468 L closepath p F P
0 g
s
.733 .656 .774 r
.48039 .80557 m .46724 .81516 L .46166 .80503 L p F P
0 g
s
.724 .662 .788 r
.49047 .8066 m .4873 .801 L .48039 .80557 L closepath p F P
0 g
s
.388 .418 .771 r
.41305 .38102 m .41803 .37033 L .40759 .3657 L p F P
0 g
s
.428 .402 .728 r
.42158 .38643 m .41305 .38102 L .41803 .37033 L p F P
0 g
s
.659 .601 .779 r
.61556 .80454 m .62088 .81656 L .59892 .82062 L p F P
0 g
s
.659 .601 .779 r
.59892 .82062 m .59513 .81218 L .61556 .80454 L p F P
0 g
s
.944 .929 .575 r
.8195 .4258 m .81856 .43409 L .82312 .42351 L p F P
0 g
s
.944 .929 .575 r
.82312 .42351 m .82402 .41521 L .8195 .4258 L p F P
0 g
s
.482 .488 .787 r
.39133 .33578 m .39359 .33615 L .39236 .33828 L closepath p F P
0 g
s
.685 .738 .891 r
.31141 .27333 m .2919 .28281 L .2983 .28848 L p F P
0 g
s
.685 .738 .891 r
.2983 .28848 m .31766 .28019 L .31141 .27333 L p F P
0 g
s
.959 .944 .649 r
.22875 .35231 m .22965 .34263 L p .23442 .33638 L F P
0 g
s
.921 .882 .46 r
.22965 .34263 m .22875 .35231 L .22555 .36177 L p F P
0 g
s
.227 .423 .846 r
.79599 .30428 m .80047 .31274 L .80812 .31692 L p F P
0 g
s
0 0 .029 r
.22362 .37999 m .22361 .38061 L .22375 .39031 L p F P
0 g
s
.628 .469 .647 r
.62585 .90542 m .64761 .90133 L p .62915 .91702 L F P
0 g
s
.628 .469 .647 r
.62915 .91702 m .62787 .91726 L .62585 .90542 L p F P
0 g
s
.634 .49 .67 r
.64494 .88893 m .64761 .90133 L .62585 .90542 L p F P
0 g
s
.754 .888 .939 r
.69446 .55076 m .69262 .54953 L .69721 .54692 L closepath p F P
0 g
s
.674 .626 .793 r
.57994 .80464 m .56799 .80609 L .5641 .79833 L p F P
0 g
s
.897 .818 .762 r
.63502 .37047 m .63828 .37783 L .64621 .3663 L p F P
0 g
s
.897 .818 .762 r
.64621 .3663 m .64265 .35903 L .63502 .37047 L p F P
0 g
s
.386 .574 .913 r
.3172 .5242 m .30784 .52232 L .30439 .51516 L p F P
0 g
s
.371 .576 .919 r
.30784 .52232 m .3172 .5242 L .32331 .53166 L p F P
0 g
s
.489 .475 .769 r
.40245 .32368 m .38568 .32277 L .39133 .33578 L p F P
0 g
s
.489 .475 .769 r
.39133 .33578 m .39359 .33615 L .40245 .32368 L p F P
0 g
s
.527 .523 .795 r
.38304 .32271 m .38568 .32277 L .39133 .33578 L p F P
0 g
s
.489 .676 .948 r
.38639 .55521 m .37949 .55524 L .38546 .56141 L p F P
0 g
s
.489 .676 .948 r
.38546 .56141 m .39197 .5614 L .38639 .55521 L p F P
0 g
s
.904 .973 .804 r
.79463 .46938 m .80438 .45701 L .80248 .46549 L p F P
0 g
s
.904 .973 .804 r
.79459 .46953 m .79463 .46938 L p .80248 .46549 L F P
0 g
s
.904 .973 .804 r
.80248 .46549 m .79852 .47037 L .79459 .46953 L p F P
0 g
s
.773 .64 .714 r
.40383 .85976 m .41715 .86269 L .40776 .87523 L p F P
0 g
s
.765 .643 .727 r
.41478 .8468 m .40383 .85976 L .41715 .86269 L p F P
0 g
s
.878 .473 .027 r
.45926 .49383 m .45441 .48725 L .45142 .4794 L p F P
0 g
s
.891 .496 .056 r
.45441 .48725 m .45926 .49383 L .46197 .50183 L p F P
0 g
s
0 .136 .672 r
.24032 .44556 m .24144 .45126 L p .23448 .43649 L F P
0 g
s
.05 .253 .749 r
.24032 .44556 m .24444 .45392 L .24144 .45126 L closepath p F P
0 g
s
.034 .249 .75 r
.24994 .4648 m .25009 .46541 L p .24144 .45126 L F P
0 g
s
.034 .249 .75 r
.24144 .45126 m .24444 .45392 L .24994 .4648 L p F P
0 g
s
.632 .67 .868 r
.33706 .27341 m .31766 .28019 L .32382 .2877 L p F P
0 g
s
.632 .67 .868 r
.32382 .2877 m .34311 .28201 L .33706 .27341 L p F P
0 g
s
.808 .778 .825 r
.68498 .30924 m .67265 .32035 L .66771 .31367 L p F P
0 g
s
.851 .784 .786 r
.67032 .32313 m .67265 .32035 L .66771 .31367 L p F P
0 g
s
.14 .344 .805 r
.24994 .4648 m .2504 .46562 L .25009 .46541 L closepath p F P
0 g
s
.764 .764 .853 r
.70571 .29315 m .69278 .30199 L .68791 .29514 L p F P
0 g
s
.813 .777 .819 r
.68498 .30924 m .69278 .30199 L .68791 .29514 L p F P
0 g
s
.813 .777 .819 r
.68791 .29514 m .6804 .30217 L .68498 .30924 L p F P
0 g
s
.808 .778 .825 r
.66771 .31367 m .6804 .30217 L .68498 .30924 L p F P
0 g
s
.596 .738 .944 r
.44204 .57602 m .45488 .57359 L .46335 .57867 L p F P
0 g
s
.608 .737 .937 r
.45488 .57359 m .44204 .57602 L .43626 .57052 L p F P
0 g
s
.739 .515 .589 r
.47672 .94571 m .45903 .94409 L .46055 .93345 L p F P
0 g
s
.744 .52 .59 r
.45114 .93247 m .46055 .93345 L .45903 .94409 L p F P
0 g
s
.921 .538 .256 r
.46439 .51 m .47117 .51586 L .46861 .50774 L p F P
0 g
s
.921 .538 .256 r
.46861 .50774 m .46197 .50183 L .46439 .51 L p F P
0 g
s
.596 .734 .941 r
.46187 .57216 m .45488 .57359 L .46335 .57867 L p F P
0 g
s
.596 .734 .941 r
.46335 .57867 m .46756 .57789 L .46187 .57216 L p F P
0 g
s
.829 .745 .225 r
.22362 .37999 m .22407 .37061 L .22555 .36177 L p F P
0 g
s
0 0 .069 r
.22407 .37061 m .22362 .37999 L .22374 .38825 L p F P
0 g
s
0 0 .029 r
.22375 .39031 m .22374 .38825 L .22362 .37999 L p F P
0 g
s
.68 .442 .554 r
.53489 .94756 m .54231 .94736 L .54348 .95743 L p F P
0 g
s
.68 .442 .554 r
.54348 .95743 m .53463 .95767 L .53489 .94756 L p F P
0 g
s
.695 .454 .554 r
.51775 .94749 m .53489 .94756 L .53463 .95767 L p F P
0 g
s
.177 .368 .815 r
.2504 .46562 m .25848 .471 L p .2483 .45732 L F P
0 g
s
.177 .368 .815 r
.2483 .45732 m .24994 .4648 L .2504 .46562 L p F P
0 g
s
.849 .784 .788 r
.65527 .32851 m .65983 .33553 L .67032 .32313 L p F P
0 g
s
.849 .784 .788 r
.67032 .32313 m .66569 .31612 L .65527 .32851 L p F P
0 g
s
.851 .784 .786 r
.66771 .31367 m .66569 .31612 L .67032 .32313 L p F P
0 g
s
.695 .454 .554 r
.53463 .95767 m .51867 .9576 L .51775 .94749 L p F P
0 g
s
.699 .457 .554 r
.50863 .94738 m .51775 .94749 L .51867 .9576 L p F P
0 g
s
.442 .457 .78 r
.40759 .3657 m .41413 .35432 L .40134 .35065 L p F P
0 g
s
.467 .436 .741 r
.41803 .37033 m .40759 .3657 L .41413 .35432 L p F P
0 g
s
.733 .656 .774 r
.46166 .80503 m .46369 .80351 L .48039 .80557 L p F P
0 g
s
.725 .665 .79 r
.48175 .79132 m .46369 .80351 L .48039 .80557 L p F P
0 g
s
.725 .665 .79 r
.48039 .80557 m .4873 .801 L .48175 .79132 L p F P
0 g
s
.629 .52 .712 r
.64165 .87594 m .63767 .8623 L .65872 .85732 L p F P
0 g
s
.633 .54 .732 r
.65764 .85406 m .65872 .85732 L .63767 .8623 L p F P
0 g
s
.633 .54 .732 r
.63767 .8623 m .63704 .86041 L .65764 .85406 L p F P
0 g
s
.976 .919 .612 r
.61437 .43875 m .61392 .44715 L .61886 .43655 L p F P
0 g
s
.976 .919 .612 r
.61886 .43655 m .61864 .42836 L .61437 .43875 L p F P
0 g
s
.633 .539 .73 r
.654 .84292 m .65764 .85406 L .63704 .86041 L p F P
0 g
s
.633 .539 .73 r
.63704 .86041 m .63294 .84793 L .654 .84292 L p F P
0 g
s
0 .001 .569 r
.23336 .42893 m .23448 .43649 L p .22917 .42109 L F P
0 g
s
0 .142 .674 r
.23336 .42893 m .23854 .44138 L .23448 .43649 L closepath p F P
0 g
s
0 .136 .672 r
.23448 .43649 m .23854 .44138 L .24032 .44556 L p F P
0 g
s
.699 .457 .554 r
.51867 .9576 m .50828 .95747 L .50863 .94738 L p F P
0 g
s
.713 .469 .554 r
.49625 .94685 m .50863 .94738 L .50828 .95747 L p F P
0 g
s
.677 .439 .554 r
.54231 .94736 m .55999 .94675 L .55983 .95687 L p F P
0 g
s
.677 .439 .554 r
.55983 .95687 m .54348 .95743 L .54231 .94736 L p F P
0 g
s
.041 .254 .752 r
.24444 .45392 m .2483 .45732 L .24994 .4648 L closepath p F P
0 g
s
.901 .974 .808 r
.79852 .47037 m .79229 .47796 L .79459 .46953 L closepath p F P
0 g
s
.637 .558 .749 r
.65221 .83802 m .654 .84292 L .63294 .84793 L p F P
0 g
s
.637 .558 .749 r
.63294 .84793 m .63162 .84432 L .65221 .83802 L p F P
0 g
s
.239 .422 .841 r
.27053 .48402 m .26061 .47889 L .25848 .471 L p F P
0 g
s
.192 .41 .845 r
.27298 .49173 m .27053 .48402 L .26061 .47889 L p F P
0 g
s
.524 .534 .808 r
.38454 .3203 m .38568 .32277 L .38304 .32271 L closepath p F P
0 g
s
.381 .58 .919 r
.32429 .5255 m .3172 .5242 L .32331 .53166 L p F P
0 g
s
.381 .58 .919 r
.32331 .53166 m .32794 .53254 L .32429 .5255 L p F P
0 g
s
.804 .922 .915 r
.74563 .52061 m .73815 .52605 L .73368 .52344 L p F P
0 g
s
.705 .647 .789 r
.53142 .78815 m .5129 .79858 L .50741 .78848 L p F P
0 g
s
0 0 .406 r
.44467 .46459 m .44279 .45683 L .43879 .44945 L p F P
0 g
s
.909 .59 .43 r
.47222 .52454 m .4801 .52998 L .47895 .52134 L p F P
0 g
s
.909 .59 .43 r
.4712 .51598 m .47222 .52454 L p .47895 .52134 L F P
0 g
s
.909 .59 .43 r
.47895 .52134 m .47125 .5159 L .4712 .51598 L p F P
0 g
s
.527 .644 .907 r
.76457 .28677 m .77186 .28665 L .77499 .29418 L p F P
0 g
s
.478 .603 .898 r
.78654 .2877 m .77186 .28665 L .77499 .29418 L p F P
0 g
s
.478 .603 .898 r
.77499 .29418 m .79117 .29569 L .78654 .2877 L p F P
0 g
s
.765 .582 .649 r
.41748 .91444 m .42164 .90449 L p .43171 .91829 L F P
0 g
s
.771 .585 .648 r
.41748 .91444 m .42164 .90449 L .41509 .90332 L closepath p F P
0 g
s
.769 .602 .672 r
.41216 .89304 m .41368 .89014 L p .42164 .90449 L F P
0 g
s
.769 .602 .672 r
.42164 .90449 m .41509 .90332 L .41216 .89304 L p F P
0 g
s
.637 .557 .747 r
.64846 .82769 m .65221 .83802 L .63162 .84432 L p F P
0 g
s
.637 .557 .747 r
.63162 .84432 m .62739 .83273 L .64846 .82769 L p F P
0 g
s
.477 .264 .511 r
.57726 .53555 m .57735 .5267 L .55873 .53536 L p F P
0 g
s
.477 .264 .511 r
.55873 .53536 m .5586 .54422 L .57726 .53555 L p F P
0 g
s
.835 .755 .24 r
.82795 .40013 m .82712 .40513 L .82724 .4029 L closepath p F P
0 g
s
.69 .638 .792 r
.55836 .78693 m .55871 .78761 L .53849 .79768 L p F P
0 g
s
.69 .638 .792 r
.53849 .79768 m .53353 .78816 L .55836 .78693 L p F P
0 g
s
.775 .606 .67 r
.41216 .89304 m .41368 .89014 L .41118 .88965 L closepath p F P
0 g
s
.771 .621 .693 r
.40667 .87697 m .40776 .87523 L p .41368 .89014 L F P
0 g
s
.771 .621 .693 r
.41368 .89014 m .41118 .88965 L .40667 .87697 L p F P
0 g
s
.623 .499 .691 r
.64257 .8796 m .64165 .87594 L .66271 .871 L p F P
0 g
s
.629 .52 .712 r
.65872 .85732 m .66271 .871 L .64165 .87594 L p F P
0 g
s
.858 .953 .873 r
.77939 .49263 m .77868 .49232 L .77992 .49115 L closepath p F P
0 g
s
.483 .489 .788 r
.40134 .35065 m .40925 .33865 L .39359 .33615 L p F P
0 g
s
.499 .467 .753 r
.41413 .35432 m .40134 .35065 L .40925 .33865 L p F P
0 g
s
.435 .63 .936 r
.35182 .54156 m .34826 .54124 L .35431 .54802 L p F P
0 g
s
.435 .63 .936 r
.35431 .54802 m .3563 .54821 L .35182 .54156 L p F P
0 g
s
.713 .469 .554 r
.50828 .95747 m .49699 .957 L .49625 .94685 L p F P
0 g
s
.718 .473 .554 r
.481 .94605 m .49625 .94685 L .49699 .957 L p F P
0 g
s
.918 .954 .798 r
.23442 .33638 m .23519 .33228 L .24359 .32084 L p F P
0 g
s
.937 .959 .658 r
.23519 .33228 m .23442 .33638 L .23118 .33946 L closepath p F P
0 g
s
.959 .944 .649 r
.22965 .34263 m .23118 .33946 L .23442 .33638 L p F P
0 g
s
.659 .601 .778 r
.61321 .7992 m .61556 .80454 L .59513 .81218 L p F P
0 g
s
.659 .601 .778 r
.59513 .81218 m .59112 .80322 L .61321 .7992 L p F P
0 g
s
.762 .659 .748 r
.42141 .8399 m .42797 .83324 L .41671 .83081 L closepath p F P
0 g
s
.757 .67 .766 r
.4401 .81823 m .44157 .82095 L .42797 .83324 L p F P
0 g
s
.757 .67 .766 r
.4299 .8161 m .4401 .81823 L p .42797 .83324 L F P
0 g
s
.757 .67 .766 r
.41575 .82912 m .4299 .8161 L p .42797 .83324 L F P
0 g
s
.757 .67 .766 r
.42797 .83324 m .41671 .83081 L .41575 .82912 L p F P
0 g
s
.719 .658 .789 r
.50741 .78848 m .4873 .801 L .48175 .79132 L p F P
0 g
s
.851 .922 .877 r
.25234 .31118 m .2456 .31111 L p .25946 .29697 L F P
0 g
s
.851 .922 .877 r
.25946 .29697 m .25599 .30786 L .25234 .31118 L p F P
0 g
s
.892 .938 .838 r
.25234 .31118 m .24359 .32084 L .2456 .31111 L closepath p F P
0 g
s
.821 .889 .892 r
.27229 .29482 m .25599 .30786 L .25946 .29697 L p F P
0 g
s
.66 .426 .553 r
.55999 .94675 m .57205 .94594 L .57356 .95596 L p F P
0 g
s
.66 .426 .553 r
.57356 .95596 m .55983 .95687 L .55999 .94675 L p F P
0 g
s
.749 .661 .763 r
.44157 .82095 m .4439 .81892 L .4401 .81823 L closepath p F P
0 g
s
.744 .672 .781 r
.46056 .80306 m .46166 .80503 L .4439 .81892 L p F P
0 g
s
.744 .672 .781 r
.44866 .80096 m .46056 .80306 L p .4439 .81892 L F P
0 g
s
.744 .672 .781 r
.43592 .81113 m .44866 .80096 L p .4439 .81892 L F P
0 g
s
.744 .672 .781 r
.4439 .81892 m .4401 .81823 L .43592 .81113 L p F P
0 g
s
.525 .494 .765 r
.40925 .33865 m .39359 .33615 L .40245 .32368 L p F P
0 g
s
.715 .851 .947 r
.66274 .55951 m .64675 .56694 L .64179 .56316 L p F P
0 g
s
.696 .847 .955 r
.62126 .5718 m .64179 .56316 L .64675 .56694 L p F P
0 g
s
.761 .555 .619 r
.44398 .93153 m .42855 .9293 L .43171 .91829 L p F P
0 g
s
.766 .561 .621 r
.41782 .91605 m .43171 .91829 L .42855 .9293 L p F P
0 g
s
.765 .582 .649 r
.43171 .91829 m .41782 .91605 L .41748 .91444 L p F P
0 g
s
.744 .52 .59 r
.45903 .94409 m .45159 .94332 L .45114 .93247 L p F P
0 g
s
.755 .528 .589 r
.44398 .93153 m .45114 .93247 L .45159 .94332 L p F P
0 g
s
.955 .899 .729 r
.62145 .41015 m .62704 .39935 L .62897 .40706 L p F P
0 g
s
.955 .899 .729 r
.62271 .41689 m .62145 .41015 L p .62897 .40706 L F P
0 g
s
.955 .899 .729 r
.62897 .40706 m .62342 .41706 L .62271 .41689 L p F P
0 g
s
.673 .622 .79 r
.59112 .80322 m .58978 .80048 L .57994 .80464 L closepath p F P
0 g
s
.674 .626 .793 r
.58443 .78957 m .58978 .80048 L .57994 .80464 L p F P
0 g
s
.674 .626 .793 r
.5641 .79833 m .58443 .78957 L p .57994 .80464 L F P
0 g
s
.828 .943 .9 r
.74563 .52061 m .75849 .51033 L .75414 .50799 L p F P
0 g
s
.828 .943 .9 r
.75414 .50799 m .74969 .51162 L .74563 .52061 L p F P
0 g
s
.804 .922 .915 r
.73368 .52344 m .74969 .51162 L .74563 .52061 L p F P
0 g
s
.912 .862 .777 r
.63848 .37858 m .638 .37823 L .63828 .37783 L closepath p F P
0 g
s
.624 .501 .693 r
.64494 .88893 m .64257 .8796 L .66318 .87287 L p F P
0 g
s
.623 .499 .691 r
.66271 .871 m .66318 .87287 L .64257 .8796 L p F P
0 g
s
.879 .955 .851 r
.78245 .48255 m .77992 .49115 L .79229 .47796 L p F P
0 g
s
.879 .955 .851 r
.79452 .46949 m .78245 .48255 L p .79229 .47796 L F P
0 g
s
.879 .955 .851 r
.79229 .47796 m .79459 .46953 L .79452 .46949 L p F P
0 g
s
.765 .66 .746 r
.41478 .8468 m .42141 .8399 L .41671 .83081 L p F P
0 g
s
0 0 .44 r
.2285 .41438 m .22917 .42109 L p .22555 .40503 L F P
0 g
s
0 .008 .573 r
.2285 .41438 m .23278 .42721 L .22917 .42109 L closepath p F P
0 g
s
0 .001 .569 r
.22917 .42109 m .23278 .42721 L .23336 .42893 L p F P
0 g
s
.764 .617 .051 r
.82852 .37936 m .82884 .38744 L .82889 .37846 L p F P
0 g
s
.764 .617 .051 r
.82889 .37846 m .82856 .37037 L .82852 .37936 L p F P
0 g
s
.698 .485 .596 r
.53657 .54882 m .5227 .54887 L .51943 .55909 L p F P
0 g
s
.728 .516 .604 r
.51085 .55841 m .51943 .55909 L .5227 .54887 L p F P
0 g
s
.728 .516 .604 r
.5227 .54887 m .50965 .54787 L .51085 .55841 L p F P
0 g
s
0 0 .561 r
.43879 .44945 m .43844 .44108 L .43366 .43403 L p F P
0 g
s
0 .012 .571 r
.43844 .44108 m .43879 .44945 L .44279 .45683 L p F P
0 g
s
.851 .574 .518 r
.48027 .53901 m .49035 .54367 L .49013 .53466 L p F P
0 g
s
.851 .574 .518 r
.49013 .53466 m .4801 .52998 L .48027 .53901 L p F P
0 g
s
.632 .702 .896 r
.73868 .28487 m .75992 .27944 L .76457 .28677 L p F P
0 g
s
.635 .707 .898 r
.75992 .27944 m .73868 .28487 L .73397 .27783 L p F P
0 g
s
.711 .743 .877 r
.71319 .28787 m .73397 .27783 L .73868 .28487 L p F P
0 g
s
.618 .426 .6 r
.55921 .55207 m .5586 .54422 L .53657 .54882 L p F P
0 g
s
.618 .426 .6 r
.55655 .55488 m .55921 .55207 L p .53657 .54882 L F P
0 g
s
.618 .426 .6 r
.53657 .54882 m .53753 .55902 L .55655 .55488 L p F P
0 g
s
.698 .485 .596 r
.51943 .55909 m .53753 .55902 L .53657 .54882 L p F P
0 g
s
.777 .607 .669 r
.41118 .88965 m .40032 .88727 L p .40764 .90183 L F P
0 g
s
.777 .607 .669 r
.40764 .90183 m .41216 .89304 L .41118 .88965 L p F P
0 g
s
.778 .624 .69 r
.41118 .88965 m .40667 .87697 L .40032 .88727 L closepath p F P
0 g
s
.259 .478 .88 r
.28647 .50349 m .28742 .50386 L .28839 .50618 L closepath p F P
0 g
s
.769 .764 .848 r
.70571 .29315 m .71319 .28787 L .70839 .2809 L p F P
0 g
s
.769 .764 .848 r
.70839 .2809 m .70116 .28603 L .70571 .29315 L p F P
0 g
s
.764 .764 .853 r
.68791 .29514 m .70116 .28603 L .70571 .29315 L p F P
0 g
s
.641 .575 .765 r
.64683 .82364 m .64846 .82769 L .62739 .83273 L p F P
0 g
s
.641 .575 .765 r
.62739 .83273 m .62624 .82989 L .64683 .82364 L p F P
0 g
s
.776 .606 .668 r
.41509 .90332 m .41216 .89304 L .40764 .90183 L closepath p F P
0 g
s
.846 .787 .794 r
.64773 .33725 m .65527 .32851 L .65983 .33553 L p F P
0 g
s
.846 .787 .794 r
.65983 .33553 m .65274 .34369 L .64773 .33725 L p F P
0 g
s
.667 .725 .892 r
.46756 .57789 m .48756 .57097 L .49315 .57766 L p F P
0 g
s
.688 .72 .874 r
.46756 .57789 m .48756 .57097 L .48679 .56997 L p F P
0 g
s
.688 .72 .874 r
.46187 .57216 m .46756 .57789 L p .48679 .56997 L F P
0 g
s
.777 .625 .691 r
.40667 .87697 m .40776 .87523 L .40589 .87482 L closepath p F P
0 g
s
.773 .64 .714 r
.40108 .86355 m .40383 .85976 L p .40776 .87523 L F P
0 g
s
.773 .64 .714 r
.40776 .87523 m .40589 .87482 L .40108 .86355 L p F P
0 g
s
.297 .482 .872 r
.28034 .49459 m .27298 .49173 L .27053 .48402 L p F P
0 g
s
.274 .477 .875 r
.27298 .49173 m .28034 .49459 L .28647 .50349 L p F P
0 g
s
.774 .657 .734 r
.4019 .84371 m .41478 .8468 L .40383 .85976 L p F P
0 g
s
.765 .66 .746 r
.41451 .83029 m .4019 .84371 L .41478 .8468 L p F P
0 g
s
.765 .66 .746 r
.41671 .83081 m .41451 .83029 L p .41478 .8468 L F P
0 g
s
0 0 0 r
.60164 .47831 m .59676 .48803 L .60134 .47747 L p F P
0 g
s
0 0 0 r
.60134 .47747 m .60516 .46807 L .60164 .47831 L p F P
0 g
s
.676 .625 .79 r
.58443 .78957 m .5641 .79833 L .55871 .78761 L p F P
0 g
s
.751 .675 .777 r
.4401 .81823 m .43592 .81113 L .4299 .8161 L closepath p F P
0 g
s
.897 .829 .771 r
.633 .37348 m .63502 .37047 L .63828 .37783 L p F P
0 g
s
.897 .829 .771 r
.63828 .37783 m .638 .37823 L .633 .37348 L p F P
0 g
s
.718 .473 .554 r
.49699 .957 m .48055 .95615 L .481 .94605 L p F P
0 g
s
.731 .484 .554 r
.47672 .94571 m .481 .94605 L .48055 .95615 L p F P
0 g
s
.632 .429 .59 r
.60675 .93183 m .61749 .93027 L .61304 .94176 L p F P
0 g
s
.632 .429 .59 r
.61304 .94176 m .60746 .94256 L .60675 .93183 L p F P
0 g
s
.649 .442 .59 r
.60675 .93183 m .60746 .94256 L .58414 .94506 L p F P
0 g
s
.641 .572 .762 r
.64683 .82364 m .62624 .82989 L .62089 .8166 L p F P
0 g
s
.545 .545 .805 r
.38568 .32277 m .40245 .32368 L p .39232 .30997 L F P
0 g
s
.545 .545 .805 r
.39232 .30997 m .38454 .3203 L .38568 .32277 L p F P
0 g
s
.832 .936 .896 r
.76456 .50532 m .75849 .51033 L .75414 .50799 L p F P
0 g
s
.933 .823 .713 r
.6326 .3886 m .638 .37823 L .633 .37348 L p F P
0 g
s
.476 .652 .936 r
.37349 .54877 m .3563 .54821 L .35182 .54156 L p F P
0 g
s
.469 .658 .943 r
.3563 .54821 m .37349 .54877 L .37949 .55524 L p F P
0 g
s
.779 .626 .69 r
.40032 .88727 m .40667 .87697 L .40589 .87482 L p F P
0 g
s
.925 .965 .775 r
.2456 .31111 m .24359 .32084 L .23519 .33228 L p F P
0 g
s
.658 .424 .554 r
.57205 .94594 m .58414 .94506 L .58406 .9552 L p F P
0 g
s
.658 .424 .554 r
.58406 .9552 m .57356 .95596 L .57205 .94594 L p F P
0 g
s
.773 .587 .647 r
.41509 .90332 m .40764 .90183 L p .41689 .91588 L F P
0 g
s
.773 .587 .647 r
.41689 .91588 m .41748 .91444 L .41509 .90332 L p F P
0 g
s
.779 .626 .69 r
.40589 .87482 m .39487 .8722 L p .40032 .88727 L F P
0 g
s
.779 .642 .71 r
.40589 .87482 m .40108 .86355 L .39487 .8722 L closepath p F P
0 g
s
.591 .619 .848 r
.34909 .29123 m .35055 .29096 L .34972 .29229 L closepath p F P
0 g
s
.858 .946 .873 r
.77446 .49022 m .78245 .48255 L .77992 .49115 L p F P
0 g
s
.858 .946 .873 r
.77992 .49115 m .77868 .49232 L .77446 .49022 L p F P
0 g
s
.792 .88 .911 r
.27229 .29482 m .27837 .29094 L .28289 .27958 L p F P
0 g
s
.792 .88 .911 r
.28289 .27958 m .26553 .29176 L .27229 .29482 L p F P
0 g
s
.821 .889 .892 r
.25946 .29697 m .26553 .29176 L .27229 .29482 L p F P
0 g
s
.857 .955 .874 r
.76456 .50532 m .77868 .49232 L .77446 .49022 L p F P
0 g
s
.857 .955 .874 r
.77446 .49022 m .76771 .49655 L .76456 .50532 L p F P
0 g
s
.832 .936 .896 r
.75414 .50799 m .76771 .49655 L .76456 .50532 L p F P
0 g
s
.696 .694 .844 r
.51836 .57586 m .49929 .57482 L .49315 .57766 L p F P
0 g
s
.706 .736 .875 r
.49929 .57482 m .49315 .57766 L .48756 .57097 L p F P
0 g
s
.618 .479 .671 r
.64761 .90133 m .64494 .88893 L .66603 .88403 L p F P
0 g
s
.624 .501 .693 r
.66318 .87287 m .66603 .88403 L .64494 .88893 L p F P
0 g
s
.736 .663 .779 r
.46166 .80503 m .46369 .80351 L .46056 .80306 L closepath p F P
0 g
s
.755 .528 .589 r
.45159 .94332 m .44254 .94215 L .44398 .93153 L p F P
0 g
s
.76 .533 .589 r
.42855 .9293 m .44398 .93153 L .44254 .94215 L p F P
0 g
s
.712 .743 .876 r
.73397 .27783 m .71319 .28787 L .70839 .2809 L p F P
0 g
s
.75 .535 .604 r
.50125 .55716 m .51085 .55841 L .50965 .54787 L p F P
0 g
s
.75 .535 .604 r
.50965 .54787 m .5041 .54708 L .50125 .55716 L p F P
0 g
s
.731 .484 .554 r
.48055 .95615 m .47729 .95589 L .47672 .94571 L p F P
0 g
s
.736 .488 .553 r
.45903 .94409 m .47672 .94571 L .47729 .95589 L p F P
0 g
s
.673 .803 .945 r
.59692 .57623 m .59568 .57513 L .60402 .57216 L closepath p F P
0 g
s
.621 .442 .619 r
.62796 .918 m .62915 .91702 L .62787 .91726 L closepath p F P
0 g
s
.639 .457 .62 r
.62787 .91726 m .62796 .918 L .61749 .93027 L p F P
0 g
s
.69 .676 .832 r
.5438 .57516 m .52008 .57588 L .51877 .57647 L p F P
0 g
s
.692 .688 .841 r
.52008 .57588 m .51836 .57586 L .51877 .57647 L closepath p F P
0 g
s
.943 .96 .676 r
.81348 .43692 m .8195 .4258 L .81856 .43409 L p F P
0 g
s
.943 .96 .676 r
.81278 .44267 m .81348 .43692 L p .81856 .43409 L F P
0 g
s
.943 .96 .676 r
.81856 .43409 m .81394 .44246 L .81278 .44267 L p F P
0 g
s
.754 .881 .936 r
.69721 .54692 m .69262 .54953 L .68789 .54618 L p F P
0 g
s
.743 .879 .943 r
.6673 .55727 m .68789 .54618 L .69262 .54953 L p F P
0 g
s
.731 .675 .796 r
.47822 .78526 m .48175 .79132 L .46369 .80351 L p F P
0 g
s
.731 .675 .796 r
.47227 .78443 m .47822 .78526 L p .46369 .80351 L F P
0 g
s
.731 .675 .796 r
.45604 .79563 m .47227 .78443 L p .46369 .80351 L F P
0 g
s
.731 .675 .796 r
.46369 .80351 m .46056 .80306 L .45604 .79563 L p F P
0 g
s
.01 .135 .647 r
.43366 .43403 m .43496 .42499 L .42917 .41836 L p F P
0 g
s
.212 .245 .679 r
.43844 .44108 m .43366 .43403 L .43496 .42499 L p F P
0 g
s
.544 .543 .804 r
.37998 .31039 m .39232 .30997 L .38454 .3203 L closepath p F P
0 g
s
.884 .788 .751 r
.65013 .34767 m .65274 .34369 L .64773 .33725 L p F P
0 g
s
.591 .61 .84 r
.36009 .2778 m .34311 .28201 L .34909 .29123 L p F P
0 g
s
.591 .61 .84 r
.34909 .29123 m .35055 .29096 L .36009 .2778 L p F P
0 g
s
.622 .443 .62 r
.62926 .92853 m .62796 .918 L .62915 .91702 L p F P
0 g
s
.637 .455 .619 r
.62926 .92853 m .62796 .918 L .61749 .93027 L closepath p F P
0 g
s
.622 .443 .62 r
.62915 .91702 m .64966 .91317 L p .62926 .92853 L F P
0 g
s
.628 .468 .646 r
.64966 .91317 m .64834 .90561 L .62915 .91702 L closepath p F P
0 g
s
.628 .469 .647 r
.64761 .90133 m .64834 .90561 L .62915 .91702 L p F P
0 g
s
.705 .555 .681 r
.52008 .57588 m .53895 .56452 L .53753 .55902 L p F P
0 g
s
.705 .555 .681 r
.51836 .57586 m .52008 .57588 L p .53753 .55902 L F P
0 g
s
.698 .624 .77 r
.53895 .56452 m .52008 .57588 L .5438 .57516 L closepath p F P
0 g
s
.705 .555 .681 r
.51328 .56586 m .51836 .57586 L p .53753 .55902 L F P
0 g
s
.713 .647 .782 r
.51328 .56586 m .49929 .57482 L .51836 .57586 L closepath p F P
0 g
s
.661 .617 .794 r
.61023 .79302 m .61321 .7992 L .59112 .80322 L p F P
0 g
s
.661 .617 .794 r
.59112 .80322 m .58978 .80048 L .61023 .79302 L p F P
0 g
s
.275 .476 .874 r
.28481 .49628 m .28034 .49459 L .28647 .50349 L p F P
0 g
s
.275 .476 .874 r
.28647 .50349 m .28742 .50386 L .28481 .49628 L p F P
0 g
s
.934 .881 .467 r
.82443 .40699 m .82402 .41521 L .82712 .40513 L p F P
0 g
s
.934 .881 .467 r
.82481 .40571 m .82443 .40699 L p .82712 .40513 L F P
0 g
s
.934 .881 .467 r
.82712 .40513 m .82724 .4029 L .82481 .40571 L p F P
0 g
s
.695 .836 .95 r
.64179 .56316 m .62126 .5718 L .61618 .56769 L p F P
0 g
s
.668 .706 .875 r
.56582 .57056 m .55485 .57245 L .54439 .5761 L p F P
0 g
s
.663 .666 .843 r
.55485 .57245 m .5438 .57516 L .54439 .5761 L closepath p F P
0 g
s
.739 .677 .791 r
.46056 .80306 m .45604 .79563 L .44866 .80096 L closepath p F P
0 g
s
0 0 .221 r
.22555 .40503 m .22536 .40156 L .22375 .39031 L p F P
0 g
s
0 0 .445 r
.22536 .40156 m .22735 .40971 L .22555 .40503 L closepath p F P
0 g
s
0 0 .44 r
.22555 .40503 m .22735 .40971 L .2285 .41438 L p F P
0 g
s
0 0 .068 r
.59515 .49032 m .59414 .49453 L .59676 .48803 L closepath p F P
0 g
s
.518 .689 .945 r
.40488 .56079 m .39197 .5614 L .38639 .55521 L p F P
0 g
s
.101 .287 .766 r
.24444 .45392 m .2483 .45732 L p .23991 .443 L F P
0 g
s
.101 .287 .766 r
.23991 .443 m .24032 .44556 L .24444 .45392 L p F P
0 g
s
.784 .561 .598 r
.48813 .55354 m .50125 .55716 L .5041 .54708 L p F P
0 g
s
.784 .561 .598 r
.5041 .54708 m .49035 .54367 L .48813 .55354 L p F P
0 g
s
.64 .41 .553 r
.58406 .9552 m .58414 .94506 L .60746 .94256 L p F P
0 g
s
.779 .644 .713 r
.40108 .86355 m .40383 .85976 L .39892 .85858 L closepath p F P
0 g
s
.774 .657 .734 r
.39541 .85154 m .4019 .84371 L p .40383 .85976 L F P
0 g
s
.774 .657 .734 r
.40383 .85976 m .39892 .85858 L .39541 .85154 L p F P
0 g
s
.212 .02 .388 r
.58589 .51899 m .57735 .5267 L .57799 .51854 L p F P
0 g
s
.212 .02 .388 r
.57799 .51854 m .58857 .50894 L .58589 .51899 L p F P
0 g
s
.771 .903 .933 r
.69721 .54692 m .71315 .53713 L .70852 .53406 L p F P
0 g
s
.771 .903 .933 r
.70852 .53406 m .70326 .53733 L .69721 .54692 L p F P
0 g
s
.754 .881 .936 r
.68789 .54618 m .70326 .53733 L .69721 .54692 L p F P
0 g
s
.543 .715 .952 r
.41078 .56672 m .43043 .56478 L .43626 .57052 L p F P
0 g
s
.547 .709 .946 r
.43043 .56478 m .41078 .56672 L .40488 .56079 L p F P
0 g
s
.613 .619 .833 r
.36841 .28758 m .35055 .29096 L .36009 .2778 L p F P
0 g
s
.592 .62 .849 r
.37423 .29864 m .36841 .28758 L .35055 .29096 L p F P
0 g
s
.753 .822 .906 r
.2919 .28281 m .27837 .29094 L .28289 .27958 L p F P
0 g
s
.531 .65 .911 r
.77186 .28665 m .76457 .28677 L .75992 .27944 L p F P
0 g
s
0 0 .19 r
.82779 .36235 m .82856 .37037 L .82711 .36194 L p F P
0 g
s
0 0 .19 r
.82711 .36194 m .82633 .35391 L .82779 .36235 L p F P
0 g
s
.437 .612 .923 r
.34218 .53414 m .32794 .53254 L .32429 .5255 L p F P
0 g
s
.426 .616 .93 r
.32794 .53254 m .34218 .53414 L .34826 .54124 L p F P
0 g
s
.884 .788 .751 r
.64773 .33725 m .64548 .3407 L .65013 .34767 L p F P
0 g
s
.883 .788 .751 r
.63806 .35206 m .64265 .35903 L .65013 .34767 L p F P
0 g
s
.883 .788 .751 r
.65013 .34767 m .64548 .3407 L .63806 .35206 L p F P
0 g
s
0 0 .295 r
.22374 .38825 m .22375 .39031 L .22536 .40156 L p F P
0 g
s
.656 .543 .714 r
.5438 .57516 m .55485 .57245 L p .55951 .55432 L F P
0 g
s
.656 .543 .714 r
.53895 .56452 m .5438 .57516 L p .55951 .55432 L F P
0 g
s
.956 .92 .567 r
.61022 .44915 m .60899 .45778 L .61392 .44715 L p F P
0 g
s
.956 .92 .567 r
.61392 .44715 m .61437 .43875 L .61022 .44915 L p F P
0 g
s
.921 .882 .46 r
.22555 .36177 m .22646 .3521 L .22965 .34263 L p F P
0 g
s
.786 .721 .189 r
.22646 .3521 m .22555 .36177 L .22407 .37061 L p F P
0 g
s
.662 .616 .793 r
.61023 .79302 m .58978 .80048 L .58443 .78957 L p F P
0 g
s
.359 .531 .889 r
.30147 .50774 m .28742 .50386 L .28481 .49628 L p F P
0 g
s
.343 .539 .901 r
.30439 .51516 m .30147 .50774 L .28742 .50386 L p F P
0 g
s
.773 .587 .647 r
.41782 .91605 m .41748 .91444 L .41689 .91588 L closepath p F P
0 g
s
.69 .652 .807 r
.5533 .77772 m .55836 .78693 L .53353 .78816 L p F P
0 g
s
.69 .652 .807 r
.53353 .78816 m .53305 .78731 L .5533 .77772 L p F P
0 g
s
.7 .656 .803 r
.53353 .78816 m .53305 .78731 L .53142 .78815 L closepath p F P
0 g
s
.705 .647 .789 r
.50741 .78848 m .50859 .7878 L .53142 .78815 L p F P
0 g
s
.701 .659 .805 r
.52759 .77774 m .50859 .7878 L .53142 .78815 L p F P
0 g
s
.701 .659 .805 r
.53142 .78815 m .53305 .78731 L .52759 .77774 L p F P
0 g
s
.763 .672 .763 r
.41671 .83081 m .41575 .82912 L .41451 .83029 L closepath p F P
0 g
s
.739 .617 .722 r
.49929 .57482 m .51328 .56586 L .51085 .55841 L p F P
0 g
s
.739 .617 .722 r
.48813 .57062 m .49929 .57482 L p .51085 .55841 L F P
0 g
s
.706 .736 .875 r
.48756 .57097 m .48813 .57062 L .49929 .57482 L p F P
0 g
s
.17 .238 .691 r
.42917 .41836 m .43228 .40857 L .4252 .40248 L p F P
0 g
s
.31 .311 .699 r
.43496 .42499 m .42917 .41836 L .43228 .40857 L p F P
0 g
s
.659 .768 .93 r
.57003 .57624 m .59046 .56974 L .59568 .57513 L p F P
0 g
s
.659 .706 .882 r
.56582 .57056 m .57003 .57624 L .59046 .56974 L p F P
0 g
s
.641 .572 .762 r
.64198 .81148 m .64683 .82364 L p .62089 .8166 L F P
0 g
s
.641 .572 .762 r
.62089 .8166 m .62141 .81644 L .64198 .81148 L p F P
0 g
s
.641 .574 .764 r
.62089 .8166 m .62141 .81644 L .62088 .81656 L closepath p F P
0 g
s
.644 .592 .781 r
.62141 .81644 m .62088 .81656 L .61556 .80454 L p F P
0 g
s
.781 .644 .711 r
.39487 .8722 m .40108 .86355 L .39892 .85858 L p F P
0 g
s
.971 .869 .678 r
.62342 .41706 m .62302 .41796 L .62271 .41689 L closepath p F P
0 g
s
.773 .587 .647 r
.40764 .90183 m .40318 .91314 L .41689 .91588 L p F P
0 g
s
.785 .597 .646 r
.39443 .89894 m .40764 .90183 L .40318 .91314 L p F P
0 g
s
.777 .607 .669 r
.40032 .88727 m .39443 .89894 L .40764 .90183 L p F P
0 g
s
.63 .427 .589 r
.61749 .93027 m .62926 .92853 L .63001 .93927 L p F P
0 g
s
.63 .427 .589 r
.63001 .93927 m .61304 .94176 L .61749 .93027 L p F P
0 g
s
.766 .561 .621 r
.42855 .9293 m .41937 .92784 L .41782 .91605 L p F P
0 g
s
.775 .567 .618 r
.41689 .91588 m .41782 .91605 L .41937 .92784 L p F P
0 g
s
.644 .592 .781 r
.64198 .81148 m .64149 .81036 L .62141 .81644 L closepath p F P
0 g
s
.644 .592 .781 r
.63617 .79821 m .64149 .81036 L .62141 .81644 L p F P
0 g
s
.644 .592 .781 r
.61556 .80454 m .63617 .79821 L p .62141 .81644 L F P
0 g
s
.708 .653 .794 r
.50741 .78848 m .50859 .7878 L .50701 .78775 L closepath p F P
0 g
s
.719 .658 .789 r
.50701 .78775 m .50741 .78848 L p .48175 .79132 L F P
0 g
s
.675 .773 .924 r
.60402 .57216 m .59568 .57513 L .59046 .56974 L p F P
0 g
s
.34 .502 .873 r
.79581 .30395 m .7959 .30398 L .79599 .30428 L closepath p F P
0 g
s
.227 .423 .846 r
.80595 .30916 m .7959 .30398 L .79599 .30428 L p F P
0 g
s
.227 .423 .846 r
.80812 .31692 m .80595 .30916 L p .79599 .30428 L F P
0 g
s
.692 .652 .806 r
.5533 .77772 m .53305 .78731 L .52759 .77774 L p F P
0 g
s
.775 .567 .618 r
.41937 .92784 m .41391 .92684 L .41689 .91588 L p F P
0 g
s
.781 .573 .619 r
.40318 .91314 m .41689 .91588 L .41391 .92684 L p F P
0 g
s
.973 .869 .673 r
.6166 .42073 m .61864 .42836 L .62302 .41796 L p F P
0 g
s
.973 .869 .673 r
.61845 .41595 m .6166 .42073 L p .62302 .41796 L F P
0 g
s
.973 .869 .673 r
.62302 .41796 m .62271 .41689 L .61845 .41595 L p F P
0 g
s
.704 .666 .809 r
.5221 .76823 m .52759 .77774 L .50859 .7878 L p F P
0 g
s
.704 .666 .809 r
.50189 .77917 m .5221 .76823 L p .50859 .7878 L F P
0 g
s
.704 .666 .809 r
.50859 .7878 m .50701 .78775 L .50189 .77917 L p F P
0 g
s
.719 .658 .789 r
.48175 .79132 m .4895 .78639 L .50701 .78775 L p F P
0 g
s
.715 .67 .804 r
.50701 .78775 m .50189 .77917 L .4895 .78639 L closepath p F P
0 g
s
.341 .513 .881 r
.7959 .30398 m .79581 .30395 L .79117 .29569 L p F P
0 g
s
.788 .619 .671 r
.38758 .88422 m .40032 .88727 L .39443 .89894 L p F P
0 g
s
.779 .626 .69 r
.39487 .8722 m .38758 .88422 L .40032 .88727 L p F P
0 g
s
.341 .513 .881 r
.79117 .29569 m .79316 .29636 L .7959 .30398 L p F P
0 g
s
.243 .441 .856 r
.80336 .30148 m .80595 .30916 L .7959 .30398 L p F P
0 g
s
.243 .441 .856 r
.7959 .30398 m .79316 .29636 L .80336 .30148 L p F P
0 g
s
.762 .671 .762 r
.4299 .8161 m .41575 .82912 L .41003 .81934 L p F P
0 g
s
.762 .671 .762 r
.41003 .81934 m .41678 .81301 L .4299 .8161 L p F P
0 g
s
.753 .678 .779 r
.43023 .80168 m .41678 .81301 L .4299 .8161 L p F P
0 g
s
.753 .678 .779 r
.4299 .8161 m .43592 .81113 L .43023 .80168 L p F P
0 g
s
.765 .676 .765 r
.41451 .83029 m .41575 .82912 L .41003 .81934 L p F P
0 g
s
.773 .673 .753 r
.40201 .82704 m .41451 .83029 L .4019 .84371 L p F P
0 g
s
.765 .676 .765 r
.41003 .81934 m .40201 .82704 L .41451 .83029 L p F P
0 g
s
.736 .488 .553 r
.47729 .95589 m .45956 .95427 L .45903 .94409 L p F P
0 g
s
.741 .491 .553 r
.45159 .94332 m .45903 .94409 L .45956 .95427 L p F P
0 g
s
.925 .965 .775 r
.23519 .33228 m .23749 .32193 L p .2456 .31111 L F P
0 g
s
.925 .959 .642 r
.23749 .32193 m .23519 .33228 L .23118 .33946 L p F P
0 g
s
.61 .455 .646 r
.64834 .90561 m .64761 .90133 L .66873 .89646 L p F P
0 g
s
.618 .479 .671 r
.66603 .88403 m .66873 .89646 L .64761 .90133 L p F P
0 g
s
.941 .961 .678 r
.81394 .44246 m .81238 .44524 L .81278 .44267 L closepath p F P
0 g
s
.781 .644 .711 r
.39892 .85858 m .39128 .8566 L p .39487 .8722 L F P
0 g
s
.779 .659 .73 r
.39892 .85858 m .39541 .85154 L .39128 .8566 L closepath p F P
0 g
s
.749 .674 .778 r
.44866 .80096 m .43592 .81113 L .43023 .80168 L p F P
0 g
s
.722 .666 .795 r
.48175 .79132 m .4895 .78639 L .47822 .78526 L closepath p F P
0 g
s
.567 .568 .814 r
.37998 .31039 m .39232 .30997 L p .37674 .29837 L F P
0 g
s
.567 .568 .814 r
.37674 .29837 m .37508 .30039 L .37998 .31039 L p F P
0 g
s
0 0 .434 r
.82514 .34596 m .82633 .35391 L .82323 .3461 L p F P
0 g
s
0 0 .434 r
.82323 .3461 m .82203 .33814 L .82514 .34596 L p F P
0 g
s
.724 .873 .951 r
.6673 .55727 m .66274 .55951 L .66587 .55628 L closepath p F P
0 g
s
.715 .851 .947 r
.66242 .55357 m .66587 .55628 L .66274 .55951 L p F P
0 g
s
.715 .851 .947 r
.64179 .56316 m .66242 .55357 L p .66274 .55951 L F P
0 g
s
.944 .875 .462 r
.82724 .4029 m .82481 .40571 L .82736 .39695 L closepath p F P
0 g
s
0 .144 .677 r
.23854 .44138 m .23991 .443 L .24032 .44556 L closepath p F P
0 g
s
.676 .625 .79 r
.58182 .78428 m .58443 .78957 L p .55871 .78761 L F P
0 g
s
.676 .625 .79 r
.55871 .78761 m .56087 .78666 L .58182 .78428 L p F P
0 g
s
.678 .63 .794 r
.55871 .78761 m .56087 .78666 L .55836 .78693 L closepath p F P
0 g
s
.933 .823 .713 r
.633 .37348 m .62902 .38137 L .6326 .3886 L p F P
0 g
s
.934 .822 .711 r
.6237 .39206 m .62704 .39935 L .6326 .3886 L p F P
0 g
s
.934 .822 .711 r
.6326 .3886 m .62902 .38137 L .6237 .39206 L p F P
0 g
s
.606 .731 .933 r
.45614 .56621 m .44714 .56822 L .45488 .57359 L p F P
0 g
s
.606 .731 .933 r
.45488 .57359 m .46187 .57216 L .45614 .56621 L p F P
0 g
s
.608 .737 .937 r
.43626 .57052 m .44714 .56822 L .45488 .57359 L p F P
0 g
s
.76 .533 .589 r
.44254 .94215 m .42708 .93993 L .42855 .9293 L p F P
0 g
s
.766 .539 .59 r
.41937 .92784 m .42855 .9293 L .42708 .93993 L p F P
0 g
s
.962 .893 .713 r
.62271 .41689 m .61845 .41595 L .62145 .41015 L closepath p F P
0 g
s
0 0 .112 r
.59846 .48847 m .60164 .47831 L .59676 .48803 L p F P
0 g
s
0 0 .112 r
.59355 .49716 m .59846 .48847 L p .59676 .48803 L F P
0 g
s
0 0 .112 r
.59676 .48803 m .59414 .49453 L .59355 .49716 L p F P
0 g
s
.677 .644 .81 r
.56087 .78666 m .55836 .78693 L .5533 .77772 L p F P
0 g
s
.93 .962 .766 r
.80569 .44865 m .80438 .45701 L .81238 .44524 L p F P
0 g
s
.93 .962 .766 r
.81007 .44207 m .80569 .44865 L p .81238 .44524 L F P
0 g
s
.93 .962 .766 r
.81238 .44524 m .81278 .44267 L .81007 .44207 L p F P
0 g
s
.67 .403 .507 r
.53463 .95767 m .54348 .95743 L .54821 .9667 L p F P
0 g
s
.67 .403 .507 r
.54821 .9667 m .53348 .96709 L .53463 .95767 L p F P
0 g
s
.687 .418 .509 r
.51867 .9576 m .53463 .95767 L .53348 .96709 L p F P
0 g
s
.705 .555 .681 r
.53753 .55902 m .51943 .55909 L .51328 .56586 L p F P
0 g
s
.729 .591 .702 r
.51943 .55909 m .51085 .55841 L .51328 .56586 L closepath p F P
0 g
s
0 0 .069 r
.22374 .38825 m .22418 .37889 L .22407 .37061 L p F P
0 g
s
0 0 .32 r
.22418 .37889 m .22374 .38825 L .22534 .39601 L p F P
0 g
s
0 0 .295 r
.22536 .40156 m .22534 .39601 L .22374 .38825 L p F P
0 g
s
.378 .363 .716 r
.4285 .39483 m .4252 .40248 L p .42158 .38643 L F P
0 g
s
.305 .314 .705 r
.4285 .39483 m .4252 .40248 L .43228 .40857 L p F P
0 g
s
.79 .639 .693 r
.38257 .86898 m .39487 .8722 L .38758 .88422 L p F P
0 g
s
.781 .644 .711 r
.39128 .8566 m .38257 .86898 L .39487 .8722 L p F P
0 g
s
.687 .418 .509 r
.53348 .96709 m .5226 .96704 L .51867 .9576 L p F P
0 g
s
.691 .419 .507 r
.50828 .95747 m .51867 .9576 L .5226 .96704 L p F P
0 g
s
.643 .515 .691 r
.55655 .55488 m .53753 .55902 L .53895 .56452 L closepath p F P
0 g
s
.779 .661 .733 r
.39541 .85154 m .4019 .84371 L .38981 .84049 L closepath p F P
0 g
s
.773 .673 .753 r
.3897 .84031 m .40201 .82704 L p .4019 .84371 L F P
0 g
s
.773 .673 .753 r
.4019 .84371 m .38981 .84049 L .3897 .84031 L p F P
0 g
s
.653 .698 .879 r
.33092 .26548 m .31141 .27333 L .31766 .28019 L p F P
0 g
s
.653 .698 .879 r
.31766 .28019 m .33706 .27341 L .33092 .26548 L p F P
0 g
s
.741 .491 .553 r
.45956 .95427 m .45101 .9534 L .45159 .94332 L p F P
0 g
s
.753 .502 .553 r
.44254 .94215 m .45159 .94332 L .45101 .9534 L p F P
0 g
s
.749 .674 .778 r
.43023 .80168 m .43464 .7981 L .44866 .80096 L p F P
0 g
s
.741 .681 .793 r
.45038 .78652 m .43464 .7981 L .44866 .80096 L p F P
0 g
s
.741 .681 .793 r
.44866 .80096 m .45604 .79563 L .45038 .78652 L p F P
0 g
s
.073 .29 .775 r
.81329 .31537 m .81537 .32317 L .80812 .31692 L p F P
0 g
s
.073 .29 .775 r
.80812 .31692 m .80595 .30916 L .81329 .31537 L p F P
0 g
s
.676 .64 .806 r
.58182 .78428 m .57906 .77911 L .56087 .78666 L closepath p F P
0 g
s
.677 .644 .81 r
.57368 .76911 m .57906 .77911 L .56087 .78666 L p F P
0 g
s
.677 .644 .81 r
.5533 .77772 m .57368 .76911 L p .56087 .78666 L F P
0 g
s
.691 .419 .507 r
.5226 .96704 m .50698 .96685 L .50828 .95747 L p F P
0 g
s
.707 .434 .509 r
.49699 .957 m .50828 .95747 L .50698 .96685 L p F P
0 g
s
.494 .669 .941 r
.38151 .54873 m .37349 .54877 L .37949 .55524 L p F P
0 g
s
.494 .669 .941 r
.37949 .55524 m .38639 .55521 L .38151 .54873 L p F P
0 g
s
0 .084 .637 r
.8204 .33026 m .82203 .33814 L .81704 .33104 L p F P
0 g
s
0 .084 .637 r
.81704 .33104 m .81537 .32317 L .8204 .33026 L p F P
0 g
s
.01 .187 .7 r
.23854 .44138 m .23991 .443 L p .23327 .42802 L F P
0 g
s
.01 .187 .7 r
.23327 .42802 m .23336 .42893 L .23854 .44138 L p F P
0 g
s
.667 .401 .509 r
.54348 .95743 m .55983 .95687 L .55882 .96634 L p F P
0 g
s
.667 .401 .509 r
.55882 .96634 m .54821 .9667 L .54348 .95743 L p F P
0 g
s
.891 .496 .056 r
.46197 .50183 m .45722 .49522 L .45441 .48725 L p F P
0 g
s
.909 .528 .098 r
.45722 .49522 m .46197 .50183 L .46439 .51 L p F P
0 g
s
.611 .456 .648 r
.64966 .91317 m .64834 .90561 L .66899 .89797 L p F P
0 g
s
.61 .455 .646 r
.66873 .89646 m .66899 .89797 L .64834 .90561 L p F P
0 g
s
.395 .577 .912 r
.32119 .5182 m .31107 .51643 L .3172 .5242 L p F P
0 g
s
.395 .577 .912 r
.3172 .5242 m .32429 .5255 L .32119 .5182 L p F P
0 g
s
.386 .574 .913 r
.30439 .51516 m .31107 .51643 L .3172 .5242 L p F P
0 g
s
.882 .546 .409 r
.47125 .5159 m .4712 .51598 L .47117 .51586 L closepath p F P
0 g
s
.781 .899 .926 r
.72702 .52815 m .71315 .53713 L .70852 .53406 L p F P
0 g
s
.931 .58 .34 r
.46541 .51483 m .46439 .51 L .47117 .51586 L p F P
0 g
s
.931 .58 .34 r
.47117 .51586 m .4712 .51598 L .46541 .51483 L p F P
0 g
s
.761 .755 .847 r
.68791 .29514 m .70116 .28603 L .69602 .27906 L p F P
0 g
s
.761 .755 .847 r
.69602 .27906 m .68299 .28798 L .68791 .29514 L p F P
0 g
s
.808 .766 .814 r
.67514 .29529 m .68299 .28798 L .68791 .29514 L p F P
0 g
s
.808 .766 .814 r
.68791 .29514 m .6804 .30217 L .67514 .29529 L p F P
0 g
s
.717 .677 .81 r
.49634 .77 m .50189 .77917 L .4895 .78639 L p F P
0 g
s
.717 .677 .81 r
.47617 .78197 m .49634 .77 L p .4895 .78639 L F P
0 g
s
.717 .677 .81 r
.4895 .78639 m .47822 .78526 L .47617 .78197 L p F P
0 g
s
.802 .763 .817 r
.66771 .31367 m .6804 .30217 L .67514 .29529 L p F P
0 g
s
.802 .763 .817 r
.67514 .29529 m .66272 .30648 L .66771 .31367 L p F P
0 g
s
.843 .77 .781 r
.66037 .30928 m .66272 .30648 L .66771 .31367 L p F P
0 g
s
.843 .77 .781 r
.66771 .31367 m .66569 .31612 L .66037 .30928 L p F P
0 g
s
.746 .877 .94 r
.6831 .54263 m .68789 .54618 L .6673 .55727 L p F P
0 g
s
.746 .877 .94 r
.6709 .54926 m .6831 .54263 L p .6673 .55727 L F P
0 g
s
.746 .877 .94 r
.6673 .55727 m .66587 .55628 L .6709 .54926 L p F P
0 g
s
.945 .624 .392 r
.47222 .52454 m .4712 .51598 L .46541 .51483 L p F P
0 g
s
.904 .62 .495 r
.47239 .53358 m .48027 .53901 L .4801 .52998 L p F P
0 g
s
.904 .62 .495 r
.4801 .52998 m .47222 .52454 L .47239 .53358 L p F P
0 g
s
.538 .357 .584 r
.57832 .5458 m .57726 .53555 L .5586 .54422 L p F P
0 g
s
.538 .357 .584 r
.56192 .55314 m .57832 .5458 L p .5586 .54422 L F P
0 g
s
.538 .357 .584 r
.5586 .54422 m .55921 .55207 L .56192 .55314 L p F P
0 g
s
0 0 .436 r
.45138 .47997 m .45074 .47481 L .45385 .48578 L p F P
0 g
s
.73 .374 0 r
.45441 .48725 m .45138 .47997 L p .4486 .47345 L F P
0 g
s
0 0 .291 r
.45722 .49522 m .45441 .48725 L .45138 .47997 L p F P
0 g
s
0 0 .436 r
.45385 .48578 m .45425 .48716 L .45138 .47997 L p F P
0 g
s
.73 .374 0 r
.45138 .47997 m .44808 .47223 L p .4486 .47345 L F P
0 g
s
.656 .543 .714 r
.55951 .55432 m .55655 .55488 L .53895 .56452 L p F P
0 g
s
.739 .617 .722 r
.51085 .55841 m .50125 .55716 L .48813 .57062 L p F P
0 g
s
.883 .791 .753 r
.6305 .3635 m .63502 .37047 L .64265 .35903 L p F P
0 g
s
.883 .791 .753 r
.64265 .35903 m .63806 .35206 L .6305 .3635 L p F P
0 g
s
.907 .788 .305 r
.82705 .38888 m .82736 .39695 L .82884 .38744 L p F P
0 g
s
.907 .788 .305 r
.82884 .38744 m .82852 .37936 L .82705 .38888 L p F P
0 g
s
.709 .77 .9 r
.30504 .26723 m .28537 .27796 L .2919 .28281 L p F P
0 g
s
.709 .77 .9 r
.2919 .28281 m .31141 .27333 L .30504 .26723 L p F P
0 g
s
.753 .822 .906 r
.28289 .27958 m .28537 .27796 L .2919 .28281 L p F P
0 g
s
.616 .736 .932 r
.44714 .56822 m .43626 .57052 L .43043 .56478 L p F P
0 g
s
.612 .413 .589 r
.63001 .93927 m .62926 .92853 L .65109 .92447 L p F P
0 g
s
.622 .443 .62 r
.64966 .91317 m .65109 .92447 L .62926 .92853 L p F P
0 g
s
.612 .51 .714 r
.66271 .871 m .65872 .85732 L .67911 .85149 L p F P
0 g
s
.618 .531 .734 r
.67848 .84958 m .67911 .85149 L .65872 .85732 L p F P
0 g
s
.618 .531 .734 r
.65872 .85732 m .65764 .85406 L .67848 .84958 L p F P
0 g
s
.707 .434 .509 r
.50698 .96685 m .50031 .96657 L .49699 .957 L p F P
0 g
s
.71 .433 .503 r
.48055 .95615 m .49699 .957 L .50031 .96657 L p F P
0 g
s
.842 .77 .782 r
.66037 .30928 m .66569 .31612 L .65527 .32851 L p F P
0 g
s
0 0 .497 r
.22534 .39601 m .22536 .40156 L .22735 .40971 L p F P
0 g
s
.671 .682 .852 r
.56469 .56883 m .55485 .57245 L .56582 .57056 L closepath p F P
0 g
s
.656 .543 .714 r
.55485 .57245 m .56469 .56883 L .55951 .55432 L p F P
0 g
s
.735 .676 .793 r
.47227 .78443 m .45604 .79563 L .45038 .78652 L p F P
0 g
s
.617 .529 .732 r
.67435 .837 m .67848 .84958 L .65764 .85406 L p F P
0 g
s
.617 .529 .732 r
.65764 .85406 m .654 .84292 L .67435 .837 L p F P
0 g
s
.649 .386 .507 r
.55983 .95687 m .57356 .95596 L .57944 .96498 L p F P
0 g
s
.649 .386 .507 r
.57944 .96498 m .55882 .96634 L .55983 .95687 L p F P
0 g
s
.622 .549 .751 r
.67303 .83337 m .67435 .837 L .654 .84292 L p F P
0 g
s
.622 .549 .751 r
.654 .84292 m .65221 .83802 L .67303 .83337 L p F P
0 g
s
.781 .662 .732 r
.39128 .8566 m .39541 .85154 L .38981 .84049 L p F P
0 g
s
.645 .592 .781 r
.63436 .79408 m .63617 .79821 L .61556 .80454 L p F P
0 g
s
.645 .592 .781 r
.61556 .80454 m .61321 .7992 L .63436 .79408 L p F P
0 g
s
.622 .395 .552 r
.60746 .94256 m .61304 .94176 L .61578 .95153 L p F P
0 g
s
.622 .395 .552 r
.61578 .95153 m .60745 .95271 L .60746 .94256 L p F P
0 g
s
.64 .41 .553 r
.60746 .94256 m .60745 .95271 L .58406 .9552 L p F P
0 g
s
.443 .624 .929 r
.34796 .53464 m .34218 .53414 L .34826 .54124 L p F P
0 g
s
.443 .624 .929 r
.34826 .54124 m .35182 .54156 L .34796 .53464 L p F P
0 g
s
.844 .612 .588 r
.47856 .54872 m .48813 .55354 L .49035 .54367 L p F P
0 g
s
.844 .612 .588 r
.49035 .54367 m .48027 .53901 L .47856 .54872 L p F P
0 g
s
.675 .773 .924 r
.61103 .56282 m .61385 .56555 L .60402 .57216 L p F P
0 g
s
.675 .773 .924 r
.59046 .56974 m .61103 .56282 L p .60402 .57216 L F P
0 g
s
.678 .802 .942 r
.61618 .56769 m .60402 .57216 L .61385 .56555 L closepath p F P
0 g
s
.399 .573 .907 r
.31107 .51643 m .30439 .51516 L .30147 .50774 L p F P
0 g
s
0 0 .422 r
.44808 .47223 m .44673 .46429 L .44279 .45683 L p F P
0 g
s
.962 .929 .602 r
.81992 .4176 m .8195 .4258 L .82402 .41521 L p F P
0 g
s
.962 .929 .602 r
.82402 .41521 m .82443 .40699 L .81992 .4176 L p F P
0 g
s
.662 .616 .793 r
.58443 .78957 m .60489 .78196 L .61023 .79302 L p F P
0 g
s
.663 .619 .795 r
.60412 .78036 m .60489 .78196 L .58443 .78957 L p F P
0 g
s
.663 .619 .795 r
.58443 .78957 m .58182 .78428 L .60412 .78036 L p F P
0 g
s
.81 .874 .437 r
.60894 .45794 m .60886 .45808 L .60899 .45778 L closepath p F P
0 g
s
.622 .548 .75 r
.66879 .82168 m .67303 .83337 L .65221 .83802 L p F P
0 g
s
.622 .548 .75 r
.65221 .83802 m .64846 .82769 L .66879 .82168 L p F P
0 g
s
.925 .959 .642 r
.23118 .33946 m .22987 .34105 L p .23749 .32193 L F P
0 g
s
.944 .942 .608 r
.23118 .33946 m .22965 .34263 L .22987 .34105 L closepath p F P
0 g
s
.606 .488 .692 r
.66318 .87287 m .66271 .871 L .68314 .86523 L p F P
0 g
s
.612 .51 .714 r
.67911 .85149 m .68314 .86523 L .66271 .871 L p F P
0 g
s
.872 .908 .5 r
.60613 .45955 m .61022 .44915 L .60899 .45778 L p F P
0 g
s
.872 .908 .5 r
.60568 .46252 m .60613 .45955 L p .60899 .45778 L F P
0 g
s
.872 .908 .5 r
.60899 .45778 m .60886 .45808 L .60568 .46252 L p F P
0 g
s
.753 .502 .553 r
.45101 .9534 m .44295 .95236 L .44254 .94215 L p F P
0 g
s
.759 .506 .552 r
.42708 .93993 m .44254 .94215 L .44295 .95236 L p F P
0 g
s
.428 .402 .728 r
.4244 .38108 m .42158 .38643 L p .41803 .37033 L F P
0 g
s
.369 .364 .723 r
.4244 .38108 m .42707 .3899 L .42158 .38643 L closepath p F P
0 g
s
.378 .363 .716 r
.42158 .38643 m .42707 .3899 L .4285 .39483 L p F P
0 g
s
.931 .904 .507 r
.60886 .45808 m .60516 .46807 L .60568 .46252 L closepath p F P
0 g
s
.531 .65 .911 r
.75992 .27944 m .76831 .2792 L .77186 .28665 L p F P
0 g
s
.483 .615 .906 r
.7819 .27996 m .76831 .2792 L .77186 .28665 L p F P
0 g
s
.483 .615 .906 r
.77186 .28665 m .78654 .2877 L .7819 .27996 L p F P
0 g
s
.791 .656 .714 r
.37939 .85322 m .39128 .8566 L .38257 .86898 L p F P
0 g
s
.781 .662 .732 r
.38959 .84043 m .37939 .85322 L .39128 .8566 L p F P
0 g
s
.781 .662 .732 r
.38981 .84049 m .38959 .84043 L p .39128 .8566 L F P
0 g
s
0 0 .497 r
.22735 .40971 m .2284 .41237 L p .22534 .39601 L F P
0 g
s
0 0 .452 r
.22735 .40971 m .2284 .41237 L .2285 .41438 L closepath p F P
0 g
s
.766 .539 .59 r
.42708 .93993 m .41982 .93879 L .41937 .92784 L p F P
0 g
s
.776 .547 .588 r
.41391 .92684 m .41937 .92784 L .41982 .93879 L p F P
0 g
s
.606 .49 .694 r
.66603 .88403 m .66318 .87287 L .68407 .86892 L p F P
0 g
s
.606 .488 .692 r
.68314 .86523 m .68407 .86892 L .66318 .87287 L p F P
0 g
s
.726 .68 .805 r
.47822 .78526 m .47617 .78197 L .47227 .78443 L closepath p F P
0 g
s
0 .013 .578 r
.23278 .42721 m .23327 .42802 L .23336 .42893 L closepath p F P
0 g
s
.778 .63 .696 r
.48679 .56997 m .48813 .57062 L .50125 .55716 L p F P
0 g
s
.778 .63 .696 r
.48196 .56277 m .48679 .56997 L p .50125 .55716 L F P
0 g
s
.778 .63 .696 r
.50125 .55716 m .48813 .55354 L .48196 .56277 L p F P
0 g
s
0 .066 .612 r
.23278 .42721 m .23327 .42802 L p .2284 .41237 L F P
0 g
s
0 .066 .612 r
.2284 .41237 m .2285 .41438 L .23278 .42721 L p F P
0 g
s
.71 .433 .503 r
.47944 .96336 m .48055 .95615 L p .50031 .96657 L F P
0 g
s
.725 .45 .511 r
.47944 .96336 m .47729 .95589 L .48055 .95615 L closepath p F P
0 g
s
.101 .287 .766 r
.2483 .45732 m .24702 .44896 L .23991 .443 L p F P
0 g
s
.183 .356 .802 r
.24702 .44896 m .2483 .45732 L .25685 .46285 L p F P
0 g
s
.177 .368 .815 r
.25848 .471 m .25685 .46285 L .2483 .45732 L p F P
0 g
s
.614 .637 .85 r
.35657 .26753 m .33706 .27341 L .34311 .28201 L p F P
0 g
s
.614 .637 .85 r
.36169 .27584 m .35657 .26753 L p .34311 .28201 L F P
0 g
s
.614 .637 .85 r
.34311 .28201 m .36009 .2778 L .36169 .27584 L p F P
0 g
s
.01 .187 .7 r
.23991 .443 m .23901 .43442 L .23327 .42802 L p F P
0 g
s
.113 .28 .756 r
.23901 .43442 m .23991 .443 L .24702 .44896 L p F P
0 g
s
.635 .707 .898 r
.73397 .27783 m .75525 .27219 L .75992 .27944 L p F P
0 g
s
.636 .711 .901 r
.75525 .27219 m .73397 .27783 L .72922 .27074 L p F P
0 g
s
.712 .743 .876 r
.70839 .2809 m .72922 .27074 L .73397 .27783 L p F P
0 g
s
0 0 .139 r
.59414 .49453 m .59238 .49856 L .59355 .49716 L closepath p F P
0 g
s
.62 .394 .552 r
.61304 .94176 m .63001 .93927 L .63009 .94944 L p F P
0 g
s
.62 .394 .552 r
.63009 .94944 m .61578 .95153 L .61304 .94176 L p F P
0 g
s
.566 .566 .813 r
.37423 .29864 m .37674 .29837 L .37508 .30039 L closepath p F P
0 g
s
.299 .48 .869 r
.28272 .48843 m .2742 .48537 L .28034 .49459 L p F P
0 g
s
.299 .48 .869 r
.28034 .49459 m .28481 .49628 L .28272 .48843 L p F P
0 g
s
.297 .482 .872 r
.27053 .48402 m .2742 .48537 L .28034 .49459 L p F P
0 g
s
.648 .609 .797 r
.63086 .78672 m .63436 .79408 L .61321 .7992 L p F P
0 g
s
.648 .609 .797 r
.61321 .7992 m .61023 .79302 L .63086 .78672 L p F P
0 g
s
.627 .567 .768 r
.66764 .81882 m .66879 .82168 L .64846 .82769 L p F P
0 g
s
.627 .567 .768 r
.64846 .82769 m .64683 .82364 L .66764 .81882 L p F P
0 g
s
.647 .385 .509 r
.57356 .95596 m .58406 .9552 L .58319 .96471 L p F P
0 g
s
.647 .385 .509 r
.58319 .96471 m .57944 .96498 L .57356 .95596 L p F P
0 g
s
.785 .597 .646 r
.40318 .91314 m .38998 .91026 L .39443 .89894 L p F P
0 g
s
.791 .605 .65 r
.38171 .89588 m .39443 .89894 L .38998 .91026 L p F P
0 g
s
.788 .619 .671 r
.39443 .89894 m .38171 .89588 L .38758 .88422 L p F P
0 g
s
.767 .758 .845 r
.70839 .2809 m .70116 .28603 L .69602 .27906 L p F P
0 g
s
.602 .429 .62 r
.65109 .92447 m .64966 .91317 L .67081 .90833 L p F P
0 g
s
.611 .456 .648 r
.66899 .89797 m .67081 .90833 L .64966 .91317 L p F P
0 g
s
.781 .573 .619 r
.41391 .92684 m .40021 .92412 L .40318 .91314 L p F P
0 g
s
.787 .58 .62 r
.38998 .91026 m .40318 .91314 L .40021 .92412 L p F P
0 g
s
.915 .955 .802 r
.79608 .46101 m .79463 .46938 L .80438 .45701 L p F P
0 g
s
.915 .955 .802 r
.80438 .45701 m .80569 .44865 L .79608 .46101 L p F P
0 g
s
.73 .452 .506 r
.47729 .95589 m .47944 .96336 L .47907 .96547 L p F P
0 g
s
.73 .452 .506 r
.45956 .95427 m .47729 .95589 L p .47907 .96547 L F P
0 g
s
.937 .958 .755 r
.81278 .44267 m .81007 .44207 L .81348 .43692 L closepath p F P
0 g
s
.799 .914 .918 r
.73368 .52344 m .72702 .52815 L .73032 .52136 L closepath p F P
0 g
s
.781 .899 .926 r
.72915 .5205 m .73032 .52136 L .72702 .52815 L p F P
0 g
s
.781 .899 .926 r
.70852 .53406 m .72915 .5205 L p .72702 .52815 L F P
0 g
s
.985 .871 .639 r
.61275 .43099 m .61437 .43875 L .61864 .42836 L p F P
0 g
s
.985 .871 .639 r
.61864 .42836 m .6166 .42073 L .61275 .43099 L p F P
0 g
s
0 .012 .571 r
.44279 .45683 m .44321 .44819 L .43844 .44108 L p F P
0 g
s
.046 .132 .631 r
.44673 .46429 m .44279 .45683 L .44321 .44819 L p F P
0 g
s
.842 .77 .782 r
.65527 .32851 m .64979 .32176 L .66037 .30928 L p F P
0 g
s
.835 .766 .785 r
.64773 .33725 m .65527 .32851 L .64979 .32176 L p F P
0 g
s
.688 .72 .874 r
.48679 .56997 m .47162 .56812 L .46187 .57216 L p F P
0 g
s
.693 .758 .902 r
.47162 .56812 m .46187 .57216 L .45614 .56621 L p F P
0 g
s
.268 .431 .839 r
.26806 .47576 m .25848 .471 L .25685 .46285 L p F P
0 g
s
.239 .422 .841 r
.26885 .47708 m .27053 .48402 L p .25848 .471 L F P
0 g
s
.239 .422 .841 r
.25848 .471 m .26806 .47576 L .26885 .47708 L p F P
0 g
s
.888 .866 .421 r
.22987 .34105 m .22965 .34263 L .22646 .3521 L p F P
0 g
s
.566 .557 .804 r
.38793 .28412 m .36841 .28758 L .37423 .29864 L p F P
0 g
s
.566 .557 .804 r
.38852 .2854 m .38793 .28412 L p .37423 .29864 L F P
0 g
s
.566 .557 .804 r
.37423 .29864 m .37674 .29837 L .38852 .2854 L p F P
0 g
s
.742 .73 .841 r
.48813 .57062 m .48679 .56997 L .48756 .57097 L closepath p F P
0 g
s
.692 .652 .806 r
.52759 .77774 m .54787 .76793 L .5533 .77772 L p F P
0 g
s
.694 .655 .807 r
.54787 .76793 m .52759 .77774 L .5221 .76823 L p F P
0 g
s
.708 .666 .807 r
.5221 .76823 m .50189 .77917 L .49634 .77 L p F P
0 g
s
.767 .678 .765 r
.41678 .81301 m .41003 .81934 L .40428 .80973 L p F P
0 g
s
.767 .678 .765 r
.40428 .80973 m .40431 .8097 L .41678 .81301 L p F P
0 g
s
.757 .683 .78 r
.42156 .79494 m .40431 .8097 L .41678 .81301 L p F P
0 g
s
.757 .683 .78 r
.42692 .79632 m .42156 .79494 L p .41678 .81301 L F P
0 g
s
.757 .683 .78 r
.41678 .81301 m .43023 .80168 L .42692 .79632 L p F P
0 g
s
0 .066 .612 r
.23327 .42802 m .23279 .4192 L .2284 .41237 L p F P
0 g
s
.032 .189 .695 r
.23279 .4192 m .23327 .42802 L .23901 .43442 L p F P
0 g
s
.659 .706 .882 r
.58517 .56303 m .57459 .56613 L .56582 .57056 L p F P
0 g
s
.659 .706 .882 r
.59046 .56974 m .58517 .56303 L p .56582 .57056 L F P
0 g
s
.641 .67 .862 r
.56469 .56883 m .57459 .56613 L .56582 .57056 L closepath p F P
0 g
s
.735 .676 .793 r
.45038 .78652 m .45693 .78191 L .47227 .78443 L p F P
0 g
s
.728 .684 .808 r
.47054 .77319 m .45693 .78191 L .47227 .78443 L p F P
0 g
s
.728 .684 .808 r
.47227 .78443 m .47617 .78197 L .47054 .77319 L p F P
0 g
s
.769 .681 .766 r
.40201 .82704 m .41003 .81934 L .40428 .80973 L p F P
0 g
s
.626 .566 .767 r
.66229 .8054 m .66764 .81882 L .64683 .82364 L p F P
0 g
s
.626 .566 .767 r
.66177 .80553 m .66229 .8054 L p .64683 .82364 L F P
0 g
s
.626 .566 .767 r
.64683 .82364 m .64198 .81148 L .66177 .80553 L p F P
0 g
s
.733 .855 .938 r
.66587 .55628 m .66242 .55357 L .6709 .54926 L closepath p F P
0 g
s
.794 .627 .674 r
.37532 .881 m .38758 .88422 L .38171 .89588 L p F P
0 g
s
.79 .639 .693 r
.38758 .88422 m .37532 .881 L .38257 .86898 L p F P
0 g
s
.94 .831 .71 r
.61839 .40278 m .62145 .41015 L .62704 .39935 L p F P
0 g
s
.94 .831 .71 r
.62704 .39935 m .6237 .39206 L .61839 .40278 L p F P
0 g
s
.664 .635 .81 r
.59956 .77168 m .60412 .78036 L .58182 .78428 L p F P
0 g
s
.664 .635 .81 r
.58182 .78428 m .57906 .77911 L .59956 .77168 L p F P
0 g
s
.779 .675 .749 r
.40201 .82704 m .3897 .84031 L .38392 .8304 L p F P
0 g
s
.779 .675 .749 r
.38392 .8304 m .3901 .8236 L .40201 .82704 L p F P
0 g
s
.769 .681 .766 r
.40428 .80973 m .3901 .8236 L .40201 .82704 L p F P
0 g
s
.776 .547 .588 r
.41982 .93879 m .4125 .93746 L .41391 .92684 L p F P
0 g
s
.782 .552 .588 r
.40021 .92412 m .41391 .92684 L .4125 .93746 L p F P
0 g
s
.716 .842 .942 r
.66242 .55357 m .64179 .56316 L .63678 .55911 L p F P
0 g
s
.695 .836 .95 r
.61618 .56769 m .63678 .55911 L .64179 .56316 L p F P
0 g
s
.6 .468 .672 r
.66873 .89646 m .66603 .88403 L .6865 .87831 L p F P
0 g
s
.606 .49 .694 r
.68407 .86892 m .6865 .87831 L .66603 .88403 L p F P
0 g
s
.786 .721 .189 r
.22407 .37061 m .22499 .36095 L .22646 .3521 L p F P
0 g
s
0 0 .105 r
.22499 .36095 m .22407 .37061 L .22418 .37889 L p F P
0 g
s
.712 .743 .876 r
.72444 .26359 m .70354 .27375 L .70839 .2809 L p F P
0 g
s
.712 .743 .876 r
.70839 .2809 m .72922 .27074 L .72444 .26359 L p F P
0 g
s
.767 .758 .845 r
.69602 .27906 m .70354 .27375 L .70839 .2809 L p F P
0 g
s
.808 .915 .911 r
.74969 .51162 m .73368 .52344 L .73032 .52136 L p F P
0 g
s
.628 .369 .506 r
.58319 .96471 m .58406 .9552 L .60745 .95271 L p F P
0 g
s
.883 .794 .757 r
.6279 .36739 m .6305 .3635 L .63502 .37047 L p F P
0 g
s
.883 .794 .757 r
.63502 .37047 m .633 .37348 L .6279 .36739 L p F P
0 g
s
.753 .682 .783 r
.43023 .80168 m .43464 .7981 L .42692 .79632 L closepath p F P
0 g
s
.483 .646 .93 r
.36746 .54201 m .35182 .54156 L .34796 .53464 L p F P
0 g
s
.476 .652 .936 r
.35182 .54156 m .36746 .54201 L .37349 .54877 L p F P
0 g
s
.824 .654 .106 r
.82775 .37136 m .82852 .37936 L .82856 .37037 L p F P
0 g
s
.824 .654 .106 r
.82856 .37037 m .82779 .36235 L .82775 .37136 L p F P
0 g
s
.467 .436 .741 r
.42004 .36704 m .41803 .37033 L p .41413 .35432 L F P
0 g
s
.42 .407 .739 r
.42004 .36704 m .42161 .3719 L .41803 .37033 L closepath p F P
0 g
s
.428 .402 .728 r
.41803 .37033 m .42161 .3719 L .4244 .38108 L p F P
0 g
s
.721 .678 .807 r
.49634 .77 m .47617 .78197 L .47054 .77319 L p F P
0 g
s
.708 .694 .835 r
.48196 .56277 m .47162 .56812 L .48679 .56997 L closepath p F P
0 g
s
.679 .644 .807 r
.57368 .76911 m .5533 .77772 L .54787 .76793 L p F P
0 g
s
0 0 .21 r
.5923 .50448 m .58857 .50894 L .59238 .49856 L p F P
0 g
s
0 0 .21 r
.59238 .49856 m .59355 .49716 L .5923 .50448 L p F P
0 g
s
.746 .692 .799 r
.44616 .77984 m .45038 .78652 L .43464 .7981 L p F P
0 g
s
.746 .692 .799 r
.44267 .77906 m .44616 .77984 L p .43464 .7981 L F P
0 g
s
.746 .692 .799 r
.4245 .79267 m .44267 .77906 L p .43464 .7981 L F P
0 g
s
.746 .692 .799 r
.43464 .7981 m .42692 .79632 L .4245 .79267 L p F P
0 g
s
.835 .766 .785 r
.64979 .32176 m .64265 .32997 L .64773 .33725 L p F P
0 g
s
.872 .768 .745 r
.64001 .33396 m .64265 .32997 L .64773 .33725 L p F P
0 g
s
.872 .768 .745 r
.64773 .33725 m .64548 .3407 L .64001 .33396 L p F P
0 g
s
.307 .48 .867 r
.26885 .47708 m .2742 .48537 L .27053 .48402 L closepath p F P
0 g
s
.621 .545 .747 r
.55951 .55432 m .56469 .56883 L .57459 .56613 L p F P
0 g
s
.274 .107 .465 r
.58521 .52843 m .57726 .53555 L .57735 .5267 L p F P
0 g
s
.274 .107 .465 r
.57735 .5267 m .58589 .51899 L .58521 .52843 L p F P
0 g
s
.915 .79 .708 r
.62902 .38137 m .633 .37348 L .6279 .36739 L p F P
0 g
s
.212 .245 .679 r
.4397 .43487 m .43844 .44108 L p .43496 .42499 L F P
0 g
s
.099 .164 .644 r
.4397 .43487 m .43844 .44108 L .44321 .44819 L p F P
0 g
s
.522 .683 .939 r
.39894 .5546 m .38639 .55521 L .38151 .54873 L p F P
0 g
s
.518 .689 .945 r
.38639 .55521 m .39894 .5546 L .40488 .56079 L p F P
0 g
s
.568 .56 .805 r
.38852 .2854 m .39368 .29647 L .37674 .29837 L closepath p F P
0 g
s
.567 .568 .814 r
.3971 .30444 m .39368 .29647 L .37674 .29837 L p F P
0 g
s
.567 .568 .814 r
.39232 .30997 m .3971 .30444 L p .37674 .29837 L F P
0 g
s
.648 .609 .797 r
.63086 .78672 m .61023 .79302 L .60489 .78196 L p F P
0 g
s
.532 .656 .915 r
.76831 .2792 m .75992 .27944 L .75525 .27219 L p F P
0 g
s
.888 .952 .841 r
.79459 .46953 m .79452 .46949 L .79463 .46938 L closepath p F P
0 g
s
.778 .675 .749 r
.38981 .84049 m .3897 .84031 L .38959 .84043 L closepath p F P
0 g
s
.526 .374 .618 r
.55921 .55207 m .56192 .55314 L .55951 .55432 L closepath p F P
0 g
s
.633 .451 .618 r
.55921 .55207 m .55655 .55488 L .55951 .55432 L closepath p F P
0 g
s
.795 .647 .697 r
.37076 .86559 m .38257 .86898 L .37532 .881 L p F P
0 g
s
.791 .656 .714 r
.38257 .86898 m .37076 .86559 L .37939 .85322 L p F P
0 g
s
.925 .959 .642 r
.22987 .34105 m .23181 .33235 L .23749 .32193 L p F P
0 g
s
.83 .845 .382 r
.23181 .33235 m .22987 .34105 L .22708 .34766 L p F P
0 g
s
.888 .866 .421 r
.22646 .3521 m .22708 .34766 L .22987 .34105 L p F P
0 g
s
.781 .679 .752 r
.38959 .84043 m .3897 .84031 L .38392 .8304 L p F P
0 g
s
.791 .673 .733 r
.37807 .8369 m .38959 .84043 L .37939 .85322 L p F P
0 g
s
.781 .679 .752 r
.38392 .8304 m .37807 .8369 L .38959 .84043 L p F P
0 g
s
0 0 .497 r
.2284 .41237 m .22837 .40329 L .22534 .39601 L p F P
0 g
s
0 .077 .613 r
.22837 .40329 m .2284 .41237 L .23279 .4192 L p F P
0 g
s
.547 .709 .946 r
.40488 .56079 m .42457 .5588 L .43043 .56478 L p F P
0 g
s
.55 .703 .941 r
.41867 .55258 m .39894 .5546 L .40488 .56079 L p F P
0 g
s
.55 .703 .941 r
.40488 .56079 m .42457 .5588 L .41867 .55258 L p F P
0 g
s
.888 .944 .842 r
.79037 .46739 m .79608 .46101 L .79463 .46938 L p F P
0 g
s
.888 .944 .842 r
.79463 .46938 m .79452 .46949 L .79037 .46739 L p F P
0 g
s
.889 .952 .84 r
.78245 .48255 m .79452 .46949 L .79037 .46739 L p F P
0 g
s
.341 .522 .889 r
.79316 .29636 m .79117 .29569 L .78654 .2877 L p F P
0 g
s
.872 .768 .745 r
.64001 .33396 m .64548 .3407 L .63806 .35206 L p F P
0 g
s
.73 .452 .506 r
.47907 .96547 m .46237 .96395 L .45956 .95427 L p F P
0 g
s
.735 .455 .505 r
.45101 .9534 m .45956 .95427 L .46237 .96395 L p F P
0 g
s
.63 .584 .784 r
.64198 .81148 m .64149 .81036 L .66177 .80553 L closepath p F P
0 g
s
.759 .506 .552 r
.44295 .95236 m .42743 .95015 L .42708 .93993 L p F P
0 g
s
.764 .511 .551 r
.41982 .93879 m .42708 .93993 L .42743 .95015 L p F P
0 g
s
.829 .928 .898 r
.75414 .50799 m .74969 .51162 L .7516 .50651 L closepath p F P
0 g
s
.808 .915 .911 r
.74972 .50519 m .7516 .50651 L .74969 .51162 L p F P
0 g
s
.808 .915 .911 r
.73121 .51909 m .74972 .50519 L p .74969 .51162 L F P
0 g
s
.808 .915 .911 r
.73032 .52136 m .73121 .51909 L p .74969 .51162 L F P
0 g
s
.757 .874 .932 r
.70326 .53733 m .68789 .54618 L .6831 .54263 L p F P
0 g
s
.69 .806 .936 r
.63172 .55472 m .63678 .55911 L .61618 .56769 L p F P
0 g
s
.69 .806 .936 r
.62026 .55928 m .63172 .55472 L p .61618 .56769 L F P
0 g
s
.69 .806 .936 r
.61618 .56769 m .61385 .56555 L .62026 .55928 L p F P
0 g
s
.63 .584 .784 r
.66177 .80553 m .64149 .81036 L .63617 .79821 L p F P
0 g
s
.621 .545 .747 r
.57976 .55134 m .56192 .55314 L .55951 .55432 L p F P
0 g
s
.621 .545 .747 r
.58459 .56208 m .57976 .55134 L p .55951 .55432 L F P
0 g
s
.621 .545 .747 r
.57459 .56613 m .58459 .56208 L p .55951 .55432 L F P
0 g
s
.959 .945 .693 r
.81396 .42873 m .81348 .43692 L .8195 .4258 L p F P
0 g
s
.959 .945 .693 r
.8195 .4258 m .81992 .4176 L .81396 .42873 L p F P
0 g
s
.665 .635 .81 r
.59956 .77168 m .57906 .77911 L .57368 .76911 L p F P
0 g
s
0 0 .12 r
.59576 .49852 m .5923 .50448 L .59355 .49716 L p F P
0 g
s
0 0 .12 r
.59355 .49716 m .59846 .48847 L .59576 .49852 L p F P
0 g
s
.836 .928 .892 r
.76771 .49655 m .75414 .50799 L .7516 .50651 L p F P
0 g
s
.499 .467 .753 r
.41532 .35258 m .41413 .35432 L p .40925 .33865 L F P
0 g
s
.46 .444 .754 r
.41532 .35258 m .41612 .35488 L .41413 .35432 L closepath p F P
0 g
s
.467 .436 .741 r
.41413 .35432 m .41612 .35488 L .42004 .36704 L p F P
0 g
s
.739 .684 .798 r
.45038 .78652 m .45693 .78191 L .44616 .77984 L closepath p F P
0 g
s
.447 .609 .916 r
.33608 .52674 m .32429 .5255 L .32119 .5182 L p F P
0 g
s
.437 .612 .923 r
.32429 .5255 m .33608 .52674 L .34218 .53414 L p F P
0 g
s
.956 .879 .48 r
.82419 .39892 m .82705 .38888 L .82736 .39695 L p F P
0 g
s
.956 .879 .48 r
.82443 .40609 m .82419 .39892 L p .82736 .39695 L F P
0 g
s
.956 .879 .48 r
.82736 .39695 m .82481 .40571 L .82443 .40609 L p F P
0 g
s
.646 .754 .928 r
.61103 .56282 m .59046 .56974 L .58517 .56303 L p F P
0 g
s
.838 .911 .886 r
.26553 .29176 m .25946 .29697 L .26159 .29067 L closepath p F P
0 g
s
.87 .946 .862 r
.26159 .29067 m .25946 .29697 L .2458 .3105 L p F P
0 g
s
.851 .922 .877 r
.2456 .31111 m .2458 .3105 L .25946 .29697 L p F P
0 g
s
.615 .731 .928 r
.45037 .56013 m .44009 .56258 L .44714 .56822 L p F P
0 g
s
.615 .731 .928 r
.44714 .56822 m .45614 .56621 L .45037 .56013 L p F P
0 g
s
.616 .736 .932 r
.43043 .56478 m .44009 .56258 L .44714 .56822 L p F P
0 g
s
.889 .952 .84 r
.79037 .46739 m .7843 .47409 L .78245 .48255 L p F P
0 g
s
.863 .938 .869 r
.77017 .48792 m .7843 .47409 L .78245 .48255 L p F P
0 g
s
.863 .938 .869 r
.78245 .48255 m .77446 .49022 L .77017 .48792 L p F P
0 g
s
.898 .975 .813 r
.2458 .3105 m .2456 .31111 L .24518 .31122 L closepath p F P
0 g
s
.925 .965 .775 r
.23749 .32193 m .24518 .31122 L .2456 .31111 L p F P
0 g
s
.756 .731 .829 r
.47162 .56812 m .48196 .56277 L .47634 .55338 L p F P
0 g
s
.756 .731 .829 r
.47634 .55338 m .46232 .56324 L .47162 .56812 L p F P
0 g
s
.693 .758 .902 r
.45614 .56621 m .46232 .56324 L .47162 .56812 L p F P
0 g
s
0 0 .139 r
.82659 .35442 m .82779 .36235 L .82633 .35391 L p F P
0 g
s
0 0 .139 r
.82633 .35391 m .82514 .34596 L .82659 .35442 L p F P
0 g
s
.592 .441 .646 r
.66899 .89797 m .66873 .89646 L .68924 .8908 L p F P
0 g
s
.6 .468 .672 r
.6865 .87831 m .68924 .8908 L .66873 .89646 L p F P
0 g
s
.862 .943 .87 r
.76771 .49655 m .77446 .49022 L .77017 .48792 L p F P
0 g
s
.922 .891 .478 r
.60267 .46979 m .60164 .47831 L .60516 .46807 L p F P
0 g
s
.922 .891 .478 r
.60401 .46518 m .60267 .46979 L p .60516 .46807 L F P
0 g
s
.922 .891 .478 r
.60516 .46807 m .60568 .46252 L .60401 .46518 L p F P
0 g
s
.791 .871 .907 r
.26553 .29176 m .26159 .29067 L p .28396 .2771 L F P
0 g
s
.791 .871 .907 r
.28396 .2771 m .28289 .27958 L .26553 .29176 L p F P
0 g
s
.6 .378 .551 r
.63009 .94944 m .63001 .93927 L .6519 .93522 L p F P
0 g
s
.612 .413 .589 r
.65109 .92447 m .6519 .93522 L .63001 .93927 L p F P
0 g
s
.862 .943 .87 r
.77017 .48792 m .77015 .48795 L .76771 .49655 L p F P
0 g
s
.836 .928 .892 r
.75271 .50287 m .77015 .48795 L .76771 .49655 L p F P
0 g
s
.836 .928 .892 r
.7516 .50651 m .75271 .50287 L p .76771 .49655 L F P
0 g
s
.832 .709 .729 r
.47634 .55338 m .47856 .54872 L .48813 .55354 L p F P
0 g
s
.832 .709 .729 r
.48813 .55354 m .48196 .56277 L .47634 .55338 L p F P
0 g
s
.753 .694 .795 r
.42692 .79632 m .4245 .79267 L .42156 .79494 L closepath p F P
0 g
s
.735 .455 .505 r
.46237 .96395 m .44928 .96264 L .45101 .9534 L p F P
0 g
s
.749 .468 .507 r
.44295 .95236 m .45101 .9534 L .44928 .96264 L p F P
0 g
s
.31 .311 .699 r
.43607 .42163 m .43496 .42499 L p .43228 .40857 L F P
0 g
s
.218 .247 .678 r
.43607 .42163 m .43792 .42843 L .43496 .42499 L closepath p F P
0 g
s
.212 .245 .679 r
.43496 .42499 m .43792 .42843 L .4397 .43487 L p F P
0 g
s
.408 .574 .905 r
.31869 .51062 m .30492 .50836 L .31107 .51643 L p F P
0 g
s
.408 .574 .905 r
.31107 .51643 m .32119 .5182 L .31869 .51062 L p F P
0 g
s
.399 .573 .907 r
.30147 .50774 m .30492 .50836 L .31107 .51643 L p F P
0 g
s
.341 .522 .889 r
.78654 .2877 m .79001 .28881 L .79316 .29636 L p F P
0 g
s
.231 .445 .862 r
.80034 .29388 m .80336 .30148 L .79316 .29636 L p F P
0 g
s
.231 .445 .862 r
.79316 .29636 m .79001 .28881 L .80034 .29388 L p F P
0 g
s
.375 .532 .884 r
.29875 .49996 m .28481 .49628 L .28272 .48843 L p F P
0 g
s
.359 .531 .889 r
.29931 .50076 m .30147 .50774 L p .28481 .49628 L F P
0 g
s
.359 .531 .889 r
.28481 .49628 m .29875 .49996 L .29931 .50076 L p F P
0 g
s
.733 .694 .813 r
.46489 .76452 m .47054 .77319 L .45693 .78191 L p F P
0 g
s
.733 .694 .813 r
.44469 .77768 m .46489 .76452 L p .45693 .78191 L F P
0 g
s
.733 .694 .813 r
.45693 .78191 m .44616 .77984 L .44469 .77768 L p F P
0 g
s
.592 .443 .648 r
.67081 .90833 m .66899 .89797 L .69 .8951 L p F P
0 g
s
.592 .441 .646 r
.68924 .8908 m .69 .8951 L .66899 .89797 L p F P
0 g
s
.87 .946 .862 r
.2458 .3105 m .2499 .2993 L p .26159 .29067 L F P
0 g
s
.893 .982 .807 r
.2499 .2993 m .2458 .3105 L .24518 .31122 L p F P
0 g
s
.895 .658 .572 r
.47099 .54319 m .47856 .54872 L .48027 .53901 L p F P
0 g
s
.895 .658 .572 r
.48027 .53901 m .47239 .53358 L .47099 .54319 L p F P
0 g
s
.796 .665 .719 r
.368 .84967 m .37939 .85322 L .37076 .86559 L p F P
0 g
s
.791 .673 .733 r
.37939 .85322 m .368 .84967 L .37807 .8369 L p F P
0 g
s
.893 .982 .807 r
.24518 .31122 m .23951 .31401 L p .2499 .2993 L F P
0 g
s
.921 .975 .757 r
.24518 .31122 m .23749 .32193 L .23951 .31401 L closepath p F P
0 g
s
.58 .475 .699 r
.56192 .55314 m .57832 .5458 L .57976 .55134 L closepath p F P
0 g
s
.787 .58 .62 r
.40021 .92412 m .38697 .92124 L .38998 .91026 L p F P
0 g
s
.793 .587 .622 r
.38221 .90841 m .38998 .91026 L .38697 .92124 L p F P
0 g
s
.791 .605 .65 r
.38013 .89997 m .38171 .89588 L p .38998 .91026 L F P
0 g
s
.791 .605 .65 r
.38998 .91026 m .38221 .90841 L .38013 .89997 L p F P
0 g
s
0 0 .32 r
.22534 .39601 m .22579 .38665 L .22418 .37889 L p F P
0 g
s
0 0 .501 r
.22579 .38665 m .22534 .39601 L .22837 .40329 L p F P
0 g
s
.945 .624 .392 r
.46541 .51483 m .46584 .51855 L .47222 .52454 L p F P
0 g
s
.945 .658 .464 r
.46601 .52759 m .47239 .53358 L .47222 .52454 L p F P
0 g
s
.945 .658 .464 r
.47222 .52454 m .46584 .51855 L .46601 .52759 L p F P
0 g
s
.764 .511 .551 r
.42743 .95015 m .41909 .94886 L .41982 .93879 L p F P
0 g
s
.775 .521 .551 r
.4125 .93746 m .41982 .93879 L .41909 .94886 L p F P
0 g
s
.592 .399 .588 r
.6519 .93522 m .65109 .92447 L .67229 .91965 L p F P
0 g
s
.602 .429 .62 r
.67081 .90833 m .67229 .91965 L .65109 .92447 L p F P
0 g
s
.989 .882 .619 r
.60905 .44125 m .61022 .44915 L .61437 .43875 L p F P
0 g
s
.989 .882 .619 r
.61437 .43875 m .61275 .43099 L .60905 .44125 L p F P
0 g
s
.798 .61 .648 r
.38013 .89997 m .38171 .89588 L .37893 .89516 L closepath p F P
0 g
s
.794 .627 .674 r
.37466 .88235 m .37532 .881 L p .38171 .89588 L F P
0 g
s
.794 .627 .674 r
.38171 .89588 m .37893 .89516 L .37466 .88235 L p F P
0 g
s
.944 .849 .719 r
.61338 .41284 m .61839 .40278 L .62145 .41015 L p F P
0 g
s
.944 .849 .719 r
.62145 .41015 m .61845 .41595 L .61338 .41284 L p F P
0 g
s
.499 .662 .934 r
.37734 .54195 m .36746 .54201 L .37349 .54877 L p F P
0 g
s
.499 .662 .934 r
.37349 .54877 m .38151 .54873 L .37734 .54195 L p F P
0 g
s
.525 .494 .765 r
.41009 .33753 m .40925 .33865 L p .40245 .32368 L F P
0 g
s
.494 .477 .767 r
.41009 .33753 m .41058 .33885 L .40925 .33865 L closepath p F P
0 g
s
.499 .467 .753 r
.40925 .33865 m .41058 .33885 L .41532 .35258 L p F P
0 g
s
.909 .528 .098 r
.46439 .51 m .45976 .50335 L .45722 .49522 L p F P
0 g
s
.946 .596 .201 r
.46541 .51483 m .46439 .51 L .45976 .50335 L p F P
0 g
s
.547 .535 .793 r
.3971 .30444 m .39937 .30968 L .39232 .30997 L closepath p F P
0 g
s
.545 .545 .805 r
.40413 .32162 m .39937 .30968 L .39232 .30997 L p F P
0 g
s
.545 .545 .805 r
.40245 .32368 m .40413 .32162 L p .39232 .30997 L F P
0 g
s
.915 .79 .708 r
.6279 .36739 m .62438 .37445 L .62902 .38137 L p F P
0 g
s
.916 .789 .706 r
.61912 .38514 m .6237 .39206 L .62902 .38137 L p F P
0 g
s
.916 .789 .706 r
.62902 .38137 m .62438 .37445 L .61912 .38514 L p F P
0 g
s
.588 .587 .818 r
.38211 .27265 m .36253 .27719 L .36841 .28758 L p F P
0 g
s
.588 .587 .818 r
.36841 .28758 m .38793 .28412 L .38211 .27265 L p F P
0 g
s
.613 .619 .833 r
.36009 .2778 m .36253 .27719 L .36841 .28758 L p F P
0 g
s
.475 .442 .741 r
.42161 .3719 m .42875 .37495 L p .42769 .3578 L F P
0 g
s
.475 .442 .741 r
.42769 .3578 m .42004 .36704 L .42161 .3719 L p F P
0 g
s
.432 .405 .729 r
.42161 .3719 m .42875 .37495 L .4244 .38108 L closepath p F P
0 g
s
.675 .728 .89 r
.32468 .25829 m .30504 .26723 L .31141 .27333 L p F P
0 g
s
.675 .728 .89 r
.31141 .27333 m .33092 .26548 L .32468 .25829 L p F P
0 g
s
.475 .442 .741 r
.41612 .35488 m .42769 .3578 L .42004 .36704 L closepath p F P
0 g
s
.655 .35 .444 r
.5313 .97573 m .53348 .96709 L .54821 .9667 L p F P
0 g
s
.674 .369 .449 r
.5226 .96704 m .53348 .96709 L .5313 .97573 L p F P
0 g
s
.509 .474 .753 r
.41612 .35488 m .42769 .3578 L p .42638 .3407 L F P
0 g
s
.509 .474 .753 r
.42638 .3407 m .41532 .35258 L .41612 .35488 L p F P
0 g
s
.674 .369 .449 r
.5313 .97573 m .52994 .97572 L .5226 .96704 L p F P
0 g
s
.674 .358 .431 r
.50698 .96685 m .5226 .96704 L .52994 .97572 L p F P
0 g
s
.509 .473 .752 r
.41058 .33885 m .42638 .3407 L .41532 .35258 L closepath p F P
0 g
s
.607 .351 .503 r
.60745 .95271 m .61578 .95153 L .6265 .95943 L p F P
0 g
s
.607 .351 .503 r
.6265 .95943 m .60666 .96223 L .60745 .95271 L p F P
0 g
s
.628 .369 .506 r
.60745 .95271 m .60666 .96223 L .58319 .96471 L p F P
0 g
s
.793 .749 .812 r
.66272 .30648 m .67514 .29529 L .66915 .28861 L p F P
0 g
s
.793 .749 .812 r
.66915 .28861 m .65767 .29877 L .66272 .30648 L p F P
0 g
s
.835 .756 .776 r
.65436 .30264 m .65767 .29877 L .66272 .30648 L p F P
0 g
s
.835 .756 .776 r
.66272 .30648 m .66037 .30928 L .65436 .30264 L p F P
0 g
s
.782 .552 .588 r
.4125 .93746 m .39878 .93474 L .40021 .92412 L p F P
0 g
s
.788 .559 .589 r
.38697 .92124 m .40021 .92412 L .39878 .93474 L p F P
0 g
s
.756 .746 .844 r
.68299 .28798 m .69602 .27906 L .69025 .27227 L p F P
0 g
s
.756 .746 .844 r
.69025 .27227 m .67803 .2805 L .68299 .28798 L p F P
0 g
s
.803 .755 .809 r
.66915 .28861 m .67803 .2805 L .68299 .28798 L p F P
0 g
s
.803 .755 .809 r
.68299 .28798 m .67514 .29529 L .66915 .28861 L p F P
0 g
s
.431 .404 .728 r
.42875 .37495 m .4244 .38108 L .42707 .3899 L p F P
0 g
s
.694 .655 .807 r
.54651 .7655 m .54787 .76793 L p .5221 .76823 L F P
0 g
s
.694 .655 .807 r
.5221 .76823 m .52664 .76599 L .54651 .7655 L p F P
0 g
s
.696 .661 .812 r
.5221 .76823 m .52664 .76599 L .52082 .76605 L closepath p F P
0 g
s
.708 .666 .807 r
.52082 .76605 m .5221 .76823 L p .49634 .77 L F P
0 g
s
0 0 .401 r
.82351 .33809 m .82514 .34596 L .82203 .33814 L p F P
0 g
s
0 0 .401 r
.82203 .33814 m .8204 .33026 L .82351 .33809 L p F P
0 g
s
.771 .686 .769 r
.40428 .80973 m .40431 .8097 L .40425 .80969 L closepath p F P
0 g
s
.764 .696 .787 r
.40945 .79147 m .42156 .79494 L .40431 .8097 L p F P
0 g
s
.764 .696 .787 r
.39846 .80103 m .40945 .79147 L p .40431 .8097 L F P
0 g
s
.764 .696 .787 r
.40431 .8097 m .40425 .80969 L .39846 .80103 L p F P
0 g
s
.774 .687 .767 r
.3901 .8236 m .40428 .80973 L .40425 .80969 L p F P
0 g
s
.334 .495 .87 r
.2742 .48537 m .28272 .48843 L p .26863 .47604 L F P
0 g
s
.334 .495 .87 r
.26863 .47604 m .26885 .47708 L .2742 .48537 L p F P
0 g
s
.774 .687 .767 r
.40425 .80969 m .39274 .80611 L p .3901 .8236 L F P
0 g
s
.769 .697 .783 r
.40425 .80969 m .39846 .80103 L .39274 .80611 L closepath p F P
0 g
s
.674 .358 .431 r
.50513 .97361 m .50698 .96685 L p .52994 .97572 L F P
0 g
s
.695 .388 .452 r
.50513 .97361 m .50031 .96657 L .50698 .96685 L closepath p F P
0 g
s
0 0 .291 r
.45476 .48853 m .45722 .49522 L p .45138 .47997 L F P
0 g
s
.725 .408 0 r
.45476 .48853 m .45722 .49522 L .45976 .50335 L p F P
0 g
s
.452 .619 .922 r
.34472 .52743 m .33608 .52674 L .34218 .53414 L p F P
0 g
s
.452 .619 .922 r
.34218 .53414 m .34796 .53464 L .34472 .52743 L p F P
0 g
s
.522 .507 .78 r
.40413 .32162 m .405 .32379 L .40245 .32368 L closepath p F P
0 g
s
.525 .494 .765 r
.40245 .32368 m .405 .32379 L .41009 .33753 L p F P
0 g
s
.708 .666 .807 r
.49634 .77 m .50488 .76529 L .52082 .76605 L p F P
0 g
s
.711 .674 .812 r
.49634 .77 m .50488 .76529 L .49294 .76447 L closepath p F P
0 g
s
.721 .678 .807 r
.49294 .76447 m .49634 .77 L p .47054 .77319 L F P
0 g
s
.431 .404 .728 r
.42707 .3899 m .43017 .39191 L p .42875 .37495 L F P
0 g
s
.372 .359 .715 r
.42707 .3899 m .43017 .39191 L .4285 .39483 L closepath p F P
0 g
s
.8 .631 .672 r
.37466 .88235 m .37532 .881 L .37408 .88064 L closepath p F P
0 g
s
.795 .647 .697 r
.36901 .86857 m .37076 .86559 L p .37532 .881 L F P
0 g
s
.795 .647 .697 r
.37532 .881 m .37408 .88064 L .36901 .86857 L p F P
0 g
s
.834 .756 .778 r
.65436 .30264 m .66037 .30928 L .64979 .32176 L p F P
0 g
s
.655 .35 .444 r
.54821 .9667 m .55688 .97494 L p .5313 .97573 L F P
0 g
s
.652 .351 .449 r
.55688 .97494 m .54821 .9667 L .55882 .96634 L closepath p F P
0 g
s
.73 .685 .141 r
.22708 .34766 m .22646 .3521 L .22499 .36095 L p F P
0 g
s
.749 .468 .507 r
.44928 .96264 m .44536 .96213 L .44295 .95236 L p F P
0 g
s
.754 .471 .503 r
.42743 .95015 m .44295 .95236 L .44536 .96213 L p F P
0 g
s
.872 .768 .745 r
.63806 .35206 m .63247 .34539 L .64001 .33396 L p F P
0 g
s
.869 .766 .746 r
.63247 .34539 m .63806 .35206 L .6305 .3635 L p F P
0 g
s
.048 .286 .777 r
.81077 .30767 m .81329 .31537 L .80595 .30916 L p F P
0 g
s
.048 .286 .777 r
.80595 .30916 m .80336 .30148 L .81077 .30767 L p F P
0 g
s
.799 .611 .647 r
.37893 .89516 m .36971 .8926 L p .37739 .90717 L F P
0 g
s
.799 .611 .647 r
.37739 .90717 m .38013 .89997 L .37893 .89516 L p F P
0 g
s
.8 .63 .671 r
.37893 .89516 m .37466 .88235 L .36971 .8926 L closepath p F P
0 g
s
.71 .433 .503 r
.50031 .96657 m .48023 .96554 L .47944 .96336 L p F P
0 g
s
.715 .435 .501 r
.48023 .96554 m .47907 .96547 L .47944 .96336 L closepath p F P
0 g
s
.536 .502 .765 r
.41058 .33885 m .42638 .3407 L p .4239 .32399 L F P
0 g
s
.536 .502 .765 r
.4239 .32399 m .41009 .33753 L .41058 .33885 L p F P
0 g
s
.648 .609 .797 r
.60489 .78196 m .62554 .77558 L .63086 .78672 L p F P
0 g
s
.648 .611 .798 r
.62537 .77522 m .62554 .77558 L .60489 .78196 L p F P
0 g
s
.648 .611 .798 r
.60489 .78196 m .60412 .78036 L .62537 .77522 L p F P
0 g
s
.37 .356 .714 r
.43017 .39191 m .4285 .39483 L .43238 .40834 L p F P
0 g
s
.305 .314 .705 r
.43228 .40857 m .43238 .40834 L .4285 .39483 L p F P
0 g
s
.699 .385 .442 r
.50031 .96657 m .50513 .97361 L .50456 .97539 L p F P
0 g
s
.699 .385 .442 r
.48023 .96554 m .50031 .96657 L p .50456 .97539 L F P
0 g
s
.619 .734 .928 r
.44009 .56258 m .43043 .56478 L .42457 .5588 L p F P
0 g
s
.785 .682 .751 r
.3901 .8236 m .38392 .8304 L .37809 .8207 L p F P
0 g
s
.785 .682 .751 r
.37809 .8207 m .37874 .81997 L .3901 .8236 L p F P
0 g
s
.774 .687 .767 r
.39274 .80611 m .37874 .81997 L .3901 .8236 L p F P
0 g
s
.536 .501 .764 r
.405 .32379 m .4239 .32399 L .41009 .33753 L closepath p F P
0 g
s
.755 .699 .798 r
.41872 .78419 m .40945 .79147 L .42156 .79494 L p F P
0 g
s
.755 .699 .798 r
.42156 .79494 m .4245 .79267 L .41872 .78419 L p F P
0 g
s
.679 .644 .807 r
.5705 .76325 m .57368 .76911 L p .54787 .76793 L F P
0 g
s
.679 .644 .807 r
.54787 .76793 m .55527 .76474 L .5705 .76325 L p F P
0 g
s
.681 .65 .812 r
.54787 .76793 m .55527 .76474 L .54651 .7655 L closepath p F P
0 g
s
.801 .632 .672 r
.36971 .8926 m .37466 .88235 L .37408 .88064 L p F P
0 g
s
0 .064 .626 r
.81834 .32246 m .8204 .33026 L .81537 .32317 L p F P
0 g
s
0 .064 .626 r
.81537 .32317 m .81329 .31537 L .81834 .32246 L p F P
0 g
s
.633 .665 .863 r
.35052 .2586 m .33092 .26548 L .33706 .27341 L p F P
0 g
s
.633 .665 .863 r
.33706 .27341 m .35657 .26753 L .35052 .2586 L p F P
0 g
s
.801 .632 .672 r
.37408 .88064 m .36378 .87755 L p .36971 .8926 L F P
0 g
s
.801 .649 .694 r
.37408 .88064 m .36901 .86857 L .36378 .87755 L closepath p F P
0 g
s
.646 .659 .849 r
.57459 .56613 m .58459 .56208 L .58517 .56303 L closepath p F P
0 g
s
.033 0 .292 r
.59144 .51233 m .58589 .51899 L .58857 .50894 L p F P
0 g
s
.033 0 .292 r
.58857 .50894 m .5923 .50448 L .59144 .51233 L p F P
0 g
s
.63 .584 .784 r
.63617 .79821 m .65699 .79324 L p .66177 .80553 L F P
0 g
s
.63 .584 .784 r
.65464 .78785 m .65699 .79324 L .63617 .79821 L p F P
0 g
s
.63 .584 .784 r
.63617 .79821 m .63436 .79408 L .65464 .78785 L p F P
0 g
s
.627 .319 .429 r
.55882 .96634 m .57944 .96498 L p .58132 .97343 L F P
0 g
s
.627 .319 .429 r
.55688 .97494 m .55882 .96634 L p .58132 .97343 L F P
0 g
s
.751 .693 .796 r
.44267 .77906 m .4245 .79267 L .41872 .78419 L p F P
0 g
s
.798 .609 .647 r
.38221 .90841 m .38013 .89997 L .37739 .90717 L closepath p F P
0 g
s
.772 .891 .929 r
.70852 .53406 m .70326 .53733 L .70601 .53231 L closepath p F P
0 g
s
.757 .874 .932 r
.70382 .53058 m .70601 .53231 L .70326 .53733 L p F P
0 g
s
.757 .874 .932 r
.6831 .54263 m .70382 .53058 L p .70326 .53733 L F P
0 g
s
.651 .627 .814 r
.62022 .76532 m .62537 .77522 L .60412 .78036 L p F P
0 g
s
.651 .627 .814 r
.60412 .78036 m .59956 .77168 L .62022 .76532 L p F P
0 g
s
.693 .673 .826 r
.52664 .76599 m .52082 .76605 L .51659 .75931 L p F P
0 g
s
.704 .678 .821 r
.52082 .76605 m .51659 .75931 L .50488 .76529 L closepath p F P
0 g
s
.304 .311 .702 r
.43238 .40834 m .43251 .40877 L .43228 .40857 L closepath p F P
0 g
s
.31 .311 .699 r
.43228 .40857 m .43251 .40877 L .43607 .42163 L p F P
0 g
s
.691 .667 .822 r
.54651 .7655 m .54242 .75873 L .52664 .76599 L closepath p F P
0 g
s
.693 .673 .826 r
.53694 .7498 m .54242 .75873 L .52664 .76599 L p F P
0 g
s
.693 .673 .826 r
.51659 .75931 m .53694 .7498 L p .52664 .76599 L F P
0 g
s
0 0 .534 r
.45074 .47481 m .45138 .47997 L p .44673 .46429 L F P
0 g
s
0 0 .268 r
.45425 .48716 m .45443 .48787 L p .45418 .48695 L F P
0 g
s
0 0 .268 r
.45007 .47203 m .45074 .47481 L .45425 .48716 L p F P
0 g
s
0 0 .268 r
.45007 .47203 m .45425 .48716 L .45418 .48695 L F
0 0 .291 r
.45425 .48716 m .45476 .48853 L p .45434 .48746 L F P
0 g
s
0 0 .291 r
.45138 .47997 m .45425 .48716 L p .45434 .48746 L F P
0 g
s
.721 .678 .807 r
.47054 .77319 m .48624 .76368 L .49294 .76447 L p F P
0 g
s
.725 .684 .811 r
.48624 .76368 m .47054 .77319 L .46489 .76452 L p F P
0 g
s
.786 .684 .752 r
.37807 .8369 m .38392 .8304 L .37809 .8207 L p F P
0 g
s
.775 .521 .551 r
.41909 .94886 m .41274 .94771 L .4125 .93746 L p F P
0 g
s
.781 .526 .55 r
.39878 .93474 m .4125 .93746 L .41274 .94771 L p F P
0 g
s
.37 .356 .714 r
.43238 .40834 m .43859 .39752 L .43017 .39191 L p F P
0 g
s
.365 .351 .711 r
.43859 .39752 m .43238 .40834 L .43251 .40877 L p F P
0 g
s
.939 .951 .759 r
.80643 .44041 m .81396 .42873 L .81348 .43692 L p F P
0 g
s
.939 .951 .759 r
.80639 .44103 m .80643 .44041 L p .81348 .43692 L F P
0 g
s
.939 .951 .759 r
.81348 .43692 m .81007 .44207 L .80639 .44103 L p F P
0 g
s
.365 .351 .711 r
.43251 .40877 m .43883 .41492 L p .43859 .39752 L F P
0 g
s
.276 .289 .693 r
.43251 .40877 m .43883 .41492 L .43607 .42163 L closepath p F P
0 g
s
.965 .824 .654 r
.6166 .42073 m .61845 .41595 L .61338 .41284 L p F P
0 g
s
.773 .849 .908 r
.28537 .27796 m .28289 .27958 L .28396 .2771 L closepath p F P
0 g
s
.685 .794 .932 r
.61385 .56555 m .61103 .56282 L .62026 .55928 L closepath p F P
0 g
s
.595 .5 .716 r
.68314 .86523 m .67911 .85149 L .68829 .84836 L p F P
0 g
s
.602 .522 .737 r
.67911 .85149 m .67848 .84958 L .68829 .84836 L closepath p F P
0 g
s
.602 .521 .735 r
.68829 .84836 m .67848 .84958 L .67435 .837 L p F P
0 g
s
.733 .846 .934 r
.6709 .54926 m .66242 .55357 L .65748 .54949 L p F P
0 g
s
.716 .842 .942 r
.63678 .55911 m .65748 .54949 L .66242 .55357 L p F P
0 g
s
.606 .352 .506 r
.61578 .95153 m .63009 .94944 L .62942 .95901 L p F P
0 g
s
.606 .352 .506 r
.62942 .95901 m .6265 .95943 L .61578 .95153 L p F P
0 g
s
.74 .696 .809 r
.44616 .77984 m .44469 .77768 L .44267 .77906 L closepath p F P
0 g
s
.942 .805 .349 r
.82628 .3809 m .82705 .38888 L .82852 .37936 L p F P
0 g
s
.942 .805 .349 r
.82852 .37936 m .82775 .37136 L .82628 .3809 L p F P
0 g
s
.68 .663 .827 r
.55527 .76474 m .54651 .7655 L .54242 .75873 L p F P
0 g
s
.532 .656 .915 r
.75525 .27219 m .76432 .27185 L .76831 .2792 L p F P
0 g
s
.485 .625 .913 r
.77725 .27244 m .76432 .27185 L .76831 .2792 L p F P
0 g
s
.485 .625 .913 r
.76831 .2792 m .7819 .27996 L .77725 .27244 L p F P
0 g
s
.602 .521 .735 r
.67435 .837 m .69311 .83047 L p .68829 .84836 L F P
0 g
s
.607 .541 .754 r
.67435 .837 m .67303 .83337 L .69311 .83047 L closepath p F P
0 g
s
.633 .602 .8 r
.65168 .78161 m .65464 .78785 L .63436 .79408 L p F P
0 g
s
.633 .602 .8 r
.63436 .79408 m .63086 .78672 L .65168 .78161 L p F P
0 g
s
.802 .652 .696 r
.36901 .86857 m .37076 .86559 L .36727 .86451 L closepath p F P
0 g
s
.796 .665 .719 r
.36327 .85657 m .368 .84967 L p .37076 .86559 L F P
0 g
s
.796 .665 .719 r
.37076 .86559 m .36727 .86451 L .36327 .85657 L p F P
0 g
s
.636 .711 .901 r
.72922 .27074 m .75055 .26498 L .75525 .27219 L p F P
0 g
s
.636 .714 .904 r
.74583 .25784 m .72444 .26359 L .72922 .27074 L p F P
0 g
s
.636 .714 .904 r
.72922 .27074 m .75055 .26498 L .74583 .25784 L p F P
0 g
s
.757 .849 .92 r
.29855 .26201 m .30504 .26723 L .28537 .27796 L p F P
0 g
s
.757 .849 .92 r
.29022 .26699 m .29855 .26201 L p .28537 .27796 L F P
0 g
s
.757 .849 .92 r
.28537 .27796 m .28396 .2771 L .29022 .26699 L p F P
0 g
s
.764 .752 .842 r
.70354 .27375 m .69602 .27906 L .69025 .27227 L p F P
0 g
s
.795 .682 .74 r
.36706 .83319 m .37807 .8369 L .368 .84967 L p F P
0 g
s
.786 .684 .752 r
.37809 .8207 m .36706 .83319 L .37807 .8369 L p F P
0 g
s
.788 .892 .918 r
.72453 .51695 m .72915 .5205 L .70852 .53406 L p F P
0 g
s
.788 .892 .918 r
.70775 .52816 m .72453 .51695 L p .70852 .53406 L F P
0 g
s
.788 .892 .918 r
.70852 .53406 m .70601 .53231 L .70775 .52816 L p F P
0 g
s
.559 .528 .777 r
.405 .32379 m .4239 .32399 L p .41881 .30823 L F P
0 g
s
.559 .528 .777 r
.41881 .30823 m .40413 .32162 L .405 .32379 L p F P
0 g
s
.793 .587 .622 r
.38697 .92124 m .38409 .92057 L .38221 .90841 L p F P
0 g
s
.801 .592 .619 r
.37739 .90717 m .38221 .90841 L .38409 .92057 L p F P
0 g
s
.907 .952 .609 r
.23951 .31401 m .23749 .32193 L .23181 .33235 L p F P
0 g
s
.706 .684 .827 r
.51104 .75065 m .51659 .75931 L .50488 .76529 L p F P
0 g
s
.706 .684 .827 r
.49076 .76116 m .51104 .75065 L p .50488 .76529 L F P
0 g
s
.706 .684 .827 r
.50488 .76529 m .49294 .76447 L .49076 .76116 L p F P
0 g
s
.583 .415 .62 r
.67229 .91965 m .67081 .90833 L .69138 .90271 L p F P
0 g
s
.592 .443 .648 r
.69 .8951 m .69138 .90271 L .67081 .90833 L p F P
0 g
s
.699 .385 .442 r
.50456 .97539 m .48652 .97444 L .48023 .96554 L p F P
0 g
s
.702 .385 .438 r
.47907 .96547 m .48023 .96554 L .48652 .97444 L p F P
0 g
s
.406 .568 .901 r
.29931 .50076 m .30492 .50836 L .30147 .50774 L closepath p F P
0 g
s
.834 .756 .778 r
.64979 .32176 m .64337 .31529 L .65436 .30264 L p F P
0 g
s
.822 .745 .779 r
.64265 .32997 m .64979 .32176 L .64337 .31529 L p F P
0 g
s
.607 .54 .753 r
.69311 .83047 m .67303 .83337 L .66879 .82168 L p F P
0 g
s
.702 .385 .438 r
.48652 .97444 m .47629 .97383 L .47907 .96547 L p F P
0 g
s
.72 .404 .443 r
.46237 .96395 m .47907 .96547 L .47629 .97383 L p F P
0 g
s
.955 .88 .48 r
.82481 .40571 m .82443 .40699 L .82443 .40609 L closepath p F P
0 g
s
.665 .635 .81 r
.57368 .76911 m .5942 .76154 L .59956 .77168 L p F P
0 g
s
.666 .638 .813 r
.59311 .75951 m .5942 .76154 L .57368 .76911 L p F P
0 g
s
.666 .638 .813 r
.57368 .76911 m .5705 .76325 L .59311 .75951 L p F P
0 g
s
0 0 .105 r
.22418 .37889 m .22512 .36923 L .22499 .36095 L p F P
0 g
s
0 0 .348 r
.22512 .36923 m .22418 .37889 L .22579 .38665 L p F P
0 g
s
.558 .526 .776 r
.39937 .30968 m .41881 .30823 L .40413 .32162 L closepath p F P
0 g
s
.588 .477 .695 r
.68407 .86892 m .68314 .86523 L .70294 .85859 L p F P
0 g
s
.595 .5 .716 r
.69961 .84734 m .70294 .85859 L .68314 .86523 L p F P
0 g
s
.595 .5 .716 r
.68829 .84836 m .69961 .84734 L p .68314 .86523 L F P
0 g
s
.713 .76 .889 r
.46232 .56324 m .45614 .56621 L .45037 .56013 L p F P
0 g
s
.271 .283 .689 r
.43883 .41492 m .43607 .42163 L .43792 .42843 L p F P
0 g
s
.938 .952 .761 r
.81007 .44207 m .80569 .44865 L .80639 .44103 L closepath p F P
0 g
s
.803 .652 .695 r
.36378 .87755 m .36901 .86857 L .36727 .86451 L p F P
0 g
s
.046 .132 .631 r
.44692 .46133 m .44673 .46429 L p .44321 .44819 L F P
0 g
s
0 .025 .568 r
.44692 .46133 m .44878 .4684 L .44673 .46429 L closepath p F P
0 g
s
0 0 .534 r
.44673 .46429 m .44878 .4684 L .45074 .47481 L p F P
0 g
s
.751 .693 .796 r
.41872 .78419 m .42977 .77579 L .44267 .77906 L p F P
0 g
s
.742 .701 .812 r
.43896 .76944 m .42977 .77579 L .44267 .77906 L p F P
0 g
s
.742 .701 .812 r
.44267 .77906 m .44469 .77768 L .43896 .76944 L p F P
0 g
s
.973 .926 .63 r
.81984 .4095 m .81992 .4176 L .82443 .40699 L p F P
0 g
s
.973 .926 .63 r
.82111 .40641 m .81984 .4095 L p .82443 .40699 L F P
0 g
s
.973 .926 .63 r
.82443 .40699 m .82443 .40609 L .82111 .40641 L p F P
0 g
s
.678 .658 .823 r
.5705 .76325 m .56828 .75944 L .55527 .76474 L closepath p F P
0 g
s
.68 .663 .827 r
.56286 .75028 m .56828 .75944 L .55527 .76474 L p F P
0 g
s
.68 .663 .827 r
.54242 .75873 m .56286 .75028 L p .55527 .76474 L F P
0 g
s
.589 .479 .697 r
.6865 .87831 m .68407 .86892 L .70529 .86768 L p F P
0 g
s
.588 .477 .695 r
.70294 .85859 m .70529 .86768 L .68407 .86892 L p F P
0 g
s
.793 .892 .915 r
.73032 .52136 m .72915 .5205 L .73121 .51909 L closepath p F P
0 g
s
.632 .34 .456 r
.58266 .96748 m .57944 .96498 L .58319 .96471 L closepath p F P
0 g
s
.627 .319 .429 r
.57944 .96498 m .58266 .96748 L .58132 .97343 L p F P
0 g
s
.711 .742 .876 r
.71962 .25638 m .69865 .26642 L .70354 .27375 L p F P
0 g
s
.711 .742 .876 r
.70354 .27375 m .72444 .26359 L .71962 .25638 L p F P
0 g
s
.764 .752 .842 r
.69025 .27227 m .69865 .26642 L .70354 .27375 L p F P
0 g
s
.842 .805 .315 r
.60012 .47977 m .59846 .48847 L .60164 .47831 L p F P
0 g
s
.842 .805 .315 r
.60164 .47831 m .60267 .46979 L .60012 .47977 L p F P
0 g
s
.368 .245 .578 r
.58872 .53656 m .57832 .5458 L .57726 .53555 L p F P
0 g
s
.368 .245 .578 r
.57726 .53555 m .58521 .52843 L .58872 .53656 L p F P
0 g
s
.271 .283 .689 r
.43792 .42843 m .44039 .4318 L p .43883 .41492 L F P
0 g
s
.13 .19 .658 r
.43792 .42843 m .44039 .4318 L .4397 .43487 L closepath p F P
0 g
s
.737 .695 .811 r
.46489 .76452 m .44469 .77768 L .43896 .76944 L p F P
0 g
s
.716 .688 .822 r
.49294 .76447 m .49076 .76116 L .48624 .76368 L closepath p F P
0 g
s
.615 .639 .851 r
.36169 .27584 m .36253 .27719 L .36009 .2778 L closepath p F P
0 g
s
.607 .54 .753 r
.66879 .82168 m .68435 .81613 L p .69311 .83047 L F P
0 g
s
.612 .559 .771 r
.66879 .82168 m .66764 .81882 L .68435 .81613 L closepath p F P
0 g
s
.822 .745 .779 r
.64337 .31529 m .63751 .32187 L .64265 .32997 L p F P
0 g
s
.859 .749 .74 r
.6337 .32747 m .63751 .32187 L .64265 .32997 L p F P
0 g
s
.859 .749 .74 r
.64265 .32997 m .64001 .33396 L .6337 .32747 L p F P
0 g
s
.803 .652 .695 r
.36727 .86451 m .35956 .86201 L p .36378 .87755 L F P
0 g
s
.8 .667 .716 r
.36727 .86451 m .36327 .85657 L .35956 .86201 L closepath p F P
0 g
s
.607 .309 .439 r
.58319 .96471 m .60666 .96223 L .60496 .97102 L p F P
0 g
s
.607 .309 .439 r
.58266 .96748 m .58319 .96471 L p .60496 .97102 L F P
0 g
s
.869 .766 .746 r
.6305 .3635 m .62477 .35689 L .63247 .34539 L p F P
0 g
s
.865 .763 .748 r
.6279 .36739 m .6305 .3635 L .62477 .35689 L p F P
0 g
s
.968 .647 .328 r
.46077 .51206 m .45978 .50347 L .46541 .51483 L p F P
0 g
s
.968 .647 .328 r
.46541 .51483 m .46584 .51855 L .46077 .51206 L p F P
0 g
s
.946 .596 .201 r
.45976 .50335 m .45978 .50347 L .46541 .51483 L p F P
0 g
s
.965 .824 .654 r
.61338 .41284 m .61313 .41352 L .6166 .42073 L p F P
0 g
s
.968 .823 .647 r
.6095 .42373 m .61275 .43099 L .6166 .42073 L p F P
0 g
s
.968 .823 .647 r
.6166 .42073 m .61313 .41352 L .6095 .42373 L p F P
0 g
s
.918 .792 .705 r
.61387 .39585 m .61839 .40278 L .6237 .39206 L p F P
0 g
s
.918 .792 .705 r
.6237 .39206 m .61912 .38514 L .61387 .39585 L p F P
0 g
s
.818 .904 .901 r
.7516 .50651 m .74972 .50519 L .75271 .50287 L closepath p F P
0 g
s
.119 .178 .65 r
.44039 .4318 m .4397 .43487 L .44325 .44802 L p F P
0 g
s
.099 .164 .644 r
.44321 .44819 m .44325 .44802 L .4397 .43487 L p F P
0 g
s
.431 .404 .728 r
.43017 .39191 m .4396 .3796 L .42875 .37495 L p F P
0 g
s
.455 .386 .69 r
.43859 .39752 m .43017 .39191 L .4396 .3796 L p F P
0 g
s
.989 .891 .593 r
.60548 .45151 m .60613 .45955 L .61022 .44915 L p F P
0 g
s
.989 .891 .593 r
.61022 .44915 m .60905 .44125 L .60548 .45151 L p F P
0 g
s
.612 .559 .771 r
.68435 .81613 m .66764 .81882 L .66229 .8054 L p F P
0 g
s
.338 .53 .896 r
.79001 .28881 m .78654 .2877 L .7819 .27996 L p F P
0 g
s
.754 .471 .503 r
.44536 .96213 m .42982 .95992 L .42743 .95015 L p F P
0 g
s
.759 .475 .502 r
.41909 .94886 m .42743 .95015 L .42982 .95992 L p F P
0 g
s
.745 .864 .935 r
.6709 .54926 m .6831 .54263 L .67826 .53889 L p F P
0 g
s
.745 .864 .935 r
.67826 .53889 m .677 .53957 L .6709 .54926 L p F P
0 g
s
.733 .846 .934 r
.65748 .54949 m .677 .53957 L .6709 .54926 L p F P
0 g
s
.977 .919 .619 r
.82443 .40609 m .82111 .40641 L .82419 .39892 L closepath p F P
0 g
s
.801 .592 .619 r
.38409 .92057 m .37454 .91813 L .37739 .90717 L p F P
0 g
s
.808 .599 .619 r
.3655 .90388 m .37739 .90717 L .37454 .91813 L p F P
0 g
s
.799 .611 .647 r
.36971 .8926 m .3655 .90388 L .37739 .90717 L p F P
0 g
s
.113 .28 .756 r
.24702 .44896 m .24627 .44033 L .23901 .43442 L p F P
0 g
s
.24 .379 .803 r
.25577 .45442 m .24702 .44896 L .24627 .44033 L p F P
0 g
s
.183 .356 .802 r
.25685 .46285 m .25577 .45442 L .24702 .44896 L p F P
0 g
s
.768 .866 .921 r
.29022 .26699 m .28396 .2771 L .27868 .27428 L closepath p F P
0 g
s
.791 .871 .907 r
.26407 .28553 m .27868 .27428 L .28396 .2771 L p F P
0 g
s
.791 .871 .907 r
.26159 .29067 m .26407 .28553 L p .28396 .2771 L F P
0 g
s
.531 .66 .918 r
.76432 .27185 m .75525 .27219 L .75055 .26498 L p F P
0 g
s
.578 .551 .789 r
.39937 .30968 m .41881 .30823 L p .40889 .2943 L F P
0 g
s
.578 .551 .789 r
.40889 .2943 m .3971 .30444 L .39937 .30968 L p F P
0 g
s
.032 .189 .695 r
.23901 .43442 m .23865 .42556 L .23279 .4192 L p F P
0 g
s
.179 .308 .759 r
.24627 .44033 m .23901 .43442 L .23865 .42556 L p F P
0 g
s
.49 .641 .923 r
.36141 .53496 m .34796 .53464 L .34472 .52743 L p F P
0 g
s
.483 .646 .93 r
.34796 .53464 m .36141 .53496 L .36746 .54201 L p F P
0 g
s
.581 .456 .674 r
.68924 .8908 m .6865 .87831 L .70637 .87176 L p F P
0 g
s
.589 .479 .697 r
.70529 .86768 m .70637 .87176 L .6865 .87831 L p F P
0 g
s
.553 .697 .935 r
.41274 .54611 m .39298 .54815 L .39894 .5546 L p F P
0 g
s
.553 .697 .935 r
.39894 .5546 m .41867 .55258 L .41274 .54611 L p F P
0 g
s
.522 .683 .939 r
.38151 .54873 m .39298 .54815 L .39894 .5546 L p F P
0 g
s
.802 .67 .718 r
.36327 .85657 m .368 .84967 L .3579 .84624 L closepath p F P
0 g
s
.795 .682 .74 r
.35745 .84548 m .36706 .83319 L p .368 .84967 L F P
0 g
s
.795 .682 .74 r
.368 .84967 m .3579 .84624 L .35745 .84548 L p F P
0 g
s
.792 .751 .815 r
.46232 .56324 m .47634 .55338 L .47069 .54399 L p F P
0 g
s
.792 .751 .815 r
.47069 .54399 m .45504 .55765 L .46232 .56324 L p F P
0 g
s
.713 .76 .889 r
.45037 .56013 m .45504 .55765 L .46232 .56324 L p F P
0 g
s
.811 .623 .648 r
.35824 .88915 m .36971 .8926 L .3655 .90388 L p F P
0 g
s
.801 .632 .672 r
.36378 .87755 m .35824 .88915 L .36971 .8926 L p F P
0 g
s
.788 .559 .589 r
.39878 .93474 m .38548 .93189 L .38697 .92124 L p F P
0 g
s
.794 .565 .589 r
.38409 .92057 m .38697 .92124 L .38548 .93189 L p F P
0 g
s
.912 .938 .812 r
.79692 .45277 m .79608 .46101 L .80569 .44865 L p F P
0 g
s
.912 .938 .812 r
.80608 .44086 m .79692 .45277 L p .80569 .44865 L F P
0 g
s
.912 .938 .812 r
.80569 .44865 m .80639 .44103 L .80608 .44086 L p F P
0 g
s
.633 .603 .801 r
.65168 .78161 m .63086 .78672 L .62554 .77558 L p F P
0 g
s
.725 .684 .811 r
.46489 .76452 m .47005 .76135 L .48624 .76368 L p F P
0 g
s
.718 .692 .825 r
.48514 .75282 m .47005 .76135 L .48624 .76368 L p F P
0 g
s
.718 .692 .825 r
.48624 .76368 m .49076 .76116 L .48514 .75282 L p F P
0 g
s
.714 .832 .938 r
.65748 .54949 m .63678 .55911 L .63172 .55472 L p F P
0 g
s
.859 .749 .74 r
.6337 .32747 m .64001 .33396 L .63247 .34539 L p F P
0 g
s
.292 .439 .838 r
.26196 .46525 m .25685 .46285 L .25577 .45442 L p F P
0 g
s
.268 .431 .839 r
.25685 .46285 m .26196 .46525 L .26806 .47576 L p F P
0 g
s
.526 .677 .933 r
.39298 .54815 m .38151 .54873 L .37734 .54195 L p F P
0 g
s
.865 .763 .748 r
.62477 .35689 m .62273 .35992 L .6279 .36739 L p F P
0 g
s
.896 .76 .704 r
.61871 .36784 m .62273 .35992 L .6279 .36739 L p F P
0 g
s
.896 .76 .704 r
.6279 .36739 m .62438 .37445 L .61871 .36784 L p F P
0 g
s
.869 .715 .689 r
.47069 .54399 m .47099 .54319 L .47856 .54872 L p F P
0 g
s
.869 .715 .689 r
.47856 .54872 m .47634 .55338 L .47069 .54399 L p F P
0 g
s
.625 .643 .848 r
.36253 .27719 m .38211 .27265 L p .37571 .26212 L F P
0 g
s
.625 .643 .848 r
.37571 .26212 m .36169 .27584 L .36253 .27719 L p F P
0 g
s
.251 .429 .843 r
.26806 .47576 m .26863 .47604 L .26885 .47708 L closepath p F P
0 g
s
.72 .404 .443 r
.47629 .97383 m .46778 .97305 L .46237 .96395 L p F P
0 g
s
.722 .397 .429 r
.44928 .96264 m .46237 .96395 L .46778 .97305 L p F P
0 g
s
.875 .685 .161 r
.82653 .36344 m .82775 .37136 L .82779 .36235 L p F P
0 g
s
.875 .685 .161 r
.82779 .36235 m .82659 .35442 L .82653 .36344 L p F P
0 g
s
.651 .628 .814 r
.62022 .76532 m .59956 .77168 L .5942 .76154 L p F P
0 g
s
.84 .945 .89 r
.26407 .28553 m .26159 .29067 L .25855 .29031 L closepath p F P
0 g
s
.87 .946 .862 r
.2499 .2993 m .25855 .29031 L .26159 .29067 L p F P
0 g
s
.579 .361 .549 r
.65204 .94541 m .6519 .93522 L .67316 .93043 L p F P
0 g
s
.6 .378 .551 r
.6519 .93522 m .65204 .94541 L .63009 .94944 L p F P
0 g
s
.592 .399 .588 r
.67229 .91965 m .67316 .93043 L .6519 .93522 L p F P
0 g
s
.898 .893 .473 r
.60568 .46252 m .60401 .46518 L .60613 .45955 L closepath p F P
0 g
s
.088 .15 .633 r
.44325 .44802 m .44335 .4484 L .44321 .44819 L closepath p F P
0 g
s
.046 .132 .631 r
.44321 .44819 m .44335 .4484 L .44692 .46133 L p F P
0 g
s
.666 .653 .827 r
.58883 .75205 m .59311 .75951 L .5705 .76325 L p F P
0 g
s
.666 .653 .827 r
.5705 .76325 m .56828 .75944 L .58883 .75205 L p F P
0 g
s
.428 .579 .901 r
.30492 .50836 m .31869 .51062 L p .29912 .50005 L F P
0 g
s
.428 .579 .901 r
.29912 .50005 m .29931 .50076 L .30492 .50836 L p F P
0 g
s
.584 .333 .502 r
.62942 .95901 m .63009 .94944 L .65204 .94541 L p F P
0 g
s
.119 .178 .65 r
.44325 .44802 m .44527 .43889 L .44039 .4318 L p F P
0 g
s
.093 .153 .634 r
.44527 .43889 m .44325 .44802 L .44335 .4484 L p F P
0 g
s
.093 .153 .634 r
.44335 .4484 m .44694 .45574 L p .44527 .43889 L F P
0 g
s
0 0 .549 r
.44335 .4484 m .44694 .45574 L .44692 .46133 L closepath p F P
0 g
s
.619 .734 .928 r
.42457 .5588 m .43381 .55662 L .44009 .56258 L p F P
0 g
s
.621 .733 .926 r
.44455 .55399 m .43381 .55662 L .44009 .56258 L p F P
0 g
s
.621 .733 .926 r
.44009 .56258 m .45037 .56013 L .44455 .55399 L p F P
0 g
s
.646 .754 .928 r
.58517 .56303 m .60582 .55707 L .61103 .56282 L p F P
0 g
s
.645 .659 .849 r
.58459 .56208 m .58517 .56303 L .60582 .55707 L p F P
0 g
s
.696 .675 .825 r
.53694 .7498 m .51659 .75931 L .51104 .75065 L p F P
0 g
s
.781 .7 .774 r
.38175 .80231 m .39274 .80611 L .37874 .81997 L p F P
0 g
s
.772 .702 .786 r
.39261 .79253 m .38175 .80231 L .39274 .80611 L p F P
0 g
s
.772 .702 .786 r
.39274 .80611 m .39846 .80103 L .39261 .79253 L p F P
0 g
s
.83 .845 .382 r
.22708 .34766 m .22834 .34196 L .23181 .33235 L p F P
0 g
s
.73 .685 .141 r
.22499 .36095 m .22572 .35583 L .22708 .34766 L p F P
0 g
s
0 0 0 r
.22834 .34196 m .22708 .34766 L .22572 .35583 L p F P
0 g
s
.267 .427 .836 r
.26743 .46773 m .26196 .46525 L .26806 .47576 L p F P
0 g
s
.267 .427 .836 r
.26806 .47576 m .26863 .47604 L .26743 .46773 L p F P
0 g
s
.77 .699 .785 r
.40945 .79147 m .39846 .80103 L .39261 .79253 L p F P
0 g
s
0 .077 .613 r
.23279 .4192 m .23285 .41009 L .22837 .40329 L p F P
0 g
s
.108 .224 .703 r
.23865 .42556 m .23279 .4192 L .23285 .41009 L p F P
0 g
s
.624 .642 .847 r
.35657 .26753 m .37571 .26212 L .36169 .27584 L closepath p F P
0 g
s
.794 .565 .589 r
.38548 .93189 m .38461 .93169 L .38409 .92057 L p F P
0 g
s
.803 .571 .587 r
.37454 .91813 m .38409 .92057 L .38461 .93169 L p F P
0 g
s
.71 .686 .826 r
.51104 .75065 m .49076 .76116 L .48514 .75282 L p F P
0 g
s
.813 .644 .673 r
.35271 .87394 m .36378 .87755 L .35824 .88915 L p F P
0 g
s
.803 .652 .695 r
.35956 .86201 m .35271 .87394 L .36378 .87755 L p F P
0 g
s
.577 .549 .787 r
.39368 .29647 m .40889 .2943 L .3971 .30444 L closepath p F P
0 g
s
.792 .883 .912 r
.73121 .51909 m .72915 .5205 L .72453 .51695 L p F P
0 g
s
.935 .698 .555 r
.46777 .54012 m .47099 .54319 L .47239 .53358 L p F P
0 g
s
.935 .698 .555 r
.465 .53515 m .46777 .54012 L p .47239 .53358 L F P
0 g
s
.935 .698 .555 r
.47239 .53358 m .46601 .52759 L .465 .53515 L p F P
0 g
s
.77 .699 .785 r
.39261 .79253 m .39799 .78778 L .40945 .79147 L p F P
0 g
s
.759 .704 .8 r
.41291 .7759 m .39799 .78778 L .40945 .79147 L p F P
0 g
s
.759 .704 .8 r
.40945 .79147 m .41872 .78419 L .41291 .7759 L p F P
0 g
s
.781 .526 .55 r
.41274 .94771 m .39899 .945 L .39878 .93474 L p F P
0 g
s
.788 .531 .549 r
.38548 .93189 m .39878 .93474 L .39899 .945 L p F P
0 g
s
.682 .664 .826 r
.56286 .75028 m .54242 .75873 L .53694 .7498 L p F P
0 g
s
.569 .559 .803 r
.57976 .55134 m .59918 .55041 L .58459 .56208 L closepath p F P
0 g
s
.645 .659 .849 r
.60054 .55015 m .59918 .55041 L .58459 .56208 L p F P
0 g
s
.645 .659 .849 r
.60582 .55707 m .60054 .55015 L p .58459 .56208 L F P
0 g
s
.815 .903 .903 r
.73121 .51909 m .74972 .50519 L .74521 .50182 L p F P
0 g
s
.815 .903 .903 r
.74521 .50182 m .73394 .51041 L .73121 .51909 L p F P
0 g
s
.792 .883 .912 r
.72453 .51695 m .73394 .51041 L .73121 .51909 L p F P
0 g
s
.79 .69 .755 r
.37809 .8207 m .37874 .81997 L .37733 .81948 L closepath p F P
0 g
s
.781 .7 .774 r
.3722 .81191 m .38175 .80231 L p .37874 .81997 L F P
0 g
s
.781 .7 .774 r
.37874 .81997 m .37733 .81948 L .3722 .81191 L p F P
0 g
s
.352 .489 .856 r
.28119 .48031 m .26863 .47604 L .26743 .46773 L p F P
0 g
s
.334 .495 .87 r
.28272 .48843 m .28119 .48031 L .26863 .47604 L p F P
0 g
s
.136 0 .413 r
.59129 .5211 m .58521 .52843 L .58589 .51899 L p F P
0 g
s
.136 0 .413 r
.58589 .51899 m .59144 .51233 L .59129 .5211 L p F P
0 g
s
.791 .69 .753 r
.36706 .83319 m .37809 .8207 L .37733 .81948 L p F P
0 g
s
.803 .671 .718 r
.35956 .86201 m .36327 .85657 L .3579 .84624 L p F P
0 g
s
.759 .475 .502 r
.42982 .95992 m .41706 .95797 L .41909 .94886 L p F P
0 g
s
.772 .488 .504 r
.41274 .94771 m .41909 .94886 L .41706 .95797 L p F P
0 g
s
.685 .766 .913 r
.62026 .55928 m .61103 .56282 L .60582 .55707 L p F P
0 g
s
.626 .566 .767 r
.66229 .8054 m .66177 .80553 L .66228 .80537 L closepath p F P
0 g
s
.63 .584 .784 r
.65699 .79324 m .66228 .80537 L .66177 .80553 L p F P
0 g
s
0 0 .216 r
.59382 .50836 m .59144 .51233 L .5923 .50448 L p F P
0 g
s
0 0 .216 r
.5923 .50448 m .59576 .49852 L .59382 .50836 L p F P
0 g
s
.612 .559 .771 r
.66229 .8054 m .68335 .8021 L p .68435 .81613 L F P
0 g
s
.61 .557 .77 r
.68179 .79819 m .68335 .8021 L .66229 .8054 L p F P
0 g
s
.61 .557 .77 r
.66229 .8054 m .66228 .80537 L .68179 .79819 L p F P
0 g
s
.615 .577 .788 r
.67804 .78959 m .68179 .79819 L .66228 .80537 L p F P
0 g
s
.615 .577 .788 r
.66228 .80537 m .65699 .79324 L .67804 .78959 L p F P
0 g
s
.595 .499 .716 r
.69961 .84734 m .68829 .84836 L .69885 .84475 L closepath p F P
0 g
s
.602 .521 .735 r
.6941 .83036 m .69885 .84475 L .68829 .84836 L p F P
0 g
s
.602 .521 .735 r
.69311 .83047 m .6941 .83036 L p .68829 .84836 L F P
0 g
s
.907 .952 .609 r
.23181 .33235 m .23456 .32175 L p .23951 .31401 L F P
0 g
s
.795 .825 .351 r
.23456 .32175 m .23181 .33235 L .22834 .34196 L p F P
0 g
s
0 0 .524 r
.44694 .45574 m .44692 .46133 L .44878 .4684 L p F P
0 g
s
.607 .309 .439 r
.60496 .97102 m .59261 .97232 L .58266 .96748 L p F P
0 g
s
.608 .306 .431 r
.59261 .97232 m .58132 .97343 L .58266 .96748 L closepath p F P
0 g
s
0 0 .147 r
.22572 .35583 m .22499 .36095 L .22512 .36923 L p F P
0 g
s
.756 .701 .8 r
.42977 .77579 m .41872 .78419 L .41291 .7759 L p F P
0 g
s
.976 .692 .42 r
.46077 .51206 m .46584 .51855 L .46601 .52759 L p F P
0 g
s
.504 .656 .928 r
.37389 .53485 m .36141 .53496 L .36746 .54201 L p F P
0 g
s
.504 .656 .928 r
.36746 .54201 m .37734 .54195 L .37389 .53485 L p F P
0 g
s
.791 .69 .753 r
.37733 .81948 m .36805 .81611 L p .36706 .83319 L F P
0 g
s
.786 .701 .771 r
.37733 .81948 m .3722 .81191 L .36805 .81611 L closepath p F P
0 g
s
.727 .691 .816 r
.46489 .76452 m .47005 .76135 L .46185 .75995 L closepath p F P
0 g
s
.737 .695 .811 r
.46185 .75995 m .46489 .76452 L p .43896 .76944 L F P
0 g
s
.891 .935 .838 r
.78615 .46504 m .79692 .45277 L .79608 .46101 L p F P
0 g
s
.891 .935 .838 r
.79608 .46101 m .79037 .46739 L .78615 .46504 L p F P
0 g
s
.475 .442 .741 r
.42875 .37495 m .43713 .36536 L p .42769 .3578 L F P
0 g
s
.447 .394 .706 r
.43713 .36536 m .42875 .37495 L .4396 .3796 L p F P
0 g
s
.783 .736 .809 r
.65767 .29877 m .66915 .28861 L .66237 .28216 L p F P
0 g
s
.783 .736 .809 r
.66237 .28216 m .65257 .29058 L .65767 .29877 L p F P
0 g
s
.825 .742 .773 r
.64756 .29622 m .65257 .29058 L .65767 .29877 L p F P
0 g
s
.825 .742 .773 r
.65767 .29877 m .65436 .30264 L .64756 .29622 L p F P
0 g
s
.46 .613 .915 r
.34212 .51994 m .32996 .51905 L .33608 .52674 L p F P
0 g
s
.46 .613 .915 r
.33608 .52674 m .34472 .52743 L .34212 .51994 L p F P
0 g
s
.447 .609 .916 r
.32119 .5182 m .32996 .51905 L .33608 .52674 L p F P
0 g
s
.338 .53 .896 r
.7819 .27996 m .78645 .28135 L .79001 .28881 L p F P
0 g
s
.218 .447 .868 r
.79687 .28638 m .80034 .29388 L .79001 .28881 L p F P
0 g
s
.218 .447 .868 r
.79001 .28881 m .78645 .28135 L .79687 .28638 L p F P
0 g
s
.571 .383 .587 r
.67316 .93043 m .67229 .91965 L .69291 .91407 L p F P
0 g
s
.583 .415 .62 r
.69138 .90271 m .69291 .91407 L .67229 .91965 L p F P
0 g
s
.457 .606 .91 r
.32996 .51905 m .32119 .5182 L .31869 .51062 L p F P
0 g
s
.761 .861 .923 r
.70382 .53058 m .6831 .54263 L .67826 .53889 L p F P
0 g
s
.722 .397 .429 r
.44774 .96704 m .44928 .96264 L p .46778 .97305 L F P
0 g
s
.74 .427 .451 r
.44774 .96704 m .44536 .96213 L .44928 .96264 L closepath p F P
0 g
s
.795 .744 .806 r
.67803 .2805 m .66915 .28861 L .66237 .28216 L p F P
0 g
s
.738 .498 0 r
.82495 .34656 m .82659 .35442 L .82514 .34596 L p F P
0 g
s
.738 .498 0 r
.82514 .34596 m .82351 .33809 L .82495 .34656 L p F P
0 g
s
.749 .737 .841 r
.67803 .2805 m .69025 .27227 L .68379 .26566 L p F P
0 g
s
.749 .737 .841 r
.68379 .26566 m .67301 .27273 L .67803 .2805 L p F P
0 g
s
.795 .744 .806 r
.66237 .28216 m .67301 .27273 L .67803 .2805 L p F P
0 g
s
.668 .655 .828 r
.58883 .75205 m .56828 .75944 L .56286 .75028 L p F P
0 g
s
0 0 .501 r
.22837 .40329 m .22888 .39391 L .22579 .38665 L p F P
0 g
s
.026 .126 .632 r
.23285 .41009 m .22837 .40329 L .22888 .39391 L p F P
0 g
s
0 0 .524 r
.44878 .4684 m .45007 .47203 L p .44694 .45574 L F P
0 g
s
0 0 .322 r
.44878 .4684 m .45007 .47203 L .45074 .47481 L closepath p F P
0 g
s
.573 .43 .648 r
.68924 .8908 m .70916 .88431 L p .7102 .89668 L F P
0 g
s
.573 .43 .648 r
.7102 .89668 m .69 .8951 L .68924 .8908 L p F P
0 g
s
.581 .456 .674 r
.70637 .87176 m .70916 .88431 L .68924 .8908 L p F P
0 g
s
.963 .934 .703 r
.81391 .42065 m .81396 .42873 L .81992 .4176 L p F P
0 g
s
.963 .934 .703 r
.81992 .4176 m .81984 .4095 L .81391 .42065 L p F P
0 g
s
.77 .87 .922 r
.70601 .53231 m .70382 .53058 L .70775 .52816 L closepath p F P
0 g
s
.982 .878 .518 r
.82344 .39095 m .82419 .39892 L .82705 .38888 L p F P
0 g
s
.982 .878 .518 r
.82705 .38888 m .82628 .3809 L .82344 .39095 L p F P
0 g
s
.594 .574 .8 r
.39368 .29647 m .40889 .2943 L p .39075 .28357 L F P
0 g
s
.594 .574 .8 r
.39075 .28357 m .38852 .2854 L .39368 .29647 L p F P
0 g
s
.897 .76 .702 r
.61871 .36784 m .62438 .37445 L .61912 .38514 L p F P
0 g
s
.271 .283 .689 r
.44039 .4318 m .44527 .4214 L .43883 .41492 L p F P
0 g
s
.225 .215 .637 r
.44527 .4214 m .44039 .4318 L .44527 .43889 L p F P
0 g
s
.814 .664 .697 r
.34888 .85824 m .35956 .86201 L .35271 .87394 L p F P
0 g
s
.803 .671 .718 r
.35709 .84595 m .34888 .85824 L .35956 .86201 L p F P
0 g
s
.803 .671 .718 r
.3579 .84624 m .35709 .84595 L p .35956 .86201 L F P
0 g
s
.823 .743 .775 r
.64756 .29622 m .65436 .30264 L .64337 .31529 L p F P
0 g
s
.674 .358 .431 r
.52994 .97572 m .50682 .97543 L .50513 .97361 L p F P
0 g
s
.677 .357 .426 r
.50682 .97543 m .50456 .97539 L .50513 .97361 L closepath p F P
0 g
s
.893 .939 .836 r
.7843 .47409 m .79037 .46739 L .78615 .46504 L p F P
0 g
s
.725 .408 0 r
.45976 .50335 m .45973 .50329 L .45476 .48853 L p F P
0 g
s
.822 .527 0 r
.45973 .50329 m .45978 .50347 L .45976 .50335 L closepath p F P
0 g
s
.802 .686 .736 r
.36706 .83319 m .35745 .84548 L .35154 .83579 L p F P
0 g
s
.802 .686 .736 r
.35154 .83579 m .35654 .82931 L .36706 .83319 L p F P
0 g
s
.791 .69 .753 r
.36805 .81611 m .35654 .82931 L .36706 .83319 L p F P
0 g
s
.756 .701 .8 r
.41291 .7759 m .41761 .77227 L .42977 .77579 L p F P
0 g
s
.746 .706 .814 r
.43318 .76135 m .41761 .77227 L .42977 .77579 L p F P
0 g
s
.746 .706 .814 r
.42977 .77579 m .43896 .76944 L .43318 .76135 L p F P
0 g
s
.9 .569 .083 r
.45973 .50329 m .45613 .49629 L .45443 .48787 L p F P
0 g
s
.9 .569 .083 r
.45443 .48787 m .45476 .48853 L .45973 .50329 L p F P
0 g
s
.949 .642 .205 r
.45613 .49629 m .45973 .50329 L .45978 .50347 L p F P
0 g
s
.585 .291 .436 r
.60496 .97102 m .60666 .96223 L .6265 .95943 L p F P
0 g
s
.949 .642 .205 r
.45978 .50347 m .46077 .51206 L p .45613 .49629 L F P
0 g
s
.653 .695 .877 r
.34439 .25046 m .32468 .25829 L .33092 .26548 L p F P
0 g
s
.653 .695 .877 r
.33092 .26548 m .35052 .2586 L .34439 .25046 L p F P
0 g
s
.92 .798 .709 r
.60857 .40662 m .61387 .39585 L .61839 .40278 L p F P
0 g
s
.92 .798 .709 r
.61087 .4102 m .60857 .40662 L p .61839 .40278 L F P
0 g
s
.92 .798 .709 r
.61839 .40278 m .61338 .41284 L .61087 .4102 L p F P
0 g
s
.721 .701 .83 r
.47949 .7446 m .48514 .75282 L .47005 .76135 L p F P
0 g
s
.721 .701 .83 r
.4592 .75623 m .47949 .7446 L p .47005 .76135 L F P
0 g
s
.721 .701 .83 r
.47005 .76135 m .46185 .75995 L .4592 .75623 L p F P
0 g
s
.859 .749 .74 r
.63247 .34539 m .62583 .33903 L .6337 .32747 L p F P
0 g
s
.854 .742 .74 r
.62583 .33903 m .63247 .34539 L .62477 .35689 L p F P
0 g
s
.745 .423 .437 r
.44536 .96213 m .44774 .96704 L .44616 .97084 L p F P
0 g
s
.745 .423 .437 r
.42982 .95992 m .44536 .96213 L p .44616 .97084 L F P
0 g
s
.817 .896 .898 r
.75271 .50287 m .74972 .50519 L .74521 .50182 L p F P
0 g
s
.772 .488 .504 r
.41706 .95797 m .4148 .95756 L .41274 .94771 L p F P
0 g
s
.779 .491 .5 r
.39899 .945 m .41274 .94771 L .4148 .95756 L p F P
0 g
s
.697 .763 .903 r
.31833 .25194 m .29855 .26201 L .30504 .26723 L p F P
0 g
s
.697 .763 .903 r
.30504 .26723 m .32468 .25829 L .31833 .25194 L p F P
0 g
s
.862 .517 .007 r
.45425 .48716 m .45443 .48787 L .45476 .48853 L closepath p F P
0 g
s
.836 .906 .886 r
.75466 .49439 m .75271 .50287 L .77015 .48795 L p F P
0 g
s
.817 .896 .898 r
.74521 .50182 m .75466 .49439 L .75271 .50287 L p F P
0 g
s
.718 .702 .167 r
.59805 .48963 m .59576 .49852 L .59846 .48847 L p F P
0 g
s
.718 .702 .167 r
.59846 .48847 m .60012 .47977 L .59805 .48963 L p F P
0 g
s
.62 .731 .926 r
.42838 .55033 m .41867 .55258 L .42457 .5588 L p F P
0 g
s
.62 .731 .926 r
.42457 .5588 m .43381 .55662 L .42838 .55033 L p F P
0 g
s
.893 .939 .836 r
.78615 .46504 m .78551 .46576 L .7843 .47409 L p F P
0 g
s
.866 .928 .864 r
.77156 .4796 m .78551 .46576 L .7843 .47409 L p F P
0 g
s
.866 .928 .864 r
.77015 .48791 m .77156 .4796 L p .7843 .47409 L F P
0 g
s
.866 .928 .864 r
.7843 .47409 m .77017 .48792 L .77015 .48791 L p F P
0 g
s
.391 .533 .879 r
.2926 .49088 m .28272 .48843 L .28119 .48031 L p F P
0 g
s
.375 .532 .884 r
.28272 .48843 m .2926 .49088 L .29875 .49996 L p F P
0 g
s
.571 .469 .7 r
.59515 .53931 m .58872 .53656 L .57832 .5458 L p F P
0 g
s
.571 .469 .7 r
.60015 .54952 m .59515 .53931 L p .57832 .5458 L F P
0 g
s
.571 .469 .7 r
.59918 .55041 m .60015 .54952 L p .57832 .5458 L F P
0 g
s
.571 .469 .7 r
.57832 .5458 m .57976 .55134 L .59918 .55041 L p F P
0 g
s
.975 .83 .636 r
.60604 .43392 m .60905 .44125 L .61275 .43099 L p F P
0 g
s
.975 .83 .636 r
.61275 .43099 m .6095 .42373 L .60604 .43392 L p F P
0 g
s
.633 .603 .801 r
.62554 .77558 m .64638 .77044 L .65168 .78161 L p F P
0 g
s
.633 .603 .802 r
.64561 .76882 m .64638 .77044 L .62554 .77558 L p F P
0 g
s
.633 .603 .802 r
.62554 .77558 m .62537 .77522 L .64561 .76882 L p F P
0 g
s
.637 .62 .817 r
.64109 .76005 m .64561 .76882 L .62537 .77522 L p F P
0 g
s
.637 .62 .817 r
.62537 .77522 m .62022 .76532 L .64109 .76005 L p F P
0 g
s
.965 .913 .561 r
.60204 .46176 m .60548 .45151 L .60613 .45955 L p F P
0 g
s
.965 .913 .561 r
.60224 .467 m .60204 .46176 L p .60613 .45955 L F P
0 g
s
.965 .913 .561 r
.60613 .45955 m .60401 .46518 L .60224 .467 L p F P
0 g
s
.573 .431 .649 r
.69138 .90271 m .69 .8951 L .7102 .89668 L closepath p F P
0 g
s
0 0 .373 r
.82214 .33289 m .82351 .33809 L .8204 .33026 L p F P
0 g
s
0 0 .373 r
.82031 .32731 m .82214 .33289 L p .8204 .33026 L F P
0 g
s
0 0 .373 r
.8204 .33026 m .81834 .32246 L .82031 .32731 L p F P
0 g
s
.019 .28 .778 r
.8078 .30005 m .81077 .30767 L .80336 .30148 L p F P
0 g
s
.019 .28 .778 r
.80336 .30148 m .80034 .29388 L .8078 .30005 L p F P
0 g
s
.862 .929 .869 r
.77017 .48792 m .77015 .48795 L .77015 .48791 L closepath p F P
0 g
s
.836 .906 .886 r
.76578 .48472 m .75466 .49439 L p .77015 .48795 L F P
0 g
s
.836 .906 .886 r
.77015 .48795 m .77015 .48791 L .76578 .48472 L p F P
0 g
s
.845 .906 .878 r
.77015 .48791 m .76578 .48472 L .77156 .4796 L closepath p F P
0 g
s
0 0 .268 r
.45443 .48787 m .45254 .48014 L .45007 .47203 L p F P
0 g
s
.737 .478 0 r
.45254 .48014 m .45443 .48787 L .45613 .49629 L p F P
0 g
s
.737 .695 .811 r
.43896 .76944 m .45536 .75856 L .46185 .75995 L p F P
0 g
s
.741 .702 .815 r
.45536 .75856 m .43896 .76944 L .43318 .76135 L p F P
0 g
s
.624 .265 .341 r
.5313 .97573 m .55684 .97505 L .55348 .98269 L p F P
0 g
s
.624 .265 .341 r
.53099 .97652 m .5313 .97573 L p .55348 .98269 L F P
0 g
s
.655 .35 .444 r
.55688 .97494 m .55684 .97505 L .5313 .97573 L p F P
0 g
s
.656 .315 .383 r
.53099 .97652 m .52994 .97572 L .5313 .97573 L closepath p F P
0 g
s
.65 .288 .344 r
.52994 .97572 m .53099 .97652 L .52767 .98325 L p F P
0 g
s
.65 .288 .344 r
.50682 .97543 m .52994 .97572 L p .52767 .98325 L F P
0 g
s
.808 .599 .619 r
.37454 .91813 m .36265 .91484 L .3655 .90388 L p F P
0 g
s
.815 .606 .62 r
.35403 .90044 m .3655 .90388 L .36265 .91484 L p F P
0 g
s
.811 .623 .648 r
.3655 .90388 m .35403 .90044 L .35824 .88915 L p F P
0 g
s
0 .048 .615 r
.81656 .31697 m .81834 .32246 L .81329 .31537 L p F P
0 g
s
0 .048 .615 r
.81514 .31369 m .81656 .31697 L p .81329 .31537 L F P
0 g
s
0 .048 .615 r
.81329 .31537 m .81077 .30767 L .81514 .31369 L p F P
0 g
s
.759 .745 .84 r
.69865 .26642 m .69025 .27227 L .68379 .26566 L p F P
0 g
s
.823 .743 .775 r
.64337 .31529 m .63588 .30914 L .64756 .29622 L p F P
0 g
s
.808 .727 .775 r
.63751 .32187 m .64337 .31529 L .63588 .30914 L p F P
0 g
s
.803 .571 .587 r
.38461 .93169 m .37311 .92876 L .37454 .91813 L p F P
0 g
s
.81 .578 .587 r
.36265 .91484 m .37454 .91813 L .37311 .92876 L p F P
0 g
s
.69 .804 .936 r
.63172 .55472 m .62026 .55928 L .62822 .5514 L closepath p F P
0 g
s
.685 .766 .913 r
.6266 .54979 m .62822 .5514 L .62026 .55928 L p F P
0 g
s
.685 .766 .913 r
.60582 .55707 m .6266 .54979 L p .62026 .55928 L F P
0 g
s
.651 .628 .814 r
.5942 .76154 m .61489 .7551 L .62022 .76532 L p F P
0 g
s
.652 .631 .816 r
.6145 .75435 m .61489 .7551 L .5942 .76154 L p F P
0 g
s
.652 .631 .816 r
.5942 .76154 m .59311 .75951 L .6145 .75435 L p F P
0 g
s
.614 .576 .788 r
.67406 .78046 m .67804 .78959 L .65699 .79324 L p F P
0 g
s
.614 .576 .788 r
.65699 .79324 m .65464 .78785 L .67406 .78046 L p F P
0 g
s
.65 .288 .344 r
.52767 .98325 m .51848 .98313 L .50682 .97543 L p F P
0 g
s
.652 .284 .336 r
.50456 .97539 m .50682 .97543 L .51848 .98313 L p F P
0 g
s
.799 .683 .737 r
.3579 .84624 m .35745 .84548 L .35709 .84595 L closepath p F P
0 g
s
.635 .717 .907 r
.74108 .25074 m .71962 .25638 L .72444 .26359 L p F P
0 g
s
.635 .717 .907 r
.72444 .26359 m .74583 .25784 L .74108 .25074 L p F P
0 g
s
.652 .284 .336 r
.51848 .98313 m .5006 .98277 L .50456 .97539 L p F P
0 g
s
.675 .31 .347 r
.48652 .97444 m .50456 .97539 L .5006 .98277 L p F P
0 g
s
.531 .66 .918 r
.75055 .26498 m .75987 .2646 L .76432 .27185 L p F P
0 g
s
.485 .634 .92 r
.7726 .26512 m .75987 .2646 L .76432 .27185 L p F P
0 g
s
.485 .634 .92 r
.76432 .27185 m .77725 .27244 L .7726 .26512 L p F P
0 g
s
.73 .703 .825 r
.46185 .75995 m .4592 .75623 L .45536 .75856 L closepath p F P
0 g
s
.818 .631 .65 r
.3472 .88555 m .35824 .88915 L .35403 .90044 L p F P
0 g
s
.813 .644 .673 r
.35824 .88915 m .3472 .88555 L .35271 .87394 L p F P
0 g
s
0 0 .348 r
.22579 .38665 m .22679 .37699 L .22512 .36923 L p F P
0 g
s
0 .013 .545 r
.22888 .39391 m .22579 .38665 L .22679 .37699 L p F P
0 g
s
.803 .689 .739 r
.35709 .84595 m .35745 .84548 L .35154 .83579 L p F P
0 g
s
.509 .474 .753 r
.42769 .3578 m .43332 .35188 L p .42638 .3407 L F P
0 g
s
.483 .432 .724 r
.43332 .35188 m .43564 .3598 L .42769 .3578 L closepath p F P
0 g
s
.475 .442 .741 r
.43713 .36536 m .43564 .3598 L .42769 .3578 L p F P
0 g
s
.813 .681 .718 r
.34676 .84203 m .35709 .84595 L .34888 .85824 L p F P
0 g
s
.803 .689 .739 r
.35154 .83579 m .34676 .84203 L .35709 .84595 L p F P
0 g
s
.627 .319 .429 r
.58132 .97343 m .55704 .97504 L .55688 .97494 L p F P
0 g
s
.629 .316 .421 r
.55704 .97504 m .55684 .97505 L .55688 .97494 L closepath p F P
0 g
s
.294 .434 .832 r
.2668 .45912 m .25586 .45446 L .26196 .46525 L p F P
0 g
s
.294 .434 .832 r
.26196 .46525 m .26743 .46773 L .2668 .45912 L p F P
0 g
s
.292 .439 .838 r
.25577 .45442 m .25586 .45446 L .26196 .46525 L p F P
0 g
s
.624 .265 .341 r
.55348 .98269 m .54366 .98295 L .53099 .97652 L p F P
0 g
s
.625 .26 .33 r
.54366 .98295 m .52767 .98325 L .53099 .97652 L closepath p F P
0 g
s
.728 .763 .881 r
.45504 .55765 m .45037 .56013 L .44455 .55399 L p F P
0 g
s
.6 .242 .333 r
.55684 .97505 m .55704 .97504 L .57416 .98149 L p F P
0 g
s
.6 .242 .333 r
.57416 .98149 m .55348 .98269 L .55684 .97505 L p F P
0 g
s
.6 .249 .346 r
.55704 .97504 m .58132 .97343 L .57825 .98122 L p F P
0 g
s
.6 .249 .346 r
.57825 .98122 m .57416 .98149 L .55704 .97504 L p F P
0 g
s
.808 .727 .775 r
.63588 .30914 m .6323 .31301 L .63751 .32187 L p F P
0 g
s
.844 .729 .737 r
.62645 .32126 m .6323 .31301 L .63751 .32187 L p F P
0 g
s
.844 .729 .737 r
.63751 .32187 m .6337 .32747 L .62645 .32126 L p F P
0 g
s
.84 .948 .89 r
.25855 .29031 m .25317 .29084 L p .27005 .27343 L F P
0 g
s
.84 .948 .89 r
.27005 .27343 m .26407 .28553 L .25855 .29031 L p F P
0 g
s
.877 .968 .848 r
.25855 .29031 m .2499 .2993 L .25317 .29084 L closepath p F P
0 g
s
.365 .351 .711 r
.43883 .41492 m .44666 .40363 L p .43859 .39752 L F P
0 g
s
.342 .295 .66 r
.44666 .40363 m .43883 .41492 L .44527 .4214 L p F P
0 g
s
.788 .531 .549 r
.39899 .945 m .38563 .94216 L .38548 .93189 L p F P
0 g
s
.794 .537 .548 r
.38461 .93169 m .38548 .93189 L .38563 .94216 L p F P
0 g
s
.624 .641 .847 r
.37026 .25217 m .35052 .2586 L .35657 .26753 L p F P
0 g
s
.624 .641 .847 r
.37609 .26176 m .37026 .25217 L p .35657 .26753 L F P
0 g
s
.624 .641 .847 r
.35657 .26753 m .37571 .26212 L .37609 .26176 L p F P
0 g
s
.653 .646 .831 r
.60956 .74564 m .6145 .75435 L .59311 .75951 L p F P
0 g
s
.653 .646 .831 r
.59311 .75951 m .58883 .75205 L .60956 .74564 L p F P
0 g
s
.814 .912 .906 r
.27868 .27428 m .26407 .28553 L .27005 .27343 L p F P
0 g
s
.593 .572 .799 r
.38793 .28412 m .39075 .28357 L .38852 .2854 L closepath p F P
0 g
s
.708 .742 .878 r
.71477 .24913 m .69372 .25894 L .69865 .26642 L p F P
0 g
s
.708 .742 .878 r
.69865 .26642 m .71962 .25638 L .71477 .24913 L p F P
0 g
s
.759 .745 .84 r
.68379 .26566 m .69372 .25894 L .69865 .26642 L p F P
0 g
s
.794 .537 .548 r
.38563 .94216 m .38368 .94172 L .38461 .93169 L p F P
0 g
s
.804 .545 .547 r
.37311 .92876 m .38461 .93169 L .38368 .94172 L p F P
0 g
s
0 0 .524 r
.45007 .47203 m .45038 .46346 L .44694 .45574 L p F P
0 g
s
0 0 .422 r
.45038 .46346 m .45007 .47203 L .45254 .48014 L p F P
0 g
s
.373 .538 .89 r
.29875 .49996 m .29912 .50005 L .29931 .50076 L closepath p F P
0 g
s
.733 .836 .929 r
.677 .53957 m .65748 .54949 L .6525 .54516 L p F P
0 g
s
.714 .832 .938 r
.63172 .55472 m .6525 .54516 L .65748 .54949 L p F P
0 g
s
.893 .982 .807 r
.23951 .31401 m .24053 .31118 L .2499 .2993 L p F P
0 g
s
.866 .957 .613 r
.24053 .31118 m .23951 .31401 L .23743 .31627 L closepath p F P
0 g
s
.907 .952 .609 r
.23456 .32175 m .23743 .31627 L .23951 .31401 L p F P
0 g
s
.696 .675 .825 r
.51104 .75065 m .53143 .74095 L .53694 .7498 L p F P
0 g
s
.698 .681 .83 r
.53143 .74095 m .51104 .75065 L .50547 .7421 L p F P
0 g
s
.71 .686 .826 r
.48514 .75282 m .50547 .7421 L .51104 .75065 L p F P
0 g
s
.788 .704 .772 r
.38175 .80231 m .3722 .81191 L .36625 .80346 L p F P
0 g
s
.788 .704 .772 r
.36625 .80346 m .3713 .79832 L .38175 .80231 L p F P
0 g
s
.777 .708 .788 r
.38671 .78425 m .3713 .79832 L .38175 .80231 L p F P
0 g
s
.777 .708 .788 r
.38175 .80231 m .39261 .79253 L .38671 .78425 L p F P
0 g
s
.967 .814 .389 r
.82506 .373 m .82628 .3809 L .82775 .37136 L p F P
0 g
s
.967 .814 .389 r
.82775 .37136 m .82653 .36344 L .82506 .373 L p F P
0 g
s
.775 .707 .788 r
.39799 .78778 m .39261 .79253 L .38671 .78425 L p F P
0 g
s
.619 .595 .804 r
.67274 .77767 m .67406 .78046 L .65464 .78785 L p F P
0 g
s
.619 .595 .804 r
.65464 .78785 m .65168 .78161 L .67274 .77767 L p F P
0 g
s
.944 .932 .758 r
.80647 .43232 m .80643 .44041 L .81396 .42873 L p F P
0 g
s
.944 .932 .758 r
.81396 .42873 m .81391 .42065 L .80647 .43232 L p F P
0 g
s
.854 .742 .74 r
.62477 .35689 m .61776 .35068 L .62583 .33903 L p F P
0 g
s
.844 .734 .742 r
.62273 .35992 m .62477 .35689 L .61776 .35068 L p F P
0 g
s
.593 .573 .8 r
.40192 .26773 m .38211 .27265 L .38793 .28412 L p F P
0 g
s
.593 .573 .8 r
.40411 .2725 m .40192 .26773 L p .38793 .28412 L F P
0 g
s
.593 .573 .8 r
.38793 .28412 m .39075 .28357 L .40411 .2725 L p F P
0 g
s
.99 .877 .541 r
.60401 .46518 m .60267 .46979 L .60224 .467 L closepath p F P
0 g
s
.562 .401 .62 r
.69291 .91407 m .69138 .90271 L .7102 .89668 L p F P
0 g
s
.775 .707 .788 r
.38671 .78425 m .38711 .78389 L .39799 .78778 L p F P
0 g
s
.763 .71 .802 r
.40617 .76851 m .38711 .78389 L .39799 .78778 L p F P
0 g
s
.763 .71 .802 r
.40805 .76917 m .40617 .76851 L p .39799 .78778 L F P
0 g
s
.763 .71 .802 r
.39799 .78778 m .41291 .7759 L .40805 .76917 L p F P
0 g
s
.819 .652 .676 r
.34207 .87018 m .35271 .87394 L .3472 .88555 L p F P
0 g
s
.814 .664 .697 r
.35271 .87394 m .34207 .87018 L .34888 .85824 L p F P
0 g
s
.332 .535 .902 r
.78645 .28135 m .7819 .27996 L .77725 .27244 L p F P
0 g
s
.892 .989 .766 r
.25317 .29084 m .2499 .2993 L .24053 .31118 L p F P
0 g
s
.682 .664 .826 r
.53694 .7498 m .55741 .74119 L .56286 .75028 L p F P
0 g
s
.684 .669 .83 r
.55741 .74119 m .53694 .7498 L .53143 .74095 L p F P
0 g
s
.675 .31 .347 r
.5006 .98277 m .49642 .98255 L .48652 .97444 L p F P
0 g
s
.667 .281 .304 r
.47629 .97383 m .48652 .97444 L .49642 .98255 L p F P
0 g
s
.382 .534 .883 r
.29755 .49201 m .2926 .49088 L .29875 .49996 L p F P
0 g
s
.382 .534 .883 r
.29875 .49996 m .29912 .50005 L .29755 .49201 L p F P
0 g
s
.712 .693 .83 r
.50547 .7421 m .48514 .75282 L .47949 .7446 L p F P
0 g
s
.789 .707 .774 r
.36805 .81611 m .3722 .81191 L .36625 .80346 L p F P
0 g
s
.801 .752 .808 r
.45504 .55765 m .47069 .54399 L .46777 .54012 L p F P
0 g
s
.801 .752 .808 r
.44879 .55166 m .45504 .55765 L p .46777 .54012 L F P
0 g
s
.728 .763 .881 r
.44455 .55399 m .44879 .55166 L .45504 .55765 L p F P
0 g
s
.745 .423 .437 r
.44616 .97084 m .43455 .96918 L .42982 .95992 L p F P
0 g
s
.749 .419 .426 r
.41706 .95797 m .42982 .95992 L .43455 .96918 L p F P
0 g
s
.897 .76 .702 r
.61912 .38514 m .61333 .37858 L .61871 .36784 L p F P
0 g
s
.896 .758 .7 r
.61333 .37858 m .61912 .38514 L .61387 .39585 L p F P
0 g
s
.906 .738 .663 r
.47099 .54319 m .46777 .54012 L .47069 .54399 L closepath p F P
0 g
s
.77 .862 .918 r
.70775 .52816 m .70382 .53058 L .69905 .52662 L p F P
0 g
s
.761 .861 .923 r
.67826 .53889 m .69905 .52662 L .70382 .53058 L p F P
0 g
s
.439 .571 .89 r
.31682 .50275 m .29912 .50005 L .29755 .49201 L p F P
0 g
s
.428 .579 .901 r
.31869 .51062 m .31682 .50275 L .29912 .50005 L p F P
0 g
s
.795 .825 .351 r
.22834 .34196 m .2311 .33137 L .23456 .32175 L p F P
0 g
s
0 0 0 r
.2311 .33137 m .22834 .34196 L .22681 .35085 L p F P
0 g
s
0 0 0 r
.22572 .35583 m .22681 .35085 L .22834 .34196 L p F P
0 g
s
.607 .54 .753 r
.68435 .81613 m .6887 .81553 L p .69311 .83047 L F P
0 g
s
.605 .539 .754 r
.6887 .81553 m .68435 .81613 L .68839 .81468 L closepath p F P
0 g
s
.612 .559 .771 r
.68335 .8021 m .68839 .81468 L .68435 .81613 L p F P
0 g
s
.941 .785 .66 r
.61338 .41284 m .61313 .41352 L .61087 .4102 L closepath p F P
0 g
s
.8 .703 .757 r
.35788 .81207 m .36805 .81611 L .35654 .82931 L p F P
0 g
s
.789 .707 .774 r
.36625 .80346 m .35788 .81207 L .36805 .81611 L p F P
0 g
s
.6 .519 .735 r
.6941 .83036 m .69311 .83047 L .69403 .83015 L closepath p F P
0 g
s
.607 .54 .753 r
.6887 .81553 m .69403 .83015 L .69311 .83047 L p F P
0 g
s
.561 .313 .498 r
.65145 .95499 m .65204 .94541 L .67338 .94065 L p F P
0 g
s
.579 .361 .549 r
.67316 .93043 m .67338 .94065 L .65204 .94541 L p F P
0 g
s
.584 .333 .502 r
.65204 .94541 m .65145 .95499 L .62942 .95901 L p F P
0 g
s
.529 .664 .922 r
.75494 .25746 m .74583 .25784 L .75055 .26498 L p F P
0 g
s
.529 .664 .922 r
.75055 .26498 m .75987 .2646 L .75494 .25746 L p F P
0 g
s
.844 .729 .737 r
.62645 .32126 m .6337 .32747 L .62583 .33903 L p F P
0 g
s
.741 .702 .815 r
.43318 .76135 m .4422 .7553 L .45536 .75856 L p F P
0 g
s
.732 .709 .828 r
.45347 .74836 m .4422 .7553 L .45536 .75856 L p F P
0 g
s
.732 .709 .828 r
.45536 .75856 m .4592 .75623 L .45347 .74836 L p F P
0 g
s
.555 .69 .93 r
.40678 .53939 m .38697 .54143 L .39298 .54815 L p F P
0 g
s
.555 .69 .93 r
.39298 .54815 m .41274 .54611 L .40678 .53939 L p F P
0 g
s
.526 .677 .933 r
.37734 .54195 m .38697 .54143 L .39298 .54815 L p F P
0 g
s
.844 .734 .742 r
.61776 .35068 m .61747 .35109 L .62273 .35992 L p F P
0 g
s
.876 .733 .7 r
.61195 .36155 m .61747 .35109 L .62273 .35992 L p F P
0 g
s
.876 .733 .7 r
.62273 .35992 m .61871 .36784 L .61195 .36155 L p F P
0 g
s
.576 .488 .718 r
.69961 .84734 m .69885 .84475 L .71794 .83705 L p F P
0 g
s
.583 .511 .739 r
.71551 .8298 m .71794 .83705 L .69885 .84475 L p F P
0 g
s
.583 .511 .739 r
.69885 .84475 m .6941 .83036 L .71551 .8298 L p F P
0 g
s
.943 .784 .654 r
.60488 .41687 m .6095 .42373 L .61313 .41352 L p F P
0 g
s
.943 .784 .654 r
.60819 .40741 m .60488 .41687 L p .61313 .41352 L F P
0 g
s
.943 .784 .654 r
.61313 .41352 m .61087 .4102 L .60819 .40741 L p F P
0 g
s
.576 .488 .718 r
.71794 .83705 m .72109 .8476 L .69961 .84734 L p F P
0 g
s
.577 .49 .72 r
.70294 .85859 m .69961 .84734 L .72109 .8476 L p F P
0 g
s
.291 .205 .583 r
.59269 .53174 m .58872 .53656 L .58521 .52843 L p F P
0 g
s
.291 .205 .583 r
.58521 .52843 m .59129 .5211 L .59269 .53174 L p F P
0 g
s
.582 .509 .738 r
.71302 .82229 m .71551 .8298 L .6941 .83036 L p F P
0 g
s
.582 .509 .738 r
.6941 .83036 m .69403 .83015 L .71302 .82229 L p F P
0 g
s
.589 .531 .758 r
.71006 .81427 m .71302 .82229 L .69403 .83015 L p F P
0 g
s
.589 .531 .758 r
.69403 .83015 m .6887 .81553 L .71006 .81427 L p F P
0 g
s
0 0 .221 r
.22681 .35085 m .22572 .35583 L .22568 .36541 L p F P
0 g
s
0 0 .147 r
.22512 .36923 m .22568 .36541 L .22572 .35583 L p F P
0 g
s
.98 .914 .629 r
.81919 .40152 m .82344 .39095 L .82419 .39892 L p F P
0 g
s
.98 .914 .629 r
.81963 .40639 m .81919 .40152 L p .82419 .39892 L F P
0 g
s
.98 .914 .629 r
.82419 .39892 m .82111 .40641 L .81963 .40639 L p F P
0 g
s
.667 .281 .304 r
.47345 .97888 m .47629 .97383 L p .49642 .98255 L F P
0 g
s
.701 .34 .361 r
.47345 .97888 m .46778 .97305 L .47629 .97383 L closepath p F P
0 g
s
.722 .397 .429 r
.46778 .97305 m .45044 .97131 L .44774 .96704 L p F P
0 g
s
.726 .398 .424 r
.45044 .97131 m .44616 .97084 L .44774 .96704 L closepath p F P
0 g
s
.759 .709 .805 r
.41291 .7759 m .41761 .77227 L .40805 .76917 L closepath p F P
0 g
s
.768 .864 .92 r
.27868 .27428 m .2718 .27198 L p .29472 .25956 L F P
0 g
s
.768 .864 .92 r
.29472 .25956 m .29022 .26699 L .27868 .27428 L p F P
0 g
s
.814 .912 .906 r
.27005 .27343 m .2718 .27198 L .27868 .27428 L p F P
0 g
s
.588 .304 .452 r
.62922 .96032 m .6265 .95943 L .62942 .95901 L closepath p F P
0 g
s
.585 .291 .436 r
.6265 .95943 m .62922 .96032 L p .60496 .97102 L F P
0 g
s
.789 .88 .913 r
.70775 .52816 m .72453 .51695 L .71987 .51318 L p F P
0 g
s
.789 .88 .913 r
.71987 .51318 m .71062 .51942 L .70775 .52816 L p F P
0 g
s
.77 .862 .918 r
.69905 .52662 m .71062 .51942 L .70775 .52816 L p F P
0 g
s
.779 .491 .5 r
.4148 .95756 m .40104 .95485 L .39899 .945 L p F P
0 g
s
.784 .495 .497 r
.38563 .94216 m .39899 .945 L .40104 .95485 L p F P
0 g
s
.668 .655 .828 r
.56286 .75028 m .58344 .74278 L .58883 .75205 L p F P
0 g
s
.669 .657 .829 r
.58344 .74278 m .56286 .75028 L .55741 .74119 L p F P
0 g
s
.725 .703 .829 r
.47949 .7446 m .4592 .75623 L .45347 .74836 L p F P
0 g
s
.594 .574 .801 r
.40411 .2725 m .40768 .28018 L .39075 .28357 L closepath p F P
0 g
s
.594 .574 .8 r
.41239 .29131 m .40768 .28018 L .39075 .28357 L p F P
0 g
s
.594 .574 .8 r
.40889 .2943 m .41239 .29131 L p .39075 .28357 L F P
0 g
s
.572 .468 .698 r
.70294 .85859 m .72213 .85104 L p .7154 .86829 L F P
0 g
s
.572 .468 .698 r
.7154 .86829 m .70529 .86768 L .70294 .85859 L p F P
0 g
s
.577 .49 .72 r
.72109 .8476 m .72213 .85104 L .70294 .85859 L p F P
0 g
s
.556 .343 .547 r
.67338 .94065 m .67316 .93043 L .69384 .92488 L p F P
0 g
s
.571 .383 .587 r
.69291 .91407 m .69384 .92488 L .67316 .93043 L p F P
0 g
s
.751 .717 .82 r
.42737 .75344 m .43318 .76135 L .41761 .77227 L p F P
0 g
s
.751 .717 .82 r
.40705 .76787 m .42737 .75344 L p .41761 .77227 L F P
0 g
s
.751 .717 .82 r
.41761 .77227 m .40805 .76917 L .40705 .76787 L p F P
0 g
s
.621 .733 .927 r
.44455 .55399 m .43381 .55662 L .42838 .55033 L p F P
0 g
s
.636 .622 .819 r
.64109 .76005 m .62022 .76532 L .61489 .7551 L p F P
0 g
s
.575 .223 .335 r
.57825 .98122 m .58132 .97343 L .59261 .97232 L p F P
0 g
s
.564 .282 .447 r
.62922 .96032 m .62942 .95901 L .65145 .95499 L p F P
0 g
s
.093 .153 .634 r
.44694 .45574 m .44998 .44611 L .44527 .43889 L p F P
0 g
s
.059 .083 .57 r
.44998 .44611 m .44694 .45574 L .45038 .46346 L p F P
0 g
s
.536 .502 .765 r
.42638 .3407 m .42914 .33799 L p .4239 .32399 L F P
0 g
s
.512 .465 .741 r
.42914 .33799 m .43016 .34113 L .42638 .3407 L closepath p F P
0 g
s
.509 .474 .753 r
.43332 .35188 m .43016 .34113 L .42638 .3407 L p F P
0 g
s
.976 .692 .42 r
.46601 .52759 m .46091 .52112 L .46077 .51206 L p F P
0 g
s
.969 .738 .535 r
.46091 .52112 m .46601 .52759 L .465 .53515 L p F P
0 g
s
.53 .671 .927 r
.38697 .54143 m .37734 .54195 L .37389 .53485 L p F P
0 g
s
.982 .837 .623 r
.60273 .4441 m .60548 .45151 L .60905 .44125 L p F P
0 g
s
.982 .837 .623 r
.60905 .44125 m .60604 .43392 L .60273 .4441 L p F P
0 g
s
.82 .672 .699 r
.33862 .85432 m .34888 .85824 L .34207 .87018 L p F P
0 g
s
.813 .681 .718 r
.34888 .85824 m .33862 .85432 L .34676 .84203 L p F P
0 g
s
.618 .597 .807 r
.67274 .77767 m .65168 .78161 L .64638 .77044 L p F P
0 g
s
.497 .637 .917 r
.35532 .52763 m .34472 .52743 L .34212 .51994 L p F P
0 g
s
.49 .641 .923 r
.34472 .52743 m .35532 .52763 L .36141 .53496 L p F P
0 g
s
0 0 .376 r
.22568 .36541 m .22512 .36923 L .22679 .37699 L p F P
0 g
s
.711 .81 .926 r
.64746 .54054 m .6525 .54516 L .63172 .55472 L p F P
0 g
s
.711 .81 .926 r
.62973 .54846 m .64746 .54054 L p .63172 .55472 L F P
0 g
s
.711 .81 .926 r
.63172 .55472 m .62822 .5514 L .62973 .54846 L p F P
0 g
s
.988 .867 .511 r
.59887 .47197 m .60012 .47977 L .60267 .46979 L p F P
0 g
s
.988 .867 .511 r
.59906 .47112 m .59887 .47197 L p .60267 .46979 L F P
0 g
s
.988 .867 .511 r
.60267 .46979 m .60224 .467 L .59906 .47112 L p F P
0 g
s
.917 .935 .803 r
.80639 .44103 m .80608 .44086 L .80643 .44041 L closepath p F P
0 g
s
.808 .693 .738 r
.35654 .82931 m .35154 .83579 L .34559 .8264 L p F P
0 g
s
.808 .693 .738 r
.34559 .8264 m .34646 .82526 L .35654 .82931 L p F P
0 g
s
.8 .703 .757 r
.35654 .82931 m .34646 .82526 L .35788 .81207 L p F P
0 g
s
0 0 .02 r
.59668 .4993 m .59382 .50836 L .59576 .49852 L p F P
0 g
s
0 0 .02 r
.59576 .49852 m .59805 .48963 L .59668 .4993 L p F P
0 g
s
.701 .324 .332 r
.46778 .97305 m .47345 .97888 L .47192 .981 L p F P
0 g
s
.701 .324 .332 r
.45044 .97131 m .46778 .97305 L p .47192 .981 L F P
0 g
s
.468 .609 .907 r
.3402 .51213 m .32381 .51107 L .32996 .51905 L p F P
0 g
s
.468 .609 .907 r
.32996 .51905 m .34212 .51994 L .3402 .51213 L p F P
0 g
s
.457 .606 .91 r
.31869 .51062 m .32381 .51107 L .32996 .51905 L p F P
0 g
s
.508 .649 .921 r
.37116 .52744 m .35532 .52763 L .36141 .53496 L p F P
0 g
s
.508 .649 .921 r
.36141 .53496 m .37389 .53485 L .37116 .52744 L p F P
0 g
s
.587 .529 .757 r
.70725 .80662 m .71006 .81427 L .6887 .81553 L p F P
0 g
s
.587 .529 .757 r
.6887 .81553 m .68839 .81468 L .70725 .80662 L p F P
0 g
s
.773 .724 .807 r
.65257 .29058 m .66237 .28216 L .65467 .276 L p F P
0 g
s
.773 .724 .807 r
.65467 .276 m .64742 .28197 L .65257 .29058 L p F P
0 g
s
.813 .728 .771 r
.63988 .29008 m .64742 .28197 L .65257 .29058 L p F P
0 g
s
.813 .728 .771 r
.65257 .29058 m .64756 .29622 L .63988 .29008 L p F P
0 g
s
.916 .709 .213 r
.82487 .35561 m .82653 .36344 L .82659 .35442 L p F P
0 g
s
.916 .709 .213 r
.82659 .35442 m .82495 .34656 L .82487 .35561 L p F P
0 g
s
.594 .551 .776 r
.70468 .80024 m .70725 .80662 L .68839 .81468 L p F P
0 g
s
.594 .551 .776 r
.68839 .81468 m .68335 .8021 L .70468 .80024 L p F P
0 g
s
.455 .386 .69 r
.44369 .3911 m .43859 .39752 L p .4396 .3796 L F P
0 g
s
.401 .349 .685 r
.44369 .3911 m .44648 .40282 L .43859 .39752 L closepath p F P
0 g
s
.365 .351 .711 r
.44666 .40363 m .44648 .40282 L .43859 .39752 L p F P
0 g
s
.892 .989 .766 r
.24053 .31118 m .24508 .29973 L p .25317 .29084 L F P
0 g
s
.842 .946 .588 r
.24508 .29973 m .24053 .31118 L .23743 .31627 L p F P
0 g
s
.572 .47 .7 r
.70637 .87176 m .70529 .86768 L .7154 .86829 L closepath p F P
0 g
s
.644 .761 .933 r
.6266 .54979 m .60582 .55707 L .60054 .55015 L p F P
0 g
s
.916 .925 .804 r
.80193 .43835 m .80647 .43232 L .80643 .44041 L p F P
0 g
s
.916 .925 .804 r
.80643 .44041 m .80608 .44086 L .80193 .43835 L p F P
0 g
s
.786 .732 .803 r
.67301 .27273 m .66237 .28216 L .65467 .276 L p F P
0 g
s
0 0 .361 r
.59337 .51775 m .59129 .5211 L .59144 .51233 L p F P
0 g
s
0 0 .361 r
.59144 .51233 m .59382 .50836 L .59337 .51775 L p F P
0 g
s
.919 .931 .8 r
.79692 .45277 m .80608 .44086 L .80193 .43835 L p F P
0 g
s
.179 .308 .759 r
.24614 .43485 m .24627 .44033 L p .23865 .42556 L F P
0 g
s
.247 .379 .8 r
.24614 .43485 m .24985 .44241 L .24627 .44033 L closepath p F P
0 g
s
.24 .379 .803 r
.25575 .45426 m .25577 .45442 L p .24627 .44033 L F P
0 g
s
.24 .379 .803 r
.24627 .44033 m .24985 .44241 L .25575 .45426 L p F P
0 g
s
.564 .282 .447 r
.65145 .95499 m .65035 .962 L .62922 .96032 L p F P
0 g
s
.559 .266 .426 r
.62781 .9678 m .62922 .96032 L .65035 .962 L p F P
0 g
s
.585 .291 .436 r
.62922 .96032 m .62781 .9678 L .60496 .97102 L p F P
0 g
s
.741 .729 .841 r
.67301 .27273 m .68379 .26566 L .67648 .25931 L p F P
0 g
s
.741 .729 .841 r
.67648 .25931 m .66796 .2647 L .67301 .27273 L p F P
0 g
s
.786 .732 .803 r
.65467 .276 m .66796 .2647 L .67301 .27273 L p F P
0 g
s
.949 .642 .205 r
.46077 .51206 m .45722 .50498 L .45613 .49629 L p F P
0 g
s
.984 .717 .337 r
.45722 .50498 m .46077 .51206 L .46091 .52112 L p F P
0 g
s
.561 .443 .675 r
.70916 .88431 m .70637 .87176 L .7154 .86829 L p F P
0 g
s
.811 .729 .773 r
.63988 .29008 m .64756 .29622 L .63588 .30914 L p F P
0 g
s
.654 .649 .832 r
.60956 .74564 m .58883 .75205 L .58344 .74278 L p F P
0 g
s
.3 .438 .833 r
.25575 .45426 m .25586 .45446 L .25577 .45442 L closepath p F P
0 g
s
.81 .578 .587 r
.37311 .92876 m .36119 .92549 L .36265 .91484 L p F P
0 g
s
.817 .585 .587 r
.35115 .91142 m .36265 .91484 L .36119 .92549 L p F P
0 g
s
.815 .606 .62 r
.36265 .91484 m .35115 .91142 L .35403 .90044 L p F P
0 g
s
.821 .615 .623 r
.34296 .89686 m .35403 .90044 L .35115 .91142 L p F P
0 g
s
.818 .631 .65 r
.35403 .90044 m .34296 .89686 L .3472 .88555 L p F P
0 g
s
.108 .224 .703 r
.23882 .41769 m .23865 .42556 L p .23285 .41009 L F P
0 g
s
.185 .309 .757 r
.23882 .41769 m .24388 .4296 L .23865 .42556 L closepath p F P
0 g
s
.179 .308 .759 r
.23865 .42556 m .24388 .4296 L .24614 .43485 L p F P
0 g
s
.33 .455 .837 r
.25586 .45446 m .2668 .45912 L p .2555 .4456 L F P
0 g
s
.33 .455 .837 r
.2555 .4456 m .25575 .45426 L .25586 .45446 L p F P
0 g
s
.749 .419 .426 r
.41602 .96051 m .41706 .95797 L p .43455 .96918 L F P
0 g
s
.765 .448 .448 r
.41602 .96051 m .4148 .95756 L .41706 .95797 L closepath p F P
0 g
s
.808 .695 .74 r
.34676 .84203 m .35154 .83579 L .34559 .8264 L p F P
0 g
s
.58 .243 .362 r
.60358 .9752 m .59261 .97232 L .60496 .97102 L closepath p F P
0 g
s
.575 .223 .335 r
.59261 .97232 m .60358 .9752 L p .57825 .98122 L F P
0 g
s
.252 .386 .805 r
.24985 .44241 m .2555 .4456 L .25575 .45426 L closepath p F P
0 g
s
.877 .732 .698 r
.61195 .36155 m .61871 .36784 L .61333 .37858 L p F P
0 g
s
.844 .729 .737 r
.62583 .33903 m .61802 .33304 L .62645 .32126 L p F P
0 g
s
.825 .711 .738 r
.61776 .35068 m .62583 .33903 L .61802 .33304 L p F P
0 g
s
.745 .71 .819 r
.4422 .7553 m .43318 .76135 L .42737 .75344 L p F P
0 g
s
.755 .844 .918 r
.29855 .26201 m .29022 .26699 L .29472 .25956 L closepath p F P
0 g
s
.332 .535 .902 r
.77725 .27244 m .78245 .27398 L .78645 .28135 L p F P
0 g
s
.202 .449 .872 r
.79294 .27897 m .79687 .28638 L .78645 .28135 L p F P
0 g
s
.202 .449 .872 r
.78645 .28135 m .78245 .27398 L .79294 .27897 L p F P
0 g
s
.794 .876 .907 r
.73394 .51041 m .72453 .51695 L .71987 .51318 L p F P
0 g
s
.98 .914 .63 r
.82111 .40641 m .81984 .4095 L .81963 .40639 L closepath p F P
0 g
s
.771 .443 .432 r
.4148 .95756 m .41602 .96051 L .41337 .96587 L p F P
0 g
s
.771 .443 .432 r
.40104 .95485 m .4148 .95756 L p .41337 .96587 L F P
0 g
s
.896 .709 .642 r
.465 .53515 m .46429 .53732 L .46777 .54012 L closepath p F P
0 g
s
.801 .752 .808 r
.46777 .54012 m .46429 .53732 L .44879 .55166 L p F P
0 g
s
.804 .545 .547 r
.38368 .94172 m .37319 .93906 L .37311 .92876 L p F P
0 g
s
.811 .551 .546 r
.36119 .92549 m .37311 .92876 L .37319 .93906 L p F P
0 g
s
.61 .6 .816 r
.39608 .25626 m .37623 .26198 L .38211 .27265 L p F P
0 g
s
.61 .6 .816 r
.38211 .27265 m .40192 .26773 L .39608 .25626 L p F P
0 g
s
.625 .643 .848 r
.38211 .27265 m .37623 .26198 L .37571 .26212 L p F P
0 g
s
.824 .639 .652 r
.33654 .88181 m .3472 .88555 L .34296 .89686 L p F P
0 g
s
.819 .652 .676 r
.3472 .88555 m .33654 .88181 L .34207 .87018 L p F P
0 g
s
.672 .728 .891 r
.33815 .24316 m .31833 .25194 L .32468 .25829 L p F P
0 g
s
.672 .728 .891 r
.32468 .25829 m .34439 .25046 L .33815 .24316 L p F P
0 g
s
.559 .528 .777 r
.4239 .32399 m .42444 .32349 L p .41881 .30823 L F P
0 g
s
.537 .495 .757 r
.42444 .32349 m .42462 .32399 L .4239 .32399 L closepath p F P
0 g
s
.536 .502 .765 r
.42914 .33799 m .42462 .32399 L .4239 .32399 L p F P
0 g
s
.842 .946 .588 r
.23743 .31627 m .23536 .31909 L p .24508 .29973 L F P
0 g
s
.87 .933 .554 r
.23743 .31627 m .23456 .32175 L .23536 .31909 L closepath p F P
0 g
s
.896 .758 .7 r
.61387 .39585 m .60796 .38936 L .61333 .37858 L p F P
0 g
s
.891 .753 .702 r
.60857 .40662 m .61387 .39585 L .60796 .38936 L p F P
0 g
s
.923 .798 .704 r
.61087 .4102 m .60819 .40741 L .60857 .40662 L closepath p F P
0 g
s
.549 .366 .586 r
.69384 .92488 m .69291 .91407 L .71297 .9077 L p F P
0 g
s
.562 .401 .62 r
.71148 .89705 m .71297 .9077 L .69291 .91407 L p F P
0 g
s
.562 .401 .62 r
.7102 .89668 m .71148 .89705 L p .69291 .91407 L F P
0 g
s
.617 .727 .924 r
.42373 .54371 m .41274 .54611 L .41867 .55258 L p F P
0 g
s
.617 .727 .924 r
.41867 .55258 m .42838 .55033 L .42373 .54371 L p F P
0 g
s
.371 .492 .852 r
.28025 .47188 m .26743 .46773 L .2668 .45912 L p F P
0 g
s
.352 .489 .856 r
.28028 .47193 m .28119 .48031 L p .26743 .46773 L F P
0 g
s
.352 .489 .856 r
.26743 .46773 m .28025 .47188 L .28028 .47193 L p F P
0 g
s
.225 .215 .637 r
.44527 .43889 m .45165 .42796 L .44527 .4214 L p F P
0 g
s
.351 .285 .642 r
.44998 .44611 m .44527 .43889 L .45165 .42796 L p F P
0 g
s
.026 .126 .632 r
.23336 .40239 m .23285 .41009 L p .22888 .39391 L F P
0 g
s
.113 .225 .702 r
.23336 .40239 m .23802 .41547 L .23285 .41009 L closepath p F P
0 g
s
.108 .224 .703 r
.23285 .41009 m .23802 .41547 L .23882 .41769 L p F P
0 g
s
.819 .689 .721 r
.33687 .83795 m .34676 .84203 L .33862 .85432 L p F P
0 g
s
.808 .695 .74 r
.34559 .8264 m .33687 .83795 L .34676 .84203 L p F P
0 g
s
.797 .535 0 r
.82401 .34307 m .82495 .34656 L .82351 .33809 L p F P
0 g
s
.797 .535 0 r
.82351 .33809 m .82214 .33289 L .82401 .34307 L p F P
0 g
s
.547 .486 .739 r
.42914 .33799 m .43016 .34113 L .44924 .34073 L p F P
0 g
s
.547 .472 .722 r
.43016 .34113 m .44924 .34073 L .43332 .35188 L closepath p F P
0 g
s
.561 .494 .737 r
.42462 .32399 m .42914 .33799 L .44588 .32642 L p F P
0 g
s
.547 .486 .739 r
.44995 .34023 m .44588 .32642 L .42914 .33799 L p F P
0 g
s
.547 .486 .739 r
.44924 .34073 m .44995 .34023 L p .42914 .33799 L F P
0 g
s
.745 .855 .931 r
.67826 .53889 m .677 .53957 L .67765 .53839 L closepath p F P
0 g
s
.733 .836 .929 r
.67335 .53455 m .67765 .53839 L .677 .53957 L p F P
0 g
s
.733 .836 .929 r
.6525 .54516 m .67335 .53455 L p .677 .53957 L F P
0 g
s
.811 .729 .773 r
.63588 .30914 m .62715 .3034 L .63988 .29008 L p F P
0 g
s
.793 .711 .774 r
.6323 .31301 m .63588 .30914 L .62715 .3034 L p F P
0 g
s
.566 .512 .754 r
.42444 .32349 m .42462 .32399 L .44457 .32194 L p F P
0 g
s
.561 .494 .737 r
.44588 .32642 m .44457 .32194 L .42462 .32399 L p F P
0 g
s
.737 .478 0 r
.45613 .49629 m .45455 .48847 L p .45319 .48307 L F P
0 g
s
.779 .548 0 r
.45455 .48847 m .45613 .49629 L .45722 .50498 L p F P
0 g
s
.779 .548 0 r
.45588 .49709 m .45455 .48847 L p .45524 .49272 L F P
0 g
s
.779 .548 0 r
.45722 .50498 m .45588 .49709 L p .45524 .49272 L F P
0 g
s
.864 .666 .134 r
.45588 .49709 m .45722 .50498 L .45732 .51407 L p F P
0 g
s
.864 .666 .134 r
.456 .50619 m .45588 .49709 L p .45645 .50383 L F P
0 g
s
.864 .666 .134 r
.45732 .51407 m .456 .50619 L p .45645 .50383 L F P
0 g
s
.973 .828 .416 r
.45553 .52385 m .45364 .51618 L .456 .50619 L p F P
0 g
s
0 0 0 r
.456 .50619 m .45364 .51618 L p .45555 .50856 L F P
0 g
s
.973 .828 .416 r
.456 .50619 m .45732 .51407 L .45553 .52385 L p F P
0 g
s
0 0 0 r
.45847 .49693 m .456 .50619 L p .45555 .50856 L F P
0 g
s
0 0 .219 r
.45588 .49709 m .456 .50619 L p .45653 .5015 L F P
0 g
s
0 0 .219 r
.45804 .48792 m .45588 .49709 L p .45653 .5015 L F P
0 g
s
0 0 .343 r
.45455 .48847 m .45588 .49709 L p .45593 .49391 L F P
0 g
s
0 0 .343 r
.45614 .47948 m .45455 .48847 L p .45593 .49391 L F P
0 g
s
.737 .478 0 r
.45455 .48847 m .45254 .48014 L p .45319 .48307 L F P
0 g
s
.593 .549 .775 r
.70051 .78988 m .70468 .80024 L .68335 .8021 L p F P
0 g
s
.593 .549 .775 r
.68335 .8021 m .68179 .79819 L .70051 .78988 L p F P
0 g
s
.575 .516 .752 r
.41903 .30821 m .42444 .32349 L .44131 .31201 L p F P
0 g
s
.566 .512 .754 r
.44457 .32194 m .44131 .31201 L .42444 .32349 L p F P
0 g
s
.559 .528 .777 r
.42444 .32349 m .41903 .30821 L .41881 .30823 L p F P
0 g
s
.466 .603 .904 r
.32381 .51107 m .31869 .51062 L .31682 .50275 L p F P
0 g
s
.765 .858 .919 r
.69423 .52243 m .69905 .52662 L .67826 .53889 L p F P
0 g
s
.765 .858 .919 r
.68035 .53068 m .69423 .52243 L p .67826 .53889 L F P
0 g
s
.765 .858 .919 r
.67826 .53889 m .67765 .53839 L .68035 .53068 L p F P
0 g
s
.992 .874 .541 r
.82222 .38307 m .82344 .39095 L .82628 .3809 L p F P
0 g
s
.992 .874 .541 r
.82628 .3809 m .82506 .373 L .82222 .38307 L p F P
0 g
s
.753 .737 .838 r
.69372 .25894 m .68379 .26566 L .67648 .25931 L p F P
0 g
s
.745 .71 .819 r
.42737 .75344 m .42982 .75178 L .4422 .7553 L p F P
0 g
s
.736 .714 .831 r
.4477 .74066 m .42982 .75178 L .4422 .7553 L p F P
0 g
s
.736 .714 .831 r
.4422 .7553 m .45347 .74836 L .4477 .74066 L p F P
0 g
s
.701 .324 .332 r
.47192 .981 m .45914 .97968 L .45044 .97131 L p F P
0 g
s
.689 .288 .281 r
.44616 .97084 m .45044 .97131 L .45914 .97968 L p F P
0 g
s
.698 .681 .83 r
.53116 .74053 m .53143 .74095 L p .50547 .7421 L F P
0 g
s
.698 .681 .83 r
.50547 .7421 m .50998 .73994 L .53116 .74053 L p F P
0 g
s
.7 .688 .835 r
.50547 .7421 m .50998 .73994 L .50383 .73965 L closepath p F P
0 g
s
.712 .693 .83 r
.50383 .73965 m .50547 .7421 L p .47949 .7446 L F P
0 g
s
.816 .891 .897 r
.73394 .51041 m .74521 .50182 L .74065 .49822 L p F P
0 g
s
.816 .891 .897 r
.74065 .49822 m .73584 .50192 L .73394 .51041 L p F P
0 g
s
.794 .876 .907 r
.71987 .51318 m .73584 .50192 L .73394 .51041 L p F P
0 g
s
.793 .711 .774 r
.62715 .3034 m .62705 .30351 L .6323 .31301 L p F P
0 g
s
.827 .71 .735 r
.61809 .3154 m .62705 .30351 L .6323 .31301 L p F P
0 g
s
.827 .71 .735 r
.6323 .31301 m .62645 .32126 L .61809 .3154 L p F P
0 g
s
.919 .931 .8 r
.80193 .43835 m .79718 .44464 L .79692 .45277 L p F P
0 g
s
.894 .924 .833 r
.78594 .45761 m .79718 .44464 L .79692 .45277 L p F P
0 g
s
.894 .924 .833 r
.7856 .4647 m .78594 .45761 L p .79692 .45277 L F P
0 g
s
.894 .924 .833 r
.79692 .45277 m .78615 .46504 L .7856 .4647 L p F P
0 g
s
.577 .55 .787 r
.41239 .29131 m .41339 .29365 L .40889 .2943 L closepath p F P
0 g
s
.578 .551 .789 r
.41898 .30808 m .41339 .29365 L .40889 .2943 L p F P
0 g
s
.578 .551 .789 r
.41881 .30823 m .41898 .30808 L p .40889 .2943 L F P
0 g
s
.961 .921 .72 r
.81336 .41266 m .81391 .42065 L .81984 .4095 L p F P
0 g
s
.961 .921 .72 r
.81719 .40533 m .81336 .41266 L p .81984 .4095 L F P
0 g
s
.961 .921 .72 r
.81984 .4095 m .81963 .40639 L .81719 .40533 L p F P
0 g
s
.547 .472 .722 r
.44924 .34073 m .43332 .35188 L .43564 .3598 L p F P
0 g
s
.684 .669 .83 r
.55606 .73899 m .55741 .74119 L p .53143 .74095 L F P
0 g
s
.684 .669 .83 r
.53143 .74095 m .53259 .74046 L .55606 .73899 L p F P
0 g
s
.685 .676 .835 r
.53143 .74095 m .53259 .74046 L .53116 .74053 L closepath p F P
0 g
s
.793 .712 .775 r
.3713 .79832 m .36625 .80346 L .36026 .79527 L p F P
0 g
s
.793 .712 .775 r
.36026 .79527 m .36135 .79415 L .3713 .79832 L p F P
0 g
s
.781 .715 .79 r
.37698 .77975 m .36135 .79415 L .3713 .79832 L p F P
0 g
s
.781 .715 .79 r
.38617 .78353 m .37698 .77975 L p .3713 .79832 L F P
0 g
s
.781 .715 .79 r
.3713 .79832 m .38671 .78425 L .38617 .78353 L p F P
0 g
s
.779 .715 .792 r
.38671 .78425 m .38711 .78389 L .38617 .78353 L closepath p F P
0 g
s
.769 .722 .809 r
.39567 .76444 m .40617 .76851 L .38711 .78389 L p F P
0 g
s
.769 .722 .809 r
.38075 .77661 m .39567 .76444 L p .38711 .78389 L F P
0 g
s
.769 .722 .809 r
.38711 .78389 m .38617 .78353 L .38075 .77661 L p F P
0 g
s
.969 .891 .519 r
.60224 .467 m .59906 .47112 L .60204 .46176 L closepath p F P
0 g
s
.641 .67 .862 r
.36421 .2432 m .34439 .25046 L .35052 .2586 L p F P
0 g
s
.641 .67 .862 r
.35052 .2586 m .37026 .25217 L .36421 .2432 L p F P
0 g
s
.949 .784 .643 r
.60147 .42706 m .60604 .43392 L .6095 .42373 L p F P
0 g
s
.949 .784 .643 r
.6095 .42373 m .60488 .41687 L .60147 .42706 L p F P
0 g
s
.599 .57 .793 r
.69935 .78722 m .70051 .78988 L .68179 .79819 L p F P
0 g
s
.599 .57 .793 r
.68179 .79819 m .67804 .78959 L .69935 .78722 L p F P
0 g
s
.825 .661 .679 r
.33183 .86628 m .34207 .87018 L .33654 .88181 L p F P
0 g
s
.82 .672 .699 r
.34207 .87018 m .33183 .86628 L .33862 .85432 L p F P
0 g
s
.541 .189 .321 r
.60496 .97102 m .62781 .9678 L .6251 .97571 L p F P
0 g
s
.541 .189 .321 r
.60358 .9752 m .60496 .97102 L p .6251 .97571 L F P
0 g
s
.683 .688 .848 r
.53259 .74046 m .53116 .74053 L .5259 .7328 L p F P
0 g
s
.694 .692 .843 r
.53116 .74053 m .5259 .7328 L .50998 .73994 L closepath p F P
0 g
s
.784 .495 .497 r
.40104 .95485 m .38763 .95203 L .38563 .94216 L p F P
0 g
s
.79 .499 .495 r
.38368 .94172 m .38563 .94216 L .38763 .95203 L p F P
0 g
s
.794 .713 .776 r
.35788 .81207 m .36625 .80346 L .36026 .79527 L p F P
0 g
s
.681 .681 .844 r
.55606 .73899 m .55195 .73269 L .53259 .74046 L closepath p F P
0 g
s
.683 .688 .848 r
.54645 .72451 m .55195 .73269 L .53259 .74046 L p F P
0 g
s
.683 .688 .848 r
.5259 .7328 m .54645 .72451 L p .53259 .74046 L F P
0 g
s
.397 .533 .876 r
.29659 .48367 m .28643 .48152 L .2926 .49088 L p F P
0 g
s
.397 .533 .876 r
.2926 .49088 m .29755 .49201 L .29659 .48367 L p F P
0 g
s
.391 .533 .879 r
.28119 .48031 m .28643 .48152 L .2926 .49088 L p F P
0 g
s
0 .271 .775 r
.80437 .29252 m .8078 .30005 L .80034 .29388 L p F P
0 g
s
0 .271 .775 r
.80034 .29388 m .79687 .28638 L .80437 .29252 L p F P
0 g
s
.547 .472 .722 r
.43564 .3598 m .44361 .36051 L p .44924 .34073 L F P
0 g
s
.526 .446 .708 r
.43564 .3598 m .44361 .36051 L .43713 .36536 L closepath p F P
0 g
s
.618 .597 .807 r
.64638 .77044 m .66745 .76654 L .67274 .77767 L p F P
0 g
s
.617 .596 .806 r
.66488 .76114 m .66745 .76654 L .64638 .77044 L p F P
0 g
s
.617 .596 .806 r
.64638 .77044 m .64561 .76882 L .66488 .76114 L p F P
0 g
s
.559 .523 .772 r
.41898 .30808 m .41903 .30821 L .41881 .30823 L closepath p F P
0 g
s
.712 .693 .83 r
.47949 .7446 m .4915 .73821 L .50383 .73965 L p F P
0 g
s
.714 .7 .835 r
.4915 .73821 m .47949 .7446 L .47381 .73653 L p F P
0 g
s
.725 .703 .829 r
.45347 .74836 m .47381 .73653 L .47949 .7446 L p F P
0 g
s
.742 .843 .927 r
.31185 .24657 m .31833 .25194 L .29855 .26201 L p F P
0 g
s
.742 .843 .927 r
.29948 .2535 m .31185 .24657 L p .29855 .26201 L F P
0 g
s
.742 .843 .927 r
.29855 .26201 m .29472 .25956 L .29948 .2535 L p F P
0 g
s
.757 .718 .816 r
.40805 .76917 m .40705 .76787 L .40617 .76851 L closepath p F P
0 g
s
.689 .288 .281 r
.44155 .97733 m .44616 .97084 L p .45914 .97968 L F P
0 g
s
.726 .353 .345 r
.44155 .97733 m .43455 .96918 L .44616 .97084 L closepath p F P
0 g
s
.583 .537 .769 r
.41898 .30808 m .41903 .30821 L .43899 .30489 L p F P
0 g
s
.575 .516 .752 r
.44131 .31201 m .43899 .30489 L .41903 .30821 L p F P
0 g
s
.774 .723 .805 r
.38617 .78353 m .38075 .77661 L .37698 .77975 L closepath p F P
0 g
s
.589 .539 .767 r
.41339 .29365 m .41898 .30808 L .43605 .29677 L p F P
0 g
s
.583 .537 .769 r
.43899 .30489 m .43605 .29677 L .41898 .30808 L p F P
0 g
s
.632 .72 .911 r
.7363 .24371 m .71477 .24913 L .71962 .25638 L p F P
0 g
s
.632 .72 .911 r
.71962 .25638 m .74108 .25074 L .7363 .24371 L p F P
0 g
s
0 0 .329 r
.81834 .32246 m .81656 .31697 L .82031 .32731 L closepath p F P
0 g
s
.551 .416 .65 r
.71137 .8963 m .70916 .88431 L .72851 .87697 L p F P
0 g
s
.561 .443 .675 r
.72695 .87017 m .72851 .87697 L .70916 .88431 L p F P
0 g
s
.561 .443 .675 r
.7154 .86829 m .72695 .87017 L p .70916 .88431 L F P
0 g
s
.573 .43 .648 r
.70916 .88431 m .71137 .8963 L .7102 .89668 L p F P
0 g
s
.636 .622 .819 r
.61489 .7551 m .63578 .74981 L .64109 .76005 L p F P
0 g
s
.636 .624 .82 r
.63471 .74775 m .63578 .74981 L .61489 .7551 L p F P
0 g
s
.636 .624 .82 r
.61489 .7551 m .6145 .75435 L .63471 .74775 L p F P
0 g
s
.748 .84 .921 r
.67765 .53839 m .67335 .53455 L .68035 .53068 L closepath p F P
0 g
s
.48 .64 .926 r
.7726 .26512 m .75987 .2646 L .75494 .25746 L p F P
0 g
s
0 0 .221 r
.22568 .36541 m .22705 .35911 L .22681 .35085 L p F P
0 g
s
0 0 .43 r
.22705 .35911 m .22568 .36541 L .22689 .37633 L p F P
0 g
s
0 0 .376 r
.22679 .37699 m .22689 .37633 L .22568 .36541 L p F P
0 g
s
.819 .887 .893 r
.75466 .49439 m .74521 .50182 L .74065 .49822 L p F P
0 g
s
.804 .712 .763 r
.34818 .80785 m .35788 .81207 L .34646 .82526 L p F P
0 g
s
.794 .713 .776 r
.36026 .79527 m .34818 .80785 L .35788 .81207 L p F P
0 g
s
.525 .445 .707 r
.44361 .36051 m .43713 .36536 L .44061 .37846 L p F P
0 g
s
.447 .394 .706 r
.4396 .3796 m .44061 .37846 L .43713 .36536 L p F P
0 g
s
.622 .614 .821 r
.66217 .75587 m .66488 .76114 L .64561 .76882 L p F P
0 g
s
.622 .614 .821 r
.64561 .76882 m .64109 .76005 L .66217 .75587 L p F P
0 g
s
.79 .499 .495 r
.38763 .95203 m .38113 .95057 L .38368 .94172 L p F P
0 g
s
.802 .512 .497 r
.37319 .93906 m .38368 .94172 L .38113 .95057 L p F P
0 g
s
0 .026 .598 r
.81029 .30335 m .8078 .30005 L .81077 .30767 L p F P
0 g
s
0 .026 .598 r
.81077 .30767 m .81514 .31369 L .81029 .30335 L p F P
0 g
s
.669 .657 .829 r
.57921 .73559 m .58344 .74278 L p .55741 .74119 L F P
0 g
s
.669 .657 .829 r
.55741 .74119 m .56793 .73731 L .57921 .73559 L p F P
0 g
s
.67 .664 .835 r
.55741 .74119 m .56793 .73731 L .55606 .73899 L closepath p F P
0 g
s
.695 .698 .848 r
.52033 .72486 m .5259 .7328 L .50998 .73994 L p F P
0 g
s
.695 .698 .848 r
.49986 .73407 m .52033 .72486 L p .50998 .73994 L F P
0 g
s
.695 .698 .848 r
.50998 .73994 m .50383 .73965 L .49986 .73407 L p F P
0 g
s
.639 .64 .835 r
.63047 .74021 m .63471 .74775 L .6145 .75435 L p F P
0 g
s
.639 .64 .835 r
.6145 .75435 m .60956 .74564 L .63047 .74021 L p F P
0 g
s
.969 .738 .535 r
.465 .53515 m .46214 .53406 L p .46091 .52112 L F P
0 g
s
.958 .794 .637 r
.465 .53515 m .46429 .53732 L .46214 .53406 L closepath p F P
0 g
s
0 0 0 r
.22681 .35085 m .22956 .34028 L .2311 .33137 L p F P
0 g
s
0 0 .246 r
.22956 .34028 m .22681 .35085 L .22705 .35911 L p F P
0 g
s
.728 .764 .881 r
.44455 .55399 m .44879 .55166 L .4434 .54533 L p F P
0 g
s
.728 .764 .881 r
.4434 .54533 m .4387 .54784 L .44455 .55399 L p F P
0 g
s
.621 .733 .927 r
.42838 .55033 m .4387 .54784 L .44455 .55399 L p F P
0 g
s
.446 .393 .705 r
.44061 .37846 m .44109 .38025 L .4396 .3796 L closepath p F P
0 g
s
.455 .386 .69 r
.4396 .3796 m .44109 .38025 L .44369 .3911 L p F P
0 g
s
.749 .419 .426 r
.43455 .96918 m .41937 .96685 L .41602 .96051 L p F P
0 g
s
.753 .421 .421 r
.41937 .96685 m .41337 .96587 L .41602 .96051 L closepath p F P
0 g
s
.825 .711 .738 r
.61696 .35012 m .61776 .35068 L p .61802 .33304 L F P
0 g
s
.83 .711 .733 r
.61696 .35012 m .61747 .35109 L .61776 .35068 L closepath p F P
0 g
s
0 .013 .545 r
.22945 .38867 m .22888 .39391 L p .22679 .37699 L F P
0 g
s
.03 .127 .633 r
.22945 .38867 m .23238 .39898 L .22888 .39391 L closepath p F P
0 g
s
.026 .126 .632 r
.22888 .39391 m .23238 .39898 L .23336 .40239 L p F P
0 g
s
.989 .844 .607 r
.59959 .45427 m .60204 .46176 L .60548 .45151 L p F P
0 g
s
.989 .844 .607 r
.60548 .45151 m .60273 .4441 L .59959 .45427 L p F P
0 g
s
.396 .529 .873 r
.28028 .47193 m .28643 .48152 L .28119 .48031 L closepath p F P
0 g
s
.857 .718 .708 r
.61747 .35109 m .61195 .36155 L p .61015 .34463 L F P
0 g
s
.857 .718 .708 r
.61015 .34463 m .61696 .35012 L .61747 .35109 L p F P
0 g
s
.742 .791 .303 r
.23536 .31909 m .23456 .32175 L .2311 .33137 L p F P
0 g
s
.759 .724 .82 r
.40114 .76039 m .39567 .76444 L .40617 .76851 L p F P
0 g
s
.759 .724 .82 r
.40617 .76851 m .40705 .76787 L .40114 .76039 L p F P
0 g
s
.891 .924 .836 r
.78615 .46504 m .78551 .46576 L .7856 .4647 L closepath p F P
0 g
s
.704 .741 .88 r
.70989 .24185 m .68875 .25133 L .69372 .25894 L p F P
0 g
s
.704 .741 .88 r
.69372 .25894 m .71477 .24913 L .70989 .24185 L p F P
0 g
s
.753 .737 .838 r
.67648 .25931 m .68875 .25133 L .69372 .25894 L p F P
0 g
s
.707 .702 .843 r
.50383 .73965 m .49986 .73407 L .4915 .73821 L closepath p F P
0 g
s
.863 .904 .86 r
.77229 .47139 m .77156 .4796 L .78551 .46576 L p F P
0 g
s
.863 .904 .86 r
.78182 .46181 m .77229 .47139 L p .78551 .46576 L F P
0 g
s
.863 .904 .86 r
.78551 .46576 m .7856 .4647 L .78182 .46181 L p F P
0 g
s
.755 .72 .819 r
.42737 .75344 m .40705 .76787 L .40114 .76039 L p F P
0 g
s
0 0 .422 r
.45254 .48014 m .45348 .47136 L .45038 .46346 L p F P
0 g
s
0 0 .396 r
.45348 .47136 m .45254 .48014 L .45455 .48847 L p F P
0 g
s
.286 .403 .806 r
.24985 .44241 m .2555 .4456 L p .24623 .43135 L F P
0 g
s
.286 .403 .806 r
.24623 .43135 m .24614 .43485 L .24985 .44241 L p F P
0 g
s
.843 .902 .878 r
.75466 .49439 m .76578 .48472 L .76133 .48127 L p F P
0 g
s
.843 .902 .878 r
.76133 .48127 m .75588 .48608 L .75466 .49439 L p F P
0 g
s
.819 .887 .893 r
.74065 .49822 m .75588 .48608 L .75466 .49439 L p F P
0 g
s
.322 .539 .908 r
.78245 .27398 m .77725 .27244 L .7726 .26512 L p F P
0 g
s
.825 .711 .738 r
.61802 .33304 m .61216 .3411 L .61696 .35012 L p F P
0 g
s
.856 .718 .709 r
.61216 .3411 m .61015 .34463 L .61696 .35012 L closepath p F P
0 g
s
.827 .71 .736 r
.61809 .3154 m .62645 .32126 L .61802 .33304 L p F P
0 g
s
.729 .711 .834 r
.47381 .73653 m .45347 .74836 L .4477 .74066 L p F P
0 g
s
.973 .828 .416 r
.5971 .48174 m .59805 .48963 L .60012 .47977 L p F P
0 g
s
.973 .828 .416 r
.60012 .47977 m .59887 .47197 L .5971 .48174 L p F P
0 g
s
.843 .897 .876 r
.77156 .4796 m .76578 .48472 L .76133 .48127 L p F P
0 g
s
.821 .799 .831 r
.46214 .53406 m .46429 .53732 L .44879 .55166 L p F P
0 g
s
.843 .897 .876 r
.76133 .48127 m .77229 .47139 L .77156 .4796 L p F P
0 g
s
.821 .799 .831 r
.44879 .55166 m .4434 .54533 L p .46214 .53406 L F P
0 g
s
0 0 .247 r
.59655 .50862 m .59337 .51775 L .59382 .50836 L p F P
0 g
s
0 0 .247 r
.59382 .50836 m .59668 .4993 L .59655 .50862 L p F P
0 g
s
.877 .732 .698 r
.61333 .37858 m .60627 .37241 L .61195 .36155 L p F P
0 g
s
.873 .726 .696 r
.60627 .37241 m .61333 .37858 L .60796 .38936 L p F P
0 g
s
.669 .677 .848 r
.56793 .73731 m .55606 .73899 L .55195 .73269 L p F P
0 g
s
.556 .683 .924 r
.40078 .5324 m .38094 .53446 L .38697 .54143 L p F P
0 g
s
.556 .683 .924 r
.38697 .54143 m .40678 .53939 L .40078 .5324 L p F P
0 g
s
.53 .671 .927 r
.37389 .53485 m .38094 .53446 L .38697 .54143 L p F P
0 g
s
.825 .682 .705 r
.32877 .85025 m .33862 .85432 L .33183 .86628 L p F P
0 g
s
.819 .689 .721 r
.33862 .85432 m .32877 .85025 L .33687 .83795 L p F P
0 g
s
.525 .445 .707 r
.44061 .37846 m .45663 .36614 L p .44361 .36051 L F P
0 g
s
.493 .423 .706 r
.45949 .37856 m .45663 .36614 L .44061 .37846 L p F P
0 g
s
.493 .423 .706 r
.45342 .38327 m .45949 .37856 L p .44061 .37846 L F P
0 g
s
.493 .423 .706 r
.44061 .37846 m .44109 .38025 L .45342 .38327 L p F P
0 g
s
.597 .569 .793 r
.69405 .77516 m .69935 .78722 L .67804 .78959 L p F P
0 g
s
.597 .569 .793 r
.68302 .77631 m .69405 .77516 L p .67804 .78959 L F P
0 g
s
.597 .569 .793 r
.67804 .78959 m .67406 .78046 L .68302 .77631 L p F P
0 g
s
.702 .798 .924 r
.62822 .5514 m .6266 .54979 L .62973 .54846 L closepath p F P
0 g
s
.597 .56 .784 r
.41239 .29131 m .41339 .29365 L .43337 .28931 L p F P
0 g
s
.589 .539 .767 r
.43605 .29677 m .43337 .28931 L .41339 .29365 L p F P
0 g
s
.498 .414 .692 r
.44109 .38025 m .45342 .38327 L .44369 .3911 L closepath p F P
0 g
s
.535 .293 .494 r
.67286 .95024 m .67338 .94065 L .69412 .93512 L p F P
0 g
s
.556 .343 .547 r
.69384 .92488 m .69412 .93512 L .67338 .94065 L p F P
0 g
s
.561 .313 .498 r
.67338 .94065 m .67286 .95024 L .65145 .95499 L p F P
0 g
s
.814 .702 .742 r
.34559 .8264 m .34646 .82526 L .34417 .82427 L closepath p F P
0 g
s
.804 .712 .763 r
.33956 .81791 m .34818 .80785 L p .34646 .82526 L F P
0 g
s
.804 .712 .763 r
.34646 .82526 m .34417 .82427 L .33956 .81791 L p F P
0 g
s
.87 .903 .853 r
.7856 .4647 m .78182 .46181 L .78594 .45761 L closepath p F P
0 g
s
.526 .667 .926 r
.74955 .25042 m .74108 .25074 L .74583 .25784 L p F P
0 g
s
.526 .667 .926 r
.74583 .25784 m .75494 .25746 L .74955 .25042 L p F P
0 g
s
.342 .295 .66 r
.44527 .4214 m .44924 .41574 L .44666 .40363 L p F P
0 g
s
.341 .292 .657 r
.44924 .41574 m .44527 .4214 L .45165 .42796 L p F P
0 g
s
.535 .252 .432 r
.65035 .962 m .65145 .95499 L .67286 .95024 L p F P
0 g
s
.814 .702 .741 r
.33687 .83795 m .34559 .8264 L .34417 .82427 L p F P
0 g
s
.732 .828 .924 r
.67335 .53455 m .6525 .54516 L .64746 .54054 L p F P
0 g
s
.654 .649 .832 r
.58344 .74278 m .6042 .7363 L .60956 .74564 L p F P
0 g
s
.655 .652 .835 r
.60078 .73042 m .6042 .7363 L .58344 .74278 L p F P
0 g
s
.655 .652 .835 r
.58344 .74278 m .57921 .73559 L .60078 .73042 L p F P
0 g
s
.449 .427 .742 r
.58872 .53656 m .59269 .53174 L .59515 .53931 L closepath p F P
0 g
s
.771 .443 .432 r
.41337 .96587 m .40518 .96425 L .40104 .95485 L p F P
0 g
s
.777 .444 .424 r
.38763 .95203 m .40104 .95485 L .40518 .96425 L p F P
0 g
s
.985 .818 .424 r
.82338 .36519 m .82506 .373 L .82653 .36344 L p F P
0 g
s
.985 .818 .424 r
.82653 .36344 m .82487 .35561 L .82338 .36519 L p F P
0 g
s
.597 .56 .784 r
.43337 .28931 m .42977 .28029 L .41239 .29131 L p F P
0 g
s
.603 .562 .781 r
.40768 .28018 m .41239 .29131 L .42977 .28029 L p F P
0 g
s
.56 .443 .676 r
.72695 .87017 m .7154 .86829 L .72563 .86432 L closepath p F P
0 g
s
.572 .468 .698 r
.72213 .85104 m .72563 .86432 L .7154 .86829 L p F P
0 g
s
.891 .753 .702 r
.60546 .40331 m .60857 .40662 L p .60796 .38936 L F P
0 g
s
.893 .752 .698 r
.60546 .40331 m .60819 .40741 L .60857 .40662 L closepath p F P
0 g
s
.728 .343 .32 r
.43455 .96918 m .44155 .97733 L .44121 .9777 L p F P
0 g
s
.728 .343 .32 r
.41937 .96685 m .43455 .96918 L p .44121 .9777 L F P
0 g
s
.817 .585 .587 r
.36119 .92549 m .34965 .92209 L .35115 .91142 L p F P
0 g
s
.824 .592 .588 r
.34267 .90871 m .35115 .91142 L .34965 .92209 L p F P
0 g
s
.821 .615 .623 r
.34146 .9026 m .34296 .89686 L p .35115 .91142 L F P
0 g
s
.821 .615 .623 r
.35115 .91142 m .34267 .90871 L .34146 .9026 L p F P
0 g
s
.477 .604 .9 r
.33693 .50386 m .31765 .50281 L .32381 .51107 L p F P
0 g
s
.477 .604 .9 r
.3395 .50742 m .33693 .50386 L p .32381 .51107 L F P
0 g
s
.477 .604 .9 r
.32381 .51107 m .3402 .51213 L .3395 .50742 L p F P
0 g
s
.466 .603 .904 r
.31682 .50275 m .31765 .50281 L .32381 .51107 L p F P
0 g
s
.625 .643 .848 r
.37609 .26176 m .37623 .26198 L .37571 .26212 L closepath p F P
0 g
s
.714 .7 .835 r
.47381 .73653 m .47504 .73587 L .4915 .73821 L p F P
0 g
s
.709 .708 .847 r
.49422 .72636 m .47504 .73587 L .4915 .73821 L p F P
0 g
s
.709 .708 .847 r
.4915 .73821 m .49986 .73407 L .49422 .72636 L p F P
0 g
s
.965 .916 .71 r
.81963 .40639 m .81719 .40533 L .81919 .40152 L closepath p F P
0 g
s
.919 .748 .654 r
.60819 .40741 m .60488 .41687 L p .60263 .40015 L F P
0 g
s
.919 .748 .654 r
.60263 .40015 m .60546 .40331 L .60819 .40741 L p F P
0 g
s
.829 .621 .621 r
.34146 .9026 m .34296 .89686 L .34006 .89585 L closepath p F P
0 g
s
.824 .639 .652 r
.33602 .88324 m .33654 .88181 L p .34296 .89686 L F P
0 g
s
.824 .639 .652 r
.34296 .89686 m .34006 .89585 L .33602 .88324 L p F P
0 g
s
.762 .714 .807 r
.64742 .28197 m .65467 .276 L .64581 .27021 L p F P
0 g
s
.762 .714 .807 r
.64581 .27021 m .64222 .27301 L .64742 .28197 L p F P
0 g
s
.799 .713 .769 r
.63111 .28427 m .64222 .27301 L .64742 .28197 L p F P
0 g
s
.799 .713 .769 r
.64742 .28197 m .63988 .29008 L .63111 .28427 L p F P
0 g
s
.667 .281 .304 r
.49642 .98255 m .47686 .98134 L .47345 .97888 L p F P
0 g
s
.669 .278 .295 r
.47686 .98134 m .47192 .981 L .47345 .97888 L closepath p F P
0 g
s
.84 .948 .89 r
.25317 .29084 m .25478 .28768 L .27005 .27343 L p F P
0 g
s
.859 .997 .796 r
.25478 .28768 m .25317 .29084 L .25121 .29166 L closepath p F P
0 g
s
.892 .989 .766 r
.24508 .29973 m .25121 .29166 L .25317 .29084 L p F P
0 g
s
.943 .917 .759 r
.80596 .42435 m .80647 .43232 L .81391 .42065 L p F P
0 g
s
.943 .917 .759 r
.81391 .42065 m .81336 .41266 L .80596 .42435 L p F P
0 g
s
.626 .643 .847 r
.37609 .26176 m .37623 .26198 L .39608 .25626 L p F P
0 g
s
.613 .655 .868 r
.59918 .55041 m .60015 .54952 L .60054 .55015 L closepath p F P
0 g
s
.561 .399 .619 r
.71148 .89705 m .7102 .89668 L .71137 .8963 L closepath p F P
0 g
s
.512 .642 .914 r
.36879 .5197 m .34922 .52002 L .35532 .52763 L p F P
0 g
s
.512 .642 .914 r
.36941 .52049 m .36879 .5197 L p .35532 .52763 L F P
0 g
s
.512 .642 .914 r
.35532 .52763 m .37116 .52744 L .36941 .52049 L p F P
0 g
s
.497 .637 .917 r
.34212 .51994 m .34922 .52002 L .35532 .52763 L p F P
0 g
s
.534 .072 .102 r
.52767 .98325 m .54366 .98295 L p .54818 .98882 L F P
0 g
s
.534 .072 .102 r
.52547 .98608 m .52767 .98325 L p .54818 .98882 L F P
0 g
s
.609 .191 .225 r
.52547 .98608 m .51848 .98313 L .52767 .98325 L closepath p F P
0 g
s
.634 .645 .844 r
.37026 .25217 m .37609 .26176 L .39211 .24916 L p F P
0 g
s
.626 .643 .847 r
.39608 .25626 m .39211 .24916 L .37609 .26176 L p F P
0 g
s
.615 .731 .928 r
.4387 .54784 m .42838 .55033 L .42373 .54371 L p F P
0 g
s
.811 .551 .546 r
.37319 .93906 m .36124 .9358 L .36119 .92549 L p F P
0 g
s
.818 .558 .545 r
.34965 .92209 m .36119 .92549 L .36124 .9358 L p F P
0 g
s
.195 .318 .763 r
.24388 .4296 m .24623 .43135 L .24614 .43485 L closepath p F P
0 g
s
.573 .112 .12 r
.51848 .98313 m .52547 .98608 L .52196 .98918 L p F P
0 g
s
.573 .112 .12 r
.5006 .98277 m .51848 .98313 L p .52196 .98918 L F P
0 g
s
.775 .719 .801 r
.66796 .2647 m .65467 .276 L .64581 .27021 L p F P
0 g
s
0 .014 .545 r
.22689 .37633 m .22721 .37789 L .22679 .37699 L closepath p F P
0 g
s
0 .013 .545 r
.22679 .37699 m .22721 .37789 L .22945 .38867 L p F P
0 g
s
.771 .854 .913 r
.71062 .51942 m .69905 .52662 L .69423 .52243 L p F P
0 g
s
.814 .702 .741 r
.34417 .82427 m .33688 .82103 L p .33687 .83795 L F P
0 g
s
.807 .712 .76 r
.34417 .82427 m .33956 .81791 L .33688 .82103 L closepath p F P
0 g
s
.059 .083 .57 r
.45038 .46346 m .4545 .45346 L .44998 .44611 L p F P
0 g
s
.258 .202 .601 r
.45348 .47136 m .45038 .46346 L .4545 .45346 L p F P
0 g
s
.842 .946 .588 r
.23536 .31909 m .2388 .31045 L .24508 .29973 L p F P
0 g
s
.742 .791 .303 r
.2311 .33137 m .23276 .32589 L .23536 .31909 L p F P
0 g
s
0 0 0 r
.2388 .31045 m .23536 .31909 L .23276 .32589 L p F P
0 g
s
.747 .717 .823 r
.42737 .75344 m .42982 .75178 L .42492 .75021 L closepath p F P
0 g
s
.755 .72 .819 r
.42492 .75021 m .42737 .75344 L p .40114 .76039 L F P
0 g
s
.984 .717 .337 r
.46091 .52112 m .45732 .51407 L .45722 .50498 L p F P
0 g
s
.996 .787 .504 r
.45732 .51407 m .46091 .52112 L .45947 .53077 L p F P
0 g
s
.969 .738 .535 r
.46214 .53406 m .45947 .53077 L .46091 .52112 L p F P
0 g
s
.582 .169 .226 r
.55156 .98546 m .54366 .98295 L .55348 .98269 L closepath p F P
0 g
s
.534 .072 .102 r
.54366 .98295 m .55156 .98546 L .54818 .98882 L p F P
0 g
s
.2 .146 .568 r
.59646 .52605 m .59269 .53174 L .59129 .5211 L p F P
0 g
s
.2 .146 .568 r
.59129 .5211 m .59337 .51775 L .59646 .52605 L p F P
0 g
s
.541 .385 .619 r
.71137 .8963 m .73078 .88902 L p .72315 .90396 L F P
0 g
s
.541 .385 .619 r
.72315 .90396 m .71148 .89705 L .71137 .8963 L p F P
0 g
s
.551 .416 .65 r
.72851 .87697 m .73078 .88902 L .71137 .8963 L p F P
0 g
s
.782 .699 .772 r
.62715 .3034 m .63988 .29008 L .63111 .28427 L p F P
0 g
s
.644 .761 .933 r
.60054 .55015 m .62142 .54415 L .6266 .54979 L p F P
0 g
s
.645 .669 .859 r
.60015 .54952 m .60054 .55015 L .62142 .54415 L p F P
0 g
s
.497 .412 .691 r
.45342 .38327 m .44369 .3911 L .44648 .40282 L p F P
0 g
s
.832 .645 .65 r
.33602 .88324 m .33654 .88181 L .33539 .88138 L closepath p F P
0 g
s
.825 .661 .679 r
.33026 .86965 m .33183 .86628 L p .33654 .88181 L F P
0 g
s
.825 .661 .679 r
.33654 .88181 m .33539 .88138 L .33026 .86965 L p F P
0 g
s
.449 .57 .884 r
.31148 .49395 m .29755 .49201 L .29659 .48367 L p F P
0 g
s
.439 .571 .89 r
.3166 .50137 m .31682 .50275 L p .29755 .49201 L F P
0 g
s
.439 .571 .89 r
.29755 .49201 m .31148 .49395 L .3166 .50137 L p F P
0 g
s
.985 .897 .641 r
.818 .39365 m .81919 .40152 L .82344 .39095 L p F P
0 g
s
.985 .897 .641 r
.82344 .39095 m .82222 .38307 L .818 .39365 L p F P
0 g
s
.573 .112 .12 r
.49941 .98421 m .5006 .98277 L p .52196 .98918 L F P
0 g
s
.641 .226 .242 r
.49941 .98421 m .49642 .98255 L .5006 .98277 L closepath p F P
0 g
s
.738 .724 .838 r
.44189 .73313 m .4477 .74066 L .42982 .75178 L p F P
0 g
s
.738 .724 .838 r
.42151 .74593 m .44189 .73313 L p .42982 .75178 L F P
0 g
s
.738 .724 .838 r
.42982 .75178 m .42492 .75021 L .42151 .74593 L p F P
0 g
s
.732 .722 .841 r
.66796 .2647 m .67648 .25931 L .66807 .25332 L p F P
0 g
s
.732 .722 .841 r
.66807 .25332 m .66286 .25646 L .66796 .2647 L p F P
0 g
s
.775 .719 .801 r
.64581 .27021 m .66286 .25646 L .66796 .2647 L p F P
0 g
s
.668 .671 .843 r
.57921 .73559 m .57803 .73372 L .56793 .73731 L closepath p F P
0 g
s
.669 .677 .848 r
.57261 .72531 m .57803 .73372 L .56793 .73731 L p F P
0 g
s
.669 .677 .848 r
.55195 .73269 m .57261 .72531 L p .56793 .73731 L F P
0 g
s
.54 .386 .62 r
.71297 .9077 m .71148 .89705 L .72315 .90396 L closepath p F P
0 g
s
.509 .058 .114 r
.55348 .98269 m .57416 .98149 L p .57329 .9875 L F P
0 g
s
.509 .058 .114 r
.55156 .98546 m .55348 .98269 L p .57329 .9875 L F P
0 g
s
.827 .71 .736 r
.61802 .33304 m .60882 .32749 L .61809 .3154 L p F P
0 g
s
.806 .691 .737 r
.61216 .3411 m .61802 .33304 L .60882 .32749 L p F P
0 g
s
0 0 .43 r
.22689 .37633 m .22895 .36678 L .22705 .35911 L p F P
0 g
s
.019 .073 .578 r
.22895 .36678 m .22689 .37633 L .22721 .37789 L p F P
0 g
s
.621 .616 .825 r
.66217 .75587 m .64109 .76005 L .63578 .74981 L p F P
0 g
s
.531 .324 .544 r
.69412 .93512 m .69384 .92488 L .71396 .91855 L p F P
0 g
s
.549 .366 .586 r
.71297 .9077 m .71396 .91855 L .69384 .92488 L p F P
0 g
s
.555 .571 .825 r
.59515 .53931 m .60974 .5391 L .60015 .54952 L closepath p F P
0 g
s
.645 .669 .859 r
.61617 .53789 m .60974 .5391 L .60015 .54952 L p F P
0 g
s
.645 .669 .859 r
.62142 .54415 m .61617 .53789 L p .60015 .54952 L F P
0 g
s
.234 .34 .768 r
.24388 .4296 m .24623 .43135 L p .23892 .41637 L F P
0 g
s
.234 .34 .768 r
.23892 .41637 m .23882 .41769 L .24388 .4296 L p F P
0 g
s
.604 .589 .809 r
.67406 .78046 m .67274 .77767 L .68302 .77631 L closepath p F P
0 g
s
0 0 .288 r
.82031 .32731 m .82138 .33032 L .82214 .33289 L closepath p F P
0 g
s
.826 .554 .004 r
.82277 .33882 m .82401 .34307 L .82214 .33289 L p F P
0 g
s
.826 .554 .004 r
.82214 .33289 m .82138 .33032 L .82277 .33882 L p F P
0 g
s
.954 .785 .635 r
.59823 .43723 m .60273 .4441 L .60604 .43392 L p F P
0 g
s
.954 .785 .635 r
.60604 .43392 m .60147 .42706 L .59823 .43723 L p F P
0 g
s
.614 .159 .15 r
.49642 .98255 m .49941 .98421 L .49439 .98844 L p F P
0 g
s
.614 .159 .15 r
.47686 .98134 m .49642 .98255 L p .49439 .98844 L F P
0 g
s
.679 .358 0 r
.81656 .31697 m .82031 .32731 L .82138 .33032 L p F P
0 g
s
.83 .621 .621 r
.34006 .89585 m .33244 .89309 L p .34009 .90784 L F P
0 g
s
.83 .621 .621 r
.34009 .90784 m .34146 .9026 L .34006 .89585 L p F P
0 g
s
.829 .641 .649 r
.34006 .89585 m .33602 .88324 L .33244 .89309 L closepath p F P
0 g
s
.019 .073 .578 r
.22721 .37789 m .23023 .38413 L p .22895 .36678 L F P
0 g
s
0 .033 .556 r
.22721 .37789 m .23023 .38413 L .22945 .38867 L closepath p F P
0 g
s
.832 .645 .65 r
.33244 .89309 m .33602 .88324 L .33539 .88138 L p F P
0 g
s
.533 .665 .921 r
.38094 .53446 m .37389 .53485 L .37116 .52744 L p F P
0 g
s
.832 .645 .65 r
.33539 .88138 m .32644 .87788 L p .33244 .89309 L F P
0 g
s
.829 .663 .676 r
.33539 .88138 m .33026 .86965 L .32644 .87788 L closepath p F P
0 g
s
.701 .779 .912 r
.62973 .54846 m .6266 .54979 L .62142 .54415 L p F P
0 g
s
.857 .718 .708 r
.61195 .36155 m .60396 .35565 L .61015 .34463 L p F P
0 g
s
.855 .706 .696 r
.60396 .35565 m .61195 .36155 L .60627 .37241 L p F P
0 g
s
.802 .512 .497 r
.38113 .95057 m .37493 .949 L .37319 .93906 L p F P
0 g
s
.81 .516 .493 r
.36124 .9358 m .37319 .93906 L .37493 .949 L p F P
0 g
s
.825 .698 .723 r
.32739 .83372 m .33687 .83795 L .32877 .85025 L p F P
0 g
s
.814 .702 .741 r
.33688 .82103 m .32739 .83372 L .33687 .83795 L p F P
0 g
s
.611 .583 .798 r
.40411 .2725 m .40768 .28018 L .42769 .27503 L p F P
0 g
s
.603 .562 .781 r
.42977 .28029 m .42769 .27503 L .40768 .28018 L p F P
0 g
s
.517 .173 .323 r
.6251 .97571 m .62781 .9678 L .64999 .96385 L p F P
0 g
s
.559 .266 .426 r
.65035 .962 m .64999 .96385 L .62781 .9678 L p F P
0 g
s
.782 .699 .772 r
.62692 .30327 m .62715 .3034 L p .63111 .28427 L F P
0 g
s
.788 .701 .768 r
.62692 .30327 m .62705 .30351 L .62715 .3034 L closepath p F P
0 g
s
.814 .709 .75 r
.62705 .30351 m .61809 .3154 L p .61844 .2976 L F P
0 g
s
.814 .709 .75 r
.61844 .2976 m .62692 .30327 L .62705 .30351 L p F P
0 g
s
.541 .189 .321 r
.6251 .97571 m .61932 .97652 L .60358 .9752 L p F P
0 g
s
.536 .173 .298 r
.61932 .97652 m .60205 .97884 L .60358 .9752 L closepath p F P
0 g
s
.575 .223 .335 r
.60358 .9752 m .60205 .97884 L .57825 .98122 L p F P
0 g
s
.503 .633 .91 r
.34922 .52002 m .34212 .51994 L .3402 .51213 L p F P
0 g
s
.697 .705 .854 r
.52033 .72486 m .49986 .73407 L .49422 .72636 L p F P
0 g
s
.782 .699 .772 r
.63111 .28427 m .62175 .2935 L .62692 .30327 L p F P
0 g
s
.814 .709 .75 r
.62175 .2935 m .61844 .2976 L .62692 .30327 L closepath p F P
0 g
s
.639 .643 .837 r
.63047 .74021 m .60956 .74564 L .6042 .7363 L p F P
0 g
s
.947 .725 .26 r
.82304 .34888 m .82487 .35561 L .82495 .34656 L p F P
0 g
s
.947 .725 .26 r
.82495 .34656 m .82401 .34307 L .82304 .34888 L p F P
0 g
s
.683 .694 .854 r
.54645 .72451 m .5259 .7328 L .52033 .72486 L p F P
0 g
s
.421 .543 .874 r
.28643 .48152 m .29659 .48367 L p .28028 .47188 L F P
0 g
s
.421 .543 .874 r
.28028 .47188 m .28028 .47193 L .28643 .48152 L p F P
0 g
s
.604 .59 .81 r
.68302 .77631 m .67274 .77767 L .66745 .76654 L p F P
0 g
s
.787 .728 .797 r
.3674 .7754 m .37698 .77975 L .36135 .79415 L p F P
0 g
s
.777 .73 .809 r
.37474 .76924 m .3674 .7754 L .37698 .77975 L p F P
0 g
s
.777 .73 .809 r
.37698 .77975 m .38075 .77661 L .37474 .76924 L p F P
0 g
s
.798 .721 .779 r
.36026 .79527 m .36135 .79415 L .35837 .79279 L closepath p F P
0 g
s
.787 .728 .797 r
.35421 .78767 m .3674 .7754 L p .36135 .79415 L F P
0 g
s
.787 .728 .797 r
.36135 .79415 m .35837 .79279 L .35421 .78767 L p F P
0 g
s
.799 .721 .778 r
.34818 .80785 m .36026 .79527 L .35837 .79279 L p F P
0 g
s
.931 .773 .664 r
.45947 .53077 m .46214 .53406 L .45916 .53157 L closepath p F P
0 g
s
.821 .799 .831 r
.4434 .54533 m .45916 .53157 L .46214 .53406 L p F P
0 g
s
.833 .667 .677 r
.33026 .86965 m .33183 .86628 L .32799 .8647 L closepath p F P
0 g
s
.825 .682 .705 r
.32436 .85811 m .32877 .85025 L p .33183 .86628 L F P
0 g
s
.825 .682 .705 r
.33183 .86628 m .32799 .8647 L .32436 .85811 L p F P
0 g
s
.751 .86 .929 r
.29948 .2535 m .29472 .25956 L .2919 .25793 L closepath p F P
0 g
s
.768 .864 .92 r
.2718 .27198 m .2919 .25793 L .29472 .25956 L p F P
0 g
s
.774 .727 .808 r
.39567 .76444 m .38075 .77661 L .37474 .76924 L p F P
0 g
s
.701 .779 .912 r
.62142 .54415 m .63262 .53965 L .62973 .54846 L p F P
0 g
s
.696 .784 .919 r
.62973 .54846 m .64746 .54054 L .64237 .5356 L p F P
0 g
s
.696 .784 .919 r
.64237 .5356 m .63262 .53965 L .62973 .54846 L p F P
0 g
s
.322 .539 .908 r
.7726 .26512 m .77802 .2667 L .78245 .27398 L p F P
0 g
s
.183 .448 .876 r
.78854 .27167 m .79294 .27897 L .78245 .27398 L p F P
0 g
s
.183 .448 .876 r
.78245 .27398 m .77802 .2667 L .78854 .27167 L p F P
0 g
s
.993 .866 .598 r
.59664 .46442 m .59959 .45427 L .60204 .46176 L p F P
0 g
s
.993 .866 .598 r
.59858 .47129 m .59664 .46442 L p .60204 .46176 L F P
0 g
s
.993 .866 .598 r
.60204 .46176 m .59906 .47112 L .59858 .47129 L p F P
0 g
s
.789 .869 .907 r
.71062 .51942 m .71987 .51318 L .71514 .50917 L p F P
0 g
s
.789 .869 .907 r
.71514 .50917 m .71263 .51089 L .71062 .51942 L p F P
0 g
s
.771 .854 .913 r
.69423 .52243 m .71263 .51089 L .71062 .51942 L p F P
0 g
s
.547 .472 .722 r
.44361 .36051 m .4534 .3533 L p .44924 .34073 L F P
0 g
s
.525 .442 .704 r
.4534 .3533 m .45557 .36161 L .44361 .36051 L closepath p F P
0 g
s
.525 .445 .707 r
.45663 .36614 m .45557 .36161 L .44361 .36051 L p F P
0 g
s
.827 .618 .621 r
.34267 .90871 m .34146 .9026 L .34009 .90784 L closepath p F P
0 g
s
.716 .706 .839 r
.47381 .73653 m .47504 .73587 L .47309 .73554 L closepath p F P
0 g
s
.729 .711 .834 r
.47309 .73554 m .47381 .73653 L p .4477 .74066 L F P
0 g
s
.873 .726 .696 r
.60796 .38936 m .60057 .38332 L .60627 .37241 L p F P
0 g
s
.861 .714 .699 r
.60289 .39946 m .60796 .38936 L .60057 .38332 L p F P
0 g
s
.891 .753 .702 r
.60796 .38936 m .60289 .39946 L .60546 .40331 L p F P
0 g
s
.745 .729 .837 r
.68875 .25133 m .67648 .25931 L .66807 .25332 L p F P
0 g
s
.497 .412 .691 r
.44648 .40282 m .4472 .40315 L p .45342 .38327 L F P
0 g
s
.462 .379 .677 r
.44648 .40282 m .4472 .40315 L .44666 .40363 L closepath p F P
0 g
s
0 0 .51 r
.81514 .31369 m .81578 .31477 L .81656 .31697 L closepath p F P
0 g
s
.679 .358 0 r
.8187 .32268 m .81578 .31477 L .81656 .31697 L p F P
0 g
s
.679 .358 0 r
.82138 .33032 m .8187 .32268 L p .81656 .31697 L F P
0 g
s
.459 .374 .673 r
.4472 .40315 m .44666 .40363 L .44924 .41574 L p F P
0 g
s
.611 .721 .924 r
.41979 .53679 m .40678 .53939 L .41274 .54611 L p F P
0 g
s
.611 .721 .924 r
.41274 .54611 m .42373 .54371 L .41979 .53679 L p F P
0 g
s
0 0 .011 r
.23276 .32589 m .2311 .33137 L .22956 .34028 L p F P
0 g
s
.561 .481 .723 r
.71794 .83705 m .73151 .83066 L p .72805 .84834 L F P
0 g
s
.561 .481 .723 r
.72805 .84834 m .72109 .8476 L .71794 .83705 L p F P
0 g
s
.567 .504 .744 r
.71794 .83705 m .71551 .8298 L .73151 .83066 L closepath p F P
0 g
s
.709 .714 .853 r
.48854 .71884 m .49422 .72636 L .47504 .73587 L p F P
0 g
s
.709 .714 .853 r
.46808 .729 m .48854 .71884 L p .47504 .73587 L F P
0 g
s
.709 .714 .853 r
.47504 .73587 m .47309 .73554 L .46808 .729 L p F P
0 g
s
.806 .691 .737 r
.60882 .32749 m .60678 .33012 L .61216 .3411 L p F P
0 g
s
.838 .693 .701 r
.60137 .33895 m .60678 .33012 L .61216 .3411 L p F P
0 g
s
.838 .693 .701 r
.61216 .3411 m .61015 .34463 L .60137 .33895 L p F P
0 g
s
.67 .683 .854 r
.57261 .72531 m .55195 .73269 L .54645 .72451 L p F P
0 g
s
.561 .162 .243 r
.57762 .98228 m .57416 .98149 L .57825 .98122 L closepath p F P
0 g
s
.509 .058 .114 r
.57416 .98149 m .57762 .98228 L .57329 .9875 L p F P
0 g
s
.83 .944 .898 r
.2718 .27198 m .27005 .27343 L .2709 .27184 L closepath p F P
0 g
s
.849 .976 .87 r
.2709 .27184 m .27005 .27343 L .25478 .28768 L p F P
0 g
s
.917 .914 .8 r
.79771 .43552 m .80596 .42435 L .80647 .43232 L p F P
0 g
s
.917 .914 .8 r
.80647 .43232 m .80193 .43835 L .79771 .43552 L p F P
0 g
s
.755 .72 .819 r
.40114 .76039 m .4185 .74791 L .42492 .75021 L p F P
0 g
s
.747 .726 .832 r
.42492 .75021 m .42151 .74593 L .4185 .74791 L closepath p F P
0 g
s
.809 .948 .913 r
.28505 .25538 m .2919 .25793 L .2718 .27198 L p F P
0 g
s
.809 .948 .913 r
.27884 .26008 m .28505 .25538 L p .2718 .27198 L F P
0 g
s
.809 .948 .913 r
.2718 .27198 m .2709 .27184 L .27884 .26008 L p F P
0 g
s
.567 .502 .742 r
.73151 .83066 m .71551 .8298 L .71302 .82229 L p F P
0 g
s
.916 .75 .66 r
.60289 .39946 m .60263 .40015 L .60546 .40331 L closepath p F P
0 g
s
.614 .159 .15 r
.49439 .98844 m .49189 .98828 L .47686 .98134 L p F P
0 g
s
.565 .063 .021 r
.47192 .981 m .47686 .98134 L .49189 .98828 L p F P
0 g
s
.849 .998 .786 r
.26153 .2752 m .25478 .28768 L .25121 .29166 L p F P
0 g
s
.849 .976 .87 r
.25478 .28768 m .26153 .2752 L p .2709 .27184 L F P
0 g
s
.658 .701 .879 r
.35807 .23511 m .33815 .24316 L .34439 .25046 L p F P
0 g
s
.658 .701 .879 r
.34439 .25046 m .36421 .2432 L .35807 .23511 L p F P
0 g
s
.692 .765 .908 r
.3318 .23681 m .31185 .24657 L .31833 .25194 L p F P
0 g
s
.692 .765 .908 r
.31833 .25194 m .33815 .24316 L .3318 .23681 L p F P
0 g
s
.127 .237 .709 r
.23802 .41547 m .23892 .41637 L .23882 .41769 L closepath p F P
0 g
s
.728 .343 .32 r
.44121 .9777 m .42703 .97546 L .41937 .96685 L p F P
0 g
s
.721 .315 .279 r
.41337 .96587 m .41937 .96685 L .42703 .97546 L p F P
0 g
s
.811 .717 .761 r
.34818 .80785 m .33956 .81791 L .33346 .80991 L p F P
0 g
s
.811 .717 .761 r
.33346 .80991 m .33892 .80347 L .34818 .80785 L p F P
0 g
s
.799 .721 .778 r
.35195 .78978 m .33892 .80347 L .34818 .80785 L p F P
0 g
s
.799 .721 .778 r
.35837 .79279 m .35195 .78978 L p .34818 .80785 L F P
0 g
s
.655 .666 .848 r
.59882 .72726 m .60078 .73042 L .57921 .73559 L p F P
0 g
s
.655 .666 .848 r
.57921 .73559 m .57803 .73372 L .59882 .72726 L p F P
0 g
s
.567 .502 .742 r
.71302 .82229 m .729 .81449 L p .73151 .83066 L F P
0 g
s
.573 .524 .763 r
.71302 .82229 m .71006 .81427 L .729 .81449 L closepath p F P
0 g
s
.497 .412 .691 r
.4472 .40315 m .46212 .39073 L p .45342 .38327 L F P
0 g
s
.466 .37 .662 r
.46212 .39073 m .4472 .40315 L .45768 .40819 L p F P
0 g
s
.459 .374 .673 r
.44924 .41574 m .45768 .40819 L .4472 .40315 L p F P
0 g
s
.774 .727 .808 r
.37474 .76924 m .38577 .76016 L .39567 .76444 L p F P
0 g
s
.763 .731 .823 r
.39518 .75312 m .38577 .76016 L .39567 .76444 L p F P
0 g
s
.763 .731 .823 r
.39567 .76444 m .40114 .76039 L .39518 .75312 L p F P
0 g
s
.729 .711 .834 r
.4477 .74066 m .46124 .73272 L .47309 .73554 L p F P
0 g
s
.722 .718 .846 r
.47309 .73554 m .46808 .729 L .46124 .73272 L closepath p F P
0 g
s
.102 .177 .656 r
.23023 .38413 m .22945 .38867 L .23238 .39898 L p F P
0 g
s
.529 .128 .225 r
.57762 .98228 m .57825 .98122 L .60205 .97884 L p F P
0 g
s
.56 .483 .724 r
.72213 .85104 m .72109 .8476 L .72805 .84834 L closepath p F P
0 g
s
.174 .265 .719 r
.23802 .41547 m .23892 .41637 L p .23357 .40064 L F P
0 g
s
.174 .265 .719 r
.23357 .40064 m .23336 .40239 L .23802 .41547 L p F P
0 g
s
.549 .456 .701 r
.72563 .86432 m .72213 .85104 L .72805 .84834 L p F P
0 g
s
.927 .776 .301 r
.59596 .49136 m .59668 .4993 L .59805 .48963 L p F P
0 g
s
.927 .776 .301 r
.59805 .48963 m .5971 .48174 L .59596 .49136 L p F P
0 g
s
.833 .667 .677 r
.32644 .87788 m .33026 .86965 L .32799 .8647 L p F P
0 g
s
.565 .063 .021 r
.46752 .98484 m .47192 .981 L p .49189 .98828 L F P
0 g
s
.656 .216 .192 r
.46752 .98484 m .45914 .97968 L .47192 .981 L closepath p F P
0 g
s
.849 .998 .786 r
.25121 .29166 m .24749 .29412 L p .26153 .2752 L F P
0 g
s
.873 .989 .726 r
.25121 .29166 m .24508 .29973 L .24749 .29412 L closepath p F P
0 g
s
.824 .592 .588 r
.34965 .92209 m .34335 .9201 L .34267 .90871 L p F P
0 g
s
.831 .597 .585 r
.34009 .90784 m .34267 .90871 L .34335 .9201 L p F P
0 g
s
.351 .285 .642 r
.45393 .4395 m .44998 .44611 L p .45165 .42796 L F P
0 g
s
.251 .21 .616 r
.45393 .4395 m .44998 .44611 L .4545 .45346 L p F P
0 g
s
.573 .112 .12 r
.52196 .98918 m .51359 .98899 L .49941 .98421 L p F P
0 g
s
.571 .103 .105 r
.51359 .98899 m .49439 .98844 L .49941 .98421 L closepath p F P
0 g
s
.777 .444 .424 r
.40518 .96425 m .39179 .96142 L .38763 .95203 L p F P
0 g
s
.779 .435 .405 r
.38113 .95057 m .38763 .95203 L .39179 .96142 L p F P
0 g
s
.619 .585 .794 r
.40192 .26773 m .40411 .2725 L .42198 .26195 L p F P
0 g
s
.611 .583 .798 r
.42769 .27503 m .42198 .26195 L .40411 .2725 L p F P
0 g
s
.867 .578 .052 r
.8201 .33118 m .82277 .33882 L .82138 .33032 L p F P
0 g
s
.867 .578 .052 r
.82138 .33032 m .8187 .32268 L .8201 .33118 L p F P
0 g
s
.76 .728 .823 r
.4185 .74791 m .40114 .76039 L .39518 .75312 L p F P
0 g
s
.796 .868 .902 r
.73584 .50192 m .71987 .51318 L .71514 .50917 L p F P
0 g
s
.102 .177 .656 r
.23238 .39898 m .23357 .40064 L p .23023 .38413 L F P
0 g
s
.05 .142 .641 r
.23238 .39898 m .23357 .40064 L .23336 .40239 L closepath p F P
0 g
s
0 0 .494 r
.81578 .31477 m .81514 .31369 L .81029 .30335 L p F P
0 g
s
0 0 .246 r
.22705 .35911 m .22982 .34855 L .22956 .34028 L p F P
0 g
s
0 0 .441 r
.22982 .34855 m .22705 .35911 L .22895 .36678 L p F P
0 g
s
.839 .692 .7 r
.60137 .33895 m .61015 .34463 L .60396 .35565 L p F P
0 g
s
.234 .34 .768 r
.24623 .43135 m .24699 .42198 L .23892 .41637 L p F P
0 g
s
.312 .4 .792 r
.25586 .43647 m .24623 .43135 L .24699 .42198 L p F P
0 g
s
.286 .403 .806 r
.2555 .4456 m .25586 .43647 L .24623 .43135 L p F P
0 g
s
.791 .728 .794 r
.35837 .79279 m .35421 .78767 L .35195 .78978 L closepath p F P
0 g
s
.919 .748 .654 r
.60488 .41687 m .59896 .4104 L .60263 .40015 L p F P
0 g
s
.921 .744 .646 r
.59896 .4104 m .60488 .41687 L .60147 .42706 L p F P
0 g
s
.573 .523 .761 r
.729 .81449 m .71006 .81427 L .70725 .80662 L p F P
0 g
s
.919 .916 .797 r
.79718 .44464 m .80193 .43835 L .79771 .43552 L p F P
0 g
s
.731 .719 .839 r
.46124 .73272 m .4477 .74066 L .44189 .73313 L p F P
0 g
s
.626 .722 .916 r
.7315 .23677 m .70989 .24185 L .71477 .24913 L p F P
0 g
s
.626 .722 .916 r
.71477 .24913 m .7363 .24371 L .7315 .23677 L p F P
0 g
s
.352 .452 .823 r
.26682 .4502 m .2555 .4456 L .25586 .43647 L p F P
0 g
s
.33 .455 .837 r
.2668 .45912 m .26682 .4502 L .2555 .4456 L p F P
0 g
s
.814 .709 .75 r
.61809 .3154 m .60836 .30998 L .61844 .2976 L p F P
0 g
s
.79 .675 .737 r
.60882 .32749 m .61809 .3154 L .60836 .30998 L p F P
0 g
s
.656 .672 .853 r
.59882 .72726 m .57803 .73372 L .57261 .72531 L p F P
0 g
s
.469 .643 .933 r
.76793 .25799 m .75494 .25746 L .74955 .25042 L p F P
0 g
s
.48 .64 .926 r
.75494 .25746 m .76793 .25799 L .7726 .26512 L p F P
0 g
s
0 .001 .506 r
.59897 .51716 m .59646 .52605 L .59337 .51775 L p F P
0 g
s
0 .001 .506 r
.59337 .51775 m .59655 .50862 L .59897 .51716 L p F P
0 g
s
0 .261 .77 r
.80047 .2851 m .80437 .29252 L .79687 .28638 L p F P
0 g
s
0 .261 .77 r
.79687 .28638 m .79294 .27897 L .80047 .2851 L p F P
0 g
s
.821 .979 .889 r
.27884 .26008 m .2709 .27184 L .26461 .27212 L closepath p F P
0 g
s
.849 .976 .87 r
.26153 .2752 m .26461 .27212 L .2709 .27184 L p F P
0 g
s
.811 .719 .763 r
.33688 .82103 m .33956 .81791 L .33346 .80991 L p F P
0 g
s
.834 .687 .701 r
.32877 .85025 m .32436 .85811 L .31836 .84775 L p F P
0 g
s
.834 .687 .701 r
.31836 .84775 m .31931 .84603 L .32877 .85025 L p F P
0 g
s
.825 .698 .723 r
.32877 .85025 m .31931 .84603 L .32739 .83372 L p F P
0 g
s
.996 .866 .56 r
.82054 .37528 m .82222 .38307 L .82506 .373 L p F P
0 g
s
.996 .866 .56 r
.82506 .373 m .82338 .36519 L .82054 .37528 L p F P
0 g
s
.833 .667 .677 r
.32799 .8647 m .32205 .8622 L p .32644 .87788 L F P
0 g
s
.829 .683 .701 r
.32799 .8647 m .32436 .85811 L .32205 .8622 L closepath p F P
0 g
s
.174 .265 .719 r
.23892 .41637 m .24014 .40674 L .23357 .40064 L p F P
0 g
s
.244 .335 .759 r
.24014 .40674 m .23892 .41637 L .24699 .42198 L p F P
0 g
s
.747 .831 .916 r
.68035 .53068 m .67335 .53455 L .66839 .52991 L p F P
0 g
s
.732 .828 .924 r
.64746 .54054 m .66839 .52991 L .67335 .53455 L p F P
0 g
s
.721 .315 .279 r
.40957 .97037 m .41337 .96587 L p .42703 .97546 L F P
0 g
s
.754 .379 .344 r
.40957 .97037 m .40518 .96425 L .41337 .96587 L closepath p F P
0 g
s
.713 .76 .889 r
.4387 .54784 m .4434 .54533 L .43906 .53859 L p F P
0 g
s
.713 .76 .889 r
.43906 .53859 m .4328 .54162 L .4387 .54784 L p F P
0 g
s
.615 .731 .928 r
.42373 .54371 m .4328 .54162 L .4387 .54784 L p F P
0 g
s
.698 .741 .884 r
.70497 .23458 m .68374 .24362 L .68875 .25133 L p F P
0 g
s
.698 .741 .884 r
.68875 .25133 m .70989 .24185 L .70497 .23458 L p F P
0 g
s
.745 .729 .837 r
.66807 .25332 m .68374 .24362 L .68875 .25133 L p F P
0 g
s
0 0 .396 r
.45455 .48847 m .45614 .47948 L .45348 .47136 L p F P
0 g
s
.564 .497 .738 r
.59269 .53174 m .59515 .53931 L .60974 .5391 L p F P
0 g
s
.573 .523 .761 r
.70725 .80662 m .72057 .79987 L p .729 .81449 L F P
0 g
s
.579 .545 .781 r
.70725 .80662 m .70468 .80024 L .72057 .79987 L closepath p F P
0 g
s
.831 .597 .585 r
.34335 .9201 m .33862 .91851 L .34009 .90784 L p F P
0 g
s
.839 .604 .584 r
.32964 .90407 m .34009 .90784 L .33862 .91851 L p F P
0 g
s
.83 .621 .621 r
.33244 .89309 m .32964 .90407 L .34009 .90784 L p F P
0 g
s
0 0 .494 r
.81029 .30335 m .81266 .30721 L .81578 .31477 L p F P
0 g
s
.704 .365 0 r
.81559 .31512 m .8187 .32268 L .81578 .31477 L p F P
0 g
s
.704 .365 0 r
.81578 .31477 m .81266 .30721 L .81559 .31512 L p F P
0 g
s
.564 .497 .738 r
.61028 .53093 m .59646 .52605 L .59269 .53174 L p F P
0 g
s
.564 .497 .738 r
.60974 .5391 m .61028 .53093 L p .59269 .53174 L F P
0 g
s
.823 .714 .744 r
.32776 .81663 m .33688 .82103 L .32739 .83372 L p F P
0 g
s
.811 .719 .763 r
.33346 .80991 m .32776 .81663 L .33688 .82103 L p F P
0 g
s
.963 .907 .715 r
.81313 .40316 m .818 .39365 L .81919 .40152 L p F P
0 g
s
.963 .907 .715 r
.81919 .40152 m .81719 .40533 L .81313 .40316 L p F P
0 g
s
.47 .598 .898 r
.3166 .50137 m .31765 .50281 L .31682 .50275 L closepath p F P
0 g
s
.486 .038 .111 r
.57329 .9875 m .57762 .98228 L .59857 .98404 L p F P
0 g
s
.529 .128 .225 r
.60205 .97884 m .59857 .98404 L .57762 .98228 L p F P
0 g
s
.542 .431 .677 r
.72563 .86432 m .74429 .85593 L p .73715 .87319 L F P
0 g
s
.542 .431 .677 r
.73715 .87319 m .72695 .87017 L .72563 .86432 L p F P
0 g
s
.549 .456 .701 r
.74304 .85132 m .74429 .85593 L .72563 .86432 L p F P
0 g
s
.549 .456 .701 r
.72805 .84834 m .74304 .85132 L p .72563 .86432 L F P
0 g
s
.621 .596 .804 r
.41615 .24984 m .39608 .25626 L .40192 .26773 L p F P
0 g
s
.621 .596 .804 r
.40192 .26773 m .42195 .26189 L .41615 .24984 L p F P
0 g
s
.619 .585 .794 r
.42198 .26195 m .42195 .26189 L .40192 .26773 L p F P
0 g
s
.525 .349 .585 r
.72315 .90396 m .71297 .9077 L .71396 .91855 L p F P
0 g
s
.855 .706 .696 r
.60627 .37241 m .59777 .36671 L .60396 .35565 L p F P
0 g
s
.833 .684 .698 r
.60057 .38332 m .60627 .37241 L .59777 .36671 L p F P
0 g
s
0 .016 .588 r
.80552 .29401 m .80437 .29252 L .8078 .30005 L p F P
0 g
s
0 .016 .588 r
.8078 .30005 m .81029 .30335 L .80552 .29401 L p F P
0 g
s
.457 .371 .67 r
.45768 .40819 m .44924 .41574 L .45176 .42781 L p F P
0 g
s
.341 .292 .657 r
.45165 .42796 m .45176 .42781 L .44924 .41574 L p F P
0 g
s
.818 .558 .545 r
.36124 .9358 m .34965 .93242 L .34965 .92209 L p F P
0 g
s
.825 .564 .544 r
.34335 .9201 m .34965 .92209 L .34965 .93242 L p F P
0 g
s
.387 .497 .849 r
.27411 .46132 m .2668 .45912 L .26682 .4502 L p F P
0 g
s
.371 .492 .852 r
.2668 .45912 m .27411 .46132 L .28025 .47188 L p F P
0 g
s
.919 .916 .797 r
.79771 .43552 m .79689 .43662 L .79718 .44464 L p F P
0 g
s
.893 .902 .827 r
.78574 .4496 m .78594 .45761 L .79718 .44464 L p F P
0 g
s
.893 .902 .827 r
.79718 .44464 m .79689 .43662 L .78574 .4496 L p F P
0 g
s
.31 .542 .913 r
.77315 .25951 m .76793 .25799 L .7726 .26512 L p F P
0 g
s
.31 .542 .913 r
.7726 .26512 m .77802 .2667 L .77315 .25951 L p F P
0 g
s
.621 .616 .825 r
.63578 .74981 m .65689 .74566 L .66217 .75587 L p F P
0 g
s
.62 .616 .825 r
.65377 .73968 m .65689 .74566 L .63578 .74981 L p F P
0 g
s
.62 .616 .825 r
.63578 .74981 m .63471 .74775 L .65377 .73968 L p F P
0 g
s
.842 .633 .62 r
.32237 .88917 m .33244 .89309 L .32964 .90407 L p F P
0 g
s
.832 .645 .65 r
.32644 .87788 m .32237 .88917 L .33244 .89309 L p F P
0 g
s
.639 .654 .849 r
.38419 .23607 m .36421 .2432 L .37026 .25217 L p F P
0 g
s
.639 .654 .849 r
.37026 .25217 m .39018 .24569 L .38419 .23607 L p F P
0 g
s
.634 .645 .844 r
.39211 .24916 m .39018 .24569 L .37026 .25217 L p F P
0 g
s
.558 .676 .918 r
.39475 .52514 m .37488 .52722 L .38094 .53446 L p F P
0 g
s
.558 .676 .918 r
.38094 .53446 m .40078 .5324 L .39475 .52514 L p F P
0 g
s
.533 .665 .921 r
.37116 .52744 m .37488 .52722 L .38094 .53446 L p F P
0 g
s
.798 .916 .527 r
.24749 .29412 m .24508 .29973 L .2388 .31045 L p F P
0 g
s
.534 .072 .102 r
.54818 .98882 m .53812 .98901 L .52547 .98608 L p F P
0 g
s
.528 .055 .076 r
.53812 .98901 m .52196 .98918 L .52547 .98608 L closepath p F P
0 g
s
.49 .608 .897 r
.31765 .50281 m .33693 .50386 L p .31591 .49446 L F P
0 g
s
.49 .608 .897 r
.31591 .49446 m .3166 .50137 L .31765 .50281 L p F P
0 g
s
.953 .723 .265 r
.82274 .34786 m .82304 .34888 L .82401 .34307 L p F P
0 g
s
.953 .723 .265 r
.82401 .34307 m .82277 .33882 L .82274 .34786 L p F P
0 g
s
.635 .162 .112 r
.45914 .97968 m .46752 .98484 L .46496 .98625 L p F P
0 g
s
.635 .162 .112 r
.44214 .97781 m .45914 .97968 L p .46496 .98625 L F P
0 g
s
.689 .288 .281 r
.45914 .97968 m .44214 .97781 L .44155 .97733 L p F P
0 g
s
.76 .709 .804 r
.63842 .26632 m .64222 .27301 L .64581 .27021 L closepath p F P
0 g
s
.789 .718 .786 r
.64222 .27301 m .63111 .28427 L p .63604 .2647 L F P
0 g
s
.789 .718 .786 r
.63604 .2647 m .63842 .26632 L .64222 .27301 L p F P
0 g
s
.604 .59 .81 r
.66745 .76654 m .68878 .76383 L p .68302 .77631 L F P
0 g
s
.601 .589 .811 r
.6835 .75278 m .68878 .76383 L .66745 .76654 L p F P
0 g
s
.601 .589 .811 r
.68122 .75306 m .6835 .75278 L p .66745 .76654 L F P
0 g
s
.601 .589 .811 r
.66745 .76654 m .66488 .76114 L .68122 .75306 L p F P
0 g
s
.958 .786 .626 r
.59516 .44739 m .59959 .45427 L .60273 .4441 L p F P
0 g
s
.958 .786 .626 r
.60273 .4441 m .59823 .43723 L .59516 .44739 L p F P
0 g
s
.535 .252 .432 r
.67286 .95024 m .67154 .95901 L .65035 .962 L p F P
0 g
s
.526 .23 .408 r
.64999 .96385 m .65035 .962 L .67154 .95901 L p F P
0 g
s
.102 .177 .656 r
.23357 .40064 m .2353 .39072 L .23023 .38413 L p F P
0 g
s
.189 .265 .712 r
.2353 .39072 m .23357 .40064 L .24014 .40674 L p F P
0 g
s
.779 .435 .405 r
.37772 .95651 m .38113 .95057 L p .39179 .96142 L F P
0 g
s
.796 .467 .432 r
.37772 .95651 m .37493 .949 L .38113 .95057 L closepath p F P
0 g
s
.814 .878 .892 r
.74065 .49822 m .73584 .50192 L .73681 .49501 L closepath p F P
0 g
s
.796 .868 .902 r
.73602 .49429 m .73681 .49501 L .73584 .50192 L p F P
0 g
s
.796 .868 .902 r
.71514 .50917 m .73602 .49429 L p .73584 .50192 L F P
0 g
s
.812 .8 .84 r
.45916 .53157 m .4434 .54533 L .43906 .53859 L p F P
0 g
s
.76 .728 .823 r
.39518 .75312 m .40813 .74373 L .4185 .74791 L p F P
0 g
s
.749 .732 .836 r
.4156 .73876 m .40813 .74373 L .4185 .74791 L p F P
0 g
s
.749 .732 .836 r
.4185 .74791 m .42151 .74593 L .4156 .73876 L p F P
0 g
s
.509 .058 .114 r
.57329 .9875 m .56761 .98784 L .55156 .98546 L p F P
0 g
s
.499 .032 .077 r
.56761 .98784 m .54818 .98882 L .55156 .98546 L closepath p F P
0 g
s
.996 .787 .504 r
.45947 .53077 m .45553 .52385 L .45732 .51407 L p F P
0 g
s
.936 .819 .704 r
.45916 .53157 m .45947 .53077 L .45553 .52385 L p F P
0 g
s
.579 .544 .78 r
.72057 .79987 m .70468 .80024 L .70051 .78988 L p F P
0 g
s
.76 .709 .804 r
.64581 .27021 m .66286 .25646 L p .63698 .26379 L F P
0 g
s
.76 .709 .804 r
.63698 .26379 m .63842 .26632 L .64581 .27021 L p F P
0 g
s
.861 .714 .699 r
.60057 .38332 m .5975 .38918 L .60289 .39946 L p F P
0 g
s
.892 .716 .657 r
.5956 .394 m .5975 .38918 L .60289 .39946 L p F P
0 g
s
.892 .716 .657 r
.60289 .39946 m .60263 .40015 L .5956 .394 L p F P
0 g
s
.761 .844 .914 r
.68035 .53068 m .69423 .52243 L .68936 .51801 L p F P
0 g
s
.761 .844 .914 r
.68936 .51801 m .6825 .52208 L .68035 .53068 L p F P
0 g
s
.747 .831 .916 r
.66839 .52991 m .6825 .52208 L .68035 .53068 L p F P
0 g
s
.966 .908 .707 r
.81336 .41266 m .81719 .40533 L .81313 .40316 L p F P
0 g
s
.625 .634 .839 r
.6516 .73578 m .65377 .73968 L .63471 .74775 L p F P
0 g
s
.625 .634 .839 r
.63471 .74775 m .63047 .74021 L .6516 .73578 L p F P
0 g
s
.542 .432 .679 r
.72851 .87697 m .72695 .87017 L .73715 .87319 L closepath p F P
0 g
s
.82 .878 .887 r
.75588 .48608 m .74065 .49822 L .73681 .49501 L p F P
0 g
s
.751 .864 .931 r
.2919 .25793 m .28505 .25538 L p .30742 .24369 L F P
0 g
s
.751 .864 .931 r
.30742 .24369 m .29948 .2535 L .2919 .25793 L p F P
0 g
s
.81 .516 .493 r
.37493 .949 m .36297 .94575 L .36124 .9358 L p F P
0 g
s
.817 .521 .489 r
.34965 .93242 m .36124 .9358 L .36297 .94575 L p F P
0 g
s
.52 .669 .931 r
.7437 .2435 m .7363 .24371 L .74108 .25074 L p F P
0 g
s
.52 .669 .931 r
.74108 .25074 m .74955 .25042 L .7437 .2435 L p F P
0 g
s
.844 .657 .65 r
.31673 .8738 m .32644 .87788 L .32237 .88917 L p F P
0 g
s
.833 .667 .677 r
.32205 .8622 m .31673 .8738 L .32644 .87788 L p F P
0 g
s
.936 .819 .704 r
.45553 .52385 m .45325 .52856 L .45916 .53157 L p F P
0 g
s
.812 .8 .84 r
.43906 .53859 m .45325 .52856 L .45916 .53157 L p F P
0 g
s
.518 .635 .905 r
.36269 .51164 m .34308 .51214 L .34922 .52002 L p F P
0 g
s
.518 .635 .905 r
.34922 .52002 m .36879 .5197 L .36269 .51164 L p F P
0 g
s
.503 .633 .91 r
.3402 .51213 m .34308 .51214 L .34922 .52002 L p F P
0 g
s
.505 .225 .422 r
.67154 .95901 m .67286 .95024 L .69368 .94474 L p F P
0 g
s
.535 .293 .494 r
.69412 .93512 m .69368 .94474 L .67286 .95024 L p F P
0 g
s
.894 .715 .652 r
.5956 .394 m .60263 .40015 L .59896 .4104 L p F P
0 g
s
.743 .727 .837 r
.44189 .73313 m .42151 .74593 L .4156 .73876 L p F P
0 g
s
.769 .688 .774 r
.62175 .2935 m .63111 .28427 L .62096 .27893 L p F P
0 g
s
.789 .718 .786 r
.63111 .28427 m .62096 .27893 L .63604 .2647 L p F P
0 g
s
.454 .579 .889 r
.31148 .49395 m .31591 .49446 L .3166 .50137 L closepath p F P
0 g
s
.996 .822 .554 r
.59906 .47112 m .59887 .47197 L .59858 .47129 L closepath p F P
0 g
s
.597 .572 .796 r
.69405 .77516 m .68302 .77631 L .69259 .77182 L closepath p F P
0 g
s
.604 .59 .81 r
.68878 .76383 m .69259 .77182 L .68302 .77631 L p F P
0 g
s
.79 .675 .737 r
.60463 .32546 m .60882 .32749 L p .60836 .30998 L F P
0 g
s
.799 .678 .731 r
.60463 .32546 m .60678 .33012 L .60882 .32749 L closepath p F P
0 g
s
.639 .643 .837 r
.6042 .7363 m .62514 .73084 L .63047 .74021 L p F P
0 g
s
.64 .645 .84 r
.62095 .72357 m .62514 .73084 L .6042 .7363 L p F P
0 g
s
.64 .645 .84 r
.6042 .7363 m .60078 .73042 L .62095 .72357 L p F P
0 g
s
.833 .688 .703 r
.32205 .8622 m .32436 .85811 L .31836 .84775 L p F P
0 g
s
.867 .893 .851 r
.77742 .45819 m .78574 .4496 L .78594 .45761 L p F P
0 g
s
.867 .893 .851 r
.78594 .45761 m .78182 .46181 L .77742 .45819 L p F P
0 g
s
.731 .719 .839 r
.44189 .73313 m .44856 .72921 L .46124 .73272 L p F P
0 g
s
.723 .724 .85 r
.46232 .72171 m .44856 .72921 L .46124 .73272 L p F P
0 g
s
.723 .724 .85 r
.46124 .73272 m .46808 .729 L .46232 .72171 L p F P
0 g
s
.769 .688 .774 r
.62096 .27893 m .61641 .28311 L .62175 .2935 L p F P
0 g
s
.801 .689 .74 r
.60844 .29222 m .61641 .28311 L .62175 .2935 L p F P
0 g
s
.801 .689 .74 r
.62175 .2935 m .61844 .2976 L .60844 .29222 L p F P
0 g
s
.421 0 .058 r
.60205 .97884 m .61932 .97652 L p .62062 .98215 L F P
0 g
s
.421 0 .058 r
.59857 .98404 m .60205 .97884 L p .62062 .98215 L F P
0 g
s
.999 .812 .521 r
.59401 .47458 m .5971 .48174 L .59887 .47197 L p F P
0 g
s
.999 .812 .521 r
.59887 .47197 m .59858 .47129 L .59401 .47458 L p F P
0 g
s
.367 .497 .857 r
.28025 .47188 m .28028 .47188 L .28028 .47193 L closepath p F P
0 g
s
.376 .492 .85 r
.28032 .46304 m .27411 .46132 L .28025 .47188 L p F P
0 g
s
.376 .492 .85 r
.28025 .47188 m .28028 .47188 L .28032 .46304 L p F P
0 g
s
.757 .366 .314 r
.40518 .96425 m .40957 .97037 L .40751 .97219 L p F P
0 g
s
.757 .366 .314 r
.39179 .96142 m .40518 .96425 L p .40751 .97219 L F P
0 g
s
.434 .535 .861 r
.29632 .47501 m .28028 .47188 L .28032 .46304 L p F P
0 g
s
.421 .543 .874 r
.29659 .48367 m .29632 .47501 L .28028 .47188 L p F P
0 g
s
.869 .898 .851 r
.77229 .47139 m .78182 .46181 L .77742 .45819 L p F P
0 g
s
.548 .457 .704 r
.74304 .85132 m .72805 .84834 L .74067 .84249 L closepath p F P
0 g
s
.561 .481 .723 r
.73729 .8314 m .74067 .84249 L .72805 .84834 L p F P
0 g
s
.561 .481 .723 r
.73151 .83066 m .73729 .8314 L p .72805 .84834 L F P
0 g
s
.817 .685 .718 r
.60678 .33012 m .60137 .33895 L p .59882 .32219 L F P
0 g
s
.817 .685 .718 r
.59882 .32219 m .60463 .32546 L .60678 .33012 L p F P
0 g
s
.722 .716 .843 r
.66286 .25646 m .66807 .25332 L .65802 .24788 L p F P
0 g
s
.722 .716 .843 r
.65802 .24788 m .65772 .24805 L .66286 .25646 L p F P
0 g
s
.76 .709 .804 r
.66286 .25646 m .65772 .24805 L .63698 .26379 L p F P
0 g
s
.508 .27 .49 r
.69368 .94474 m .69412 .93512 L .71431 .92882 L p F P
0 g
s
.531 .324 .544 r
.71396 .91855 m .71431 .92882 L .69412 .93512 L p F P
0 g
s
.83 .708 .73 r
.31831 .82933 m .32739 .83372 L .31931 .84603 L p F P
0 g
s
.823 .714 .744 r
.32739 .83372 m .31831 .82933 L .32776 .81663 L p F P
0 g
s
.843 .889 .872 r
.75588 .48608 m .76133 .48127 L .75681 .47755 L p F P
0 g
s
.843 .889 .872 r
.75681 .47755 m .75641 .47791 L .75588 .48608 L p F P
0 g
s
.82 .878 .887 r
.73693 .49363 m .75641 .47791 L .75588 .48608 L p F P
0 g
s
.82 .878 .887 r
.73681 .49501 m .73693 .49363 L p .75588 .48608 L F P
0 g
s
.729 .818 .92 r
.66839 .52991 m .64746 .54054 L .64237 .5356 L p F P
0 g
s
.839 .692 .7 r
.60396 .35565 m .59448 .35023 L .60137 .33895 L p F P
0 g
s
.83 .679 .695 r
.59448 .35023 m .60396 .35565 L .59777 .36671 L p F P
0 g
s
.604 .522 .735 r
.44131 .31201 m .44457 .32194 L .46483 .31631 L p F P
0 g
s
.599 .503 .717 r
.46518 .31757 m .46483 .31631 L .44457 .32194 L p F P
0 g
s
.599 .503 .717 r
.44457 .32194 m .44588 .32642 L .46518 .31757 L p F P
0 g
s
.844 .887 .87 r
.77229 .47139 m .76133 .48127 L .75681 .47755 L p F P
0 g
s
.996 .822 .467 r
.82125 .35746 m .82338 .36519 L .82487 .35561 L p F P
0 g
s
.996 .822 .467 r
.82256 .34905 m .82125 .35746 L p .82487 .35561 L F P
0 g
s
.996 .822 .467 r
.82487 .35561 m .82304 .34888 L .82256 .34905 L p F P
0 g
s
.607 .608 .826 r
.66488 .76114 m .66217 .75587 L .68122 .75306 L closepath p F P
0 g
s
.333 .282 .65 r
.45176 .42781 m .45183 .42816 L .45165 .42796 L closepath p F P
0 g
s
.351 .285 .642 r
.45165 .42796 m .45183 .42816 L .45393 .4395 L p F P
0 g
s
.801 .689 .742 r
.60844 .29222 m .61844 .2976 L .60836 .30998 L p F P
0 g
s
.869 .898 .851 r
.77742 .45819 m .77239 .46332 L .77229 .47139 L p F P
0 g
s
.844 .887 .87 r
.75681 .47755 m .77239 .46332 L .77229 .47139 L p F P
0 g
s
.529 .401 .651 r
.73078 .88902 m .72851 .87697 L .73715 .87319 L p F P
0 g
s
.258 .202 .601 r
.45776 .46241 m .45348 .47136 L p .4545 .45346 L F P
0 g
s
.1 .071 .535 r
.45776 .46241 m .45348 .47136 L .45614 .47948 L p F P
0 g
s
.607 .523 .733 r
.43899 .30489 m .44131 .31201 L .46063 .30314 L p F P
0 g
s
.604 .522 .735 r
.46483 .31631 m .46063 .30314 L .44131 .31201 L p F P
0 g
s
.683 .694 .854 r
.52033 .72486 m .54093 .71655 L .54645 .72451 L p F P
0 g
s
.684 .704 .863 r
.54093 .71655 m .52033 .72486 L .51473 .71713 L p F P
0 g
s
.697 .705 .854 r
.49422 .72636 m .51473 .71713 L .52033 .72486 L p F P
0 g
s
.482 .138 .307 r
.64736 .97173 m .64999 .96385 L .67152 .95913 L p F P
0 g
s
.526 .23 .408 r
.67154 .95901 m .67152 .95913 L .64999 .96385 L p F P
0 g
s
.517 .173 .323 r
.64999 .96385 m .64736 .97173 L .6251 .97571 L p F P
0 g
s
.697 .714 .861 r
.51473 .71713 m .49422 .72636 L .48854 .71884 L p F P
0 g
s
.998 .853 .552 r
.59399 .47451 m .59401 .47458 L .59858 .47129 L p F P
0 g
s
.998 .853 .552 r
.59858 .47129 m .59664 .46442 L .59399 .47451 L p F P
0 g
s
.608 .725 .928 r
.4328 .54162 m .42373 .54371 L .41979 .53679 L p F P
0 g
s
.613 .542 .751 r
.43605 .29677 m .43899 .30489 L .45924 .29874 L p F P
0 g
s
.607 .523 .733 r
.46063 .30314 m .45924 .29874 L .43899 .30489 L p F P
0 g
s
.595 .501 .718 r
.46906 .33117 m .46518 .31757 L .44588 .32642 L p F P
0 g
s
.595 .501 .718 r
.44588 .32642 m .44995 .34023 L .46906 .33117 L p F P
0 g
s
.457 .371 .67 r
.45176 .42781 m .46669 .41434 L p .45768 .40819 L F P
0 g
s
.387 .318 .657 r
.46852 .42566 m .46669 .41434 L .45176 .42781 L p F P
0 g
s
.387 .318 .657 r
.4589 .4343 m .46852 .42566 L p .45176 .42781 L F P
0 g
s
.387 .318 .657 r
.45176 .42781 m .45183 .42816 L .4589 .4343 L p F P
0 g
s
.4 .319 .649 r
.45183 .42816 m .4589 .4343 L .45393 .4395 L closepath p F P
0 g
s
.793 .733 .797 r
.3674 .7754 m .35421 .78767 L .34809 .78046 L p F P
0 g
s
.793 .733 .797 r
.34809 .78046 m .35833 .77086 L .3674 .7754 L p F P
0 g
s
.781 .737 .812 r
.36868 .7621 m .35833 .77086 L .3674 .7754 L p F P
0 g
s
.781 .737 .812 r
.3674 .7754 m .37474 .76924 L .36868 .7621 L p F P
0 g
s
.579 .544 .78 r
.70051 .78988 m .70625 .78685 L p .72057 .79987 L F P
0 g
s
.584 .564 .798 r
.70051 .78988 m .69935 .78722 L .70625 .78685 L closepath p F P
0 g
s
.692 .284 .269 r
.44214 .97781 m .44121 .9777 L .44155 .97733 L closepath p F P
0 g
s
.547 .472 .722 r
.44995 .34023 m .45009 .34071 L .44924 .34073 L closepath p F P
0 g
s
.547 .472 .722 r
.4534 .3533 m .45009 .34071 L .44924 .34073 L p F P
0 g
s
.794 .736 .798 r
.35195 .78978 m .35421 .78767 L .34809 .78046 L p F P
0 g
s
.019 .073 .578 r
.23023 .38413 m .23249 .37389 L .22895 .36678 L p F P
0 g
s
.121 .179 .65 r
.23249 .37389 m .23023 .38413 L .2353 .39072 L p F P
0 g
s
.807 .732 .782 r
.34306 .78522 m .35195 .78978 L .33892 .80347 L p F P
0 g
s
.794 .736 .798 r
.34809 .78046 m .34306 .78522 L .35195 .78978 L p F P
0 g
s
.844 .679 .678 r
.3127 .85797 m .32205 .8622 L .31673 .8738 L p F P
0 g
s
.833 .688 .703 r
.31836 .84775 m .3127 .85797 L .32205 .8622 L p F P
0 g
s
.825 .564 .544 r
.34965 .93242 m .34214 .93008 L .34335 .9201 L p F P
0 g
s
.833 .572 .543 r
.33862 .91851 m .34335 .9201 L .34214 .93008 L p F P
0 g
s
.779 .735 .812 r
.38577 .76016 m .37474 .76924 L .36868 .7621 L p F P
0 g
s
.741 .845 .928 r
.31185 .24657 m .29948 .2535 L .30742 .24369 L closepath p F P
0 g
s
.803 .467 .419 r
.37493 .949 m .37772 .95651 L .37664 .95801 L p F P
0 g
s
.803 .467 .419 r
.36297 .94575 m .37493 .949 L p .37664 .95801 L F P
0 g
s
0 0 0 r
.23276 .32589 m .23501 .32022 L .2388 .31045 L p F P
0 g
s
0 0 .086 r
.23501 .32022 m .23276 .32589 L .23145 .33413 L p F P
0 g
s
0 0 .011 r
.22956 .34028 m .23145 .33413 L .23276 .32589 L p F P
0 g
s
.67 .683 .854 r
.54645 .72451 m .56715 .7171 L .57261 .72531 L p F P
0 g
s
.67 .691 .861 r
.56715 .7171 m .54645 .72451 L .54093 .71655 L p F P
0 g
s
0 0 .274 r
.23145 .33413 m .22956 .34028 L .22982 .34855 L p F P
0 g
s
.734 .718 .836 r
.68374 .24362 m .66807 .25332 L .65802 .24788 L p F P
0 g
s
.712 .722 .858 r
.48854 .71884 m .46808 .729 L .46232 .72171 L p F P
0 g
s
.615 .542 .749 r
.43337 .28931 m .43605 .29677 L .45541 .2879 L p F P
0 g
s
.613 .542 .751 r
.45924 .29874 m .45541 .2879 L .43605 .29677 L p F P
0 g
s
.593 .5 .718 r
.47038 .33579 m .46906 .33117 L .44995 .34023 L p F P
0 g
s
.593 .5 .718 r
.44995 .34023 m .45009 .34071 L .47038 .33579 L p F P
0 g
s
.586 .481 .701 r
.47253 .3443 m .47038 .33579 L .45009 .34071 L p F P
0 g
s
.586 .481 .701 r
.45009 .34071 m .4534 .3533 L .47253 .3443 L p F P
0 g
s
.966 .908 .707 r
.81313 .40316 m .8123 .40477 L .81336 .41266 L p F P
0 g
s
.94 .902 .76 r
.80494 .41647 m .80596 .42435 L .81336 .41266 L p F P
0 g
s
.94 .902 .76 r
.81336 .41266 m .8123 .40477 L .80494 .41647 L p F P
0 g
s
.635 .162 .112 r
.46496 .98625 m .45549 .98512 L .44214 .97781 L p F P
0 g
s
.58 .061 0 r
.44121 .9777 m .44214 .97781 L .45549 .98512 L p F P
0 g
s
.921 .744 .646 r
.60147 .42706 m .59544 .42064 L .59896 .4104 L p F P
0 g
s
.921 .74 .639 r
.59544 .42064 m .60147 .42706 L .59823 .43723 L p F P
0 g
s
.584 .565 .798 r
.70625 .78685 m .69935 .78722 L .69405 .77516 L p F P
0 g
s
.58 .061 0 r
.43543 .9815 m .44121 .9777 L p .45549 .98512 L F P
0 g
s
.681 .228 .169 r
.43543 .9815 m .42703 .97546 L .44121 .9777 L closepath p F P
0 g
s
0 0 .472 r
.81266 .30721 m .81029 .30335 L .80552 .29401 L p F P
0 g
s
.79 .675 .737 r
.60836 .30998 m .60137 .31842 L .60463 .32546 L p F P
0 g
s
.817 .685 .718 r
.60137 .31842 m .59882 .32219 L .60463 .32546 L closepath p F P
0 g
s
.817 .653 .103 r
.59586 .50069 m .59655 .50862 L .59668 .4993 L p F P
0 g
s
.817 .653 .103 r
.59668 .4993 m .59596 .49136 L .59586 .50069 L p F P
0 g
s
.69 .755 .901 r
.63262 .53965 m .62142 .54415 L .61617 .53789 L p F P
0 g
s
.771 .846 .908 r
.71263 .51089 m .69423 .52243 L .68936 .51801 L p F P
0 g
s
.833 .684 .698 r
.59282 .37859 m .60057 .38332 L p .59777 .36671 L F P
0 g
s
.84 .685 .69 r
.59282 .37859 m .5975 .38918 L .60057 .38332 L closepath p F P
0 g
s
.779 .735 .812 r
.36868 .7621 m .37644 .75566 L .38577 .76016 L p F P
0 g
s
.767 .738 .826 r
.38918 .74605 m .37644 .75566 L .38577 .76016 L p F P
0 g
s
.767 .738 .826 r
.38577 .76016 m .39518 .75312 L .38918 .74605 L p F P
0 g
s
.498 .408 .684 r
.45949 .37856 m .46101 .38521 L .45342 .38327 L closepath p F P
0 g
s
.497 .412 .691 r
.46212 .39073 m .46101 .38521 L .45342 .38327 L p F P
0 g
s
.622 .563 .767 r
.42977 .28029 m .43337 .28931 L .45361 .28275 L p F P
0 g
s
.615 .542 .749 r
.45541 .2879 m .45361 .28275 L .43337 .28931 L p F P
0 g
s
.817 .725 .764 r
.33892 .80347 m .33346 .80991 L .3273 .80223 L p F P
0 g
s
.817 .725 .764 r
.3273 .80223 m .3301 .79891 L .33892 .80347 L p F P
0 g
s
.807 .732 .782 r
.33892 .80347 m .3301 .79891 L .34306 .78522 L p F P
0 g
s
.983 .884 .65 r
.81633 .38587 m .818 .39365 L .82222 .38307 L p F P
0 g
s
.983 .884 .65 r
.82222 .38307 m .82054 .37528 L .81633 .38587 L p F P
0 g
s
.634 .631 .83 r
.39211 .24916 m .39608 .25626 L .41615 .24984 L p F P
0 g
s
.798 .916 .527 r
.2388 .31045 m .24357 .29941 L .24749 .29412 L p F P
0 g
s
0 0 0 r
.24357 .29941 m .2388 .31045 L .23501 .32022 L p F P
0 g
s
.602 .713 .922 r
.4166 .52955 m .40078 .5324 L .40678 .53939 L p F P
0 g
s
.602 .713 .922 r
.40678 .53939 m .41979 .53679 L .4166 .52955 L p F P
0 g
s
.161 .447 .878 r
.77315 .25951 m .77802 .2667 L .78854 .27167 L p F P
0 g
s
.656 .672 .853 r
.57261 .72531 m .59343 .7188 L .59882 .72726 L p F P
0 g
s
.657 .678 .859 r
.59343 .7188 m .57261 .72531 L .56715 .7171 L p F P
0 g
s
.801 .689 .742 r
.60836 .30998 m .5969 .30515 L .60844 .29222 L p F P
0 g
s
.775 .663 .74 r
.60137 .31842 m .60836 .30998 L .5969 .30515 L p F P
0 g
s
.607 .61 .828 r
.68122 .75306 m .66217 .75587 L .65689 .74566 L p F P
0 g
s
.817 .685 .718 r
.60137 .33895 m .591 .33379 L .59882 .32219 L p F P
0 g
s
.814 .668 .7 r
.591 .33379 m .60137 .33895 L .59448 .35023 L p F P
0 g
s
.536 .659 .915 r
.36941 .52049 m .37488 .52722 L .37116 .52744 L closepath p F P
0 g
s
.642 .66 .852 r
.6198 .72168 m .62095 .72357 L .60078 .73042 L p F P
0 g
s
.642 .66 .852 r
.60078 .73042 m .59882 .72726 L .6198 .72168 L p F P
0 g
s
.763 .736 .827 r
.40813 .74373 m .39518 .75312 L .38918 .74605 L p F P
0 g
s
.789 .718 .786 r
.63698 .26379 m .63604 .2647 L .63842 .26632 L closepath p F P
0 g
s
.971 .729 .301 r
.82007 .34024 m .82274 .34786 L .82277 .33882 L p F P
0 g
s
.971 .729 .301 r
.82277 .33882 m .8201 .33118 L .82007 .34024 L p F P
0 g
s
.582 .478 .701 r
.47579 .35718 m .47253 .3443 L .4534 .3533 L p F P
0 g
s
.582 .478 .701 r
.47427 .35791 m .47579 .35718 L p .4534 .3533 L F P
0 g
s
.582 .478 .701 r
.4534 .3533 m .45557 .36161 L .47427 .35791 L p F P
0 g
s
.624 .637 .843 r
.6516 .73578 m .63047 .74021 L .62514 .73084 L p F P
0 g
s
.817 .727 .766 r
.32776 .81663 m .33346 .80991 L .3273 .80223 L p F P
0 g
s
.732 .725 .844 r
.44856 .72921 m .44189 .73313 L .43604 .72577 L p F P
0 g
s
.743 .727 .837 r
.4156 .73876 m .43604 .72577 L .44189 .73313 L p F P
0 g
s
.459 .569 .879 r
.3053 .48476 m .29659 .48367 L .29632 .47501 L p F P
0 g
s
.449 .57 .884 r
.29659 .48367 m .3053 .48476 L .31148 .49395 L p F P
0 g
s
.675 .737 .897 r
.35181 .22797 m .3318 .23681 L .33815 .24316 L p F P
0 g
s
.675 .737 .897 r
.33815 .24316 m .35807 .23511 L .35181 .22797 L p F P
0 g
s
.839 .604 .584 r
.33862 .91851 m .32815 .91475 L .32964 .90407 L p F P
0 g
s
.846 .612 .584 r
.31956 .90016 m .32964 .90407 L .32815 .91475 L p F P
0 g
s
.842 .633 .62 r
.32964 .90407 m .31956 .90016 L .32237 .88917 L p F P
0 g
s
.84 .696 .703 r
.31836 .84775 m .31931 .84603 L .31646 .84466 L closepath p F P
0 g
s
.83 .708 .73 r
.31226 .83863 m .31831 .82933 L p .31931 .84603 L F P
0 g
s
.83 .708 .73 r
.31931 .84603 m .31646 .84466 L .31226 .83863 L p F P
0 g
s
.505 .304 .542 r
.72867 .91319 m .71396 .91855 L .71431 .92882 L p F P
0 g
s
.525 .349 .585 r
.71396 .91855 m .72867 .91319 L .72315 .90396 L p F P
0 g
s
.622 .563 .767 r
.45361 .28275 m .44922 .27146 L .42977 .28029 L p F P
0 g
s
.624 .562 .765 r
.42769 .27503 m .42977 .28029 L .44922 .27146 L p F P
0 g
s
.833 .572 .543 r
.34214 .93008 m .33853 .92887 L .33862 .91851 L p F P
0 g
s
.841 .578 .541 r
.32815 .91475 m .33862 .91851 L .33853 .92887 L p F P
0 g
s
.501 .108 .227 r
.62463 .97661 m .61932 .97652 L .6251 .97571 L closepath p F P
0 g
s
.421 0 .058 r
.61932 .97652 m .62463 .97661 L .62062 .98215 L p F P
0 g
s
.964 .787 .614 r
.59231 .45752 m .59664 .46442 L .59959 .45427 L p F P
0 g
s
.964 .787 .614 r
.59959 .45427 m .59516 .44739 L .59231 .45752 L p F P
0 g
s
.523 .348 .586 r
.73245 .9005 m .72315 .90396 L .72867 .91319 L p F P
0 g
s
.541 .385 .619 r
.73078 .88902 m .73245 .9005 L .72315 .90396 L p F P
0 g
s
.506 .627 .905 r
.3395 .50742 m .34308 .51214 L .3402 .51213 L closepath p F P
0 g
s
.393 .309 .642 r
.4589 .4343 m .45393 .4395 L .45596 .45107 L p F P
0 g
s
.251 .21 .616 r
.4545 .45346 m .45596 .45107 L .45393 .4395 L p F P
0 g
s
.861 .691 .67 r
.5975 .38918 m .5956 .394 L p .59164 .37777 L F P
0 g
s
.861 .691 .67 r
.59164 .37777 m .59282 .37859 L .5975 .38918 L p F P
0 g
s
.578 .462 .685 r
.45557 .36161 m .47427 .35791 L .45663 .36614 L closepath p F P
0 g
s
.894 .715 .652 r
.59896 .4104 m .59165 .40435 L .5956 .394 L p F P
0 g
s
.891 .706 .647 r
.59165 .40435 m .59896 .4104 L .59544 .42064 L p F P
0 g
s
.84 .696 .704 r
.3127 .85797 m .31836 .84775 L .31646 .84466 L p F P
0 g
s
.829 .722 .747 r
.31904 .81207 m .32776 .81663 L .31831 .82933 L p F P
0 g
s
.817 .727 .766 r
.3273 .80223 m .31904 .81207 L .32776 .81663 L p F P
0 g
s
.85 .641 .62 r
.31266 .8851 m .32237 .88917 L .31956 .90016 L p F P
0 g
s
.844 .657 .65 r
.32237 .88917 m .31266 .8851 L .31673 .8738 L p F P
0 g
s
0 0 .441 r
.22895 .36678 m .23179 .35621 L .22982 .34855 L p F P
0 g
s
.083 .103 .581 r
.23249 .37389 m .22895 .36678 L .23179 .35621 L p F P
0 g
s
.83 .679 .695 r
.59777 .36671 m .58749 .36158 L .59448 .35023 L p F P
0 g
s
.808 .659 .698 r
.59204 .37686 m .59777 .36671 L .58749 .36158 L p F P
0 g
s
.833 .684 .698 r
.59777 .36671 m .59204 .37686 L .59282 .37859 L p F P
0 g
s
.459 .572 .881 r
.31577 .48581 m .3053 .48476 L .31148 .49395 L p F P
0 g
s
.459 .572 .881 r
.31148 .49395 m .31591 .49446 L .31577 .48581 L p F P
0 g
s
.849 .998 .786 r
.24749 .29412 m .25106 .2876 L .26153 .2752 L p F P
0 g
s
.718 .884 .491 r
.25106 .2876 m .24749 .29412 L .24357 .29941 L p F P
0 g
s
.775 .663 .74 r
.5969 .30515 m .59592 .30624 L .60137 .31842 L p F P
0 g
s
.801 .661 .708 r
.58768 .31725 m .59592 .30624 L .60137 .31842 L p F P
0 g
s
.801 .661 .708 r
.60137 .31842 m .59882 .32219 L .58768 .31725 L p F P
0 g
s
.514 .368 .621 r
.73245 .9005 m .73078 .88902 L .74962 .88086 L p F P
0 g
s
.529 .401 .651 r
.74932 .87931 m .74962 .88086 L .73078 .88902 L p F P
0 g
s
.529 .401 .651 r
.73715 .87319 m .74932 .87931 L p .73078 .88902 L F P
0 g
s
.633 .584 .782 r
.42769 .27503 m .44794 .26813 L p .42269 .26163 L F P
0 g
s
.633 .584 .782 r
.42269 .26163 m .42198 .26195 L .42769 .27503 L p F P
0 g
s
.624 .562 .765 r
.44922 .27146 m .44794 .26813 L .42769 .27503 L p F P
0 g
s
.453 .645 .94 r
.76325 .25107 m .74955 .25042 L .7437 .2435 L p F P
0 g
s
.469 .643 .933 r
.74955 .25042 m .76325 .25107 L .76793 .25799 L p F P
0 g
s
.653 .684 .867 r
.37812 .22736 m .35807 .23511 L .36421 .2432 L p F P
0 g
s
.653 .684 .867 r
.36421 .2432 m .38419 .23607 L .37812 .22736 L p F P
0 g
s
0 0 .343 r
.45588 .49709 m .45804 .48792 L .45614 .47948 L p F P
0 g
s
.617 .724 .923 r
.72668 .22994 m .70497 .23458 L .70989 .24185 L p F P
0 g
s
.617 .724 .923 r
.70989 .24185 m .7315 .23677 L .72668 .22994 L p F P
0 g
s
.817 .521 .489 r
.36297 .94575 m .35134 .94238 L .34965 .93242 L p F P
0 g
s
.823 .523 .481 r
.34214 .93008 m .34965 .93242 L .35134 .94238 L p F P
0 g
s
.277 .339 .747 r
.61014 .52986 m .61028 .53093 L .59646 .52605 L p F P
0 g
s
.277 .339 .747 r
.6055 .52239 m .61014 .52986 L p .59646 .52605 L F P
0 g
s
.277 .339 .747 r
.59646 .52605 m .59897 .51716 L .6055 .52239 L p F P
0 g
s
.757 .366 .314 r
.40751 .97219 m .39851 .97025 L .39179 .96142 L p F P
0 g
s
.759 .359 .295 r
.37867 .9585 m .39179 .96142 L .39851 .97025 L p F P
0 g
s
.779 .435 .405 r
.39179 .96142 m .37867 .9585 L .37772 .95651 L p F P
0 g
s
.763 .736 .827 r
.38918 .74605 m .39842 .7393 L .40813 .74373 L p F P
0 g
s
.753 .739 .84 r
.40965 .73179 m .39842 .7393 L .40813 .74373 L p F P
0 g
s
.753 .739 .84 r
.40813 .74373 m .4156 .73876 L .40965 .73179 L p F P
0 g
s
.732 .725 .844 r
.43604 .72577 m .43658 .72546 L .44856 .72921 L p F P
0 g
s
.725 .731 .855 r
.45651 .71461 m .43658 .72546 L .44856 .72921 L p F P
0 g
s
.725 .731 .855 r
.44856 .72921 m .46232 .72171 L .45651 .71461 L p F P
0 g
s
.24 .194 .603 r
.45596 .45107 m .4571 .45813 L .4545 .45346 L closepath p F P
0 g
s
.258 .202 .601 r
.4545 .45346 m .4571 .45813 L .45776 .46241 L p F P
0 g
s
.744 .701 .81 r
.63698 .26379 m .65772 .24805 L p .64942 .24185 L F P
0 g
s
.744 .701 .81 r
.64942 .24185 m .63171 .25441 L .63698 .26379 L p F P
0 g
s
.784 .708 .78 r
.6265 .25906 m .63171 .25441 L .63698 .26379 L p F P
0 g
s
.784 .708 .78 r
.63698 .26379 m .63604 .2647 L .6265 .25906 L p F P
0 g
s
.759 .681 .776 r
.62096 .27893 m .63604 .2647 L .6265 .25906 L p F P
0 g
s
.916 .901 .796 r
.79597 .42874 m .80494 .41647 L .80596 .42435 L p F P
0 g
s
.916 .901 .796 r
.7967 .43476 m .79597 .42874 L p .80596 .42435 L F P
0 g
s
.916 .901 .796 r
.80596 .42435 m .79771 .43552 L .7967 .43476 L p F P
0 g
s
.393 .494 .843 r
.28106 .45384 m .26796 .45052 L .27411 .46132 L p F P
0 g
s
.393 .494 .843 r
.27411 .46132 m .28032 .46304 L .28106 .45384 L p F P
0 g
s
.387 .497 .849 r
.26682 .4502 m .26796 .45052 L .27411 .46132 L p F P
0 g
s
.9 .597 .098 r
.81699 .32363 m .8201 .33118 L .8187 .32268 L p F P
0 g
s
.9 .597 .098 r
.8187 .32268 m .81559 .31512 L .81699 .32363 L p F P
0 g
s
.691 .741 .889 r
.70002 .22735 m .6787 .23585 L .68374 .24362 L p F P
0 g
s
.691 .741 .889 r
.68374 .24362 m .70497 .23458 L .70002 .22735 L p F P
0 g
s
.734 .718 .836 r
.65802 .24788 m .6787 .23585 L .68374 .24362 L p F P
0 g
s
.555 .479 .725 r
.73729 .8314 m .73151 .83066 L .73637 .82833 L closepath p F P
0 g
s
.567 .502 .742 r
.73175 .81469 m .73637 .82833 L .73151 .83066 L p F P
0 g
s
.567 .502 .742 r
.729 .81449 m .73175 .81469 L p .73151 .83066 L F P
0 g
s
.731 .844 .934 r
.32531 .23154 m .3318 .23681 L .31185 .24657 L p F P
0 g
s
.731 .844 .934 r
.31264 .23831 m .32531 .23154 L p .31185 .24657 L F P
0 g
s
.731 .844 .934 r
.31185 .24657 m .30742 .24369 L .31264 .23831 L p F P
0 g
s
.578 .46 .683 r
.47427 .35791 m .45663 .36614 L .45949 .37856 L p F P
0 g
s
0 .248 .761 r
.79609 .27779 m .80047 .2851 L .79294 .27897 L p F P
0 g
s
0 .248 .761 r
.79294 .27897 m .78854 .27167 L .79609 .27779 L p F P
0 g
s
.465 .072 .209 r
.62463 .97661 m .6251 .97571 L .64736 .97173 L p F P
0 g
s
.584 .565 .798 r
.69405 .77516 m .71567 .77417 L p .70625 .78685 L F P
0 g
s
.578 .562 .799 r
.71038 .76225 m .71567 .77417 L .69405 .77516 L p F P
0 g
s
.578 .562 .799 r
.70933 .76229 m .71038 .76225 L p .69405 .77516 L F P
0 g
s
.578 .562 .799 r
.69405 .77516 m .69259 .77182 L .70933 .76229 L p F P
0 g
s
.643 .666 .858 r
.6198 .72168 m .59882 .72726 L .59343 .7188 L p F P
0 g
s
.759 .681 .776 r
.61254 .27546 m .62096 .27893 L p .6265 .25906 L F P
0 g
s
.767 .684 .772 r
.61254 .27546 m .61641 .28311 L .62096 .27893 L closepath p F P
0 g
s
.785 .691 .761 r
.61641 .28311 m .60844 .29222 L p .60961 .27399 L F P
0 g
s
.785 .691 .761 r
.60961 .27399 m .61254 .27546 L .61641 .28311 L p F P
0 g
s
.692 .752 .897 r
.4328 .54162 m .43906 .53859 L .43678 .53109 L p F P
0 g
s
.692 .752 .897 r
.43678 .53109 m .42686 .53527 L .4328 .54162 L p F P
0 g
s
.608 .725 .928 r
.41979 .53679 m .42686 .53527 L .4328 .54162 L p F P
0 g
s
.564 .671 .91 r
.37488 .52722 m .39475 .52514 L p .36931 .51966 L F P
0 g
s
.564 .671 .91 r
.36931 .51966 m .36941 .52049 L .37488 .52722 L p F P
0 g
s
.579 .544 .78 r
.70625 .78685 m .72099 .78667 L p .72057 .79987 L F P
0 g
s
.575 .545 .784 r
.72099 .78667 m .70625 .78685 L .71839 .7803 L closepath p F P
0 g
s
.584 .565 .798 r
.71567 .77417 m .71839 .7803 L .70625 .78685 L p F P
0 g
s
.801 .661 .708 r
.58768 .31725 m .59882 .32219 L .591 .33379 L p F P
0 g
s
.788 .858 .902 r
.71514 .50917 m .71263 .51089 L .71315 .50739 L closepath p F P
0 g
s
.771 .846 .908 r
.71035 .50471 m .71315 .50739 L .71263 .51089 L p F P
0 g
s
.771 .846 .908 r
.68936 .51801 m .71035 .50471 L p .71263 .51089 L F P
0 g
s
.721 .315 .279 r
.42703 .97546 m .41221 .97301 L .40957 .97037 L p F P
0 g
s
.663 .179 .092 r
.42703 .97546 m .43543 .9815 L .43323 .98233 L p F P
0 g
s
.663 .179 .092 r
.41221 .97301 m .42703 .97546 L p .43323 .98233 L F P
0 g
s
.851 .666 .652 r
.30739 .86958 m .31673 .8738 L .31266 .8851 L p F P
0 g
s
.844 .679 .678 r
.31673 .8738 m .30739 .86958 L .3127 .85797 L p F P
0 g
s
.999 .787 .46 r
.59293 .48412 m .59596 .49136 L .5971 .48174 L p F P
0 g
s
.999 .787 .46 r
.59397 .47465 m .59293 .48412 L p .5971 .48174 L F P
0 g
s
.999 .787 .46 r
.5971 .48174 m .59401 .47458 L .59397 .47465 L p F P
0 g
s
.84 .696 .704 r
.31646 .84466 m .31028 .84165 L p .3127 .85797 L F P
0 g
s
.833 .708 .727 r
.31646 .84466 m .31226 .83863 L .31028 .84165 L closepath p F P
0 g
s
.69 .755 .901 r
.63722 .5303 m .6378 .53091 L .63262 .53965 L p F P
0 g
s
.69 .755 .901 r
.61617 .53789 m .63722 .5303 L p .63262 .53965 L F P
0 g
s
.696 .794 .926 r
.64237 .5356 m .63262 .53965 L .6378 .53091 L closepath p F P
0 g
s
.8 .859 .893 r
.73132 .48978 m .73602 .49429 L .71514 .50917 L p F P
0 g
s
.8 .859 .893 r
.71346 .50265 m .73132 .48978 L p .71514 .50917 L F P
0 g
s
.8 .859 .893 r
.71514 .50917 m .71315 .50739 L .71346 .50265 L p F P
0 g
s
.296 .543 .917 r
.76783 .25242 m .76325 .25107 L .76793 .25799 L p F P
0 g
s
.296 .543 .917 r
.76793 .25799 m .77315 .25951 L .76783 .25242 L p F P
0 g
s
.64 .632 .826 r
.39018 .24569 m .39211 .24916 L .41035 .23888 L p F P
0 g
s
.634 .631 .83 r
.41615 .24984 m .41035 .23888 L .39211 .24916 L p F P
0 g
s
.528 .637 .902 r
.34308 .51214 m .36269 .51164 L p .33927 .50391 L F P
0 g
s
.528 .637 .902 r
.33927 .50391 m .3395 .50742 L .34308 .51214 L p F P
0 g
s
0 0 .472 r
.80552 .29401 m .80911 .29973 L .81266 .30721 L p F P
0 g
s
.753 .395 0 r
.81204 .30765 m .81559 .31512 L .81266 .30721 L p F P
0 g
s
.753 .395 0 r
.81266 .30721 m .80911 .29973 L .81204 .30765 L p F P
0 g
s
.747 .736 .843 r
.43604 .72577 m .4156 .73876 L .40965 .73179 L p F P
0 g
s
.587 .583 .816 r
.69259 .77182 m .68878 .76383 L .70933 .76229 L closepath p F P
0 g
s
.996 .856 .576 r
.81839 .36757 m .82054 .37528 L .82338 .36519 L p F P
0 g
s
.996 .856 .576 r
.82338 .36519 m .82125 .35746 L .81839 .36757 L p F P
0 g
s
0 .002 .571 r
.80082 .28554 m .80047 .2851 L .80437 .29252 L p F P
0 g
s
0 .002 .571 r
.80437 .29252 m .80552 .29401 L .80082 .28554 L p F P
0 g
s
.746 .822 .911 r
.6825 .52208 m .66839 .52991 L .66337 .52501 L p F P
0 g
s
.729 .818 .92 r
.64237 .5356 m .66337 .52501 L .66839 .52991 L p F P
0 g
s
.861 .691 .67 r
.5956 .394 m .58708 .38831 L .59164 .37777 L p F P
0 g
s
.863 .681 .654 r
.58708 .38831 m .5956 .394 L .59165 .40435 L p F P
0 g
s
.565 .063 .021 r
.49189 .98828 m .47302 .98688 L .46752 .98484 L p F P
0 g
s
.563 .058 .013 r
.47302 .98688 m .46496 .98625 L .46752 .98484 L closepath p F P
0 g
s
.724 .313 .269 r
.41221 .97301 m .40751 .97219 L .40957 .97037 L closepath p F P
0 g
s
.785 .691 .761 r
.60844 .29222 m .59671 .28743 L .60961 .27399 L p F P
0 g
s
.762 .655 .744 r
.5969 .30515 m .60844 .29222 L .59671 .28743 L p F P
0 g
s
.527 .402 .653 r
.74932 .87931 m .73715 .87319 L .74726 .8687 L closepath p F P
0 g
s
.542 .431 .677 r
.74429 .85593 m .74726 .8687 L .73715 .87319 L p F P
0 g
s
.605 .701 .911 r
.61088 .53091 m .61028 .53093 L .60974 .5391 L p F P
0 g
s
.605 .701 .911 r
.60974 .5391 m .61617 .53789 L .61088 .53091 L p F P
0 g
s
.814 .668 .7 r
.59448 .35023 m .58309 .34545 L .591 .33379 L p F P
0 g
s
.788 .642 .701 r
.58749 .36158 m .59448 .35023 L .58309 .34545 L p F P
0 g
s
.803 .467 .419 r
.37664 .95801 m .3666 .95528 L .36297 .94575 L p F P
0 g
s
.81 .469 .41 r
.35134 .94238 m .36297 .94575 L .3666 .95528 L p F P
0 g
s
.465 .072 .209 r
.64736 .97173 m .64582 .97463 L .62463 .97661 L p F P
0 g
s
.412 0 .087 r
.62062 .98215 m .62463 .97661 L .64582 .97463 L p F P
0 g
s
.466 .37 .662 r
.45768 .40819 m .46446 .40258 L .46212 .39073 L p F P
0 g
s
.464 .366 .659 r
.46446 .40258 m .46639 .41257 L .45768 .40819 L closepath p F P
0 g
s
.457 .371 .67 r
.46669 .41434 m .46639 .41257 L .45768 .40819 L p F P
0 g
s
.921 .74 .639 r
.59823 .43723 m .59209 .43086 L .59544 .42064 L p F P
0 g
s
.922 .735 .632 r
.59209 .43086 m .59823 .43723 L .59516 .44739 L p F P
0 g
s
.962 .893 .713 r
.8107 .39699 m .81633 .38587 L .818 .39365 L p F P
0 g
s
.962 .893 .713 r
.81182 .40232 m .8107 .39699 L p .818 .39365 L F P
0 g
s
.962 .893 .713 r
.818 .39365 m .81313 .40316 L .81182 .40232 L p F P
0 g
s
.433 0 0 r
.51987 .99036 m .52196 .98918 L .53812 .98901 L p F P
0 g
s
.482 0 0 r
.51987 .99036 m .51359 .98899 L .52196 .98918 L closepath p F P
0 g
s
.838 .714 .727 r
.31831 .82933 m .31226 .83863 L .30607 .83028 L p F P
0 g
s
.838 .714 .727 r
.30607 .83028 m .30961 .82478 L .31831 .82933 L p F P
0 g
s
.829 .722 .747 r
.31831 .82933 m .30961 .82478 L .31904 .81207 L p F P
0 g
s
.684 .704 .863 r
.51473 .71713 m .53537 .70889 L .54093 .71655 L p F P
0 g
s
.68 .72 .88 r
.53537 .70889 m .51473 .71713 L .5091 .70967 L p F P
0 g
s
.697 .714 .861 r
.48854 .71884 m .5091 .70967 L .51473 .71713 L p F P
0 g
s
.802 .861 .893 r
.73681 .49501 m .73602 .49429 L .73693 .49363 L closepath p F P
0 g
s
.446 0 0 r
.54612 .99014 m .53812 .98901 L .54818 .98882 L closepath p F P
0 g
s
.433 0 0 r
.53812 .98901 m .54612 .99014 L p .51987 .99036 L F P
0 g
s
.784 .817 .878 r
.45325 .52856 m .43906 .53859 L .43678 .53109 L p F P
0 g
s
.486 0 0 r
.51359 .98899 m .51987 .99036 L p .49365 .98884 L F P
0 g
s
.486 0 0 r
.49365 .98884 m .49439 .98844 L .51359 .98899 L p F P
0 g
s
.722 .715 .843 r
.65746 .24763 m .65772 .24805 L .65802 .24788 L closepath p F P
0 g
s
.744 .701 .81 r
.65772 .24805 m .65746 .24763 L .64942 .24185 L p F P
0 g
s
.696 .728 .875 r
.5091 .70967 m .48854 .71884 L .48282 .71153 L p F P
0 g
s
.712 .722 .858 r
.46232 .72171 m .48282 .71153 L .48854 .71884 L p F P
0 g
s
.512 .671 .935 r
.7374 .23667 m .7315 .23677 L .7363 .24371 L p F P
0 g
s
.512 .671 .935 r
.7363 .24371 m .7437 .2435 L .7374 .23667 L p F P
0 g
s
.916 .901 .797 r
.79771 .43552 m .79689 .43662 L .7967 .43476 L closepath p F P
0 g
s
.722 .715 .843 r
.65802 .24788 m .6787 .23585 L p .65255 .23957 L F P
0 g
s
.722 .715 .843 r
.65255 .23957 m .65746 .24763 L .65802 .24788 L p F P
0 g
s
.86 .692 .673 r
.59204 .37686 m .59164 .37777 L .59282 .37859 L closepath p F P
0 g
s
.578 .46 .683 r
.45949 .37856 m .47851 .36944 L p .47427 .35791 L F P
0 g
s
.568 .453 .683 r
.48119 .38167 m .47851 .36944 L .45949 .37856 L p F P
0 g
s
.568 .453 .683 r
.47867 .3829 m .48119 .38167 L p .45949 .37856 L F P
0 g
s
.568 .453 .683 r
.45949 .37856 m .46101 .38521 L .47867 .3829 L p F P
0 g
s
.562 .502 .745 r
.73175 .81469 m .729 .81449 L .7313 .81335 L closepath p F P
0 g
s
.573 .523 .761 r
.72634 .80002 m .7313 .81335 L .729 .81449 L p F P
0 g
s
.573 .523 .761 r
.72057 .79987 m .72634 .80002 L p .729 .81449 L F P
0 g
s
.911 .849 .769 r
.45325 .52856 m .45553 .52385 L .45364 .51618 L p F P
0 g
s
.798 .742 .8 r
.35833 .77086 m .34809 .78046 L .34192 .77353 L p F P
0 g
s
.798 .742 .8 r
.34192 .77353 m .34976 .76613 L .35833 .77086 L p F P
0 g
s
.786 .744 .815 r
.36257 .75521 m .34976 .76613 L .35833 .77086 L p F P
0 g
s
.786 .744 .815 r
.35833 .77086 m .36868 .7621 L .36257 .75521 L p F P
0 g
s
.886 .886 .827 r
.78497 .44171 m .78574 .4496 L .79689 .43662 L p F P
0 g
s
.886 .886 .827 r
.79337 .43181 m .78497 .44171 L p .79689 .43662 L F P
0 g
s
.886 .886 .827 r
.79689 .43662 m .7967 .43476 L .79337 .43181 L p F P
0 g
s
.4 0 0 r
.54612 .99014 m .54818 .98882 L .56761 .98784 L p F P
0 g
s
.568 .524 .765 r
.72634 .80002 m .72057 .79987 L .72536 .7974 L closepath p F P
0 g
s
.579 .544 .78 r
.72099 .78667 m .72536 .7974 L .72057 .79987 L p F P
0 g
s
.758 .728 .824 r
.65255 .23957 m .64942 .24185 L .65746 .24763 L closepath p F P
0 g
s
.393 .309 .642 r
.45596 .45107 m .46581 .44084 L .4589 .4343 L p F P
0 g
s
.383 .294 .63 r
.46581 .44084 m .45596 .45107 L .4571 .45813 L p F P
0 g
s
.851 .688 .68 r
.30371 .85359 m .3127 .85797 L .30739 .86958 L p F P
0 g
s
.84 .696 .704 r
.31028 .84165 m .30371 .85359 L .3127 .85797 L p F P
0 g
s
.244 .335 .759 r
.24699 .42198 m .24844 .41226 L .24014 .40674 L p F P
0 g
s
.334 .411 .792 r
.25579 .42641 m .24699 .42198 L .24844 .41226 L p F P
0 g
s
.312 .4 .792 r
.25672 .42849 m .25586 .43647 L p .24699 .42198 L F P
0 g
s
.312 .4 .792 r
.24699 .42198 m .25579 .42641 L .25672 .42849 L p F P
0 g
s
.799 .743 .801 r
.34306 .78522 m .34809 .78046 L .34192 .77353 L p F P
0 g
s
0 0 0 r
.23501 .32022 m .2401 .3085 L p .24357 .29941 L F P
0 g
s
0 0 .116 r
.2401 .3085 m .23501 .32022 L .2334 .32918 L p F P
0 g
s
0 0 .086 r
.23145 .33413 m .2334 .32918 L .23501 .32022 L p F P
0 g
s
.67 .691 .861 r
.54093 .71655 m .56167 .70915 L .56715 .7171 L p F P
0 g
s
.669 .703 .873 r
.56167 .70915 m .54093 .71655 L .53537 .70889 L p F P
0 g
s
.643 .647 .839 r
.40435 .2287 m .38419 .23607 L .39018 .24569 L p F P
0 g
s
.643 .647 .839 r
.39018 .24569 m .41029 .23877 L .40435 .2287 L p F P
0 g
s
.64 .632 .826 r
.41035 .23888 m .41029 .23877 L .39018 .24569 L p F P
0 g
s
.355 .45 .82 r
.25672 .42849 m .26186 .43873 L .25586 .43647 L closepath p F P
0 g
s
.352 .452 .823 r
.26692 .44865 m .26682 .4502 L p .25586 .43647 L F P
0 g
s
.352 .452 .823 r
.25586 .43647 m .26186 .43873 L .26692 .44865 L p F P
0 g
s
.607 .61 .828 r
.65689 .74566 m .67824 .74258 L p .68122 .75306 L F P
0 g
s
.604 .609 .83 r
.67297 .73247 m .67824 .74258 L .65689 .74566 L p F P
0 g
s
.604 .609 .83 r
.66517 .73356 m .67297 .73247 L p .65689 .74566 L F P
0 g
s
.604 .609 .83 r
.65689 .74566 m .65377 .73968 L .66517 .73356 L p F P
0 g
s
.812 .74 .785 r
.33461 .78048 m .34306 .78522 L .3301 .79891 L p F P
0 g
s
.799 .743 .801 r
.34192 .77353 m .33461 .78048 L .34306 .78522 L p F P
0 g
s
.785 .437 .398 r
.37867 .9585 m .37664 .95801 L .37772 .95651 L closepath p F P
0 g
s
.632 .582 .78 r
.42195 .26189 m .42269 .26163 L .42198 .26195 L closepath p F P
0 g
s
.638 .603 .799 r
.43644 .24241 m .41615 .24984 L .42195 .26189 L p F P
0 g
s
.638 .603 .799 r
.44138 .25296 m .43644 .24241 L p .42195 .26189 L F P
0 g
s
.638 .603 .799 r
.42195 .26189 m .42269 .26163 L .44138 .25296 L p F P
0 g
s
.497 .6 .887 r
.33077 .4951 m .31591 .49446 L .31577 .48581 L p F P
0 g
s
.49 .608 .897 r
.33693 .50386 m .33077 .4951 L .31591 .49446 L p F P
0 g
s
0 0 .441 r
.80911 .29973 m .80552 .29401 L .80082 .28554 L p F P
0 g
s
.808 .659 .698 r
.58749 .36158 m .58654 .36314 L .59204 .37686 L p F P
0 g
s
.838 .663 .666 r
.58192 .37245 m .58654 .36314 L .59204 .37686 L p F P
0 g
s
.838 .663 .666 r
.59204 .37686 m .59164 .37777 L .58192 .37245 L p F P
0 g
s
.783 .743 .816 r
.37644 .75566 m .36868 .7621 L .36257 .75521 L p F P
0 g
s
.997 .815 .46 r
.82304 .34888 m .82256 .34905 L .82274 .34786 L closepath p F P
0 g
s
.535 .02 0 r
.49365 .98884 m .49189 .98828 L .49439 .98844 L closepath p F P
0 g
s
.637 .603 .798 r
.44138 .25296 m .44221 .25471 L .42269 .26163 L closepath p F P
0 g
s
.633 .584 .782 r
.44794 .26813 m .44221 .25471 L .42269 .26163 L p F P
0 g
s
.712 .73 .865 r
.48282 .71153 m .46232 .72171 L .45651 .71461 L p F P
0 g
s
.762 .655 .744 r
.59518 .30456 m .5969 .30515 L p .59671 .28743 L F P
0 g
s
.773 .66 .738 r
.59518 .30456 m .59592 .30624 L .5969 .30515 L closepath p F P
0 g
s
0 0 .246 r
.59771 .50943 m .59897 .51716 L .59655 .50862 L p F P
0 g
s
0 0 .246 r
.59655 .50862 m .59586 .50069 L .59771 .50943 L p F P
0 g
s
.475 .201 .418 r
.69272 .95176 m .69368 .94474 L .71395 .93846 L p F P
0 g
s
.508 .27 .49 r
.71431 .92882 m .71395 .93846 L .69368 .94474 L p F P
0 g
s
.505 .225 .422 r
.69368 .94474 m .69272 .95176 L .67154 .95901 L p F P
0 g
s
.839 .662 .662 r
.58192 .37245 m .59164 .37777 L .58708 .38831 L p F P
0 g
s
0 0 .333 r
.2334 .32918 m .23145 .33413 L .23133 .34367 L p F P
0 g
s
0 0 .274 r
.22982 .34855 m .23133 .34367 L .23145 .33413 L p F P
0 g
s
.783 .664 .732 r
.59592 .30624 m .58768 .31725 L p .5849 .30048 L F P
0 g
s
.783 .664 .732 r
.5849 .30048 m .59518 .30456 L .59592 .30624 L p F P
0 g
s
.1 .071 .535 r
.45614 .47948 m .45917 .47334 L .45776 .46241 L p F P
0 g
s
.059 .018 .491 r
.45917 .47334 m .45614 .47948 L .45804 .48792 L p F P
0 g
s
.492 .198 .395 r
.67152 .95913 m .67154 .95901 L .69272 .95176 L p F P
0 g
s
.437 0 0 r
.49189 .98828 m .49365 .98884 L .48785 .99041 L p F P
0 g
s
.437 0 0 r
.48785 .99041 m .47302 .98688 L .49189 .98828 L p F P
0 g
s
.783 .743 .816 r
.36257 .75521 m .36766 .75096 L .37644 .75566 L p F P
0 g
s
.771 .745 .829 r
.38312 .73921 m .36766 .75096 L .37644 .75566 L p F P
0 g
s
.771 .745 .829 r
.37644 .75566 m .38918 .74605 L .38312 .73921 L p F P
0 g
s
.189 .265 .712 r
.24014 .40674 m .24204 .39675 L .2353 .39072 L p F P
0 g
s
.294 .357 .757 r
.24844 .41226 m .24014 .40674 L .24204 .39675 L p F P
0 g
s
.624 .637 .843 r
.62514 .73084 m .6463 .72642 L .6516 .73578 L p F P
0 g
s
.624 .638 .844 r
.64098 .71712 m .6463 .72642 L .62514 .73084 L p F P
0 g
s
.624 .638 .844 r
.63013 .71938 m .64098 .71712 L p .62514 .73084 L F P
0 g
s
.624 .638 .844 r
.62514 .73084 m .62095 .72357 L .63013 .71938 L p F P
0 g
s
.538 .469 .726 r
.73637 .82833 m .75409 .81847 L p .75457 .83505 L F P
0 g
s
.538 .469 .726 r
.75457 .83505 m .73729 .8314 L .73637 .82833 L p F P
0 g
s
.545 .493 .748 r
.75389 .8179 m .75409 .81847 L .73637 .82833 L p F P
0 g
s
.545 .493 .748 r
.73637 .82833 m .73175 .81469 L .75389 .8179 L p F P
0 g
s
0 0 .456 r
.23133 .34367 m .22982 .34855 L .23179 .35621 L p F P
0 g
s
.823 .523 .481 r
.33962 .93662 m .34214 .93008 L p .35134 .94238 L F P
0 g
s
.833 .538 .491 r
.33962 .93662 m .33853 .92887 L .34214 .93008 L closepath p F P
0 g
s
.444 .102 .291 r
.66898 .96701 m .67152 .95913 L .6924 .95362 L p F P
0 g
s
.492 .198 .395 r
.69272 .95176 m .6924 .95362 L .67152 .95913 L p F P
0 g
s
.482 .138 .307 r
.67152 .95913 m .66898 .96701 L .64736 .97173 L p F P
0 g
s
.538 .47 .728 r
.74067 .84249 m .73729 .8314 L .75457 .83505 L closepath p F P
0 g
s
.391 .494 .844 r
.26692 .44865 m .26796 .45052 L .26682 .4502 L closepath p F P
0 g
s
.565 .439 .667 r
.46101 .38521 m .47867 .3829 L .46212 .39073 L closepath p F P
0 g
s
.801 .661 .708 r
.591 .33379 m .57857 .32934 L .58768 .31725 L p F P
0 g
s
.77 .63 .706 r
.58309 .34545 m .591 .33379 L .57857 .32934 L p F P
0 g
s
.8 .852 .889 r
.73693 .49363 m .73602 .49429 L .73132 .48978 L p F P
0 g
s
.817 .86 .88 r
.73695 .4856 m .73693 .49363 L .75641 .47791 L p F P
0 g
s
.8 .852 .889 r
.73132 .48978 m .73695 .4856 L .73693 .49363 L p F P
0 g
s
.762 .655 .744 r
.59671 .28743 m .59045 .29382 L .59518 .30456 L p F P
0 g
s
.783 .664 .732 r
.59045 .29382 m .5849 .30048 L .59518 .30456 L closepath p F P
0 g
s
.759 .681 .776 r
.6265 .25906 m .61104 .27248 L .61254 .27546 L p F P
0 g
s
.785 .691 .76 r
.61104 .27248 m .60961 .27399 L .61254 .27546 L closepath p F P
0 g
s
.823 .734 .767 r
.3301 .79891 m .3273 .80223 L .32109 .79492 L p F P
0 g
s
.823 .734 .767 r
.32109 .79492 m .32169 .79419 L .3301 .79891 L p F P
0 g
s
.812 .74 .785 r
.3301 .79891 m .32169 .79419 L .33461 .78048 L p F P
0 g
s
.657 .678 .859 r
.56715 .7171 m .58801 .71055 L .59343 .7188 L p F P
0 g
s
.657 .687 .867 r
.58801 .71055 m .56715 .7171 L .56167 .70915 L p F P
0 g
s
.817 .983 .886 r
.26461 .27212 m .26307 .27254 L p .28243 .25495 L F P
0 g
s
.817 .983 .886 r
.28243 .25495 m .27884 .26008 L .26461 .27212 L p F P
0 g
s
.845 .996 .834 r
.26461 .27212 m .26153 .2752 L .26307 .27254 L closepath p F P
0 g
s
.971 .786 .597 r
.58976 .46759 m .59399 .47451 L .59664 .46442 L p F P
0 g
s
.971 .786 .597 r
.59664 .46442 m .59231 .45752 L .58976 .46759 L p F P
0 g
s
.531 .446 .704 r
.74067 .84249 m .75457 .83505 L p .74951 .85324 L F P
0 g
s
.531 .446 .704 r
.74951 .85324 m .74304 .85132 L .74067 .84249 L p F P
0 g
s
.54 .489 .747 r
.74882 .80319 m .75389 .8179 L .73175 .81469 L p F P
0 g
s
.54 .489 .747 r
.73175 .81469 m .7313 .81335 L .74882 .80319 L p F P
0 g
s
.587 .584 .816 r
.70933 .76229 m .68878 .76383 L .6835 .75278 L p F P
0 g
s
.552 .515 .768 r
.74838 .80203 m .74882 .80319 L .7313 .81335 L p F P
0 g
s
.552 .515 .768 r
.7313 .81335 m .72634 .80002 L .74838 .80203 L p F P
0 g
s
.43 0 0 r
.57237 .98822 m .56761 .98784 L .57329 .9875 L closepath p F P
0 g
s
.4 0 0 r
.56761 .98784 m .57237 .98822 L p .54612 .99014 L F P
0 g
s
.73 .803 .909 r
.6583 .51985 m .66337 .52501 L .64237 .5356 L p F P
0 g
s
.73 .803 .909 r
.63782 .53001 m .6583 .51985 L p .64237 .5356 L F P
0 g
s
.73 .803 .909 r
.64237 .5356 m .6378 .53091 L .63782 .53001 L p F P
0 g
s
.891 .706 .647 r
.59544 .42064 m .58784 .4147 L .59165 .40435 L p F P
0 g
s
.887 .698 .641 r
.58784 .4147 m .59544 .42064 L .59209 .43086 L p F P
0 g
s
.82 .988 .725 r
.26307 .27254 m .26153 .2752 L .25106 .2876 L p F P
0 g
s
.999 .811 .477 r
.81876 .34918 m .82007 .34024 L .82274 .34786 L p F P
0 g
s
.999 .811 .477 r
.82274 .34786 m .82256 .34905 L .81876 .34918 L p F P
0 g
s
.496 .329 .584 r
.73352 .9114 m .73245 .9005 L .75136 .8924 L p F P
0 g
s
.514 .368 .621 r
.74962 .88086 m .75136 .8924 L .73245 .9005 L p F P
0 g
s
.523 .348 .586 r
.72867 .91319 m .73352 .9114 L .73245 .9005 L p F P
0 g
s
.911 .849 .769 r
.45364 .51618 m .44729 .52557 L .45325 .52856 L p F P
0 g
s
.784 .817 .878 r
.43678 .53109 m .44729 .52557 L .45325 .52856 L p F P
0 g
s
.867 .883 .845 r
.77295 .45427 m .78497 .44171 L .78574 .4496 L p F P
0 g
s
.867 .883 .845 r
.78574 .4496 m .77742 .45819 L .77295 .45427 L p F P
0 g
s
.6 .716 .926 r
.42686 .53527 m .41979 .53679 L .4166 .52955 L p F P
0 g
s
.822 .735 .768 r
.31904 .81207 m .3273 .80223 L .32109 .79492 L p F P
0 g
s
.838 .716 .729 r
.31028 .84165 m .31226 .83863 L .30607 .83028 L p F P
0 g
s
.759 .359 .295 r
.39851 .97025 m .38553 .96729 L .37867 .9585 L p F P
0 g
s
.75 .327 .244 r
.37664 .95801 m .37867 .9585 L .38553 .96729 L p F P
0 g
s
.759 .835 .91 r
.6825 .52208 m .68936 .51801 L .68444 .51333 L p F P
0 g
s
.759 .835 .91 r
.68444 .51333 m .68388 .51366 L .6825 .52208 L p F P
0 g
s
.746 .822 .911 r
.66337 .52501 m .68388 .51366 L .6825 .52208 L p F P
0 g
s
.663 .179 .092 r
.43323 .98233 m .42395 .98069 L .41221 .97301 L p F P
0 g
s
.623 .104 0 r
.40751 .97219 m .41221 .97301 L .42395 .98069 L p F P
0 g
s
.417 .508 .845 r
.26796 .45052 m .28106 .45384 L p .26786 .44082 L F P
0 g
s
.417 .508 .845 r
.26786 .44082 m .26692 .44865 L .26796 .45052 L p F P
0 g
s
.89 .886 .821 r
.7967 .43476 m .79337 .43181 L .79597 .42874 L closepath p F P
0 g
s
.486 0 0 r
.51987 .99036 m .51421 .99175 L .49365 .98884 L p F P
0 g
s
.058 0 0 r
.49365 .98884 m .51421 .99175 L .5118 .99163 L p F P
0 g
s
.058 0 0 r
.48785 .99041 m .49365 .98884 L p .5118 .99163 L F P
0 g
s
.384 0 0 r
.57237 .98822 m .57329 .9875 L .59737 .98523 L p F P
0 g
s
.486 .038 .111 r
.59857 .98404 m .59737 .98523 L .57329 .9875 L p F P
0 g
s
.651 .761 .93 r
.63722 .5303 m .61617 .53789 L .61088 .53091 L p F P
0 g
s
.841 .578 .541 r
.33853 .92887 m .32806 .92513 L .32815 .91475 L p F P
0 g
s
.85 .585 .539 r
.31804 .91086 m .32815 .91475 L .32806 .92513 L p F P
0 g
s
.846 .612 .584 r
.32815 .91475 m .31804 .91086 L .31956 .90016 L p F P
0 g
s
.5 .614 .897 r
.33693 .50386 m .33927 .50391 L .3395 .50742 L closepath p F P
0 g
s
.78 .843 .899 r
.71315 .50739 m .71035 .50471 L .71346 .50265 L closepath p F P
0 g
s
.805 .949 .915 r
.28505 .25538 m .27884 .26008 L .28243 .25495 L closepath p F P
0 g
s
.854 .62 .583 r
.30982 .89612 m .31956 .90016 L .31804 .91086 L p F P
0 g
s
.85 .641 .62 r
.31956 .90016 m .30982 .89612 L .31266 .8851 L p F P
0 g
s
.767 .744 .832 r
.39842 .7393 m .38918 .74605 L .38312 .73921 L p F P
0 g
s
.734 .732 .849 r
.43604 .72577 m .43658 .72546 L .43544 .72505 L closepath p F P
0 g
s
.747 .736 .843 r
.43544 .72505 m .43604 .72577 L p .40965 .73179 L F P
0 g
s
.383 .294 .63 r
.4571 .45813 m .45885 .46095 L p .46581 .44084 L F P
0 g
s
.296 .229 .609 r
.4571 .45813 m .45885 .46095 L .45776 .46241 L closepath p F P
0 g
s
.999 .807 .467 r
.82125 .35746 m .82256 .34905 L .81876 .34918 L p F P
0 g
s
.868 .885 .846 r
.77239 .46332 m .77742 .45819 L .77295 .45427 L p F P
0 g
s
.593 .702 .919 r
.4143 .52194 m .39475 .52514 L .40078 .5324 L p F P
0 g
s
.593 .702 .919 r
.40078 .5324 m .4166 .52955 L .4143 .52194 L p F P
0 g
s
.724 .737 .862 r
.45066 .7077 m .45651 .71461 L .43658 .72546 L p F P
0 g
s
.724 .737 .862 r
.43013 .71888 m .45066 .7077 L p .43658 .72546 L F P
0 g
s
.724 .737 .862 r
.43658 .72546 m .43544 .72505 L .43013 .71888 L p F P
0 g
s
.564 .435 .664 r
.47867 .3829 m .46212 .39073 L .46446 .40258 L p F P
0 g
s
.121 .179 .65 r
.2353 .39072 m .23771 .38043 L .23249 .37389 L p F P
0 g
s
.249 .296 .716 r
.24204 .39675 m .2353 .39072 L .23771 .38043 L p F P
0 g
s
.962 .893 .713 r
.81313 .40316 m .8123 .40477 L .81182 .40232 L closepath p F P
0 g
s
.53 .447 .706 r
.74429 .85593 m .74304 .85132 L .74951 .85324 L closepath p F P
0 g
s
.788 .642 .701 r
.58568 .36086 m .58749 .36158 L p .58309 .34545 L F P
0 g
s
.799 .646 .693 r
.58568 .36086 m .58654 .36314 L .58749 .36158 L closepath p F P
0 g
s
.416 .311 .627 r
.46852 .42566 m .4589 .4343 L .46581 .44084 L p F P
0 g
s
.469 .569 .874 r
.31642 .4768 m .2991 .47531 L .3053 .48476 L p F P
0 g
s
.469 .569 .874 r
.3053 .48476 m .31577 .48581 L .31642 .4768 L p F P
0 g
s
.459 .569 .879 r
.29632 .47501 m .2991 .47531 L .3053 .48476 L p F P
0 g
s
.84 .877 .868 r
.75681 .47755 m .75641 .47791 L .7564 .47718 L closepath p F P
0 g
s
.817 .86 .88 r
.75221 .47315 m .73695 .4856 L p .75641 .47791 L F P
0 g
s
.817 .86 .88 r
.75641 .47791 m .7564 .47718 L .75221 .47315 L p F P
0 g
s
.844 .876 .865 r
.77239 .46332 m .75681 .47755 L .7564 .47718 L p F P
0 g
s
.868 .885 .846 r
.77295 .45427 m .77187 .45538 L .77239 .46332 L p F P
0 g
s
.844 .876 .865 r
.75606 .46995 m .77187 .45538 L .77239 .46332 L p F P
0 g
s
.844 .876 .865 r
.7564 .47718 m .75606 .46995 L p .77239 .46332 L F P
0 g
s
.849 .707 .705 r
.30165 .83711 m .31028 .84165 L .30371 .85359 L p F P
0 g
s
.838 .716 .729 r
.30607 .83028 m .30165 .83711 L .31028 .84165 L p F P
0 g
s
.747 .676 .782 r
.61104 .27248 m .6265 .25906 L .61544 .25393 L p F P
0 g
s
.747 .676 .782 r
.61544 .25393 m .60564 .26176 L .61104 .27248 L p F P
0 g
s
.777 .677 .753 r
.59799 .2691 m .60564 .26176 L .61104 .27248 L p F P
0 g
s
.777 .677 .753 r
.61104 .27248 m .60961 .27399 L .59799 .2691 L p F P
0 g
s
.39 0 0 r
.60981 .98363 m .59737 .98523 L .59857 .98404 L closepath p F P
0 g
s
.421 0 .058 r
.62062 .98215 m .60981 .98363 L .59857 .98404 L p F P
0 g
s
.75 .327 .244 r
.37109 .96239 m .37664 .95801 L p .38553 .96729 L F P
0 g
s
.786 .398 .32 r
.37109 .96239 m .3666 .95528 L .37664 .95801 L closepath p F P
0 g
s
.643 .555 .74 r
.45541 .2879 m .45924 .29874 L .47972 .28941 L p F P
0 g
s
.637 .536 .723 r
.48206 .29659 m .47972 .28941 L .45924 .29874 L p F P
0 g
s
.637 .536 .723 r
.45924 .29874 m .46063 .30314 L .48206 .29659 L p F P
0 g
s
.137 .444 .878 r
.76783 .25242 m .77315 .25951 L .78366 .26447 L p F P
0 g
s
.161 .447 .878 r
.78854 .27167 m .78366 .26447 L .77315 .25951 L p F P
0 g
s
.842 .543 .484 r
.33853 .92887 m .33962 .93662 L .33876 .93847 L p F P
0 g
s
.842 .543 .484 r
.32806 .92513 m .33853 .92887 L p .33876 .93847 L F P
0 g
s
.64 .538 .724 r
.48534 .3066 m .48206 .29659 L .46063 .30314 L p F P
0 g
s
.64 .538 .724 r
.46063 .30314 m .46483 .31631 L .48534 .3066 L p F P
0 g
s
.366 .46 .824 r
.26186 .43873 m .26786 .44082 L .26692 .44865 L closepath p F P
0 g
s
.61 .628 .843 r
.65377 .73968 m .6516 .73578 L .66517 .73356 L closepath p F P
0 g
s
.633 .519 .707 r
.48667 .31111 m .48534 .3066 L .46483 .31631 L p F P
0 g
s
.633 .519 .707 r
.46483 .31631 m .46518 .31757 L .48667 .31111 L p F P
0 g
s
.751 .65 .75 r
.59671 .28743 m .60961 .27399 L .59799 .2691 L p F P
0 g
s
.479 .247 .485 r
.72671 .92434 m .71431 .92882 L .71395 .93846 L p F P
0 g
s
.505 .304 .542 r
.71431 .92882 m .72671 .92434 L .72867 .91319 L p F P
0 g
s
.747 .736 .843 r
.40965 .73179 m .42627 .72117 L .43544 .72505 L p F P
0 g
s
.738 .74 .853 r
.43544 .72505 m .43013 .71888 L .42627 .72117 L closepath p F P
0 g
s
.636 .522 .706 r
.49078 .32502 m .48667 .31111 L .46518 .31757 L p F P
0 g
s
.636 .522 .706 r
.46518 .31757 m .46906 .33117 L .49078 .32502 L p F P
0 g
s
.857 .65 .621 r
.3033 .8809 m .31266 .8851 L .30982 .89612 L p F P
0 g
s
.851 .666 .652 r
.31266 .8851 m .3033 .8809 L .30739 .86958 L p F P
0 g
s
.783 .951 .927 r
.29837 .23992 m .30521 .24241 L .28505 .25538 L p F P
0 g
s
.783 .951 .927 r
.2905 .24544 m .29837 .23992 L p .28505 .25538 L F P
0 g
s
.783 .951 .927 r
.28505 .25538 m .28243 .25495 L .2905 .24544 L p F P
0 g
s
.751 .864 .931 r
.28505 .25538 m .30521 .24241 L .30742 .24369 L p F P
0 g
s
.445 .537 .857 r
.29291 .46527 m .28032 .46304 L .28106 .45384 L p F P
0 g
s
.434 .535 .861 r
.29649 .47123 m .29632 .47501 L p .28032 .46304 L F P
0 g
s
.434 .535 .861 r
.28032 .46304 m .29291 .46527 L .29649 .47123 L p F P
0 g
s
.81 .651 .686 r
.58654 .36314 m .58192 .37245 L p .57629 .35674 L F P
0 g
s
.81 .651 .686 r
.57629 .35674 m .58568 .36086 L .58654 .36314 L p F P
0 g
s
.931 .887 .766 r
.8034 .4087 m .80494 .41647 L .8123 .40477 L p F P
0 g
s
.931 .887 .766 r
.80891 .39985 m .8034 .4087 L p .8123 .40477 L F P
0 g
s
.931 .887 .766 r
.8123 .40477 m .81182 .40232 L .80891 .39985 L p F P
0 g
s
.516 .417 .68 r
.74951 .85324 m .74429 .85593 L .74726 .8687 L p F P
0 g
s
.219 0 0 r
.47302 .98688 m .48785 .99041 L .48327 .99033 L p F P
0 g
s
.219 0 0 r
.46496 .98625 m .47302 .98688 L p .48327 .99033 L F P
0 g
s
.547 .511 .768 r
.74297 .78776 m .74838 .80203 L .72634 .80002 L p F P
0 g
s
.547 .511 .768 r
.74147 .7876 m .74297 .78776 L p .72634 .80002 L F P
0 g
s
.547 .511 .768 r
.72634 .80002 m .72536 .7974 L .74147 .7876 L p F P
0 g
s
.768 .694 .781 r
.63171 .25441 m .6265 .25906 L .61544 .25393 L p F P
0 g
s
.783 .664 .732 r
.58768 .31725 m .5743 .3131 L .5849 .30048 L p F P
0 g
s
.756 .623 .712 r
.57857 .32934 m .58768 .31725 L .5743 .3131 L p F P
0 g
s
.788 .642 .701 r
.58309 .34545 m .581 .34851 L .58568 .36086 L p F P
0 g
s
.81 .652 .687 r
.581 .34851 m .57629 .35674 L .58568 .36086 L closepath p F P
0 g
s
.767 .744 .832 r
.38312 .73921 m .38934 .73465 L .39842 .7393 L p F P
0 g
s
.756 .746 .843 r
.40365 .72502 m .38934 .73465 L .39842 .7393 L p F P
0 g
s
.756 .746 .843 r
.39842 .7393 m .40965 .73179 L .40365 .72502 L p F P
0 g
s
.733 .696 .815 r
.63171 .25441 m .64942 .24185 L .63979 .23615 L p F P
0 g
s
.733 .696 .815 r
.63979 .23615 m .62641 .24495 L .63171 .25441 L p F P
0 g
s
.768 .694 .781 r
.61544 .25393 m .62641 .24495 L .63171 .25441 L p F P
0 g
s
.835 .731 .75 r
.31071 .80735 m .31904 .81207 L .30961 .82478 L p F P
0 g
s
.822 .735 .768 r
.32109 .79492 m .31071 .80735 L .31904 .81207 L p F P
0 g
s
.623 .104 0 r
.40323 .97443 m .40751 .97219 L p .42395 .98069 L F P
0 g
s
.717 .265 .178 r
.40323 .97443 m .39851 .97025 L .40751 .97219 L closepath p F P
0 g
s
.643 .666 .858 r
.59343 .7188 m .61444 .71317 L .6198 .72168 L p F P
0 g
s
.643 .673 .863 r
.61444 .71317 m .59343 .7188 L .58801 .71055 L p F P
0 g
s
.773 .833 .899 r
.71035 .50471 m .68936 .51801 L .68444 .51333 L p F P
0 g
s
.824 .86 .874 r
.7564 .47718 m .75221 .47315 L .75606 .46995 L closepath p F P
0 g
s
.979 .87 .657 r
.81419 .37818 m .81633 .38587 L .82054 .37528 L p F P
0 g
s
.979 .87 .657 r
.82054 .37528 m .81839 .36757 L .81419 .37818 L p F P
0 g
s
.641 .553 .74 r
.45361 .28275 m .45541 .2879 L .47677 .28122 L p F P
0 g
s
.643 .555 .74 r
.47972 .28941 m .47677 .28122 L .45541 .2879 L p F P
0 g
s
.559 .537 .787 r
.72536 .7974 m .72099 .78667 L .74147 .7876 L closepath p F P
0 g
s
.863 .681 .654 r
.59165 .40435 m .58266 .39884 L .58708 .38831 L p F P
0 g
s
.857 .67 .648 r
.58266 .39884 m .59165 .40435 L .58784 .4147 L p F P
0 g
s
0 0 .219 r
.456 .50619 m .45847 .49693 L p .45696 .49756 L F P
0 g
s
0 0 0 r
.45542 .50718 m .45847 .49693 L p .45503 .51064 L F P
0 g
s
0 0 0 r
.45364 .51618 m .45542 .50718 L p .45503 .51064 L F P
0 g
s
.829 1 .81 r
.45542 .50718 m .44189 .52102 L p .45567 .50496 L F P
0 g
s
0 0 .049 r
.45847 .49693 m .45542 .50718 L p .4592 .49663 L F P
0 g
s
0 0 .049 r
.45879 .50133 m .46032 .49349 L p .45601 .50553 L F P
0 g
s
0 0 .049 r
.45542 .50718 m .45879 .50133 L p .45601 .50553 L F P
0 g
s
0 0 .168 r
.46598 .48586 m .46032 .49349 L .45879 .50133 L p F P
0 g
s
.829 1 .81 r
.44189 .52102 m .44162 .51268 L p .45879 .50133 L F P
0 g
s
0 0 .168 r
.46246 .49631 m .46598 .48586 L p .46028 .49812 L F P
0 g
s
0 0 .168 r
.45879 .50133 m .46246 .49631 L p .46028 .49812 L F P
0 g
s
.829 1 .81 r
.44162 .51268 m .45605 .5033 L .45879 .50133 L p F P
0 g
s
.721 .955 .671 r
.45879 .50133 m .45605 .5033 L .46118 .4977 L p F P
0 g
s
.721 .955 .671 r
.46118 .4977 m .46246 .49631 L .45879 .50133 L p F P
0 g
s
0 0 0 r
.46246 .49631 m .45605 .5033 L p .46497 .49422 L F P
0 g
s
0 0 0 r
.47252 .48652 m .46246 .49631 L p .46497 .49422 L F P
0 g
s
.829 1 .81 r
.45879 .50133 m .45542 .50718 L p .45567 .50496 L F P
0 g
s
0 0 .049 r
.46032 .49349 m .45847 .49693 L p .4592 .49663 L F P
0 g
s
0 0 .219 r
.45847 .49693 m .45804 .48792 L p .45696 .49756 L F P
0 g
s
.271 .196 .585 r
.45885 .46095 m .45776 .46241 L .45917 .47334 L p F P
0 g
s
.82 .988 .725 r
.25106 .2876 m .2577 .27608 L .26307 .27254 L p F P
0 g
s
.681 .86 .458 r
.2577 .27608 m .25106 .2876 L .24398 .29867 L p F P
0 g
s
.718 .884 .491 r
.24357 .29941 m .24398 .29867 L .25106 .2876 L p F P
0 g
s
.647 .573 .757 r
.44922 .27146 m .45361 .28275 L .47408 .2737 L p F P
0 g
s
.641 .553 .74 r
.47677 .28122 m .47408 .2737 L .45361 .28275 L p F P
0 g
s
.433 0 0 r
.54612 .99014 m .54061 .99174 L .51987 .99036 L p F P
0 g
s
.032 .603 .738 r
.51987 .99036 m .54061 .99174 L .53877 .99168 L p F P
0 g
s
.032 .603 .738 r
.51421 .99175 m .51987 .99036 L p .53877 .99168 L F P
0 g
s
.542 .654 .908 r
.36879 .5197 m .36931 .51966 L .36941 .52049 L closepath p F P
0 g
s
.983 .737 .339 r
.59279 .49347 m .59586 .50069 L .59596 .49136 L p F P
0 g
s
.983 .737 .339 r
.59596 .49136 m .59293 .48412 L .59279 .49347 L p F P
0 g
s
.982 .731 .333 r
.81696 .33269 m .82007 .34024 L .8201 .33118 L p F P
0 g
s
.982 .731 .333 r
.8201 .33118 m .81699 .32363 L .81696 .33269 L p F P
0 g
s
.637 .522 .707 r
.49093 .32551 m .49078 .32502 L .46906 .33117 L p F P
0 g
s
.637 .522 .707 r
.46906 .33117 m .47038 .33579 L .49093 .32551 L p F P
0 g
s
.751 .65 .75 r
.58627 .28431 m .59671 .28743 L p .59799 .2691 L F P
0 g
s
.762 .655 .744 r
.58627 .28431 m .59045 .29382 L .59671 .28743 L closepath p F P
0 g
s
.738 .862 .938 r
.31264 .23831 m .30742 .24369 L .30521 .24241 L closepath p F P
0 g
s
.415 .014 .167 r
.64582 .97463 m .64736 .97173 L .66898 .96701 L p F P
0 g
s
.666 .718 .887 r
.37195 .21962 m .35181 .22797 L .35807 .23511 L p F P
0 g
s
.666 .718 .887 r
.35807 .23511 m .37812 .22736 L .37195 .21962 L p F P
0 g
s
.219 0 0 r
.46157 .98733 m .46496 .98625 L p .48327 .99033 L F P
0 g
s
.529 0 0 r
.46157 .98733 m .45549 .98512 L .46496 .98625 L closepath p F P
0 g
s
.922 .735 .632 r
.59516 .44739 m .5889 .44107 L .59209 .43086 L p F P
0 g
s
.922 .729 .624 r
.5889 .44107 m .59516 .44739 L .59231 .45752 L p F P
0 g
s
.77 .63 .706 r
.57944 .34426 m .58309 .34545 L p .57857 .32934 L F P
0 g
s
.783 .636 .698 r
.57944 .34426 m .581 .34851 L .58309 .34545 L closepath p F P
0 g
s
.648 .628 .816 r
.41615 .24984 m .43644 .24241 L p .41225 .23803 L F P
0 g
s
.648 .628 .816 r
.41225 .23803 m .41035 .23888 L .41615 .24984 L p F P
0 g
s
.432 .645 .947 r
.75856 .24437 m .7437 .2435 L .7374 .23667 L p F P
0 g
s
.453 .645 .94 r
.7437 .2435 m .75856 .24437 L .76325 .25107 L p F P
0 g
s
.631 .505 .69 r
.49429 .33819 m .49093 .32551 L .47038 .33579 L p F P
0 g
s
.631 .505 .69 r
.47038 .33579 m .47253 .3443 L .49429 .33819 L p F P
0 g
s
.384 0 0 r
.59737 .98523 m .59338 .98772 L .57237 .98822 L p F P
0 g
s
.002 0 0 r
.57237 .98822 m .59338 .98772 L .58901 .98859 L p F P
0 g
s
.002 0 0 r
.56701 .99046 m .57237 .98822 L p .58901 .98859 L F P
0 g
s
.4 0 0 r
.57237 .98822 m .56701 .99046 L .54612 .99014 L p F P
0 g
s
.692 .778 .917 r
.34544 .22188 m .32531 .23154 L .3318 .23681 L p F P
0 g
s
.692 .778 .917 r
.3318 .23681 m .35181 .22797 L .34544 .22188 L p F P
0 g
s
.817 .983 .886 r
.26307 .27254 m .27082 .26157 L p .28243 .25495 L F P
0 g
s
.764 .979 .718 r
.27082 .26157 m .26307 .27254 L .2577 .27608 L p F P
0 g
s
.858 .675 .653 r
.2984 .86522 m .30739 .86958 L .3033 .8809 L p F P
0 g
s
.851 .688 .68 r
.30739 .86958 m .2984 .86522 L .30371 .85359 L p F P
0 g
s
.6 .592 .815 r
.6835 .75278 m .68122 .75306 L .68316 .75208 L closepath p F P
0 g
s
.607 .61 .828 r
.67824 .74258 m .68316 .75208 L .68122 .75306 L p F P
0 g
s
.81 .469 .41 r
.3666 .95528 m .35499 .9519 L .35134 .94238 L p F P
0 g
s
.816 .47 .402 r
.34002 .93889 m .35134 .94238 L .35499 .9519 L p F P
0 g
s
.823 .523 .481 r
.35134 .94238 m .34002 .93889 L .33962 .93662 L p F P
0 g
s
.769 .658 .74 r
.59045 .29382 m .5849 .30048 L p .58316 .28328 L F P
0 g
s
.769 .658 .74 r
.58316 .28328 m .58627 .28431 L .59045 .29382 L p F P
0 g
s
.502 .301 .54 r
.73352 .9114 m .72867 .91319 L .72671 .92434 L p F P
0 g
s
.544 .648 .902 r
.36916 .51122 m .36269 .51164 L .36879 .5197 L p F P
0 g
s
.544 .648 .902 r
.36879 .5197 m .36931 .51966 L .36916 .51122 L p F P
0 g
s
.047 .615 .72 r
.54612 .99014 m .56701 .99046 L .56439 .99059 L p F P
0 g
s
.047 .615 .72 r
.54061 .99174 m .54612 .99014 L p .56439 .99059 L F P
0 g
s
.681 .742 .896 r
.69505 .2202 m .67363 .22807 L .6787 .23585 L p F P
0 g
s
.681 .742 .896 r
.6787 .23585 m .70002 .22735 L .69505 .2202 L p F P
0 g
s
.722 .715 .843 r
.6787 .23585 m .67363 .22807 L .65255 .23957 L p F P
0 g
s
.503 .608 .89 r
.33945 .49522 m .33077 .4951 L .33693 .50386 L p F P
0 g
s
.503 .608 .89 r
.33693 .50386 m .33927 .50391 L .33945 .49522 L p F P
0 g
s
.605 .726 .931 r
.72183 .22327 m .70002 .22735 L .70497 .23458 L p F P
0 g
s
.605 .726 .931 r
.70497 .23458 m .72668 .22994 L .72183 .22327 L p F P
0 g
s
.56 .663 .906 r
.38869 .5176 m .36931 .51966 L .36916 .51122 L p F P
0 g
s
.564 .671 .91 r
.39475 .52514 m .38869 .5176 L .36931 .51966 L p F P
0 g
s
.61 .631 .846 r
.66517 .73356 m .6516 .73578 L .6463 .72642 L p F P
0 g
s
.628 .654 .856 r
.62095 .72357 m .6198 .72168 L .63013 .71938 L closepath p F P
0 g
s
.083 .103 .581 r
.23453 .36648 m .23249 .37389 L p .23179 .35621 L F P
0 g
s
.153 .194 .652 r
.23453 .36648 m .23249 .37389 L .23771 .38043 L p F P
0 g
s
.788 .638 .695 r
.581 .34851 m .57629 .35674 L p .57038 .3411 L F P
0 g
s
.788 .638 .695 r
.57038 .3411 m .57944 .34426 L .581 .34851 L p F P
0 g
s
.75 .744 .847 r
.42627 .72117 m .40965 .73179 L .40365 .72502 L p F P
0 g
s
.839 .662 .662 r
.58708 .38831 m .57668 .38324 L .58192 .37245 L p F P
0 g
s
.83 .647 .656 r
.57668 .38324 m .58708 .38831 L .58266 .39884 L p F P
0 g
s
.695 .792 .925 r
.42686 .53527 m .42089 .5287 L p .44213 .52209 L F P
0 g
s
.695 .792 .925 r
.44213 .52209 m .43678 .53109 L .42686 .53527 L p F P
0 g
s
.6 .716 .926 r
.4166 .52955 m .42089 .5287 L .42686 .53527 L p F P
0 g
s
0 .232 .748 r
.78366 .26447 m .78854 .27167 L .79609 .27779 L p F P
0 g
s
.383 .294 .63 r
.45885 .46095 m .4718 .44797 L p .46581 .44084 L F P
0 g
s
.341 .227 .576 r
.4718 .44797 m .45885 .46095 L .46264 .4687 L p F P
0 g
s
.271 .196 .585 r
.45917 .47334 m .46264 .4687 L .45885 .46095 L p F P
0 g
s
.645 .57 .756 r
.44794 .26813 m .44922 .27146 L .47048 .26459 L p F P
0 g
s
.647 .573 .757 r
.47408 .2737 m .47048 .26459 L .44922 .27146 L p F P
0 g
s
.564 .435 .664 r
.46446 .40258 m .48341 .39338 L p .47867 .3829 L F P
0 g
s
.551 .425 .662 r
.48553 .40501 m .48341 .39338 L .46446 .40258 L p F P
0 g
s
.551 .425 .662 r
.47058 .41246 m .48553 .40501 L p .46446 .40258 L F P
0 g
s
.551 .425 .662 r
.46446 .40258 m .46639 .41257 L .47058 .41246 L p F P
0 g
s
.634 .506 .689 r
.4965 .34656 m .49429 .33819 L .47253 .3443 L p F P
0 g
s
.634 .506 .689 r
.47753 .35672 m .4965 .34656 L p .47253 .3443 L F P
0 g
s
.634 .506 .689 r
.47253 .3443 m .47579 .35718 L .47753 .35672 L p F P
0 g
s
.587 .584 .816 r
.6835 .75278 m .70513 .75132 L p .70933 .76229 L F P
0 g
s
.581 .583 .819 r
.70032 .7414 m .70513 .75132 L .6835 .75278 L p F P
0 g
s
.581 .583 .819 r
.6835 .75278 m .68316 .75208 L .70032 .7414 L p F P
0 g
s
.925 .61 .142 r
.81344 .31616 m .81699 .32363 L .81559 .31512 L p F P
0 g
s
.925 .61 .142 r
.81559 .31512 m .81204 .30765 L .81344 .31616 L p F P
0 g
s
.77 .63 .706 r
.57857 .32934 m .57545 .33345 L .57944 .34426 L p F P
0 g
s
.788 .639 .696 r
.57545 .33345 m .57038 .3411 L .57944 .34426 L closepath p F P
0 g
s
.769 .658 .74 r
.5849 .30048 m .57074 .29657 L .58316 .28328 L p F P
0 g
s
.744 .619 .72 r
.5743 .3131 m .5849 .30048 L .57074 .29657 L p F P
0 g
s
.508 .389 .653 r
.74726 .8687 m .76433 .85997 L p .75079 .88028 L F P
0 g
s
.508 .389 .653 r
.75079 .88028 m .74932 .87931 L .74726 .8687 L p F P
0 g
s
.516 .417 .68 r
.74726 .8687 m .76433 .85997 L .74951 .85324 L p F P
0 g
s
.559 .537 .786 r
.74147 .7876 m .72099 .78667 L .71839 .7803 L p F P
0 g
s
.935 .885 .759 r
.81182 .40232 m .80891 .39985 L .8107 .39699 L closepath p F P
0 g
s
.59 .604 .834 r
.69986 .74051 m .70032 .7414 L .68316 .75208 L p F P
0 g
s
.59 .604 .834 r
.68316 .75208 m .67824 .74258 L .69986 .74051 L p F P
0 g
s
.263 0 0 r
.59338 .98772 m .59737 .98523 L .60981 .98363 L p F P
0 g
s
.68 .72 .88 r
.53284 .70568 m .53537 .70889 L p .5091 .70967 L F P
0 g
s
.68 .72 .88 r
.5091 .70967 m .52053 .70533 L .53284 .70568 L p F P
0 g
s
.68 .721 .88 r
.5091 .70967 m .52053 .70533 L .50521 .70484 L closepath p F P
0 g
s
.696 .728 .875 r
.50521 .70484 m .5091 .70967 L p .48282 .71153 L F P
0 g
s
.756 .623 .712 r
.57342 .32793 m .57857 .32934 L p .5743 .3131 L F P
0 g
s
.769 .629 .705 r
.57342 .32793 m .57545 .33345 L .57857 .32934 L closepath p F P
0 g
s
.648 .589 .774 r
.44794 .26813 m .4684 .25928 L p .46193 .24634 L F P
0 g
s
.648 .589 .774 r
.46193 .24634 m .44221 .25471 L .44794 .26813 L p F P
0 g
s
.645 .57 .756 r
.47048 .26459 m .4684 .25928 L .44794 .26813 L p F P
0 g
s
.654 .676 .858 r
.39833 .21957 m .37812 .22736 L .38419 .23607 L p F P
0 g
s
.654 .676 .858 r
.38419 .23607 m .40435 .2287 L .39833 .21957 L p F P
0 g
s
.754 .717 .818 r
.65255 .23957 m .64942 .24185 L .63979 .23615 L p F P
0 g
s
.429 0 0 r
.45549 .98512 m .46157 .98733 L .4556 .98775 L p F P
0 g
s
.429 0 0 r
.4556 .98775 m .43905 .98308 L .45549 .98512 L p F P
0 g
s
.58 .061 0 r
.45549 .98512 m .43905 .98308 L .43543 .9815 L p F P
0 g
s
.462 .566 .874 r
.29649 .47123 m .2991 .47531 L .29632 .47501 L closepath p F P
0 g
s
.387 .469 .822 r
.26186 .43873 m .26786 .44082 L p .25698 .42697 L F P
0 g
s
.387 .469 .822 r
.25698 .42697 m .25672 .42849 L .26186 .43873 L p F P
0 g
s
.845 .723 .729 r
.30961 .82478 m .30607 .83028 L .29981 .8224 L p F P
0 g
s
.845 .723 .729 r
.29981 .8224 m .30129 .82009 L .30961 .82478 L p F P
0 g
s
.835 .731 .75 r
.30961 .82478 m .30129 .82009 L .31071 .80735 L p F P
0 g
s
0 0 .116 r
.2334 .32918 m .23852 .31747 L .2401 .3085 L p F P
0 g
s
0 0 .348 r
.23852 .31747 m .2334 .32918 L .23381 .33741 L p F P
0 g
s
0 0 .333 r
.23133 .34367 m .23381 .33741 L .2334 .32918 L p F P
0 g
s
.628 .66 .862 r
.63013 .71938 m .6198 .72168 L .61444 .71317 L p F P
0 g
s
.696 .728 .875 r
.48282 .71153 m .50032 .70398 L .50521 .70484 L p F P
0 g
s
.688 .742 .892 r
.50032 .70398 m .48282 .71153 L .47706 .70448 L p F P
0 g
s
.712 .73 .865 r
.45651 .71461 m .47706 .70448 L .48282 .71153 L p F P
0 g
s
.023 .005 .495 r
.23381 .33741 m .23133 .34367 L .23234 .35445 L p F P
0 g
s
0 0 .456 r
.23179 .35621 m .23234 .35445 L .23133 .34367 L p F P
0 g
s
.912 .881 .79 r
.79448 .42098 m .79597 .42874 L .80494 .41647 L p F P
0 g
s
.912 .881 .79 r
.80494 .41647 m .8034 .4087 L .79448 .42098 L p F P
0 g
s
.277 .542 .92 r
.76207 .24544 m .75856 .24437 L .76325 .25107 L p F P
0 g
s
.277 .542 .92 r
.76325 .25107 m .76783 .25242 L .76207 .24544 L p F P
0 g
s
.531 .629 .893 r
.35656 .50333 m .33927 .50391 L .33945 .49522 L p F P
0 g
s
.528 .637 .902 r
.36269 .51164 m .35656 .50333 L .33927 .50391 L p F P
0 g
s
.669 .703 .873 r
.55748 .70346 m .56167 .70915 L p .53537 .70889 L F P
0 g
s
.669 .703 .873 r
.53537 .70889 m .54766 .70461 L .55748 .70346 L p F P
0 g
s
.67 .716 .883 r
.53537 .70889 m .54766 .70461 L .53284 .70568 L closepath p F P
0 g
s
.577 .054 0 r
.43905 .98308 m .43323 .98233 L .43543 .9815 L closepath p F P
0 g
s
.723 .739 .864 r
.66852 .22033 m .64734 .23106 L .65255 .23957 L p F P
0 g
s
.723 .739 .864 r
.65255 .23957 m .67363 .22807 L .66852 .22033 L p F P
0 g
s
.754 .717 .818 r
.63979 .23615 m .64734 .23106 L .65255 .23957 L p F P
0 g
s
0 0 .441 r
.80082 .28554 m .80513 .29234 L .80911 .29973 L p F P
0 g
s
.795 .42 0 r
.80807 .30026 m .81204 .30765 L .80911 .29973 L p F P
0 g
s
.795 .42 0 r
.80911 .29973 m .80513 .29234 L .80807 .30026 L p F P
0 g
s
0 0 .546 r
.79617 .27789 m .79609 .27779 L .80047 .2851 L p F P
0 g
s
0 0 .546 r
.80047 .2851 m .80082 .28554 L .79617 .27789 L p F P
0 g
s
.698 .214 .094 r
.39851 .97025 m .40323 .97443 L .39807 .9759 L p F P
0 g
s
.698 .214 .094 r
.38553 .96729 m .39851 .97025 L p .39807 .9759 L F P
0 g
s
.887 .698 .641 r
.59209 .43086 m .58417 .42505 L .58784 .4147 L p F P
0 g
s
.883 .688 .635 r
.58417 .42505 m .59209 .43086 L .5889 .44107 L p F P
0 g
s
.995 .828 .469 r
.59401 .47458 m .59397 .47465 L .59399 .47451 L closepath p F P
0 g
s
.803 .75 .804 r
.34976 .76613 m .34192 .77353 L .33569 .76688 L p F P
0 g
s
.803 .75 .804 r
.33569 .76688 m .34167 .76121 L .34976 .76613 L p F P
0 g
s
.79 .752 .819 r
.3564 .74858 m .34167 .76121 L .34976 .76613 L p F P
0 g
s
.79 .752 .819 r
.34976 .76613 m .36257 .75521 L .3564 .74858 L p F P
0 g
s
.858 .697 .681 r
.29509 .84907 m .30371 .85359 L .2984 .86522 L p F P
0 g
s
.849 .707 .705 r
.30371 .85359 m .29509 .84907 L .30165 .83711 L p F P
0 g
s
.58 .471 .694 r
.47579 .35718 m .4759 .3576 L .47427 .35791 L closepath p F P
0 g
s
.578 .46 .683 r
.47851 .36944 m .4759 .3576 L .47427 .35791 L p F P
0 g
s
.982 .777 .551 r
.5887 .47325 m .58976 .46759 L .59399 .47451 L p F P
0 g
s
.982 .777 .551 r
.59399 .47451 m .59397 .47465 L .5887 .47325 L p F P
0 g
s
.81 .651 .686 r
.58192 .37245 m .57001 .36787 L .57629 .35674 L p F P
0 g
s
.805 .629 .664 r
.57001 .36787 m .58192 .37245 L .57668 .38324 L p F P
0 g
s
.981 .746 .509 r
.59293 .48412 m .59397 .47465 L .5887 .47325 L p F P
0 g
s
.804 .751 .804 r
.33461 .78048 m .34192 .77353 L .33569 .76688 L p F P
0 g
s
0 0 0 r
.24398 .29867 m .24357 .29941 L .24298 .30095 L closepath p F P
0 g
s
0 0 0 r
.2401 .3085 m .24298 .30095 L .24357 .29941 L p F P
0 g
s
.77 .629 .705 r
.57545 .33345 m .57038 .3411 L p .56442 .32547 L F P
0 g
s
.77 .629 .705 r
.56442 .32547 m .57342 .32793 L .57545 .33345 L p F P
0 g
s
.815 .75 .791 r
.32661 .77557 m .33461 .78048 L .32169 .79419 L p F P
0 g
s
.804 .751 .804 r
.33569 .76688 m .32661 .77557 L .33461 .78048 L p F P
0 g
s
0 0 .402 r
.80513 .29234 m .80082 .28554 L .79617 .27789 L p F P
0 g
s
.999 .807 .467 r
.81876 .34918 m .81867 .34982 L .82125 .35746 L p F P
0 g
s
.993 .844 .589 r
.81579 .35995 m .81839 .36757 L .82125 .35746 L p F P
0 g
s
.993 .844 .589 r
.82125 .35746 m .81867 .34982 L .81579 .35995 L p F P
0 g
s
.514 .418 .684 r
.7623 .84648 m .74951 .85324 L .76433 .85997 L p F P
0 g
s
.531 .446 .704 r
.7596 .83671 m .7623 .84648 L .74951 .85324 L p F P
0 g
s
.531 .446 .704 r
.75457 .83505 m .7596 .83671 L p .74951 .85324 L F P
0 g
s
.788 .752 .82 r
.36766 .75096 m .36257 .75521 L .3564 .74858 L p F P
0 g
s
.559 .537 .786 r
.71839 .7803 m .72785 .77425 L p .74147 .7876 L F P
0 g
s
.566 .558 .804 r
.71839 .7803 m .71567 .77417 L .72785 .77425 L closepath p F P
0 g
s
.79 .388 .291 r
.3666 .95528 m .37109 .96239 L .36925 .96337 L p F P
0 g
s
.79 .388 .291 r
.35499 .9519 m .3666 .95528 L p .36925 .96337 L F P
0 g
s
.745 .813 .906 r
.68388 .51366 m .66337 .52501 L .6583 .51985 L p F P
0 g
s
.713 .742 .875 r
.47706 .70448 m .45651 .71461 L .45066 .7077 L p F P
0 g
s
.779 .834 .895 r
.71346 .50265 m .71035 .50471 L .7055 .49984 L p F P
0 g
s
.773 .833 .899 r
.68444 .51333 m .7055 .49984 L .71035 .50471 L p F P
0 g
s
.751 .65 .75 r
.59799 .2691 m .58496 .28134 L .58627 .28431 L p F P
0 g
s
.769 .658 .74 r
.58496 .28134 m .58316 .28328 L .58627 .28431 L closepath p F P
0 g
s
.472 .279 .537 r
.73392 .92169 m .73352 .9114 L .75249 .90334 L p F P
0 g
s
.502 .301 .54 r
.72671 .92434 m .73392 .92169 L .73352 .9114 L p F P
0 g
s
.496 .329 .584 r
.75136 .8924 m .75249 .90334 L .73352 .9114 L p F P
0 g
s
.788 .752 .82 r
.3564 .74858 m .35942 .74604 L .36766 .75096 L p F P
0 g
s
.775 .753 .833 r
.37701 .73261 m .35942 .74604 L .36766 .75096 L p F P
0 g
s
.775 .753 .833 r
.36766 .75096 m .38312 .73921 L .37701 .73261 L p F P
0 g
s
.634 .505 .688 r
.47579 .35718 m .4759 .3576 L .47753 .35672 L closepath p F P
0 g
s
.624 .485 .672 r
.47753 .35672 m .4759 .3576 L .47851 .36944 L p F P
0 g
s
.738 .872 .943 r
.30521 .24241 m .29837 .23992 L p .32188 .2294 L F P
0 g
s
.738 .872 .943 r
.32188 .2294 m .31264 .23831 L .30521 .24241 L p F P
0 g
s
.756 .623 .712 r
.5743 .3131 m .56988 .31831 L .57342 .32793 L p F P
0 g
s
.77 .63 .705 r
.56988 .31831 m .56442 .32547 L .57342 .32793 L closepath p F P
0 g
s
.657 .687 .867 r
.56167 .70915 m .58257 .70258 L .58801 .71055 L p F P
0 g
s
.657 .701 .879 r
.57945 .69835 m .58257 .70258 L .56167 .70915 L p F P
0 g
s
.657 .701 .879 r
.56167 .70915 m .55748 .70346 L .57945 .69835 L p F P
0 g
s
.787 .982 .902 r
.2905 .24544 m .28243 .25495 L .27791 .25512 L closepath p F P
0 g
s
.817 .983 .886 r
.27082 .26157 m .27791 .25512 L .28243 .25495 L p F P
0 g
s
.844 .724 .731 r
.30165 .83711 m .30607 .83028 L .29981 .8224 L p F P
0 g
s
.681 .86 .458 r
.24398 .29867 m .25143 .28586 L p .2577 .27608 L F P
0 g
s
0 0 0 r
.25143 .28586 m .24398 .29867 L .24298 .30095 L p F P
0 g
s
.5 .67 .94 r
.73068 .22994 m .72668 .22994 L .7315 .23677 L p F P
0 g
s
.5 .67 .94 r
.7315 .23677 m .7374 .23667 L .73068 .22994 L p F P
0 g
s
.744 .619 .72 r
.56735 .31152 m .5743 .3131 L p .57074 .29657 L F P
0 g
s
.758 .626 .714 r
.56735 .31152 m .56988 .31831 L .5743 .3131 L closepath p F P
0 g
s
.735 .672 .789 r
.60564 .26176 m .61544 .25393 L .60223 .24957 L p F P
0 g
s
.735 .672 .789 r
.60223 .24957 m .60022 .25104 L .60564 .26176 L p F P
0 g
s
.757 .659 .753 r
.58412 .26501 m .60022 .25104 L .60564 .26176 L p F P
0 g
s
.757 .659 .753 r
.60564 .26176 m .59799 .2691 L .58412 .26501 L p F P
0 g
s
.475 .201 .418 r
.71395 .93846 m .71379 .93978 L .69272 .95176 L p F P
0 g
s
.455 .169 .388 r
.6924 .95362 m .69272 .95176 L .71379 .93978 L p F P
0 g
s
.797 .847 .888 r
.71346 .50265 m .73132 .48978 L .72655 .48499 L p F P
0 g
s
.797 .847 .888 r
.72655 .48499 m .71322 .49469 L .71346 .50265 L p F P
0 g
s
.779 .834 .895 r
.7055 .49984 m .71322 .49469 L .71346 .50265 L p F P
0 g
s
.788 .638 .695 r
.57629 .35674 m .56278 .35269 L .57038 .3411 L p F P
0 g
s
.784 .615 .672 r
.56278 .35269 m .57629 .35674 L .57001 .36787 L p F P
0 g
s
.628 .494 .68 r
.4965 .34656 m .47753 .35672 L .49758 .35112 L closepath p F P
0 g
s
.624 .485 .672 r
.50051 .36362 m .49758 .35112 L .47753 .35672 L p F P
0 g
s
.624 .485 .672 r
.47851 .36944 m .50051 .36362 L p .47753 .35672 L F P
0 g
s
.957 .873 .713 r
.80858 .38932 m .8107 .39699 L .81633 .38587 L p F P
0 g
s
.957 .873 .713 r
.81633 .38587 m .81419 .37818 L .80858 .38932 L p F P
0 g
s
.04 .294 .785 r
.60007 .51267 m .59771 .50943 L .59897 .51716 L p F P
0 g
s
.04 .294 .785 r
.59897 .51716 m .6055 .52239 L .60007 .51267 L p F P
0 g
s
.231 .145 .547 r
.46264 .4687 m .45917 .47334 L .46014 .48383 L p F P
0 g
s
.059 .018 .491 r
.45804 .48792 m .46014 .48383 L .45917 .47334 L p F P
0 g
s
0 0 .391 r
.46014 .48383 m .45804 .48792 L .45847 .49693 L p F P
0 g
s
.739 .647 .758 r
.58496 .28134 m .59799 .2691 L .58412 .26501 L p F P
0 g
s
.828 .743 .771 r
.32109 .79492 m .32169 .79419 L .31888 .79247 L closepath p F P
0 g
s
.815 .75 .791 r
.31479 .78816 m .32661 .77557 L p .32169 .79419 L F P
0 g
s
.815 .75 .791 r
.32169 .79419 m .31888 .79247 L .31479 .78816 L p F P
0 g
s
.55 .413 .647 r
.46639 .41257 m .47058 .41246 L .46669 .41434 L closepath p F P
0 g
s
.484 .576 .872 r
.2991 .47531 m .31642 .4768 L p .29708 .46589 L F P
0 g
s
.484 .576 .872 r
.29708 .46589 m .29649 .47123 L .2991 .47531 L p F P
0 g
s
.85 .585 .539 r
.32806 .92513 m .31792 .92125 L .31804 .91086 L p F P
0 g
s
.858 .593 .536 r
.30828 .90684 m .31804 .91086 L .31792 .92125 L p F P
0 g
s
.854 .62 .583 r
.31804 .91086 m .30828 .90684 L .30982 .89612 L p F P
0 g
s
.739 .647 .758 r
.58412 .26501 m .57946 .26897 L .58496 .28134 L p F P
0 g
s
.759 .641 .731 r
.56852 .2795 m .57946 .26897 L .58496 .28134 L p F P
0 g
s
.759 .641 .731 r
.58496 .28134 m .58316 .28328 L .56852 .2795 L p F P
0 g
s
.75 .744 .847 r
.40365 .72502 m .4168 .71658 L .42627 .72117 L p F P
0 g
s
.74 .747 .858 r
.42418 .7122 m .4168 .71658 L .42627 .72117 L p F P
0 g
s
.74 .747 .858 r
.42627 .72117 m .43013 .71888 L .42418 .7122 L p F P
0 g
s
.828 .743 .771 r
.31071 .80735 m .32109 .79492 L .31888 .79247 L p F P
0 g
s
.857 .67 .648 r
.58784 .4147 m .57834 .40938 L .58266 .39884 L p F P
0 g
s
.849 .657 .643 r
.57834 .40938 m .58784 .4147 L .58417 .42505 L p F P
0 g
s
.831 .528 .477 r
.34002 .93889 m .33876 .93847 L .33962 .93662 L closepath p F P
0 g
s
.863 .629 .583 r
.30043 .89194 m .30982 .89612 L .30828 .90684 L p F P
0 g
s
.857 .65 .621 r
.30982 .89612 m .30043 .89194 L .3033 .8809 L p F P
0 g
s
.733 .617 .729 r
.57074 .29657 m .58316 .28328 L .56852 .2795 L p F P
0 g
s
.081 .102 .581 r
.23234 .35445 m .23311 .35867 L .23179 .35621 L closepath p F P
0 g
s
.083 .103 .581 r
.23179 .35621 m .23311 .35867 L .23453 .36648 L p F P
0 g
s
.263 0 0 r
.60981 .98363 m .61969 .98298 L p .59338 .98772 L F P
0 g
s
.346 0 0 r
.61969 .98298 m .60981 .98363 L .62062 .98215 L closepath p F P
0 g
s
.754 .624 .715 r
.56988 .31831 m .56442 .32547 L p .55877 .3097 L F P
0 g
s
.754 .624 .715 r
.55877 .3097 m .56735 .31152 L .56988 .31831 L p F P
0 g
s
.751 .678 .781 r
.62641 .24495 m .61544 .25393 L .60223 .24957 L p F P
0 g
s
.842 .543 .484 r
.33876 .93847 m .32948 .93517 L .32806 .92513 L p F P
0 g
s
.85 .549 .479 r
.31792 .92125 m .32806 .92513 L .32948 .93517 L p F P
0 g
s
0 0 0 r
.24298 .30095 m .24112 .30636 L p .25143 .28586 L F P
0 g
s
0 0 0 r
.24298 .30095 m .2401 .3085 L .24112 .30636 L closepath p F P
0 g
s
.547 .406 .641 r
.47058 .41246 m .46669 .41434 L .46852 .42566 L p F P
0 g
s
.735 .848 .933 r
.44729 .52557 m .43678 .53109 L .44213 .52209 L closepath p F P
0 g
s
.535 .651 .909 r
.61028 .53093 m .61014 .52986 L .61088 .53091 L closepath p F P
0 g
s
.886 .874 .819 r
.78895 .42759 m .79448 .42098 L .79597 .42874 L p F P
0 g
s
.886 .874 .819 r
.79597 .42874 m .79337 .43181 L .78895 .42759 L p F P
0 g
s
.716 .792 .911 r
.6378 .53091 m .63722 .5303 L .63782 .53001 L closepath p F P
0 g
s
.566 .558 .805 r
.72785 .77425 m .71567 .77417 L .71038 .76225 L p F P
0 g
s
.507 .39 .655 r
.74962 .88086 m .74932 .87931 L .75079 .88028 L closepath p F P
0 g
s
.771 .752 .836 r
.38934 .73465 m .38312 .73921 L .37701 .73261 L p F P
0 g
s
.77 .629 .705 r
.57038 .3411 m .55517 .33763 L .56442 .32547 L p F P
0 g
s
.739 .584 .683 r
.56278 .35269 m .57038 .3411 L .55517 .33763 L p F P
0 g
s
.655 .611 .793 r
.44138 .25296 m .44221 .25471 L .46193 .24634 L closepath p F P
0 g
s
.728 .745 .865 r
.45066 .7077 m .43013 .71888 L .42418 .7122 L p F P
0 g
s
.647 .626 .814 r
.41029 .23877 m .41225 .23803 L .41035 .23888 L closepath p F P
0 g
s
.925 .974 .738 r
.45542 .50718 m .45364 .51618 L .44729 .52557 L p F P
0 g
s
.653 .65 .835 r
.4247 .22085 m .40435 .2287 L .41029 .23877 L p F P
0 g
s
.653 .65 .835 r
.42985 .22983 m .4247 .22085 L p .41029 .23877 L F P
0 g
s
.653 .65 .835 r
.41029 .23877 m .41225 .23803 L .42985 .22983 L p F P
0 g
s
.329 .411 .794 r
.25579 .42641 m .25698 .42697 L .25672 .42849 L closepath p F P
0 g
s
.415 .014 .167 r
.66898 .96701 m .66712 .97052 L .64582 .97463 L p F P
0 g
s
.338 0 .017 r
.64305 .97821 m .64582 .97463 L .66712 .97052 L p F P
0 g
s
.412 0 .087 r
.64582 .97463 m .64305 .97821 L .62062 .98215 L p F P
0 g
s
.651 .761 .93 r
.61088 .53091 m .63202 .52447 L .63722 .5303 L p F P
0 g
s
.652 .702 .883 r
.61014 .52986 m .61088 .53091 L .63202 .52447 L p F P
0 g
s
.586 .689 .912 r
.40885 .51444 m .38869 .5176 L .39475 .52514 L p F P
0 g
s
.586 .689 .912 r
.41421 .52104 m .40885 .51444 L p .39475 .52514 L F P
0 g
s
.586 .689 .912 r
.39475 .52514 m .4143 .52194 L .41421 .52104 L p F P
0 g
s
.643 .673 .863 r
.58801 .71055 m .60906 .70485 L .61444 .71317 L p F P
0 g
s
.644 .681 .87 r
.60906 .70485 m .58801 .71055 L .58257 .70258 L p F P
0 g
s
.865 .659 .621 r
.29429 .87657 m .3033 .8809 L .30043 .89194 L p F P
0 g
s
.858 .675 .653 r
.3033 .8809 m .29429 .87657 L .2984 .86522 L p F P
0 g
s
.856 .716 .707 r
.29338 .83242 m .30165 .83711 L .29509 .84907 L p F P
0 g
s
.844 .724 .731 r
.29981 .8224 m .29338 .83242 L .30165 .83711 L p F P
0 g
s
.722 .693 .822 r
.62641 .24495 m .63979 .23615 L .62838 .23107 L p F P
0 g
s
.722 .693 .822 r
.62838 .23107 m .62108 .23549 L .62641 .24495 L p F P
0 g
s
.751 .678 .781 r
.60223 .24957 m .62108 .23549 L .62641 .24495 L p F P
0 g
s
.199 0 0 r
.43905 .98308 m .4556 .98775 L .45247 .98729 L p F P
0 g
s
.199 0 0 r
.43323 .98233 m .43905 .98308 L p .45247 .98729 L F P
0 g
s
.889 .878 .818 r
.78497 .44171 m .79337 .43181 L .78895 .42759 L p F P
0 g
s
.922 .729 .624 r
.59231 .45752 m .58591 .45126 L .5889 .44107 L p F P
0 g
s
.924 .722 .612 r
.58591 .45126 m .59231 .45752 L .58976 .46759 L p F P
0 g
s
.667 .724 .891 r
.54766 .70461 m .53284 .70568 L .52978 .70195 L p F P
0 g
s
.676 .727 .888 r
.53284 .70568 m .52978 .70195 L .52053 .70533 L closepath p F P
0 g
s
.744 .619 .72 r
.57074 .29657 m .56431 .30336 L .56735 .31152 L p F P
0 g
s
.754 .624 .715 r
.56431 .30336 m .55877 .3097 L .56735 .31152 L closepath p F P
0 g
s
.488 .351 .62 r
.75079 .88028 m .74962 .88086 L .75136 .8924 L p F P
0 g
s
.655 .609 .791 r
.43644 .24241 m .44138 .25296 L .46193 .24634 L p F P
0 g
s
.671 .56 .721 r
.48206 .29659 m .48534 .3066 L .506 .29328 L p F P
0 g
s
.67 .546 .705 r
.51059 .30751 m .506 .29328 L .48534 .3066 L p F P
0 g
s
.67 .546 .705 r
.48534 .3066 m .48667 .31111 L .51059 .30751 L p F P
0 g
s
.731 .854 .939 r
.32531 .23154 m .31264 .23831 L .32188 .2294 L closepath p F P
0 g
s
.339 .408 .787 r
.25926 .41694 m .2498 .41289 L .25579 .42641 L p F P
0 g
s
.339 .408 .787 r
.25579 .42641 m .25698 .42697 L .25926 .41694 L p F P
0 g
s
.334 .411 .792 r
.24844 .41226 m .2498 .41289 L .25579 .42641 L p F P
0 g
s
.83 .647 .656 r
.58266 .39884 m .57151 .39405 L .57668 .38324 L p F P
0 g
s
.82 .633 .65 r
.57151 .39405 m .58266 .39884 L .57834 .40938 L p F P
0 g
s
.771 .752 .836 r
.37701 .73261 m .38087 .72977 L .38934 .73465 L p F P
0 g
s
.759 .754 .848 r
.39759 .71845 m .38087 .72977 L .38934 .73465 L p F P
0 g
s
.759 .754 .848 r
.38934 .73465 m .40365 .72502 L .39759 .71845 L p F P
0 g
s
.67 .559 .72 r
.47972 .28941 m .48206 .29659 L .50582 .29277 L p F P
0 g
s
.671 .56 .721 r
.506 .29328 m .50582 .29277 L .48206 .29659 L p F P
0 g
s
.404 .067 .277 r
.68997 .96151 m .6924 .95362 L .71269 .94731 L p F P
0 g
s
.455 .169 .388 r
.71379 .93978 m .71269 .94731 L .6924 .95362 L p F P
0 g
s
.444 .102 .291 r
.6924 .95362 m .68997 .96151 L .66898 .96701 L p F P
0 g
s
.733 .617 .729 r
.56101 .29474 m .57074 .29657 L p .56852 .2795 L F P
0 g
s
.747 .625 .723 r
.56101 .29474 m .56431 .30336 L .57074 .29657 L closepath p F P
0 g
s
.715 .781 .904 r
.63782 .53001 m .63722 .5303 L .63202 .52447 L p F P
0 g
s
.67 .574 .738 r
.47677 .28122 m .47972 .28941 L .50037 .27723 L p F P
0 g
s
.67 .559 .72 r
.50582 .29277 m .50037 .27723 L .47972 .28941 L p F P
0 g
s
.672 .547 .704 r
.51163 .31069 m .51059 .30751 L .48667 .31111 L p F P
0 g
s
.672 .547 .704 r
.4918 .32488 m .51163 .31069 L p .48667 .31111 L F P
0 g
s
.672 .547 .704 r
.48667 .31111 m .49078 .32502 L .4918 .32488 L p F P
0 g
s
.676 .728 .889 r
.52416 .69585 m .52978 .70195 L .52053 .70533 L p F P
0 g
s
.676 .728 .889 r
.50342 .7027 m .52416 .69585 L p .52053 .70533 L F P
0 g
s
.676 .728 .889 r
.52053 .70533 m .50521 .70484 L .50342 .7027 L p F P
0 g
s
.479 .247 .485 r
.71395 .93846 m .71647 .93756 L .72671 .92434 L p F P
0 g
s
.473 .24 .48 r
.73392 .92169 m .72671 .92434 L .71647 .93756 L p F P
0 g
s
.653 .65 .834 r
.42985 .22983 m .4306 .23112 L .41225 .23803 L closepath p F P
0 g
s
.648 .628 .816 r
.43644 .24241 m .4306 .23112 L .41225 .23803 L p F P
0 g
s
.999 .799 .488 r
.81557 .34228 m .81696 .33269 L .82007 .34024 L p F P
0 g
s
.999 .799 .488 r
.81836 .34906 m .81557 .34228 L p .82007 .34024 L F P
0 g
s
.999 .799 .488 r
.82007 .34024 m .81876 .34918 L .81836 .34906 L p F P
0 g
s
.631 .489 .67 r
.50207 .37031 m .50051 .36362 L .47851 .36944 L p F P
0 g
s
.631 .489 .67 r
.48412 .38092 m .50207 .37031 L p .47851 .36944 L F P
0 g
s
.631 .489 .67 r
.47851 .36944 m .48119 .38167 L .48412 .38092 L p F P
0 g
s
.816 .47 .402 r
.35499 .9519 m .34367 .94842 L .34002 .93889 L p F P
0 g
s
.819 .459 .374 r
.33876 .93847 m .34002 .93889 L .34367 .94842 L p F P
0 g
s
.715 .781 .904 r
.63202 .52447 m .6365 .5224 L .63782 .53001 L p F P
0 g
s
.717 .785 .905 r
.63782 .53001 m .6583 .51985 L .65319 .51441 L p F P
0 g
s
.717 .785 .905 r
.65319 .51441 m .6365 .5224 L .63782 .53001 L p F P
0 g
s
.8 .843 .884 r
.73695 .4856 m .73132 .48978 L .72655 .48499 L p F P
0 g
s
.754 .624 .715 r
.56442 .32547 m .54747 .3226 L .55877 .3097 L p F P
0 g
s
.727 .583 .693 r
.55517 .33763 m .56442 .32547 L .54747 .3226 L p F P
0 g
s
.61 .631 .846 r
.6463 .72642 m .66769 .72296 L p .66517 .73356 L F P
0 g
s
.607 .634 .852 r
.66769 .72296 m .6463 .72642 L .64098 .71712 L p F P
0 g
s
.895 .59 .088 r
.59429 .50234 m .59771 .50943 L .59586 .50069 L p F P
0 g
s
.895 .59 .088 r
.59586 .50069 m .59279 .49347 L .59429 .50234 L p F P
0 g
s
.109 .439 .877 r
.76207 .24544 m .76783 .25242 L .77831 .25738 L p F P
0 g
s
.137 .444 .878 r
.78366 .26447 m .77831 .25738 L .76783 .25242 L p F P
0 g
s
.838 .741 .757 r
.30278 .80247 m .31071 .80735 L .30129 .82009 L p F P
0 g
s
.828 .743 .771 r
.31372 .7893 m .30278 .80247 L .31071 .80735 L p F P
0 g
s
.828 .743 .771 r
.31888 .79247 m .31372 .7893 L p .31071 .80735 L F P
0 g
s
.652 .702 .883 r
.62677 .51835 m .61641 .52086 L .61014 .52986 L p F P
0 g
s
.652 .702 .883 r
.63202 .52447 m .62677 .51835 L p .61014 .52986 L F P
0 g
s
.591 .646 .873 r
.6055 .52239 m .61641 .52086 L .61014 .52986 L closepath p F P
0 g
s
.587 .607 .84 r
.69986 .74051 m .67824 .74258 L .67297 .73247 L p F P
0 g
s
.488 .351 .62 r
.75136 .8924 m .75822 .88904 L .75079 .88028 L p F P
0 g
s
.485 .35 .622 r
.76784 .87167 m .75079 .88028 L .75822 .88904 L p F P
0 g
s
.508 .389 .653 r
.7657 .86097 m .76784 .87167 L .75079 .88028 L p F P
0 g
s
.508 .389 .653 r
.76433 .85997 m .7657 .86097 L p .75079 .88028 L F P
0 g
s
.023 .005 .495 r
.23234 .35445 m .23611 .34496 L .23381 .33741 L p F P
0 g
s
.155 .154 .604 r
.23611 .34496 m .23234 .35445 L .23311 .35867 L p F P
0 g
s
.449 .543 .861 r
.29291 .46527 m .29708 .46589 L .29649 .47123 L closepath p F P
0 g
s
.741 .621 .726 r
.56431 .30336 m .55877 .3097 L p .55394 .2936 L F P
0 g
s
.741 .621 .726 r
.55394 .2936 m .56101 .29474 L .56431 .30336 L p F P
0 g
s
.504 .599 .881 r
.32458 .48609 m .31577 .48581 L .31642 .4768 L p F P
0 g
s
.497 .6 .887 r
.31577 .48581 m .32458 .48609 L .33077 .4951 L p F P
0 g
s
.691 .732 .882 r
.50521 .70484 m .50342 .7027 L .50032 .70398 L closepath p F P
0 g
s
.817 .75 .789 r
.31888 .79247 m .31479 .78816 L .31372 .7893 L closepath p F P
0 g
s
.595 .706 .921 r
.42089 .5287 m .4166 .52955 L .4143 .52194 L p F P
0 g
s
.67 .572 .737 r
.47408 .2737 m .47677 .28122 L .50032 .27709 L p F P
0 g
s
.67 .574 .738 r
.50037 .27723 m .50032 .27709 L .47677 .28122 L p F P
0 g
s
.199 0 0 r
.4293 .98307 m .43323 .98233 L p .45247 .98729 L F P
0 g
s
.554 0 0 r
.4293 .98307 m .42395 .98069 L .43323 .98233 L closepath p F P
0 g
s
.672 .547 .704 r
.49078 .32502 m .49093 .32551 L .4918 .32488 L closepath p F P
0 g
s
.662 .528 .69 r
.4918 .32488 m .49093 .32551 L .49429 .33819 L p F P
0 g
s
.624 .644 .85 r
.64098 .71712 m .63013 .71938 L .63966 .71487 L closepath p F P
0 g
s
.628 .66 .862 r
.63566 .70842 m .63966 .71487 L .63013 .71938 L p F P
0 g
s
.628 .66 .862 r
.61444 .71317 m .63566 .70842 L p .63013 .71938 L F P
0 g
s
.819 .459 .374 r
.33258 .9447 m .33876 .93847 L p .34367 .94842 L F P
0 g
s
.835 .494 .408 r
.33258 .9447 m .32948 .93517 L .33876 .93847 L closepath p F P
0 g
s
.446 .182 .418 r
.71379 .93978 m .71647 .93756 L .71395 .93846 L closepath p F P
0 g
s
.219 0 0 r
.48327 .99033 m .47943 .98997 L .46157 .98733 L p F P
0 g
s
.253 0 0 r
.47943 .98997 m .46157 .98733 L .4556 .98775 L p F P
0 g
s
.821 .855 .873 r
.73695 .4856 m .75221 .47315 L .74754 .46844 L p F P
0 g
s
.821 .855 .873 r
.74754 .46844 m .73625 .47773 L .73695 .4856 L p F P
0 g
s
.8 .843 .884 r
.72655 .48499 m .73625 .47773 L .73695 .4856 L p F P
0 g
s
.509 .603 .883 r
.34047 .48614 m .32458 .48609 L .33077 .4951 L p F P
0 g
s
.509 .603 .883 r
.33077 .4951 m .33945 .49522 L .34047 .48614 L p F P
0 g
s
.672 .547 .704 r
.51163 .31069 m .4918 .32488 L .51486 .32161 L closepath p F P
0 g
s
.662 .528 .69 r
.51724 .32965 m .51486 .32161 L .4918 .32488 L p F P
0 g
s
.662 .528 .69 r
.50891 .33643 m .51724 .32965 L p .4918 .32488 L F P
0 g
s
.662 .528 .69 r
.49429 .33819 m .50891 .33643 L p .4918 .32488 L F P
0 g
s
.889 .878 .818 r
.78895 .42759 m .78363 .43393 L .78497 .44171 L p F P
0 g
s
.866 .871 .84 r
.77067 .44759 m .78363 .43393 L .78497 .44171 L p F P
0 g
s
.866 .871 .84 r
.77153 .45293 m .77067 .44759 L p .78497 .44171 L F P
0 g
s
.866 .871 .84 r
.78497 .44171 m .77295 .45427 L .77153 .45293 L p F P
0 g
s
.805 .629 .664 r
.57668 .38324 m .56374 .37903 L .57001 .36787 L p F P
0 g
s
.771 .598 .663 r
.57151 .39405 m .57668 .38324 L .56374 .37903 L p F P
0 g
s
.547 .413 .65 r
.48553 .40501 m .48684 .41236 L .47058 .41246 L closepath p F P
0 g
s
.547 .406 .641 r
.48746 .41643 m .48684 .41236 L .47058 .41246 L p F P
0 g
s
.547 .406 .641 r
.46852 .42566 m .48746 .41643 L p .47058 .41246 L F P
0 g
s
.666 .714 .883 r
.55748 .70346 m .55616 .70175 L .54766 .70461 L closepath p F P
0 g
s
.667 .724 .891 r
.55062 .69537 m .55616 .70175 L .54766 .70461 L p F P
0 g
s
.667 .724 .891 r
.52978 .70195 m .55062 .69537 L p .54766 .70461 L F P
0 g
s
.295 0 0 r
.61969 .98298 m .62062 .98215 L .64305 .97821 L p F P
0 g
s
.405 .465 .809 r
.26971 .43104 m .25698 .42697 L .25926 .41694 L p F P
0 g
s
.387 .469 .822 r
.26786 .44082 m .26971 .43104 L .25698 .42697 L p F P
0 g
s
.866 .684 .654 r
.28976 .86072 m .2984 .86522 L .29429 .87657 L p F P
0 g
s
.858 .697 .681 r
.2984 .86522 m .28976 .86072 L .29509 .84907 L p F P
0 g
s
.294 .357 .757 r
.24878 .41056 m .24844 .41226 L p .24204 .39675 L F P
0 g
s
.337 .41 .79 r
.24878 .41056 m .2498 .41289 L .24844 .41226 L closepath p F P
0 g
s
.544 .641 .896 r
.36976 .50243 m .35656 .50333 L .36269 .51164 L p F P
0 g
s
.544 .641 .896 r
.36269 .51164 m .36916 .51122 L .36976 .50243 L p F P
0 g
s
.67 .588 .755 r
.47048 .26459 m .47408 .2737 L .49472 .2624 L p F P
0 g
s
.67 .572 .737 r
.50032 .27709 m .49472 .2624 L .47408 .2737 L p F P
0 g
s
.603 .614 .835 r
.67297 .73247 m .66517 .73356 L .67164 .72997 L closepath p F P
0 g
s
.61 .631 .846 r
.66769 .72296 m .67164 .72997 L .66517 .73356 L p F P
0 g
s
.565 .444 .673 r
.48119 .38167 m .48138 .38257 L .47867 .3829 L closepath p F P
0 g
s
.564 .435 .664 r
.48341 .39338 m .48138 .38257 L .47867 .3829 L p F P
0 g
s
.75 .327 .244 r
.38553 .96729 m .37274 .96425 L .37109 .96239 L p F P
0 g
s
.698 .214 .094 r
.39807 .9759 m .39572 .97534 L .38553 .96729 L p F P
0 g
s
.684 .179 .034 r
.37274 .96425 m .38553 .96729 L .39572 .97534 L p F P
0 g
s
.403 .642 .953 r
.75385 .23791 m .7374 .23667 L .73068 .22994 L p F P
0 g
s
.432 .645 .947 r
.7374 .23667 m .75385 .23791 L .75856 .24437 L p F P
0 g
s
.155 .154 .604 r
.23311 .35867 m .23571 .36318 L p .23611 .34496 L F P
0 g
s
.115 .125 .592 r
.23311 .35867 m .23571 .36318 L .23453 .36648 L closepath p F P
0 g
s
.741 .621 .726 r
.55877 .3097 m .54013 .30743 L .55394 .2936 L p F P
0 g
s
.718 .584 .705 r
.54747 .3226 m .55877 .3097 L .54013 .30743 L p F P
0 g
s
.883 .688 .635 r
.5889 .44107 m .58063 .43539 L .58417 .42505 L p F P
0 g
s
.868 .673 .637 r
.58591 .45126 m .5889 .44107 L .58063 .43539 L p F P
0 g
s
.925 .974 .738 r
.44729 .52557 m .44213 .52209 L p .45542 .50718 L F P
0 g
s
.784 .615 .672 r
.57001 .36787 m .55513 .36432 L .56278 .35269 L p F P
0 g
s
.753 .588 .672 r
.56374 .37903 m .57001 .36787 L .55513 .36432 L p F P
0 g
s
.688 .742 .892 r
.47706 .70448 m .48663 .70066 L .50032 .70398 L p F P
0 g
s
.693 .749 .895 r
.4977 .6964 m .48663 .70066 L .50032 .70398 L p F P
0 g
s
.693 .749 .895 r
.50032 .70398 m .50342 .7027 L .4977 .6964 L p F P
0 g
s
.623 .104 0 r
.42395 .98069 m .40971 .97806 L .40323 .97443 L p F P
0 g
s
.623 .103 0 r
.40971 .97806 m .39807 .9759 L .40323 .97443 L closepath p F P
0 g
s
.821 .851 .87 r
.75606 .46995 m .75221 .47315 L .74754 .46844 L p F P
0 g
s
.733 .617 .729 r
.56852 .2795 m .55873 .28878 L .56101 .29474 L p F P
0 g
s
.741 .621 .726 r
.55873 .28878 m .55394 .2936 L .56101 .29474 L closepath p F P
0 g
s
.366 0 .137 r
.66712 .97052 m .66898 .96701 L .68997 .96151 L p F P
0 g
s
.416 .311 .627 r
.46581 .44084 m .47024 .43689 L .46852 .42566 L p F P
0 g
s
.408 .3 .618 r
.47024 .43689 m .47169 .44704 L .46581 .44084 L closepath p F P
0 g
s
.383 .294 .63 r
.4718 .44797 m .47169 .44704 L .46581 .44084 L p F P
0 g
s
.864 .871 .842 r
.77295 .45427 m .77187 .45538 L .77153 .45293 L closepath p F P
0 g
s
.93 .872 .759 r
.80458 .39579 m .80858 .38932 L .8107 .39699 L p F P
0 g
s
.93 .872 .759 r
.8107 .39699 m .80891 .39985 L .80458 .39579 L p F P
0 g
s
.432 .504 .833 r
.28055 .44377 m .26786 .44082 L .26971 .43104 L p F P
0 g
s
.417 .508 .845 r
.28215 .44679 m .28055 .44377 L .26786 .44082 L p F P
0 g
s
.417 .508 .845 r
.28106 .45384 m .28215 .44679 L p .26786 .44082 L F P
0 g
s
.74 .706 .82 r
.64734 .23106 m .63979 .23615 L .62838 .23107 L p F P
0 g
s
.839 .857 .858 r
.75505 .46214 m .75606 .46995 L .77187 .45538 L p F P
0 g
s
.839 .857 .858 r
.76839 .44973 m .75505 .46214 L p .77187 .45538 L F P
0 g
s
.839 .857 .858 r
.77187 .45538 m .77153 .45293 L .76839 .44973 L p F P
0 g
s
.577 .566 .804 r
.71038 .76225 m .70933 .76229 L .71018 .76179 L closepath p F P
0 g
s
.587 .584 .816 r
.70513 .75132 m .71018 .76179 L .70933 .76229 L p F P
0 g
s
.821 .851 .87 r
.74754 .46844 m .75505 .46214 L .75606 .46995 L p F P
0 g
s
.628 .666 .867 r
.63566 .70842 m .61444 .71317 L .60906 .70485 L p F P
0 g
s
.42 .146 .389 r
.71269 .94731 m .71379 .93978 L .71647 .93756 L p F P
0 g
s
.68 .756 .909 r
.36567 .21293 m .34544 .22188 L .35181 .22797 L p F P
0 g
s
.68 .756 .909 r
.35181 .22797 m .37195 .21962 L .36567 .21293 L p F P
0 g
s
.974 .855 .662 r
.81158 .37059 m .81419 .37818 L .81839 .36757 L p F P
0 g
s
.974 .855 .662 r
.81839 .36757 m .81579 .35995 L .81158 .37059 L p F P
0 g
s
.752 .752 .852 r
.4168 .71658 m .40365 .72502 L .39759 .71845 L p F P
0 g
s
.742 .653 .761 r
.57694 .26346 m .57946 .26897 L .58412 .26501 L closepath p F P
0 g
s
.724 .618 .739 r
.57946 .26897 m .57694 .26346 L .56851 .26154 L p F P
0 g
s
.724 .618 .739 r
.56852 .2795 m .57946 .26897 L p .56851 .26154 L F P
0 g
s
.67 .743 .905 r
.69004 .21318 m .66852 .22033 L .67363 .22807 L p F P
0 g
s
.67 .743 .905 r
.67363 .22807 m .69505 .2202 L .69004 .21318 L p F P
0 g
s
.249 .296 .716 r
.24261 .39441 m .24204 .39675 L p .23771 .38043 L F P
0 g
s
.296 .357 .756 r
.24261 .39441 m .24394 .3979 L .24204 .39675 L closepath p F P
0 g
s
.294 .357 .757 r
.24204 .39675 m .24394 .3979 L .24878 .41056 L p F P
0 g
s
.758 .826 .905 r
.68444 .51333 m .68388 .51366 L .68393 .51283 L closepath p F P
0 g
s
.745 .813 .906 r
.67945 .50814 m .68393 .51283 L .68388 .51366 L p F P
0 g
s
.745 .813 .906 r
.6583 .51985 m .67945 .50814 L p .68388 .51366 L F P
0 g
s
.988 .729 .362 r
.81341 .32524 m .81696 .33269 L .81699 .32363 L p F P
0 g
s
.988 .729 .362 r
.81699 .32363 m .81344 .31616 L .81341 .32524 L p F P
0 g
s
.42 .146 .389 r
.71647 .93756 m .73359 .93132 L p .71269 .94731 L F P
0 g
s
.473 .24 .48 r
.71647 .93756 m .73359 .93132 L .73392 .92169 L p F P
0 g
s
.674 .535 .687 r
.49429 .33819 m .4965 .34656 L .50891 .33643 L closepath p F P
0 g
s
.776 .829 .894 r
.70059 .49471 m .7055 .49984 L .68444 .51333 L p F P
0 g
s
.776 .829 .894 r
.68344 .50576 m .70059 .49471 L p .68444 .51333 L F P
0 g
s
.776 .829 .894 r
.68444 .51333 m .68393 .51283 L .68344 .50576 L p F P
0 g
s
.73 .647 .766 r
.58412 .26501 m .60022 .25104 L p .5887 .2453 L F P
0 g
s
.73 .647 .766 r
.57694 .26346 m .58412 .26501 L p .5887 .2453 L F P
0 g
s
.739 .584 .683 r
.55073 .35044 m .56278 .35269 L p .55517 .33763 L F P
0 g
s
.756 .593 .675 r
.55073 .35044 m .56278 .35269 L .55513 .36432 L p F P
0 g
s
.523 .443 .707 r
.7596 .83671 m .75457 .83505 L .75855 .83286 L closepath p F P
0 g
s
.538 .469 .726 r
.75409 .81847 m .75855 .83286 L .75457 .83505 L p F P
0 g
s
.656 .71 .887 r
.57711 .69533 m .57945 .69835 L .55748 .70346 L p F P
0 g
s
.656 .71 .887 r
.55748 .70346 m .55616 .70175 L .57711 .69533 L p F P
0 g
s
.724 .618 .739 r
.55417 .27728 m .56852 .2795 L p .56851 .26154 L F P
0 g
s
.738 .626 .734 r
.55417 .27728 m .55873 .28878 L .56852 .2795 L closepath p F P
0 g
s
.537 .395 .636 r
.48903 .42747 m .48746 .41643 L .46852 .42566 L p F P
0 g
s
.537 .395 .636 r
.46852 .42566 m .47024 .43689 L .48903 .42747 L p F P
0 g
s
.981 .746 .509 r
.5887 .47325 m .58824 .47736 L .59293 .48412 L p F P
0 g
s
.984 .716 .433 r
.58807 .48674 m .59279 .49347 L .59293 .48412 L p F P
0 g
s
.984 .716 .433 r
.59293 .48412 m .58824 .47736 L .58807 .48674 L p F P
0 g
s
.566 .558 .805 r
.71038 .76225 m .73234 .76263 L p .72785 .77425 L F P
0 g
s
.557 .555 .807 r
.72705 .75094 m .73234 .76263 L .71038 .76225 L p F P
0 g
s
.557 .555 .807 r
.72562 .75091 m .72705 .75094 L p .71038 .76225 L F P
0 g
s
.557 .555 .807 r
.71038 .76225 m .71018 .76179 L .72562 .75091 L p F P
0 g
s
.372 .432 .793 r
.2498 .41289 m .25926 .41694 L p .2511 .40199 L F P
0 g
s
.372 .432 .793 r
.2511 .40199 m .24878 .41056 L .2498 .41289 L p F P
0 g
s
.79 .388 .291 r
.36925 .96337 m .36094 .96093 L .35499 .9519 L p F P
0 g
s
.793 .382 .27 r
.34367 .94842 m .35499 .9519 L .36094 .96093 L p F P
0 g
s
.631 .487 .668 r
.48119 .38167 m .48138 .38257 L .48412 .38092 L closepath p F P
0 g
s
.933 .874 .755 r
.8034 .4087 m .80891 .39985 L .80458 .39579 L p F P
0 g
s
.569 .578 .823 r
.71018 .76179 m .70513 .75132 L .72562 .75091 L closepath p F P
0 g
s
.589 .728 .94 r
.71541 .21698 m .69505 .2202 L .70002 .22735 L p F P
0 g
s
.589 .728 .94 r
.7187 .2191 m .71541 .21698 L p .70002 .22735 L F P
0 g
s
.589 .728 .94 r
.70002 .22735 m .72183 .22327 L .7187 .2191 L p F P
0 g
s
.664 .707 .879 r
.39223 .21144 m .37195 .21962 L .37812 .22736 L p F P
0 g
s
.664 .707 .879 r
.37812 .22736 m .39833 .21957 L .39223 .21144 L p F P
0 g
s
.73 .622 .738 r
.55873 .28878 m .55394 .2936 L p .5507 .27688 L F P
0 g
s
.73 .622 .738 r
.5507 .27688 m .55417 .27728 L .55873 .28878 L p F P
0 g
s
0 0 .149 r
.24112 .30636 m .2401 .3085 L .23852 .31747 L p F P
0 g
s
.67 .588 .755 r
.49472 .2624 m .49372 .26002 L .47048 .26459 L p F P
0 g
s
.668 .586 .754 r
.4684 .25928 m .47048 .26459 L .49372 .26002 L p F P
0 g
s
.668 .772 .928 r
.43531 .51568 m .41488 .52183 L .42089 .5287 L p F P
0 g
s
.668 .772 .928 r
.42089 .5287 m .4413 .52139 L .43531 .51568 L p F P
0 g
s
.695 .792 .925 r
.42089 .5287 m .4413 .52139 L .44213 .52209 L p F P
0 g
s
.595 .706 .921 r
.4143 .52194 m .41488 .52183 L .42089 .5287 L p F P
0 g
s
.628 .782 .955 r
.52416 .69585 m .50342 .7027 L .4977 .6964 L p F P
0 g
s
.727 .583 .693 r
.54649 .33637 m .55517 .33763 L p .54747 .3226 L F P
0 g
s
.744 .592 .686 r
.54649 .33637 m .54925 .34539 L .55517 .33763 L closepath p F P
0 g
s
.739 .584 .683 r
.55517 .33763 m .54925 .34539 L .55073 .35044 L p F P
0 g
s
.621 .468 .653 r
.48412 .38092 m .48138 .38257 L .48341 .39338 L p F P
0 g
s
.231 .145 .547 r
.46014 .48383 m .4653 .4769 L .46264 .4687 L p F P
0 g
s
.146 .037 .462 r
.4653 .4769 m .46014 .48383 L .46032 .49349 L p F P
0 g
s
0 0 .391 r
.45847 .49693 m .46032 .49349 L .46014 .48383 L p F P
0 g
s
0 .213 .73 r
.77831 .25738 m .78366 .26447 L .79122 .27059 L p F P
0 g
s
0 .232 .748 r
.79609 .27779 m .79122 .27059 L .78366 .26447 L p F P
0 g
s
.737 .677 .792 r
.59902 .24872 m .60022 .25104 L .60223 .24957 L closepath p F P
0 g
s
.73 .647 .766 r
.60022 .25104 m .59902 .24872 L .5887 .2453 L p F P
0 g
s
.851 .732 .732 r
.29981 .8224 m .30129 .82009 L .29401 .81564 L closepath p F P
0 g
s
.838 .741 .757 r
.29348 .81506 m .30278 .80247 L p .30129 .82009 L F P
0 g
s
.838 .741 .757 r
.30129 .82009 m .29401 .81564 L .29348 .81506 L p F P
0 g
s
.686 .732 .886 r
.47706 .70448 m .48663 .70066 L .4719 .69845 L closepath p F P
0 g
s
.713 .742 .875 r
.4719 .69845 m .47706 .70448 L p .45066 .7077 L F P
0 g
s
.73 .622 .738 r
.55394 .2936 m .5338 .29186 L .5507 .27688 L p F P
0 g
s
.71 .588 .717 r
.54013 .30743 m .55394 .2936 L .5338 .29186 L p F P
0 g
s
.657 .629 .81 r
.43644 .24241 m .45692 .23384 L p .4491 .22347 L F P
0 g
s
.657 .629 .81 r
.4491 .22347 m .4306 .23112 L .43644 .24241 L p F P
0 g
s
.655 .609 .791 r
.46268 .24602 m .45692 .23384 L .43644 .24241 L p F P
0 g
s
.655 .609 .791 r
.46193 .24634 m .46268 .24602 L p .43644 .24241 L F P
0 g
s
.313 .369 .76 r
.24394 .3979 m .2511 .40199 L .24878 .41056 L closepath p F P
0 g
s
0 0 .348 r
.23381 .33741 m .23896 .3257 L .23852 .31747 L p F P
0 g
s
.095 .05 .511 r
.23611 .34496 m .23381 .33741 L .23896 .3257 L p F P
0 g
s
.758 .816 .899 r
.68393 .51283 m .67945 .50814 L .68344 .50576 L closepath p F P
0 g
s
.728 .672 .796 r
.60223 .24957 m .62108 .23549 L p .61472 .22681 L F P
0 g
s
.728 .672 .796 r
.59902 .24872 m .60223 .24957 L p .61472 .22681 L F P
0 g
s
.849 .657 .643 r
.58417 .42505 m .57409 .41993 L .57834 .40938 L p F P
0 g
s
.826 .636 .645 r
.58063 .43539 m .58417 .42505 L .57409 .41993 L p F P
0 g
s
.664 .516 .674 r
.50891 .33643 m .4965 .34656 L .49758 .35112 L p F P
0 g
s
.631 .778 .951 r
.55062 .69537 m .52978 .70195 L .52416 .69585 L p F P
0 g
s
.713 .74 .872 r
.66338 .21269 m .64211 .22259 L .64734 .23106 L p F P
0 g
s
.713 .74 .872 r
.64734 .23106 m .66852 .22033 L .66338 .21269 L p F P
0 g
s
.74 .706 .82 r
.62838 .23107 m .64211 .22259 L .64734 .23106 L p F P
0 g
s
.217 .238 .668 r
.23571 .36318 m .23453 .36648 L .2379 .37975 L p F P
0 g
s
.153 .194 .652 r
.23771 .38043 m .2379 .37975 L .23453 .36648 L p F P
0 g
s
.718 .584 .705 r
.54201 .322 m .54747 .3226 L p .54013 .30743 L F P
0 g
s
.734 .593 .699 r
.54201 .322 m .54362 .32698 L .54747 .3226 L closepath p F P
0 g
s
.727 .583 .693 r
.54747 .3226 m .54362 .32698 L .54649 .33637 L p F P
0 g
s
.865 .706 .683 r
.28681 .8444 m .29509 .84907 L .28976 .86072 L p F P
0 g
s
.856 .716 .707 r
.29509 .84907 m .28681 .8444 L .29338 .83242 L p F P
0 g
s
.462 0 0 r
.42395 .98069 m .4293 .98307 L .42315 .98295 L p F P
0 g
s
.462 0 0 r
.42315 .98295 m .40971 .97806 L .42395 .98069 L p F P
0 g
s
.295 0 0 r
.64305 .97821 m .64096 .97995 L .61969 .98298 L p F P
0 g
s
.017 0 0 r
.64096 .97995 m .61969 .98298 L .61457 .98542 L p F P
0 g
s
.263 0 0 r
.61969 .98298 m .61457 .98542 L .59338 .98772 L p F P
0 g
s
.454 .537 .853 r
.29885 .45631 m .28673 .45473 L .29291 .46527 L p F P
0 g
s
.454 .537 .853 r
.29291 .46527 m .29708 .46589 L .29885 .45631 L p F P
0 g
s
.445 .537 .857 r
.28106 .45384 m .28673 .45473 L .29291 .46527 L p F P
0 g
s
.058 0 0 r
.5118 .99163 m .49981 .99106 L .48785 .99041 L p F P
0 g
s
.067 0 0 r
.49981 .99106 m .48327 .99033 L .48785 .99041 L closepath p F P
0 g
s
.341 .227 .576 r
.46264 .4687 m .47286 .45853 L .4718 .44797 L p F P
0 g
s
.316 .191 .547 r
.47286 .45853 m .46264 .4687 L .4653 .4769 L p F P
0 g
s
.626 .479 .662 r
.50207 .37031 m .48412 .38092 L .50322 .37587 L closepath p F P
0 g
s
.621 .468 .653 r
.50564 .3878 m .50322 .37587 L .48412 .38092 L p F P
0 g
s
.621 .468 .653 r
.48341 .39338 m .50564 .3878 L p .48412 .38092 L F P
0 g
s
.807 .759 .808 r
.34167 .76121 m .33569 .76688 L .3294 .76053 L p F P
0 g
s
.807 .759 .808 r
.3294 .76053 m .33405 .7561 L .34167 .76121 L p F P
0 g
s
.794 .761 .822 r
.35017 .74222 m .33405 .7561 L .34167 .76121 L p F P
0 g
s
.794 .761 .822 r
.34167 .76121 m .3564 .74858 L .35017 .74222 L p F P
0 g
s
.851 .733 .733 r
.29338 .83242 m .29981 .8224 L .29401 .81564 L p F P
0 g
s
.67 .603 .772 r
.46271 .24608 m .4684 .25928 L .48903 .24868 L p F P
0 g
s
.668 .586 .754 r
.49372 .26002 m .48903 .24868 L .4684 .25928 L p F P
0 g
s
.648 .589 .774 r
.4684 .25928 m .46271 .24608 L .46193 .24634 L p F P
0 g
s
.808 .76 .808 r
.32661 .77557 m .33569 .76688 L .3294 .76053 L p F P
0 g
s
.943 .619 .182 r
.80946 .30878 m .81344 .31616 L .81204 .30765 L p F P
0 g
s
.943 .619 .182 r
.81204 .30765 m .80807 .30026 L .80946 .30878 L p F P
0 g
s
.721 .853 .944 r
.33893 .217 m .34544 .22188 L .32531 .23154 L p F P
0 g
s
.721 .853 .944 r
.33309 .22001 m .33893 .217 L p .32531 .23154 L F P
0 g
s
.721 .853 .944 r
.32531 .23154 m .32188 .2294 L .33309 .22001 L p F P
0 g
s
.447 .534 .853 r
.28215 .44679 m .28673 .45473 L .28106 .45384 L closepath p F P
0 g
s
.699 .574 .711 r
.51059 .30751 m .51163 .31069 L .5156 .30733 L closepath p F P
0 g
s
.689 .557 .7 r
.5156 .30733 m .51163 .31069 L .51486 .32161 L p F P
0 g
s
.685 .566 .715 r
.51059 .30751 m .5156 .30733 L p .50676 .29272 L F P
0 g
s
.685 .566 .715 r
.50676 .29272 m .506 .29328 L .51059 .30751 L p F P
0 g
s
.695 .584 .728 r
.50582 .29277 m .506 .29328 L .50676 .29272 L closepath p F P
0 g
s
.821 .757 .792 r
.32661 .77557 m .31479 .78816 L .30843 .78182 L p F P
0 g
s
.821 .757 .792 r
.30843 .78182 m .31904 .77048 L .32661 .77557 L p F P
0 g
s
.808 .76 .808 r
.3294 .76053 m .31904 .77048 L .32661 .77557 L p F P
0 g
s
.71 .588 .717 r
.53719 .3072 m .54013 .30743 L p .5338 .29186 L F P
0 g
s
.725 .597 .712 r
.53719 .3072 m .538 .30955 L .54013 .30743 L closepath p F P
0 g
s
.718 .584 .705 r
.54013 .30743 m .538 .30955 L .54201 .322 L p F P
0 g
s
.682 .577 .73 r
.50582 .29277 m .50676 .29272 L p .5006 .27707 L F P
0 g
s
.682 .577 .73 r
.5006 .27707 m .50037 .27723 L .50582 .29277 L p F P
0 g
s
.695 .55 .686 r
.54362 .32698 m .54201 .322 L .52566 .3215 L p F P
0 g
s
.695 .55 .686 r
.53597 .33559 m .54362 .32698 L p .52566 .3215 L F P
0 g
s
.726 .582 .694 r
.54362 .32698 m .53597 .33559 L .54649 .33637 L closepath p F P
0 g
s
.714 .582 .706 r
.538 .30955 m .52566 .3215 L .54201 .322 L closepath p F P
0 g
s
.73 .647 .766 r
.5887 .2453 m .57393 .25684 L .57694 .26346 L p F P
0 g
s
.744 .653 .76 r
.57393 .25684 m .56851 .26154 L .57694 .26346 L closepath p F P
0 g
s
.682 .577 .73 r
.50676 .29272 m .52676 .27767 L p .5006 .27707 L F P
0 g
s
.699 .591 .732 r
.52676 .27767 m .50676 .29272 L .53189 .29177 L closepath p F P
0 g
s
.685 .566 .715 r
.53238 .29312 m .53189 .29177 L .50676 .29272 L p F P
0 g
s
.685 .566 .715 r
.5156 .30733 m .53238 .29312 L p .50676 .29272 L F P
0 g
s
.706 .586 .719 r
.53238 .29312 m .5156 .30733 L .53719 .3072 L closepath p F P
0 g
s
.689 .557 .7 r
.538 .30955 m .53719 .3072 L .5156 .30733 L p F P
0 g
s
.689 .557 .7 r
.52566 .3215 m .538 .30955 L p .5156 .30733 L F P
0 g
s
.689 .557 .7 r
.51486 .32161 m .52566 .3215 L p .5156 .30733 L F P
0 g
s
.249 .296 .715 r
.2379 .37975 m .23826 .38088 L .23771 .38043 L closepath p F P
0 g
s
.249 .296 .716 r
.23771 .38043 m .23826 .38088 L .24261 .39441 L p F P
0 g
s
.728 .672 .796 r
.61472 .22681 m .59477 .24046 L .59902 .24872 L p F P
0 g
s
.748 .681 .786 r
.59477 .24046 m .5887 .2453 L .59902 .24872 L closepath p F P
0 g
s
.651 .743 .916 r
.57711 .69533 m .55616 .70175 L .55062 .69537 L p F P
0 g
s
.792 .76 .825 r
.35942 .74604 m .3564 .74858 L .35017 .74222 L p F P
0 g
s
.664 .516 .674 r
.49758 .35112 m .52237 .34857 L p .50891 .33643 L F P
0 g
s
.678 .525 .67 r
.52286 .35039 m .52237 .34857 L .49758 .35112 L p F P
0 g
s
.678 .525 .67 r
.50996 .36271 m .52286 .35039 L p .49758 .35112 L F P
0 g
s
.678 .525 .67 r
.49758 .35112 m .50051 .36362 L .50996 .36271 L p F P
0 g
s
.71 .588 .717 r
.5338 .29186 m .53238 .29312 L .53719 .3072 L p F P
0 g
s
.44 .214 .474 r
.73359 .93132 m .73392 .92169 L .75295 .91367 L p F P
0 g
s
.472 .279 .537 r
.75249 .90334 m .75295 .91367 L .73392 .92169 L p F P
0 g
s
.713 .742 .875 r
.45066 .7077 m .47066 .698 L .4719 .69845 L p F P
0 g
s
.709 .752 .886 r
.47066 .698 m .45066 .7077 L .44476 .70098 L p F P
0 g
s
.728 .745 .865 r
.42418 .7122 m .44476 .70098 L .45066 .7077 L p F P
0 g
s
.676 .539 .69 r
.51724 .32965 m .50891 .33643 L .51877 .33528 L closepath p F P
0 g
s
.664 .516 .674 r
.52237 .34857 m .51877 .33528 L .50891 .33643 L p F P
0 g
s
.467 .308 .581 r
.75822 .88904 m .75136 .8924 L .75249 .90334 L p F P
0 g
s
.754 .324 .231 r
.37274 .96425 m .36925 .96337 L .37109 .96239 L closepath p F P
0 g
s
.726 .582 .693 r
.53597 .33559 m .54649 .33637 L .54925 .34539 L p F P
0 g
s
.792 .76 .825 r
.35017 .74222 m .35171 .74093 L .35942 .74604 L p F P
0 g
s
.779 .761 .837 r
.37085 .72625 m .35171 .74093 L .35942 .74604 L p F P
0 g
s
.779 .761 .837 r
.35942 .74604 m .37701 .73261 L .37085 .72625 L p F P
0 g
s
0 0 .505 r
.79617 .27789 m .79609 .27779 L .79122 .27059 L p F P
0 g
s
.704 .566 .696 r
.51486 .32161 m .51724 .32965 L .52566 .3215 L closepath p F P
0 g
s
0 0 .402 r
.79617 .27789 m .80072 .28504 L .80513 .29234 L p F P
0 g
s
.83 .442 0 r
.80365 .29296 m .80807 .30026 L .80513 .29234 L p F P
0 g
s
.83 .442 0 r
.80513 .29234 m .80072 .28504 L .80365 .29296 L p F P
0 g
s
0 0 .505 r
.79122 .27059 m .79156 .27102 L .79617 .27789 L p F P
0 g
s
.621 .191 0 r
.79588 .27782 m .79156 .27102 L .79617 .27789 L p F P
0 g
s
.621 .191 0 r
.79617 .27789 m .80072 .28504 L .79588 .27782 L p F P
0 g
s
.82 .633 .65 r
.57834 .40938 m .56635 .40488 L .57151 .39405 L p F P
0 g
s
.795 .611 .652 r
.57409 .41993 m .57834 .40938 L .56635 .40488 L p F P
0 g
s
.338 .383 .762 r
.24394 .3979 m .2511 .40199 L p .2452 .38618 L F P
0 g
s
.338 .383 .762 r
.2452 .38618 m .24261 .39441 L .24394 .3979 L p F P
0 g
s
.695 .55 .686 r
.51877 .33528 m .53597 .33559 L p .52566 .3215 L F P
0 g
s
.695 .55 .686 r
.52566 .3215 m .51724 .32965 L .51877 .33528 L p F P
0 g
s
.858 .593 .536 r
.31792 .92125 m .30812 .91725 L .30828 .90684 L p F P
0 g
s
.866 .601 .534 r
.29885 .90268 m .30828 .90684 L .30812 .91725 L p F P
0 g
s
.863 .629 .583 r
.30828 .90684 m .29885 .90268 L .30043 .89194 L p F P
0 g
s
.252 .538 .922 r
.75587 .23855 m .75385 .23791 L .75856 .24437 L p F P
0 g
s
.252 .538 .922 r
.75856 .24437 m .76207 .24544 L .75587 .23855 L p F P
0 g
s
.752 .752 .852 r
.39759 .71845 m .40806 .71173 L .4168 .71658 L p F P
0 g
s
.742 .754 .862 r
.41819 .70571 m .40806 .71173 L .4168 .71658 L p F P
0 g
s
.742 .754 .862 r
.4168 .71658 m .42418 .7122 L .41819 .70571 L p F P
0 g
s
.726 .582 .693 r
.54925 .34539 m .54591 .34982 L p .53597 .33559 L F P
0 g
s
.741 .585 .682 r
.54925 .34539 m .54591 .34982 L .55073 .35044 L closepath p F P
0 g
s
.924 .722 .612 r
.58976 .46759 m .58321 .46139 L .58591 .45126 L p F P
0 g
s
.93 .707 .581 r
.5887 .47325 m .58976 .46759 L .58321 .46139 L p F P
0 g
s
.27 .31 .72 r
.23826 .38088 m .2452 .38618 L .24261 .39441 L closepath p F P
0 g
s
.844 .857 .853 r
.77153 .45293 m .76839 .44973 L .77067 .44759 L closepath p F P
0 g
s
.298 .328 .724 r
.23826 .38088 m .2452 .38618 L p .24157 .36948 L F P
0 g
s
.298 .328 .724 r
.24157 .36948 m .2379 .37975 L .23826 .38088 L p F P
0 g
s
.217 .238 .668 r
.2379 .37975 m .24157 .36948 L .23571 .36318 L p F P
0 g
s
.724 .618 .739 r
.56851 .26154 m .55315 .27469 L .55417 .27728 L p F P
0 g
s
.73 .621 .737 r
.55315 .27469 m .5507 .27688 L .55417 .27728 L closepath p F P
0 g
s
.66 .675 .853 r
.41872 .21154 m .39833 .21957 L .40435 .2287 L p F P
0 g
s
.66 .675 .853 r
.40435 .2287 m .4247 .22085 L .41872 .21154 L p F P
0 g
s
.85 .549 .479 r
.32948 .93517 m .31934 .9313 L .31792 .92125 L p F P
0 g
s
.858 .555 .474 r
.30812 .91725 m .31792 .92125 L .31934 .9313 L p F P
0 g
s
.718 .602 .726 r
.53189 .29177 m .53238 .29312 L .5338 .29186 L closepath p F P
0 g
s
.756 .593 .675 r
.55513 .36432 m .55476 .36425 L .55073 .35044 L p F P
0 g
s
.741 .584 .681 r
.54591 .34982 m .55073 .35044 L .55476 .36425 L p F P
0 g
s
.704 .594 .73 r
.5338 .29186 m .5507 .27688 L .52948 .27552 L p F P
0 g
s
.704 .594 .73 r
.53189 .29177 m .5338 .29186 L p .52948 .27552 L F P
0 g
s
.871 .638 .583 r
.29138 .88763 m .30043 .89194 L .29885 .90268 L p F P
0 g
s
.865 .659 .621 r
.30043 .89194 m .29138 .88763 L .29429 .87657 L p F P
0 g
s
.704 .594 .73 r
.52948 .27552 m .52676 .27767 L .53189 .29177 L p F P
0 g
s
.691 .595 .744 r
.50032 .27709 m .50037 .27723 L .5006 .27707 L closepath p F P
0 g
s
.587 .607 .84 r
.67297 .73247 m .69461 .73053 L .69986 .74051 L p F P
0 g
s
.585 .605 .839 r
.68935 .72059 m .69461 .73053 L .67297 .73247 L p F P
0 g
s
.585 .605 .839 r
.68448 .72101 m .68935 .72059 L p .67297 .73247 L F P
0 g
s
.585 .605 .839 r
.67297 .73247 m .67164 .72997 L .68448 .72101 L p F P
0 g
s
.68 .588 .746 r
.50032 .27709 m .5006 .27707 L p .49942 .2595 L F P
0 g
s
.68 .588 .746 r
.49942 .2595 m .49472 .2624 L .50032 .27709 L p F P
0 g
s
0 0 0 r
.24112 .30636 m .24724 .29584 L .25143 .28586 L p F P
0 g
s
0 0 .21 r
.24724 .29584 m .24112 .30636 L .23987 .31465 L p F P
0 g
s
0 0 .149 r
.23852 .31747 m .23987 .31465 L .24112 .30636 L p F P
0 g
s
.68 .588 .746 r
.5006 .27707 m .52112 .26316 L p .49942 .2595 L F P
0 g
s
.693 .599 .746 r
.52112 .26316 m .5006 .27707 L .52588 .27543 L closepath p F P
0 g
s
.682 .577 .73 r
.52676 .27767 m .52588 .27543 L .5006 .27707 L p F P
0 g
s
.821 .758 .793 r
.31372 .7893 m .31479 .78816 L .30843 .78182 L p F P
0 g
s
.711 .559 .68 r
.51877 .33528 m .53597 .33559 L .52443 .34861 L p F P
0 g
s
.726 .582 .693 r
.54591 .34982 m .52443 .34861 L .53597 .33559 L p F P
0 g
s
.562 .657 .9 r
.3826 .50978 m .36916 .51122 L .36976 .50243 L p F P
0 g
s
.56 .663 .906 r
.36916 .51122 m .3826 .50978 L .38869 .5176 L p F P
0 g
s
.032 .603 .738 r
.53877 .99168 m .52209 .99168 L .51421 .99175 L p F P
0 g
s
.05 .616 .758 r
.52209 .99168 m .5118 .99163 L .51421 .99175 L closepath p F P
0 g
s
.835 .754 .774 r
.30617 .78423 m .31372 .7893 L .30278 .80247 L p F P
0 g
s
.821 .758 .793 r
.30843 .78182 m .30617 .78423 L .31372 .7893 L p F P
0 g
s
.999 .799 .488 r
.81876 .34918 m .81867 .34982 L .81836 .34906 L closepath p F P
0 g
s
.933 .874 .755 r
.80458 .39579 m .80136 .40103 L .8034 .4087 L p F P
0 g
s
.908 .867 .787 r
.79248 .41332 m .79448 .42098 L .8034 .4087 L p F P
0 g
s
.908 .867 .787 r
.8034 .4087 m .80136 .40103 L .79248 .41332 L p F P
0 g
s
.771 .598 .663 r
.56239 .39137 m .57151 .39405 L p .56374 .37903 L F P
0 g
s
.787 .605 .653 r
.56239 .39137 m .57151 .39405 L .56635 .40488 L p F P
0 g
s
.721 .604 .726 r
.55315 .27469 m .5507 .27688 L .52948 .27552 L p F P
0 g
s
.716 .622 .752 r
.55315 .27469 m .56851 .26154 L .55042 .25899 L p F P
0 g
s
.716 .622 .752 r
.55042 .25899 m .54755 .26118 L .55315 .27469 L p F P
0 g
s
.721 .604 .726 r
.52948 .27552 m .54755 .26118 L .55315 .27469 L p F P
0 g
s
.513 .458 .732 r
.75471 .81807 m .75409 .81847 L .75855 .83286 L p F P
0 g
s
.528 .487 .755 r
.75409 .81847 m .75389 .8179 L .75471 .81807 L closepath p F P
0 g
s
0 0 0 r
.58901 .98859 m .59338 .98772 L .61457 .98542 L p F P
0 g
s
.528 .486 .754 r
.75471 .81807 m .75389 .8179 L .74882 .80319 L p F P
0 g
s
.711 .559 .68 r
.52443 .34861 m .52237 .34857 L .51877 .33528 L p F P
0 g
s
.499 .629 .91 r
.61641 .52086 m .6055 .52239 L .60007 .51267 L p F P
0 g
s
.607 .634 .852 r
.64098 .71712 m .66241 .71373 L .66769 .72296 L p F P
0 g
s
.607 .636 .854 r
.6571 .70457 m .66241 .71373 L .64098 .71712 L p F P
0 g
s
.607 .636 .854 r
.65588 .70476 m .6571 .70457 L p .64098 .71712 L F P
0 g
s
.607 .636 .854 r
.64098 .71712 m .63966 .71487 L .65588 .70476 L p F P
0 g
s
.701 .543 .671 r
.53689 .36194 m .54591 .34982 L .52443 .34861 L p F P
0 g
s
.741 .584 .681 r
.55476 .36425 m .53689 .36194 L .54591 .34982 L p F P
0 g
s
.986 .832 .608 r
.81273 .35242 m .81579 .35995 L .81867 .34982 L p F P
0 g
s
.986 .832 .608 r
.81457 .34584 m .81273 .35242 L p .81867 .34982 L F P
0 g
s
.986 .832 .608 r
.81867 .34982 m .81836 .34906 L .81457 .34584 L p F P
0 g
s
.723 .696 .825 r
.61659 .22763 m .62108 .23549 L .62838 .23107 L closepath p F P
0 g
s
.728 .672 .796 r
.62108 .23549 m .61659 .22763 L .61472 .22681 L p F P
0 g
s
.644 .681 .87 r
.58257 .70258 m .60366 .6968 L .60906 .70485 L p F P
0 g
s
.647 .701 .886 r
.59954 .69104 m .60366 .6968 L .58257 .70258 L p F P
0 g
s
.647 .701 .886 r
.58257 .70258 m .57945 .69835 L .59954 .69104 L p F P
0 g
s
.753 .588 .672 r
.5586 .37783 m .56374 .37903 L p .55513 .36432 L F P
0 g
s
.77 .596 .663 r
.5586 .37783 m .56054 .38478 L .56374 .37903 L closepath p F P
0 g
s
.771 .598 .663 r
.56374 .37903 m .56054 .38478 L .56239 .39137 L p F P
0 g
s
.505 .432 .707 r
.75855 .83286 m .77296 .82377 L p .77076 .84136 L F P
0 g
s
.505 .432 .707 r
.77076 .84136 m .7596 .83671 L .75855 .83286 L p F P
0 g
s
.513 .458 .732 r
.75855 .83286 m .77296 .82377 L .75471 .81807 L p F P
0 g
s
.755 .591 .673 r
.55476 .36425 m .55488 .36469 L .55513 .36432 L closepath p F P
0 g
s
.753 .588 .672 r
.55513 .36432 m .55488 .36469 L .5586 .37783 L p F P
0 g
s
.559 .537 .786 r
.72785 .77425 m .73764 .77483 L p .74147 .7876 L F P
0 g
s
.553 .538 .793 r
.73764 .77483 m .72785 .77425 L .73533 .76928 L closepath p F P
0 g
s
.566 .558 .805 r
.73234 .76263 m .73533 .76928 L .72785 .77425 L p F P
0 g
s
.743 .805 .902 r
.67945 .50814 m .6583 .51985 L .65319 .51441 L p F P
0 g
s
.711 .541 .657 r
.55488 .36469 m .55476 .36425 L .53689 .36194 L p F P
0 g
s
.485 .669 .945 r
.72356 .2233 m .72183 .22327 L .72668 .22994 L p F P
0 g
s
.485 .669 .945 r
.72668 .22994 m .73068 .22994 L .72356 .2233 L p F P
0 g
s
.711 .541 .657 r
.54807 .37576 m .55488 .36469 L p .53689 .36194 L F P
0 g
s
.76 .592 .669 r
.55488 .36469 m .54807 .37576 L .5586 .37783 L closepath p F P
0 g
s
.511 .461 .737 r
.77101 .80729 m .75471 .81807 L .77296 .82377 L p F P
0 g
s
.528 .486 .754 r
.77093 .80708 m .77101 .80729 L .75471 .81807 L p F P
0 g
s
.528 .486 .754 r
.75015 .80229 m .77093 .80708 L p .75471 .81807 L F P
0 g
s
.528 .486 .754 r
.74882 .80319 m .75015 .80229 L p .75471 .81807 L F P
0 g
s
.629 .471 .649 r
.50764 .39784 m .50564 .3878 L .48341 .39338 L p F P
0 g
s
.629 .471 .649 r
.50335 .40077 m .50764 .39784 L p .48341 .39338 L F P
0 g
s
.629 .471 .649 r
.48341 .39338 m .48553 .40501 L .50335 .40077 L p F P
0 g
s
.739 .966 .693 r
.27498 .25595 m .27082 .26157 L .25868 .27468 L p F P
0 g
s
.764 .979 .718 r
.2577 .27608 m .25868 .27468 L .27082 .26157 L p F P
0 g
s
.802 .999 .84 r
.27791 .25512 m .27082 .26157 L .27498 .25595 L closepath p F P
0 g
s
.844 .497 .396 r
.32948 .93517 m .33258 .9447 L .33248 .94478 L p F P
0 g
s
.844 .497 .396 r
.31934 .9313 m .32948 .93517 L p .33248 .94478 L F P
0 g
s
.733 .632 .746 r
.57393 .25684 m .56851 .26154 L .55042 .25899 L p F P
0 g
s
.778 .987 .895 r
.27791 .25512 m .27498 .25595 L p .29572 .23955 L F P
0 g
s
.778 .987 .895 r
.29572 .23955 m .2905 .24544 L .27791 .25512 L p F P
0 g
s
.047 .615 .72 r
.56439 .99059 m .54833 .99135 L .54061 .99174 L p F P
0 g
s
.099 .655 .779 r
.54833 .99135 m .53877 .99168 L .54061 .99174 L closepath p F P
0 g
s
.873 .67 .625 r
.28561 .87209 m .29429 .87657 L .29138 .88763 L p F P
0 g
s
.866 .684 .654 r
.29429 .87657 m .28561 .87209 L .28976 .86072 L p F P
0 g
s
.774 .761 .841 r
.38087 .72977 m .37701 .73261 L .37085 .72625 L p F P
0 g
s
.61 .837 .454 r
.25868 .27468 m .2577 .27608 L .25685 .27718 L closepath p F P
0 g
s
.681 .86 .458 r
.25143 .28586 m .25685 .27718 L .2577 .27608 L p F P
0 g
s
.778 .826 .89 r
.71322 .49469 m .7055 .49984 L .70059 .49471 L p F P
0 g
s
.73 .753 .871 r
.44476 .70098 m .42418 .7122 L .41819 .70571 L p F P
0 g
s
.002 0 0 r
.58901 .98859 m .582 .98924 L .56701 .99046 L p F P
0 g
s
.085 .644 .737 r
.582 .98924 m .56439 .99059 L .56701 .99046 L closepath p F P
0 g
s
.504 .433 .709 r
.7623 .84648 m .7596 .83671 L .77076 .84136 L closepath p F P
0 g
s
.72 .649 .777 r
.57393 .25684 m .5887 .2453 L .57293 .24184 L p F P
0 g
s
.72 .649 .777 r
.57293 .24184 m .56839 .24504 L .57393 .25684 L p F P
0 g
s
.733 .632 .746 r
.55042 .25899 m .56839 .24504 L .57393 .25684 L p F P
0 g
s
.584 .676 .903 r
.40279 .50667 m .3826 .50978 L .38869 .5176 L p F P
0 g
s
.584 .676 .903 r
.38869 .5176 m .40885 .51444 L .40279 .50667 L p F P
0 g
s
.594 .625 .852 r
.67164 .72997 m .66769 .72296 L .68448 .72101 L closepath p F P
0 g
s
.535 .51 .774 r
.74882 .80319 m .74838 .80203 L .75015 .80229 L closepath p F P
0 g
s
.68 .738 .894 r
.49194 .69066 m .4977 .6964 L .48663 .70066 L p F P
0 g
s
.68 .738 .894 r
.47126 .69772 m .49194 .69066 L p .48663 .70066 L F P
0 g
s
.68 .738 .894 r
.48663 .70066 m .4719 .69845 L .47126 .69772 L p F P
0 g
s
.684 .179 .034 r
.39572 .97534 m .38333 .97219 L .37274 .96425 L p F P
0 g
s
.644 .11 0 r
.36925 .96337 m .37274 .96425 L .38333 .97219 L p F P
0 g
s
.863 .726 .71 r
.28546 .82758 m .29338 .83242 L .28681 .8444 L p F P
0 g
s
.851 .733 .733 r
.29335 .81524 m .28546 .82758 L .29338 .83242 L p F P
0 g
s
.851 .733 .733 r
.29401 .81564 m .29335 .81524 L p .29338 .83242 L F P
0 g
s
.987 .828 .598 r
.81836 .34906 m .81457 .34584 L .81557 .34228 L closepath p F P
0 g
s
.712 .609 .741 r
.52588 .27543 m .52676 .27767 L .52948 .27552 L closepath p F P
0 g
s
.535 .51 .774 r
.75015 .80229 m .74838 .80203 L .74297 .78776 L p F P
0 g
s
.523 .381 .629 r
.49045 .43839 m .48903 .42747 L .47024 .43689 L p F P
0 g
s
.523 .381 .629 r
.47308 .44733 m .49045 .43839 L p .47024 .43689 L F P
0 g
s
.523 .381 .629 r
.47024 .43689 m .47169 .44704 L .47308 .44733 L p F P
0 g
s
.678 .524 .669 r
.50051 .36362 m .50207 .37031 L .50996 .36271 L closepath p F P
0 g
s
.774 .761 .841 r
.37085 .72625 m .37301 .72465 L .38087 .72977 L p F P
0 g
s
.762 .761 .852 r
.39149 .7121 m .37301 .72465 L .38087 .72977 L p F P
0 g
s
.762 .761 .852 r
.38087 .72977 m .39759 .71845 L .39149 .7121 L p F P
0 g
s
.951 .858 .713 r
.80598 .38174 m .80858 .38932 L .81419 .37818 L p F P
0 g
s
.951 .858 .713 r
.81419 .37818 m .81158 .37059 L .80598 .38174 L p F P
0 g
s
.649 .591 .776 r
.46268 .24602 m .46193 .24634 L .46271 .24608 L closepath p F P
0 g
s
.699 .602 .744 r
.52948 .27552 m .54755 .26118 L p .52865 .25782 L F P
0 g
s
.699 .602 .744 r
.52588 .27543 m .52948 .27552 L p .52865 .25782 L F P
0 g
s
.515 .599 .876 r
.33803 .47664 m .31838 .47684 L .32458 .48609 L p F P
0 g
s
.515 .599 .876 r
.34134 .48176 m .33803 .47664 L p .32458 .48609 L F P
0 g
s
.515 .599 .876 r
.32458 .48609 m .34047 .48614 L .34134 .48176 L p F P
0 g
s
.504 .599 .881 r
.31642 .4768 m .31838 .47684 L .32458 .48609 L p F P
0 g
s
.536 .626 .888 r
.3504 .49477 m .33945 .49522 L .34047 .48614 L p F P
0 g
s
.531 .629 .893 r
.33945 .49522 m .3504 .49477 L .35656 .50333 L p F P
0 g
s
.868 .673 .637 r
.57808 .44623 m .58591 .45126 L p .58063 .43539 L F P
0 g
s
.874 .665 .617 r
.57808 .44623 m .58591 .45126 L .58321 .46139 L p F P
0 g
s
.492 .57 .862 r
.31218 .46694 m .29708 .46589 L .29885 .45631 L p F P
0 g
s
.484 .576 .872 r
.31678 .47441 m .31218 .46694 L .29708 .46589 L p F P
0 g
s
.484 .576 .872 r
.31642 .4768 m .31678 .47441 L p .29708 .46589 L F P
0 g
s
.568 .579 .824 r
.72562 .75091 m .70513 .75132 L .70032 .7414 L p F P
0 g
s
.699 .602 .744 r
.52865 .25782 m .52112 .26316 L .52588 .27543 L p F P
0 g
s
.665 .599 .771 r
.46268 .24602 m .46271 .24608 L .4855 .24084 L p F P
0 g
s
.67 .603 .772 r
.48903 .24868 m .4855 .24084 L .46271 .24608 L p F P
0 g
s
.613 .653 .866 r
.63966 .71487 m .63566 .70842 L .65588 .70476 L closepath p F P
0 g
s
.674 .63 .798 r
.47757 .22424 m .45692 .23384 L .46268 .24602 L p F P
0 g
s
.674 .63 .798 r
.46268 .24602 m .48332 .23598 L .47757 .22424 L p F P
0 g
s
.665 .599 .771 r
.4855 .24084 m .48332 .23598 L .46268 .24602 L p F P
0 g
s
.711 .559 .679 r
.52237 .34857 m .52286 .35039 L .52443 .34861 L closepath p F P
0 g
s
.701 .543 .671 r
.52558 .36139 m .53689 .36194 L p .52443 .34861 L F P
0 g
s
.701 .543 .671 r
.52443 .34861 m .52286 .35039 L .52558 .36139 L p F P
0 g
s
.155 .154 .604 r
.23571 .36318 m .24026 .35185 L .23611 .34496 L p F P
0 g
s
.258 .253 .663 r
.24157 .36948 m .23571 .36318 L .24026 .35185 L p F P
0 g
s
.76 .59 .667 r
.54807 .37576 m .5586 .37783 L .56054 .38478 L p F P
0 g
s
.688 .607 .76 r
.49372 .26002 m .49472 .2624 L .49942 .2595 L closepath p F P
0 g
s
.683 .532 .675 r
.52286 .35039 m .50996 .36271 L .52558 .36139 L closepath p F P
0 g
s
.488 .401 .683 r
.7654 .85942 m .7623 .84648 L .77076 .84136 L p F P
0 g
s
.514 .418 .684 r
.76433 .85997 m .7654 .85942 L .7623 .84648 L p F P
0 g
s
.723 .696 .824 r
.62838 .23107 m .64211 .22259 L p .61572 .22611 L F P
0 g
s
.723 .696 .824 r
.61572 .22611 m .61659 .22763 L .62838 .23107 L p F P
0 g
s
0 0 .539 r
.59461 .50295 m .59429 .50234 L .59771 .50943 L p F P
0 g
s
0 0 .539 r
.59771 .50943 m .60007 .51267 L .59461 .50295 L p F P
0 g
s
.846 .749 .756 r
.30278 .80247 m .29348 .81506 L .28705 .80854 L p F P
0 g
s
.846 .749 .756 r
.28705 .80854 m .29523 .79744 L .30278 .80247 L p F P
0 g
s
.835 .754 .774 r
.30278 .80247 m .29523 .79744 L .30617 .78423 L p F P
0 g
s
.796 .836 .882 r
.71322 .49469 m .72655 .48499 L .72174 .47993 L p F P
0 g
s
.796 .836 .882 r
.72174 .47993 m .71221 .4869 L .71322 .49469 L p F P
0 g
s
.778 .826 .89 r
.70059 .49471 m .71221 .4869 L .71322 .49469 L p F P
0 g
s
.208 0 0 r
.64096 .97995 m .64305 .97821 L .66481 .97349 L p F P
0 g
s
.338 0 .017 r
.66712 .97052 m .66481 .97349 L .64305 .97821 L p F P
0 g
s
.666 .505 .657 r
.52849 .37327 m .52558 .36139 L .50996 .36271 L p F P
0 g
s
.666 .505 .657 r
.52774 .37414 m .52849 .37327 L p .50996 .36271 L F P
0 g
s
.666 .505 .657 r
.50322 .37587 m .52774 .37414 L p .50996 .36271 L F P
0 g
s
.666 .505 .657 r
.50996 .36271 m .50207 .37031 L .50322 .37587 L p F P
0 g
s
.546 .634 .89 r
.37034 .49329 m .3504 .49477 L .35656 .50333 L p F P
0 g
s
.546 .634 .89 r
.37111 .49439 m .37034 .49329 L p .35656 .50333 L F P
0 g
s
.546 .634 .89 r
.35656 .50333 m .36976 .50243 L .37111 .49439 L p F P
0 g
s
.779 .958 .927 r
.29837 .23992 m .2905 .24544 L .29572 .23955 L closepath p F P
0 g
s
.077 .431 .872 r
.75587 .23855 m .76207 .24544 L .77249 .2504 L p F P
0 g
s
.109 .439 .877 r
.77831 .25738 m .77249 .2504 L .76207 .24544 L p F P
0 g
s
.519 .486 .76 r
.77093 .80708 m .75015 .80229 L .76547 .79162 L closepath p F P
0 g
s
.535 .51 .774 r
.76541 .79147 m .76547 .79162 L .75015 .80229 L p F P
0 g
s
.535 .51 .774 r
.74297 .78776 m .76541 .79147 L p .75015 .80229 L F P
0 g
s
.739 .966 .693 r
.25868 .27468 m .26919 .26048 L p .27498 .25595 L F P
0 g
s
0 0 0 r
.26919 .26048 m .25868 .27468 L .25685 .27718 L p F P
0 g
s
.678 .601 .762 r
.49372 .26002 m .49942 .2595 L p .50682 .23855 L F P
0 g
s
.678 .601 .762 r
.50682 .23855 m .48903 .24868 L .49372 .26002 L p F P
0 g
s
.546 .515 .773 r
.74297 .78776 m .74147 .7876 L .74263 .78687 L closepath p F P
0 g
s
.559 .537 .786 r
.73764 .77483 m .74263 .78687 L .74147 .7876 L p F P
0 g
s
.76 .59 .667 r
.56054 .38478 m .55787 .39008 L p .54807 .37576 L F P
0 g
s
.784 .605 .658 r
.56054 .38478 m .55787 .39008 L .56239 .39137 L closepath p F P
0 g
s
.738 .66 .772 r
.59477 .24046 m .5887 .2453 L .57293 .24184 L p F P
0 g
s
.29 0 0 r
.40971 .97806 m .42315 .98295 L .4187 .98205 L p F P
0 g
s
.29 0 0 r
.39807 .9759 m .40971 .97806 L p .4187 .98205 L F P
0 g
s
.644 .11 0 r
.36455 .96465 m .36925 .96337 L p .38333 .97219 L F P
0 g
s
.748 .285 .148 r
.36455 .96465 m .36094 .96093 L .36925 .96337 L closepath p F P
0 g
s
.664 .654 .831 r
.42985 .22983 m .4306 .23112 L .4491 .22347 L closepath p F P
0 g
s
.199 0 0 r
.45247 .98729 m .4452 .98614 L .4293 .98307 L p F P
0 g
s
.256 0 0 r
.4452 .98614 m .4293 .98307 L .42315 .98295 L p F P
0 g
s
.874 .694 .656 r
.28146 .85608 m .28976 .86072 L .28561 .87209 L p F P
0 g
s
.865 .706 .683 r
.28976 .86072 m .28146 .85608 L .28681 .8444 L p F P
0 g
s
.884 .862 .814 r
.78445 .423 m .79248 .41332 L .79448 .42098 L p F P
0 g
s
.884 .862 .814 r
.79448 .42098 m .78895 .42759 L .78445 .423 L p F P
0 g
s
.71 .771 .9 r
.6365 .5224 m .63202 .52447 L .62677 .51835 L p F P
0 g
s
.93 .707 .581 r
.58321 .46139 m .58318 .46153 L .5887 .47325 L p F P
0 g
s
.948 .705 .537 r
.58211 .47103 m .58318 .46153 L .5887 .47325 L p F P
0 g
s
.948 .705 .537 r
.5887 .47325 m .58824 .47736 L .58211 .47103 L p F P
0 g
s
.628 .666 .867 r
.60906 .70485 m .63032 .70004 L .63566 .70842 L p F P
0 g
s
.63 .673 .873 r
.63032 .70004 m .60906 .70485 L .60366 .6968 L p F P
0 g
s
.68 .588 .746 r
.52112 .26316 m .51887 .25776 L .49942 .2595 L p F P
0 g
s
.678 .601 .762 r
.49942 .2595 m .51548 .24957 L p .50682 .23855 L F P
0 g
s
.689 .608 .76 r
.51548 .24957 m .49942 .2595 L .51887 .25776 L closepath p F P
0 g
s
.826 .636 .645 r
.57391 .4322 m .58063 .43539 L p .57409 .41993 L F P
0 g
s
.836 .635 .631 r
.57391 .4322 m .57756 .44482 L .58063 .43539 L closepath p F P
0 g
s
.868 .673 .637 r
.58063 .43539 m .57756 .44482 L .57808 .44623 L p F P
0 g
s
.717 .673 .806 r
.59477 .24046 m .61472 .22681 L .60224 .22205 L p F P
0 g
s
.717 .673 .806 r
.60224 .22205 m .58931 .23009 L .59477 .24046 L p F P
0 g
s
.738 .66 .772 r
.57293 .24184 m .58931 .23009 L .59477 .24046 L p F P
0 g
s
.366 0 .137 r
.68997 .96151 m .68852 .9644 L .66712 .97052 L p F P
0 g
s
.269 0 0 r
.66481 .97349 m .66712 .97052 L .68852 .9644 L p F P
0 g
s
.787 .605 .653 r
.56635 .40488 m .56611 .40481 L .56239 .39137 L p F P
0 g
s
.784 .603 .655 r
.55787 .39008 m .56239 .39137 L .56611 .40481 L p F P
0 g
s
.793 .382 .27 r
.36094 .96093 m .34972 .95742 L .34367 .94842 L p F P
0 g
s
.796 .375 .25 r
.33264 .94483 m .34367 .94842 L .34972 .95742 L p F P
0 g
s
.819 .459 .374 r
.34367 .94842 m .33264 .94483 L .33258 .9447 L p F P
0 g
s
.996 .786 .505 r
.81201 .33484 m .81557 .34228 L .81696 .33269 L p F P
0 g
s
.996 .786 .505 r
.81696 .33269 m .81341 .32524 L .81201 .33484 L p F P
0 g
s
.61 .803 .383 r
.25685 .27718 m .25143 .28586 L .25405 .28161 L closepath p F P
0 g
s
0 0 0 r
.25685 .27718 m .25405 .28161 L p .26919 .26048 L F P
0 g
s
.72 .554 .664 r
.52558 .36139 m .52849 .37327 L .53689 .36194 L closepath p F P
0 g
s
.711 .541 .657 r
.52868 .37409 m .54807 .37576 L p .53689 .36194 L F P
0 g
s
.711 .541 .657 r
.53689 .36194 m .52849 .37327 L .52868 .37409 L p F P
0 g
s
.722 .634 .76 r
.54643 .25861 m .54755 .26118 L .55042 .25899 L closepath p F P
0 g
s
.699 .602 .744 r
.54755 .26118 m .54643 .25861 L .52865 .25782 L p F P
0 g
s
.472 .547 .852 r
.28673 .45473 m .29885 .45631 L p .28274 .44421 L F P
0 g
s
.472 .547 .852 r
.28274 .44421 m .28215 .44679 L .28673 .45473 L p F P
0 g
s
.411 .637 .949 r
.72356 .2233 m .73068 .22994 L .74913 .23173 L p F P
0 g
s
.403 .642 .953 r
.73068 .22994 m .74913 .23173 L .75385 .23791 L p F P
0 g
s
.663 .653 .829 r
.4247 .22085 m .42985 .22983 L .4491 .22347 L p F P
0 g
s
.523 .502 .774 r
.76001 .77757 m .76541 .79147 L .74297 .78776 L p F P
0 g
s
.523 .502 .774 r
.75623 .77688 m .76001 .77757 L p .74297 .78776 L F P
0 g
s
.523 .502 .774 r
.74297 .78776 m .74263 .78687 L .75623 .77688 L p F P
0 g
s
.538 .53 .794 r
.74263 .78687 m .73764 .77483 L .75623 .77688 L closepath p F P
0 g
s
.709 .628 .764 r
.55042 .25899 m .56839 .24504 L p .55504 .23916 L F P
0 g
s
.709 .628 .764 r
.54643 .25861 m .55042 .25899 L p .55504 .23916 L F P
0 g
s
.706 .618 .755 r
.51887 .25776 m .52112 .26316 L .52865 .25782 L closepath p F P
0 g
s
.146 .037 .462 r
.46032 .49349 m .46598 .48586 L .4653 .4769 L p F P
0 g
s
.962 .632 .263 r
.59182 .49892 m .59429 .50234 L .59279 .49347 L p F P
0 g
s
.962 .632 .263 r
.58913 .49378 m .59182 .49892 L p .59279 .49347 L F P
0 g
s
.962 .632 .263 r
.59279 .49347 m .58807 .48674 L .58913 .49378 L p F P
0 g
s
0 0 .365 r
.23987 .31465 m .23852 .31747 L .23896 .3257 L p F P
0 g
s
.886 .864 .813 r
.78363 .43393 m .78895 .42759 L .78445 .423 L p F P
0 g
s
.755 .958 .937 r
.31179 .22557 m .31866 .22765 L .29837 .23992 L p F P
0 g
s
.755 .958 .937 r
.30712 .22864 m .31179 .22557 L p .29837 .23992 L F P
0 g
s
.755 .958 .937 r
.29837 .23992 m .29572 .23955 L .30712 .22864 L p F P
0 g
s
.738 .872 .943 r
.29837 .23992 m .31866 .22765 L .32188 .2294 L p F P
0 g
s
.727 .873 .949 r
.33309 .22001 m .32188 .2294 L .31866 .22765 L closepath p F P
0 g
s
.497 .382 .653 r
.7657 .86097 m .76433 .85997 L .7654 .85942 L closepath p F P
0 g
s
.799 .834 .878 r
.73625 .47773 m .72655 .48499 L .72174 .47993 L p F P
0 g
s
.709 .628 .764 r
.55504 .23916 m .54195 .2483 L .54643 .25861 L p F P
0 g
s
.713 .629 .763 r
.54195 .2483 m .52865 .25782 L .54643 .25861 L closepath p F P
0 g
s
.795 .611 .652 r
.56994 .41841 m .57409 .41993 L p .56635 .40488 L F P
0 g
s
.808 .614 .64 r
.56994 .41841 m .57189 .42563 L .57409 .41993 L closepath p F P
0 g
s
.826 .636 .645 r
.57409 .41993 m .57189 .42563 L .57391 .4322 L p F P
0 g
s
.683 .515 .652 r
.51673 .38702 m .50564 .3878 L .50322 .37587 L p F P
0 g
s
.683 .515 .652 r
.50322 .37587 m .52774 .37414 L .51673 .38702 L p F P
0 g
s
.754 .76 .858 r
.40806 .71173 m .39759 .71845 L .39149 .7121 L p F P
0 g
s
.706 .745 .882 r
.4719 .69845 m .47126 .69772 L .47066 .698 L closepath p F P
0 g
s
.731 .551 .649 r
.52868 .37409 m .54807 .37576 L .54117 .38718 L p F P
0 g
s
.76 .59 .667 r
.55787 .39008 m .54117 .38718 L .54807 .37576 L p F P
0 g
s
.71 .771 .9 r
.62677 .51835 m .63422 .51504 L .6365 .5224 L p F P
0 g
s
.71 .775 .903 r
.6365 .5224 m .65319 .51441 L .64802 .5087 L p F P
0 g
s
.71 .775 .903 r
.64802 .5087 m .63422 .51504 L .6365 .5224 L p F P
0 g
s
.628 .468 .646 r
.48553 .40501 m .48684 .41236 L .50335 .40077 L closepath p F P
0 g
s
.467 .308 .581 r
.75249 .90334 m .76171 .89887 L .75822 .88904 L p F P
0 g
s
.463 .305 .582 r
.76967 .88331 m .75822 .88904 L .76171 .89887 L p F P
0 g
s
.485 .35 .622 r
.75822 .88904 m .76967 .88331 L .76784 .87167 L p F P
0 g
s
.648 .711 .893 r
.59824 .68931 m .59954 .69104 L .57945 .69835 L p F P
0 g
s
.648 .711 .893 r
.57945 .69835 m .57711 .69533 L .59824 .68931 L p F P
0 g
s
.165 .696 .852 r
.53502 .99117 m .52209 .99168 L .53877 .99168 L closepath p F P
0 g
s
.173 .701 .861 r
.52209 .99168 m .53502 .99117 L p .5085 .99115 L F P
0 g
s
.173 .701 .861 r
.5085 .99115 m .5118 .99163 L .52209 .99168 L p F P
0 g
s
.217 .732 .876 r
.53502 .99117 m .53877 .99168 L .54833 .99135 L p F P
0 g
s
.84 .741 .755 r
.29401 .81564 m .29348 .81506 L .29335 .81524 L closepath p F P
0 g
s
.101 .649 .825 r
.5085 .99115 m .49981 .99106 L .5118 .99163 L closepath p F P
0 g
s
.787 .601 .649 r
.56611 .40481 m .56621 .40519 L .56635 .40488 L closepath p F P
0 g
s
.795 .611 .652 r
.56635 .40488 m .56621 .40519 L .56994 .41841 L p F P
0 g
s
.784 .603 .655 r
.56611 .40481 m .5526 .40096 L .55787 .39008 L p F P
0 g
s
.786 .6 .649 r
.5526 .40096 m .56611 .40481 L .56621 .40519 L p F P
0 g
s
.655 .746 .916 r
.68501 .20636 m .66338 .21269 L .66852 .22033 L p F P
0 g
s
.655 .746 .916 r
.66852 .22033 m .69004 .21318 L .68501 .20636 L p F P
0 g
s
.786 .6 .649 r
.56621 .40519 m .56231 .41536 L p .5526 .40096 L F P
0 g
s
.816 .622 .641 r
.56621 .40519 m .56231 .41536 L .56994 .41841 L closepath p F P
0 g
s
.756 .567 .641 r
.54117 .38718 m .55787 .39008 L .5526 .40096 L p F P
0 g
s
.925 .974 .738 r
.44213 .52209 m .44189 .52102 L .45542 .50718 L p F P
0 g
s
.765 .812 .89 r
.44189 .52102 m .44213 .52209 L .4413 .52139 L closepath p F P
0 g
s
.478 .37 .652 r
.7654 .85942 m .78284 .84898 L p .77398 .86814 L F P
0 g
s
.478 .37 .652 r
.77398 .86814 m .7657 .86097 L .7654 .85942 L p F P
0 g
s
.488 .401 .683 r
.78273 .84851 m .78284 .84898 L .7654 .85942 L p F P
0 g
s
.488 .401 .683 r
.77076 .84136 m .78273 .84851 L p .7654 .85942 L F P
0 g
s
.886 .864 .813 r
.78445 .423 m .78174 .42627 L .78363 .43393 L p F P
0 g
s
.863 .854 .832 r
.76885 .43994 m .77067 .44759 L .78363 .43393 L p F P
0 g
s
.863 .854 .832 r
.78363 .43393 m .78174 .42627 L .76885 .43994 L p F P
0 g
s
.709 .752 .886 r
.44476 .70098 m .46101 .6934 L .47066 .698 L p F P
0 g
s
.708 .755 .889 r
.4654 .69144 m .46101 .6934 L .47066 .698 L p F P
0 g
s
.708 .755 .889 r
.47066 .698 m .47126 .69772 L .4654 .69144 L p F P
0 g
s
.597 .697 .913 r
.41421 .52104 m .41488 .52183 L .4143 .52194 L closepath p F P
0 g
s
.694 .61 .758 r
.52865 .25782 m .54195 .2483 L p .53362 .23782 L F P
0 g
s
.694 .61 .758 r
.51887 .25776 m .52865 .25782 L p .53362 .23782 L F P
0 g
s
.441 .256 .532 r
.76171 .89887 m .75249 .90334 L .75295 .91367 L p F P
0 g
s
.694 .61 .758 r
.53362 .23782 m .51548 .24957 L .51887 .25776 L p F P
0 g
s
.167 .702 .83 r
.56156 .99037 m .54833 .99135 L .56439 .99059 L closepath p F P
0 g
s
.217 .732 .876 r
.54833 .99135 m .56156 .99037 L p .53502 .99117 L F P
0 g
s
.686 .62 .777 r
.4855 .24084 m .48903 .24868 L .50682 .23855 L closepath p F P
0 g
s
.845 .75 .758 r
.29335 .81524 m .29348 .81506 L .28705 .80854 L p F P
0 g
s
.355 .018 .248 r
.73242 .94018 m .71269 .94731 L .71038 .95523 L p F P
0 g
s
.42 .146 .389 r
.73359 .93132 m .73242 .94018 L .71269 .94731 L p F P
0 g
s
.404 .067 .277 r
.71269 .94731 m .71038 .95523 L .68997 .96151 L p F P
0 g
s
.636 .781 .951 r
.49194 .69066 m .47126 .69772 L .4654 .69144 L p F P
0 g
s
.859 .743 .735 r
.2858 .81022 m .29335 .81524 L .28546 .82758 L p F P
0 g
s
.845 .75 .758 r
.28705 .80854 m .2858 .81022 L .29335 .81524 L p F P
0 g
s
.819 .843 .867 r
.73625 .47773 m .74754 .46844 L .74282 .46342 L p F P
0 g
s
.819 .843 .867 r
.74282 .46342 m .73487 .47002 L .73625 .47773 L p F P
0 g
s
.799 .834 .878 r
.72174 .47993 m .73487 .47002 L .73625 .47773 L p F P
0 g
s
.628 .782 .955 r
.4977 .6964 m .51849 .69092 L .52416 .69585 L p F P
0 g
s
.52 .805 .998 r
.4977 .6964 m .51849 .69092 L .51806 .69068 L p F P
0 g
s
.52 .805 .998 r
.49194 .69066 m .4977 .6964 L p .51806 .69068 L F P
0 g
s
.63 .71 .903 r
.41488 .52183 m .43531 .51568 L p .41831 .51211 L F P
0 g
s
.63 .71 .903 r
.41831 .51211 m .41421 .52104 L .41488 .52183 L p F P
0 g
s
.525 .372 .616 r
.47169 .44704 m .47308 .44733 L .4718 .44797 L closepath p F P
0 g
s
.675 .744 .903 r
.38602 .20436 m .36567 .21293 L .37195 .21962 L p F P
0 g
s
.675 .744 .903 r
.37195 .21962 m .39223 .21144 L .38602 .20436 L p F P
0 g
s
.593 .628 .855 r
.68448 .72101 m .66769 .72296 L .66241 .71373 L p F P
0 g
s
.701 .742 .883 r
.65822 .20523 m .63684 .21424 L .64211 .22259 L p F P
0 g
s
.701 .742 .883 r
.64211 .22259 m .66338 .21269 L .65822 .20523 L p F P
0 g
s
.723 .696 .824 r
.64211 .22259 m .63684 .21424 L .61572 .22611 L p F P
0 g
s
.989 .724 .386 r
.80942 .31787 m .81341 .32524 L .81344 .31616 L p F P
0 g
s
.989 .724 .386 r
.81344 .31616 m .80946 .30878 L .80942 .31787 L p F P
0 g
s
.476 .37 .654 r
.76784 .87167 m .7657 .86097 L .77398 .86814 L closepath p F P
0 g
s
.872 .716 .685 r
.27888 .83959 m .28681 .8444 L .28146 .85608 L p F P
0 g
s
.863 .726 .71 r
.28681 .8444 m .27888 .83959 L .28546 .82758 L p F P
0 g
s
0 .192 .706 r
.77249 .2504 m .77831 .25738 L .78585 .2635 L p F P
0 g
s
0 .213 .73 r
.79122 .27059 m .78585 .2635 L .77831 .25738 L p F P
0 g
s
.07 .628 .798 r
.49981 .99106 m .5085 .99115 L p .48202 .99018 L F P
0 g
s
.07 .628 .798 r
.48202 .99018 m .48327 .99033 L .49981 .99106 L p F P
0 g
s
.926 .859 .756 r
.80017 .39125 m .80598 .38174 L .80858 .38932 L p F P
0 g
s
.926 .859 .756 r
.80858 .38932 m .80458 .39579 L .80017 .39125 L p F P
0 g
s
.955 .681 .478 r
.58211 .47103 m .58824 .47736 L .58807 .48674 L p F P
0 g
s
.967 .841 .666 r
.8085 .36308 m .81158 .37059 L .81579 .35995 L p F P
0 g
s
.967 .841 .666 r
.81579 .35995 m .81273 .35242 L .8085 .36308 L p F P
0 g
s
.725 .659 .784 r
.56634 .24083 m .56839 .24504 L .57293 .24184 L closepath p F P
0 g
s
.709 .628 .764 r
.56839 .24504 m .56634 .24083 L .55504 .23916 L p F P
0 g
s
.516 .355 .601 r
.47308 .44733 m .4718 .44797 L .47286 .45853 L p F P
0 g
s
.573 .718 .941 r
.70587 .21113 m .69004 .21318 L .69505 .2202 L p F P
0 g
s
.573 .718 .941 r
.69505 .2202 m .71541 .21698 L .70587 .21113 L p F P
0 g
s
.812 .768 .812 r
.33405 .7561 m .3294 .76053 L .32304 .75448 L p F P
0 g
s
.812 .768 .812 r
.32304 .75448 m .3269 .75079 L .33405 .7561 L p F P
0 g
s
.798 .77 .827 r
.34389 .73614 m .3269 .75079 L .33405 .7561 L p F P
0 g
s
.798 .77 .827 r
.33405 .7561 m .35017 .74222 L .34389 .73614 L p F P
0 g
s
.568 .579 .824 r
.70032 .7414 m .70162 .74042 L p .72562 .75091 L F P
0 g
s
.575 .599 .839 r
.70032 .7414 m .69986 .74051 L .70162 .74042 L closepath p F P
0 g
s
.631 .778 .951 r
.52416 .69585 m .54505 .69031 L .55062 .69537 L p F P
0 g
s
.493 .823 .999 r
.51849 .69092 m .52416 .69585 L p .54445 .69 L F P
0 g
s
.493 .823 .999 r
.51985 .6907 m .51849 .69092 L p .52433 .69071 L F P
0 g
s
.493 .823 .999 r
.54445 .69 m .51985 .6907 L p .52433 .69071 L F P
0 g
s
.611 .211 .26 r
.52404 .6913 m .5182 .69069 L .51985 .6907 L F
.518 .813 .999 r
.51985 .6907 m .51806 .69068 L .51849 .69092 L closepath p F P
0 g
s
.611 .211 .26 r
.51806 .69068 m .51985 .6907 L p .5182 .69069 L F P
0 g
s
.493 .823 .999 r
.52416 .69585 m .54295 .69087 L p .54132 .6909 L F P
0 g
s
.611 .211 .26 r
.53802 .69329 m .52296 .69132 L .52404 .6913 L F
.52296 .69132 m .51806 .69068 L .52404 .6913 L F
.493 .823 .999 r
.54505 .69031 m .54445 .69 L p .54132 .6909 L F P
0 g
s
.493 .823 .999 r
.54295 .69087 m .54505 .69031 L p .54132 .6909 L F P
0 g
s
.324 0 .123 r
.68852 .9644 m .68997 .96151 L .71038 .95523 L p F P
0 g
s
.743 .704 .814 r
.61572 .22611 m .61472 .22681 L .61659 .22763 L closepath p F P
0 g
s
.82 .841 .865 r
.75505 .46214 m .74754 .46844 L .74282 .46342 L p F P
0 g
s
.813 .769 .811 r
.31904 .77048 m .3294 .76053 L .32304 .75448 L p F P
0 g
s
.693 .802 .933 r
.35926 .20742 m .33893 .217 L .34544 .22188 L p F P
0 g
s
.693 .802 .933 r
.34544 .22188 m .36567 .21293 L .35926 .20742 L p F P
0 g
s
.817 .619 .635 r
.56231 .41536 m .56994 .41841 L .57189 .42563 L p F P
0 g
s
.756 .808 .894 r
.68344 .50576 m .67945 .50814 L .6744 .50267 L p F P
0 g
s
.743 .805 .902 r
.65319 .51441 m .6744 .50267 L .67945 .50814 L p F P
0 g
s
.713 .784 .907 r
.4413 .52139 m .44189 .52102 L .44162 .51268 L p F P
0 g
s
.713 .784 .907 r
.44162 .51268 m .43531 .51568 L .4413 .52139 L p F P
0 g
s
.095 .05 .511 r
.2406 .33487 m .23611 .34496 L p .23896 .3257 L F P
0 g
s
.168 .152 .595 r
.2406 .33487 m .23611 .34496 L .24026 .35185 L p F P
0 g
s
.499 .629 .91 r
.60007 .51267 m .61489 .5132 L .61641 .52086 L p F P
0 g
s
.381 .585 .923 r
.61489 .5132 m .60007 .51267 L .59461 .50295 L p F P
0 g
s
.623 .7 .901 r
.40885 .51444 m .41831 .51211 L .41421 .52104 L closepath p F P
0 g
s
.866 .601 .534 r
.30812 .91725 m .29865 .91312 L .29885 .90268 L p F P
0 g
s
.875 .609 .532 r
.28975 .8984 m .29885 .90268 L .29865 .91312 L p F P
0 g
s
.871 .638 .583 r
.29885 .90268 m .28975 .8984 L .29138 .88763 L p F P
0 g
s
.692 .53 .662 r
.52849 .37327 m .52774 .37414 L .52868 .37409 L closepath p F P
0 g
s
.672 .638 .808 r
.45116 .22275 m .45692 .23384 L .47757 .22424 L p F P
0 g
s
.657 .629 .81 r
.45692 .23384 m .45116 .22275 L .4491 .22347 L p F P
0 g
s
.84 .847 .85 r
.76377 .44475 m .76885 .43994 L .77067 .44759 L p F P
0 g
s
.84 .847 .85 r
.77067 .44759 m .76839 .44973 L .76377 .44475 L p F P
0 g
s
.841 .85 .851 r
.75505 .46214 m .76839 .44973 L .76377 .44475 L p F P
0 g
s
.316 .191 .547 r
.4653 .4769 m .47358 .46874 L .47286 .45853 L p F P
0 g
s
.265 .118 .487 r
.47358 .46874 m .4653 .4769 L .46598 .48586 L p F P
0 g
s
.692 .527 .659 r
.53141 .38636 m .51673 .38702 L .52774 .37414 L p F P
0 g
s
.692 .527 .659 r
.52774 .37414 m .52868 .37409 L .53141 .38636 L p F P
0 g
s
.826 .766 .796 r
.31904 .77048 m .30843 .78182 L .302 .77581 L p F P
0 g
s
.826 .766 .796 r
.302 .77581 m .3119 .76521 L .31904 .77048 L p F P
0 g
s
.813 .769 .811 r
.32304 .75448 m .3119 .76521 L .31904 .77048 L p F P
0 g
s
.731 .551 .649 r
.54117 .38718 m .53141 .38636 L .52868 .37409 L p F P
0 g
s
.575 .601 .842 r
.70162 .74042 m .69986 .74051 L .69461 .73053 L p F P
0 g
s
.754 .76 .858 r
.39149 .7121 m .40003 .70662 L .40806 .71173 L p F P
0 g
s
.744 .761 .867 r
.41214 .6994 m .40003 .70662 L .40806 .71173 L p F P
0 g
s
.744 .761 .867 r
.40806 .71173 m .41819 .70571 L .41214 .6994 L p F P
0 g
s
.858 .555 .474 r
.31934 .9313 m .30952 .92731 L .30812 .91725 L p F P
0 g
s
.867 .561 .468 r
.29865 .91312 m .30812 .91725 L .30952 .92731 L p F P
0 g
s
.841 .85 .851 r
.76377 .44475 m .7534 .45447 L .75505 .46214 L p F P
0 g
s
.82 .841 .865 r
.74282 .46342 m .7534 .45447 L .75505 .46214 L p F P
0 g
s
.624 .735 .927 r
.62147 .51201 m .61489 .5132 L .61641 .52086 L p F P
0 g
s
.624 .735 .927 r
.61641 .52086 m .62677 .51835 L .62147 .51201 L p F P
0 g
s
.506 .594 .877 r
.31678 .47441 m .31838 .47684 L .31642 .4768 L closepath p F P
0 g
s
.703 .758 .895 r
.46101 .6934 m .44476 .70098 L .43882 .69447 L p F P
0 g
s
.73 .753 .871 r
.41819 .70571 m .43882 .69447 L .44476 .70098 L p F P
0 g
s
.21 .732 .85 r
.56156 .99037 m .56439 .99059 L .582 .98924 L p F P
0 g
s
.29 0 0 r
.39691 .97603 m .39807 .9759 L p .4187 .98205 L F P
0 g
s
.611 .066 0 r
.39691 .97603 m .39572 .97534 L .39807 .9759 L closepath p F P
0 g
s
.613 .659 .871 r
.65588 .70476 m .63566 .70842 L .63032 .70004 L p F P
0 g
s
.725 .658 .783 r
.57293 .24184 m .58931 .23009 L p .56284 .23364 L F P
0 g
s
.725 .658 .783 r
.56284 .23364 m .56634 .24083 L .57293 .24184 L p F P
0 g
s
.796 .769 .829 r
.35171 .74093 m .35017 .74222 L .34389 .73614 L p F P
0 g
s
.667 .705 .876 r
.41267 .20323 m .39223 .21144 L .39833 .21957 L p F P
0 g
s
.667 .705 .876 r
.39833 .21957 m .41872 .21154 L .41267 .20323 L p F P
0 g
s
0 0 0 r
.25405 .28161 m .25143 .28586 L .24724 .29584 L p F P
0 g
s
.515 .359 .608 r
.49045 .43839 m .47308 .44733 L .48664 .45172 L p F P
0 g
s
.516 .355 .601 r
.47286 .45853 m .48664 .45172 L .47308 .44733 L p F P
0 g
s
.796 .769 .829 r
.34389 .73614 m .34453 .7356 L .35171 .74093 L p F P
0 g
s
.783 .77 .842 r
.36463 .72014 m .34453 .7356 L .35171 .74093 L p F P
0 g
s
.783 .77 .842 r
.35171 .74093 m .37085 .72625 L .36463 .72014 L p F P
0 g
s
.651 .743 .916 r
.55062 .69537 m .57163 .68914 L .57711 .69533 L p F P
0 g
s
.624 .805 .969 r
.55062 .69537 m .57163 .68914 L .56729 .68557 L p F P
0 g
s
.624 .805 .969 r
.54505 .69031 m .55062 .69537 L p .56729 .68557 L F P
0 g
s
.538 .53 .794 r
.75623 .77688 m .73764 .77483 L .73533 .76928 L p F P
0 g
s
.253 0 0 r
.4556 .98775 m .46193 .98816 L .47943 .98997 L p F P
0 g
s
.02 .588 .781 r
.46193 .98816 m .45247 .98729 L .4556 .98775 L closepath p F P
0 g
s
.88 .647 .582 r
.28382 .88377 m .29138 .88763 L .28975 .8984 L p F P
0 g
s
.873 .67 .625 r
.28305 .88179 m .28561 .87209 L p .29138 .88763 L F P
0 g
s
.873 .67 .625 r
.29138 .88763 m .28382 .88377 L .28305 .88179 L p F P
0 g
s
.954 .623 .219 r
.80504 .30149 m .80946 .30878 L .80807 .30026 L p F P
0 g
s
.954 .623 .219 r
.80807 .30026 m .80365 .29296 L .80504 .30149 L p F P
0 g
s
.618 .45 .632 r
.50335 .40077 m .48684 .41236 L .48746 .41643 L p F P
0 g
s
.74 .697 .81 r
.61572 .22611 m .61472 .22681 L .60224 .22205 L p F P
0 g
s
.817 .619 .635 r
.57189 .42563 m .57048 .4303 L p .56231 .41536 L F P
0 g
s
.854 .649 .625 r
.57189 .42563 m .57048 .4303 L .57391 .4322 L closepath p F P
0 g
s
0 .55 .738 r
.48202 .99018 m .47943 .98997 L .48327 .99033 L closepath p F P
0 g
s
.77 .817 .889 r
.68344 .50576 m .70059 .49471 L .69563 .48931 L p F P
0 g
s
.77 .817 .889 r
.69563 .48931 m .68203 .49809 L .68344 .50576 L p F P
0 g
s
.756 .808 .894 r
.6744 .50267 m .68203 .49809 L .68344 .50576 L p F P
0 g
s
.73 .24 .076 r
.36094 .96093 m .36455 .96465 L .35802 .96519 L p F P
0 g
s
.73 .24 .076 r
.35802 .96519 m .34972 .95742 L .36094 .96093 L p F P
0 g
s
.702 .627 .77 r
.51038 .23815 m .51548 .24957 L .53362 .23782 L closepath p F P
0 g
s
.678 .601 .762 r
.51548 .24957 m .51038 .23815 L .50682 .23855 L p F P
0 g
s
.724 .729 .855 r
.63155 .20606 m .61034 .21693 L .61572 .22611 L p F P
0 g
s
.724 .729 .855 r
.61572 .22611 m .63684 .21424 L .63155 .20606 L p F P
0 g
s
.74 .697 .81 r
.60224 .22205 m .61034 .21693 L .61572 .22611 L p F P
0 g
s
.856 .645 .616 r
.57048 .4303 m .57391 .4322 L .57756 .44482 L p F P
0 g
s
.778 .987 .895 r
.27498 .25595 m .28329 .24653 L p .29572 .23955 L F P
0 g
s
.672 .944 .681 r
.28329 .24653 m .27498 .25595 L .27029 .25921 L closepath p F P
0 g
s
.739 .966 .693 r
.26919 .26048 m .27029 .25921 L .27498 .25595 L p F P
0 g
s
0 0 .21 r
.23987 .31465 m .24556 .30488 L .24724 .29584 L p F P
0 g
s
.032 0 .407 r
.24556 .30488 m .23987 .31465 L .2397 .32417 L p F P
0 g
s
0 0 .365 r
.23896 .3257 m .2397 .32417 L .23987 .31465 L p F P
0 g
s
.715 .641 .773 r
.53716 .23787 m .54195 .2483 L .55504 .23916 L closepath p F P
0 g
s
.694 .61 .758 r
.54195 .2483 m .53716 .23787 L .53362 .23782 L p F P
0 g
s
0 0 .447 r
.79156 .27102 m .79122 .27059 L .78585 .2635 L p F P
0 g
s
.435 .509 .836 r
.28055 .44377 m .28274 .44421 L .28215 .44679 L closepath p F P
0 g
s
.874 .665 .617 r
.58321 .46139 m .58313 .46135 L .57808 .44623 L p F P
0 g
s
.878 .65 .588 r
.58313 .46135 m .58318 .46153 L .58321 .46139 L closepath p F P
0 g
s
.568 .579 .824 r
.70162 .74042 m .72181 .7402 L p .72562 .75091 L F P
0 g
s
.56 .578 .828 r
.70162 .74042 m .72181 .7402 L .71655 .72957 L p F P
0 g
s
.56 .578 .828 r
.71655 .72957 m .71525 .72957 L .70162 .74042 L p F P
0 g
s
.575 .601 .842 r
.69461 .73053 m .71525 .72957 L .70162 .74042 L p F P
0 g
s
.901 .676 .588 r
.58313 .46135 m .57551 .45553 L .57736 .44568 L p F P
0 g
s
.901 .676 .588 r
.57736 .44568 m .57808 .44623 L .58313 .46135 L p F P
0 g
s
.909 .664 .557 r
.57551 .45553 m .58313 .46135 L .58318 .46153 L p F P
0 g
s
.391 .122 .381 r
.7527 .92333 m .73359 .93132 L .73242 .94018 L p F P
0 g
s
.44 .214 .474 r
.75295 .91367 m .7527 .92333 L .73359 .93132 L p F P
0 g
s
.909 .664 .557 r
.58318 .46153 m .58211 .47103 L p .57551 .45553 L F P
0 g
s
.844 .497 .396 r
.33248 .94478 m .32249 .94097 L .31934 .9313 L p F P
0 g
s
.852 .499 .385 r
.30952 .92731 m .31934 .9313 L .32249 .94097 L p F P
0 g
s
.539 0 0 r
.39572 .97534 m .39691 .97603 L .39059 .97579 L p F P
0 g
s
.539 0 0 r
.39059 .97579 m .38333 .97219 L .39572 .97534 L p F P
0 g
s
.858 .46 0 r
.79588 .27782 m .80072 .28504 L .80365 .29296 L p F P
0 g
s
.826 .767 .796 r
.30617 .78423 m .30843 .78182 L .302 .77581 L p F P
0 g
s
.683 .513 .65 r
.50564 .3878 m .50764 .39784 L .51673 .38702 L closepath p F P
0 g
s
.194 .697 .908 r
.47943 .98997 m .48202 .99018 L .47614 .98838 L p F P
0 g
s
.194 .697 .908 r
.47614 .98838 m .46193 .98816 L .47943 .98997 L p F P
0 g
s
.652 .735 .91 r
.59824 .68931 m .57711 .69533 L .57163 .68914 L p F P
0 g
s
.686 .619 .775 r
.48332 .23598 m .4855 .24084 L .50682 .23855 L p F P
0 g
s
.724 .658 .783 r
.56284 .23364 m .55504 .23916 L .56634 .24083 L closepath p F P
0 g
s
.928 .86 .752 r
.80136 .40103 m .80458 .39579 L .80017 .39125 L p F P
0 g
s
.84 .763 .778 r
.29902 .77899 m .30617 .78423 L .29523 .79744 L p F P
0 g
s
.826 .767 .796 r
.302 .77581 m .29902 .77899 L .30617 .78423 L p F P
0 g
s
0 0 .447 r
.78585 .2635 m .787 .26498 L .79156 .27102 L p F P
0 g
s
.669 .221 0 r
.79059 .2707 m .787 .26498 L .79156 .27102 L p F P
0 g
s
.669 .221 0 r
.79156 .27102 m .79588 .27782 L .79059 .2707 L p F P
0 g
s
.372 .432 .793 r
.25926 .41694 m .26231 .40668 L p .2511 .40199 L F P
0 g
s
.406 .464 .807 r
.26231 .40668 m .26828 .41958 L .25926 .41694 L closepath p F P
0 g
s
.405 .465 .809 r
.2711 .42561 m .26971 .43104 L p .25926 .41694 L F P
0 g
s
.405 .465 .809 r
.25926 .41694 m .26828 .41958 L .2711 .42561 L p F P
0 g
s
.526 .604 .874 r
.31838 .47684 m .33803 .47664 L p .31852 .46719 L F P
0 g
s
.526 .604 .874 r
.31852 .46719 m .31678 .47441 L .31838 .47684 L p F P
0 g
s
.897 .682 .605 r
.57756 .44482 m .57736 .44568 L .57808 .44623 L closepath p F P
0 g
s
.856 .645 .616 r
.57756 .44482 m .57736 .44568 L p .57048 .4303 L F P
0 g
s
.338 .383 .762 r
.2511 .40199 m .25469 .39127 L .2452 .38618 L p F P
0 g
s
.392 .43 .781 r
.26221 .40643 m .2511 .40199 L .25469 .39127 L p F P
0 g
s
.372 .432 .793 r
.26231 .40668 m .26221 .40643 L .2511 .40199 L p F P
0 g
s
.538 .53 .794 r
.73533 .76928 m .74299 .7633 L p .75623 .77688 L F P
0 g
s
.546 .552 .812 r
.73533 .76928 m .73234 .76263 L .74299 .7633 L closepath p F P
0 g
s
.882 .677 .62 r
.28561 .87209 m .28305 .88179 L .27709 .86821 L p F P
0 g
s
.882 .677 .62 r
.27709 .86821 m .27728 .86748 L .28561 .87209 L p F P
0 g
s
.874 .694 .656 r
.28561 .87209 m .27728 .86748 L .28146 .85608 L p F P
0 g
s
.73 .55 .648 r
.53141 .38636 m .54117 .38718 L .53434 .3986 L p F P
0 g
s
.756 .567 .641 r
.5526 .40096 m .53434 .3986 L .54117 .38718 L p F P
0 g
s
.221 .53 .921 r
.74923 .23176 m .74913 .23173 L .75385 .23791 L p F P
0 g
s
.221 .53 .921 r
.75385 .23791 m .75587 .23855 L .74923 .23176 L p F P
0 g
s
0 0 0 r
.66237 .97549 m .64096 .97995 L .63592 .98179 L p F P
0 g
s
.017 0 0 r
.61457 .98542 m .63592 .98179 L .64096 .97995 L p F P
0 g
s
.208 0 0 r
.66481 .97349 m .66237 .97549 L .64096 .97995 L p F P
0 g
s
.583 .667 .896 r
.3967 .49856 m .37648 .50169 L .3826 .50978 L p F P
0 g
s
.583 .667 .896 r
.3826 .50978 m .40279 .50667 L .3967 .49856 L p F P
0 g
s
.562 .657 .9 r
.36976 .50243 m .37648 .50169 L .3826 .50978 L p F P
0 g
s
.44 .504 .828 r
.28574 .43401 m .2744 .43201 L .28055 .44377 L p F P
0 g
s
.44 .504 .828 r
.28055 .44377 m .28274 .44421 L .28574 .43401 L p F P
0 g
s
.432 .504 .833 r
.26971 .43104 m .2744 .43201 L .28055 .44377 L p F P
0 g
s
.618 .45 .632 r
.48746 .41643 m .50986 .41101 L p .50335 .40077 L F P
0 g
s
.624 .45 .626 r
.51167 .4223 m .50986 .41101 L .48746 .41643 L p F P
0 g
s
.624 .45 .626 r
.48746 .41643 m .48903 .42747 L .51167 .4223 L p F P
0 g
s
.671 .495 .639 r
.53408 .39858 m .53141 .38636 L .51673 .38702 L p F P
0 g
s
.671 .495 .639 r
.50795 .39963 m .53408 .39858 L p .51673 .38702 L F P
0 g
s
.671 .495 .639 r
.51673 .38702 m .50764 .39784 L .50795 .39963 L p F P
0 g
s
.433 .502 .83 r
.2711 .42561 m .2744 .43201 L .26971 .43104 L closepath p F P
0 g
s
.856 .645 .616 r
.57736 .44568 m .56779 .4404 L .57048 .4303 L p F P
0 g
s
.862 .632 .588 r
.56779 .4404 m .57736 .44568 L .57551 .45553 L p F P
0 g
s
.29 0 0 r
.4187 .98205 m .41503 .98123 L .39691 .97603 L p F P
0 g
s
.355 0 0 r
.41503 .98123 m .39691 .97603 L .39059 .97579 L p F P
0 g
s
.777 .769 .846 r
.37301 .72465 m .37085 .72625 L .36463 .72014 L p F P
0 g
s
.731 .76 .876 r
.43882 .69447 m .41819 .70571 L .41214 .6994 L p F P
0 g
s
.668 .681 .853 r
.43929 .2032 m .41872 .21154 L .4247 .22085 L p F P
0 g
s
.668 .681 .853 r
.4247 .22085 m .44523 .21244 L .43929 .2032 L p F P
0 g
s
.663 .653 .829 r
.4511 .22264 m .44523 .21244 L .4247 .22085 L p F P
0 g
s
.663 .653 .829 r
.4491 .22347 m .4511 .22264 L p .4247 .22085 L F P
0 g
s
.456 .33 .619 r
.77398 .86814 m .76784 .87167 L .76967 .88331 L p F P
0 g
s
.87 .736 .712 r
.2779 .82259 m .28546 .82758 L .27888 .83959 L p F P
0 g
s
.859 .743 .735 r
.28546 .82758 m .2779 .82259 L .2858 .81022 L p F P
0 g
s
.112 .665 .752 r
.58808 .98863 m .582 .98924 L .58901 .98859 L closepath p F P
0 g
s
.21 .732 .85 r
.582 .98924 m .58808 .98863 L p .56156 .99037 L F P
0 g
s
.777 .769 .846 r
.36463 .72014 m .36576 .7193 L .37301 .72465 L p F P
0 g
s
.765 .77 .856 r
.38533 .70598 m .36576 .7193 L .37301 .72465 L p F P
0 g
s
.765 .77 .856 r
.37301 .72465 m .39149 .7121 L .38533 .70598 L p F P
0 g
s
.744 .985 .903 r
.30712 .22864 m .29572 .23955 L .29124 .23989 L closepath p F P
0 g
s
.778 .987 .895 r
.28329 .24653 m .29124 .23989 L .29572 .23955 L p F P
0 g
s
.706 .675 .818 r
.58931 .23009 m .60224 .22205 L .58641 .21855 L p F P
0 g
s
.706 .675 .818 r
.58641 .21855 m .58382 .22 L .58931 .23009 L p F P
0 g
s
.725 .658 .783 r
.58931 .23009 m .58382 .22 L .56284 .23364 L p F P
0 g
s
.69 .651 .806 r
.49837 .21394 m .47757 .22424 L .48332 .23598 L p F P
0 g
s
.69 .651 .806 r
.48332 .23598 m .50411 .22499 L .49837 .21394 L p F P
0 g
s
.686 .619 .775 r
.5098 .23684 m .50411 .22499 L .48332 .23598 L p F P
0 g
s
.686 .619 .775 r
.50682 .23855 m .5098 .23684 L p .48332 .23598 L F P
0 g
s
.549 .628 .882 r
.36418 .48427 m .34422 .48595 L .3504 .49477 L p F P
0 g
s
.549 .628 .882 r
.3504 .49477 m .37034 .49329 L .36418 .48427 L p F P
0 g
s
.536 .626 .888 r
.34047 .48614 m .34422 .48595 L .3504 .49477 L p F P
0 g
s
.981 .816 .605 r
.81022 .3413 m .81201 .33484 L .81557 .34228 L p F P
0 g
s
.981 .816 .605 r
.81557 .34228 m .81457 .34584 L .81022 .3413 L p F P
0 g
s
.07 .628 .798 r
.5085 .99115 m .50275 .98901 L .48202 .99018 L p F P
0 g
s
.512 .799 .997 r
.50275 .98901 m .48202 .99018 L .47614 .98838 L p F P
0 g
s
.73 .55 .648 r
.53434 .3986 m .53408 .39858 L .53141 .38636 L p F P
0 g
s
.827 .462 .364 r
.33264 .94483 m .33248 .94478 L .33258 .9447 L closepath p F P
0 g
s
.928 .86 .752 r
.80017 .39125 m .79882 .39345 L .80136 .40103 L p F P
0 g
s
.903 .853 .784 r
.78995 .40577 m .79248 .41332 L .80136 .40103 L p F P
0 g
s
.903 .853 .784 r
.80136 .40103 m .79882 .39345 L .78995 .40577 L p F P
0 g
s
.721 .535 .638 r
.54753 .4118 m .5526 .40096 L .53434 .3986 L p F P
0 g
s
.786 .6 .649 r
.56231 .41536 m .54753 .4118 L .5526 .40096 L p F P
0 g
s
.796 .375 .25 r
.34972 .95742 m .33878 .9538 L .33264 .94483 L p F P
0 g
s
.789 .346 .196 r
.33248 .94478 m .33264 .94483 L .33878 .9538 L p F P
0 g
s
.5 .578 .865 r
.31218 .46694 m .31852 .46719 L .31678 .47441 L closepath p F P
0 g
s
.817 .619 .635 r
.57048 .4303 m .55858 .42577 L .56231 .41536 L p F P
0 g
s
.818 .601 .609 r
.55858 .42577 m .57048 .4303 L .56779 .4404 L p F P
0 g
s
.298 .328 .724 r
.2452 .38618 m .24934 .37514 L .24157 .36948 L p F P
0 g
s
.362 .385 .751 r
.25469 .39127 m .2452 .38618 L .24934 .37514 L p F P
0 g
s
.716 .64 .771 r
.55504 .23916 m .56284 .23364 L p .53633 .23605 L F P
0 g
s
.716 .64 .771 r
.53633 .23605 m .53716 .23787 L .55504 .23916 L p F P
0 g
s
.789 .346 .196 r
.32578 .94703 m .33248 .94478 L p .33878 .9538 L F P
0 g
s
.825 .424 .288 r
.32578 .94703 m .32249 .94097 L .33248 .94478 L closepath p F P
0 g
s
.724 .89 .956 r
.31866 .22765 m .31179 .22557 L p .33779 .21636 L F P
0 g
s
.724 .89 .956 r
.33779 .21636 m .33309 .22001 L .31866 .22765 L p F P
0 g
s
.466 .667 .95 r
.72183 .22327 m .72356 .2233 L .7187 .2191 L closepath p F P
0 g
s
.741 .797 .897 r
.6744 .50267 m .65319 .51441 L .64802 .5087 L p F P
0 g
s
.625 .464 .644 r
.50764 .39784 m .50335 .40077 L .50795 .39963 L closepath p F P
0 g
s
.618 .45 .632 r
.50986 .41101 m .50795 .39963 L .50335 .40077 L p F P
0 g
s
.63 .673 .873 r
.60366 .6968 m .62495 .69188 L .63032 .70004 L p F P
0 g
s
.634 .692 .886 r
.61957 .68402 m .62495 .69188 L .60366 .6968 L p F P
0 g
s
.634 .692 .886 r
.60691 .6871 m .61957 .68402 L p .60366 .6968 L F P
0 g
s
.634 .692 .886 r
.60366 .6968 m .59954 .69104 L .60691 .6871 L p F P
0 g
s
.778 .573 .622 r
.54753 .4118 m .56231 .41536 L .55858 .42577 L p F P
0 g
s
.852 .759 .759 r
.29523 .79744 m .28705 .80854 L .28053 .80245 L p F P
0 g
s
.852 .759 .759 r
.28053 .80245 m .28805 .79223 L .29523 .79744 L p F P
0 g
s
.84 .763 .778 r
.29523 .79744 m .28805 .79223 L .29902 .77899 L p F P
0 g
s
.169 .707 .781 r
.58808 .98863 m .58901 .98859 L .61251 .98554 L p F P
0 g
s
0 0 0 r
.61457 .98542 m .61251 .98554 L .58901 .98859 L p F P
0 g
s
.685 .618 .775 r
.5098 .23684 m .50682 .23855 L .51038 .23815 L closepath p F P
0 g
s
.041 .419 .865 r
.74923 .23176 m .75587 .23855 L .76619 .24354 L p F P
0 g
s
.077 .431 .872 r
.77249 .2504 m .76619 .24354 L .75587 .23855 L p F P
0 g
s
.777 .817 .884 r
.71221 .4869 m .70059 .49471 L .69563 .48931 L p F P
0 g
s
.88 .705 .66 r
.2735 .8513 m .28146 .85608 L .27728 .86748 L p F P
0 g
s
.872 .716 .685 r
.28146 .85608 m .2735 .8513 L .27888 .83959 L p F P
0 g
s
.485 .402 .687 r
.78273 .84851 m .77076 .84136 L .7796 .83585 L closepath p F P
0 g
s
.505 .432 .707 r
.77665 .82543 m .7796 .83585 L .77076 .84136 L p F P
0 g
s
.505 .432 .707 r
.77296 .82377 m .77665 .82543 L p .77076 .84136 L F P
0 g
s
.482 .541 .841 r
.29975 .44609 m .28274 .44421 L .28574 .43401 L p F P
0 g
s
.472 .547 .852 r
.30097 .44829 m .29975 .44609 L .28274 .44421 L p F P
0 g
s
.472 .547 .852 r
.29885 .45631 m .30097 .44829 L p .28274 .44421 L F P
0 g
s
.545 .553 .813 r
.74299 .7633 m .73234 .76263 L .72705 .75094 L p F P
0 g
s
.944 .844 .713 r
.8029 .37425 m .80598 .38174 L .81158 .37059 L p F P
0 g
s
.944 .844 .713 r
.81158 .37059 m .8085 .36308 L .8029 .37425 L p F P
0 g
s
.657 .63 .811 r
.4511 .22264 m .4491 .22347 L .45116 .22275 L closepath p F P
0 g
s
.702 .626 .769 r
.5098 .23684 m .51038 .23815 L .53362 .23782 L p F P
0 g
s
.133 0 0 r
.66237 .97549 m .66481 .97349 L .6859 .96797 L p F P
0 g
s
.269 0 0 r
.68852 .9644 m .6859 .96797 L .66481 .97349 L p F P
0 g
s
.379 .622 .948 r
.7415 .22531 m .72356 .2233 L .7187 .2191 L p F P
0 g
s
.411 .637 .949 r
.74895 .2315 m .7415 .22531 L .72356 .2233 L p F P
0 g
s
.411 .637 .949 r
.74913 .23173 m .74895 .2315 L p .72356 .2233 L F P
0 g
s
.138 .667 .87 r
.46193 .98816 m .47614 .98838 L p .44959 .98665 L F P
0 g
s
.138 .667 .87 r
.44959 .98665 m .45247 .98729 L .46193 .98816 L p F P
0 g
s
.173 .701 .861 r
.53502 .99117 m .52938 .98897 L .5085 .99115 L p F P
0 g
s
.553 .806 .992 r
.52938 .98897 m .5085 .99115 L .50275 .98901 L p F P
0 g
s
.705 .659 .802 r
.56284 .23364 m .58382 .22 L p .57005 .21521 L F P
0 g
s
.705 .659 .802 r
.57005 .21521 m .55726 .22273 L .56284 .23364 L p F P
0 g
s
.716 .64 .771 r
.56284 .23364 m .55726 .22273 L .53633 .23605 L p F P
0 g
s
.199 .728 .788 r
.61251 .98554 m .61457 .98542 L .63592 .98179 L p F P
0 g
s
.505 .331 .579 r
.48664 .45172 m .47286 .45853 L .47358 .46874 L p F P
0 g
s
.706 .635 .775 r
.53633 .23605 m .53362 .23782 L .53716 .23787 L closepath p F P
0 g
s
.702 .626 .769 r
.53362 .23782 m .53633 .23605 L p .5098 .23684 L F P
0 g
s
.691 .505 .631 r
.53415 .39893 m .53408 .39858 L .50795 .39963 L p F P
0 g
s
.691 .505 .631 r
.52667 .41036 m .53415 .39893 L p .50795 .39963 L F P
0 g
s
.691 .505 .631 r
.50795 .39963 m .50986 .41101 L .52667 .41036 L p F P
0 g
s
.706 .661 .803 r
.52501 .21361 m .50411 .22499 L .5098 .23684 L p F P
0 g
s
.706 .661 .803 r
.5098 .23684 m .53068 .22449 L .52501 .21361 L p F P
0 g
s
.702 .626 .769 r
.53633 .23605 m .53068 .22449 L .5098 .23684 L p F P
0 g
s
.982 .815 .601 r
.81273 .35242 m .81457 .34584 L .81022 .3413 L p F P
0 g
s
.593 .628 .855 r
.66241 .71373 m .68409 .71127 L p .68448 .72101 L F P
0 g
s
.588 .632 .862 r
.68409 .71127 m .66241 .71373 L .6571 .70457 L p F P
0 g
s
.563 .651 .894 r
.37111 .49439 m .37648 .50169 L .36976 .50243 L closepath p F P
0 g
s
.752 .32 0 r
.59429 .50234 m .59182 .49892 L .59461 .50295 L closepath p F P
0 g
s
0 0 0 r
.25405 .28161 m .26118 .272 L .26919 .26048 L p F P
0 g
s
0 0 .016 r
.26118 .272 m .25405 .28161 L .2517 .28864 L p F P
0 g
s
0 0 0 r
.24724 .29584 m .2517 .28864 L .25405 .28161 L p F P
0 g
s
.668 .635 .808 r
.4511 .22264 m .45116 .22275 L .47367 .21698 L p F P
0 g
s
.672 .638 .808 r
.47757 .22424 m .47367 .21698 L .45116 .22275 L p F P
0 g
s
.703 .763 .899 r
.63422 .51504 m .62677 .51835 L .62147 .51201 L p F P
0 g
s
.089 .046 .51 r
.2397 .32417 m .24014 .32927 L .23896 .3257 L closepath p F P
0 g
s
.095 .05 .511 r
.23896 .3257 m .24014 .32927 L .2406 .33487 L p F P
0 g
s
.676 .67 .836 r
.46593 .20356 m .44523 .21244 L .4511 .22264 L p F P
0 g
s
.676 .67 .836 r
.4511 .22264 m .47177 .21343 L .46593 .20356 L p F P
0 g
s
.668 .635 .808 r
.47367 .21698 m .47177 .21343 L .4511 .22264 L p F P
0 g
s
.697 .644 .793 r
.53633 .23605 m .55726 .22273 L p .55006 .21325 L F P
0 g
s
.697 .644 .793 r
.55006 .21325 m .53068 .22449 L .53633 .23605 L p F P
0 g
s
.324 0 .123 r
.71038 .95523 m .70997 .95614 L .68852 .9644 L p F P
0 g
s
.209 0 0 r
.6859 .96797 m .68852 .9644 L .70997 .95614 L p F P
0 g
s
.572 .602 .844 r
.71525 .72957 m .69461 .73053 L .68935 .72059 L p F P
0 g
s
.703 .758 .895 r
.43882 .69447 m .45223 .68849 L .46101 .6934 L p F P
0 g
s
.704 .762 .897 r
.45951 .68536 m .45223 .68849 L .46101 .6934 L p F P
0 g
s
.704 .762 .897 r
.46101 .6934 m .4654 .69144 L .45951 .68536 L p F P
0 g
s
.644 .11 0 r
.38333 .97219 m .3711 .96897 L .36455 .96465 L p F P
0 g
s
.644 .109 0 r
.3711 .96897 m .36455 .96465 L .35802 .96519 L p F P
0 g
s
.217 .732 .876 r
.56156 .99037 m .55604 .98844 L .53502 .99117 L p F P
0 g
s
.561 .815 .993 r
.55604 .98844 m .53502 .99117 L .52938 .98897 L p F P
0 g
s
.258 .253 .663 r
.24561 .35974 m .24157 .36948 L p .24026 .35185 L F P
0 g
s
.302 .317 .71 r
.24561 .35974 m .24157 .36948 L .24934 .37514 L p F P
0 g
s
0 0 .23 r
.2517 .28864 m .24724 .29584 L .24556 .30488 L p F P
0 g
s
.99 .775 .518 r
.80801 .32749 m .81201 .33484 L .81341 .32524 L p F P
0 g
s
.99 .775 .518 r
.81341 .32524 m .80942 .31787 L .80801 .32749 L p F P
0 g
s
.381 .585 .923 r
.59461 .50295 m .61115 .5062 L .61489 .5132 L p F P
0 g
s
.399 .576 .91 r
.59182 .49892 m .59461 .50295 L .61115 .5062 L p F P
0 g
s
.169 .707 .781 r
.61251 .98554 m .60934 .98532 L .58808 .98863 L p F P
0 g
s
.492 .846 .994 r
.60934 .98532 m .58808 .98863 L .58269 .98733 L p F P
0 g
s
.21 .732 .85 r
.58808 .98863 m .58269 .98733 L .56156 .99037 L p F P
0 g
s
.757 .769 .863 r
.40003 .70662 m .39149 .7121 L .38533 .70598 L p F P
0 g
s
.723 .683 .811 r
.61034 .21693 m .60224 .22205 L .58641 .21855 L p F P
0 g
s
.544 .83 .998 r
.58269 .98733 m .56156 .99037 L .55604 .98844 L p F P
0 g
s
.881 .85 .809 r
.77989 .418 m .78995 .40577 L .79248 .41332 L p F P
0 g
s
.881 .85 .809 r
.79248 .41332 m .78445 .423 L .77989 .418 L p F P
0 g
s
.73 .546 .643 r
.53408 .39858 m .53415 .39893 L .53434 .3986 L closepath p F P
0 g
s
.721 .535 .638 r
.53641 .41041 m .54753 .4118 L p .53434 .3986 L F P
0 g
s
.721 .535 .638 r
.53434 .3986 m .53415 .39893 L .53641 .41041 L p F P
0 g
s
.794 .825 .876 r
.71221 .4869 m .72174 .47993 L .71686 .47458 L p F P
0 g
s
.794 .825 .876 r
.71686 .47458 m .71045 .47929 L .71221 .4869 L p F P
0 g
s
.777 .817 .884 r
.69563 .48931 m .71045 .47929 L .71221 .4869 L p F P
0 g
s
.005 .569 .798 r
.44959 .98665 m .4452 .98614 L .45247 .98729 L closepath p F P
0 g
s
.706 .525 .642 r
.53415 .39893 m .52667 .41036 L .53641 .41041 L closepath p F P
0 g
s
.405 .187 .467 r
.76097 .90982 m .75295 .91367 L .7527 .92333 L p F P
0 g
s
.441 .256 .532 r
.75295 .91367 m .76097 .90982 L .76171 .89887 L p F P
0 g
s
.955 .681 .478 r
.58807 .48674 m .58193 .48042 L .58211 .47103 L p F P
0 g
s
.952 .618 .346 r
.58193 .48042 m .58807 .48674 L .58913 .49378 L p F P
0 g
s
.434 .25 .53 r
.77087 .89432 m .76171 .89887 L .76097 .90982 L p F P
0 g
s
.463 .305 .582 r
.76171 .89887 m .77087 .89432 L .76967 .88331 L p F P
0 g
s
.851 .759 .761 r
.2858 .81022 m .28705 .80854 L .28053 .80245 L p F P
0 g
s
.622 .708 .907 r
.42015 .50292 m .40279 .50667 L .40885 .51444 L p F P
0 g
s
.622 .708 .907 r
.40885 .51444 m .41831 .51211 L .42015 .50292 L p F P
0 g
s
.46 .516 .829 r
.2744 .43201 m .28574 .43401 L p .27275 .42072 L F P
0 g
s
.46 .516 .829 r
.27275 .42072 m .2711 .42561 L .2744 .43201 L p F P
0 g
s
.637 .75 .93 r
.67996 .19979 m .65822 .20523 L .66338 .21269 L p F P
0 g
s
.637 .75 .93 r
.66338 .21269 m .68501 .20636 L .67996 .19979 L p F P
0 g
s
.613 .659 .871 r
.63032 .70004 m .6518 .69612 L p .65588 .70476 L F P
0 g
s
.613 .666 .877 r
.6518 .69612 m .63032 .70004 L .62495 .69188 L p F P
0 g
s
.626 .446 .619 r
.51321 .43251 m .51167 .4223 L .48903 .42747 L p F P
0 g
s
.626 .446 .619 r
.51177 .4338 m .51321 .43251 L p .48903 .42747 L F P
0 g
s
.626 .446 .619 r
.48903 .42747 m .49045 .43839 L .51177 .4338 L p F P
0 g
s
.688 .746 .896 r
.65303 .198 m .63155 .20606 L .63684 .21424 L p F P
0 g
s
.688 .746 .896 r
.63684 .21424 m .65822 .20523 L .65303 .198 L p F P
0 g
s
.451 0 0 r
.38333 .97219 m .39059 .97579 L .38424 .97454 L p F P
0 g
s
.451 0 0 r
.38424 .97454 m .3711 .96897 L .38333 .97219 L p F P
0 g
s
.865 .753 .738 r
.27861 .80505 m .2858 .81022 L .2779 .82259 L p F P
0 g
s
.851 .759 .761 r
.28053 .80245 m .27861 .80505 L .2858 .81022 L p F P
0 g
s
.716 .204 .005 r
.34972 .95742 m .35802 .96519 L .35689 .96512 L p F P
0 g
s
.716 .204 .005 r
.33878 .9538 m .34972 .95742 L p .35689 .96512 L F P
0 g
s
.636 .781 .951 r
.4654 .69144 m .48612 .68561 L .49194 .69066 L p F P
0 g
s
.593 .783 .971 r
.4654 .69144 m .48612 .68561 L .48532 .68499 L p F P
0 g
s
.593 .783 .971 r
.45951 .68536 m .4654 .69144 L p .48532 .68499 L F P
0 g
s
.88 .647 .582 r
.28975 .8984 m .28582 .89641 L .28382 .88377 L p F P
0 g
s
.883 .649 .58 r
.28268 .88318 m .28382 .88377 L .28582 .89641 L p F P
0 g
s
.876 .671 .622 r
.28382 .88377 m .28305 .88179 L .28268 .88318 L closepath p F P
0 g
s
.88 .726 .687 r
.2713 .83463 m .27888 .83959 L .2735 .8513 L p F P
0 g
s
.87 .736 .712 r
.27888 .83959 m .2713 .83463 L .2779 .82259 L p F P
0 g
s
.032 0 .407 r
.2397 .32417 m .24619 .31306 L .24556 .30488 L p F P
0 g
s
.168 .104 .536 r
.24619 .31306 m .2397 .32417 L .24014 .32927 L p F P
0 g
s
.537 .621 .883 r
.34134 .48176 m .34422 .48595 L .34047 .48614 L closepath p F P
0 g
s
.884 .618 .529 r
.28582 .89641 m .28975 .8984 L .28951 .90885 L p F P
0 g
s
.875 .609 .532 r
.29865 .91312 m .28951 .90885 L .28975 .8984 L p F P
0 g
s
.867 .561 .468 r
.30952 .92731 m .30002 .9232 L .29865 .91312 L p F P
0 g
s
.876 .568 .463 r
.28951 .90885 m .29865 .91312 L .30002 .9232 L p F P
0 g
s
.882 .678 .622 r
.28268 .88318 m .28305 .88179 L .27709 .86821 L p F P
0 g
s
0 .167 .676 r
.76619 .24354 m .77249 .2504 L .78 .25652 L p F P
0 g
s
0 .192 .706 r
.78585 .2635 m .78 .25652 L .77249 .2504 L p F P
0 g
s
.798 .825 .873 r
.73487 .47002 m .72174 .47993 L .71686 .47458 L p F P
0 g
s
.265 .118 .487 r
.46598 .48586 m .47369 .47832 L .47358 .46874 L p F P
0 g
s
.118 0 .309 r
.47369 .47832 m .46598 .48586 L .46246 .49631 L p F P
0 g
s
.52 .805 .998 r
.51806 .69068 m .49829 .68967 L p .50093 .69067 L F P
0 g
s
.033 .601 .771 r
.49829 .68967 m .51806 .69068 L .51461 .69031 L p F P
0 g
s
.033 .601 .771 r
.51461 .69031 m .51275 .6901 L .50976 .69001 L p F P
0 g
s
.033 .601 .771 r
.50976 .69001 m .49829 .68967 L p .51461 .69031 L F P
0 g
s
.52 .805 .998 r
.49829 .68967 m .49194 .69066 L p .50093 .69067 L F P
0 g
s
.567 .757 .968 r
.49829 .68967 m .49194 .69066 L .48612 .68561 L p F P
0 g
s
.568 .047 0 r
.51018 .69271 m .50016 .6915 L .4947 .68911 L p F P
0 g
s
.568 .047 0 r
.49829 .68967 m .51275 .6901 L .51018 .69271 L p F P
0 g
s
.568 .047 0 r
.51018 .69271 m .49077 .68684 L .49829 .68967 L F
.48671 .68562 m .49829 .68967 L p .49077 .68684 L F P
0 g
s
.567 .757 .968 r
.48671 .68562 m .49829 .68967 L p .48836 .68636 L F P
0 g
s
.567 .757 .968 r
.48612 .68561 m .48671 .68562 L p .48836 .68636 L F P
0 g
s
.568 .047 0 r
.4947 .68911 m .48671 .68562 L p .49917 .68938 L F P
0 g
s
.568 .047 0 r
.51018 .69271 m .4947 .68911 L .49917 .68938 L F
.721 .26 .156 r
.48671 .68562 m .50016 .6915 L p .48549 .68507 L F P
0 g
s
.721 .26 .156 r
.48532 .68499 m .48671 .68562 L p .48549 .68507 L F P
0 g
s
.556 .56 .814 r
.72705 .75094 m .72562 .75091 L .72668 .75012 L closepath p F P
0 g
s
.568 .579 .824 r
.72181 .7402 m .72668 .75012 L .72562 .75091 L p F P
0 g
s
.503 .571 .857 r
.32177 .45706 m .30597 .45669 L .31218 .46694 L p F P
0 g
s
.503 .571 .857 r
.31218 .46694 m .31852 .46719 L .32177 .45706 L p F P
0 g
s
.492 .57 .862 r
.29885 .45631 m .30597 .45669 L .31218 .46694 L p F P
0 g
s
.494 .567 .858 r
.30097 .44829 m .30597 .45669 L .29885 .45631 L closepath p F P
0 g
s
.909 .664 .557 r
.58211 .47103 m .57429 .46522 L .57551 .45553 L p F P
0 g
s
.913 .638 .506 r
.57429 .46522 m .58211 .47103 L .58193 .48042 L p F P
0 g
s
.757 .769 .863 r
.38533 .70598 m .39271 .70124 L .40003 .70662 L p F P
0 g
s
.746 .769 .871 r
.40604 .69328 m .39271 .70124 L .40003 .70662 L p F P
0 g
s
.746 .769 .871 r
.40003 .70662 m .41214 .6994 L .40604 .69328 L p F P
0 g
s
.816 .778 .817 r
.3269 .75079 m .32304 .75448 L .31661 .74874 L p F P
0 g
s
.816 .778 .817 r
.31661 .74874 m .32022 .7453 L .3269 .75079 L p F P
0 g
s
.802 .779 .831 r
.33754 .73034 m .32022 .7453 L .3269 .75079 L p F P
0 g
s
.802 .779 .831 r
.3269 .75079 m .34389 .73614 L .33754 .73034 L p F P
0 g
s
.882 .851 .808 r
.78174 .42627 m .78445 .423 L .77989 .418 L p F P
0 g
s
.431 .283 .578 r
.78032 .87724 m .76967 .88331 L .77087 .89432 L p F P
0 g
s
.456 .33 .619 r
.76967 .88331 m .78032 .87724 L .77398 .86814 L p F P
0 g
s
.817 .778 .816 r
.3119 .76521 m .32304 .75448 L .31661 .74874 L p F P
0 g
s
.703 .763 .899 r
.62147 .51201 m .63108 .50789 L .63422 .51504 L p F P
0 g
s
.702 .768 .903 r
.63422 .51504 m .64802 .5087 L .6428 .50272 L p F P
0 g
s
.702 .768 .903 r
.6428 .50272 m .63108 .50789 L .63422 .51504 L p F P
0 g
s
.683 .652 .814 r
.47367 .21698 m .47757 .22424 L .49837 .21394 L p F P
0 g
s
.987 .717 .408 r
.80499 .31059 m .80942 .31787 L .80946 .30878 L p F P
0 g
s
.987 .717 .408 r
.80946 .30878 m .80504 .30149 L .80499 .31059 L p F P
0 g
s
.712 .734 .868 r
.62624 .19814 m .60493 .20799 L .61034 .21693 L p F P
0 g
s
.712 .734 .868 r
.61034 .21693 m .63155 .20606 L .62624 .19814 L p F P
0 g
s
.723 .683 .811 r
.58641 .21855 m .60493 .20799 L .61034 .21693 L p F P
0 g
s
.256 0 0 r
.42315 .98295 m .43012 .9837 L .4452 .98614 L p F P
0 g
s
0 .566 .787 r
.43012 .9837 m .4187 .98205 L .42315 .98295 L closepath p F P
0 g
s
.743 .546 .628 r
.53641 .41041 m .54753 .4118 L .54266 .42261 L p F P
0 g
s
.778 .573 .622 r
.55858 .42577 m .54266 .42261 L .54753 .4118 L p F P
0 g
s
.883 .649 .58 r
.28582 .89641 m .28107 .89396 L .28268 .88318 L p F P
0 g
s
.892 .658 .578 r
.27441 .87856 m .28268 .88318 L .28107 .89396 L p F P
0 g
s
.882 .678 .622 r
.27709 .86821 m .27441 .87856 L .28268 .88318 L p F P
0 g
s
.697 .762 .902 r
.45223 .68849 m .43882 .69447 L .43283 .68814 L p F P
0 g
s
.731 .76 .876 r
.41214 .6994 m .43283 .68814 L .43882 .69447 L p F P
0 g
s
.852 .499 .385 r
.32249 .94097 m .31268 .93699 L .30952 .92731 L p F P
0 g
s
.86 .502 .374 r
.30002 .9232 m .30952 .92731 L .31268 .93699 L p F P
0 g
s
.831 .776 .8 r
.3119 .76521 m .302 .77581 L .29549 .77013 L p F P
0 g
s
.831 .776 .8 r
.29549 .77013 m .30518 .75976 L .3119 .76521 L p F P
0 g
s
.817 .778 .816 r
.31661 .74874 m .30518 .75976 L .3119 .76521 L p F P
0 g
s
.584 .611 .845 r
.68935 .72059 m .68448 .72101 L .68813 .71832 L closepath p F P
0 g
s
.593 .628 .855 r
.68409 .71127 m .68813 .71832 L .68448 .72101 L p F P
0 g
s
.674 .74 .901 r
.40652 .19598 m .38602 .20436 L .39223 .21144 L p F P
0 g
s
.674 .74 .901 r
.39223 .21144 m .41267 .20323 L .40652 .19598 L p F P
0 g
s
.684 .788 .929 r
.3797 .19845 m .35926 .20742 L .36567 .21293 L p F P
0 g
s
.684 .788 .929 r
.36567 .21293 m .38602 .20436 L .3797 .19845 L p F P
0 g
s
.191 .684 .92 r
.4452 .98614 m .44959 .98665 L .44356 .98434 L p F P
0 g
s
.191 .684 .92 r
.44356 .98434 m .43012 .9837 L .4452 .98614 L p F P
0 g
s
.721 .872 .952 r
.33893 .217 m .33309 .22001 L .33779 .21636 L closepath p F P
0 g
s
.882 .851 .808 r
.77989 .418 m .7793 .41871 L .78174 .42627 L p F P
0 g
s
.859 .842 .827 r
.76646 .4324 m .76885 .43994 L .78174 .42627 L p F P
0 g
s
.859 .842 .827 r
.78174 .42627 m .7793 .41871 L .76646 .4324 L p F P
0 g
s
.799 .779 .834 r
.34453 .7356 m .34389 .73614 L .33754 .73034 L p F P
0 g
s
.799 .779 .834 r
.33754 .73034 m .33788 .73005 L .34453 .7356 L p F P
0 g
s
.786 .779 .846 r
.35835 .71429 m .33788 .73005 L .34453 .7356 L p F P
0 g
s
.786 .779 .846 r
.34453 .7356 m .36463 .72014 L .35835 .71429 L p F P
0 g
s
.545 .553 .813 r
.72705 .75094 m .74937 .75262 L p .74299 .7633 L F P
0 g
s
.535 .549 .816 r
.74411 .74126 m .74937 .75262 L .72705 .75094 L p F P
0 g
s
.535 .549 .816 r
.73738 .74068 m .74411 .74126 L p .72705 .75094 L F P
0 g
s
.535 .549 .816 r
.72705 .75094 m .72668 .75012 L .73738 .74068 L p F P
0 g
s
.554 .715 .947 r
.69627 .20525 m .68501 .20636 L .69004 .21318 L p F P
0 g
s
.554 .715 .947 r
.69004 .21318 m .70587 .21113 L .69627 .20525 L p F P
0 g
s
.451 .328 .622 r
.7854 .86138 m .77398 .86814 L .78032 .87724 L p F P
0 g
s
.478 .37 .652 r
.78284 .84898 m .7854 .86138 L .77398 .86814 L p F P
0 g
s
.982 .815 .601 r
.81022 .3413 m .8092 .34499 L .81273 .35242 L p F P
0 g
s
.959 .826 .669 r
.80496 .35567 m .8085 .36308 L .81273 .35242 L p F P
0 g
s
.959 .826 .669 r
.81273 .35242 m .8092 .34499 L .80496 .35567 L p F P
0 g
s
.862 .632 .588 r
.57551 .45553 m .56559 .45037 L .56779 .4404 L p F P
0 g
s
.859 .614 .566 r
.56559 .45037 m .57551 .45553 L .57429 .46522 L p F P
0 g
s
.921 .845 .752 r
.79579 .38597 m .8029 .37425 L .80598 .38174 L p F P
0 g
s
.921 .845 .752 r
.79604 .3866 m .79579 .38597 L p .80598 .38174 L F P
0 g
s
.921 .845 .752 r
.80598 .38174 m .80017 .39125 L .79604 .3866 L p F P
0 g
s
.549 .574 .832 r
.72668 .75012 m .72181 .7402 L .73738 .74068 L closepath p F P
0 g
s
.494 .429 .712 r
.77665 .82543 m .77296 .82377 L .77568 .82199 L closepath p F P
0 g
s
.511 .461 .737 r
.77296 .82377 m .77568 .82199 L .77101 .80729 L p F P
0 g
s
.715 .837 .94 r
.43531 .51568 m .42929 .50925 L p .45043 .50179 L F P
0 g
s
.715 .837 .94 r
.45043 .50179 m .44162 .51268 L .43531 .51568 L p F P
0 g
s
.63 .71 .903 r
.43531 .51568 m .42929 .50925 L .41831 .51211 L p F P
0 g
s
.817 .832 .862 r
.73487 .47002 m .74282 .46342 L .73804 .45809 L p F P
0 g
s
.817 .832 .862 r
.73804 .45809 m .73281 .46245 L .73487 .47002 L p F P
0 g
s
.798 .825 .873 r
.71686 .47458 m .73281 .46245 L .73487 .47002 L p F P
0 g
s
.637 .703 .894 r
.59954 .69104 m .59824 .68931 L .60691 .6871 L closepath p F P
0 g
s
.737 .534 .619 r
.55521 .43611 m .55858 .42577 L .54266 .42261 L p F P
0 g
s
.818 .601 .609 r
.56779 .4404 m .55521 .43611 L .55858 .42577 L p F P
0 g
s
.755 .8 .889 r
.68203 .49809 m .6744 .50267 L .66931 .49693 L p F P
0 g
s
.741 .797 .897 r
.64802 .5087 m .66931 .49693 L .6744 .50267 L p F P
0 g
s
.69 .501 .627 r
.51939 .422 m .51167 .4223 L .50986 .41101 L p F P
0 g
s
.69 .501 .627 r
.50986 .41101 m .52667 .41036 L .51939 .422 L p F P
0 g
s
.809 .583 .595 r
.55521 .43611 m .56779 .4404 L .56559 .45037 L p F P
0 g
s
.616 .143 0 r
.787 .26498 m .78585 .2635 L .78 .25652 L p F P
0 g
s
.422 .475 .81 r
.26828 .41958 m .27275 .42072 L .2711 .42561 L closepath p F P
0 g
s
.858 .46 0 r
.80365 .29296 m .7988 .28575 L .79588 .27782 L p F P
0 g
s
.959 .624 .251 r
.7988 .28575 m .80365 .29296 L .80504 .30149 L p F P
0 g
s
.71 .687 .826 r
.58266 .21796 m .58382 .22 L .58641 .21855 L closepath p F P
0 g
s
.705 .659 .802 r
.58382 .22 m .58266 .21796 L .57005 .21521 L p F P
0 g
s
.168 .152 .595 r
.24026 .35185 m .24257 .34673 L .2406 .33487 L p F P
0 g
s
.256 .253 .663 r
.24257 .34673 m .24486 .35652 L .24026 .35185 L closepath p F P
0 g
s
.258 .253 .663 r
.24026 .35185 m .24486 .35652 L .24561 .35974 L p F P
0 g
s
.624 .805 .969 r
.56729 .68557 m .55591 .68739 L .54505 .69031 L p F P
0 g
s
.584 .857 .995 r
.55591 .68739 m .54445 .69 L .54505 .69031 L closepath p F P
0 g
s
.831 .776 .8 r
.29902 .77899 m .302 .77581 L .29549 .77013 L p F P
0 g
s
.379 .622 .948 r
.73331 .21898 m .7415 .22531 L p .7187 .2191 L F P
0 g
s
.379 .622 .948 r
.7187 .2191 m .71696 .21681 L .73331 .21898 L p F P
0 g
s
.543 .71 .949 r
.71541 .21698 m .7187 .2191 L .71696 .21681 L closepath p F P
0 g
s
.585 .661 .89 r
.37648 .50169 m .3967 .49856 L p .37155 .49314 L F P
0 g
s
.585 .661 .89 r
.37155 .49314 m .37111 .49439 L .37648 .50169 L p F P
0 g
s
.31 .797 .885 r
.60934 .98532 m .61251 .98554 L .63534 .98178 L p F P
0 g
s
.199 .728 .788 r
.63592 .98179 m .63534 .98178 L .61251 .98554 L p F P
0 g
s
.168 .104 .536 r
.24014 .32927 m .24154 .33316 L p .24619 .31306 L F P
0 g
s
.135 .079 .524 r
.24014 .32927 m .24154 .33316 L .2406 .33487 L closepath p F P
0 g
s
.819 .831 .859 r
.7534 .45447 m .74282 .46342 L .73804 .45809 L p F P
0 g
s
.611 .211 .26 r
.51985 .6907 m .53947 .69052 L .53802 .69329 L p F P
0 g
s
.056 0 0 r
.53947 .69052 m .51985 .6907 L .54445 .69 L closepath p F P
0 g
s
.611 .211 .26 r
.51275 .6901 m .51806 .69068 L p .53802 .69329 L F P
0 g
s
.652 .735 .91 r
.57163 .68914 m .59281 .68284 L .59824 .68931 L p F P
0 g
s
.642 .805 .961 r
.56729 .68557 m .57163 .68914 L .59281 .68284 L p F P
0 g
s
.672 .71 .877 r
.43328 .19494 m .41267 .20323 L .41872 .21154 L p F P
0 g
s
.672 .71 .877 r
.41872 .21154 m .43929 .2032 L .43328 .19494 L p F P
0 g
s
.891 .687 .62 r
.27709 .86821 m .27728 .86748 L .27648 .867 L closepath p F P
0 g
s
.88 .705 .66 r
.27081 .8587 m .2735 .8513 L p .27728 .86748 L F P
0 g
s
.88 .705 .66 r
.27728 .86748 m .27648 .867 L .27081 .8587 L p F P
0 g
s
.879 .473 .029 r
.79059 .2707 m .79588 .27782 L .7988 .28575 L p F P
0 g
s
.755 .366 0 r
.58913 .49378 m .58987 .49551 L .59182 .49892 L closepath p F P
0 g
s
.399 .576 .91 r
.60624 .49952 m .58987 .49551 L .59182 .49892 L p F P
0 g
s
.399 .576 .91 r
.61115 .5062 m .60624 .49952 L p .59182 .49892 L F P
0 g
s
.838 .837 .844 r
.75908 .43944 m .76646 .4324 L .76885 .43994 L p F P
0 g
s
.838 .837 .844 r
.76885 .43994 m .76377 .44475 L .75908 .43944 L p F P
0 g
s
.845 .773 .781 r
.29226 .77359 m .29902 .77899 L .28805 .79223 L p F P
0 g
s
.831 .776 .8 r
.29549 .77013 m .29226 .77359 L .29902 .77899 L p F P
0 g
s
.682 .647 .809 r
.50411 .22499 m .52501 .21361 L p .49892 .21367 L F P
0 g
s
.682 .647 .809 r
.49892 .21367 m .49837 .21394 L .50411 .22499 L p F P
0 g
s
.557 .63 .88 r
.34422 .48595 m .36418 .48427 L p .34309 .47641 L F P
0 g
s
.557 .63 .88 r
.34309 .47641 m .34134 .48176 L .34422 .48595 L p F P
0 g
s
.743 .546 .628 r
.54266 .42261 m .53861 .42212 L .53641 .41041 L p F P
0 g
s
.706 .522 .637 r
.52667 .41036 m .53641 .41041 L .53861 .42212 L p F P
0 g
s
.839 .839 .845 r
.7534 .45447 m .76377 .44475 L .75908 .43944 L p F P
0 g
s
.706 .522 .637 r
.53861 .42212 m .51939 .422 L .52667 .41036 L p F P
0 g
s
.839 .839 .845 r
.75908 .43944 m .75114 .44693 L .7534 .45447 L p F P
0 g
s
.819 .831 .859 r
.73804 .45809 m .75114 .44693 L .7534 .45447 L p F P
0 g
s
.71 .686 .825 r
.58641 .21855 m .60493 .20799 L p .57831 .21029 L F P
0 g
s
.71 .686 .825 r
.57831 .21029 m .58266 .21796 L .58641 .21855 L p F P
0 g
s
.829 .413 .253 r
.32249 .94097 m .32578 .94703 L .3214 .94762 L p F P
0 g
s
.829 .413 .253 r
.31268 .93699 m .32249 .94097 L p .3214 .94762 L F P
0 g
s
.891 .687 .62 r
.27441 .87856 m .27709 .86821 L .27648 .867 L p F P
0 g
s
.595 .72 .932 r
.61613 .50553 m .61115 .5062 L .61489 .5132 L p F P
0 g
s
.595 .72 .932 r
.61489 .5132 m .62147 .51201 L .61613 .50553 L p F P
0 g
s
.709 .671 .811 r
.55227 .21344 m .55726 .22273 L .57005 .21521 L closepath p F P
0 g
s
.697 .644 .793 r
.55726 .22273 m .55227 .21344 L .55006 .21325 L p F P
0 g
s
.891 .687 .62 r
.27648 .867 m .26934 .86271 L p .27441 .87856 L F P
0 g
s
.883 .705 .656 r
.27648 .867 m .27081 .8587 L .26934 .86271 L closepath p F P
0 g
s
.707 .87 .959 r
.35531 .20485 m .35926 .20742 L .33893 .217 L p F P
0 g
s
.707 .87 .959 r
.33893 .217 m .33779 .21636 L .35531 .20485 L p F P
0 g
s
.606 .643 .861 r
.6571 .70457 m .65588 .70476 L .65684 .70413 L closepath p F P
0 g
s
.613 .659 .871 r
.6518 .69612 m .65684 .70413 L .65588 .70476 L p F P
0 g
s
.391 0 .039 r
.54445 .69 m .55591 .68739 L p .56096 .68878 L F P
0 g
s
.391 0 .039 r
.53947 .69052 m .54445 .69 L p .56096 .68878 L F P
0 g
s
.69 .654 .809 r
.53068 .22449 m .55006 .21325 L .52763 .21223 L p F P
0 g
s
.69 .654 .809 r
.52763 .21223 m .52501 .21361 L .53068 .22449 L p F P
0 g
s
.884 .618 .529 r
.28951 .90885 m .28363 .90592 L .28582 .89641 L p F P
0 g
s
.889 .622 .529 r
.28107 .89396 m .28582 .89641 L .28363 .90592 L p F P
0 g
s
.505 .331 .579 r
.47358 .46874 m .49249 .45939 L p .48664 .45172 L F P
0 g
s
.478 .281 .534 r
.49263 .46896 m .49249 .45939 L .47358 .46874 L p F P
0 g
s
.478 .281 .534 r
.47358 .46874 m .47369 .47832 L .49263 .46896 L p F P
0 g
s
.732 .767 .881 r
.43283 .68814 m .41214 .6994 L .40604 .69328 L p F P
0 g
s
.78 .779 .851 r
.36576 .7193 m .36463 .72014 L .35835 .71429 L p F P
0 g
s
.717 .689 .822 r
.57831 .21029 m .57005 .21521 L .58266 .21796 L closepath p F P
0 g
s
.876 .746 .715 r
.27069 .81745 m .2779 .82259 L .2713 .83463 L p F P
0 g
s
.865 .753 .738 r
.2779 .82259 m .27069 .81745 L .27861 .80505 L p F P
0 g
s
.635 .729 .915 r
.60691 .6871 m .59824 .68931 L .59281 .68284 L p F P
0 g
s
.768 .807 .884 r
.68203 .49809 m .69563 .48931 L .69062 .48363 L p F P
0 g
s
.768 .807 .884 r
.69062 .48363 m .67979 .49063 L .68203 .49809 L p F P
0 g
s
.755 .8 .889 r
.66931 .49693 m .67979 .49063 L .68203 .49809 L p F P
0 g
s
.78 .779 .851 r
.35835 .71429 m .35914 .7137 L .36576 .7193 L p F P
0 g
s
.768 .778 .861 r
.37911 .70009 m .35914 .7137 L .36576 .7193 L p F P
0 g
s
.768 .778 .861 r
.36576 .7193 m .38533 .70598 L .37911 .70009 L p F P
0 g
s
.437 .482 .808 r
.26828 .41958 m .27275 .42072 L p .26238 .4065 L F P
0 g
s
.437 .482 .808 r
.26238 .4065 m .26231 .40668 L .26828 .41958 L p F P
0 g
s
.355 .018 .248 r
.73135 .94438 m .73242 .94018 L p .71038 .95523 L F P
0 g
s
.355 .018 .248 r
.71038 .95523 m .71536 .95345 L .73135 .94438 L p F P
0 g
s
.288 0 .126 r
.70997 .95614 m .71536 .95345 L .71038 .95523 L closepath p F P
0 g
s
.572 .602 .844 r
.68935 .72059 m .71132 .71973 L p .71525 .72957 L F P
0 g
s
.564 .601 .849 r
.70607 .71004 m .71132 .71973 L .68935 .72059 L p F P
0 g
s
.564 .601 .849 r
.69674 .71035 m .70607 .71004 L p .68935 .72059 L F P
0 g
s
.564 .601 .849 r
.68935 .72059 m .68813 .71832 L .69674 .71035 L p F P
0 g
s
.768 .944 .937 r
.45605 .5033 m .44162 .51268 L .45043 .50179 L closepath p F P
0 g
s
.715 .254 0 r
.78486 .26368 m .78249 .25982 L .787 .26498 L p F P
0 g
s
.715 .254 0 r
.787 .26498 m .79059 .2707 L .78486 .26368 L p F P
0 g
s
.616 .143 0 r
.78 .25652 m .78249 .25982 L .787 .26498 L p F P
0 g
s
.588 .632 .862 r
.6571 .70457 m .67882 .7022 L .68409 .71127 L p F P
0 g
s
.587 .634 .865 r
.67353 .69324 m .67882 .7022 L .6571 .70457 L p F P
0 g
s
.587 .634 .865 r
.66869 .69377 m .67353 .69324 L p .6571 .70457 L F P
0 g
s
.587 .634 .865 r
.6571 .70457 m .65684 .70413 L .66869 .69377 L p F P
0 g
s
.538 .53 .794 r
.74299 .7633 m .75468 .76476 L p .75623 .77688 L F P
0 g
s
.53 .532 .802 r
.75468 .76476 m .74299 .7633 L .75118 .75654 L closepath p F P
0 g
s
.545 .553 .813 r
.74937 .75262 m .75118 .75654 L .74299 .7633 L p F P
0 g
s
.138 .667 .87 r
.47614 .98838 m .47023 .98545 L .44959 .98665 L p F P
0 g
s
.536 .785 .99 r
.47023 .98545 m .44959 .98665 L .44356 .98434 L p F P
0 g
s
.331 .016 .272 r
.73135 .94438 m .74244 .93602 L .73242 .94018 L closepath p F P
0 g
s
.391 .122 .381 r
.75239 .92613 m .7527 .92333 L p .73242 .94018 L F P
0 g
s
.391 .122 .381 r
.73242 .94018 m .74244 .93602 L .75239 .92613 L p F P
0 g
s
.597 .652 .875 r
.65684 .70413 m .6518 .69612 L .66869 .69377 L closepath p F P
0 g
s
.676 .693 .858 r
.46002 .1946 m .43929 .2032 L .44523 .21244 L p F P
0 g
s
.676 .693 .858 r
.44523 .21244 m .46593 .20356 L .46002 .1946 L p F P
0 g
s
.486 .446 .738 r
.77119 .80715 m .77101 .80729 L .77568 .82199 L p F P
0 g
s
.504 .478 .761 r
.77101 .80729 m .77093 .80708 L .77119 .80715 L closepath p F P
0 g
s
.504 .477 .76 r
.77119 .80715 m .77093 .80708 L .76547 .79162 L p F P
0 g
s
.18 .518 .917 r
.74913 .23173 m .74923 .23176 L .74895 .2315 L closepath p F P
0 g
s
.624 .437 .61 r
.49787 .44781 m .49169 .44912 L .49045 .43839 L p F P
0 g
s
.624 .437 .61 r
.49045 .43839 m .51177 .4338 L .49787 .44781 L p F P
0 g
s
.515 .359 .608 r
.48664 .45172 m .49169 .44912 L .49045 .43839 L p F P
0 g
s
.477 .418 .712 r
.77568 .82199 m .78699 .81352 L p .78678 .83074 L F P
0 g
s
.477 .418 .712 r
.78678 .83074 m .77665 .82543 L .77568 .82199 L p F P
0 g
s
.486 .446 .738 r
.77568 .82199 m .78699 .81352 L .77119 .80715 L p F P
0 g
s
.631 .918 .64 r
.28859 .24077 m .28329 .24653 L .27029 .25921 L p F P
0 g
s
.74 .992 .826 r
.29124 .23989 m .28329 .24653 L .28859 .24077 L closepath p F P
0 g
s
.616 .712 .914 r
.42929 .50925 m .41831 .51211 L .42015 .50292 L p F P
0 g
s
0 .386 .841 r
.75943 .23678 m .74923 .23176 L .74895 .2315 L p F P
0 g
s
.041 .419 .865 r
.76619 .24354 m .75943 .23678 L .74923 .23176 L p F P
0 g
s
0 0 0 r
.68391 .9697 m .66237 .97549 L .65743 .97713 L p F P
0 g
s
0 0 0 r
.63592 .98179 m .65743 .97713 L .66237 .97549 L p F P
0 g
s
.133 0 0 r
.6859 .96797 m .68391 .9697 L .66237 .97549 L p F P
0 g
s
.513 .708 .959 r
.71696 .21681 m .71541 .21698 L .70587 .21113 L p F P
0 g
s
.682 .651 .812 r
.47177 .21343 m .47367 .21698 L .49824 .21371 L p F P
0 g
s
.683 .652 .814 r
.49837 .21394 m .49824 .21371 L .47367 .21698 L p F P
0 g
s
.921 .845 .751 r
.80017 .39125 m .79882 .39345 L .79604 .3866 L closepath p F P
0 g
s
.483 .45 .745 r
.78385 .79714 m .77119 .80715 L .78699 .81352 L p F P
0 g
s
.504 .477 .76 r
.76561 .79151 m .78385 .79714 L .77119 .80715 L p F P
0 g
s
.504 .477 .76 r
.76547 .79162 m .76561 .79151 L p .77119 .80715 L F P
0 g
s
.238 .202 .614 r
.24154 .33316 m .2406 .33487 L .24257 .34673 L p F P
0 g
s
.973 .801 .609 r
.80573 .33574 m .80801 .32749 L .81201 .33484 L p F P
0 g
s
.973 .801 .609 r
.81201 .33484 m .81022 .3413 L .80573 .33574 L p F P
0 g
s
.89 .713 .656 r
.2735 .8513 m .27081 .8587 L .26439 .8505 L p F P
0 g
s
.89 .713 .656 r
.26439 .8505 m .26589 .84637 L .2735 .8513 L p F P
0 g
s
.88 .726 .687 r
.2735 .8513 m .26589 .84637 L .2713 .83463 L p F P
0 g
s
0 .386 .841 r
.75221 .23012 m .75943 .23678 L p .74895 .2315 L F P
0 g
s
0 .386 .841 r
.74895 .2315 m .74442 .22608 L .75221 .23012 L p F P
0 g
s
.23 .561 .936 r
.7415 .22531 m .74895 .2315 L .74442 .22608 L closepath p F P
0 g
s
.476 .419 .714 r
.7796 .83585 m .77665 .82543 L .78678 .83074 L closepath p F P
0 g
s
.858 .769 .763 r
.28805 .79223 m .28053 .80245 L .27394 .79681 L p F P
0 g
s
.858 .769 .763 r
.27394 .79681 m .28126 .78687 L .28805 .79223 L p F P
0 g
s
.845 .773 .781 r
.28805 .79223 m .28126 .78687 L .29226 .77359 L p F P
0 g
s
.576 .622 .861 r
.68813 .71832 m .68409 .71127 L .69674 .71035 L closepath p F P
0 g
s
.724 .987 .887 r
.29124 .23989 m .28859 .24077 L p .31058 .22548 L F P
0 g
s
.724 .987 .887 r
.31058 .22548 m .30712 .22864 L .29124 .23989 L p F P
0 g
s
.889 .462 .131 r
.58913 .49378 m .58987 .49551 L .58651 .49256 L closepath p F P
0 g
s
.952 .618 .346 r
.58913 .49378 m .58651 .49256 L p .58193 .48042 L F P
0 g
s
.631 .918 .64 r
.27029 .25921 m .26983 .25965 L p .28859 .24077 L F P
0 g
s
.654 .903 .578 r
.27029 .25921 m .26919 .26048 L .26983 .25965 L closepath p F P
0 g
s
.739 .789 .892 r
.66931 .49693 m .64802 .5087 L .6428 .50272 L p F P
0 g
s
.713 .894 .962 r
.3527 .20338 m .35531 .20485 L .33779 .21636 L p F P
0 g
s
.713 .894 .962 r
.33779 .21636 m .33224 .2138 L .3527 .20338 L p F P
0 g
s
.724 .89 .956 r
.31179 .22557 m .33224 .2138 L .33779 .21636 L p F P
0 g
s
.893 .839 .785 r
.78691 .39832 m .78995 .40577 L .79882 .39345 L p F P
0 g
s
.893 .839 .785 r
.79567 .38614 m .78691 .39832 L p .79882 .39345 L F P
0 g
s
.893 .839 .785 r
.79882 .39345 m .79604 .3866 L .79567 .38614 L p F P
0 g
s
0 0 .23 r
.24556 .30488 m .25049 .29697 L .2517 .28864 L p F P
0 g
s
.06 0 .414 r
.25049 .29697 m .24556 .30488 L .24619 .31306 L p F P
0 g
s
.531 .598 .866 r
.33183 .46689 m .31852 .46719 L .32177 .45706 L p F P
0 g
s
.526 .604 .874 r
.33803 .47664 m .33183 .46689 L .31852 .46719 L p F P
0 g
s
.163 0 0 r
.70638 .96164 m .70997 .95614 L .71536 .95345 L p F P
0 g
s
.209 0 0 r
.70997 .95614 m .70638 .96164 L .6859 .96797 L p F P
0 g
s
0 0 0 r
.26983 .25965 m .26919 .26048 L .26118 .272 L p F P
0 g
s
.301 0 0 r
.3711 .96897 m .38424 .97454 L .37987 .97312 L p F P
0 g
s
.301 0 0 r
.35894 .9657 m .3711 .96897 L p .37987 .97312 L F P
0 g
s
.644 .109 0 r
.35802 .96519 m .35894 .9657 L .3711 .96897 L p F P
0 g
s
.697 .762 .902 r
.43283 .68814 m .44419 .6833 L .45223 .68849 L p F P
0 g
s
.699 .767 .905 r
.45356 .67943 m .44419 .6833 L .45223 .68849 L p F P
0 g
s
.699 .767 .905 r
.45223 .68849 m .45951 .68536 L .45356 .67943 L p F P
0 g
s
.114 .644 .871 r
.43012 .9837 m .44356 .98434 L p .41698 .98159 L F P
0 g
s
.114 .644 .871 r
.41698 .98159 m .4187 .98205 L .43012 .9837 L p F P
0 g
s
.347 .634 .96 r
.72471 .21274 m .71208 .21068 L .71696 .21681 L p F P
0 g
s
.347 .634 .96 r
.71696 .21681 m .73331 .21898 L .72471 .21274 L p F P
0 g
s
.513 .708 .959 r
.70587 .21113 m .71208 .21068 L .71696 .21681 L p F P
0 g
s
.537 .609 .872 r
.33803 .47664 m .34309 .47641 L .34134 .48176 L closepath p F P
0 g
s
.405 .187 .467 r
.7527 .92333 m .75555 .92197 L .76097 .90982 L p F P
0 g
s
.395 .177 .461 r
.77139 .90468 m .76097 .90982 L .75555 .92197 L p F P
0 g
s
.434 .25 .53 r
.76097 .90982 m .77139 .90468 L .77087 .89432 L p F P
0 g
s
.742 .541 .622 r
.53861 .42212 m .53987 .42926 L .54266 .42261 L closepath p F P
0 g
s
.737 .534 .619 r
.54059 .43359 m .55521 .43611 L p .54266 .42261 L F P
0 g
s
.737 .534 .619 r
.54266 .42261 m .53987 .42926 L .54059 .43359 L p F P
0 g
s
.521 .507 .782 r
.76001 .77757 m .75623 .77688 L .75893 .77479 L closepath p F P
0 g
s
.538 .53 .794 r
.75468 .76476 m .75893 .77479 L .75623 .77688 L p F P
0 g
s
.513 .502 .782 r
.76547 .79162 m .76541 .79147 L .76561 .79151 L closepath p F P
0 g
s
.513 .502 .782 r
.76561 .79151 m .76541 .79147 L .76001 .77757 L p F P
0 g
s
.118 0 .309 r
.46246 .49631 m .47252 .48652 L .47369 .47832 L p F P
0 g
s
.468 .391 .687 r
.7796 .83585 m .78678 .83074 L p .78313 .84879 L F P
0 g
s
.468 .391 .687 r
.78313 .84879 m .78273 .84851 L .7796 .83585 L p F P
0 g
s
.493 .478 .769 r
.7774 .78161 m .76561 .79151 L .78385 .79714 L p F P
0 g
s
.513 .502 .782 r
.76001 .77757 m .7774 .78161 L .76561 .79151 L p F P
0 g
s
.516 .578 .856 r
.30597 .45669 m .32177 .45706 L p .30172 .44624 L F P
0 g
s
.516 .578 .856 r
.30172 .44624 m .30097 .44829 L .30597 .45669 L p F P
0 g
s
.689 .497 .621 r
.51167 .4223 m .51321 .43251 L .51939 .422 L closepath p F P
0 g
s
.548 .575 .834 r
.73738 .74068 m .72181 .7402 L .71655 .72957 L p F P
0 g
s
.716 .204 .005 r
.35689 .96512 m .34804 .96207 L .33878 .9538 L p F P
0 g
s
.701 .174 0 r
.3281 .95009 m .33878 .9538 L .34804 .96207 L p F P
0 g
s
.789 .346 .196 r
.33878 .9538 m .3281 .95009 L .32578 .94703 L p F P
0 g
s
.512 .799 .997 r
.47614 .98838 m .49695 .98565 L .50275 .98901 L p F P
0 g
s
.597 .784 .97 r
.49695 .98565 m .47614 .98838 L .47023 .98545 L p F P
0 g
s
.776 .809 .879 r
.71045 .47929 m .69563 .48931 L .69062 .48363 L p F P
0 g
s
.501 .333 .585 r
.49169 .44912 m .49219 .45505 L .48664 .45172 L closepath p F P
0 g
s
.505 .331 .579 r
.49249 .45939 m .49219 .45505 L .48664 .45172 L p F P
0 g
s
.937 .829 .713 r
.79934 .36687 m .8029 .37425 L .8085 .36308 L p F P
0 g
s
.937 .829 .713 r
.8085 .36308 m .80496 .35567 L .79934 .36687 L p F P
0 g
s
.675 .479 .613 r
.53987 .42926 m .53861 .42212 L .51939 .422 L p F P
0 g
s
.631 .918 .64 r
.26983 .25965 m .28364 .2446 L .28859 .24077 L p F P
0 g
s
0 0 0 r
.28359 .24467 m .28364 .2446 L .26983 .25965 L p F P
0 g
s
0 0 0 r
.27437 .25661 m .28359 .24467 L p .26983 .25965 L F P
0 g
s
0 0 0 r
.26983 .25965 m .26637 .26532 L .27437 .25661 L p F P
0 g
s
0 0 0 r
.26118 .272 m .26637 .26532 L .26983 .25965 L p F P
0 g
s
.613 .666 .877 r
.62495 .69188 m .64647 .68787 L .6518 .69612 L p F P
0 g
s
.615 .673 .883 r
.64647 .68787 m .62495 .69188 L .61957 .68402 L p F P
0 g
s
.685 .687 .846 r
.48679 .19443 m .46593 .20356 L .47177 .21343 L p F P
0 g
s
.685 .687 .846 r
.47177 .21343 m .4926 .20377 L .48679 .19443 L p F P
0 g
s
.682 .651 .812 r
.49824 .21371 m .4926 .20377 L .47177 .21343 L p F P
0 g
s
.675 .479 .613 r
.538 .43339 m .53987 .42926 L p .51939 .422 L F P
0 g
s
.675 .479 .613 r
.51333 .43345 m .538 .43339 L p .51939 .422 L F P
0 g
s
.675 .479 .613 r
.51939 .422 m .51321 .43251 L .51333 .43345 L p F P
0 g
s
.71 .671 .81 r
.57005 .21521 m .57831 .21029 L p .55167 .21231 L F P
0 g
s
.71 .671 .81 r
.55167 .21231 m .55227 .21344 L .57005 .21521 L p F P
0 g
s
.697 .758 .899 r
.63108 .50789 m .62147 .51201 L .61613 .50553 L p F P
0 g
s
.355 0 0 r
.39059 .97579 m .40226 .97816 L .41503 .98123 L p F P
0 g
s
.145 0 0 r
.40226 .97816 m .39059 .97579 L .38424 .97454 L p F P
0 g
s
0 0 0 r
.45605 .5033 m .45043 .50179 L p .47252 .48652 L F P
0 g
s
.168 .104 .536 r
.24154 .33316 m .24903 .32043 L .24619 .31306 L p F P
0 g
s
.274 .218 .611 r
.24639 .3398 m .24154 .33316 L .24903 .32043 L p F P
0 g
s
.238 .202 .614 r
.24257 .34673 m .24639 .3398 L .24154 .33316 L p F P
0 g
s
.163 0 0 r
.71536 .95345 m .73012 .94803 L p .70638 .96164 L F P
0 g
s
.329 0 .212 r
.71536 .95345 m .73012 .94803 L .73135 .94438 L closepath p F P
0 g
s
.399 .224 .525 r
.7834 .88724 m .77087 .89432 L .77139 .90468 L p F P
0 g
s
.431 .283 .578 r
.77087 .89432 m .7834 .88724 L .78032 .87724 L p F P
0 g
s
.27 .611 .956 r
.60624 .49952 m .58987 .49551 L .58651 .49256 L p F P
0 g
s
.759 .777 .868 r
.39271 .70124 m .38533 .70598 L .37911 .70009 L p F P
0 g
s
0 0 .016 r
.2517 .28864 m .25647 .28223 L .26118 .272 L p F P
0 g
s
0 0 .28 r
.25647 .28223 m .2517 .28864 L .25049 .29697 L p F P
0 g
s
.609 .688 .898 r
.41717 .4944 m .3967 .49856 L .40279 .50667 L p F P
0 g
s
.609 .688 .898 r
.42133 .4998 m .41717 .4944 L p .40279 .50667 L F P
0 g
s
.609 .688 .898 r
.40279 .50667 m .42015 .50292 L .42133 .4998 L p F P
0 g
s
.642 .805 .961 r
.58736 .67768 m .57639 .68128 L .56729 .68557 L p F P
0 g
s
.652 .854 .977 r
.56613 .68484 m .57639 .68128 L .56729 .68557 L closepath p F P
0 g
s
.02 0 0 r
.56613 .68484 m .57639 .68128 L p .5745 .68219 L F P
0 g
s
.589 .835 .991 r
.56031 .68668 m .56729 .68557 L .56613 .68484 L p F P
0 g
s
.642 .805 .961 r
.59281 .68284 m .58736 .67768 L p .56729 .68557 L F P
0 g
s
.02 0 0 r
.56096 .68878 m .56613 .68484 L p .5745 .68219 L F P
0 g
s
.589 .835 .991 r
.56613 .68484 m .55591 .68739 L .56031 .68668 L p F P
0 g
s
.391 0 .039 r
.55591 .68739 m .56613 .68484 L .56096 .68878 L p F P
0 g
s
.394 .433 .783 r
.26221 .40643 m .26238 .4065 L .26231 .40668 L closepath p F P
0 g
s
.4 .429 .775 r
.26725 .39529 m .25624 .39182 L .26221 .40643 L p F P
0 g
s
.4 .429 .775 r
.26221 .40643 m .26238 .4065 L .26725 .39529 L p F P
0 g
s
.392 .43 .781 r
.25469 .39127 m .25624 .39182 L .26221 .40643 L p F P
0 g
s
.08 0 0 r
.68391 .9697 m .6859 .96797 L .70638 .96164 L p F P
0 g
s
.876 .568 .463 r
.30002 .9232 m .29084 .91895 L .28951 .90885 L p F P
0 g
s
.885 .573 .454 r
.28363 .90592 m .28951 .90885 L .29084 .91895 L p F P
0 g
s
.857 .769 .764 r
.27861 .80505 m .28053 .80245 L .27394 .79681 L p F P
0 g
s
.759 .54 .6 r
.54059 .43359 m .55521 .43611 L .55231 .44632 L p F P
0 g
s
.809 .583 .595 r
.56559 .45037 m .55231 .44632 L .55521 .43611 L p F P
0 g
s
.913 .638 .506 r
.58193 .48042 m .57412 .4746 L .57429 .46522 L p F P
0 g
s
.916 .582 .395 r
.57412 .4746 m .58193 .48042 L .58341 .48931 L p F P
0 g
s
.952 .618 .346 r
.58651 .49256 m .58341 .48931 L .58193 .48042 L p F P
0 g
s
.983 .763 .529 r
.80356 .32023 m .80801 .32749 L .80942 .31787 L p F P
0 g
s
.983 .763 .529 r
.80942 .31787 m .80499 .31059 L .80356 .32023 L p F P
0 g
s
.451 .478 .796 r
.27713 .40981 m .26238 .4065 L .26725 .39529 L p F P
0 g
s
.437 .482 .808 r
.27275 .42072 m .27713 .40981 L .26238 .4065 L p F P
0 g
s
.889 .622 .529 r
.28363 .90592 m .28076 .90444 L .28107 .89396 L p F P
0 g
s
.898 .631 .525 r
.27278 .88936 m .28107 .89396 L .28076 .90444 L p F P
0 g
s
.892 .658 .578 r
.28107 .89396 m .27278 .88936 L .27441 .87856 L p F P
0 g
s
.635 .729 .915 r
.61417 .67687 m .61712 .68072 L .60691 .6871 L p F P
0 g
s
.635 .729 .915 r
.59281 .68284 m .61417 .67687 L p .60691 .6871 L F P
0 g
s
.633 .703 .896 r
.61957 .68402 m .60691 .6871 L .61712 .68072 L closepath p F P
0 g
s
.553 .806 .992 r
.50275 .98901 m .52369 .98543 L .52938 .98897 L p F P
0 g
s
.621 .779 .957 r
.52369 .98543 m .50275 .98901 L .49695 .98565 L p F P
0 g
s
.671 .752 .912 r
.64782 .19108 m .62624 .19814 L .63155 .20606 L p F P
0 g
s
.671 .752 .912 r
.63155 .20606 m .65303 .198 L .64782 .19108 L p F P
0 g
s
.325 .809 .873 r
.63534 .98178 m .63592 .98179 L .65743 .97713 L p F P
0 g
s
.36 .106 .387 r
.75239 .92613 m .75555 .92197 L .7527 .92333 L closepath p F P
0 g
s
.887 .737 .689 r
.26406 .82952 m .2713 .83463 L .26589 .84637 L p F P
0 g
s
.876 .746 .715 r
.2713 .83463 m .26406 .82952 L .27069 .81745 L p F P
0 g
s
.859 .614 .566 r
.57429 .46522 m .5641 .46016 L .56559 .45037 L p F P
0 g
s
.859 .587 .525 r
.5641 .46016 m .57429 .46522 L .57412 .4746 L p F P
0 g
s
0 .139 .64 r
.75943 .23678 m .76619 .24354 L .77366 .24966 L p F P
0 g
s
0 .167 .676 r
.78 .25652 m .77366 .24966 L .76619 .24354 L p F P
0 g
s
.871 .763 .74 r
.27178 .79972 m .27861 .80505 L .27069 .81745 L p F P
0 g
s
.857 .769 .764 r
.27394 .79681 m .27178 .79972 L .27861 .80505 L p F P
0 g
s
.362 .385 .751 r
.25533 .38958 m .25469 .39127 L p .24934 .37514 L F P
0 g
s
.393 .43 .78 r
.25533 .38958 m .25624 .39182 L .25469 .39127 L closepath p F P
0 g
s
.801 .561 .575 r
.55231 .44632 m .56559 .45037 L .5641 .46016 L p F P
0 g
s
.86 .502 .374 r
.31268 .93699 m .30318 .93288 L .30002 .9232 L p F P
0 g
s
.867 .506 .362 r
.29084 .91895 m .30002 .9232 L .30318 .93288 L p F P
0 g
s
.699 .741 .884 r
.6209 .19056 m .5995 .19938 L .60493 .20799 L p F P
0 g
s
.699 .741 .884 r
.60493 .20799 m .62624 .19814 L .6209 .19056 L p F P
0 g
s
.71 .686 .825 r
.60493 .20799 m .5995 .19938 L .57831 .21029 L p F P
0 g
s
.745 .969 .931 r
.31179 .22557 m .30712 .22864 L .31058 .22548 L closepath p F P
0 g
s
.689 .67 .826 r
.49824 .21371 m .49837 .21394 L .49892 .21367 L closepath p F P
0 g
s
.593 .783 .971 r
.48532 .68499 m .46958 .68321 L .45951 .68536 L p F P
0 g
s
.609 .74 .938 r
.46958 .68321 m .45951 .68536 L .45356 .67943 L p F P
0 g
s
.471 .512 .818 r
.28737 .42295 m .27275 .42072 L .27713 .40981 L p F P
0 g
s
.46 .516 .829 r
.28877 .42578 m .28737 .42295 L .27275 .42072 L p F P
0 g
s
.46 .516 .829 r
.28574 .43401 m .28877 .42578 L p .27275 .42072 L F P
0 g
s
.614 .754 .945 r
.67489 .19356 m .65303 .198 L .65822 .20523 L p F P
0 g
s
.614 .754 .945 r
.65822 .20523 m .67996 .19979 L .67489 .19356 L p F P
0 g
s
.31 .289 .674 r
.24639 .3398 m .24257 .34673 L .24486 .35652 L p F P
0 g
s
.689 .669 .825 r
.4926 .20377 m .49824 .21371 L .49892 .21367 L p F P
0 g
s
.689 .669 .825 r
.49892 .21367 m .51931 .20345 L p .4926 .20377 L F P
0 g
s
.689 .669 .825 r
.51931 .20345 m .49892 .21367 L .52422 .2122 L closepath p F P
0 g
s
.682 .647 .809 r
.52501 .21361 m .52422 .2122 L .49892 .21367 L p F P
0 g
s
.974 .801 .606 r
.8092 .34499 m .81022 .3413 L .80573 .33574 L p F P
0 g
s
.877 .838 .804 r
.7763 .41128 m .78691 .39832 L .78995 .40577 L p F P
0 g
s
.877 .838 .804 r
.77826 .41609 m .7763 .41128 L p .78995 .40577 L F P
0 g
s
.877 .838 .804 r
.78995 .40577 m .77989 .418 L .77826 .41609 L p F P
0 g
s
.569 .643 .884 r
.37034 .49329 m .37155 .49314 L .37111 .49439 L closepath p F P
0 g
s
.89 .714 .657 r
.26934 .86271 m .27081 .8587 L .26439 .8505 L p F P
0 g
s
.759 .777 .868 r
.37911 .70009 m .38612 .69558 L .39271 .70124 L p F P
0 g
s
.748 .776 .876 r
.39989 .68734 m .38612 .69558 L .39271 .70124 L p F P
0 g
s
.748 .776 .876 r
.39271 .70124 m .40604 .69328 L .39989 .68734 L p F P
0 g
s
.466 .391 .689 r
.78284 .84898 m .78273 .84851 L .78313 .84879 L closepath p F P
0 g
s
.506 .498 .782 r
.7774 .78161 m .76001 .77757 L .75893 .77479 L p F P
0 g
s
0 .512 .77 r
.41698 .98159 m .41503 .98123 L .4187 .98205 L closepath p F P
0 g
s
.561 .815 .993 r
.52938 .98897 m .55045 .98502 L .55604 .98844 L p F P
0 g
s
.625 .78 .956 r
.55045 .98502 m .52938 .98897 L .52369 .98543 L p F P
0 g
s
.708 .67 .811 r
.55167 .21231 m .55006 .21325 L .55227 .21344 L closepath p F P
0 g
s
.901 .668 .576 r
.26646 .87381 m .27441 .87856 L .27278 .88936 L p F P
0 g
s
.891 .687 .62 r
.26934 .86271 m .26646 .87381 L .27441 .87856 L p F P
0 g
s
.443 .35 .655 r
.78313 .84879 m .78284 .84898 L .7854 .86138 L p F P
0 g
s
.71 .726 .863 r
.59404 .19116 m .57277 .20101 L .57831 .21029 L p F P
0 g
s
.71 .726 .863 r
.57831 .21029 m .5995 .19938 L .59404 .19116 L p F P
0 g
s
.71 .671 .81 r
.57831 .21029 m .57277 .20101 L .55167 .21231 L p F P
0 g
s
.705 .661 .804 r
.55167 .21231 m .55006 .21325 L .52763 .21223 L p F P
0 g
s
.792 .815 .871 r
.71045 .47929 m .71686 .47458 L .71193 .46892 L p F P
0 g
s
.792 .815 .871 r
.71193 .46892 m .70795 .47186 L .71045 .47929 L p F P
0 g
s
.776 .809 .879 r
.69062 .48363 m .70795 .47186 L .71045 .47929 L p F P
0 g
s
.728 .528 .621 r
.53987 .42926 m .538 .43339 L .54059 .43359 L closepath p F P
0 g
s
.443 .35 .655 r
.7854 .86138 m .79137 .85737 L .78313 .84879 L p F P
0 g
s
.438 .35 .66 r
.79757 .83862 m .78313 .84879 L .79137 .85737 L p F P
0 g
s
.468 .391 .687 r
.78678 .83074 m .79757 .83862 L .78313 .84879 L p F P
0 g
s
.82 .787 .821 r
.31661 .74874 m .32022 .7453 L .31401 .73961 L p F P
0 g
s
.806 .788 .836 r
.33754 .73034 m .32022 .7453 L .31401 .73961 L p F P
0 g
s
.539 .602 .865 r
.34731 .46601 m .33183 .46689 L .33803 .47664 L p F P
0 g
s
.539 .602 .865 r
.33803 .47664 m .34309 .47641 L .34731 .46601 L p F P
0 g
s
.404 .845 .935 r
.63076 .98111 m .63534 .98178 L .65736 .97712 L p F P
0 g
s
.325 .809 .873 r
.65743 .97713 m .65736 .97712 L .63534 .98178 L p F P
0 g
s
.31 .797 .885 r
.63534 .98178 m .63076 .98111 L .60934 .98532 L p F P
0 g
s
.82 .787 .821 r
.31401 .73961 m .31012 .74332 L .31661 .74874 L p F P
0 g
s
.822 .787 .82 r
.31661 .74874 m .30518 .75976 L .29889 .75412 L p F P
0 g
s
.822 .787 .82 r
.29889 .75412 m .31012 .74332 L .31661 .74874 L p F P
0 g
s
.692 .764 .907 r
.44419 .6833 m .43283 .68814 L .42679 .68199 L p F P
0 g
s
.732 .767 .881 r
.40604 .69328 m .42679 .68199 L .43283 .68814 L p F P
0 g
s
.506 .498 .782 r
.75893 .77479 m .76768 .76696 L p .7774 .78161 L F P
0 g
s
.515 .523 .803 r
.75893 .77479 m .75468 .76476 L .76768 .76696 L closepath p F P
0 g
s
.544 .85 .998 r
.63076 .98111 m .60934 .98532 L .604 .98327 L p F P
0 g
s
.492 .846 .994 r
.58269 .98733 m .604 .98327 L .60934 .98532 L p F P
0 g
s
.696 .673 .824 r
.52422 .2122 m .52501 .21361 L .52763 .21223 L closepath p F P
0 g
s
.792 .343 .178 r
.3281 .95009 m .3214 .94762 L .32578 .94703 L closepath p F P
0 g
s
.544 .83 .998 r
.55604 .98844 m .57723 .9844 L .58269 .98733 L p F P
0 g
s
.617 .792 .966 r
.57723 .9844 m .55604 .98844 L .55045 .98502 L p F P
0 g
s
.714 .965 .939 r
.32695 .21277 m .33224 .2138 L .31179 .22557 L p F P
0 g
s
.714 .965 .939 r
.31179 .22557 m .31058 .22548 L .32695 .21277 L p F P
0 g
s
0 0 .048 r
.26637 .26532 m .26118 .272 L .25647 .28223 L p F P
0 g
s
.711 .711 .849 r
.56721 .19223 m .54604 .20249 L .55167 .21231 L p F P
0 g
s
.711 .711 .849 r
.55167 .21231 m .57277 .20101 L .56721 .19223 L p F P
0 g
s
.705 .661 .804 r
.52763 .21223 m .54604 .20249 L .55167 .21231 L p F P
0 g
s
.57 .638 .879 r
.3761 .4828 m .36418 .48427 L .37034 .49329 L p F P
0 g
s
.57 .638 .879 r
.37034 .49329 m .37155 .49314 L .3761 .4828 L p F P
0 g
s
.959 .624 .251 r
.80504 .30149 m .80017 .29429 L .7988 .28575 L p F P
0 g
s
.982 .709 .426 r
.80017 .29429 m .80504 .30149 L .80499 .31059 L p F P
0 g
s
.414 .717 .987 r
.48671 .68562 m .48532 .68499 L .48612 .68561 L closepath p F P
0 g
s
.594 .817 .985 r
.604 .98327 m .58269 .98733 L .57723 .9844 L p F P
0 g
s
.836 .786 .804 r
.29549 .77013 m .30518 .75976 L .29889 .75412 L p F P
0 g
s
.618 .419 .591 r
.49169 .44912 m .49219 .45505 L .49787 .44781 L closepath p F P
0 g
s
.803 .788 .839 r
.33177 .72429 m .33112 .72484 L .33754 .73034 L p F P
0 g
s
.803 .788 .839 r
.33754 .73034 m .33788 .73005 L .33177 .72429 L p F P
0 g
s
.806 .788 .836 r
.31401 .73961 m .33112 .72484 L .33754 .73034 L p F P
0 g
s
.789 .788 .851 r
.35835 .71429 m .33788 .73005 L .33177 .72429 L p F P
0 g
s
.302 .317 .71 r
.24934 .37514 m .24982 .37399 L .24561 .35974 L p F P
0 g
s
.362 .385 .751 r
.24982 .37399 m .25041 .37565 L .24934 .37514 L closepath p F P
0 g
s
.362 .385 .751 r
.24934 .37514 m .25041 .37565 L .25533 .38958 L p F P
0 g
s
.797 .816 .867 r
.73281 .46245 m .71686 .47458 L .71193 .46892 L p F P
0 g
s
.425 .45 .782 r
.25624 .39182 m .26725 .39529 L p .26 .37978 L F P
0 g
s
.425 .45 .782 r
.26 .37978 m .25533 .38958 L .25624 .39182 L p F P
0 g
s
.575 .626 .865 r
.69674 .71035 m .68409 .71127 L .67882 .7022 L p F P
0 g
s
.829 .413 .253 r
.3214 .94762 m .31792 .9462 L .31268 .93699 L p F P
0 g
s
.833 .409 .23 r
.30318 .93288 m .31268 .93699 L .31792 .9462 L p F P
0 g
s
.31 .289 .674 r
.24486 .35652 m .24649 .35802 L p .24639 .3398 L F P
0 g
s
.286 .272 .668 r
.24486 .35652 m .24649 .35802 L .24561 .35974 L closepath p F P
0 g
s
.697 .672 .822 r
.52763 .21223 m .54604 .20249 L p .51931 .20345 L F P
0 g
s
.697 .672 .822 r
.51931 .20345 m .52422 .2122 L .52763 .21223 L p F P
0 g
s
.678 .782 .929 r
.40027 .1899 m .3797 .19845 L .38602 .20436 L p F P
0 g
s
.678 .782 .929 r
.38602 .20436 m .40652 .19598 L .40027 .1899 L p F P
0 g
s
.483 .539 .838 r
.28877 .42578 m .29356 .43471 L .28574 .43401 L closepath p F P
0 g
s
.482 .541 .841 r
.28574 .43401 m .29356 .43471 L .29975 .44609 L p F P
0 g
s
.116 .627 .894 r
.41503 .98123 m .41698 .98159 L .41079 .97917 L p F P
0 g
s
.116 .627 .894 r
.41079 .97917 m .40226 .97816 L .41503 .98123 L p F P
0 g
s
.685 .197 0 r
.78249 .25982 m .78 .25652 L .77366 .24966 L p F P
0 g
s
.584 .654 .885 r
.39058 .49016 m .37155 .49314 L .3761 .4828 L p F P
0 g
s
.585 .661 .89 r
.3967 .49856 m .39058 .49016 L .37155 .49314 L p F P
0 g
s
.382 .398 .753 r
.25041 .37565 m .26 .37978 L .25533 .38958 L closepath p F P
0 g
s
.412 .153 .409 r
.49195 .47567 m .49263 .46896 L .47369 .47832 L p F P
0 g
s
.412 .153 .409 r
.48916 .47859 m .49195 .47567 L p .47369 .47832 L F P
0 g
s
.412 .153 .409 r
.47369 .47832 m .47252 .48652 L .48916 .47859 L p F P
0 g
s
.697 .762 .902 r
.63108 .50789 m .6428 .50272 L .63753 .49649 L p F P
0 g
s
.697 .762 .902 r
.63753 .49649 m .62712 .50094 L .63108 .50789 L p F P
0 g
s
.697 .758 .899 r
.61613 .50553 m .62712 .50094 L .63108 .50789 L p F P
0 g
s
.715 .837 .94 r
.42929 .50925 m .44998 .50149 L .45043 .50179 L p F P
0 g
s
.674 .777 .927 r
.44394 .49572 m .42324 .50219 L .42929 .50925 L p F P
0 g
s
.674 .777 .927 r
.42929 .50925 m .44998 .50149 L .44394 .49572 L p F P
0 g
s
.616 .712 .914 r
.42015 .50292 m .42324 .50219 L .42929 .50925 L p F P
0 g
s
.312 .051 .347 r
.75555 .92197 m .77116 .91432 L p .75155 .93215 L F P
0 g
s
.312 .051 .347 r
.75155 .93215 m .75239 .92613 L .75555 .92197 L p F P
0 g
s
.395 .177 .461 r
.75555 .92197 m .77116 .91432 L .77139 .90468 L p F P
0 g
s
.622 .441 .617 r
.51321 .43251 m .51177 .4338 L .51333 .43345 L closepath p F P
0 g
s
.618 .428 .603 r
.5145 .44405 m .49787 .44781 L .51177 .4338 L p F P
0 g
s
.618 .428 .603 r
.51177 .4338 m .51333 .43345 L .5145 .44405 L p F P
0 g
s
.674 .744 .903 r
.42718 .18773 m .40652 .19598 L .41267 .20323 L p F P
0 g
s
.674 .744 .903 r
.41267 .20323 m .43328 .19494 L .42718 .18773 L p F P
0 g
s
.254 0 .182 r
.73012 .94803 m .73135 .94438 L .74244 .93602 L p F P
0 g
s
.974 .801 .606 r
.80573 .33574 m .80521 .33764 L .8092 .34499 L p F P
0 g
s
.951 .812 .671 r
.80094 .34835 m .80496 .35567 L .8092 .34499 L p F P
0 g
s
.951 .812 .671 r
.8092 .34499 m .80521 .33764 L .80094 .34835 L p F P
0 g
s
.901 .698 .619 r
.26174 .85779 m .26934 .86271 L .26646 .87381 L p F P
0 g
s
.89 .714 .657 r
.26439 .8505 m .26174 .85779 L .26934 .86271 L p F P
0 g
s
.559 .584 .835 r
.71655 .72957 m .71525 .72957 L .71617 .7288 L closepath p F P
0 g
s
.572 .602 .844 r
.71132 .71973 m .71617 .7288 L .71525 .72957 L p F P
0 g
s
.349 .348 .717 r
.24649 .35802 m .24561 .35974 L .24982 .37399 L p F P
0 g
s
.57 0 0 r
.35894 .9657 m .35689 .96512 L .35802 .96519 L closepath p F P
0 g
s
.879 .473 .029 r
.7988 .28575 m .7935 .27863 L .79059 .2707 L p F P
0 g
s
.96 .623 .28 r
.7935 .27863 m .7988 .28575 L .80017 .29429 L p F P
0 g
s
.531 .711 .954 r
.68653 .19937 m .67996 .19979 L .68501 .20636 L p F P
0 g
s
.531 .711 .954 r
.68501 .20636 m .69627 .20525 L .68653 .19937 L p F P
0 g
s
.877 .838 .804 r
.77989 .418 m .7793 .41871 L .77826 .41609 L closepath p F P
0 g
s
.596 .658 .881 r
.66869 .69377 m .6518 .69612 L .64647 .68787 L p F P
0 g
s
.759 .54 .6 r
.55231 .44632 m .5422 .44464 L .54059 .43359 L p F P
0 g
s
.727 .519 .609 r
.538 .43339 m .54059 .43359 L .5422 .44464 L p F P
0 g
s
.836 .786 .804 r
.29889 .75412 m .28891 .7648 L .29549 .77013 L p F P
0 g
s
.835 .785 .804 r
.29549 .77013 m .29226 .77359 L .28591 .76801 L p F P
0 g
s
.835 .785 .804 r
.28591 .76801 m .28891 .7648 L .29549 .77013 L p F P
0 g
s
.852 .83 .825 r
.7635 .42499 m .76646 .4324 L .7793 .41871 L p F P
0 g
s
.852 .83 .825 r
.77524 .41242 m .7635 .42499 L p .7793 .41871 L F P
0 g
s
.852 .83 .825 r
.7793 .41871 m .77826 .41609 L .77524 .41242 L p F P
0 g
s
.489 .548 .843 r
.29975 .44609 m .30172 .44624 L .30097 .44829 L closepath p F P
0 g
s
.721 .26 .156 r
.48024 .6821 m .48532 .68499 L p .50016 .6915 L F P
0 g
s
.464 .789 .999 r
.48024 .6821 m .46958 .68321 L .48532 .68499 L closepath p F P
0 g
s
.699 .487 .597 r
.53392 .444 m .5145 .44405 L .51333 .43345 L p F P
0 g
s
.699 .487 .597 r
.51333 .43345 m .538 .43339 L .53392 .444 L p F P
0 g
s
.893 .484 .071 r
.78486 .26368 m .79059 .2707 L .7935 .27863 L p F P
0 g
s
.915 .829 .747 r
.79223 .37861 m .79579 .38597 L .8029 .37425 L p F P
0 g
s
.915 .829 .747 r
.8029 .37425 m .79934 .36687 L .79223 .37861 L p F P
0 g
s
.424 .279 .578 r
.78733 .87313 m .78032 .87724 L .7834 .88724 L p F P
0 g
s
.451 .328 .622 r
.78032 .87724 m .78733 .87313 L .7854 .86138 L p F P
0 g
s
.727 .519 .609 r
.5422 .44464 m .53392 .444 L .538 .43339 L p F P
0 g
s
.27 .611 .956 r
.60033 .49312 m .60624 .49952 L p .58651 .49256 L F P
0 g
s
.829 .375 0 r
.58373 .48992 m .58341 .48931 L .5846 .49056 L p F P
0 g
s
.829 .375 0 r
.5846 .49056 m .58651 .49256 L .58373 .48992 L p F P
0 g
s
.916 .582 .395 r
.58341 .48931 m .57592 .48338 L .57412 .4746 L p F P
0 g
s
.766 .263 0 r
.58373 .48992 m .58341 .48931 L .57592 .48338 L p F P
0 g
s
.766 .263 0 r
.57828 .48663 m .58373 .48992 L p .58362 .48983 L F P
0 g
s
.766 .263 0 r
.57592 .48338 m .57828 .48663 L p .58362 .48983 L F P
0 g
s
.859 .528 .425 r
.56386 .46956 m .57412 .4746 L .57592 .48338 L p F P
0 g
s
.859 .528 .425 r
.57592 .48338 m .56622 .47815 L .56386 .46956 L p F P
0 g
s
.522 0 0 r
.57828 .48663 m .57592 .48338 L .56622 .47815 L p F P
0 g
s
.522 0 0 r
.56622 .47815 m .57278 .48336 L .57828 .48663 L p F P
0 g
s
.422 .695 .977 r
.58384 .48168 m .57281 .48336 L p .57828 .48663 L F P
0 g
s
.422 .695 .977 r
.57281 .48336 m .57278 .48336 L .57828 .48663 L p F P
0 g
s
.303 .607 .953 r
.59322 .48705 m .57925 .48666 L p .58373 .48992 L F P
0 g
s
.303 .607 .953 r
.57925 .48666 m .57828 .48663 L .58373 .48992 L p F P
0 g
s
.27 .611 .956 r
.58651 .49256 m .58373 .48992 L .60033 .49312 L p F P
0 g
s
.753 .792 .884 r
.67979 .49063 m .66931 .49693 L .66416 .49093 L p F P
0 g
s
.739 .789 .892 r
.6428 .50272 m .66416 .49093 L .66931 .49693 L p F P
0 g
s
.85 .783 .785 r
.29226 .77359 m .28591 .76801 L .27485 .78133 L p F P
0 g
s
.85 .783 .785 r
.27485 .78133 m .28126 .78687 L .29226 .77359 L p F P
0 g
s
.399 .409 .754 r
.25041 .37565 m .26 .37978 L p .25536 .36326 L F P
0 g
s
.399 .409 .754 r
.25536 .36326 m .24982 .37399 L .25041 .37565 L p F P
0 g
s
.377 .104 .367 r
.74244 .93602 m .75155 .93215 L .75239 .92613 L closepath p F P
0 g
s
.349 .348 .717 r
.24982 .37399 m .25536 .36326 L .24649 .35802 L p F P
0 g
s
.724 .987 .887 r
.28859 .24077 m .30114 .22914 L p .31058 .22548 L F P
0 g
s
.541 .873 .604 r
.30114 .22914 m .28859 .24077 L .28364 .2446 L p F P
0 g
s
.548 .575 .834 r
.71655 .72957 m .73886 .73047 L p .73738 .74068 L F P
0 g
s
.538 .573 .838 r
.73362 .72015 m .73886 .73047 L .71655 .72957 L p F P
0 g
s
.538 .573 .838 r
.72498 .71973 m .73362 .72015 L p .71655 .72957 L F P
0 g
s
.538 .573 .838 r
.71655 .72957 m .71617 .7288 L .72498 .71973 L p F P
0 g
s
.474 .704 .97 r
.71208 .21068 m .70587 .21113 L .69627 .20525 L p F P
0 g
s
.606 .403 .581 r
.51533 .45431 m .5145 .44405 L .49787 .44781 L p F P
0 g
s
.606 .403 .581 r
.49249 .45939 m .51533 .45431 L p .49787 .44781 L F P
0 g
s
.606 .403 .581 r
.49787 .44781 m .49219 .45505 L .49249 .45939 L p F P
0 g
s
.693 .85 .958 r
.37398 .19437 m .3797 .19845 L .35926 .20742 L p F P
0 g
s
.693 .85 .958 r
.35926 .20742 m .35531 .20485 L .37398 .19437 L p F P
0 g
s
.301 0 0 r
.37987 .97312 m .37635 .97202 L .35894 .9657 L p F P
0 g
s
0 .429 .739 r
.35689 .96512 m .35894 .9657 L .37635 .97202 L p F P
0 g
s
.114 .644 .871 r
.44356 .98434 m .4375 .98111 L .41698 .98159 L p F P
0 g
s
.508 .772 .991 r
.4375 .98111 m .41698 .98159 L .41079 .97917 L p F P
0 g
s
.814 .822 .856 r
.73281 .46245 m .73804 .45809 L .73319 .45244 L p F P
0 g
s
.814 .822 .856 r
.73319 .45244 m .73009 .45504 L .73281 .46245 L p F P
0 g
s
.797 .816 .867 r
.71193 .46892 m .73009 .45504 L .73281 .46245 L p F P
0 g
s
.254 0 .182 r
.74244 .93602 m .75155 .93215 L p .73012 .94803 L F P
0 g
s
.676 .721 .883 r
.45405 .18661 m .43328 .19494 L .43929 .2032 L p F P
0 g
s
.676 .721 .883 r
.43929 .2032 m .46002 .1946 L .45405 .18661 L p F P
0 g
s
.553 .597 .852 r
.71617 .7288 m .71132 .71973 L .72498 .71973 L closepath p F P
0 g
s
.665 .749 .913 r
.61417 .67687 m .59281 .68284 L .58736 .67768 L p F P
0 g
s
.492 .542 .836 r
.30636 .43542 m .29356 .43471 L .29975 .44609 L p F P
0 g
s
.492 .542 .836 r
.29975 .44609 m .30172 .44624 L .30636 .43542 L p F P
0 g
s
.734 .774 .885 r
.42679 .68199 m .40604 .69328 L .39989 .68734 L p F P
0 g
s
.679 .978 .879 r
.32531 .21279 m .32695 .21277 L .31058 .22548 L p F P
0 g
s
.679 .978 .879 r
.31058 .22548 m .30461 .22647 L .32531 .21279 L p F P
0 g
s
.724 .987 .887 r
.30114 .22914 m .30461 .22647 L .31058 .22548 L p F P
0 g
s
.883 .756 .717 r
.26382 .81216 m .27069 .81745 L .26406 .82952 L p F P
0 g
s
.871 .763 .74 r
.27069 .81745 m .26382 .81216 L .27178 .79972 L p F P
0 g
s
.816 .822 .854 r
.75114 .44693 m .73804 .45809 L .73319 .45244 L p F P
0 g
s
.155 .533 .922 r
.74442 .22608 m .7415 .22531 L .73331 .21898 L p F P
0 g
s
.784 .788 .856 r
.35315 .70786 m .352 .70871 L .35835 .71429 L p F P
0 g
s
.784 .788 .856 r
.35835 .71429 m .35914 .7137 L .35315 .70786 L p F P
0 g
s
.789 .788 .851 r
.33177 .72429 m .352 .70871 L .35835 .71429 L p F P
0 g
s
.515 .524 .803 r
.76768 .76696 m .75468 .76476 L .75118 .75654 L p F P
0 g
s
.771 .787 .866 r
.37911 .70009 m .35914 .7137 L .35315 .70786 L p F P
0 g
s
.836 .826 .839 r
.75433 .43378 m .7635 .42499 L .76646 .4324 L p F P
0 g
s
.836 .826 .839 r
.76646 .4324 m .75908 .43944 L .75433 .43378 L p F P
0 g
s
.835 .827 .84 r
.75114 .44693 m .75908 .43944 L .75433 .43378 L p F P
0 g
s
.57 .71 .936 r
.61075 .49899 m .60624 .49952 L .61115 .5062 L p F P
0 g
s
.57 .71 .936 r
.61115 .5062 m .61613 .50553 L .61075 .49899 L p F P
0 g
s
.885 .573 .454 r
.28115 .90829 m .28363 .90592 L p .29084 .91895 L F P
0 g
s
.89 .587 .467 r
.28115 .90829 m .28076 .90444 L .28363 .90592 L closepath p F P
0 g
s
.835 .827 .84 r
.75433 .43378 m .74827 .43953 L .75114 .44693 L p F P
0 g
s
.816 .822 .854 r
.73319 .45244 m .74827 .43953 L .75114 .44693 L p F P
0 g
s
0 .429 .739 r
.35149 .96425 m .35689 .96512 L p .37635 .97202 L F P
0 g
s
.588 .015 0 r
.35149 .96425 m .34804 .96207 L .35689 .96512 L closepath p F P
0 g
s
.31 .289 .674 r
.24649 .35802 m .25335 .34569 L .24639 .3398 L p F P
0 g
s
.374 .355 .709 r
.25536 .36326 m .24649 .35802 L .25335 .34569 L p F P
0 g
s
.419 .306 .618 r
.79137 .85737 m .7854 .86138 L .78733 .87313 L p F P
0 g
s
.56 .624 .872 r
.35801 .47502 m .34309 .47641 L .34731 .46601 L p F P
0 g
s
.557 .63 .88 r
.36418 .48427 m .35801 .47502 L .34309 .47641 L p F P
0 g
s
.701 .174 0 r
.34804 .96207 m .33762 .95828 L .3281 .95009 L p F P
0 g
s
.674 .13 0 r
.3214 .94762 m .3281 .95009 L .33762 .95828 L p F P
0 g
s
.899 .724 .656 r
.26589 .84637 m .26439 .8505 L .25784 .84342 L p F P
0 g
s
.899 .724 .656 r
.25784 .84342 m .25861 .84129 L .26589 .84637 L p F P
0 g
s
.887 .737 .689 r
.26589 .84637 m .25861 .84129 L .26406 .82952 L p F P
0 g
s
.682 .71 .869 r
.48092 .18597 m .46002 .1946 L .46593 .20356 L p F P
0 g
s
.682 .71 .869 r
.46593 .20356 m .48679 .19443 L .48092 .18597 L p F P
0 g
s
.06 0 .414 r
.24619 .31306 m .25031 .30649 L .25049 .29697 L p F P
0 g
s
.182 .108 .531 r
.25031 .30649 m .24619 .31306 L .24903 .32043 L p F P
0 g
s
.693 .769 .91 r
.44757 .67355 m .43687 .67785 L .44419 .6833 L p F P
0 g
s
.693 .769 .91 r
.44419 .6833 m .45356 .67943 L .44757 .67355 L p F P
0 g
s
.692 .764 .907 r
.42679 .68199 m .43687 .67785 L .44419 .6833 L p F P
0 g
s
.757 .527 .583 r
.5422 .44464 m .55231 .44632 L .5502 .45632 L p F P
0 g
s
.801 .561 .575 r
.5641 .46016 m .5502 .45632 L .55231 .44632 L p F P
0 g
s
.522 .572 .847 r
.31939 .44634 m .30172 .44624 L .30636 .43542 L p F P
0 g
s
.516 .578 .856 r
.32331 .45318 m .31939 .44634 L .30172 .44624 L p F P
0 g
s
.516 .578 .856 r
.32177 .45706 m .32331 .45318 L p .30172 .44624 L F P
0 g
s
.165 .559 .931 r
.45993 .67849 m .47334 .6797 L p .46826 .67741 L F P
0 g
s
.165 .559 .931 r
.47334 .6797 m .47428 .67979 L .46826 .67741 L p F P
0 g
s
.165 .559 .931 r
.46826 .67741 m .45237 .67308 L .45993 .67849 L p F P
0 g
s
.099 .516 .907 r
.45237 .67308 m .46826 .67741 L .46518 .67513 L p F P
0 g
s
.889 .462 .117 r
.46826 .67741 m .46855 .67808 L .46726 .67695 L p F P
0 g
s
.889 .462 .117 r
.46726 .67695 m .46518 .67513 L .46826 .67741 L p F P
0 g
s
.837 .369 .057 r
.47428 .67979 m .46826 .67741 L p .46837 .67748 L F P
0 g
s
.327 .678 .978 r
.46958 .68321 m .48021 .6821 L p .47428 .67979 L F P
0 g
s
.327 .678 .978 r
.47428 .67979 m .45993 .67849 L .46958 .68321 L p F P
0 g
s
.837 .369 .057 r
.47647 .6834 m .47428 .67979 L p .46837 .67748 L F P
0 g
s
.327 .678 .978 r
.48021 .6821 m .48024 .6821 L .47428 .67979 L p F P
0 g
s
.609 .74 .938 r
.45356 .67943 m .45993 .67849 L .46958 .68321 L p F P
0 g
s
.863 .779 .766 r
.27394 .79681 m .28126 .78687 L .27485 .78133 L p F P
0 g
s
.766 .798 .879 r
.67979 .49063 m .69062 .48363 L .68555 .47766 L p F P
0 g
s
.766 .798 .879 r
.68555 .47766 m .67671 .48337 L .67979 .49063 L p F P
0 g
s
.753 .792 .884 r
.66416 .49093 m .67671 .48337 L .67979 .49063 L p F P
0 g
s
0 0 0 r
.70554 .96247 m .68391 .9697 L .67907 .9715 L p F P
0 g
s
0 0 0 r
.65743 .97713 m .67907 .9715 L .68391 .9697 L p F P
0 g
s
.08 0 0 r
.70638 .96164 m .70554 .96247 L .68391 .9697 L p F P
0 g
s
.615 .673 .883 r
.61957 .68402 m .64112 .67984 L .64647 .68787 L p F P
0 g
s
.621 .698 .9 r
.63575 .67208 m .64112 .67984 L .61957 .68402 L p F P
0 g
s
.621 .698 .9 r
.62378 .67466 m .63575 .67208 L p .61957 .68402 L F P
0 g
s
.621 .698 .9 r
.61957 .68402 m .61712 .68072 L .62378 .67466 L p F P
0 g
s
.965 .787 .612 r
.80111 .3291 m .80356 .32023 L .80801 .32749 L p F P
0 g
s
.965 .787 .612 r
.80801 .32749 m .80573 .33574 L .80111 .3291 L p F P
0 g
s
.611 .211 .26 r
.53802 .69329 m .51913 .69337 L .51275 .6901 L p F P
0 g
s
.613 .154 .139 r
.51913 .69337 m .51018 .69271 L .51275 .6901 L closepath p F P
0 g
s
.895 .839 .782 r
.79604 .3866 m .79567 .38614 L .79579 .38597 L closepath p F P
0 g
s
.855 .83 .822 r
.77826 .41609 m .77524 .41242 L .7763 .41128 L closepath p F P
0 g
s
.737 .781 .888 r
.66416 .49093 m .6428 .50272 L .63753 .49649 L p F P
0 g
s
.452 .385 .691 r
.79609 .82383 m .78678 .83074 L .79757 .83862 L p F P
0 g
s
.477 .418 .712 r
.79424 .81753 m .79609 .82383 L .78678 .83074 L p F P
0 g
s
.477 .418 .712 r
.78699 .81352 m .79424 .81753 L p .78678 .83074 L F P
0 g
s
.536 .785 .99 r
.44356 .98434 m .46429 .98153 L .47023 .98545 L p F P
0 g
s
.604 .774 .962 r
.46429 .98153 m .44356 .98434 L .4375 .98111 L p F P
0 g
s
.756 .287 0 r
.77868 .25675 m .77804 .25568 L .78249 .25982 L p F P
0 g
s
.756 .287 0 r
.78249 .25982 m .78486 .26368 L .77868 .25675 L p F P
0 g
s
.685 .197 0 r
.77366 .24966 m .77804 .25568 L .78249 .25982 L p F P
0 g
s
.515 .524 .803 r
.75118 .75654 m .75463 .75322 L p .76768 .76696 L F P
0 g
s
.525 .548 .821 r
.75118 .75654 m .74937 .75262 L .75463 .75322 L closepath p F P
0 g
s
.604 .671 .888 r
.41109 .48604 m .39058 .49016 L .3967 .49856 L p F P
0 g
s
.604 .671 .888 r
.3967 .49856 m .41717 .4944 L .41109 .48604 L p F P
0 g
s
.794 .53 .538 r
.5502 .45632 m .5641 .46016 L .56386 .46956 L p F P
0 g
s
.859 .587 .525 r
.57412 .4746 m .56386 .46956 L .5641 .46016 L p F P
0 g
s
.355 .146 .452 r
.78297 .89819 m .77139 .90468 L .77116 .91432 L p F P
0 g
s
.399 .224 .525 r
.77139 .90468 m .78297 .89819 L .7834 .88724 L p F P
0 g
s
.69 .709 .862 r
.5078 .18541 m .48679 .19443 L .4926 .20377 L p F P
0 g
s
.69 .709 .862 r
.4926 .20377 m .51358 .19404 L .5078 .18541 L p F P
0 g
s
.689 .669 .825 r
.51931 .20345 m .51358 .19404 L .4926 .20377 L p F P
0 g
s
.89 .826 .779 r
.79106 .38023 m .79223 .37861 L .79579 .38597 L p F P
0 g
s
.89 .826 .779 r
.79579 .38597 m .79567 .38614 L .79106 .38023 L p F P
0 g
s
0 0 .048 r
.25647 .28223 m .26412 .27241 L .26637 .26532 L p F P
0 g
s
.025 0 .295 r
.26412 .27241 m .25647 .28223 L .25468 .29134 L p F P
0 g
s
0 0 .28 r
.25049 .29697 m .25468 .29134 L .25647 .28223 L p F P
0 g
s
0 .367 .819 r
.74453 .22358 m .73971 .22091 L .74442 .22608 L p F P
0 g
s
0 .367 .819 r
.74442 .22608 m .75221 .23012 L .74453 .22358 L p F P
0 g
s
.155 .533 .922 r
.73331 .21898 m .73971 .22091 L .74442 .22608 L p F P
0 g
s
.892 .828 .777 r
.78691 .39832 m .79567 .38614 L .79106 .38023 L p F P
0 g
s
.149 .027 .446 r
.25468 .29134 m .25049 .29697 L .25031 .30649 L p F P
0 g
s
.899 .592 .456 r
.28076 .90444 m .28115 .90829 L .27593 .91136 L p F P
0 g
s
.899 .592 .456 r
.27246 .89986 m .28076 .90444 L p .27593 .91136 L F P
0 g
s
.898 .631 .525 r
.28076 .90444 m .27246 .89986 L .27278 .88936 L p F P
0 g
s
.899 .724 .657 r
.26174 .85779 m .26439 .8505 L .25784 .84342 L p F P
0 g
s
.391 0 .039 r
.56096 .68878 m .55787 .68932 L .53947 .69052 L p F P
0 g
s
.451 .052 .191 r
.55787 .68932 m .53802 .69329 L .53947 .69052 L closepath p F P
0 g
s
.543 .599 .86 r
.3456 .45552 m .3256 .45692 L .33183 .46689 L p F P
0 g
s
.543 .599 .86 r
.34938 .46178 m .3456 .45552 L p .33183 .46689 L F P
0 g
s
.543 .599 .86 r
.33183 .46689 m .34731 .46601 L .34938 .46178 L p F P
0 g
s
.531 .598 .866 r
.32177 .45706 m .3256 .45692 L .33183 .46689 L p F P
0 g
s
.693 .756 .9 r
.62712 .50094 m .61613 .50553 L .61075 .49899 L p F P
0 g
s
.757 .527 .583 r
.5502 .45632 m .54338 .45523 L .5422 .44464 L p F P
0 g
s
.726 .505 .591 r
.53392 .444 m .5422 .44464 L .54338 .45523 L p F P
0 g
s
.907 .639 .521 r
.26481 .88463 m .27278 .88936 L .27246 .89986 L p F P
0 g
s
.901 .668 .576 r
.27278 .88936 m .26481 .88463 L .26646 .87381 L p F P
0 g
s
.303 .62 .959 r
.71572 .20659 m .70718 .20491 L .71208 .21068 L p F P
0 g
s
.303 .62 .959 r
.71208 .21068 m .72471 .21274 L .71572 .20659 L p F P
0 g
s
.474 .704 .97 r
.69627 .20525 m .70718 .20491 L .71208 .21068 L p F P
0 g
s
.929 .816 .712 r
.7953 .35957 m .79934 .36687 L .80496 .35567 L p F P
0 g
s
.929 .816 .712 r
.80496 .35567 m .80094 .34835 L .7953 .35957 L p F P
0 g
s
.6 .375 .547 r
.51556 .46392 m .51533 .45431 L .49249 .45939 L p F P
0 g
s
.6 .375 .547 r
.49249 .45939 m .49263 .46896 L .51556 .46392 L p F P
0 g
s
.867 .506 .362 r
.30318 .93288 m .29401 .92864 L .29084 .91895 L p F P
0 g
s
.876 .509 .349 r
.282 .91458 m .29084 .91895 L .29401 .92864 L p F P
0 g
s
.885 .573 .454 r
.29084 .91895 m .282 .91458 L .28115 .90829 L p F P
0 g
s
.695 .946 .959 r
.34594 .20131 m .3527 .20338 L .33224 .2138 L p F P
0 g
s
.695 .946 .959 r
.33631 .20655 m .34594 .20131 L p .33224 .2138 L F P
0 g
s
.695 .946 .959 r
.33224 .2138 m .32695 .21277 L .33631 .20655 L p F P
0 g
s
.774 .8 .874 r
.70795 .47186 m .69062 .48363 L .68555 .47766 L p F P
0 g
s
.762 .786 .873 r
.38026 .68964 m .37284 .69442 L .37911 .70009 L p F P
0 g
s
.762 .786 .873 r
.37911 .70009 m .38612 .69558 L .38026 .68964 L p F P
0 g
s
.771 .787 .866 r
.35315 .70786 m .37284 .69442 L .37911 .70009 L p F P
0 g
s
.697 .714 .862 r
.53471 .18475 m .51358 .19404 L .51931 .20345 L p F P
0 g
s
.697 .714 .862 r
.51931 .20345 m .54039 .19329 L .53471 .18475 L p F P
0 g
s
.697 .672 .822 r
.54604 .20249 m .54039 .19329 L .51931 .20345 L p F P
0 g
s
.241 .696 .952 r
.40226 .97816 m .41079 .97917 L .40457 .976 L p F P
0 g
s
.241 .696 .952 r
.40457 .976 m .38915 .97514 L .40226 .97816 L p F P
0 g
s
.145 0 0 r
.38424 .97454 m .38915 .97514 L .40226 .97816 L p F P
0 g
s
0 .109 .598 r
.75221 .23012 m .75943 .23678 L .76683 .24291 L p F P
0 g
s
0 .139 .64 r
.77366 .24966 m .76683 .24291 L .75943 .23678 L p F P
0 g
s
.863 .779 .766 r
.27485 .78133 m .26726 .79162 L .27394 .79681 L p F P
0 g
s
.863 .779 .768 r
.27394 .79681 m .27178 .79972 L .26531 .79423 L p F P
0 g
s
.863 .779 .768 r
.26531 .79423 m .26726 .79162 L .27394 .79681 L p F P
0 g
s
.303 .607 .953 r
.58373 .48992 m .60033 .49312 L .59322 .48705 L p F P
0 g
s
.683 .75 .902 r
.61553 .18341 m .59404 .19116 L .5995 .19938 L p F P
0 g
s
.683 .75 .902 r
.5995 .19938 m .6209 .19056 L .61553 .18341 L p F P
0 g
s
.7 .724 .868 r
.56162 .18402 m .54039 .19329 L .54604 .20249 L p F P
0 g
s
.7 .724 .868 r
.54604 .20249 m .56721 .19223 L .56162 .18402 L p F P
0 g
s
.575 .626 .865 r
.67882 .7022 m .70082 .70068 L p .69674 .71035 L F P
0 g
s
.568 .63 .873 r
.70082 .70068 m .67882 .7022 L .67353 .69324 L p F P
0 g
s
.524 .549 .823 r
.75463 .75322 m .74937 .75262 L .74411 .74126 L p F P
0 g
s
.697 .737 .882 r
.58856 .18343 m .56721 .19223 L .57277 .20101 L p F P
0 g
s
.697 .737 .882 r
.57277 .20101 m .59404 .19116 L .58856 .18343 L p F P
0 g
s
.597 .784 .97 r
.47023 .98545 m .49112 .98121 L .49695 .98565 L p F P
0 g
s
.643 .761 .935 r
.49112 .98121 m .47023 .98545 L .46429 .98153 L p F P
0 g
s
.571 .631 .873 r
.37828 .47238 m .35801 .47502 L .36418 .48427 L p F P
0 g
s
.571 .631 .873 r
.38008 .47515 m .37828 .47238 L p .36418 .48427 L F P
0 g
s
.571 .631 .873 r
.36418 .48427 m .3761 .4828 L .38008 .47515 L p F P
0 g
s
.532 .556 .824 r
.74411 .74126 m .73738 .74068 L .74185 .73644 L closepath p F P
0 g
s
.548 .575 .834 r
.73886 .73047 m .74185 .73644 L .73738 .74068 L p F P
0 g
s
.65 .761 .93 r
.64259 .18458 m .6209 .19056 L .62624 .19814 L p F P
0 g
s
.65 .761 .93 r
.62624 .19814 m .64782 .19108 L .64259 .18458 L p F P
0 g
s
.697 .474 .581 r
.53101 .45426 m .51533 .45431 L .5145 .44405 L p F P
0 g
s
.697 .474 .581 r
.5145 .44405 m .53392 .444 L .53101 .45426 L p F P
0 g
s
.982 .709 .426 r
.80499 .31059 m .80011 .3034 L .80017 .29429 L p F P
0 g
s
.974 .751 .539 r
.80011 .3034 m .80499 .31059 L .80356 .32023 L p F P
0 g
s
.626 .87 .988 r
.57639 .68128 m .58678 .67736 L .58736 .67768 L closepath p F P
0 g
s
.02 0 0 r
.57639 .68128 m .58678 .67736 L p .56096 .68878 L F P
0 g
s
.726 .505 .591 r
.54338 .45523 m .53101 .45426 L .53392 .444 L p F P
0 g
s
.895 .748 .691 r
.25716 .82426 m .26406 .82952 L .25861 .84129 L p F P
0 g
s
.883 .756 .717 r
.26406 .82952 m .25716 .82426 L .26382 .81216 L p F P
0 g
s
.877 .774 .744 r
.27178 .79972 m .26531 .79423 L .25731 .80671 L p F P
0 g
s
.877 .774 .744 r
.25731 .80671 m .26382 .81216 L .27178 .79972 L p F P
0 g
s
.254 0 .182 r
.75155 .93215 m .7493 .93996 L .73012 .94803 L p F P
0 g
s
.162 0 0 r
.7272 .95321 m .73012 .94803 L .7493 .93996 L p F P
0 g
s
.163 0 0 r
.73012 .94803 m .7272 .95321 L p .70638 .96164 L F P
0 g
s
.91 .677 .574 r
.25883 .86892 m .26646 .87381 L .26481 .88463 L p F P
0 g
s
.901 .698 .619 r
.26646 .87381 m .25883 .86892 L .26174 .85779 L p F P
0 g
s
.274 .218 .611 r
.25292 .32885 m .24639 .3398 L p .24903 .32043 L F P
0 g
s
.318 .287 .666 r
.25292 .32885 m .24639 .3398 L .25335 .34569 L p F P
0 g
s
.571 .73 .95 r
.45993 .67849 m .45356 .67943 L .44757 .67355 L p F P
0 g
s
.506 .551 .836 r
.29356 .43471 m .30636 .43542 L p .28997 .42324 L F P
0 g
s
.506 .551 .836 r
.28997 .42324 m .28877 .42578 L .29356 .43471 L p F P
0 g
s
.617 .697 .901 r
.42133 .4998 m .42324 .50219 L .42015 .50292 L closepath p F P
0 g
s
.552 .599 .855 r
.72498 .71973 m .71132 .71973 L .70607 .71004 L p F P
0 g
s
.75 .784 .881 r
.39989 .68734 m .38612 .69558 L .38026 .68964 L p F P
0 g
s
.626 .709 .905 r
.61712 .68072 m .61417 .67687 L .62378 .67466 L closepath p F P
0 g
s
0 0 .105 r
.27437 .25661 m .26637 .26532 L .26412 .27241 L p F P
0 g
s
.563 .608 .856 r
.70607 .71004 m .69674 .71035 L .70286 .7042 L closepath p F P
0 g
s
.575 .626 .865 r
.70082 .70068 m .70286 .7042 L .69674 .71035 L p F P
0 g
s
.833 .409 .23 r
.31792 .9462 m .30848 .94208 L .30318 .93288 L p F P
0 g
s
.837 .404 .205 r
.29401 .92864 m .30318 .93288 L .30848 .94208 L p F P
0 g
s
.621 .779 .957 r
.49695 .98565 m .51796 .98069 L .52369 .98543 L p F P
0 g
s
.657 .75 .919 r
.51796 .98069 m .49695 .98565 L .49112 .98121 L p F P
0 g
s
.583 .758 .961 r
.66443 .18845 m .64782 .19108 L .65303 .198 L p F P
0 g
s
.583 .758 .961 r
.67331 .19173 m .66443 .18845 L p .65303 .198 L F P
0 g
s
.583 .758 .961 r
.65303 .198 m .67489 .19356 L .67331 .19173 L p F P
0 g
s
.674 .13 0 r
.31901 .94754 m .3214 .94762 L p .33762 .95828 L F P
0 g
s
.786 .313 .112 r
.31901 .94754 m .31792 .9462 L .3214 .94762 L closepath p F P
0 g
s
.398 .849 .905 r
.65736 .97712 m .65743 .97713 L .67907 .9715 L p F P
0 g
s
.596 .658 .881 r
.64647 .68787 m .66823 .6848 L p .66869 .69377 L F P
0 g
s
.596 .664 .887 r
.66823 .6848 m .64647 .68787 L .64112 .67984 L p F P
0 g
s
.69 .767 .91 r
.43687 .67785 m .42679 .68199 L .4207 .67602 L p F P
0 g
s
.734 .774 .885 r
.39989 .68734 m .4207 .67602 L .42679 .68199 L p F P
0 g
s
.459 .87 .952 r
.65234 .97623 m .65736 .97712 L .67851 .97148 L p F P
0 g
s
.398 .849 .905 r
.67907 .9715 m .67851 .97148 L .65736 .97712 L p F P
0 g
s
.404 .845 .935 r
.65736 .97712 m .65234 .97623 L .63076 .98111 L p F P
0 g
s
.074 .606 .865 r
.38915 .97514 m .37987 .97312 L .38424 .97454 L closepath p F P
0 g
s
.892 .828 .777 r
.79106 .38023 m .78336 .39098 L .78691 .39832 L p F P
0 g
s
.872 .824 .798 r
.77276 .40396 m .7763 .41128 L .78691 .39832 L p F P
0 g
s
.872 .824 .798 r
.78691 .39832 m .78336 .39098 L .77276 .40396 L p F P
0 g
s
.824 .797 .826 r
.31012 .74332 m .31401 .73961 L .30827 .73371 L p F P
0 g
s
.81 .798 .841 r
.33112 .72484 m .31401 .73961 L .30827 .73371 L p F P
0 g
s
.388 .253 .573 r
.79696 .86671 m .78733 .87313 L .7886 .88421 L p F P
0 g
s
.419 .306 .618 r
.78733 .87313 m .79696 .86671 L .79137 .85737 L p F P
0 g
s
.424 .279 .578 r
.7834 .88724 m .7886 .88421 L .78733 .87313 L p F P
0 g
s
.824 .797 .826 r
.30827 .73371 m .30355 .73821 L .31012 .74332 L p F P
0 g
s
.825 .797 .825 r
.31012 .74332 m .29889 .75412 L .29303 .7483 L p F P
0 g
s
.825 .797 .825 r
.29303 .7483 m .30355 .73821 L .31012 .74332 L p F P
0 g
s
.96 .623 .28 r
.80017 .29429 m .79486 .28718 L .7935 .27863 L p F P
0 g
s
.975 .699 .442 r
.79486 .28718 m .80017 .29429 L .80011 .3034 L p F P
0 g
s
.421 .697 .978 r
.70718 .20491 m .69627 .20525 L .68653 .19937 L p F P
0 g
s
.519 0 0 r
.34804 .96207 m .35149 .96425 L .34494 .96245 L p F P
0 g
s
.519 0 0 r
.34494 .96245 m .33762 .95828 L .34804 .96207 L p F P
0 g
s
.625 .78 .956 r
.52369 .98543 m .54482 .98028 L .55045 .98502 L p F P
0 g
s
.658 .746 .915 r
.54482 .98028 m .52369 .98543 L .51796 .98069 L p F P
0 g
s
.894 .581 .446 r
.282 .91458 m .27593 .91136 L .28115 .90829 L closepath p F P
0 g
s
.712 .217 0 r
.76683 .24291 m .77366 .24966 L .77804 .25568 L p F P
0 g
s
.463 .415 .719 r
.79424 .81753 m .78699 .81352 L .79194 .80965 L closepath p F P
0 g
s
.483 .45 .745 r
.78848 .79912 m .78385 .79714 L p .78699 .81352 L F P
0 g
s
.483 .45 .745 r
.78699 .81352 m .79194 .80965 L .78848 .79912 L p F P
0 g
s
.84 .796 .808 r
.28891 .7648 m .29889 .75412 L .29303 .7483 L p F P
0 g
s
.711 .845 .946 r
.45134 .50085 m .45043 .50179 L .44998 .50149 L closepath p F P
0 g
s
0 0 0 r
.45043 .50179 m .45134 .50085 L p .47252 .48652 L F P
0 g
s
.965 .786 .611 r
.80521 .33764 m .80573 .33574 L .80111 .3291 L p F P
0 g
s
.694 .87 .965 r
.37324 .19391 m .37398 .19437 L .35531 .20485 L p F P
0 g
s
.694 .87 .965 r
.35531 .20485 m .3527 .20338 L .37324 .19391 L p F P
0 g
s
.248 0 .209 r
.76993 .92323 m .75155 .93215 L .7493 .93996 L p F P
0 g
s
.312 .051 .347 r
.7701 .92304 m .76993 .92323 L .75155 .93215 L p F P
0 g
s
.312 .051 .347 r
.77116 .91432 m .7701 .92304 L p .75155 .93215 L F P
0 g
s
.807 .798 .844 r
.32619 .71831 m .32463 .71962 L .33112 .72484 L p F P
0 g
s
.807 .798 .844 r
.33112 .72484 m .33177 .72429 L .32619 .71831 L p F P
0 g
s
.81 .798 .841 r
.30827 .73371 m .32463 .71962 L .33112 .72484 L p F P
0 g
s
.635 .703 .896 r
.42324 .50219 m .44394 .49572 L p .42861 .49135 L F P
0 g
s
.635 .703 .896 r
.42861 .49135 m .42133 .4998 L .42324 .50219 L p F P
0 g
s
.792 .797 .857 r
.352 .70871 m .33177 .72429 L .32619 .71831 L p F P
0 g
s
.532 .594 .862 r
.32331 .45318 m .3256 .45692 L .32177 .45706 L closepath p F P
0 g
s
.789 .806 .866 r
.70795 .47186 m .71193 .46892 L .70695 .46294 L p F P
0 g
s
.789 .806 .866 r
.70695 .46294 m .70472 .46459 L .70795 .47186 L p F P
0 g
s
.774 .8 .874 r
.68555 .47766 m .70472 .46459 L .70795 .47186 L p F P
0 g
s
.91 .709 .618 r
.25446 .85274 m .26174 .85779 L .25883 .86892 L p F P
0 g
s
.899 .724 .657 r
.25784 .84342 m .25446 .85274 L .26174 .85779 L p F P
0 g
s
.617 .792 .966 r
.55045 .98502 m .5717 .98 L .57723 .9844 L p F P
0 g
s
.651 .752 .923 r
.5717 .98 m .55045 .98502 L .54482 .98028 L p F P
0 g
s
.049 0 0 r
.70554 .96247 m .71563 .95831 L .70638 .96164 L closepath p F P
0 g
s
.163 0 0 r
.7272 .95321 m .71563 .95831 L .70638 .96164 L p F P
0 g
s
.104 0 0 r
.48916 .47859 m .47252 .48652 L .47092 .48883 L closepath p F P
0 g
s
0 0 0 r
.47092 .48883 m .47252 .48652 L p .45874 .49584 L F P
0 g
s
0 0 0 r
.47092 .48883 m .46551 .48832 L p .48904 .4784 L F P
0 g
s
0 0 0 r
.49163 .4773 m .48916 .47859 L .47092 .48883 L p F P
0 g
s
.351 .074 .345 r
.49195 .47567 m .48916 .47859 L .49163 .4773 L closepath p F P
0 g
s
0 0 0 r
.49163 .4773 m .47092 .48883 L .48904 .4784 L F
.45134 .50085 m .47092 .48883 L p .45874 .49584 L F P
0 g
s
.893 .484 .071 r
.7935 .27863 m .78775 .27162 L .78486 .26368 L p F P
0 g
s
.958 .619 .306 r
.78775 .27162 m .7935 .27863 L .79486 .28718 L p F P
0 g
s
.902 .491 .11 r
.77868 .25675 m .78486 .26368 L .78775 .27162 L p F P
0 g
s
.389 .216 .522 r
.7886 .88421 m .7834 .88724 L .78297 .89819 L p F P
0 g
s
.709 .862 .955 r
.44998 .50149 m .44394 .49572 L p .46551 .48832 L F P
0 g
s
.709 .862 .955 r
.46551 .48832 m .45134 .50085 L .44998 .50149 L p F P
0 g
s
.565 .851 .997 r
.65234 .97623 m .63076 .98111 L .62548 .97859 L p F P
0 g
s
.544 .85 .998 r
.604 .98327 m .62548 .97859 L .63076 .98111 L p F P
0 g
s
.794 .806 .862 r
.73009 .45504 m .71193 .46892 L .70695 .46294 L p F P
0 g
s
.056 .49 .89 r
.73971 .22091 m .73331 .21898 L .72471 .21274 L p F P
0 g
s
.594 .817 .985 r
.57723 .9844 m .59859 .9796 L .604 .98327 L p F P
0 g
s
.637 .77 .943 r
.59859 .9796 m .57723 .9844 L .5717 .98 L p F P
0 g
s
.965 .786 .611 r
.80111 .3291 m .80075 .3304 L .80521 .33764 L p F P
0 g
s
.942 .798 .672 r
.79646 .34113 m .80094 .34835 L .80521 .33764 L p F P
0 g
s
.942 .798 .672 r
.80521 .33764 m .80075 .3304 L .79646 .34113 L p F P
0 g
s
.411 .303 .621 r
.80221 .8498 m .79137 .85737 L .79696 .86671 L p F P
0 g
s
.438 .35 .66 r
.80048 .84175 m .79757 .83862 L p .79137 .85737 L F P
0 g
s
.438 .35 .66 r
.79137 .85737 m .80221 .8498 L .80048 .84175 L p F P
0 g
s
.674 .785 .933 r
.42099 .1817 m .40027 .1899 L .40652 .19598 L p F P
0 g
s
.674 .785 .933 r
.40652 .19598 m .42718 .18773 L .42099 .1817 L p F P
0 g
s
.693 .756 .9 r
.61075 .49899 m .62225 .49422 L .62712 .50094 L p F P
0 g
s
.695 .759 .901 r
.62712 .50094 m .63753 .49649 L .63222 .49 L p F P
0 g
s
.695 .759 .901 r
.63222 .49 m .62225 .49422 L .62712 .50094 L p F P
0 g
s
.84 .796 .808 r
.29303 .7483 m .28225 .7598 L .28891 .7648 L p F P
0 g
s
.839 .795 .809 r
.28891 .7648 m .28591 .76801 L .27995 .76225 L p F P
0 g
s
.839 .795 .809 r
.27995 .76225 m .28225 .7598 L .28891 .7648 L p F P
0 g
s
.754 .5 .549 r
.54338 .45523 m .5502 .45632 L .54961 .46584 L p F P
0 g
s
.794 .53 .538 r
.56386 .46956 m .54961 .46584 L .5502 .45632 L p F P
0 g
s
.721 .969 .933 r
.47092 .48883 m .45134 .50085 L .46551 .48832 L closepath p F P
0 g
s
.613 .804 .973 r
.62548 .97859 m .604 .98327 L .59859 .9796 L p F P
0 g
s
.515 .524 .803 r
.75463 .75322 m .77214 .75643 L p .76768 .76696 L F P
0 g
s
.501 .519 .808 r
.75463 .75322 m .77214 .75643 L .76683 .74435 L p F P
0 g
s
.501 .519 .808 r
.76683 .74435 m .76375 .74374 L .75463 .75322 L p F P
0 g
s
.524 .549 .823 r
.74411 .74126 m .76375 .74374 L .75463 .75322 L p F P
0 g
s
.586 .64 .871 r
.67353 .69324 m .66869 .69377 L .67197 .69066 L closepath p F P
0 g
s
.596 .658 .881 r
.66823 .6848 m .67197 .69066 L .66869 .69377 L p F P
0 g
s
.675 .755 .911 r
.448 .17968 m .42718 .18773 L .43328 .19494 L p F P
0 g
s
.675 .755 .911 r
.43328 .19494 m .45405 .18661 L .448 .17968 L p F P
0 g
s
.721 .26 .156 r
.50016 .6915 m .48645 .68803 L .48024 .6821 L p F P
0 g
s
.681 .134 0 r
.48645 .68803 m .48024 .6821 L .47428 .67979 L p F P
0 g
s
.855 .793 .789 r
.28591 .76801 m .27995 .76225 L .26882 .77563 L p F P
0 g
s
.855 .793 .789 r
.26882 .77563 m .27485 .78133 L .28591 .76801 L p F P
0 g
s
.774 .282 .051 r
.31792 .9462 m .31901 .94754 L .31226 .94649 L p F P
0 g
s
.774 .282 .051 r
.31226 .94649 m .30848 .94208 L .31792 .9462 L p F P
0 g
s
.908 .816 .745 r
.78818 .37134 m .79223 .37861 L .79934 .36687 L p F P
0 g
s
.908 .816 .745 r
.79934 .36687 m .7953 .35957 L .78818 .37134 L p F P
0 g
s
.504 .706 .961 r
.67658 .19351 m .67489 .19356 L .67996 .19979 L p F P
0 g
s
.504 .706 .961 r
.67996 .19979 m .68653 .19937 L .67658 .19351 L p F P
0 g
s
.752 .785 .88 r
.67671 .48337 m .66416 .49093 L .65896 .48466 L p F P
0 g
s
.737 .781 .888 r
.63753 .49649 m .65896 .48466 L .66416 .49093 L p F P
0 g
s
.85 .819 .818 r
.77052 .40637 m .77276 .40396 L .7763 .41128 L p F P
0 g
s
.85 .819 .818 r
.7763 .41128 m .77524 .41242 L .77052 .40637 L p F P
0 g
s
.68 .837 .959 r
.39399 .18521 m .40027 .1899 L .3797 .19845 L p F P
0 g
s
.68 .837 .959 r
.3797 .19845 m .37398 .19437 L .39399 .18521 L p F P
0 g
s
.852 .821 .818 r
.7635 .42499 m .77524 .41242 L .77052 .40637 L p F P
0 g
s
.735 .781 .89 r
.41455 .6702 m .39368 .6816 L .39989 .68734 L p F P
0 g
s
.735 .781 .89 r
.39989 .68734 m .4207 .67602 L .41455 .6702 L p F P
0 g
s
.75 .784 .881 r
.38026 .68964 m .39368 .6816 L .39989 .68734 L p F P
0 g
s
.679 .399 .491 r
.51913 .69337 m .53802 .69329 L .53709 .70235 L p F P
0 g
s
.679 .399 .491 r
.53709 .70235 m .52252 .70239 L .51913 .69337 L p F P
0 g
s
.712 .417 .476 r
.51018 .69271 m .51913 .69337 L .52252 .70239 L p F P
0 g
s
.571 .73 .95 r
.44757 .67355 m .45237 .67308 L .45993 .67849 L p F P
0 g
s
.89 .767 .72 r
.26382 .81216 m .25731 .80671 L .2506 .81885 L p F P
0 g
s
.89 .767 .72 r
.2506 .81885 m .25716 .82426 L .26382 .81216 L p F P
0 g
s
.575 .308 .475 r
.53709 .70235 m .53802 .69329 L .55787 .68932 L p F P
0 g
s
.479 .518 .82 r
.28737 .42295 m .28997 .42324 L .28877 .42578 L closepath p F P
0 g
s
.518 .548 .826 r
.76375 .74374 m .74411 .74126 L .74185 .73644 L p F P
0 g
s
.474 .444 .745 r
.78848 .79912 m .78385 .79714 L .78697 .79454 L closepath p F P
0 g
s
.493 .478 .769 r
.78293 .78343 m .7774 .78161 L p .78385 .79714 L F P
0 g
s
.493 .478 .769 r
.78385 .79714 m .78697 .79454 L .78293 .78343 L p F P
0 g
s
.678 .738 .896 r
.47499 .17846 m .45405 .18661 L .46002 .1946 L p F P
0 g
s
.678 .738 .896 r
.46002 .1946 m .48092 .18597 L .47499 .17846 L p F P
0 g
s
.787 .797 .861 r
.34778 .70176 m .34559 .70338 L .352 .70871 L p F P
0 g
s
.787 .797 .861 r
.352 .70871 m .35315 .70786 L .34778 .70176 L p F P
0 g
s
.792 .797 .857 r
.32619 .71831 m .34559 .70338 L .352 .70871 L p F P
0 g
s
.665 .749 .913 r
.58736 .67768 m .60876 .67059 L .61417 .67687 L p F P
0 g
s
.628 .871 .988 r
.58678 .67736 m .58736 .67768 L .60876 .67059 L p F P
0 g
s
.773 .796 .871 r
.37284 .69442 m .35315 .70786 L .34778 .70176 L p F P
0 g
s
.754 .5 .549 r
.54961 .46584 m .54381 .46497 L .54338 .45523 L p F P
0 g
s
.724 .478 .554 r
.53101 .45426 m .54338 .45523 L .54381 .46497 L p F P
0 g
s
.629 .694 .891 r
.41717 .4944 m .42861 .49135 L .42133 .4998 L closepath p F P
0 g
s
.149 .027 .446 r
.25031 .30649 m .25559 .29943 L .25468 .29134 L p F P
0 g
s
.252 .159 .551 r
.25559 .29943 m .25031 .30649 L .25112 .31712 L p F P
0 g
s
.182 .108 .531 r
.24903 .32043 m .25112 .31712 L .25031 .30649 L p F P
0 g
s
.811 .811 .851 r
.73009 .45504 m .73319 .45244 L .72829 .44645 L p F P
0 g
s
.811 .811 .851 r
.72829 .44645 m .72671 .44778 L .73009 .45504 L p F P
0 g
s
.794 .806 .862 r
.70695 .46294 m .72671 .44778 L .73009 .45504 L p F P
0 g
s
.168 .661 .918 r
.38915 .97514 m .40457 .976 L p .37788 .97238 L F P
0 g
s
.168 .661 .918 r
.37788 .97238 m .37987 .97312 L .38915 .97514 L p F P
0 g
s
.57 .71 .937 r
.61075 .49899 m .60624 .49952 L .60033 .49312 L p F P
0 g
s
.712 .417 .476 r
.52252 .70239 m .50882 .70144 L .51018 .69271 L p F P
0 g
s
.739 .439 .473 r
.50016 .6915 m .51018 .69271 L .50882 .70144 L p F P
0 g
s
.69 .767 .91 r
.4207 .67602 m .43034 .67209 L .43687 .67785 L p F P
0 g
s
.688 .768 .912 r
.44153 .66763 m .43034 .67209 L .43687 .67785 L p F P
0 g
s
.688 .768 .912 r
.43687 .67785 m .44757 .67355 L .44153 .66763 L p F P
0 g
s
.814 .812 .848 r
.74827 .43953 m .73319 .45244 L .72829 .44645 L p F P
0 g
s
.623 .734 .926 r
.62378 .67466 m .61417 .67687 L .60876 .67059 L p F P
0 g
s
.552 .604 .859 r
.3256 .45692 m .3456 .45552 L p .32704 .4461 L F P
0 g
s
.552 .604 .859 r
.32704 .4461 m .32331 .45318 L .3256 .45692 L p F P
0 g
s
.907 .735 .656 r
.25861 .84129 m .25784 .84342 L .25115 .83752 L p F P
0 g
s
.907 .735 .656 r
.25115 .83752 m .25168 .83606 L .25861 .84129 L p F P
0 g
s
.895 .748 .691 r
.25861 .84129 m .25168 .83606 L .25716 .82426 L p F P
0 g
s
.506 .498 .782 r
.76768 .76696 m .7775 .76941 L p .7774 .78161 L F P
0 g
s
.494 .5 .792 r
.7775 .76941 m .76768 .76696 L .77406 .76082 L closepath p F P
0 g
s
.515 .524 .803 r
.77214 .75643 m .77406 .76082 L .76768 .76696 L p F P
0 g
s
.025 0 .295 r
.25468 .29134 m .26294 .28078 L .26412 .27241 L p F P
0 g
s
.168 .04 .45 r
.26294 .28078 m .25468 .29134 L .25559 .29943 L p F P
0 g
s
.674 .13 0 r
.33762 .95828 m .32747 .95439 L .31901 .94754 L p F P
0 g
s
.676 .133 0 r
.32747 .95439 m .31901 .94754 L .31226 .94649 L p F P
0 g
s
0 0 0 r
.71563 .95831 m .70554 .96247 L .70084 .96482 L p F P
0 g
s
0 0 0 r
.67907 .9715 m .70084 .96482 L .70554 .96247 L p F P
0 g
s
.482 .512 .813 r
.29616 .41165 m .28123 .41033 L .28737 .42295 L p F P
0 g
s
.482 .512 .813 r
.28737 .42295 m .28997 .42324 L .29616 .41165 L p F P
0 g
s
.471 .512 .818 r
.27713 .40981 m .28123 .41033 L .28737 .42295 L p F P
0 g
s
.425 .45 .782 r
.26725 .39529 m .2711 .38755 L p .26 .37978 L F P
0 g
s
.451 .478 .796 r
.2711 .38755 m .27513 .39683 L .26725 .39529 L closepath p F P
0 g
s
.451 .478 .796 r
.27901 .40573 m .27713 .40981 L p .26725 .39529 L F P
0 g
s
.451 .478 .796 r
.26725 .39529 m .27513 .39683 L .27901 .40573 L p F P
0 g
s
.852 .821 .818 r
.77052 .40637 m .75997 .4177 L .7635 .42499 L p F P
0 g
s
.832 .816 .834 r
.74951 .42776 m .75997 .4177 L .7635 .42499 L p F P
0 g
s
.832 .816 .834 r
.7635 .42499 m .75433 .43378 L .74951 .42776 L p F P
0 g
s
.784 .463 .445 r
.54961 .46584 m .56386 .46956 L .56622 .47815 L p F P
0 g
s
0 .429 .739 r
.37635 .97202 m .3655 .96837 L .35149 .96425 L p F P
0 g
s
.213 0 0 r
.3655 .96837 m .35149 .96425 L .34494 .96245 L p F P
0 g
s
.484 .472 .769 r
.78293 .78343 m .7774 .78161 L .78107 .77834 L closepath p F P
0 g
s
.506 .498 .782 r
.7775 .76941 m .78107 .77834 L .7774 .78161 L p F P
0 g
s
.508 .772 .991 r
.41079 .97917 m .43141 .9771 L .4375 .98111 L p F P
0 g
s
.578 .771 .971 r
.43141 .9771 m .41079 .97917 L .40457 .976 L p F P
0 g
s
.602 .662 .881 r
.40497 .47733 m .38444 .48148 L .39058 .49016 L p F P
0 g
s
.602 .662 .881 r
.39058 .49016 m .41109 .48604 L .40497 .47733 L p F P
0 g
s
.584 .654 .885 r
.3761 .4828 m .38444 .48148 L .39058 .49016 L p F P
0 g
s
.683 .732 .887 r
.50198 .17763 m .48092 .18597 L .48679 .19443 L p F P
0 g
s
.683 .732 .887 r
.48679 .19443 m .5078 .18541 L .50198 .17763 L p F P
0 g
s
.832 .816 .835 r
.74827 .43953 m .75433 .43378 L .74951 .42776 L p F P
0 g
s
.472 .511 .817 r
.27901 .40573 m .28123 .41033 L .27713 .40981 L closepath p F P
0 g
s
.832 .816 .835 r
.74951 .42776 m .7448 .43225 L .74827 .43953 L p F P
0 g
s
.814 .812 .848 r
.72829 .44645 m .7448 .43225 L .74827 .43953 L p F P
0 g
s
.638 .965 .885 r
.58197 .67782 m .60193 .66609 L .58678 .67736 L closepath p F P
0 g
s
.217 0 .079 r
.58197 .67782 m .60193 .66609 L p .59448 .67115 L F P
0 g
s
.02 0 0 r
.58678 .67736 m .58197 .67782 L p .56353 .68764 L F P
0 g
s
.217 0 .079 r
.5806 .68059 m .58197 .67782 L p .59448 .67115 L F P
0 g
s
.02 0 0 r
.56096 .68878 m .56353 .68764 L .58197 .67782 L F
.628 .871 .988 r
.60333 .66548 m .60193 .66609 L .58678 .67736 L p F P
0 g
s
.628 .871 .988 r
.60876 .67059 m .60333 .66548 L p .58678 .67736 L F P
0 g
s
.691 .448 .55 r
.53013 .46387 m .51556 .46392 L .51533 .45431 L p F P
0 g
s
.691 .448 .55 r
.51533 .45431 m .53101 .45426 L .53013 .46387 L p F P
0 g
s
.724 .478 .554 r
.54381 .46497 m .53013 .46387 L .53101 .45426 L p F P
0 g
s
.869 .79 .77 r
.26726 .79162 m .27485 .78133 L .26882 .77563 L p F P
0 g
s
.271 .217 .612 r
.25112 .31712 m .25228 .3246 L .24903 .32043 L closepath p F P
0 g
s
.274 .218 .611 r
.24903 .32043 m .25228 .3246 L .25292 .32885 L p F P
0 g
s
.399 .409 .754 r
.26 .37978 m .26472 .37095 L p .25536 .36326 L F P
0 g
s
.428 .441 .771 r
.26472 .37095 m .2691 .38234 L .26 .37978 L closepath p F P
0 g
s
.425 .45 .782 r
.2711 .38755 m .2691 .38234 L .26 .37978 L p F P
0 g
s
.547 .282 .465 r
.51454 .47214 m .51556 .46392 L .49263 .46896 L p F P
0 g
s
.547 .282 .465 r
.4947 .47669 m .51454 .47214 L p .49263 .46896 L F P
0 g
s
.547 .282 .465 r
.49263 .46896 m .49195 .47567 L .4947 .47669 L p F P
0 g
s
.568 .63 .873 r
.67353 .69324 m .69557 .69183 L .70082 .70068 L p F P
0 g
s
.565 .63 .875 r
.69029 .68311 m .69557 .69183 L .67353 .69324 L p F P
0 g
s
.565 .63 .875 r
.67724 .68392 m .69029 .68311 L p .67353 .69324 L F P
0 g
s
.565 .63 .875 r
.67353 .69324 m .67197 .69066 L .67724 .68392 L p F P
0 g
s
.907 .735 .657 r
.25446 .85274 m .25784 .84342 L .25115 .83752 L p F P
0 g
s
.974 .751 .539 r
.80356 .32023 m .79866 .31306 L .80011 .3034 L p F P
0 g
s
.956 .773 .616 r
.80111 .3291 m .80356 .32023 L .79866 .31306 L p F P
0 g
s
.518 .548 .826 r
.74185 .73644 m .74663 .73107 L p .76375 .74374 L F P
0 g
s
.528 .57 .842 r
.74185 .73644 m .73886 .73047 L .74663 .73107 L closepath p F P
0 g
s
.573 .626 .866 r
.3721 .46271 m .3518 .46555 L .35801 .47502 L p F P
0 g
s
.573 .626 .866 r
.35801 .47502 m .37828 .47238 L .3721 .46271 L p F P
0 g
s
.56 .624 .872 r
.34731 .46601 m .3518 .46555 L .35801 .47502 L p F P
0 g
s
.552 .599 .855 r
.70607 .71004 m .72838 .71017 L p .72498 .71973 L F P
0 g
s
.542 .598 .859 r
.72316 .70076 m .72838 .71017 L .70607 .71004 L p F P
0 g
s
.542 .598 .859 r
.70577 .70053 m .72316 .70076 L p .70607 .71004 L F P
0 g
s
.542 .598 .859 r
.70607 .71004 m .70286 .7042 L .70577 .70053 L p F P
0 g
s
.688 .733 .885 r
.52898 .17697 m .5078 .18541 L .51358 .19404 L p F P
0 g
s
.688 .733 .885 r
.51358 .19404 m .53471 .18475 L .52898 .17697 L p F P
0 g
s
.899 .592 .456 r
.27593 .91136 m .27354 .91005 L .27246 .89986 L p F P
0 g
s
.909 .599 .448 r
.26447 .89515 m .27246 .89986 L .27354 .91005 L p F P
0 g
s
.907 .639 .521 r
.27246 .89986 m .26447 .89515 L .26481 .88463 L p F P
0 g
s
.763 .789 .874 r
.67671 .48337 m .68555 .47766 L .68043 .47138 L p F P
0 g
s
.763 .789 .874 r
.68043 .47138 m .67278 .47633 L .67671 .48337 L p F P
0 g
s
.752 .785 .88 r
.65896 .48466 m .67278 .47633 L .67671 .48337 L p F P
0 g
s
.739 .439 .473 r
.50882 .70144 m .50299 .70068 L .50016 .6915 L p F P
0 g
s
.78 .478 .475 r
.48645 .68803 m .50016 .6915 L .50299 .70068 L p F P
0 g
s
.676 .909 .976 r
.36661 .19131 m .34594 .20131 L .3527 .20338 L p F P
0 g
s
.676 .909 .976 r
.3527 .20338 m .37324 .19391 L .36661 .19131 L p F P
0 g
s
.876 .509 .349 r
.29401 .92864 m .28515 .92428 L .282 .91458 L p F P
0 g
s
.883 .51 .331 r
.27593 .91136 m .282 .91458 L .28515 .92428 L p F P
0 g
s
.736 .773 .883 r
.65896 .48466 m .63753 .49649 L .63222 .49 L p F P
0 g
s
.688 .741 .891 r
.556 .17645 m .53471 .18475 L .54039 .19329 L p F P
0 g
s
.688 .741 .891 r
.54039 .19329 m .56162 .18402 L .556 .17645 L p F P
0 g
s
0 .077 .551 r
.74453 .22358 m .75221 .23012 L .75954 .23627 L p F P
0 g
s
0 .109 .598 r
.76683 .24291 m .75954 .23627 L .75221 .23012 L p F P
0 g
s
.916 .648 .517 r
.25716 .87976 m .26481 .88463 L .26447 .89515 L p F P
0 g
s
.91 .677 .574 r
.26481 .88463 m .25716 .87976 L .25883 .86892 L p F P
0 g
s
.533 .58 .848 r
.31939 .44634 m .32704 .4461 L .32331 .45318 L closepath p F P
0 g
s
.292 .041 .351 r
.7701 .92304 m .77867 .91015 L .77116 .91432 L closepath p F P
0 g
s
.355 .146 .452 r
.77116 .91432 m .77867 .91015 L .78297 .89819 L p F P
0 g
s
.584 .648 .879 r
.38008 .47515 m .38444 .48148 L .3761 .4828 L closepath p F P
0 g
s
.682 .751 .904 r
.58305 .17627 m .56162 .18402 L .56721 .19223 L p F P
0 g
s
.682 .751 .904 r
.56721 .19223 m .58856 .18343 L .58305 .17627 L p F P
0 g
s
.514 .546 .827 r
.30695 .42384 m .28997 .42324 L .29616 .41165 L p F P
0 g
s
.506 .551 .836 r
.3096 .42897 m .30695 .42384 L .28997 .42324 L p F P
0 g
s
.506 .551 .836 r
.30636 .43542 m .3096 .42897 L p .28997 .42324 L F P
0 g
s
.884 .814 .775 r
.78637 .37385 m .78818 .37134 L .79223 .37861 L p F P
0 g
s
.884 .814 .775 r
.79223 .37861 m .79106 .38023 L .78637 .37385 L p F P
0 g
s
.541 .873 .604 r
.28364 .2446 m .28376 .24449 L .30114 .22914 L p F P
0 g
s
0 0 0 r
.28376 .24449 m .28364 .2446 L .28359 .24467 L closepath p F P
0 g
s
.693 .757 .901 r
.61075 .49899 m .62225 .49422 L .61638 .48777 L p F P
0 g
s
.693 .757 .901 r
.61638 .48777 m .60533 .49242 L .61075 .49899 L p F P
0 g
s
.57 .71 .937 r
.60033 .49312 m .60533 .49242 L .61075 .49899 L p F P
0 g
s
.604 .774 .962 r
.4375 .98111 m .45832 .97676 L .46429 .98153 L p F P
0 g
s
.645 .76 .932 r
.45832 .97676 m .4375 .98111 L .43141 .9771 L p F P
0 g
s
.482 .827 .545 r
.28376 .24449 m .29902 .23088 L .30371 .22686 L p F P
0 g
s
.482 .827 .545 r
.30371 .22686 m .30114 .22914 L .28376 .24449 L p F P
0 g
s
0 0 0 r
.29902 .23088 m .28376 .24449 L .28359 .24467 L p F P
0 g
s
0 0 0 r
.28359 .24467 m .28033 .25037 L p .29902 .23088 L F P
0 g
s
0 0 0 r
.28359 .24467 m .27437 .25661 L .28033 .25037 L closepath p F P
0 g
s
.663 .763 .924 r
.61014 .17678 m .58856 .18343 L .59404 .19116 L p F P
0 g
s
.663 .763 .924 r
.59404 .19116 m .61553 .18341 L .61014 .17678 L p F P
0 g
s
.349 .187 .515 r
.79976 .87684 m .7886 .88421 L .78918 .89461 L p F P
0 g
s
.389 .216 .522 r
.78297 .89819 m .78918 .89461 L .7886 .88421 L p F P
0 g
s
.388 .253 .573 r
.7886 .88421 m .79976 .87684 L .79696 .86671 L p F P
0 g
s
.886 .815 .773 r
.78336 .39098 m .79106 .38023 L .78637 .37385 L p F P
0 g
s
.578 .65 .884 r
.67197 .69066 m .66823 .6848 L .67724 .68392 L closepath p F P
0 g
s
.764 .795 .878 r
.37515 .68341 m .3665 .68899 L .37284 .69442 L p F P
0 g
s
.764 .795 .878 r
.37284 .69442 m .38026 .68964 L .37515 .68341 L p F P
0 g
s
.773 .796 .871 r
.34778 .70176 m .3665 .68899 L .37284 .69442 L p F P
0 g
s
.374 .355 .709 r
.25966 .35571 m .25536 .36326 L p .25335 .34569 L F P
0 g
s
.402 .401 .743 r
.25966 .35571 m .26319 .36633 L .25536 .36326 L closepath p F P
0 g
s
.399 .409 .754 r
.26472 .37095 m .26319 .36633 L .25536 .36326 L p F P
0 g
s
.921 .802 .711 r
.79079 .35238 m .7953 .35957 L .80094 .34835 L p F P
0 g
s
.921 .802 .711 r
.80094 .34835 m .79646 .34113 L .79079 .35238 L p F P
0 g
s
.447 .405 .719 r
.79194 .80965 m .79839 .80388 L p .79963 .82085 L F P
0 g
s
.447 .405 .719 r
.79963 .82085 m .79424 .81753 L .79194 .80965 L p F P
0 g
s
.458 .435 .745 r
.79194 .80965 m .78848 .79912 L .79839 .80388 L closepath p F P
0 g
s
.839 .399 .179 r
.28515 .92428 m .29401 .92864 L .29935 .93784 L p F P
0 g
s
.837 .404 .205 r
.30848 .94208 m .29935 .93784 L .29401 .92864 L p F P
0 g
s
.596 .664 .887 r
.64112 .67984 m .66292 .67668 L .66823 .6848 L p F P
0 g
s
.597 .672 .892 r
.66292 .67668 m .64112 .67984 L .63575 .67208 L p F P
0 g
s
.645 .959 .776 r
.30461 .22647 m .30114 .22914 L .30371 .22686 L closepath p F P
0 g
s
.437 .687 .97 r
.67658 .19351 m .68653 .19937 L .70227 .19958 L p F P
0 g
s
.421 .697 .978 r
.68653 .19937 m .70227 .19958 L .70718 .20491 L p F P
0 g
s
.869 .79 .77 r
.26882 .77563 m .26048 .78688 L .26726 .79162 L p F P
0 g
s
.868 .79 .771 r
.26726 .79162 m .26531 .79423 L .25921 .78858 L p F P
0 g
s
.868 .79 .771 r
.25921 .78858 m .26048 .78688 L .26726 .79162 L p F P
0 g
s
.458 .435 .744 r
.79839 .80388 m .78848 .79912 L .78697 .79454 L p F P
0 g
s
.772 .791 .869 r
.70472 .46459 m .68555 .47766 L .68043 .47138 L p F P
0 g
s
0 0 0 r
.72617 .95437 m .71563 .95831 L p .70084 .96482 L F P
0 g
s
.075 0 0 r
.71563 .95831 m .72617 .95437 L .7272 .95321 L closepath p F P
0 g
s
.975 .699 .442 r
.80011 .3034 m .79478 .29631 L .79486 .28718 L p F P
0 g
s
.965 .739 .546 r
.79478 .29631 m .80011 .3034 L .79866 .31306 L p F P
0 g
s
.441 0 0 r
.33762 .95828 m .34494 .96245 L .33837 .95999 L p F P
0 g
s
.441 0 0 r
.33837 .95999 m .32747 .95439 L .33762 .95828 L p F P
0 g
s
.458 .435 .744 r
.78697 .79454 m .79419 .78766 L p .79839 .80388 L F P
0 g
s
.47 .463 .769 r
.78697 .79454 m .78293 .78343 L .79419 .78766 L closepath p F P
0 g
s
0 .497 .797 r
.37788 .97238 m .37635 .97202 L .37987 .97312 L closepath p F P
0 g
s
.622 .77 .951 r
.63733 .17858 m .61553 .18341 L .6209 .19056 L p F P
0 g
s
.622 .77 .951 r
.6209 .19056 m .64259 .18458 L .63733 .17858 L p F P
0 g
s
.919 .687 .572 r
.25153 .86389 m .25883 .86892 L .25716 .87976 L p F P
0 g
s
.91 .709 .618 r
.25883 .86892 m .25153 .86389 L .25446 .85274 L p F P
0 g
s
.902 .759 .693 r
.25716 .82426 m .2506 .81885 L .24509 .83068 L p F P
0 g
s
.902 .759 .693 r
.24509 .83068 m .25168 .83606 L .25716 .82426 L p F P
0 g
s
.574 .93 .76 r
.32031 .21426 m .32531 .21279 L .30461 .22647 L p F P
0 g
s
.574 .93 .76 r
.30461 .22647 m .30371 .22686 L .32031 .21426 L p F P
0 g
s
.446 .406 .72 r
.79609 .82383 m .79424 .81753 L .79963 .82085 L closepath p F P
0 g
s
.643 .761 .935 r
.46429 .98153 m .48525 .97581 L .49112 .98121 L p F P
0 g
s
.672 .742 .903 r
.48525 .97581 m .46429 .98153 L .45832 .97676 L p F P
0 g
s
.884 .784 .747 r
.26531 .79423 m .25921 .78858 L .25115 .8011 L p F P
0 g
s
.884 .784 .747 r
.25115 .8011 m .25731 .80671 L .26531 .79423 L p F P
0 g
s
0 .321 .774 r
.7364 .21714 m .73501 .21632 L .73971 .22091 L p F P
0 g
s
0 .321 .774 r
.73971 .22091 m .74453 .22358 L .7364 .21714 L p F P
0 g
s
.056 .49 .89 r
.72471 .21274 m .73501 .21632 L .73971 .22091 L p F P
0 g
s
.54 .718 .955 r
.45237 .67308 m .44757 .67355 L .44153 .66763 L p F P
0 g
s
.536 .58 .846 r
.73362 .72015 m .72498 .71973 L .7303 .71369 L closepath p F P
0 g
s
.552 .599 .855 r
.72838 .71017 m .7303 .71369 L .72498 .71973 L p F P
0 g
s
.422 .366 .69 r
.79963 .82085 m .79609 .82383 L .7995 .8372 L p F P
0 g
s
.452 .385 .691 r
.79757 .83862 m .7995 .8372 L .79609 .82383 L p F P
0 g
s
.497 .525 .815 r
.28123 .41033 m .29616 .41165 L p .28337 .39808 L F P
0 g
s
.497 .525 .815 r
.28337 .39808 m .27901 .40573 L .28123 .41033 L p F P
0 g
s
.527 .573 .844 r
.74663 .73107 m .73886 .73047 L .73362 .72015 L p F P
0 g
s
.248 .601 .952 r
.70633 .20054 m .70227 .19958 L .70718 .20491 L p F P
0 g
s
.248 .601 .952 r
.70718 .20491 m .71572 .20659 L .70633 .20054 L p F P
0 g
s
.342 .134 .445 r
.78918 .89461 m .78297 .89819 L .77867 .91015 L p F P
0 g
s
.427 .342 .658 r
.80048 .84175 m .79757 .83862 L .7995 .8372 L closepath p F P
0 g
s
.793 .32 0 r
.77804 .25568 m .77868 .25675 L .77678 .2548 L closepath p F P
0 g
s
.712 .217 0 r
.77804 .25568 m .77678 .2548 L p .76683 .24291 L F P
0 g
s
.746 .247 0 r
.75954 .23627 m .76683 .24291 L .7719 .24998 L p F P
0 g
s
.712 .217 0 r
.77678 .2548 m .7719 .24998 L .76683 .24291 L p F P
0 g
s
.752 .792 .885 r
.39368 .6816 m .38026 .68964 L .37515 .68341 L p F P
0 g
s
.621 .699 .901 r
.63575 .67208 m .62378 .67466 L .63206 .66705 L closepath p F P
0 g
s
.623 .734 .926 r
.63036 .66481 m .63206 .66705 L .62378 .67466 L p F P
0 g
s
.623 .734 .926 r
.60876 .67059 m .63036 .66481 L p .62378 .67466 L F P
0 g
s
.657 .75 .919 r
.49112 .98121 m .51219 .97487 L .51796 .98069 L p F P
0 g
s
.68 .727 .885 r
.51219 .97487 m .49112 .98121 L .48525 .97581 L p F P
0 g
s
.69 .77 .913 r
.42469 .66601 m .41455 .6702 L .4207 .67602 L p F P
0 g
s
.69 .77 .913 r
.4207 .67602 m .43034 .67209 L .42469 .66601 L p F P
0 g
s
.252 .159 .551 r
.25112 .31712 m .25904 .30658 L .25559 .29943 L p F P
0 g
s
.326 .257 .624 r
.25904 .30658 m .25112 .31712 L .25228 .3246 L p F P
0 g
s
.629 .693 .891 r
.43183 .48088 m .41109 .48604 L .41717 .4944 L p F P
0 g
s
.629 .693 .891 r
.43458 .48452 m .43183 .48088 L p .41717 .4944 L F P
0 g
s
.629 .693 .891 r
.41717 .4944 m .42861 .49135 L .43458 .48452 L p F P
0 g
s
0 0 .105 r
.26412 .27241 m .26894 .26717 L .27437 .25661 L p F P
0 g
s
.12 0 .334 r
.26894 .26717 m .26412 .27241 L .26294 .28078 L p F P
0 g
s
.56 .62 .868 r
.34938 .46178 m .3518 .46555 L .34731 .46601 L closepath p F P
0 g
s
.47 .463 .769 r
.79419 .78766 m .78293 .78343 L .78107 .77834 L p F P
0 g
s
.66 .965 .922 r
.33631 .20655 m .32695 .21277 L .32531 .21279 L closepath p F P
0 g
s
.061 .491 .892 r
.71572 .20659 m .72471 .21274 L .73501 .21632 L p F P
0 g
s
.958 .619 .306 r
.79486 .28718 m .78909 .28018 L .78775 .27162 L p F P
0 g
s
.967 .689 .455 r
.78909 .28018 m .79486 .28718 L .79478 .29631 L p F P
0 g
s
.575 .308 .475 r
.55787 .68932 m .5607 .6906 L p .53709 .70235 L F P
0 g
s
.577 .29 .444 r
.5607 .6906 m .55787 .68932 L .56096 .68878 L closepath p F P
0 g
s
.557 .62 .87 r
.70286 .7042 m .70082 .70068 L .70577 .70053 L closepath p F P
0 g
s
.738 .42 .443 r
.54381 .46497 m .54961 .46584 L .55262 .47419 L p F P
0 g
s
.784 .463 .445 r
.56622 .47815 m .55262 .47419 L .54961 .46584 L p F P
0 g
s
.436 .872 .904 r
.67851 .97148 m .67907 .9715 L .70084 .96482 L p F P
0 g
s
.559 .737 .959 r
.65183 .1835 m .64259 .18458 L .64782 .19108 L p F P
0 g
s
.559 .737 .959 r
.64782 .19108 m .66443 .18845 L .65183 .1835 L p F P
0 g
s
.658 .746 .915 r
.51796 .98069 m .53914 .97433 L .54482 .98028 L p F P
0 g
s
.677 .718 .88 r
.53914 .97433 m .51796 .98069 L .51219 .97487 L p F P
0 g
s
.828 .808 .831 r
.30355 .73821 m .30827 .73371 L .30302 .72761 L p F P
0 g
s
.813 .808 .846 r
.32463 .71962 m .30827 .73371 L .30302 .72761 L p F P
0 g
s
.077 .585 .888 r
.37635 .97202 m .37788 .97238 L .37149 .96946 L p F P
0 g
s
.077 .585 .888 r
.37149 .96946 m .3655 .96837 L .37635 .97202 L p F P
0 g
s
.47 .463 .769 r
.78107 .77834 m .78708 .77219 L p .79419 .78766 L F P
0 g
s
.481 .491 .791 r
.78107 .77834 m .7775 .76941 L .78708 .77219 L closepath p F P
0 g
s
.828 .808 .831 r
.30302 .72761 m .2969 .73341 L .30355 .73821 L p F P
0 g
s
.829 .807 .83 r
.30355 .73821 m .29303 .7483 L .28761 .74229 L p F P
0 g
s
.829 .807 .83 r
.28761 .74229 m .2969 .73341 L .30355 .73821 L p F P
0 g
s
.886 .815 .773 r
.78637 .37385 m .7793 .38374 L .78336 .39098 L p F P
0 g
s
.867 .812 .794 r
.76868 .39676 m .77276 .40396 L .78336 .39098 L p F P
0 g
s
.867 .812 .794 r
.78336 .39098 m .7793 .38374 L .76868 .39676 L p F P
0 g
s
.534 .573 .84 r
.33314 .43441 m .31317 .43535 L .31939 .44634 L p F P
0 g
s
.534 .573 .84 r
.33359 .43524 m .33314 .43441 L p .31939 .44634 L F P
0 g
s
.534 .573 .84 r
.31939 .44634 m .32704 .4461 L .33359 .43524 L p F P
0 g
s
.522 .572 .847 r
.30636 .43542 m .31317 .43535 L .31939 .44634 L p F P
0 g
s
.919 .719 .617 r
.2475 .84753 m .25446 .85274 L .25153 .86389 L p F P
0 g
s
.907 .735 .657 r
.25115 .83752 m .2475 .84753 L .25446 .85274 L p F P
0 g
s
.422 .695 .977 r
.57828 .48663 m .59322 .48705 L .58384 .48168 L p F P
0 g
s
.91 .503 .151 r
.78155 .2647 m .77868 .25675 L .77678 .2548 L p F P
0 g
s
.902 .491 .11 r
.78775 .27162 m .78155 .2647 L .77868 .25675 L p F P
0 g
s
.469 .489 .796 r
.27513 .39683 m .28337 .39808 L .27901 .40573 L closepath p F P
0 g
s
.758 .249 0 r
.30848 .94208 m .31226 .94649 L .3055 .94464 L p F P
0 g
s
.758 .249 0 r
.3055 .94464 m .29935 .93784 L .30848 .94208 L p F P
0 g
s
.953 .615 .328 r
.78155 .2647 m .78775 .27162 L .78909 .28018 L p F P
0 g
s
.405 .144 .4 r
.5607 .6906 m .56348 .68765 L .56096 .68878 L closepath p F P
0 g
s
.02 0 0 r
.58197 .67782 m .56348 .68765 L .56096 .68878 L p F P
0 g
s
0 0 0 r
.31797 .21599 m .32031 .21426 L .30371 .22686 L p F P
0 g
s
0 0 0 r
.30692 .22485 m .31797 .21599 L p .30371 .22686 L F P
0 g
s
0 0 0 r
.30371 .22686 m .29902 .23088 L .30692 .22485 L p F P
0 g
s
.523 .57 .844 r
.3096 .42897 m .31317 .43535 L .30636 .43542 L closepath p F P
0 g
s
0 0 .132 r
.28033 .25037 m .27437 .25661 L .26894 .26717 L p F P
0 g
s
.845 .806 .813 r
.28225 .7598 m .29303 .7483 L .28761 .74229 L p F P
0 g
s
.956 .773 .616 r
.79866 .31306 m .79635 .32134 L .80111 .3291 L p F P
0 g
s
.956 .772 .615 r
.79582 .32325 m .79635 .32134 L .80111 .3291 L p F P
0 g
s
.956 .772 .615 r
.80111 .3291 m .80075 .3304 L .79582 .32325 L p F P
0 g
s
.651 .752 .923 r
.54482 .98028 m .56611 .97426 L .5717 .98 L p F P
0 g
s
.669 .718 .885 r
.56611 .97426 m .54482 .98028 L .53914 .97433 L p F P
0 g
s
.81 .808 .849 r
.32116 .71209 m .31807 .71469 L .32463 .71962 L p F P
0 g
s
.81 .808 .849 r
.32463 .71962 m .32619 .71831 L .32116 .71209 L p F P
0 g
s
.813 .808 .846 r
.30302 .72761 m .31807 .71469 L .32463 .71962 L p F P
0 g
s
.795 .807 .862 r
.34559 .70338 m .32619 .71831 L .32116 .71209 L p F P
0 g
s
.738 .42 .443 r
.55262 .47419 m .54258 .47281 L .54381 .46497 L p F P
0 g
s
.708 .396 .447 r
.53013 .46387 m .54381 .46497 L .54258 .47281 L p F P
0 g
s
.318 .287 .666 r
.25335 .34569 m .25576 .34171 L .25292 .32885 L p F P
0 g
s
.373 .355 .71 r
.25576 .34171 m .2575 .34792 L .25335 .34569 L closepath p F P
0 g
s
.374 .355 .709 r
.25335 .34569 m .2575 .34792 L .25966 .35571 L p F P
0 g
s
.484 .885 .95 r
.67408 .97076 m .67851 .97148 L .69892 .96491 L p F P
0 g
s
.436 .872 .904 r
.70084 .96482 m .69892 .96491 L .67851 .97148 L p F P
0 g
s
.459 .87 .952 r
.67851 .97148 m .67408 .97076 L .65234 .97623 L p F P
0 g
s
.786 .796 .86 r
.70472 .46459 m .70695 .46294 L .7019 .45664 L p F P
0 g
s
.786 .796 .86 r
.7019 .45664 m .70073 .45751 L .70472 .46459 L p F P
0 g
s
.772 .791 .869 r
.68043 .47138 m .70073 .45751 L .70472 .46459 L p F P
0 g
s
.168 .661 .918 r
.40457 .976 m .39832 .9722 L .37788 .97238 L p F P
0 g
s
.495 .757 .988 r
.39832 .9722 m .37788 .97238 L .37149 .96946 L p F P
0 g
s
.409 .33 .656 r
.7995 .8372 m .80926 .82906 L p .80527 .84738 L F P
0 g
s
.409 .33 .656 r
.80527 .84738 m .80048 .84175 L .7995 .8372 L p F P
0 g
s
.422 .366 .69 r
.7995 .8372 m .80926 .82906 L .79963 .82085 L p F P
0 g
s
.933 .784 .672 r
.79582 .32325 m .80075 .3304 L .79646 .34113 L p F P
0 g
s
.637 .77 .943 r
.5717 .98 m .59311 .97446 L .59859 .9796 L p F P
0 g
s
.657 .729 .902 r
.59311 .97446 m .5717 .98 L .56611 .97426 L p F P
0 g
s
0 0 0 r
.72617 .95437 m .7272 .95321 L .74881 .94102 L p F P
0 g
s
.162 0 0 r
.7493 .93996 m .74881 .94102 L .7272 .95321 L p F P
0 g
s
.78 .478 .475 r
.50299 .70068 m .48855 .69743 L .48645 .68803 L p F P
0 g
s
.85 .539 .462 r
.47647 .6834 m .48645 .68803 L .48855 .69743 L p F P
0 g
s
.681 .134 0 r
.47428 .67979 m .47647 .6834 L .48645 .68803 L p F P
0 g
s
.694 .756 .899 r
.63222 .49 m .62225 .49422 L .61638 .48777 L p F P
0 g
s
.099 .516 .907 r
.44587 .66729 m .45237 .67308 L p .46518 .67513 L F P
0 g
s
.54 .718 .955 r
.44153 .66763 m .44587 .66729 L .45237 .67308 L p F P
0 g
s
.673 .772 .925 r
.45883 .48191 m .43789 .48876 L .44394 .49572 L p F P
0 g
s
.673 .772 .925 r
.44394 .49572 m .46485 .4879 L .45883 .48191 L p F P
0 g
s
.709 .862 .955 r
.44394 .49572 m .46485 .4879 L .46551 .48832 L p F P
0 g
s
.635 .703 .896 r
.44394 .49572 m .43789 .48876 L .42861 .49135 L p F P
0 g
s
.792 .797 .856 r
.72671 .44778 m .70695 .46294 L .7019 .45664 L p F P
0 g
s
.845 .806 .813 r
.28761 .74229 m .27551 .75514 L .28225 .7598 L p F P
0 g
s
.843 .805 .813 r
.28225 .7598 m .27995 .76225 L .27441 .75631 L p F P
0 g
s
.843 .805 .813 r
.27441 .75631 m .27551 .75514 L .28225 .7598 L p F P
0 g
s
.326 .257 .624 r
.25228 .3246 m .25431 .32692 L p .25904 .30658 L F P
0 g
s
.307 .242 .618 r
.25228 .3246 m .25431 .32692 L .25292 .32885 L closepath p F P
0 g
s
.379 .248 .574 r
.80424 .86167 m .79696 .86671 L .79976 .87684 L p F P
0 g
s
.411 .303 .621 r
.79696 .86671 m .80424 .86167 L .80221 .8498 L p F P
0 g
s
.567 .858 .997 r
.67408 .97076 m .65234 .97623 L .64713 .97353 L p F P
0 g
s
.565 .851 .997 r
.62548 .97859 m .64713 .97353 L .65234 .97623 L p F P
0 g
s
.883 .51 .331 r
.27391 .9115 m .27593 .91136 L p .28515 .92428 L F P
0 g
s
.894 .543 .374 r
.27391 .9115 m .27354 .91005 L .27593 .91136 L closepath p F P
0 g
s
.86 .803 .793 r
.27995 .76225 m .27441 .75631 L .26318 .76975 L p F P
0 g
s
.86 .803 .793 r
.26318 .76975 m .26882 .77563 L .27995 .76225 L p F P
0 g
s
.485 .246 .476 r
.56348 .68765 m .5806 .68059 L p .56022 .69795 L F P
0 g
s
.485 .246 .476 r
.56022 .69795 m .5607 .6906 L .56348 .68765 L p F P
0 g
s
.247 0 .093 r
.56348 .68765 m .5806 .68059 L .58197 .67782 L closepath p F P
0 g
s
.668 .796 .943 r
.44187 .17393 m .42099 .1817 L .42718 .18773 L p F P
0 g
s
.668 .796 .943 r
.42718 .18773 m .448 .17968 L .44187 .17393 L p F P
0 g
s
.602 .656 .875 r
.38444 .48148 m .40497 .47733 L p .3828 .47159 L F P
0 g
s
.602 .656 .875 r
.3828 .47159 m .38008 .47515 L .38444 .48148 L p F P
0 g
s
.556 .624 .875 r
.70577 .70053 m .70082 .70068 L .69557 .69183 L p F P
0 g
s
.901 .803 .742 r
.78364 .36418 m .78818 .37134 L .7953 .35957 L p F P
0 g
s
.901 .803 .742 r
.7953 .35957 m .79079 .35238 L .78364 .36418 L p F P
0 g
s
.613 .804 .973 r
.59859 .9796 m .62013 .97446 L .62548 .97859 L p F P
0 g
s
.641 .755 .931 r
.62013 .97446 m .59859 .9796 L .59311 .97446 L p F P
0 g
s
.674 .379 .466 r
.53357 .47206 m .51454 .47214 L .51556 .46392 L p F P
0 g
s
.674 .379 .466 r
.51556 .46392 m .53013 .46387 L .53357 .47206 L p F P
0 g
s
.48 .492 .792 r
.78708 .77219 m .7775 .76941 L .77406 .76082 L p F P
0 g
s
.556 .252 .408 r
.49195 .47567 m .4947 .47669 L .49163 .4773 L closepath p F P
0 g
s
.75 .777 .875 r
.67278 .47633 m .65896 .48466 L .65372 .47812 L p F P
0 g
s
.736 .773 .883 r
.63222 .49 m .65372 .47812 L .65896 .48466 L p F P
0 g
s
.708 .396 .447 r
.54258 .47281 m .53357 .47206 L .53013 .46387 L p F P
0 g
s
.693 .457 .561 r
.52252 .70239 m .53709 .70235 L .53738 .71272 L p F P
0 g
s
.693 .457 .561 r
.53738 .71272 m .52161 .71276 L .52252 .70239 L p F P
0 g
s
.724 .485 .565 r
.50882 .70144 m .52252 .70239 L .52161 .71276 L p F P
0 g
s
.737 .789 .894 r
.40835 .66456 m .38741 .67605 L .39368 .6816 L p F P
0 g
s
.737 .789 .894 r
.39368 .6816 m .41455 .6702 L .40835 .66456 L p F P
0 g
s
.752 .792 .885 r
.37515 .68341 m .38741 .67605 L .39368 .6816 L p F P
0 g
s
.575 .308 .475 r
.5607 .6906 m .56022 .69795 L .53709 .70235 L p F P
0 g
s
.48 .494 .795 r
.27513 .39683 m .28337 .39808 L p .27365 .38339 L F P
0 g
s
.48 .494 .795 r
.27365 .38339 m .2711 .38755 L .27513 .39683 L p F P
0 g
s
.609 .391 .56 r
.53738 .71272 m .53709 .70235 L .56022 .69795 L p F P
0 g
s
.671 .772 .926 r
.46899 .17201 m .448 .17968 L .45405 .18661 L p F P
0 g
s
.671 .772 .926 r
.45405 .18661 m .47499 .17846 L .46899 .17201 L p F P
0 g
s
.897 .778 .722 r
.25731 .80671 m .25115 .8011 L .2444 .81328 L p F P
0 g
s
.897 .778 .722 r
.2444 .81328 m .2506 .81885 L .25731 .80671 L p F P
0 g
s
.579 .628 .865 r
.3518 .46555 m .3721 .46271 L p .35414 .45458 L F P
0 g
s
.579 .628 .865 r
.35414 .45458 m .34938 .46178 L .3518 .46555 L p F P
0 g
s
.577 .655 .89 r
.67724 .68392 m .66823 .6848 L .66292 .67668 L p F P
0 g
s
.618 .799 .969 r
.64713 .97353 m .62548 .97859 L .62013 .97446 L p F P
0 g
s
.846 .809 .813 r
.76573 .39994 m .76868 .39676 L .77276 .40396 L p F P
0 g
s
.846 .809 .813 r
.77276 .40396 m .77052 .40637 L .76573 .39994 L p F P
0 g
s
.91 .503 .151 r
.77489 .25788 m .78155 .2647 L p .77678 .2548 L F P
0 g
s
.91 .503 .151 r
.77678 .2548 m .77384 .25485 L .77489 .25788 L p F P
0 g
s
.894 .472 .12 r
.7719 .24998 m .77678 .2548 L .77384 .25485 L closepath p F P
0 g
s
.666 .83 .962 r
.4154 .17752 m .42099 .1817 L .40027 .1899 L p F P
0 g
s
.666 .83 .962 r
.40027 .1899 m .39399 .18521 L .4154 .17752 L p F P
0 g
s
.168 .04 .45 r
.25559 .29943 m .26277 .2903 L .26294 .28078 L p F P
0 g
s
.264 .164 .55 r
.26277 .2903 m .25559 .29943 L .25904 .30658 L p F P
0 g
s
.407 .33 .657 r
.80221 .8498 m .80048 .84175 L .80527 .84738 L closepath p F P
0 g
s
.847 .809 .813 r
.75997 .4177 m .77052 .40637 L .76573 .39994 L p F P
0 g
s
.789 .807 .867 r
.34305 .69541 m .33912 .69832 L .34559 .70338 L p F P
0 g
s
.789 .807 .867 r
.34559 .70338 m .34778 .70176 L .34305 .69541 L p F P
0 g
s
.795 .807 .862 r
.32116 .71209 m .33912 .69832 L .34559 .70338 L p F P
0 g
s
.666 .742 .907 r
.63036 .66481 m .60876 .67059 L .60333 .66548 L p F P
0 g
s
.595 .72 .932 r
.60533 .49242 m .60033 .49312 L .59322 .48705 L p F P
0 g
s
.688 .768 .912 r
.44153 .66763 m .43034 .67209 L .42469 .66601 L p F P
0 g
s
.68 .167 .013 r
.55262 .47419 m .56622 .47815 L .57135 .48223 L p F P
0 g
s
.68 .167 .013 r
.55262 .47419 m .57135 .48223 L .56665 .48057 L F
.56799 .47963 m .5666 .47892 L .55262 .47419 L p F P
0 g
s
.68 .167 .013 r
.57135 .48223 m .57278 .48336 L p .56665 .48057 L F P
0 g
s
.68 .167 .013 r
.57278 .48336 m .56799 .47963 L p .55262 .47419 L F P
0 g
s
.293 0 0 r
.55262 .47419 m .54258 .47281 L p .55379 .47566 L F P
0 g
s
.293 0 0 r
.5666 .47892 m .55826 .4761 L p .55379 .47566 L F P
0 g
s
.293 0 0 r
.55826 .4761 m .55262 .47419 L p .55379 .47566 L F P
0 g
s
.293 0 0 r
.54258 .47281 m .54556 .47315 L .54984 .47466 L F
.54556 .47315 m .55498 .47422 L .54984 .47466 L F
.54258 .47281 m .54008 .47472 L .55498 .47422 L p F P
0 g
s
.553 .042 0 r
.53357 .47206 m .54258 .47281 L .54008 .47472 L closepath p F P
0 g
s
.396 0 .079 r
.53357 .47206 m .51454 .47214 L p .53207 .47391 L F P
0 g
s
.396 0 .079 r
.54008 .47472 m .53773 .47376 L p .53207 .47391 L F P
0 g
s
.396 0 .079 r
.53773 .47376 m .53357 .47206 L p .53207 .47391 L F P
0 g
s
.371 0 .065 r
.4947 .47669 m .51454 .47214 L .51302 .47443 L closepath p F P
0 g
s
.396 0 .079 r
.51454 .47214 m .53467 .47304 L .54008 .47472 L F
.53478 .47305 m .53487 .47308 L p .53467 .47304 L F P
0 g
s
.396 0 .079 r
.53487 .47308 m .54008 .47472 L p .53467 .47304 L F P
0 g
s
.396 0 .079 r
.53295 .47303 m .53478 .47305 L p .53467 .47304 L F P
0 g
s
.396 0 .079 r
.51454 .47214 m .53295 .47303 L .53467 .47304 L F
.51454 .47214 m .51302 .47443 L .53295 .47303 L p F P
0 g
s
.624 .84 .983 r
.53295 .47303 m .50779 .47384 L p .52836 .47298 L F P
0 g
s
.624 .84 .983 r
.52836 .47298 m .5331 .47278 L .53295 .47303 L F
.53435 .47273 m .53366 .47287 L p .5331 .47278 L F P
0 g
s
.624 .84 .983 r
.53366 .47287 m .53295 .47303 L p .5331 .47278 L F P
0 g
s
.168 .702 .839 r
.53295 .47303 m .50779 .47384 L .51294 .47442 L p F P
0 g
s
.168 .702 .839 r
.51294 .47442 m .51302 .47443 L .5133 .47441 L p F P
0 g
s
.168 .702 .839 r
.5133 .47441 m .53295 .47303 L p .51294 .47442 L F P
0 g
s
.239 .728 .923 r
.55498 .47422 m .53478 .47305 L .53823 .47414 L p F P
0 g
s
.239 .728 .923 r
.53823 .47414 m .54008 .47472 L .54314 .47462 L p F P
0 g
s
.239 .728 .923 r
.54314 .47462 m .55498 .47422 L p .53823 .47414 L F P
0 g
s
.293 0 0 r
.55498 .47422 m .5666 .47892 L p .54984 .47466 L F P
0 g
s
.615 .957 .887 r
.32531 .21279 m .32031 .21426 L p .34466 .20123 L F P
0 g
s
.615 .957 .887 r
.34466 .20123 m .33631 .20655 L .32531 .21279 L p F P
0 g
s
.674 .76 .916 r
.4961 .1708 m .47499 .17846 L .48092 .18597 L p F P
0 g
s
.674 .76 .916 r
.48092 .18597 m .50198 .17763 L .4961 .1708 L p F P
0 g
s
.916 .746 .657 r
.25115 .83752 m .25168 .83606 L .24509 .83068 L p F P
0 g
s
.367 .32 .674 r
.25431 .32692 m .25292 .32885 L .25576 .34171 L p F P
0 g
s
.468 .702 .97 r
.67489 .19356 m .67658 .19351 L .67331 .19173 L closepath p F P
0 g
s
.775 .804 .877 r
.3665 .68899 m .34778 .70176 L .34305 .69541 L p F P
0 g
s
.677 .854 .967 r
.3939 .18515 m .39399 .18521 L .37398 .19437 L p F P
0 g
s
.677 .854 .967 r
.37398 .19437 m .37324 .19391 L .3939 .18515 L p F P
0 g
s
.415 .367 .696 r
.81018 .81147 m .79963 .82085 L .80926 .82906 L p F P
0 g
s
.447 .405 .719 r
.79839 .80388 m .81018 .81147 L .79963 .82085 L p F P
0 g
s
.724 .485 .565 r
.52161 .71276 m .50915 .71193 L .50882 .70144 L p F P
0 g
s
.752 .506 .56 r
.50299 .70068 m .50882 .70144 L .50915 .71193 L p F P
0 g
s
.808 .801 .845 r
.72671 .44778 m .72829 .44645 L .72333 .44011 L p F P
0 g
s
.808 .801 .845 r
.72333 .44011 m .72267 .44067 L .72671 .44778 L p F P
0 g
s
.792 .797 .856 r
.7019 .45664 m .72267 .44067 L .72671 .44778 L p F P
0 g
s
.811 .802 .843 r
.7448 .43225 m .72829 .44645 L .72333 .44011 L p F P
0 g
s
.675 .758 .913 r
.52321 .17003 m .50198 .17763 L .5078 .18541 L p F P
0 g
s
.675 .758 .913 r
.5078 .18541 m .52898 .17697 L .52321 .17003 L p F P
0 g
s
.916 .746 .657 r
.24509 .83068 m .2443 .83282 L .25115 .83752 L p F P
0 g
s
.916 .747 .658 r
.25115 .83752 m .2475 .84753 L .24087 .84219 L p F P
0 g
s
.916 .747 .658 r
.24087 .84219 m .2443 .83282 L .25115 .83752 L p F P
0 g
s
.847 .809 .813 r
.76573 .39994 m .75589 .41053 L .75997 .4177 L p F P
0 g
s
.829 .805 .829 r
.74463 .42138 m .75589 .41053 L .75997 .4177 L p F P
0 g
s
.829 .805 .829 r
.75997 .4177 m .74951 .42776 L .74463 .42138 L p F P
0 g
s
.223 0 .296 r
.77867 .91015 m .78898 .90424 L p .77008 .92316 L F P
0 g
s
.223 0 .296 r
.77008 .92316 m .7701 .92304 L .77867 .91015 L p F P
0 g
s
.342 .134 .445 r
.77867 .91015 m .78898 .90424 L .78918 .89461 L p F P
0 g
s
.518 .548 .826 r
.74663 .73107 m .76157 .73313 L p .76375 .74374 L F P
0 g
s
.504 .545 .832 r
.74663 .73107 m .76157 .73313 L .75632 .72223 L p F P
0 g
s
.504 .545 .832 r
.75632 .72223 m .754 .72189 L .74663 .73107 L p F P
0 g
s
.527 .573 .844 r
.73362 .72015 m .754 .72189 L .74663 .73107 L p F P
0 g
s
.146 0 .041 r
.74881 .94102 m .75238 .93848 L .7493 .93996 L closepath p F P
0 g
s
.248 0 .209 r
.7493 .93996 m .75238 .93848 L .76993 .92323 L p F P
0 g
s
0 0 0 r
.51302 .47443 m .4947 .47669 L .49163 .4773 L p F P
0 g
s
0 0 0 r
.50779 .47384 m .51302 .47443 L p .49163 .4773 L F P
0 g
s
0 0 0 r
.49618 .47687 m .50779 .47384 L p .49163 .4773 L F P
0 g
s
0 0 0 r
.49163 .4773 m .48593 .47991 L .49618 .47687 L p F P
0 g
s
0 0 0 r
.46551 .48832 m .4757 .48388 L p .49163 .4773 L F P
0 g
s
.624 .818 .975 r
.48593 .47991 m .49618 .47687 L .49172 .47769 L p F P
0 g
s
0 0 0 r
.48593 .47991 m .49163 .4773 L p .47767 .48307 L F P
0 g
s
.624 .818 .975 r
.49172 .47769 m .48467 .47898 L .48593 .47991 L p F P
0 g
s
0 0 0 r
.4757 .48388 m .48593 .47991 L p .47767 .48307 L F P
0 g
s
.909 .599 .448 r
.27354 .91005 m .26554 .90536 L .26447 .89515 L p F P
0 g
s
.918 .607 .439 r
.25679 .89031 m .26447 .89515 L .26554 .90536 L p F P
0 g
s
.916 .648 .517 r
.26447 .89515 m .25679 .89031 L .25716 .87976 L p F P
0 g
s
.495 0 0 r
.7364 .21714 m .74453 .22358 L .75178 .22975 L p F P
0 g
s
0 .077 .551 r
.75954 .23627 m .75178 .22975 L .74453 .22358 L p F P
0 g
s
.48 .492 .792 r
.77406 .76082 m .77705 .75751 L p .78708 .77219 L F P
0 g
s
.492 .518 .812 r
.77406 .76082 m .77214 .75643 L .77705 .75751 L closepath p F P
0 g
s
.901 .544 .355 r
.27354 .91005 m .27391 .9115 L .26688 .91057 L p F P
0 g
s
.901 .544 .355 r
.26688 .91057 m .26554 .90536 L .27354 .91005 L p F P
0 g
s
.965 .739 .546 r
.79866 .31306 m .7933 .30598 L .79478 .29631 L p F P
0 g
s
.945 .759 .62 r
.79635 .32134 m .79866 .31306 L .7933 .30598 L p F P
0 g
s
.521 .573 .848 r
.754 .72189 m .73362 .72015 L .7303 .71369 L p F P
0 g
s
.875 .801 .774 r
.26048 .78688 m .26882 .77563 L .26318 .76975 L p F P
0 g
s
.828 .806 .83 r
.7448 .43225 m .74951 .42776 L .74463 .42138 L p F P
0 g
s
.448 .453 .772 r
.2691 .38234 m .27365 .38339 L .2711 .38755 L closepath p F P
0 g
s
.356 .65 .967 r
.69629 .19467 m .67658 .19351 L .67331 .19173 L p F P
0 g
s
.437 .687 .97 r
.69821 .19562 m .69629 .19467 L .67658 .19351 L p F P
0 g
s
.437 .687 .97 r
.70227 .19958 m .69821 .19562 L p .67658 .19351 L F P
0 g
s
.828 .806 .83 r
.74463 .42138 m .74072 .42511 L .7448 .43225 L p F P
0 g
s
.811 .802 .843 r
.72333 .44011 m .74072 .42511 L .7448 .43225 L p F P
0 g
s
.673 .761 .917 r
.55034 .16965 m .52898 .17697 L .53471 .18475 L p F P
0 g
s
.673 .761 .917 r
.53471 .18475 m .556 .17645 L .55034 .16965 L p F P
0 g
s
.578 .771 .971 r
.40457 .976 m .42529 .97244 L .43141 .9771 L p F P
0 g
s
.623 .765 .948 r
.42529 .97244 m .40457 .976 L .39832 .9722 L p F P
0 g
s
.655 .9 .981 r
.38736 .18235 m .36661 .19131 L .37324 .19391 L p F P
0 g
s
.655 .9 .981 r
.37324 .19391 m .3939 .18515 L .38736 .18235 L p F P
0 g
s
.752 .506 .56 r
.50915 .71193 m .50226 .71099 L .50299 .70068 L p F P
0 g
s
.789 .534 .552 r
.48855 .69743 m .50299 .70068 L .50226 .71099 L p F P
0 g
s
.564 .608 .855 r
.3456 .45552 m .35414 .45458 L .34938 .46178 L closepath p F P
0 g
s
.926 .658 .511 r
.24983 .87475 m .25716 .87976 L .25679 .89031 L p F P
0 g
s
.919 .687 .572 r
.25716 .87976 m .24983 .87475 L .25153 .86389 L p F P
0 g
s
.355 0 0 r
.32747 .95439 m .33837 .95999 L .33177 .95698 L p F P
0 g
s
.355 0 0 r
.33177 .95698 m .31757 .95039 L .32747 .95439 L p F P
0 g
s
.676 .133 0 r
.31226 .94649 m .31757 .95039 L .32747 .95439 L p F P
0 g
s
0 0 0 r
.72269 .95678 m .72617 .95437 L .74533 .94617 L p F P
0 g
s
0 0 0 r
.74881 .94102 m .74533 .94617 L .72617 .95437 L p F P
0 g
s
0 0 0 r
.70084 .96482 m .72269 .95678 L .72617 .95437 L p F P
0 g
s
.46 .461 .772 r
.2691 .38234 m .27365 .38339 L p .26693 .36756 L F P
0 g
s
.46 .461 .772 r
.26693 .36756 m .26472 .37095 L .2691 .38234 L p F P
0 g
s
.538 .602 .866 r
.70577 .70053 m .72316 .70076 L .71792 .69147 L p F P
0 g
s
.538 .602 .866 r
.71792 .69147 m .71218 .69137 L .70577 .70053 L p F P
0 g
s
.556 .624 .875 r
.69557 .69183 m .71218 .69137 L .70577 .70053 L p F P
0 g
s
.296 .099 .434 r
.79956 .8878 m .78918 .89461 L .78898 .90424 L p F P
0 g
s
.349 .187 .515 r
.78918 .89461 m .79956 .8878 L .79976 .87684 L p F P
0 g
s
.597 .672 .892 r
.63575 .67208 m .65759 .66876 L .66292 .67668 L p F P
0 g
s
.597 .689 .906 r
.65223 .66106 m .65759 .66876 L .63575 .67208 L p F P
0 g
s
.597 .689 .906 r
.63363 .66419 m .65223 .66106 L p .63575 .67208 L F P
0 g
s
.597 .689 .906 r
.63575 .67208 m .63206 .66705 L .63363 .66419 L p F P
0 g
s
.376 .279 .616 r
.80527 .84738 m .80221 .8498 L .80424 .86167 L p F P
0 g
s
.734 .766 .878 r
.64842 .47132 m .62686 .48327 L .63222 .49 L p F P
0 g
s
.734 .766 .878 r
.63222 .49 m .65372 .47812 L .64842 .47132 L p F P
0 g
s
.694 .756 .899 r
.61638 .48777 m .62686 .48327 L .63222 .49 L p F P
0 g
s
.662 .769 .929 r
.57751 .16979 m .556 .17645 L .56162 .18402 L p F P
0 g
s
.662 .769 .929 r
.56162 .18402 m .58305 .17627 L .57751 .16979 L p F P
0 g
s
.634 .702 .895 r
.43458 .48452 m .43789 .48876 L .42861 .49135 L closepath p F P
0 g
s
.761 .781 .869 r
.67278 .47633 m .68043 .47138 L .67526 .4648 L p F P
0 g
s
.761 .781 .869 r
.67526 .4648 m .668 .4695 L .67278 .47633 L p F P
0 g
s
.75 .777 .875 r
.65372 .47812 m .668 .4695 L .67278 .47633 L p F P
0 g
s
.839 .399 .179 r
.29935 .93784 m .29053 .93347 L .28515 .92428 L p F P
0 g
s
.841 .393 .152 r
.27663 .91978 m .28515 .92428 L .29053 .93347 L p F P
0 g
s
.883 .51 .331 r
.28515 .92428 m .27663 .91978 L .27391 .9115 L p F P
0 g
s
.89 .514 .318 r
.27663 .91978 m .27391 .9115 L .26688 .91057 L p F P
0 g
s
.326 .257 .624 r
.25431 .32692 m .26502 .31281 L .25904 .30658 L p F P
0 g
s
.39 .33 .67 r
.26253 .33234 m .25431 .32692 L .26502 .31281 L p F P
0 g
s
.367 .32 .674 r
.25576 .34171 m .26253 .33234 L .25431 .32692 L p F P
0 g
s
0 0 .132 r
.26894 .26717 m .27817 .25752 L .28033 .25037 L p F P
0 g
s
.142 0 .345 r
.27817 .25752 m .26894 .26717 L .26702 .27637 L p F P
0 g
s
.12 0 .334 r
.26294 .28078 m .26702 .27637 L .26894 .26717 L p F P
0 g
s
.213 0 0 r
.34494 .96245 m .35474 .96466 L .3655 .96837 L p F P
0 g
s
0 .512 .811 r
.35474 .96466 m .34494 .96245 L .33837 .95999 L p F P
0 g
s
.544 .58 .841 r
.31317 .43535 m .33314 .43441 L p .3129 .4238 L F P
0 g
s
.544 .58 .841 r
.3129 .4238 m .3096 .42897 L .31317 .43535 L p F P
0 g
s
.491 .519 .814 r
.77705 .75751 m .77214 .75643 L .76683 .74435 L p F P
0 g
s
.413 .381 .714 r
.26253 .33234 m .25576 .34171 L .2575 .34792 L p F P
0 g
s
.552 .597 .852 r
.33359 .43524 m .33938 .44508 L .32704 .4461 L closepath p F P
0 g
s
.552 .604 .859 r
.3456 .45552 m .33938 .44508 L .32704 .4461 L p F P
0 g
s
.697 .758 .899 r
.60533 .49242 m .61638 .48777 L .60959 .48157 L p F P
0 g
s
.697 .758 .899 r
.60959 .48157 m .59987 .4858 L .60533 .49242 L p F P
0 g
s
.595 .72 .932 r
.59322 .48705 m .59987 .4858 L .60533 .49242 L p F P
0 g
s
.618 .051 0 r
.31757 .95039 m .31226 .94649 L .3055 .94464 L p F P
0 g
s
.879 .803 .771 r
.78161 .36699 m .78364 .36418 L .78818 .37134 L p F P
0 g
s
.879 .803 .771 r
.78818 .37134 m .78637 .37385 L .78161 .36699 L p F P
0 g
s
.636 .778 .949 r
.60473 .17079 m .58305 .17627 L .58856 .18343 L p F P
0 g
s
.636 .778 .949 r
.58856 .18343 m .61014 .17678 L .60473 .17079 L p F P
0 g
s
.413 .381 .714 r
.2575 .34792 m .2632 .35056 L p .26253 .33234 L F P
0 g
s
.398 .37 .712 r
.2575 .34792 m .2632 .35056 L .25966 .35571 L closepath p F P
0 g
s
0 0 0 r
.74533 .94617 m .74881 .94102 L .75238 .93848 L p F P
0 g
s
.933 .784 .672 r
.79646 .34113 m .7915 .33401 L .79582 .32325 L p F P
0 g
s
.914 .789 .709 r
.7915 .33401 m .79646 .34113 L .79079 .35238 L p F P
0 g
s
.967 .689 .455 r
.79478 .29631 m .78899 .28931 L .78909 .28018 L p F P
0 g
s
.955 .726 .553 r
.78899 .28931 m .79478 .29631 L .7933 .30598 L p F P
0 g
s
.645 .76 .932 r
.43141 .9771 m .45231 .97126 L .45832 .97676 L p F P
0 g
s
.674 .747 .906 r
.45231 .97126 m .43141 .9771 L .42529 .97244 L p F P
0 g
s
.356 .65 .967 r
.68475 .18933 m .69629 .19467 L p .67331 .19173 L F P
0 g
s
.356 .65 .967 r
.67331 .19173 m .66981 .18785 L .68475 .18933 L p F P
0 g
s
.519 .737 .973 r
.66443 .18845 m .67331 .19173 L .66981 .18785 L closepath p F P
0 g
s
.424 .414 .744 r
.26319 .36633 m .26693 .36756 L .26472 .37095 L closepath p F P
0 g
s
0 .455 .861 r
.70633 .20054 m .71572 .20659 L .72735 .211 L p F P
0 g
s
.061 .491 .892 r
.73334 .21491 m .72735 .211 L .71572 .20659 L p F P
0 g
s
.061 .491 .892 r
.73501 .21632 m .73334 .21491 L p .71572 .20659 L F P
0 g
s
.928 .698 .569 r
.24454 .85872 m .25153 .86389 L .24983 .87475 L p F P
0 g
s
.919 .719 .617 r
.25153 .86389 m .24454 .85872 L .2475 .84753 L p F P
0 g
s
.663 .959 .938 r
.34594 .20131 m .33631 .20655 L .34466 .20123 L closepath p F P
0 g
s
.766 .804 .883 r
.37077 .67689 m .3601 .68379 L .3665 .68899 L p F P
0 g
s
.766 .804 .883 r
.3665 .68899 m .37515 .68341 L .37077 .67689 L p F P
0 g
s
.775 .804 .877 r
.34305 .69541 m .3601 .68379 L .3665 .68899 L p F P
0 g
s
.438 .423 .745 r
.26319 .36633 m .26693 .36756 L p .2632 .35056 L F P
0 g
s
.438 .423 .745 r
.2632 .35056 m .25966 .35571 L .26319 .36633 L p F P
0 g
s
.88 .803 .769 r
.7793 .38374 m .78637 .37385 L .78161 .36699 L p F P
0 g
s
.182 .644 .938 r
.3655 .96837 m .37149 .96946 L .36506 .966 L p F P
0 g
s
.182 .644 .938 r
.36506 .966 m .35474 .96466 L .3655 .96837 L p F P
0 g
s
0 0 0 r
.75238 .93848 m .76776 .93082 L p .74533 .94617 L F P
0 g
s
.218 0 .176 r
.77008 .92316 m .76993 .92323 L .75238 .93848 L p F P
0 g
s
.218 0 .176 r
.75238 .93848 m .76776 .93082 L .77008 .92316 L p F P
0 g
s
.621 .673 .879 r
.42575 .47223 m .40497 .47733 L .41109 .48604 L p F P
0 g
s
.621 .673 .879 r
.41109 .48604 m .43183 .48088 L .42575 .47223 L p F P
0 g
s
.767 .266 0 r
.75178 .22975 m .75954 .23627 L .76457 .24335 L p F P
0 g
s
.746 .247 0 r
.7719 .24998 m .76457 .24335 L .75954 .23627 L p F P
0 g
s
.91 .77 .694 r
.2506 .81885 m .2444 .81328 L .23884 .82514 L p F P
0 g
s
.91 .77 .694 r
.23884 .82514 m .24509 .83068 L .2506 .81885 L p F P
0 g
s
.429 .401 .726 r
.80715 .79554 m .79839 .80388 L .81018 .81147 L p F P
0 g
s
.458 .435 .744 r
.80658 .79386 m .80715 .79554 L .79839 .80388 L p F P
0 g
s
.458 .435 .744 r
.79419 .78766 m .80658 .79386 L p .79839 .80388 L F P
0 g
s
.77 .783 .864 r
.70073 .45751 m .68043 .47138 L .67526 .4648 L p F P
0 g
s
.591 .639 .867 r
.37828 .47238 m .3828 .47159 L .38008 .47515 L closepath p F P
0 g
s
.875 .801 .774 r
.26318 .76975 m .25361 .78258 L .26048 .78688 L p F P
0 g
s
.873 .8 .776 r
.26048 .78688 m .25921 .78858 L .25348 .78275 L p F P
0 g
s
.873 .8 .776 r
.25348 .78275 m .25361 .78258 L .26048 .78688 L p F P
0 g
s
.243 .097 .475 r
.26702 .27637 m .26294 .28078 L .26277 .2903 L p F P
0 g
s
.672 .742 .903 r
.45832 .97676 m .47935 .96956 L .48525 .97581 L p F P
0 g
s
.692 .726 .875 r
.47935 .96956 m .45832 .97676 L .45231 .97126 L p F P
0 g
s
.307 .032 .323 r
.76993 .92323 m .77008 .92316 L .7701 .92304 L closepath p F P
0 g
s
.583 .778 .972 r
.62451 .17432 m .61014 .17678 L .61553 .18341 L p F P
0 g
s
.583 .778 .972 r
.63588 .17707 m .62451 .17432 L p .61553 .18341 L F P
0 g
s
.583 .778 .972 r
.61553 .18341 m .63733 .17858 L .63588 .17707 L p F P
0 g
s
.54 .718 .955 r
.44153 .66763 m .44587 .66729 L .44027 .66117 L p F P
0 g
s
.54 .718 .955 r
.44027 .66117 m .43545 .66165 L .44153 .66763 L p F P
0 g
s
.688 .768 .912 r
.42469 .66601 m .43545 .66165 L .44153 .66763 L p F P
0 g
s
.157 0 .149 r
.78789 .91301 m .77008 .92316 L .76776 .93082 L p F P
0 g
s
.223 0 .296 r
.78898 .90424 m .78789 .91301 L .77008 .92316 L p F P
0 g
s
.89 .795 .75 r
.25921 .78858 m .25348 .78275 L .24535 .79533 L p F P
0 g
s
.89 .795 .75 r
.24535 .79533 m .25115 .8011 L .25921 .78858 L p F P
0 g
s
.497 .524 .816 r
.76683 .74435 m .76375 .74374 L .76563 .74163 L closepath p F P
0 g
s
.518 .548 .826 r
.76157 .73313 m .76563 .74163 L .76375 .74374 L p F P
0 g
s
.68 .727 .885 r
.48525 .97581 m .50638 .96807 L .51219 .97487 L p F P
0 g
s
.696 .707 .857 r
.50638 .96807 m .48525 .97581 L .47935 .96956 L p F P
0 g
s
.565 .638 .883 r
.67724 .68392 m .69029 .68311 L .685 .67451 L p F P
0 g
s
.565 .638 .883 r
.685 .67451 m .68366 .6746 L .67724 .68392 L p F P
0 g
s
.577 .655 .89 r
.66292 .67668 m .68366 .6746 L .67724 .68392 L p F P
0 g
s
0 0 0 r
.28033 .25037 m .29334 .23873 L p .29902 .23088 L F P
0 g
s
.065 0 .178 r
.29334 .23873 m .28033 .25037 L .27817 .25752 L p F P
0 g
s
.521 .573 .848 r
.7303 .71369 m .73274 .71035 L p .754 .72189 L F P
0 g
s
.533 .594 .861 r
.7303 .71369 m .72838 .71017 L .73274 .71035 L closepath p F P
0 g
s
.953 .615 .328 r
.78909 .28018 m .78287 .27327 L .78155 .2647 L p F P
0 g
s
.957 .679 .467 r
.78287 .27327 m .78909 .28018 L .78899 .28931 L p F P
0 g
s
.736 .211 0 r
.29935 .93784 m .3055 .94464 L .29898 .94221 L p F P
0 g
s
.736 .211 0 r
.29053 .93347 m .29935 .93784 L p .29898 .94221 L F P
0 g
s
.677 .718 .88 r
.51219 .97487 m .53342 .96724 L .53914 .97433 L p F P
0 g
s
.69 .694 .849 r
.53342 .96724 m .51219 .97487 L .50638 .96807 L p F P
0 g
s
.692 .774 .914 r
.41984 .65961 m .40835 .66456 L .41455 .6702 L p F P
0 g
s
.692 .774 .914 r
.41455 .6702 m .42469 .66601 L .41984 .65961 L p F P
0 g
s
.895 .475 .154 r
.76457 .24335 m .7719 .24998 L .77384 .25485 L p F P
0 g
s
.453 .884 .876 r
.69892 .96491 m .70084 .96482 L .72269 .95678 L p F P
0 g
s
.753 .8 .89 r
.38741 .67605 m .37515 .68341 L .37077 .67689 L p F P
0 g
s
.85 .539 .462 r
.48855 .69743 m .47795 .69298 L .47647 .6834 L p F P
0 g
s
.905 .592 .442 r
.46855 .67808 m .47647 .6834 L .47795 .69298 L p F P
0 g
s
.837 .369 .057 r
.46826 .67741 m .46855 .67808 L .47647 .6834 L p F P
0 g
s
.946 .609 .349 r
.77489 .25788 m .78155 .2647 L .78287 .27327 L p F P
0 g
s
.669 .718 .885 r
.53914 .97433 m .56047 .96726 L .56611 .97426 L p F P
0 g
s
.68 .691 .853 r
.56047 .96726 m .53914 .97433 L .53342 .96724 L p F P
0 g
s
.565 .602 .849 r
.35969 .44261 m .33938 .44508 L .3456 .45552 L p F P
0 g
s
.565 .602 .849 r
.36112 .4451 m .35969 .44261 L p .3456 .45552 L F P
0 g
s
.565 .602 .849 r
.3456 .45552 m .35414 .45458 L .36112 .4451 L p F P
0 g
s
.552 .627 .88 r
.71218 .69137 m .69557 .69183 L .69029 .68311 L p F P
0 g
s
.524 .554 .828 r
.30695 .42384 m .3129 .4238 L .3096 .42897 L closepath p F P
0 g
s
.927 .73 .616 r
.2475 .84753 m .24087 .84219 L .23788 .8534 L p F P
0 g
s
.927 .73 .616 r
.23788 .8534 m .24454 .85872 L .2475 .84753 L p F P
0 g
s
.945 .759 .62 r
.7933 .30598 m .79145 .31249 L .79635 .32134 L p F P
0 g
s
.946 .759 .618 r
.79041 .31621 m .79145 .31249 L .79635 .32134 L p F P
0 g
s
.946 .759 .618 r
.79635 .32134 m .79582 .32325 L .79041 .31621 L p F P
0 g
s
.591 .634 .862 r
.39267 .45901 m .3721 .46271 L .37828 .47238 L p F P
0 g
s
.591 .634 .862 r
.39297 .45949 m .39267 .45901 L p .37828 .47238 L F P
0 g
s
.591 .634 .862 r
.37828 .47238 m .3828 .47159 L .39297 .45949 L p F P
0 g
s
.497 .304 .549 r
.56056 .70832 m .56022 .69795 L .57983 .68967 L p F P
0 g
s
.485 .246 .476 r
.5806 .68059 m .57983 .68967 L .56022 .69795 L p F P
0 g
s
.609 .391 .56 r
.56022 .69795 m .56056 .70832 L .53738 .71272 L p F P
0 g
s
.442 .433 .754 r
.80658 .79386 m .79419 .78766 L .80179 .77987 L closepath p F P
0 g
s
.47 .463 .769 r
.80095 .77765 m .80179 .77987 L .79419 .78766 L p F P
0 g
s
.47 .463 .769 r
.78708 .77219 m .80095 .77765 L p .79419 .78766 L F P
0 g
s
.376 .279 .616 r
.80424 .86167 m .81032 .85692 L .80527 .84738 L p F P
0 g
s
.367 .277 .621 r
.81665 .83796 m .80527 .84738 L .81032 .85692 L p F P
0 g
s
.409 .33 .656 r
.80926 .82906 m .81665 .83796 L .80527 .84738 L p F P
0 g
s
.88 .803 .769 r
.78161 .36699 m .77473 .37661 L .7793 .38374 L p F P
0 g
s
.861 .801 .79 r
.76407 .38967 m .76868 .39676 L .7793 .38374 L p F P
0 g
s
.861 .801 .79 r
.7793 .38374 m .77473 .37661 L .76407 .38967 L p F P
0 g
s
.698 .48 .588 r
.52161 .71276 m .53738 .71272 L .53828 .72376 L p F P
0 g
s
.698 .48 .588 r
.53828 .72376 m .51864 .7238 L .52161 .71276 L p F P
0 g
s
.726 .509 .597 r
.50915 .71193 m .52161 .71276 L .51864 .7238 L p F P
0 g
s
.617 .42 .592 r
.53738 .71272 m .56056 .70832 L p .55521 .72054 L F P
0 g
s
.617 .42 .592 r
.55521 .72054 m .53828 .72376 L .53738 .71272 L p F P
0 g
s
.659 .85 .973 r
.4757 .48388 m .46551 .48832 L .46485 .4879 L closepath p F P
0 g
s
.832 .818 .836 r
.2969 .73341 m .30302 .72761 L .29826 .72129 L p F P
0 g
s
.815 .817 .851 r
.31807 .71469 m .30302 .72761 L .29826 .72129 L p F P
0 g
s
.48 .492 .792 r
.77705 .75751 m .79525 .76309 L .78708 .77219 L p F P
0 g
s
.467 .495 .803 r
.78452 .7485 m .77705 .75751 L .79525 .76309 L p F P
0 g
s
.491 .519 .814 r
.76683 .74435 m .78452 .7485 L .77705 .75751 L p F P
0 g
s
.832 .818 .836 r
.29826 .72129 m .29018 .72891 L .2969 .73341 L p F P
0 g
s
.832 .817 .835 r
.2969 .73341 m .28761 .74229 L .28265 .73608 L p F P
0 g
s
.832 .817 .835 r
.28265 .73608 m .29018 .72891 L .2969 .73341 L p F P
0 g
s
.657 .729 .902 r
.56611 .97426 m .58756 .96795 L .59311 .97446 L p F P
0 g
s
.667 .695 .867 r
.58756 .96795 m .56611 .97426 L .56047 .96726 L p F P
0 g
s
.575 .662 .897 r
.68366 .6746 m .66292 .67668 L .65759 .66876 L p F P
0 g
s
.526 .732 .968 r
.63946 .17843 m .63733 .17858 L .64259 .18458 L p F P
0 g
s
.526 .732 .968 r
.64259 .18458 m .65183 .1835 L .63946 .17843 L p F P
0 g
s
.46 .461 .772 r
.27365 .38339 m .28222 .37055 L .26693 .36756 L p F P
0 g
s
.49 .492 .786 r
.28845 .38521 m .27365 .38339 L .28222 .37055 L p F P
0 g
s
.48 .494 .795 r
.28966 .38813 m .28845 .38521 L .27365 .38339 L p F P
0 g
s
.48 .494 .795 r
.28337 .39808 m .28966 .38813 L p .27365 .38339 L F P
0 g
s
.178 .573 .937 r
.70227 .19958 m .70633 .20054 L .69821 .19562 L closepath p F P
0 g
s
.789 .534 .552 r
.50226 .71099 m .48808 .70765 L .48855 .69743 L p F P
0 g
s
.85 .588 .543 r
.47795 .69298 m .48855 .69743 L .48808 .70765 L p F P
0 g
s
.845 .816 .82 r
.28761 .74229 m .28265 .73608 L .2693 .75017 L p F P
0 g
s
.845 .816 .82 r
.27551 .75514 m .28761 .74229 L p .2693 .75017 L F P
0 g
s
.448 .455 .773 r
.78708 .77219 m .80095 .77765 L .79547 .76319 L p F P
0 g
s
.448 .455 .773 r
.79547 .76319 m .79525 .76309 L .78708 .77219 L p F P
0 g
s
.483 .516 .816 r
.78452 .7485 m .76683 .74435 L .76563 .74163 L p F P
0 g
s
.621 .947 .941 r
.36371 .19097 m .36661 .19131 L .34594 .20131 L p F P
0 g
s
.621 .947 .941 r
.34594 .20131 m .34466 .20123 L .36371 .19097 L p F P
0 g
s
0 .262 .709 r
.73501 .21632 m .7364 .21714 L .73334 .21491 L closepath p F P
0 g
s
.337 .177 .512 r
.8056 .87285 m .79976 .87684 L .79956 .8878 L p F P
0 g
s
.379 .248 .574 r
.79976 .87684 m .8056 .87285 L .80424 .86167 L p F P
0 g
s
.498 .517 .807 r
.28966 .38813 m .29459 .3988 L .28337 .39808 L closepath p F P
0 g
s
.497 .525 .815 r
.29862 .40751 m .29459 .3988 L .28337 .39808 L p F P
0 g
s
.497 .525 .815 r
.29616 .41165 m .29862 .40751 L p .28337 .39808 L F P
0 g
s
.924 .771 .672 r
.79041 .31621 m .79582 .32325 L .7915 .33401 L p F P
0 g
s
.531 .598 .866 r
.73274 .71035 m .72838 .71017 L .72316 .70076 L p F P
0 g
s
.644 .706 .892 r
.43789 .48876 m .45883 .48191 L p .44423 .4772 L F P
0 g
s
.644 .706 .892 r
.44423 .4772 m .43458 .48452 L .43789 .48876 L p F P
0 g
s
.813 .818 .854 r
.31668 .70564 m .31144 .71004 L .31807 .71469 L p F P
0 g
s
.813 .818 .854 r
.31807 .71469 m .32116 .71209 L .31668 .70564 L p F P
0 g
s
.815 .817 .851 r
.29826 .72129 m .31144 .71004 L .31807 .71469 L p F P
0 g
s
.696 .753 .896 r
.62686 .48327 m .61638 .48777 L .60959 .48157 L p F P
0 g
s
.099 .516 .907 r
.46518 .67513 m .46155 .67244 L .44587 .66729 L p F P
0 g
s
.234 .528 .918 r
.44587 .66729 m .44027 .66117 L p .4593 .6693 L F P
0 g
s
.234 .528 .918 r
.4593 .6693 m .46155 .67244 L .44587 .66729 L p F P
0 g
s
.458 .733 .986 r
.66981 .18785 m .66443 .18845 L .65183 .1835 L p F P
0 g
s
.797 .816 .867 r
.33912 .69832 m .32116 .71209 L .31668 .70564 L p F P
0 g
s
.339 .22 .567 r
.81032 .85692 m .80424 .86167 L .8056 .87285 L p F P
0 g
s
.607 .702 .911 r
.63206 .66705 m .63036 .66481 L .63363 .66419 L closepath p F P
0 g
s
.726 .509 .597 r
.51864 .7238 m .51026 .72326 L .50915 .71193 L p F P
0 g
s
.755 .53 .591 r
.50226 .71099 m .50915 .71193 L .51026 .72326 L p F P
0 g
s
.783 .786 .855 r
.70073 .45751 m .7019 .45664 L .6968 .45001 L p F P
0 g
s
.783 .786 .855 r
.6968 .45001 m .69598 .45062 L .70073 .45751 L p F P
0 g
s
.77 .783 .864 r
.67526 .4648 m .69598 .45062 L .70073 .45751 L p F P
0 g
s
.671 .796 .942 r
.46485 .4879 m .45883 .48191 L p .48467 .47898 L F P
0 g
s
.671 .796 .942 r
.48467 .47898 m .4757 .48388 L .46485 .4879 L p F P
0 g
s
.789 .788 .851 r
.72267 .44067 m .7019 .45664 L .6968 .45001 L p F P
0 g
s
.641 .755 .931 r
.59311 .97446 m .61469 .96884 L .62013 .97446 L p F P
0 g
s
.653 .713 .892 r
.61469 .96884 m .59311 .97446 L .58756 .96795 L p F P
0 g
s
.438 .423 .745 r
.26693 .36756 m .27622 .35431 L .2632 .35056 L p F P
0 g
s
.472 .46 .763 r
.28222 .37055 m .26693 .36756 L .27622 .35431 L p F P
0 g
s
.526 .547 .82 r
.32069 .41121 m .30075 .41172 L .30695 .42384 L p F P
0 g
s
.526 .547 .82 r
.32113 .4121 m .32069 .41121 L p .30695 .42384 L F P
0 g
s
.526 .547 .82 r
.30695 .42384 m .3129 .4238 L .32113 .4121 L p F P
0 g
s
.514 .546 .827 r
.29616 .41165 m .30075 .41172 L .30695 .42384 L p F P
0 g
s
.483 .516 .816 r
.76563 .74163 m .77089 .73472 L p .78452 .7485 L F P
0 g
s
.496 .542 .834 r
.76563 .74163 m .76157 .73313 L .77089 .73472 L closepath p F P
0 g
s
.914 .789 .709 r
.79079 .35238 m .7858 .34529 L .7915 .33401 L p F P
0 g
s
.894 .791 .74 r
.7858 .34529 m .79079 .35238 L .78364 .36418 L p F P
0 g
s
.625 .729 .922 r
.59987 .4858 m .59322 .48705 L .58384 .48168 L p F P
0 g
s
.748 .77 .871 r
.65372 .47812 m .668 .4695 L .66233 .4629 L p F P
0 g
s
.748 .77 .871 r
.66233 .4629 m .64842 .47132 L .65372 .47812 L p F P
0 g
s
.845 .816 .82 r
.2693 .75017 m .2711 .75235 L .27551 .75514 L p F P
0 g
s
.848 .815 .817 r
.2711 .75235 m .27551 .75514 L .27441 .75631 L closepath p F P
0 g
s
.484 .885 .95 r
.69892 .96491 m .69596 .96462 L .67408 .97076 L p F P
0 g
s
.556 .873 .994 r
.69596 .96462 m .67408 .97076 L .66895 .96818 L p F P
0 g
s
.567 .858 .997 r
.64713 .97353 m .66895 .96818 L .67408 .97076 L p F P
0 g
s
.865 .816 .799 r
.27441 .75631 m .26318 .76975 L .25794 .76369 L p F P
0 g
s
.865 .816 .799 r
.2711 .75235 m .27441 .75631 L p .25794 .76369 L F P
0 g
s
.738 .796 .899 r
.4021 .6591 m .38109 .67069 L .38741 .67605 L p F P
0 g
s
.738 .796 .899 r
.38741 .67605 m .40835 .66456 L .4021 .6591 L p F P
0 g
s
.753 .8 .89 r
.37077 .67689 m .38109 .67069 L .38741 .67605 L p F P
0 g
s
.495 .757 .988 r
.37149 .96946 m .39203 .96789 L .39832 .9722 L p F P
0 g
s
.552 .763 .976 r
.39203 .96789 m .37149 .96946 L .36506 .966 L p F P
0 g
s
.904 .79 .724 r
.25115 .8011 m .24535 .79533 L .23854 .80754 L p F P
0 g
s
.904 .79 .724 r
.23854 .80754 m .2444 .81328 L .25115 .8011 L p F P
0 g
s
.556 .015 0 r
.74355 .22334 m .7364 .21714 L .73334 .21491 L p F P
0 g
s
.495 0 0 r
.75178 .22975 m .74355 .22334 L .7364 .21714 L p F P
0 g
s
.842 .798 .809 r
.76087 .39311 m .76407 .38967 L .76868 .39676 L p F P
0 g
s
.842 .798 .809 r
.76868 .39676 m .76573 .39994 L .76087 .39311 L p F P
0 g
s
.529 .786 .992 r
.57278 .48336 m .58384 .48168 L .56799 .47963 L closepath p F P
0 g
s
.618 .799 .969 r
.62013 .97446 m .64183 .96922 L .64713 .97353 L p F P
0 g
s
.637 .748 .929 r
.64183 .96922 m .62013 .97446 L .61469 .96884 L p F P
0 g
s
.602 .65 .87 r
.39297 .45949 m .39883 .46832 L .3828 .47159 L closepath p F P
0 g
s
.602 .656 .875 r
.40497 .47733 m .39883 .46832 L .3828 .47159 L p F P
0 g
s
.514 .545 .825 r
.29862 .40751 m .30075 .41172 L .29616 .41165 L closepath p F P
0 g
s
.656 .813 .959 r
.46291 .16677 m .44187 .17393 L .448 .17968 L p F P
0 g
s
.656 .813 .959 r
.448 .17968 m .46899 .17201 L .46291 .16677 L p F P
0 g
s
.695 .87 .964 r
.60193 .66609 m .60293 .66522 L .60333 .66548 L closepath p F P
0 g
s
.217 0 .079 r
.60193 .66609 m .60293 .66522 L p .5806 .68059 L F P
0 g
s
.755 .53 .591 r
.51026 .72326 m .49998 .72181 L .50226 .71099 L p F P
0 g
s
.797 .563 .584 r
.48808 .70765 m .50226 .71099 L .49998 .72181 L p F P
0 g
s
.842 .798 .809 r
.75589 .41053 m .76573 .39994 L .76087 .39311 L p F P
0 g
s
.693 .769 .91 r
.43545 .66165 m .42469 .66601 L .41984 .65961 L p F P
0 g
s
.614 .804 .973 r
.66895 .96818 m .64713 .97353 L .64183 .96922 L p F P
0 g
s
.264 .164 .55 r
.25904 .30658 m .26354 .3009 L .26277 .2903 L p F P
0 g
s
.332 .255 .617 r
.26354 .3009 m .25904 .30658 L .26502 .31281 L p F P
0 g
s
.924 .758 .658 r
.2443 .83282 m .24509 .83068 L .23884 .82514 L p F P
0 g
s
.658 .795 .948 r
.49015 .16505 m .46899 .17201 L .47499 .17846 L p F P
0 g
s
.658 .795 .948 r
.47499 .17846 m .4961 .1708 L .49015 .16505 L p F P
0 g
s
0 .33 .695 r
.31757 .95039 m .33177 .95698 L .3294 .95575 L p F P
0 g
s
0 .33 .695 r
.30794 .94628 m .31757 .95039 L p .3294 .95575 L F P
0 g
s
.618 .051 0 r
.3055 .94464 m .30794 .94628 L .31757 .95039 L p F P
0 g
s
.792 .817 .872 r
.33895 .68879 m .33257 .69351 L .33912 .69832 L p F P
0 g
s
.792 .817 .872 r
.33912 .69832 m .34305 .69541 L .33895 .68879 L p F P
0 g
s
.797 .816 .867 r
.31668 .70564 m .33257 .69351 L .33912 .69832 L p F P
0 g
s
.65 .829 .969 r
.4381 .17122 m .44187 .17393 L .42099 .1817 L p F P
0 g
s
.65 .829 .969 r
.42099 .1817 m .4154 .17752 L .4381 .17122 L p F P
0 g
s
.642 .856 .981 r
.60293 .66522 m .60333 .66548 L .62496 .65822 L p F P
0 g
s
.666 .742 .907 r
.60333 .66548 m .62496 .65822 L .63036 .66481 L p F P
0 g
s
.142 0 .345 r
.26702 .27637 m .27705 .26592 L .27817 .25752 L p F P
0 g
s
.256 .106 .476 r
.27705 .26592 m .26702 .27637 L .2683 .28434 L p F P
0 g
s
.243 .097 .475 r
.26277 .2903 m .2683 .28434 L .26702 .27637 L p F P
0 g
s
.908 .546 .336 r
.26554 .90536 m .26688 .91057 L .25989 .9083 L p F P
0 g
s
.908 .546 .336 r
.25989 .9083 m .25785 .90053 L .26554 .90536 L p F P
0 g
s
.918 .607 .439 r
.26554 .90536 m .25785 .90053 L .25679 .89031 L p F P
0 g
s
.927 .614 .43 r
.24944 .88532 m .25679 .89031 L .25785 .90053 L p F P
0 g
s
.926 .658 .511 r
.25679 .89031 m .24944 .88532 L .24983 .87475 L p F P
0 g
s
.217 0 .079 r
.60293 .66522 m .59796 .66451 L p .5806 .68059 L F P
0 g
s
.214 .016 .381 r
.59149 .6717 m .5806 .68059 L .57983 .68967 L p F P
0 g
s
.029 0 .283 r
.59149 .6717 m .58819 .68286 L p .59409 .67034 L F P
0 g
s
.217 0 .079 r
.59796 .66451 m .59149 .6717 L p .58852 .67325 L F P
0 g
s
.532 .821 .479 r
.59563 .66707 m .59796 .66451 L .59278 .67027 L p F P
0 g
s
.532 .821 .479 r
.59278 .67027 m .59149 .6717 L .59563 .66707 L p F P
0 g
s
.732 .971 .931 r
.59796 .66451 m .6129 .65514 L .60293 .66522 L closepath p F P
0 g
s
0 0 0 r
.59563 .66707 m .59796 .66451 L .6129 .65514 L p F P
0 g
s
0 0 0 r
.6129 .65514 m .61348 .64724 L p .59563 .66707 L F P
0 g
s
0 0 0 r
.59958 .66159 m .59563 .66707 L p .5989 .66343 L F P
0 g
s
0 0 0 r
.61348 .64724 m .59958 .66159 L p .5989 .66343 L F P
0 g
s
.878 .972 .66 r
.61334 .64621 m .61348 .64724 L .59958 .66159 L p F P
0 g
s
.878 .972 .66 r
.60865 .64308 m .61334 .64621 L p .59958 .66159 L F P
0 g
s
.878 .972 .66 r
.60222 .65304 m .60865 .64308 L p .60366 .65327 L F P
0 g
s
.878 .972 .66 r
.59958 .66159 m .60222 .65304 L p .60366 .65327 L F P
0 g
s
0 0 .047 r
.59958 .66159 m .59679 .67264 L p .60065 .65869 L F P
0 g
s
0 0 .047 r
.60222 .65304 m .59958 .66159 L p .60065 .65869 L F P
0 g
s
0 0 .047 r
.60015 .6639 m .60222 .65304 L p .60007 .66082 L F P
0 g
s
0 0 .047 r
.59679 .67264 m .60015 .6639 L p .60007 .66082 L F P
0 g
s
0 0 .326 r
.60075 .67403 m .60015 .6639 L p .59952 .66873 L F P
0 g
s
0 0 .326 r
.59771 .68265 m .60075 .67403 L p .59952 .66873 L F P
0 g
s
0 0 .147 r
.60075 .67403 m .60268 .68383 L p .60199 .67937 L F P
0 g
s
.747 .57 0 r
.60015 .6639 m .60075 .67403 L p .60023 .66701 L F P
0 g
s
0 0 .326 r
.60015 .6639 m .59679 .67264 L .59771 .68265 L p F P
0 g
s
.747 .57 0 r
.60002 .66646 m .59944 .6563 L p .59985 .6618 L F P
0 g
s
.747 .57 0 r
.60075 .67403 m .60002 .66646 L p .59985 .6618 L F P
0 g
s
0 0 .147 r
.60002 .66646 m .60075 .67403 L p .60199 .67937 L F P
0 g
s
0 0 .147 r
.60169 .67636 m .60002 .66646 L p .60062 .67043 L F P
0 g
s
0 0 .147 r
.60268 .68383 m .60169 .67636 L p .60062 .67043 L F P
0 g
s
0 0 .212 r
.60169 .67636 m .60268 .68383 L .60538 .69348 L p F P
0 g
s
0 0 .212 r
.60406 .68613 m .60169 .67636 L p .60249 .68007 L F P
0 g
s
0 0 .212 r
.60538 .69348 m .60406 .68613 L p .60249 .68007 L F P
0 g
s
.802 .462 0 r
.60406 .68613 m .60376 .6855 L .6042 .68666 L p F P
0 g
s
0 0 .346 r
.60431 .68696 m .60406 .68613 L p .60433 .68711 L F P
0 g
s
0 0 .346 r
.60863 .70305 m .60431 .68696 L .60433 .68711 L F
.802 .462 0 r
.6042 .68666 m .60431 .68696 L .60406 .68613 L p F P
0 g
s
0 0 .346 r
.60406 .68613 m .60538 .69348 L .60863 .70305 L p F P
0 g
s
0 0 .354 r
.60431 .68696 m .60376 .6855 L p .60429 .68674 L F P
0 g
s
0 0 .354 r
.60798 .69552 m .60431 .68696 L p .60429 .68674 L F P
0 g
s
.844 .515 0 r
.60169 .67636 m .60406 .68613 L p .60277 .68233 L F P
0 g
s
0 0 .419 r
.60075 .67403 m .59771 .68265 L .60022 .69225 L p F P
0 g
s
0 0 .419 r
.60022 .69225 m .60268 .68383 L .60075 .67403 L p F P
0 g
s
.844 .515 0 r
.59842 .66957 m .60169 .67636 L p .60277 .68233 L F P
0 g
s
.907 .597 .107 r
.60002 .66646 m .60169 .67636 L p .60019 .67117 L F P
0 g
s
0 0 .197 r
.59563 .66707 m .59459 .67584 L p .59898 .66331 L F P
0 g
s
0 0 .197 r
.59958 .66159 m .59563 .66707 L p .59898 .66331 L F P
0 g
s
0 0 .197 r
.59459 .67584 m .59679 .67264 L .59958 .66159 L p F P
0 g
s
.907 .597 .107 r
.59682 .65956 m .60002 .66646 L p .60019 .67117 L F P
0 g
s
.747 .57 0 r
.59944 .6563 m .60015 .6639 L p .60023 .66701 L F P
0 g
s
.907 .778 .291 r
.60222 .65304 m .60015 .6639 L p .60062 .65277 L F P
0 g
s
.907 .778 .291 r
.60092 .64559 m .60222 .65304 L p .60062 .65277 L F P
0 g
s
.029 0 .283 r
.59563 .66707 m .59149 .6717 L p .59409 .67034 L F P
0 g
s
.217 0 .079 r
.59149 .6717 m .5806 .68059 L p .58852 .67325 L F P
0 g
s
.532 .922 .842 r
.35972 .19149 m .36371 .19097 L .34466 .20123 L p F P
0 g
s
.532 .922 .842 r
.34466 .20123 m .33888 .2024 L .35972 .19149 L p F P
0 g
s
.615 .957 .887 r
.33362 .20562 m .33888 .2024 L .34466 .20123 L p F P
0 g
s
.615 .957 .887 r
.32031 .21426 m .33362 .20562 L p .34466 .20123 L F P
0 g
s
.657 .787 .944 r
.51739 .16407 m .4961 .1708 L .50198 .17763 L p F P
0 g
s
.657 .787 .944 r
.50198 .17763 m .52321 .17003 L .51739 .16407 L p F P
0 g
s
.955 .726 .553 r
.7933 .30598 m .78748 .299 L .78899 .28931 L p F P
0 g
s
.935 .747 .624 r
.79145 .31249 m .7933 .30598 L .78748 .299 L p F P
0 g
s
.777 .813 .882 r
.3601 .68379 m .34305 .69541 L .33895 .68879 L p F P
0 g
s
.521 .573 .848 r
.73274 .71035 m .75109 .71209 L p .754 .72189 L F P
0 g
s
.509 .572 .855 r
.73274 .71035 m .75109 .71209 L .74587 .70224 L p F P
0 g
s
.509 .572 .855 r
.74587 .70224 m .73843 .70147 L .73274 .71035 L p F P
0 g
s
.531 .598 .866 r
.72316 .70076 m .73843 .70147 L .73274 .71035 L p F P
0 g
s
.804 .791 .84 r
.72267 .44067 m .72333 .44011 L .71831 .43342 L p F P
0 g
s
.804 .791 .84 r
.71831 .43342 m .71795 .43372 L .72267 .44067 L p F P
0 g
s
.789 .788 .851 r
.6968 .45001 m .71795 .43372 L .72267 .44067 L p F P
0 g
s
.604 .719 .925 r
.63363 .66419 m .63036 .66481 L .62496 .65822 L p F P
0 g
s
.808 .792 .838 r
.74072 .42511 m .72333 .44011 L .71831 .43342 L p F P
0 g
s
0 0 0 r
.30692 .22485 m .29902 .23088 L .29671 .23474 L closepath p F P
0 g
s
0 0 0 r
.29334 .23873 m .29671 .23474 L .29902 .23088 L p F P
0 g
s
.484 .892 .93 r
.69596 .96462 m .69892 .96491 L .71879 .95753 L p F P
0 g
s
.453 .884 .876 r
.72269 .95678 m .71879 .95753 L .69892 .96491 L p F P
0 g
s
.924 .758 .658 r
.23884 .82514 m .2373 .82932 L .2443 .83282 L p F P
0 g
s
.924 .759 .659 r
.2443 .83282 m .24087 .84219 L .23456 .83669 L p F P
0 g
s
.924 .759 .659 r
.23456 .83669 m .2373 .82932 L .2443 .83282 L p F P
0 g
s
.642 .856 .981 r
.61954 .6522 m .6129 .65514 L .60293 .66522 L p F P
0 g
s
.642 .856 .981 r
.62496 .65822 m .61954 .6522 L p .60293 .66522 L F P
0 g
s
.842 .798 .809 r
.76087 .39311 m .75124 .40348 L .75589 .41053 L p F P
0 g
s
.825 .795 .824 r
.73969 .41463 m .75124 .40348 L .75589 .41053 L p F P
0 g
s
.825 .795 .824 r
.75589 .41053 m .74463 .42138 L .73969 .41463 L p F P
0 g
s
.413 .381 .714 r
.2632 .35056 m .2716 .33912 L p .26253 .33234 L F P
0 g
s
.44 .417 .737 r
.2716 .33912 m .2632 .35056 L .27622 .35431 L p F P
0 g
s
.841 .393 .152 r
.29053 .93347 m .28204 .92897 L .27663 .91978 L p F P
0 g
s
.842 .387 .122 r
.26845 .91514 m .27663 .91978 L .28204 .92897 L p F P
0 g
s
.89 .514 .318 r
.26688 .91057 m .26845 .91514 L .27663 .91978 L p F P
0 g
s
.91 .505 .19 r
.77384 .25485 m .77489 .25788 L .77253 .25566 L closepath p F P
0 g
s
.895 .475 .154 r
.77384 .25485 m .77253 .25566 L p .76457 .24335 L F P
0 g
s
.65 .787 .947 r
.54464 .16373 m .52321 .17003 L .52898 .17697 L p F P
0 g
s
.65 .787 .947 r
.52898 .17697 m .55034 .16965 L .54464 .16373 L p F P
0 g
s
0 .41 .828 r
.71762 .20505 m .70633 .20054 L .69821 .19562 L p F P
0 g
s
0 .455 .861 r
.72735 .211 m .71762 .20505 L .70633 .20054 L p F P
0 g
s
.267 .686 .967 r
.35474 .96466 m .36506 .966 L .35861 .96211 L p F P
0 g
s
.267 .686 .967 r
.35861 .96211 m .34399 .9609 L .35474 .96466 L p F P
0 g
s
0 .512 .811 r
.33837 .95999 m .34399 .9609 L .35474 .96466 L p F P
0 g
s
.935 .667 .506 r
.24282 .86961 m .24983 .87475 L .24944 .88532 L p F P
0 g
s
.928 .698 .569 r
.24983 .87475 m .24282 .86961 L .24454 .85872 L p F P
0 g
s
.824 .795 .825 r
.74072 .42511 m .74463 .42138 L .73969 .41463 L p F P
0 g
s
.324 .209 .564 r
.2683 .28434 m .26277 .2903 L .26354 .3009 L p F P
0 g
s
.824 .795 .825 r
.73969 .41463 m .73604 .41811 L .74072 .42511 L p F P
0 g
s
.808 .792 .838 r
.71831 .43342 m .73604 .41811 L .74072 .42511 L p F P
0 g
s
.876 .812 .782 r
.26318 .76975 m .25794 .76369 L .24816 .77675 L p F P
0 g
s
.876 .812 .782 r
.25361 .78258 m .26318 .76975 L p .24816 .77675 L F P
0 g
s
.3 .662 .972 r
.67301 .18401 m .66471 .18279 L .66981 .18785 L p F P
0 g
s
.3 .662 .972 r
.66981 .18785 m .68475 .18933 L .67301 .18401 L p F P
0 g
s
.458 .733 .986 r
.65183 .1835 m .66471 .18279 L .66981 .18785 L p F P
0 g
s
.66 .846 .971 r
.41469 .17704 m .4154 .17752 L .39399 .18521 L p F P
0 g
s
.66 .846 .971 r
.39399 .18521 m .3939 .18515 L .41469 .17704 L p F P
0 g
s
.732 .759 .874 r
.64308 .46424 m .62145 .47628 L .62686 .48327 L p F P
0 g
s
.732 .759 .874 r
.62686 .48327 m .64842 .47132 L .64308 .46424 L p F P
0 g
s
.696 .753 .896 r
.60959 .48157 m .62145 .47628 L .62686 .48327 L p F P
0 g
s
.619 .664 .871 r
.41964 .46319 m .39883 .46832 L .40497 .47733 L p F P
0 g
s
.619 .664 .871 r
.40497 .47733 m .42575 .47223 L .41964 .46319 L p F P
0 g
s
.628 .897 .986 r
.40823 .17433 m .38736 .18235 L .3939 .18515 L p F P
0 g
s
.628 .897 .986 r
.3939 .18515 m .41469 .17704 L .40823 .17433 L p F P
0 g
s
.556 .015 0 r
.73485 .21704 m .74355 .22334 L p .73334 .21491 L F P
0 g
s
.556 .015 0 r
.73334 .21491 m .73035 .21292 L .73485 .21704 L p F P
0 g
s
0 .178 .603 r
.72735 .211 m .73334 .21491 L .73035 .21292 L closepath p F P
0 g
s
.623 .765 .948 r
.39832 .9722 m .41913 .96722 L .42529 .97244 L p F P
0 g
s
.654 .759 .927 r
.41913 .96722 m .39832 .9722 L .39203 .96789 L p F P
0 g
s
.633 .791 .958 r
.57193 .16413 m .55034 .16965 L .556 .17645 L p F P
0 g
s
.633 .791 .958 r
.556 .17645 m .57751 .16979 L .57193 .16413 L p F P
0 g
s
.783 .283 0 r
.74355 .22334 m .75178 .22975 L .75677 .23683 L p F P
0 g
s
.767 .266 0 r
.76457 .24335 m .75677 .23683 L .75178 .22975 L p F P
0 g
s
.579 .622 .859 r
.36112 .4451 m .3659 .45283 L .35414 .45458 L closepath p F P
0 g
s
.579 .628 .865 r
.3721 .46271 m .3659 .45283 L .35414 .45458 L p F P
0 g
s
.22 0 .319 r
.79605 .89963 m .78898 .90424 L .78789 .91301 L p F P
0 g
s
.296 .099 .434 r
.78898 .90424 m .79605 .89963 L .79956 .8878 L p F P
0 g
s
.64 .697 .887 r
.43183 .48088 m .44423 .4772 L .43458 .48452 L closepath p F P
0 g
s
.759 .772 .864 r
.67526 .4648 m .668 .4695 L .66233 .4629 L p F P
0 g
s
.572 .606 .848 r
.33938 .44508 m .35969 .44261 L p .33433 .4343 L F P
0 g
s
.572 .606 .848 r
.33433 .4343 m .33359 .43524 L .33938 .44508 L p F P
0 g
s
.604 .719 .925 r
.62496 .65822 m .63666 .65567 L .63363 .66419 L p F P
0 g
s
.612 .715 .918 r
.63363 .66419 m .65223 .66106 L .64685 .6536 L p F P
0 g
s
.612 .715 .918 r
.64685 .6536 m .63666 .65567 L .63363 .66419 L p F P
0 g
s
.494 .544 .837 r
.77089 .73472 m .76157 .73313 L .75632 .72223 L p F P
0 g
s
.702 .757 .894 r
.59987 .4858 m .60959 .48157 L .60194 .4756 L p F P
0 g
s
.702 .757 .894 r
.60194 .4756 m .59436 .47903 L .59987 .4858 L p F P
0 g
s
.625 .729 .922 r
.58384 .48168 m .59436 .47903 L .59987 .4858 L p F P
0 g
s
.387 .321 .661 r
.81523 .82381 m .80926 .82906 L .81665 .83796 L p F P
0 g
s
.415 .367 .696 r
.81249 .81352 m .81018 .81147 L p .80926 .82906 L F P
0 g
s
.415 .367 .696 r
.80926 .82906 m .81523 .82381 L .81249 .81352 L p F P
0 g
s
.957 .679 .467 r
.78899 .28931 m .78273 .28242 L .78287 .27327 L p F P
0 g
s
.943 .712 .56 r
.78748 .299 m .78899 .28931 L .78273 .28242 L p F P
0 g
s
0 0 0 r
.33362 .20562 m .32031 .21426 L .31797 .21599 L closepath p F P
0 g
s
.894 .791 .74 r
.78364 .36418 m .7786 .35712 L .7858 .34529 L p F P
0 g
s
.873 .791 .767 r
.78161 .36699 m .78364 .36418 L .7786 .35712 L p F P
0 g
s
.924 .771 .672 r
.7915 .33401 m .78605 .32699 L .79041 .31621 L p F P
0 g
s
.906 .776 .708 r
.78605 .32699 m .7915 .33401 L .7858 .34529 L p F P
0 g
s
.7 .491 .603 r
.51864 .7238 m .53828 .72376 L .53952 .73519 L p F P
0 g
s
.7 .491 .603 r
.53952 .73519 m .51447 .73524 L .51864 .7238 L p F P
0 g
s
.726 .521 .613 r
.51026 .72326 m .51864 .7238 L .51447 .73524 L p F P
0 g
s
.674 .833 .959 r
.48593 .47991 m .4757 .48388 L .48467 .47898 L closepath p F P
0 g
s
.938 .709 .566 r
.24454 .85872 m .23788 .8534 L .23613 .86431 L p F P
0 g
s
.938 .709 .566 r
.23613 .86431 m .24282 .86961 L .24454 .85872 L p F P
0 g
s
.622 .435 .609 r
.53828 .72376 m .55521 .72054 L .54111 .7349 L p F P
0 g
s
.622 .435 .609 r
.54111 .7349 m .53952 .73519 L .53828 .72376 L p F P
0 g
s
.674 .747 .906 r
.42529 .97244 m .44628 .96512 L .45231 .97126 L p F P
0 g
s
.694 .737 .884 r
.44628 .96512 m .42529 .97244 L .41913 .96722 L p F P
0 g
s
.545 .573 .834 r
.32113 .4121 m .32693 .42291 L .3129 .4238 L closepath p F P
0 g
s
.544 .58 .841 r
.33314 .43441 m .32693 .42291 L .3129 .4238 L p F P
0 g
s
.552 .627 .88 r
.69029 .68311 m .71267 .68256 L p .71218 .69137 L F P
0 g
s
.543 .632 .889 r
.71267 .68256 m .69029 .68311 L .685 .67451 L p F P
0 g
s
.597 .792 .974 r
.59251 .1668 m .57751 .16979 L .58305 .17627 L p F P
0 g
s
.597 .792 .974 r
.60213 .16827 m .59251 .1668 L p .58305 .17627 L F P
0 g
s
.597 .792 .974 r
.58305 .17627 m .60473 .17079 L .60213 .16827 L p F P
0 g
s
.696 .707 .857 r
.47935 .96956 m .50054 .96035 L .50638 .96807 L p F P
0 g
s
.708 .689 .829 r
.50054 .96035 m .47935 .96956 L .47342 .96256 L p F P
0 g
s
.692 .726 .875 r
.45231 .97126 m .47342 .96256 L .47935 .96956 L p F P
0 g
s
.536 .556 .823 r
.30075 .41172 m .32069 .41121 L p .30489 .39899 L F P
0 g
s
.536 .556 .823 r
.30489 .39899 m .29862 .40751 L .30075 .41172 L p F P
0 g
s
.592 .628 .856 r
.3865 .44893 m .3659 .45283 L .3721 .46271 L p F P
0 g
s
.592 .628 .856 r
.3721 .46271 m .39267 .45901 L .3865 .44893 L p F P
0 g
s
.69 .694 .849 r
.52847 .96022 m .53342 .96724 L p .50638 .96807 L F P
0 g
s
.69 .694 .849 r
.50638 .96807 m .525 .9602 L .52847 .96022 L p F P
0 g
s
.702 .678 .823 r
.525 .9602 m .50638 .96807 L .50054 .96035 L p F P
0 g
s
.708 .71 .85 r
.47342 .96256 m .45231 .97126 L .44628 .96512 L p F P
0 g
s
.873 .791 .767 r
.7786 .35712 m .77678 .35964 L .78161 .36699 L p F P
0 g
s
.874 .791 .766 r
.76964 .36959 m .77678 .35964 L .78161 .36699 L p F P
0 g
s
.874 .791 .766 r
.78161 .36699 m .77473 .37661 L .76964 .36959 L p F P
0 g
s
.736 .211 0 r
.29898 .94221 m .29864 .94204 L .29053 .93347 L p F P
0 g
s
.72 .188 0 r
.28204 .92897 m .29053 .93347 L .29864 .94204 L p F P
0 g
s
.369 .719 .988 r
.66471 .18279 m .65183 .1835 L .63946 .17843 L p F P
0 g
s
.68 .691 .853 r
.55492 .95924 m .56047 .96726 L p .53342 .96724 L F P
0 g
s
.68 .691 .853 r
.53342 .96724 m .55423 .95927 L .55492 .95924 L p F P
0 g
s
.68 .691 .853 r
.53342 .96724 m .55423 .95927 L .52847 .96022 L closepath p F P
0 g
s
.767 .774 .859 r
.67526 .4648 m .69598 .45062 L .69047 .44392 L p F P
0 g
s
.767 .774 .859 r
.69047 .44392 m .67003 .45791 L .67526 .4648 L p F P
0 g
s
.759 .772 .864 r
.66233 .4629 m .67003 .45791 L .67526 .4648 L p F P
0 g
s
.768 .813 .888 r
.36714 .67006 m .35364 .67881 L .3601 .68379 L p F P
0 g
s
.768 .813 .888 r
.3601 .68379 m .37077 .67689 L .36714 .67006 L p F P
0 g
s
.777 .813 .882 r
.33895 .68879 m .35364 .67881 L .3601 .68379 L p F P
0 g
s
0 0 0 r
.74533 .94617 m .74457 .94687 L .72269 .95678 L p F P
0 g
s
0 0 0 r
.74954 .9441 m .76373 .93685 L .76634 .93356 L closepath p F P
0 g
s
0 0 0 r
.76373 .93685 m .74954 .9441 L p .74676 .94551 L F P
0 g
s
.456 .884 .815 r
.71879 .95753 m .72269 .95678 L .74055 .94869 L p F P
0 g
s
.456 .884 .815 r
.71879 .95753 m .74055 .94869 L .74218 .94786 L F
0 0 0 r
.74457 .94687 m .74954 .9441 L .74533 .94617 L closepath p F P
0 g
s
0 0 0 r
.76634 .93356 m .74954 .9441 L .74533 .94617 L p F P
0 g
s
.456 .884 .815 r
.74055 .94869 m .74457 .94687 L p .74218 .94786 L F P
0 g
s
.456 .884 .815 r
.74457 .94687 m .74003 .94895 L p .71879 .95753 L F P
0 g
s
0 0 0 r
.74003 .94895 m .75633 .94062 L .74676 .94551 L F
.75633 .94062 m .76373 .93685 L .74676 .94551 L F
.895 .48 .191 r
.75677 .23683 m .76457 .24335 L .76763 .25122 L p F P
0 g
s
.895 .475 .154 r
.77253 .25566 m .76763 .25122 L .76457 .24335 L p F P
0 g
s
.521 .346 .584 r
.56056 .70832 m .58026 .70009 L p .5668 .71715 L F P
0 g
s
.521 .346 .584 r
.5668 .71715 m .56094 .713 L .56056 .70832 L p F P
0 g
s
.497 .304 .549 r
.57983 .68967 m .58026 .70009 L .56056 .70832 L p F P
0 g
s
.617 .42 .592 r
.56056 .70832 m .56094 .713 L .55521 .72054 L p F P
0 g
s
.918 .782 .696 r
.2444 .81328 m .23854 .80754 L .23295 .81945 L p F P
0 g
s
.918 .782 .696 r
.23295 .81945 m .23884 .82514 L .2444 .81328 L p F P
0 g
s
.113 .606 .907 r
.34399 .9609 m .33837 .95999 L .33177 .95698 L p F P
0 g
s
.946 .609 .349 r
.78287 .27327 m .77618 .26646 L .77489 .25788 L p F P
0 g
s
.947 .669 .478 r
.77618 .26646 m .78287 .27327 L .78273 .28242 L p F P
0 g
s
.726 .521 .613 r
.51447 .73524 m .51183 .73508 L .51026 .72326 L p F P
0 g
s
.757 .542 .605 r
.49998 .72181 m .51026 .72326 L .51183 .73508 L p F P
0 g
s
.571 .73 .95 r
.43545 .66165 m .44027 .66117 L .43574 .65465 L p F P
0 g
s
.571 .73 .95 r
.43574 .65465 m .42932 .65564 L .43545 .66165 L p F P
0 g
s
.693 .769 .91 r
.41984 .65961 m .42932 .65564 L .43545 .66165 L p F P
0 g
s
.526 .599 .87 r
.73843 .70147 m .72316 .70076 L .71792 .69147 L p F P
0 g
s
.905 .592 .442 r
.47795 .69298 m .46966 .68778 L .46855 .67808 L p F P
0 g
s
.945 .631 .41 r
.46518 .67513 m .46855 .67808 L .46966 .68778 L p F P
0 g
s
.935 .747 .624 r
.78748 .299 m .78644 .3026 L .79145 .31249 L p F P
0 g
s
.935 .745 .621 r
.78451 .30927 m .78644 .3026 L .79145 .31249 L p F P
0 g
s
.935 .745 .621 r
.79145 .31249 m .79041 .31621 L .78451 .30927 L p F P
0 g
s
.85 .588 .543 r
.48808 .70765 m .47747 .70321 L .47795 .69298 L p F P
0 g
s
.901 .638 .53 r
.46966 .68778 m .47795 .69298 L .47747 .70321 L p F P
0 g
s
.938 .602 .366 r
.77253 .25566 m .77489 .25788 L .77618 .26646 L p F P
0 g
s
.292 .144 .502 r
.81292 .86716 m .8056 .87285 L .80622 .88327 L p F P
0 g
s
.337 .177 .512 r
.79956 .8878 m .80622 .88327 L .8056 .87285 L p F P
0 g
s
.339 .22 .567 r
.8056 .87285 m .81292 .86716 L .81032 .85692 L p F P
0 g
s
.876 .812 .782 r
.24816 .77675 m .25304 .78226 L .25361 .78258 L p F P
0 g
s
.878 .811 .779 r
.25304 .78226 m .25361 .78258 L .25348 .78275 L closepath p F P
0 g
s
.545 0 0 r
.30794 .94628 m .29898 .94221 L .3055 .94464 L closepath p F P
0 g
s
.28 .084 .426 r
.80622 .88327 m .79956 .8878 L .79605 .89963 L p F P
0 g
s
.896 .809 .755 r
.25348 .78275 m .24535 .79533 L .23991 .78938 L p F P
0 g
s
.896 .809 .755 r
.25304 .78226 m .25348 .78275 L p .23991 .78938 L F P
0 g
s
.667 .695 .867 r
.56047 .96726 m .58195 .96013 L .58756 .96795 L p F P
0 g
s
.67 .686 .857 r
.58011 .95713 m .58195 .96013 L .56047 .96726 L p F P
0 g
s
.67 .686 .857 r
.56047 .96726 m .55492 .95924 L .58011 .95713 L p F P
0 g
s
.065 0 .178 r
.27817 .25752 m .28688 .24976 L .29334 .23873 L p F P
0 g
s
.221 .015 .374 r
.28688 .24976 m .27817 .25752 L .27705 .26592 L p F P
0 g
s
.797 .563 .584 r
.49998 .72181 m .48634 .71832 L .48808 .70765 L p F P
0 g
s
.851 .613 .577 r
.47747 .70321 m .48808 .70765 L .48634 .71832 L p F P
0 g
s
.575 .662 .897 r
.65759 .66876 m .6797 .66649 L p .68366 .6746 L F P
0 g
s
.575 .668 .902 r
.6797 .66649 m .65759 .66876 L .65223 .66106 L p F P
0 g
s
.516 .528 .807 r
.29459 .3988 m .30489 .39899 L .29862 .40751 L closepath p F P
0 g
s
.897 .511 .288 r
.26845 .91514 m .26688 .91057 L .25989 .9083 L p F P
0 g
s
.556 .754 .97 r
.60944 .17021 m .60473 .17079 L .61014 .17678 L p F P
0 g
s
.556 .754 .97 r
.61014 .17678 m .62451 .17432 L .60944 .17021 L p F P
0 g
s
.39 .33 .67 r
.26793 .32529 m .26253 .33234 L p .26502 .31281 L F P
0 g
s
.415 .376 .706 r
.26793 .32529 m .2707 .3357 L .26253 .33234 L closepath p F P
0 g
s
.413 .381 .714 r
.2716 .33912 m .2707 .3357 L .26253 .33234 L p F P
0 g
s
.698 .779 .914 r
.41574 .65291 m .4021 .6591 L .40835 .66456 L p F P
0 g
s
.698 .779 .914 r
.40835 .66456 m .41984 .65961 L .41574 .65291 L p F P
0 g
s
.865 .816 .799 r
.26867 .75092 m .2693 .75017 L .2711 .75235 L closepath p F P
0 g
s
.865 .816 .799 r
.25794 .76369 m .26867 .75092 L .2711 .75235 L p F P
0 g
s
.896 .809 .754 r
.24662 .77912 m .24816 .77675 L .25304 .78226 L closepath p F P
0 g
s
.896 .809 .755 r
.23991 .78938 m .24662 .77912 L .25304 .78226 L p F P
0 g
s
.936 .742 .615 r
.24087 .84219 m .23456 .83669 L .23154 .84793 L p F P
0 g
s
.936 .742 .615 r
.23154 .84793 m .23788 .8534 L .24087 .84219 L p F P
0 g
s
.639 .685 .877 r
.44675 .46616 m .42575 .47223 L .43183 .48088 L p F P
0 g
s
.639 .685 .877 r
.45136 .47263 m .44675 .46616 L p .43183 .48088 L F P
0 g
s
.639 .685 .877 r
.43183 .48088 m .44423 .4772 L .45136 .47263 L p F P
0 g
s
.59 .931 .952 r
.38397 .18185 m .38736 .18235 L .36661 .19131 L p F P
0 g
s
.59 .931 .952 r
.36661 .19131 m .36371 .19097 L .38397 .18185 L p F P
0 g
s
.755 .808 .895 r
.38109 .67069 m .37077 .67689 L .36714 .67006 L p F P
0 g
s
.856 .79 .786 r
.76964 .36959 m .77473 .37661 L .76407 .38967 L p F P
0 g
s
.648 .788 .949 r
.59436 .47903 m .58384 .48168 L .56799 .47963 L p F P
0 g
s
.5 .551 .84 r
.75632 .72223 m .754 .72189 L .75528 .72012 L closepath p F P
0 g
s
.521 .573 .848 r
.75109 .71209 m .75528 .72012 L .754 .72189 L p F P
0 g
s
.757 .542 .605 r
.51183 .73508 m .4969 .73293 L .49998 .72181 L p F P
0 g
s
.805 .583 .601 r
.48634 .71832 m .49998 .72181 L .4969 .73293 L p F P
0 g
s
.7 .751 .892 r
.62145 .47628 m .60959 .48157 L .60194 .4756 L p F P
0 g
s
.326 .212 .567 r
.8203 .84873 m .81032 .85692 L .81292 .86716 L p F P
0 g
s
.367 .277 .621 r
.81926 .84297 m .81665 .83796 L p .81032 .85692 L F P
0 g
s
.367 .277 .621 r
.81032 .85692 m .8203 .84873 L .81926 .84297 L p F P
0 g
s
.653 .713 .892 r
.58756 .96795 m .60918 .96183 L .61469 .96884 L p F P
0 g
s
.658 .679 .858 r
.60918 .96183 m .58756 .96795 L .58195 .96013 L p F P
0 g
s
.916 .758 .671 r
.78451 .30927 m .79041 .31621 L .78605 .32699 L p F P
0 g
s
.514 .348 .593 r
.56154 .7194 m .56094 .713 L .5668 .71715 L closepath p F P
0 g
s
.623 .428 .597 r
.56154 .7194 m .56094 .713 L .55521 .72054 L closepath p F P
0 g
s
.407 0 0 r
.71762 .20505 m .72735 .211 L .73035 .21292 L p F P
0 g
s
.535 .609 .873 r
.71792 .69147 m .71218 .69137 L .7151 .68657 L closepath p F P
0 g
s
.552 .627 .88 r
.71267 .68256 m .7151 .68657 L .71218 .69137 L p F P
0 g
s
.324 .209 .564 r
.26354 .3009 m .27263 .29117 L .2683 .28434 L p F P
0 g
s
.382 .29 .626 r
.27263 .29117 m .26354 .3009 L .26524 .31254 L p F P
0 g
s
.332 .255 .617 r
.26502 .31281 m .26524 .31254 L .26354 .3009 L p F P
0 g
s
.401 .357 .694 r
.81249 .81352 m .81018 .81147 L .81159 .81014 L closepath p F P
0 g
s
.429 .401 .726 r
.81018 .81147 m .81159 .81014 L .80715 .79554 L p F P
0 g
s
0 .41 .828 r
.70747 .1992 m .71762 .20505 L p .69821 .19562 L F P
0 g
s
0 .41 .828 r
.69821 .19562 m .69736 .19488 L .70747 .1992 L p F P
0 g
s
.188 .602 .944 r
.69629 .19467 m .69821 .19562 L .69736 .19488 L closepath p F P
0 g
s
.835 .829 .841 r
.29018 .72891 m .29826 .72129 L .29401 .71475 L p F P
0 g
s
.817 .827 .857 r
.31144 .71004 m .29826 .72129 L .29401 .71475 L p F P
0 g
s
.938 .602 .366 r
.77618 .26646 m .77225 .26278 L .77253 .25566 L p F P
0 g
s
.934 .597 .37 r
.76763 .25122 m .77253 .25566 L .77225 .26278 L p F P
0 g
s
.288 .559 .929 r
.45621 .66545 m .44027 .66117 L .43574 .65465 L p F P
0 g
s
.234 .528 .918 r
.44027 .66117 m .45621 .66545 L .4593 .6693 L p F P
0 g
s
.835 .829 .841 r
.29401 .71475 m .28337 .72472 L .29018 .72891 L p F P
0 g
s
.835 .827 .84 r
.29018 .72891 m .28265 .73608 L .27814 .72966 L p F P
0 g
s
.835 .827 .84 r
.27814 .72966 m .28337 .72472 L .29018 .72891 L p F P
0 g
s
.852 .826 .822 r
.28265 .73608 m .27814 .72966 L .26465 .74384 L p F P
0 g
s
.852 .826 .822 r
.26465 .74384 m .2693 .75017 L .28265 .73608 L p F P
0 g
s
.78 .777 .85 r
.6968 .45001 m .69598 .45062 L .69047 .44392 L p F P
0 g
s
.523 .531 .805 r
.29459 .3988 m .30489 .39899 L p .29174 .38544 L F P
0 g
s
.523 .531 .805 r
.29174 .38544 m .28966 .38813 L .29459 .3988 L p F P
0 g
s
.786 .778 .846 r
.6968 .45001 m .71795 .43372 L .71256 .42693 L p F P
0 g
s
.786 .778 .846 r
.71256 .42693 m .69165 .44304 L .6968 .45001 L p F P
0 g
s
.78 .777 .85 r
.69047 .44392 m .69165 .44304 L .6968 .45001 L p F P
0 g
s
0 .379 .753 r
.29898 .94221 m .30794 .94628 L .32359 .953 L p F P
0 g
s
0 .33 .695 r
.3294 .95575 m .32359 .953 L .30794 .94628 L p F P
0 g
s
.816 .829 .86 r
.31277 .69895 m .30473 .70565 L .31144 .71004 L p F P
0 g
s
.816 .829 .86 r
.31144 .71004 m .31668 .70564 L .31277 .69895 L p F P
0 g
s
.817 .827 .857 r
.29401 .71475 m .30473 .70565 L .31144 .71004 L p F P
0 g
s
.906 .776 .708 r
.7858 .34529 m .78031 .3383 L .78605 .32699 L p F P
0 g
s
.887 .779 .737 r
.78031 .3383 m .7858 .34529 L .7786 .35712 L p F P
0 g
s
0 0 0 r
.76776 .93082 m .76634 .93356 L p .74533 .94617 L F P
0 g
s
.746 .763 .866 r
.64842 .47132 m .66233 .4629 L .65579 .45654 L p F P
0 g
s
.746 .763 .866 r
.65579 .45654 m .64308 .46424 L .64842 .47132 L p F P
0 g
s
.494 .544 .837 r
.75632 .72223 m .77678 .72596 L .77089 .73472 L p F P
0 g
s
.486 .543 .84 r
.77678 .72596 m .75632 .72223 L .75528 .72012 L p F P
0 g
s
.66 .733 .903 r
.47397 .46747 m .4528 .47457 L .45883 .48191 L p F P
0 g
s
.66 .733 .903 r
.45883 .48191 m .47996 .47463 L .47397 .46747 L p F P
0 g
s
.644 .706 .892 r
.45883 .48191 m .4528 .47457 L .44423 .4772 L p F P
0 g
s
.671 .796 .942 r
.45883 .48191 m .47996 .47463 L .48467 .47898 L p F P
0 g
s
.556 .583 .837 r
.33314 .43441 m .33433 .4343 L .33359 .43524 L closepath p F P
0 g
s
.637 .748 .929 r
.61469 .96884 m .63645 .96341 L .64183 .96922 L p F P
0 g
s
.644 .705 .891 r
.63645 .96341 m .61469 .96884 L .60918 .96183 L p F P
0 g
s
0 0 0 r
.31797 .21599 m .30692 .22485 L .31574 .2183 L closepath p F P
0 g
s
0 0 0 r
.31574 .2183 m .30692 .22485 L .29671 .23474 L p F P
0 g
s
.798 .825 .873 r
.33257 .69351 m .31668 .70564 L .31277 .69895 L p F P
0 g
s
.481 .73 .981 r
.63733 .17858 m .63946 .17843 L .63588 .17707 L closepath p F P
0 g
s
.051 .535 .888 r
.69736 .19488 m .69629 .19467 L .68475 .18933 L p F P
0 g
s
.484 .892 .93 r
.71879 .95753 m .71796 .95754 L .69596 .96462 L p F P
0 g
s
.532 .889 .978 r
.71796 .95754 m .69596 .96462 L .69093 .96244 L p F P
0 g
s
.556 .873 .994 r
.66895 .96818 m .69093 .96244 L .69596 .96462 L p F P
0 g
s
.627 .444 .614 r
.55521 .72054 m .56154 .7194 L .56297 .73098 L p F P
0 g
s
.627 .444 .614 r
.56297 .73098 m .54111 .7349 L .55521 .72054 L p F P
0 g
s
.334 .715 .983 r
.34399 .9609 m .35861 .96211 L .35211 .95786 L p F P
0 g
s
.334 .715 .983 r
.35211 .95786 m .33318 .95713 L .34399 .9609 L p F P
0 g
s
.113 .606 .907 r
.33177 .95698 m .33318 .95713 L .34399 .9609 L p F P
0 g
s
.557 .577 .83 r
.34558 .42094 m .32693 .42291 L .33314 .43441 L p F P
0 g
s
.557 .577 .83 r
.33314 .43441 m .33433 .4343 L .34558 .42094 L p F P
0 g
s
.157 0 .149 r
.7877 .91381 m .78789 .91301 L p .76776 .93082 L F P
0 g
s
.157 0 .149 r
.76776 .93082 m .77458 .92696 L .7877 .91381 L p F P
0 g
s
.023 0 0 r
.76634 .93356 m .77458 .92696 L .76776 .93082 L closepath p F P
0 g
s
.4 .383 .724 r
.80799 .79463 m .80715 .79554 L .81159 .81014 L p F P
0 g
s
.428 .425 .753 r
.80715 .79554 m .80658 .79386 L .80799 .79463 L closepath p F P
0 g
s
0 0 0 r
.29671 .23474 m .29576 .23663 L p .31574 .2183 L F P
0 g
s
0 0 0 r
.29671 .23474 m .29334 .23873 L .29576 .23663 L closepath p F P
0 g
s
.428 .425 .753 r
.80799 .79463 m .80658 .79386 L .80179 .77987 L p F P
0 g
s
.856 .79 .786 r
.76407 .38967 m .75893 .38269 L .76964 .36959 L p F P
0 g
s
.837 .788 .804 r
.76087 .39311 m .76407 .38967 L .75893 .38269 L p F P
0 g
s
.74 .805 .904 r
.39578 .65384 m .3747 .66552 L .38109 .67069 L p F P
0 g
s
.74 .805 .904 r
.38109 .67069 m .4021 .6591 L .39578 .65384 L p F P
0 g
s
.755 .808 .895 r
.36714 .67006 m .3747 .66552 L .38109 .67069 L p F P
0 g
s
.945 .631 .41 r
.4622 .67435 m .46518 .67513 L p .46966 .68778 L F P
0 g
s
.906 .511 .25 r
.4622 .67435 m .46155 .67244 L .46518 .67513 L closepath p F P
0 g
s
.705 .518 .632 r
.51447 .73524 m .53952 .73519 L p .53339 .74743 L F P
0 g
s
.705 .518 .632 r
.51254 .73969 m .51447 .73524 L p .53339 .74743 L F P
0 g
s
.727 .53 .624 r
.51254 .73969 m .51447 .73524 L .51183 .73508 L closepath p F P
0 g
s
.256 .106 .476 r
.2683 .28434 m .27689 .27544 L .27705 .26592 L p F P
0 g
s
.332 .212 .562 r
.27689 .27544 m .2683 .28434 L .27263 .29117 L p F P
0 g
s
.911 .802 .727 r
.24535 .79533 m .23991 .78938 L .23304 .80165 L p F P
0 g
s
.911 .802 .727 r
.23304 .80165 m .23854 .80754 L .24535 .79533 L p F P
0 g
s
.915 .548 .317 r
.25785 .90053 m .25989 .9083 L .25294 .90482 L p F P
0 g
s
.915 .548 .317 r
.25294 .90482 m .25048 .89556 L .25785 .90053 L p F P
0 g
s
.927 .614 .43 r
.25785 .90053 m .25048 .89556 L .24944 .88532 L p F P
0 g
s
.625 .447 .621 r
.53965 .7362 m .54111 .7349 L .53952 .73519 L closepath p F P
0 g
s
.705 .518 .632 r
.53952 .73519 m .53965 .7362 L .53339 .74743 L p F P
0 g
s
.648 .788 .949 r
.58881 .47203 m .59436 .47903 L p .56799 .47963 L F P
0 g
s
.648 .788 .949 r
.56799 .47963 m .56721 .47889 L .58881 .47203 L p F P
0 g
s
.482 .721 .976 r
.5666 .47892 m .56799 .47963 L .56721 .47889 L closepath p F P
0 g
s
.486 .543 .84 r
.75528 .72012 m .75953 .71314 L p .77678 .72596 L F P
0 g
s
.501 .568 .856 r
.75528 .72012 m .75109 .71209 L .75953 .71314 L closepath p F P
0 g
s
.87 .828 .803 r
.26867 .75092 m .2693 .75017 L .26465 .74384 L p F P
0 g
s
.837 .788 .804 r
.75893 .38269 m .75595 .3859 L .76087 .39311 L p F P
0 g
s
.837 .788 .804 r
.74604 .39656 m .75595 .3859 L .76087 .39311 L p F P
0 g
s
.837 .788 .804 r
.76087 .39311 m .75124 .40348 L .74604 .39656 L p F P
0 g
s
.736 .536 .623 r
.51183 .73508 m .4969 .73293 L p .50965 .74692 L F P
0 g
s
.736 .536 .623 r
.50965 .74692 m .51254 .73969 L .51183 .73508 L p F P
0 g
s
.618 .657 .866 r
.39883 .46832 m .41964 .46319 L p .39384 .45874 L F P
0 g
s
.618 .657 .866 r
.39384 .45874 m .39297 .45949 L .39883 .46832 L p F P
0 g
s
.87 .828 .803 r
.26465 .74384 m .26173 .74727 L .26867 .75092 L p F P
0 g
s
.869 .827 .804 r
.26867 .75092 m .25794 .76369 L .2531 .75744 L p F P
0 g
s
.869 .827 .804 r
.2531 .75744 m .26173 .74727 L .26867 .75092 L p F P
0 g
s
.552 .763 .976 r
.36506 .966 m .38571 .96316 L .39203 .96789 L p F P
0 g
s
.593 .765 .961 r
.38571 .96316 m .36506 .966 L .35861 .96211 L p F P
0 g
s
.936 .622 .42 r
.2424 .8802 m .24944 .88532 L .25048 .89556 L p F P
0 g
s
.935 .667 .506 r
.24944 .88532 m .2424 .8802 L .24282 .86961 L p F P
0 g
s
0 .37 .764 r
.69691 .19345 m .69247 .19129 L .69736 .19488 L p F P
0 g
s
0 .37 .764 r
.69736 .19488 m .70747 .1992 L .69691 .19345 L p F P
0 g
s
.051 .535 .888 r
.68475 .18933 m .69247 .19129 L .69736 .19488 L p F P
0 g
s
.385 .347 .693 r
.81159 .81014 m .81874 .80252 L p .81917 .81989 L F P
0 g
s
.385 .347 .693 r
.81917 .81989 m .81249 .81352 L .81159 .81014 L p F P
0 g
s
.4 .383 .724 r
.81159 .81014 m .81874 .80252 L .80799 .79463 L p F P
0 g
s
.575 .601 .842 r
.35347 .43173 m .33433 .4343 L .34558 .42094 L p F P
0 g
s
.572 .606 .848 r
.35969 .44261 m .35347 .43173 L .33433 .4343 L p F P
0 g
s
.943 .712 .56 r
.78183 .29282 m .78748 .299 L p .78273 .28242 L F P
0 g
s
.926 .735 .625 r
.78183 .29282 m .78644 .3026 L .78748 .299 L closepath p F P
0 g
s
.933 .771 .658 r
.2373 .82932 m .23884 .82514 L .23295 .81945 L p F P
0 g
s
.452 .86 .693 r
.33888 .2024 m .33362 .20562 L .33817 .20275 L closepath p F P
0 g
s
0 0 0 r
.31797 .21599 m .31574 .2183 L p .33817 .20275 L F P
0 g
s
0 0 0 r
.33817 .20275 m .33362 .20562 L .31797 .21599 L p F P
0 g
s
.635 .461 .63 r
.54127 .74718 m .53965 .7362 L .54111 .7349 L p F P
0 g
s
.69 .5 .624 r
.54127 .74718 m .53965 .7362 L .53339 .74743 L closepath p F P
0 g
s
.614 .804 .973 r
.64183 .96922 m .66372 .96397 L .66895 .96818 L p F P
0 g
s
.629 .751 .935 r
.66372 .96397 m .64183 .96922 L .63645 .96341 L p F P
0 g
s
.635 .461 .63 r
.54111 .7349 m .56297 .73098 L p .54127 .74718 L F P
0 g
s
.094 0 .2 r
.29576 .23663 m .29334 .23873 L .28688 .24976 L p F P
0 g
s
.612 .744 .939 r
.63666 .65567 m .62496 .65822 L .61954 .6522 L p F P
0 g
s
.7 .774 .909 r
.42932 .65564 m .41984 .65961 L .41574 .65291 L p F P
0 g
s
.315 .168 .516 r
.58819 .68286 m .57983 .68967 L .58026 .70009 L p F P
0 g
s
.214 .016 .381 r
.57983 .68967 m .58819 .68286 L .59149 .6717 L p F P
0 g
s
.428 .425 .753 r
.80179 .77987 m .80295 .77851 L p .80799 .79463 L F P
0 g
s
.442 .456 .778 r
.80179 .77987 m .80095 .77765 L .80295 .77851 L closepath p F P
0 g
s
.563 .644 .888 r
.685 .67451 m .68366 .6746 L .68434 .67346 L closepath p F P
0 g
s
.575 .662 .897 r
.6797 .66649 m .68434 .67346 L .68366 .6746 L p F P
0 g
s
.842 .387 .122 r
.28204 .92897 m .27388 .92433 L .26845 .91514 L p F P
0 g
s
.842 .38 .09 r
.26062 .91036 m .26845 .91514 L .27388 .92433 L p F P
0 g
s
.897 .511 .288 r
.25989 .9083 m .26062 .91036 L .26845 .91514 L p F P
0 g
s
.361 .679 .978 r
.65961 .17848 m .63946 .17843 L .63588 .17707 L p F P
0 g
s
.369 .719 .988 r
.63946 .17843 m .65961 .17848 L .66471 .18279 L p F P
0 g
s
.483 .516 .816 r
.77089 .73472 m .78479 .73817 L p .78452 .7485 L F P
0 g
s
.464 .513 .823 r
.77089 .73472 m .78479 .73817 L .7795 .72668 L p F P
0 g
s
.464 .513 .823 r
.7795 .72668 m .77678 .72596 L .77089 .73472 L p F P
0 g
s
.606 .82 .982 r
.69093 .96244 m .66895 .96818 L .66372 .96397 L p F P
0 g
s
.68 .692 .855 r
.55423 .95927 m .52847 .96022 L .52766 .95908 L p F P
0 g
s
.689 .696 .851 r
.52847 .96022 m .52766 .95908 L .525 .9602 L closepath p F P
0 g
s
.702 .678 .823 r
.50054 .96035 m .50217 .95954 L .525 .9602 L p F P
0 g
s
.683 .669 .83 r
.52187 .94985 m .50217 .95954 L .525 .9602 L p F P
0 g
s
.683 .669 .83 r
.525 .9602 m .52766 .95908 L .52187 .94985 L p F P
0 g
s
.384 .347 .694 r
.81523 .82381 m .81249 .81352 L .81917 .81989 L closepath p F P
0 g
s
.658 .788 .943 r
.50715 .47341 m .49618 .47687 L .48467 .47898 L p F P
0 g
s
.658 .788 .943 r
.50125 .46731 m .50715 .47341 L p .48467 .47898 L F P
0 g
s
.658 .788 .943 r
.48467 .47898 m .47996 .47463 L .50125 .46731 L p F P
0 g
s
.794 .298 0 r
.73485 .21704 m .74355 .22334 L .7485 .23043 L p F P
0 g
s
.783 .283 0 r
.75677 .23683 m .7485 .23043 L .74355 .22334 L p F P
0 g
s
.594 .746 .949 r
.56721 .47889 m .5666 .47892 L .55498 .47422 L p F P
0 g
s
.596 .63 .855 r
.3659 .45283 m .3865 .44893 L p .36427 .44185 L F P
0 g
s
.596 .63 .855 r
.36427 .44185 m .36112 .4451 L .3659 .45283 L p F P
0 g
s
.441 .456 .779 r
.80295 .77851 m .80095 .77765 L .79547 .76319 L p F P
0 g
s
.794 .827 .877 r
.3355 .6819 m .32595 .68894 L .33257 .69351 L p F P
0 g
s
.794 .827 .877 r
.33257 .69351 m .33895 .68879 L .3355 .6819 L p F P
0 g
s
.798 .825 .873 r
.31277 .69895 m .32595 .68894 L .33257 .69351 L p F P
0 g
s
.393 .389 .736 r
.81564 .78581 m .80799 .79463 L .81874 .80252 L p F P
0 g
s
.428 .425 .753 r
.80295 .77851 m .81564 .78581 L .80799 .79463 L p F P
0 g
s
.8 .781 .835 r
.71831 .43342 m .71795 .43372 L .71256 .42693 L p F P
0 g
s
.804 .782 .833 r
.71831 .43342 m .73604 .41811 L .73075 .41125 L p F P
0 g
s
.804 .782 .833 r
.73075 .41125 m .71323 .42637 L .71831 .43342 L p F P
0 g
s
.8 .781 .835 r
.71256 .42693 m .71323 .42637 L .71831 .43342 L p F P
0 g
s
.525 .37 .614 r
.5668 .71715 m .56154 .7194 L .56297 .73098 L p F P
0 g
s
.821 .785 .819 r
.73969 .41463 m .75124 .40348 L .74604 .39656 L p F P
0 g
s
.628 .831 .978 r
.469 .16497 m .46291 .16677 L .46899 .17201 L p F P
0 g
s
.628 .831 .978 r
.48704 .16266 m .469 .16497 L p .46899 .17201 L F P
0 g
s
.628 .831 .978 r
.46899 .17201 m .49015 .16505 L .48704 .16266 L p F P
0 g
s
.652 .726 .903 r
.58322 .46473 m .56158 .47287 L .56721 .47889 L p F P
0 g
s
.652 .726 .903 r
.56721 .47889 m .58881 .47203 L .58322 .46473 L p F P
0 g
s
.594 .746 .949 r
.55498 .47422 m .56158 .47287 L .56721 .47889 L p F P
0 g
s
.945 .677 .499 r
.24282 .86961 m .23613 .86431 L .23569 .87493 L p F P
0 g
s
.945 .677 .499 r
.23569 .87493 m .2424 .8802 L .24282 .86961 L p F P
0 g
s
.543 .632 .889 r
.685 .67451 m .70742 .67409 L .71267 .68256 L p F P
0 g
s
.537 .631 .892 r
.70215 .66577 m .70742 .67409 L .685 .67451 L p F P
0 g
s
.537 .631 .892 r
.68719 .66605 m .70215 .66577 L p .685 .67451 L F P
0 g
s
.537 .631 .892 r
.685 .67451 m .68434 .67346 L .68719 .66605 L p F P
0 g
s
.706 .689 .832 r
.50054 .96035 m .50217 .95954 L .49991 .95942 L closepath p F P
0 g
s
.708 .689 .829 r
.49991 .95942 m .50054 .96035 L p .47342 .96256 L F P
0 g
s
.22 0 .319 r
.78789 .91301 m .78877 .91244 L .79605 .89963 L p F P
0 g
s
.178 0 .274 r
.80605 .89289 m .79605 .89963 L .78877 .91244 L p F P
0 g
s
.28 .084 .426 r
.79605 .89963 m .80605 .89289 L .80622 .88327 L p F P
0 g
s
0 0 0 r
.74954 .9441 m .74457 .94687 L .74003 .94895 L p F P
0 g
s
.625 .819 .975 r
.50359 .16136 m .49015 .16505 L .4961 .1708 L p F P
0 g
s
.625 .819 .975 r
.51346 .16079 m .50359 .16136 L p .4961 .1708 L F P
0 g
s
.625 .819 .975 r
.4961 .1708 m .51739 .16407 L .51346 .16079 L p F P
0 g
s
.61 .057 0 r
.73035 .21292 m .73485 .21704 L .72581 .21096 L closepath p F P
0 g
s
.407 0 0 r
.73035 .21292 m .72581 .21096 L p .71762 .20505 L F P
0 g
s
.68 .692 .855 r
.52766 .95908 m .54906 .94961 L p .55423 .95927 L F P
0 g
s
.694 .649 .8 r
.54906 .94961 m .52766 .95908 L .52187 .94985 L p F P
0 g
s
.631 .834 .978 r
.46185 .16607 m .46291 .16677 L .44187 .17393 L p F P
0 g
s
.631 .834 .978 r
.44187 .17393 m .4381 .17122 L .46185 .16607 L p F P
0 g
s
.5 .498 .786 r
.28845 .38521 m .29174 .38544 L .28966 .38813 L closepath p F P
0 g
s
.731 .752 .869 r
.63769 .45689 m .616 .46903 L .62145 .47628 L p F P
0 g
s
.731 .752 .869 r
.62145 .47628 m .64308 .46424 L .63769 .45689 L p F P
0 g
s
.7 .751 .892 r
.60194 .4756 m .616 .46903 L .62145 .47628 L p F P
0 g
s
.821 .785 .819 r
.74604 .39656 m .73469 .40749 L .73969 .41463 L p F P
0 g
s
.819 .785 .82 r
.73075 .41125 m .73469 .40749 L .73969 .41463 L p F P
0 g
s
.819 .785 .82 r
.73969 .41463 m .73604 .41811 L .73075 .41125 L p F P
0 g
s
.637 .843 .979 r
.43562 .16965 m .4381 .17122 L .4154 .17752 L p F P
0 g
s
.637 .843 .979 r
.4154 .17752 m .41469 .17704 L .43562 .16965 L p F P
0 g
s
.526 .599 .87 r
.71792 .69147 m .74064 .69267 L p .73843 .70147 L F P
0 g
s
.513 .597 .875 r
.73542 .6837 m .74064 .69267 L .71792 .69147 L p F P
0 g
s
.513 .597 .875 r
.71695 .6826 m .73542 .6837 L p .71792 .69147 L F P
0 g
s
.513 .597 .875 r
.71792 .69147 m .7151 .68657 L .71695 .6826 L p F P
0 g
s
.388 .331 .672 r
.26524 .31254 m .26533 .31299 L .26502 .31281 L closepath p F P
0 g
s
.39 .33 .67 r
.26502 .31281 m .26533 .31299 L .26793 .32529 L p F P
0 g
s
.705 .518 .632 r
.53339 .74743 m .51379 .74733 L .51254 .73969 L p F P
0 g
s
.741 .542 .625 r
.51379 .74733 m .51254 .73969 L .50965 .74692 L closepath p F P
0 g
s
.778 .822 .887 r
.35364 .67881 m .33895 .68879 L .3355 .6819 L p F P
0 g
s
.705 .69 .833 r
.51605 .93964 m .52187 .94985 L .50217 .95954 L p F P
0 g
s
.705 .69 .833 r
.49468 .95174 m .51605 .93964 L p .50217 .95954 L F P
0 g
s
.705 .69 .833 r
.50217 .95954 m .49991 .95942 L .49468 .95174 L p F P
0 g
s
.708 .689 .829 r
.47342 .96256 m .48174 .95828 L .49991 .95942 L p F P
0 g
s
.716 .715 .848 r
.47342 .96256 m .48174 .95828 L .46872 .95649 L closepath p F P
0 g
s
.708 .71 .85 r
.46872 .95649 m .47342 .96256 L p .44628 .96512 L F P
0 g
s
.382 .29 .626 r
.26524 .31254 m .27927 .29762 L p .27263 .29117 L F P
0 g
s
.416 .349 .675 r
.28186 .3103 m .27927 .29762 L .26524 .31254 L p F P
0 g
s
.416 .349 .675 r
.27496 .31757 m .28186 .3103 L p .26524 .31254 L F P
0 g
s
.416 .349 .675 r
.26524 .31254 m .26533 .31299 L .27496 .31757 L p F P
0 g
s
.947 .669 .478 r
.78273 .28242 m .77601 .27563 L .77618 .26646 L p F P
0 g
s
.931 .701 .569 r
.78129 .29149 m .78273 .28242 L .77601 .27563 L p F P
0 g
s
.943 .712 .56 r
.78273 .28242 m .78129 .29149 L .78183 .29282 L p F P
0 g
s
.707 .691 .832 r
.49991 .95942 m .49468 .95174 L .48174 .95828 L closepath p F P
0 g
s
.614 .813 .977 r
.5307 .16078 m .51739 .16407 L .52321 .17003 L p F P
0 g
s
.614 .813 .977 r
.54133 .16087 m .5307 .16078 L p .52321 .17003 L F P
0 g
s
.614 .813 .977 r
.52321 .17003 m .54464 .16373 L .54133 .16087 L p F P
0 g
s
.361 .679 .978 r
.65868 .17783 m .65961 .17848 L p .63588 .17707 L F P
0 g
s
.361 .679 .978 r
.64708 .17418 m .65868 .17783 L p .63588 .17707 L F P
0 g
s
.361 .679 .978 r
.63588 .17707 m .63206 .17335 L .64708 .17418 L p F P
0 g
s
.512 .759 .985 r
.62451 .17432 m .63588 .17707 L .63206 .17335 L closepath p F P
0 g
s
.502 .492 .779 r
.30217 .3714 m .28239 .37056 L .28845 .38521 L p F P
0 g
s
.502 .492 .779 r
.30255 .37235 m .30217 .3714 L p .28845 .38521 L F P
0 g
s
.502 .492 .779 r
.28845 .38521 m .29174 .38544 L .30255 .37235 L p F P
0 g
s
.49 .492 .786 r
.28222 .37055 m .28239 .37056 L .28845 .38521 L p F P
0 g
s
.417 .348 .673 r
.26533 .31299 m .27496 .31757 L .26793 .32529 L closepath p F P
0 g
s
.756 .764 .859 r
.67003 .45791 m .66233 .4629 L .65579 .45654 L p F P
0 g
s
.922 .735 .632 r
.78644 .3026 m .78451 .30927 L p .78119 .29213 L F P
0 g
s
.922 .735 .632 r
.78119 .29213 m .78183 .29282 L .78644 .3026 L p F P
0 g
s
.555 .652 .9 r
.68434 .67346 m .6797 .66649 L .68719 .66605 L closepath p F P
0 g
s
.885 .823 .782 r
.25794 .76369 m .2531 .75744 L .24323 .77056 L p F P
0 g
s
.885 .823 .782 r
.24323 .77056 m .24816 .77675 L .25794 .76369 L p F P
0 g
s
.933 .771 .658 r
.23295 .81945 m .23013 .82697 L .2373 .82932 L p F P
0 g
s
.932 .771 .66 r
.2373 .82932 m .23456 .83669 L .22859 .83104 L p F P
0 g
s
.932 .771 .66 r
.22859 .83104 m .23013 .82697 L .2373 .82932 L p F P
0 g
s
.68 .692 .854 r
.55492 .95924 m .55478 .95906 L .55423 .95927 L closepath p F P
0 g
s
.68 .692 .855 r
.54906 .94961 m .55478 .95906 L .55423 .95927 L p F P
0 g
s
.678 .691 .855 r
.5763 .95097 m .58011 .95713 L .55492 .95924 L p F P
0 g
s
.678 .691 .855 r
.55492 .95924 m .55478 .95906 L .5763 .95097 L p F P
0 g
s
.351 .297 .657 r
.81917 .81989 m .81523 .82381 L .81813 .83667 L p F P
0 g
s
.387 .321 .661 r
.81665 .83796 m .81813 .83667 L .81523 .82381 L p F P
0 g
s
.654 .759 .927 r
.39203 .96789 m .41295 .96156 L .41913 .96722 L p F P
0 g
s
.678 .754 .909 r
.41295 .96156 m .39203 .96789 L .38571 .96316 L p F P
0 g
s
.467 .495 .803 r
.79011 .75031 m .78452 .7485 L p .79525 .76309 L F P
0 g
s
.455 .489 .805 r
.79011 .75031 m .78452 .7485 L .78762 .74439 L closepath p F P
0 g
s
.483 .516 .816 r
.78479 .73817 m .78762 .74439 L .78452 .7485 L p F P
0 g
s
.707 .753 .888 r
.59436 .47903 m .60194 .4756 L .59341 .46987 L p F P
0 g
s
.707 .753 .888 r
.59341 .46987 m .58881 .47203 L .59436 .47903 L p F P
0 g
s
.678 .645 .809 r
.5763 .95097 m .55478 .95906 L .54906 .94961 L p F P
0 g
s
.708 .71 .85 r
.44628 .96512 m .46486 .95611 L .46872 .95649 L p F P
0 g
s
.724 .705 .832 r
.46486 .95611 m .44628 .96512 L .44021 .95845 L p F P
0 g
s
.694 .737 .884 r
.41913 .96722 m .44021 .95845 L .44628 .96512 L p F P
0 g
s
.89 .479 .216 r
.7485 .23043 m .75677 .23683 L .75981 .2447 L p F P
0 g
s
.895 .48 .191 r
.76763 .25122 m .75981 .2447 L .75677 .23683 L p F P
0 g
s
.805 .583 .601 r
.4969 .73293 m .48387 .72926 L .48634 .71832 L p F P
0 g
s
.855 .63 .597 r
.47595 .71382 m .48634 .71832 L .48387 .72926 L p F P
0 g
s
.851 .613 .577 r
.48634 .71832 m .47595 .71382 L .47747 .70321 L p F P
0 g
s
.409 .424 .764 r
.80991 .76977 m .80295 .77851 L .81564 .78581 L p F P
0 g
s
.441 .456 .779 r
.79547 .76319 m .80991 .76977 L .80295 .77851 L p F P
0 g
s
.887 .779 .737 r
.7786 .35712 m .77306 .35017 L .78031 .3383 L p F P
0 g
s
.866 .78 .764 r
.77678 .35964 m .7786 .35712 L .77306 .35017 L p F P
0 g
s
.72 .188 0 r
.29864 .94204 m .29025 .93752 L .28204 .92897 L p F P
0 g
s
.703 .165 0 r
.27388 .92433 m .28204 .92897 L .29025 .93752 L p F P
0 g
s
.898 .661 .572 r
.46913 .69804 m .47747 .70321 L .47595 .71382 L p F P
0 g
s
.901 .638 .53 r
.47747 .70321 m .46913 .69804 L .46966 .68778 L p F P
0 g
s
.916 .758 .671 r
.78605 .32699 m .78013 .32007 L .78451 .30927 L p F P
0 g
s
.898 .764 .706 r
.78013 .32007 m .78605 .32699 L .78031 .3383 L p F P
0 g
s
0 0 0 r
.29576 .23663 m .31262 .22412 L .31574 .2183 L p F P
0 g
s
.18 0 .237 r
.31061 .23133 m .31262 .22412 L .29576 .23663 L p F P
0 g
s
.18 0 .237 r
.29576 .23663 m .29371 .24385 L .31061 .23133 L p F P
0 g
s
.094 0 .2 r
.28688 .24976 m .29371 .24385 L .29576 .23663 L p F P
0 g
s
.584 .897 .986 r
.42924 .16735 m .40823 .17433 L .41469 .17704 L p F P
0 g
s
.584 .897 .986 r
.41469 .17704 m .43562 .16965 L .42924 .16735 L p F P
0 g
s
.711 .73 .866 r
.44021 .95845 m .41913 .96722 L .41295 .96156 L p F P
0 g
s
.588 .808 .984 r
.55371 .16184 m .54464 .16373 L .55034 .16965 L p F P
0 g
s
.588 .808 .984 r
.57074 .1631 m .55371 .16184 L p .55034 .16965 L F P
0 g
s
.588 .808 .984 r
.55034 .16965 m .57193 .16413 L .57074 .1631 L p F P
0 g
s
.644 .697 .884 r
.45136 .47263 m .4528 .47457 L .44423 .4772 L closepath p F P
0 g
s
.937 .658 .487 r
.77225 .26278 m .77618 .26646 L .77601 .27563 L p F P
0 g
s
.442 .458 .78 r
.79547 .76319 m .79525 .76309 L .79538 .76294 L closepath p F P
0 g
s
.467 .495 .803 r
.79525 .76309 m .79538 .76294 L .79011 .75031 L p F P
0 g
s
.947 .72 .562 r
.23788 .8534 m .23154 .84793 L .22976 .85887 L p F P
0 g
s
.947 .72 .562 r
.22976 .85887 m .23613 .86431 L .23788 .8534 L p F P
0 g
s
.942 .68 .51 r
.46295 .68206 m .46966 .68778 L .46913 .69804 L p F P
0 g
s
.945 .631 .41 r
.46966 .68778 m .46295 .68206 L .4622 .67435 L p F P
0 g
s
.736 .536 .623 r
.4969 .73293 m .49329 .74425 L .50965 .74692 L p F P
0 g
s
.813 .6 .614 r
.48387 .72926 m .4969 .73293 L .49329 .74425 L p F P
0 g
s
.866 .78 .764 r
.77306 .35017 m .77187 .35181 L .77678 .35964 L p F P
0 g
s
.867 .779 .762 r
.76403 .36269 m .77187 .35181 L .77678 .35964 L p F P
0 g
s
.867 .779 .762 r
.77678 .35964 m .76964 .36959 L .76403 .36269 L p F P
0 g
s
.924 .588 .384 r
.75981 .2447 m .76763 .25122 L .76895 .25979 L p F P
0 g
s
.934 .597 .37 r
.77225 .26278 m .76895 .25979 L .76763 .25122 L p F P
0 g
s
.485 .901 .858 r
.3806 .18219 m .38397 .18185 L .36371 .19097 L p F P
0 g
s
.485 .901 .858 r
.36371 .19097 m .35972 .19149 L .3806 .18219 L p F P
0 g
s
.429 .45 .78 r
.80991 .76977 m .79547 .76319 L .79538 .76294 L p F P
0 g
s
.429 .45 .78 r
.79538 .76294 m .80158 .75441 L p .80991 .76977 L F P
0 g
s
.444 .481 .803 r
.79538 .76294 m .79011 .75031 L .80158 .75441 L closepath p F P
0 g
s
.626 .841 .982 r
.49618 .47687 m .50779 .47384 L .50715 .47341 L closepath p F P
0 g
s
.575 .668 .902 r
.65223 .66106 m .67439 .65869 L .6797 .66649 L p F P
0 g
s
.575 .676 .908 r
.67439 .65869 m .65223 .66106 L .64685 .6536 L p F P
0 g
s
.227 .044 .412 r
.8129 .87812 m .80622 .88327 L .80605 .89289 L p F P
0 g
s
.292 .144 .502 r
.80622 .88327 m .8129 .87812 L .81292 .86716 L p F P
0 g
s
.765 .766 .854 r
.67003 .45791 m .69047 .44392 L .68418 .43741 L p F P
0 g
s
.765 .766 .854 r
.68418 .43741 m .66475 .45071 L .67003 .45791 L p F P
0 g
s
.756 .764 .859 r
.65579 .45654 m .66475 .45071 L .67003 .45791 L p F P
0 g
s
.875 .484 .019 r
.4622 .67435 m .46155 .67244 L .4593 .6693 L closepath p F P
0 g
s
.221 .015 .374 r
.27705 .26592 m .28475 .25909 L .28688 .24976 L p F P
0 g
s
.319 .154 .494 r
.28475 .25909 m .27705 .26592 L .27689 .27544 L p F P
0 g
s
.352 .266 .618 r
.81926 .84297 m .81665 .83796 L .81813 .83667 L closepath p F P
0 g
s
.218 .629 .954 r
.66098 .17875 m .65961 .17848 L .66471 .18279 L p F P
0 g
s
.218 .629 .954 r
.66471 .18279 m .67301 .18401 L .66098 .17875 L p F P
0 g
s
.607 .747 .944 r
.42932 .65564 m .43574 .65465 L .43336 .64739 L p F P
0 g
s
.607 .747 .944 r
.43336 .64739 m .42314 .64967 L .42932 .65564 L p F P
0 g
s
.7 .774 .909 r
.41574 .65291 m .42314 .64967 L .42932 .65564 L p F P
0 g
s
.715 .716 .849 r
.48879 .94235 m .49468 .95174 L .48174 .95828 L p F P
0 g
s
.715 .716 .849 r
.46747 .95487 m .48879 .94235 L p .48174 .95828 L F P
0 g
s
.715 .716 .849 r
.48174 .95828 m .46872 .95649 L .46747 .95487 L p F P
0 g
s
.691 .504 .63 r
.53339 .74743 m .54127 .74718 L .54318 .75937 L p F P
0 g
s
.691 .504 .63 r
.54318 .75937 m .52597 .75991 L .53339 .74743 L p F P
0 g
s
.706 .523 .639 r
.51379 .74733 m .53339 .74743 L .52597 .75991 L p F P
0 g
s
.658 .679 .858 r
.58195 .96013 m .6036 .95346 L .60918 .96183 L p F P
0 g
s
.656 .659 .841 r
.60355 .95336 m .6036 .95346 L .58195 .96013 L p F P
0 g
s
.656 .659 .841 r
.58195 .96013 m .58011 .95713 L .60355 .95336 L p F P
0 g
s
.635 .672 .868 r
.44067 .45712 m .41964 .46319 L .42575 .47223 L p F P
0 g
s
.635 .672 .868 r
.42575 .47223 m .44675 .46616 L .44067 .45712 L p F P
0 g
s
.133 0 .187 r
.7877 .91381 m .78877 .91244 L .78789 .91301 L closepath p F P
0 g
s
.706 .523 .639 r
.52597 .75991 m .516 .75986 L .51379 .74733 L p F P
0 g
s
.742 .547 .63 r
.50965 .74692 m .51379 .74733 L .516 .75986 L p F P
0 g
s
.925 .795 .697 r
.23854 .80754 m .23304 .80165 L .22741 .81359 L p F P
0 g
s
.925 .795 .697 r
.22741 .81359 m .23295 .81945 L .23854 .80754 L p F P
0 g
s
.527 .367 .607 r
.58127 .71119 m .5668 .71715 L .58126 .72325 L p F P
0 g
s
.521 .346 .584 r
.58026 .70009 m .58127 .71119 L .5668 .71715 L p F P
0 g
s
.525 .37 .614 r
.56297 .73098 m .58126 .72325 L .5668 .71715 L p F P
0 g
s
.771 .822 .893 r
.36426 .66294 m .3471 .67405 L .35364 .67881 L p F P
0 g
s
.771 .822 .893 r
.35364 .67881 m .36714 .67006 L .36426 .66294 L p F P
0 g
s
.778 .822 .887 r
.3355 .6819 m .3471 .67405 L .35364 .67881 L p F P
0 g
s
.567 .77 .974 r
.57467 .16371 m .57193 .16413 L .57751 .16979 L p F P
0 g
s
.567 .77 .974 r
.57751 .16979 m .59251 .1668 L .57467 .16371 L p F P
0 g
s
.516 0 0 r
.70747 .1992 m .71762 .20505 L .72566 .21087 L p F P
0 g
s
.407 0 0 r
.72581 .21096 m .72566 .21087 L .71762 .20505 L p F P
0 g
s
.565 .584 .831 r
.32693 .42291 m .34558 .42094 L p .322 .41111 L F P
0 g
s
.565 .584 .831 r
.322 .41111 m .32113 .4121 L .32693 .42291 L p F P
0 g
s
.629 .461 .636 r
.54318 .75937 m .54127 .74718 L .56459 .74282 L p F P
0 g
s
.635 .461 .63 r
.56297 .73098 m .56459 .74282 L .54127 .74718 L p F P
0 g
s
.498 .571 .86 r
.75953 .71314 m .75109 .71209 L .74587 .70224 L p F P
0 g
s
.472 .46 .763 r
.28232 .3704 m .28222 .37055 L p .27622 .35431 L F P
0 g
s
.49 .492 .786 r
.28232 .3704 m .28239 .37056 L .28222 .37055 L closepath p F P
0 g
s
.452 .4 .709 r
.27496 .31757 m .26793 .32529 L .2707 .3357 L p F P
0 g
s
.515 .506 .785 r
.28239 .37056 m .30217 .3714 L p .29452 .35615 L F P
0 g
s
.515 .506 .785 r
.29452 .35615 m .28232 .3704 L .28239 .37056 L p F P
0 g
s
.492 .472 .763 r
.27644 .35434 m .29452 .35615 L .28232 .3704 L closepath p F P
0 g
s
.472 .46 .763 r
.27622 .35431 m .27644 .35434 L .28232 .3704 L p F P
0 g
s
.524 .525 .798 r
.30255 .37235 m .30832 .38535 L .29174 .38544 L closepath p F P
0 g
s
.523 .531 .805 r
.31096 .39132 m .30832 .38535 L .29174 .38544 L p F P
0 g
s
.523 .531 .805 r
.30489 .39899 m .31096 .39132 L p .29174 .38544 L F P
0 g
s
.742 .547 .63 r
.516 .75986 m .50459 .75871 L .50965 .74692 L p F P
0 g
s
.775 .573 .625 r
.49329 .74425 m .50965 .74692 L .50459 .75871 L p F P
0 g
s
.237 .029 .381 r
.29371 .24385 m .28688 .24976 L .28475 .25909 L p F P
0 g
s
.533 .621 .885 r
.7151 .68657 m .71267 .68256 L .71695 .6826 L closepath p F P
0 g
s
.232 .666 .957 r
.33318 .95713 m .3294 .95575 L .33177 .95698 L closepath p F P
0 g
s
.429 .754 .995 r
.63206 .17335 m .62451 .17432 L .60944 .17021 L p F P
0 g
s
.706 .748 .885 r
.616 .46903 m .60194 .4756 L .59341 .46987 L p F P
0 g
s
.049 .535 .887 r
.67301 .18401 m .68475 .18933 L .69247 .19129 L p F P
0 g
s
0 0 .067 r
.78877 .91244 m .8035 .90255 L p .78553 .92055 L F P
0 g
s
0 0 .067 r
.78553 .92055 m .7877 .91381 L .78877 .91244 L p F P
0 g
s
.178 0 .274 r
.80521 .89977 m .80605 .89289 L p .78877 .91244 L F P
0 g
s
.178 0 .274 r
.78877 .91244 m .8035 .90255 L .80521 .89977 L p F P
0 g
s
.361 .806 .658 r
.35738 .19249 m .35972 .19149 L .33888 .2024 L p F P
0 g
s
.361 .806 .658 r
.33888 .2024 m .33817 .20275 L .35738 .19249 L p F P
0 g
s
.504 .579 .863 r
.74587 .70224 m .73843 .70147 L .74198 .69502 L closepath p F P
0 g
s
.526 .599 .87 r
.74064 .69267 m .74198 .69502 L .73843 .70147 L p F P
0 g
s
.275 .132 .498 r
.82173 .85999 m .81292 .86716 L .8129 .87812 L p F P
0 g
s
.326 .212 .567 r
.81292 .86716 m .82173 .85999 L .8203 .84873 L p F P
0 g
s
.903 .821 .757 r
.24662 .77912 m .24816 .77675 L .24323 .77056 L p F P
0 g
s
.473 .894 .887 r
.71796 .95754 m .7243 .95515 L .71879 .95753 L closepath p F P
0 g
s
.456 .884 .815 r
.74003 .94895 m .7243 .95515 L .71879 .95753 L p F P
0 g
s
.706 .786 .914 r
.41241 .64591 m .39578 .65384 L .4021 .6591 L p F P
0 g
s
.706 .786 .914 r
.4021 .6591 m .41574 .65291 L .41241 .64591 L p F P
0 g
s
.123 0 .117 r
.77458 .92696 m .78553 .92055 L .7877 .91381 L closepath p F P
0 g
s
.97 .656 .353 r
.4622 .67435 m .4593 .6693 L p .45758 .67586 L F P
0 g
s
.97 .656 .353 r
.45758 .67586 m .46295 .68206 L .4622 .67435 L p F P
0 g
s
0 0 0 r
.76373 .93685 m .76634 .93356 L .77458 .92696 L p F P
0 g
s
.585 .611 .844 r
.35969 .44261 m .36427 .44185 L .36112 .4451 L closepath p F P
0 g
s
.851 .78 .782 r
.76403 .36269 m .76964 .36959 L .75893 .38269 L p F P
0 g
s
.452 .4 .709 r
.2707 .3357 m .27374 .33669 L p .27496 .31757 L F P
0 g
s
.441 .391 .706 r
.2707 .3357 m .27374 .33669 L .2716 .33912 L closepath p F P
0 g
s
0 .379 .753 r
.29871 .9421 m .29898 .94221 L p .32359 .953 L F P
0 g
s
.606 .038 0 r
.29871 .9421 m .29864 .94204 L .29898 .94221 L closepath p F P
0 g
s
.922 .735 .632 r
.78451 .30927 m .77813 .30244 L .78119 .29213 L p F P
0 g
s
.907 .745 .67 r
.77813 .30244 m .78451 .30927 L .78013 .32007 L p F P
0 g
s
.945 .753 .613 r
.23456 .83669 m .22859 .83104 L .22553 .84231 L p F P
0 g
s
.945 .753 .613 r
.22553 .84231 m .23154 .84793 L .23456 .83669 L p F P
0 g
s
.333 .253 .615 r
.81813 .83667 m .82591 .82899 L p .82153 .84758 L F P
0 g
s
.333 .253 .615 r
.82153 .84758 m .81926 .84297 L .81813 .83667 L p F P
0 g
s
.351 .297 .657 r
.81813 .83667 m .82591 .82899 L .81917 .81989 L p F P
0 g
s
.44 .417 .737 r
.27622 .35431 m .27636 .35412 L .2716 .33912 L p F P
0 g
s
.472 .461 .764 r
.27636 .35412 m .27644 .35434 L .27622 .35431 L closepath p F P
0 g
s
.903 .821 .757 r
.24323 .77056 m .2395 .77623 L .24662 .77912 L p F P
0 g
s
.901 .821 .759 r
.24662 .77912 m .23991 .78938 L .23485 .78327 L p F P
0 g
s
.901 .821 .759 r
.23485 .78327 m .2395 .77623 L .24662 .77912 L p F P
0 g
s
.664 .664 .84 r
.59797 .94366 m .60355 .95336 L .58011 .95713 L p F P
0 g
s
.664 .664 .84 r
.58011 .95713 m .5763 .95097 L .59797 .94366 L p F P
0 g
s
.286 .691 .973 r
.33318 .95713 m .35211 .95786 L p .32514 .95345 L F P
0 g
s
.286 .691 .973 r
.32514 .95345 m .3294 .95575 L .33318 .95713 L p F P
0 g
s
.548 .913 .955 r
.40543 .17393 m .40823 .17433 L .38736 .18235 L p F P
0 g
s
.548 .913 .955 r
.38736 .18235 m .38397 .18185 L .40543 .17393 L p F P
0 g
s
.56 0 0 r
.29864 .94204 m .29871 .9421 L .29192 .93878 L p F P
0 g
s
.56 0 0 r
.29192 .93878 m .29025 .93752 L .29864 .94204 L p F P
0 g
s
.612 .744 .939 r
.64145 .64644 m .64205 .64722 L .63666 .65567 L p F P
0 g
s
.612 .744 .939 r
.61954 .6522 m .64145 .64644 L p .63666 .65567 L F P
0 g
s
.613 .706 .911 r
.64685 .6536 m .63666 .65567 L .64205 .64722 L closepath p F P
0 g
s
0 0 0 r
.77458 .92696 m .78553 .92055 L p .76373 .93685 L F P
0 g
s
.473 .438 .738 r
.27374 .33669 m .2716 .33912 L .27636 .35412 L p F P
0 g
s
.53 .381 .623 r
.56459 .74282 m .56297 .73098 L .58126 .72325 L p F P
0 g
s
0 .379 .753 r
.32359 .953 m .31486 .9486 L .29871 .9421 L p F P
0 g
s
0 .36 .723 r
.31486 .9486 m .29871 .9421 L .29192 .93878 L p F P
0 g
s
.5 .477 .763 r
.27644 .35434 m .29452 .35615 L p .28942 .33942 L F P
0 g
s
.5 .477 .763 r
.28942 .33942 m .27636 .35412 L .27644 .35434 L p F P
0 g
s
.473 .438 .738 r
.27636 .35412 m .28942 .33942 L .27374 .33669 L p F P
0 g
s
.644 .705 .891 r
.60918 .96183 m .63098 .9562 L .63645 .96341 L p F P
0 g
s
.646 .673 .861 r
.63098 .9562 m .60918 .96183 L .6036 .95346 L p F P
0 g
s
.61 .641 .857 r
.39267 .45901 m .39384 .45874 L .39297 .45949 L closepath p F P
0 g
s
0 0 0 r
.31574 .2183 m .33378 .20688 L .33817 .20275 L p F P
0 g
s
.07 0 .007 r
.33113 .21178 m .33378 .20688 L .31574 .2183 L p F P
0 g
s
.07 0 .007 r
.32837 .21414 m .33113 .21178 L p .31574 .2183 L F P
0 g
s
.07 0 .007 r
.31574 .2183 m .31262 .22412 L .32837 .21414 L p F P
0 g
s
.511 .754 .984 r
.60473 .17079 m .60944 .17021 L .60213 .16827 L closepath p F P
0 g
s
.537 .55 .816 r
.31096 .39132 m .3145 .39856 L .30489 .39899 L closepath p F P
0 g
s
.536 .556 .823 r
.32069 .41121 m .3145 .39856 L .30489 .39899 L p F P
0 g
s
.609 .635 .851 r
.40734 .44408 m .3865 .44893 L .39267 .45901 L p F P
0 g
s
.609 .635 .851 r
.40887 .4466 m .40734 .44408 L p .39267 .45901 L F P
0 g
s
.609 .635 .851 r
.39267 .45901 m .39384 .45874 L .40887 .4466 L p F P
0 g
s
.902 .508 .258 r
.26062 .91036 m .25989 .9083 L .25294 .90482 L p F P
0 g
s
.707 .802 .924 r
.61409 .64686 m .61348 .64724 L .6129 .65514 L p F P
0 g
s
.707 .802 .924 r
.6129 .65514 m .61954 .6522 L .61409 .64686 L p F P
0 g
s
.63 .825 .976 r
.56158 .47287 m .55498 .47422 L .53478 .47305 L p F P
0 g
s
.585 .605 .839 r
.37408 .42808 m .35347 .43173 L .35969 .44261 L p F P
0 g
s
.585 .605 .839 r
.37564 .43086 m .37408 .42808 L p .35969 .44261 L F P
0 g
s
.585 .605 .839 r
.35969 .44261 m .36427 .44185 L .37564 .43086 L p F P
0 g
s
0 0 0 r
.35303 .19653 m .35738 .19249 L .33817 .20275 L p F P
0 g
s
0 0 0 r
.33817 .20275 m .33378 .20688 L .35303 .19653 L p F P
0 g
s
.443 .482 .805 r
.80158 .75441 m .79011 .75031 L .78762 .74439 L p F P
0 g
s
.777 .768 .845 r
.69165 .44304 m .69047 .44392 L .68418 .43741 L p F P
0 g
s
.756 .816 .9 r
.3747 .66552 m .36714 .67006 L .36426 .66294 L p F P
0 g
s
.654 .701 .881 r
.45136 .47263 m .4528 .47457 L .47397 .46747 L p F P
0 g
s
.898 .764 .706 r
.78031 .3383 m .77434 .33142 L .78013 .32007 L p F P
0 g
s
.88 .768 .734 r
.77434 .33142 m .78031 .3383 L .77306 .35017 L p F P
0 g
s
.706 .713 .854 r
.46872 .95649 m .46747 .95487 L .46486 .95611 L closepath p F P
0 g
s
.782 .77 .841 r
.69165 .44304 m .71256 .42693 L .70649 .42031 L p F P
0 g
s
.782 .77 .841 r
.70649 .42031 m .68644 .43573 L .69165 .44304 L p F P
0 g
s
.777 .768 .845 r
.68418 .43741 m .68644 .43573 L .69165 .44304 L p F P
0 g
s
.744 .756 .862 r
.64308 .46424 m .65579 .45654 L .64838 .4504 L p F P
0 g
s
.744 .756 .862 r
.64838 .4504 m .63769 .45689 L .64308 .46424 L p F P
0 g
s
.351 .225 .565 r
.5893 .69276 m .58026 .70009 L .58127 .71119 L p F P
0 g
s
.315 .168 .516 r
.58026 .70009 m .5893 .69276 L .58819 .68286 L p F P
0 g
s
.937 .658 .487 r
.77601 .27563 m .77506 .27475 L .77225 .26278 L p F P
0 g
s
.932 .656 .494 r
.76895 .25979 m .77225 .26278 L .77506 .27475 L p F P
0 g
s
.694 .649 .8 r
.52187 .94985 m .5433 .939 L .54906 .94961 L p F P
0 g
s
.701 .632 .777 r
.5433 .939 m .52187 .94985 L .51605 .93964 L p F P
0 g
s
.624 .84 .983 r
.52856 .46675 m .53435 .47273 L p .50779 .47384 L F P
0 g
s
.624 .84 .983 r
.50779 .47384 m .50715 .47341 L .52856 .46675 L p F P
0 g
s
.618 .651 .861 r
.40887 .4466 m .4135 .45384 L .39384 .45874 L closepath p F P
0 g
s
.618 .657 .866 r
.41964 .46319 m .4135 .45384 L .39384 .45874 L p F P
0 g
s
.499 .898 .936 r
.7243 .95515 m .71796 .95754 L .71306 .95606 L p F P
0 g
s
.532 .889 .978 r
.69093 .96244 m .71306 .95606 L .71796 .95754 L p F P
0 g
s
.942 .712 .56 r
.78129 .29149 m .78119 .29213 L .78183 .29282 L closepath p F P
0 g
s
.716 .647 .779 r
.51605 .93964 m .49468 .95174 L .48879 .94235 L p F P
0 g
s
.452 .625 .927 r
.4502 .65585 m .43574 .65465 L .43336 .64739 L p F P
0 g
s
.288 .559 .929 r
.43574 .65465 m .4502 .65585 L .45621 .66545 L p F P
0 g
s
.931 .701 .569 r
.77601 .27563 m .7758 .27685 L .78129 .29149 L p F P
0 g
s
.932 .699 .564 r
.77433 .2854 m .7758 .27685 L .78129 .29149 L p F P
0 g
s
.932 .699 .564 r
.78129 .29149 m .78119 .29213 L .77433 .2854 L p F P
0 g
s
.803 .311 0 r
.73974 .22415 m .73485 .21704 L .72581 .21096 L p F P
0 g
s
.794 .298 0 r
.7485 .23043 m .73974 .22415 L .73485 .21704 L p F P
0 g
s
.724 .705 .832 r
.44021 .95845 m .44838 .95382 L .46486 .95611 L p F P
0 g
s
.702 .697 .842 r
.46149 .94657 m .44838 .95382 L .46486 .95611 L p F P
0 g
s
.702 .697 .842 r
.46486 .95611 m .46747 .95487 L .46149 .94657 L p F P
0 g
s
.838 .84 .847 r
.28337 .72472 m .29401 .71475 L .29028 .70799 L p F P
0 g
s
.819 .836 .862 r
.30473 .70565 m .29401 .71475 L .29028 .70799 L p F P
0 g
s
.714 .537 .648 r
.52597 .75991 m .54318 .75937 L p .51836 .77257 L F P
0 g
s
.714 .537 .648 r
.51836 .77257 m .51829 .7722 L .52597 .75991 L p F P
0 g
s
.706 .527 .643 r
.51829 .7722 m .52597 .75991 L .516 .75986 L closepath p F P
0 g
s
.838 .84 .847 r
.29028 .70799 m .27648 .72081 L .28337 .72472 L p F P
0 g
s
.837 .837 .846 r
.28337 .72472 m .27814 .72966 L .27412 .72302 L p F P
0 g
s
.837 .837 .846 r
.27412 .72302 m .27648 .72081 L .28337 .72472 L p F P
0 g
s
.721 .536 .64 r
.516 .75986 m .50459 .75871 L p .51809 .77255 L F P
0 g
s
.721 .536 .64 r
.51809 .77255 m .51829 .7722 L .516 .75986 L p F P
0 g
s
.531 .626 .891 r
.71695 .6826 m .71267 .68256 L .70742 .67409 L p F P
0 g
s
.678 .645 .809 r
.54906 .94961 m .57059 .9405 L .5763 .95097 L p F P
0 g
s
.682 .625 .785 r
.57059 .9405 m .54906 .94961 L .5433 .939 L p F P
0 g
s
.851 .78 .782 r
.75893 .38269 m .75325 .37584 L .76403 .36269 L p F P
0 g
s
.832 .778 .801 r
.75595 .3859 m .75893 .38269 L .75325 .37584 L p F P
0 g
s
.855 .837 .827 r
.27814 .72966 m .27412 .72302 L .26045 .7373 L p F P
0 g
s
.855 .837 .827 r
.26045 .7373 m .26465 .74384 L .27814 .72966 L p F P
0 g
s
.97 .656 .353 r
.4593 .6693 m .4565 .66613 L .45758 .67586 L p F P
0 g
s
.864 .439 .006 r
.4565 .66613 m .4593 .6693 L .45621 .66545 L closepath p F P
0 g
s
.922 .551 .299 r
.25048 .89556 m .25294 .90482 L .24601 .90022 L p F P
0 g
s
.922 .551 .299 r
.24601 .90022 m .24342 .89046 L .25048 .89556 L p F P
0 g
s
.936 .622 .42 r
.25048 .89556 m .24342 .89046 L .2424 .8802 L p F P
0 g
s
.914 .721 .627 r
.77433 .2854 m .78119 .29213 L .77813 .30244 L p F P
0 g
s
.629 .751 .935 r
.63645 .96341 m .6584 .95827 L .66372 .96397 L p F P
0 g
s
.633 .706 .899 r
.6584 .95827 m .63645 .96341 L .63098 .9562 L p F P
0 g
s
.659 .725 .898 r
.49532 .45986 m .47397 .46747 L .47996 .47463 L p F P
0 g
s
.659 .725 .898 r
.47996 .47463 m .50125 .46731 L .49532 .45986 L p F P
0 g
s
.63 .825 .976 r
.55589 .46611 m .56158 .47287 L p .53478 .47305 L F P
0 g
s
.63 .825 .976 r
.53478 .47305 m .53435 .47273 L .55589 .46611 L p F P
0 g
s
.571 .804 .987 r
.53295 .47303 m .53478 .47305 L .53435 .47273 L closepath p F P
0 g
s
.818 .839 .865 r
.30945 .69201 m .29794 .70153 L .30473 .70565 L p F P
0 g
s
.818 .839 .865 r
.30473 .70565 m .31277 .69895 L .30945 .69201 L p F P
0 g
s
.819 .836 .862 r
.29028 .70799 m .29794 .70153 L .30473 .70565 L p F P
0 g
s
.33 .251 .615 r
.8203 .84873 m .81926 .84297 L .82153 .84758 L closepath p F P
0 g
s
.6 .844 .991 r
.45673 .16322 m .46185 .16607 L .4381 .17122 L p F P
0 g
s
.6 .844 .991 r
.4381 .17122 m .43562 .16965 L .45673 .16322 L p F P
0 g
s
.553 .658 .906 r
.68719 .66605 m .6797 .66649 L .67439 .65869 L p F P
0 g
s
0 .505 .856 r
.32514 .95345 m .32359 .953 L .3294 .95575 L closepath p F P
0 g
s
.832 .778 .801 r
.75325 .37584 m .75097 .37828 L .75595 .3859 L p F P
0 g
s
.832 .778 .8 r
.74025 .38977 m .75097 .37828 L .75595 .3859 L p F P
0 g
s
.832 .778 .8 r
.75595 .3859 m .74604 .39656 L .74025 .38977 L p F P
0 g
s
.648 .729 .909 r
.52273 .45956 m .50125 .46731 L .50715 .47341 L p F P
0 g
s
.648 .729 .909 r
.50715 .47341 m .52856 .46675 L .52273 .45956 L p F P
0 g
s
.341 .298 .664 r
.82748 .81104 m .81917 .81989 L .82591 .82899 L p F P
0 g
s
.385 .347 .693 r
.81874 .80252 m .82748 .81104 L .81917 .81989 L p F P
0 g
s
.728 .669 .792 r
.48879 .94235 m .46747 .95487 L .46149 .94657 L p F P
0 g
s
.944 .63 .408 r
.2424 .8802 m .23569 .87493 L .23668 .88521 L p F P
0 g
s
.944 .63 .408 r
.23668 .88521 m .24342 .89046 L .2424 .8802 L p F P
0 g
s
.443 .482 .805 r
.78762 .74439 m .79063 .73978 L p .80158 .75441 L F P
0 g
s
.459 .511 .825 r
.78762 .74439 m .78479 .73817 L .79063 .73978 L closepath p F P
0 g
s
.842 .38 .09 r
.27388 .92433 m .26607 .91956 L .26062 .91036 L p F P
0 g
s
.84 .373 .056 r
.25315 .90543 m .26062 .91036 L .26607 .91956 L p F P
0 g
s
.902 .508 .258 r
.25294 .90482 m .25315 .90543 L .26062 .91036 L p F P
0 g
s
.813 .6 .614 r
.49329 .74425 m .48088 .74041 L .48387 .72926 L p F P
0 g
s
.85 .643 .621 r
.47376 .72469 m .48387 .72926 L .48088 .74041 L p F P
0 g
s
.855 .63 .597 r
.48387 .72926 m .47376 .72469 L .47595 .71382 L p F P
0 g
s
.625 .462 .641 r
.54318 .75937 m .56636 .75484 L p .54997 .77078 L F P
0 g
s
.625 .462 .641 r
.54997 .77078 m .54521 .77171 L .54318 .75937 L p F P
0 g
s
.629 .461 .636 r
.56459 .74282 m .56636 .75484 L .54318 .75937 L p F P
0 g
s
.714 .537 .648 r
.54318 .75937 m .54521 .77171 L .51836 .77257 L p F P
0 g
s
.742 .814 .908 r
.3894 .64878 m .36825 .66054 L .3747 .66552 L p F P
0 g
s
.742 .814 .908 r
.3747 .66552 m .39578 .65384 L .3894 .64878 L p F P
0 g
s
.756 .816 .9 r
.36426 .66294 m .36825 .66054 L .3747 .66552 L p F P
0 g
s
.775 .573 .625 r
.50459 .75871 m .4893 .75574 L .49329 .74425 L p F P
0 g
s
.814 .618 .637 r
.48088 .74041 m .49329 .74425 L .4893 .75574 L p F P
0 g
s
.654 .701 .881 r
.47397 .46747 m .47141 .46401 L .45136 .47263 L p F P
0 g
s
.651 .691 .874 r
.44675 .46616 m .45136 .47263 L .47141 .46401 L p F P
0 g
s
.799 .835 .878 r
.32595 .68894 m .31277 .69895 L .30945 .69201 L p F P
0 g
s
.66 .742 .911 r
.64145 .64644 m .61954 .6522 L .61409 .64686 L p F P
0 g
s
.452 .4 .709 r
.27374 .33669 m .28538 .32402 L p .27496 .31757 L F P
0 g
s
.475 .433 .732 r
.28538 .32402 m .27374 .33669 L .28942 .33942 L p F P
0 g
s
.549 .559 .817 r
.32069 .41121 m .322 .41111 L .32113 .4121 L closepath p F P
0 g
s
.917 .814 .729 r
.23991 .78938 m .23485 .78327 L .22791 .79558 L p F P
0 g
s
.917 .814 .729 r
.22791 .79558 m .23304 .80165 L .23991 .78938 L p F P
0 g
s
.647 .723 .904 r
.55015 .45872 m .52856 .46675 L .53435 .47273 L p F P
0 g
s
.647 .723 .904 r
.53435 .47273 m .55589 .46611 L .55015 .45872 L p F P
0 g
s
.892 .672 .598 r
.46775 .70869 m .47595 .71382 L .47376 .72469 L p F P
0 g
s
.898 .661 .572 r
.4677 .7085 m .46913 .69804 L p .47595 .71382 L F P
0 g
s
.898 .661 .572 r
.47595 .71382 m .46775 .70869 L .4677 .7085 L p F P
0 g
s
.938 .786 .666 r
.23295 .81945 m .22741 .81359 L .22297 .82523 L p F P
0 g
s
.938 .786 .666 r
.23013 .82697 m .23295 .81945 L p .22297 .82523 L F P
0 g
s
.332 .212 .562 r
.27263 .29117 m .27764 .28601 L .27689 .27544 L p F P
0 g
s
.387 .29 .622 r
.27764 .28601 m .27907 .29614 L .27263 .29117 L closepath p F P
0 g
s
.382 .29 .626 r
.27927 .29762 m .27907 .29614 L .27263 .29117 L p F P
0 g
s
.593 .765 .961 r
.35861 .96211 m .37936 .9581 L .38571 .96316 L p F P
0 g
s
.622 .766 .949 r
.37936 .9581 m .35861 .96211 L .35211 .95786 L p F P
0 g
s
.549 .553 .811 r
.33478 .39672 m .3145 .39856 L .32069 .41121 L p F P
0 g
s
.549 .553 .811 r
.33501 .39722 m .33478 .39672 L p .32069 .41121 L F P
0 g
s
.549 .553 .811 r
.32069 .41121 m .322 .41111 L .33501 .39722 L p F P
0 g
s
.797 .772 .831 r
.71323 .42637 m .71256 .42693 L .70649 .42031 L p F P
0 g
s
.8 .773 .828 r
.71323 .42637 m .73075 .41125 L .72484 .40454 L p F P
0 g
s
.8 .773 .828 r
.72484 .40454 m .70809 .41896 L .71323 .42637 L p F P
0 g
s
.797 .772 .831 r
.70649 .42031 m .70809 .41896 L .71323 .42637 L p F P
0 g
s
.874 .84 .808 r
.26173 .74727 m .26465 .74384 L .26045 .7373 L p F P
0 g
s
.499 .898 .936 r
.73776 .94897 m .7243 .95515 L p .71306 .95606 L F P
0 g
s
.491 .903 .89 r
.7243 .95515 m .73776 .94897 L .74003 .94895 L closepath p F P
0 g
s
.399 .712 .986 r
.62678 .16905 m .60944 .17021 L .60213 .16827 L p F P
0 g
s
.429 .754 .995 r
.60944 .17021 m .62678 .16905 L .63206 .17335 L p F P
0 g
s
.594 .848 .993 r
.71306 .95606 m .69093 .96244 L .68579 .95862 L p F P
0 g
s
.606 .82 .982 r
.66372 .96397 m .68579 .95862 L .69093 .96244 L p F P
0 g
s
.62 .764 .948 r
.68579 .95862 m .66372 .96397 L .6584 .95827 L p F P
0 g
s
.596 .624 .85 r
.37564 .43086 m .3803 .43868 L .36427 .44185 L closepath p F P
0 g
s
.596 .63 .855 r
.3865 .44893 m .3803 .43868 L .36427 .44185 L p F P
0 g
s
.816 .776 .815 r
.73469 .40749 m .74604 .39656 L .74025 .38977 L p F P
0 g
s
.885 .477 .239 r
.73974 .22415 m .7485 .23043 L .75151 .2383 L p F P
0 g
s
.89 .479 .216 r
.75981 .2447 m .75151 .2383 L .7485 .23043 L p F P
0 g
s
.73 .745 .864 r
.63225 .44927 m .6105 .4615 L .616 .46903 L p F P
0 g
s
.73 .745 .864 r
.616 .46903 m .63769 .45689 L .63225 .44927 L p F P
0 g
s
.706 .748 .885 r
.59341 .46987 m .6105 .4615 L .616 .46903 L p F P
0 g
s
.923 .692 .571 r
.77506 .27475 m .7758 .27685 L .77601 .27563 L closepath p F P
0 g
s
.721 .536 .64 r
.50459 .75871 m .49928 .77062 L .51809 .77255 L p F P
0 g
s
.785 .6 .651 r
.4893 .75574 m .50459 .75871 L .49928 .77062 L p F P
0 g
s
.29 .689 .974 r
.63278 .16971 m .62678 .16905 L .63206 .17335 L p F P
0 g
s
.29 .689 .974 r
.63206 .17335 m .64708 .17418 L .63278 .16971 L p F P
0 g
s
.745 .721 .83 r
.44838 .95382 m .44021 .95845 L .43412 .95135 L p F P
0 g
s
.711 .73 .866 r
.41295 .96156 m .43412 .95135 L .44021 .95845 L p F P
0 g
s
.954 .687 .492 r
.23613 .86431 m .22976 .85887 L .2293 .86951 L p F P
0 g
s
.954 .687 .492 r
.2293 .86951 m .23569 .87493 L .23613 .86431 L p F P
0 g
s
.663 .627 .803 r
.59797 .94366 m .5763 .95097 L .57059 .9405 L p F P
0 g
s
.706 .782 .911 r
.42314 .64967 m .41574 .65291 L .41241 .64591 L p F P
0 g
s
.816 .776 .815 r
.74025 .38977 m .72963 .39998 L .73469 .40749 L p F P
0 g
s
.815 .775 .816 r
.72484 .40454 m .72963 .39998 L .73469 .40749 L p F P
0 g
s
.815 .775 .816 r
.73469 .40749 m .73075 .41125 L .72484 .40454 L p F P
0 g
s
.319 .154 .494 r
.27689 .27544 m .28659 .26688 L .28475 .25909 L p F P
0 g
s
.384 .25 .573 r
.28659 .26688 m .27689 .27544 L .27764 .28601 L p F P
0 g
s
.874 .84 .808 r
.26045 .7373 m .2547 .744 L .26173 .74727 L p F P
0 g
s
.872 .838 .809 r
.26173 .74727 m .2531 .75744 L .2487 .751 L p F P
0 g
s
.872 .838 .809 r
.2487 .751 m .2547 .744 L .26173 .74727 L p F P
0 g
s
.754 .756 .854 r
.66475 .45071 m .65579 .45654 L .64838 .4504 L p F P
0 g
s
.936 .701 .557 r
.46913 .69804 m .4677 .7085 L .46175 .69687 L p F P
0 g
s
.936 .701 .557 r
.46175 .69687 m .46238 .69234 L .46913 .69804 L p F P
0 g
s
.942 .68 .51 r
.46913 .69804 m .46238 .69234 L .46295 .68206 L p F P
0 g
s
.486 .543 .84 r
.75953 .71314 m .77426 .71599 L p .77678 .72596 L F P
0 g
s
.469 .541 .848 r
.75953 .71314 m .77426 .71599 L .76902 .70568 L p F P
0 g
s
.469 .541 .848 r
.76902 .70568 m .76392 .70464 L .75953 .71314 L p F P
0 g
s
.498 .571 .86 r
.74587 .70224 m .76392 .70464 L .75953 .71314 L p F P
0 g
s
.491 .571 .864 r
.76392 .70464 m .74587 .70224 L .74198 .69502 L p F P
0 g
s
.565 .578 .825 r
.33501 .39722 m .34101 .40881 L .322 .41111 L closepath p F P
0 g
s
.565 .584 .831 r
.34668 .41972 m .34101 .40881 L .322 .41111 L p F P
0 g
s
.565 .584 .831 r
.34558 .42094 m .34668 .41972 L p .322 .41111 L F P
0 g
s
.69 .756 .902 r
.56158 .47287 m .58322 .46473 L p .56749 .46125 L F P
0 g
s
.69 .756 .902 r
.56749 .46125 m .55589 .46611 L .56158 .47287 L p F P
0 g
s
.213 .1 .5 r
.59459 .67584 m .58819 .68286 L .5893 .69276 L p F P
0 g
s
.029 0 .283 r
.58819 .68286 m .59459 .67584 L .59563 .66707 L p F P
0 g
s
.796 .837 .883 r
.33273 .67474 m .31926 .68461 L .32595 .68894 L p F P
0 g
s
.796 .837 .883 r
.32595 .68894 m .3355 .6819 L .33273 .67474 L p F P
0 g
s
.799 .835 .878 r
.30945 .69201 m .31926 .68461 L .32595 .68894 L p F P
0 g
s
.703 .165 0 r
.29025 .93752 m .28217 .93286 L .27388 .92433 L p F P
0 g
s
.683 .143 0 r
.26607 .91956 m .27388 .92433 L .28217 .93286 L p F P
0 g
s
.918 .691 .579 r
.7758 .27685 m .77433 .2854 L p .7687 .269 L F P
0 g
s
.918 .691 .579 r
.7687 .269 m .77506 .27475 L .7758 .27685 L p F P
0 g
s
.914 .579 .395 r
.75151 .2383 m .75981 .2447 L .76113 .25328 L p F P
0 g
s
.924 .588 .384 r
.76895 .25979 m .76113 .25328 L .75981 .2447 L p F P
0 g
s
.921 .645 .5 r
.76113 .25328 m .76895 .25979 L .7687 .269 L p F P
0 g
s
.932 .656 .494 r
.77506 .27475 m .7687 .269 L .76895 .25979 L p F P
0 g
s
.508 .603 .883 r
.71695 .6826 m .73542 .6837 L .73019 .67489 L p F P
0 g
s
.508 .603 .883 r
.73019 .67489 m .72001 .67424 L .71695 .6826 L p F P
0 g
s
.531 .626 .891 r
.70742 .67409 m .72001 .67424 L .71695 .6826 L p F P
0 g
s
.283 .181 .558 r
.82153 .84758 m .8203 .84873 L .82173 .85999 L p F P
0 g
s
.907 .745 .67 r
.78013 .32007 m .7737 .31327 L .77813 .30244 L p F P
0 g
s
.89 .752 .704 r
.7737 .31327 m .78013 .32007 L .77434 .33142 L p F P
0 g
s
.71 .746 .88 r
.58881 .47203 m .59341 .46987 L .58384 .46443 L p F P
0 g
s
.71 .746 .88 r
.58384 .46443 m .58322 .46473 L .58881 .47203 L p F P
0 g
s
.554 0 0 r
.69691 .19345 m .70747 .1992 L .71536 .20506 L p F P
0 g
s
.516 0 0 r
.72566 .21087 m .71536 .20506 L .70747 .1992 L p F P
0 g
s
.88 .768 .734 r
.77306 .35017 m .76701 .34333 L .77434 .33142 L p F P
0 g
s
.86 .769 .761 r
.77187 .35181 m .77306 .35017 L .76701 .34333 L p F P
0 g
s
0 .459 .815 r
.66098 .17875 m .67301 .18401 L .68557 .18795 L p F P
0 g
s
.049 .535 .887 r
.68896 .18941 m .68557 .18795 L .67301 .18401 L p F P
0 g
s
.049 .535 .887 r
.69247 .19129 m .68896 .18941 L p .67301 .18401 L F P
0 g
s
.725 .722 .847 r
.43412 .95135 m .41295 .96156 L .40673 .95554 L p F P
0 g
s
.678 .754 .909 r
.38571 .96316 m .40673 .95554 L .41295 .96156 L p F P
0 g
s
.539 .392 .63 r
.56636 .75484 m .56459 .74282 L .58447 .73474 L p F P
0 g
s
.53 .381 .623 r
.58276 .7237 m .58447 .73474 L .56459 .74282 L p F P
0 g
s
.53 .381 .623 r
.58126 .72325 m .58276 .7237 L p .56459 .74282 L F P
0 g
s
.633 .664 .862 r
.43457 .44772 m .4135 .45384 L .41964 .46319 L p F P
0 g
s
.633 .664 .862 r
.41964 .46319 m .44067 .45712 L .43457 .44772 L p F P
0 g
s
.696 .752 .895 r
.40673 .95554 m .38571 .96316 L .37936 .9581 L p F P
0 g
s
.457 .513 .828 r
.79063 .73978 m .78479 .73817 L .7795 .72668 L p F P
0 g
s
.568 .687 .92 r
.66368 .64367 m .66905 .65108 L .64685 .6536 L p F P
0 g
s
.568 .687 .92 r
.64208 .64635 m .66368 .64367 L p .64685 .6536 L F P
0 g
s
.568 .687 .92 r
.64685 .6536 m .64205 .64722 L .64208 .64635 L p F P
0 g
s
.575 .676 .908 r
.64685 .6536 m .66905 .65108 L .67439 .65869 L p F P
0 g
s
.86 .769 .761 r
.76701 .34333 m .76689 .3435 L .77187 .35181 L p F P
0 g
s
.861 .768 .759 r
.7579 .3559 m .76689 .3435 L .77187 .35181 L p F P
0 g
s
.861 .768 .759 r
.77187 .35181 m .76403 .36269 L .7579 .3559 L p F P
0 g
s
.237 .029 .381 r
.28475 .25909 m .29264 .25227 L .29371 .24385 L p F P
0 g
s
.328 .159 .495 r
.29264 .25227 m .28475 .25909 L .28659 .26688 L p F P
0 g
s
.975 .718 .479 r
.46295 .68206 m .45758 .67586 L .457 .68617 L p F P
0 g
s
.975 .718 .479 r
.457 .68617 m .46238 .69234 L .46295 .68206 L p F P
0 g
s
.303 .082 .403 r
.3096 .23976 m .31061 .23133 L .29371 .24385 L p F P
0 g
s
.303 .082 .403 r
.29371 .24385 m .29264 .25227 L .3096 .23976 L p F P
0 g
s
.729 .547 .645 r
.51836 .77257 m .51829 .7722 L .51809 .77255 L closepath p F P
0 g
s
.399 .712 .986 r
.62339 .16691 m .62678 .16905 L p .60213 .16827 L F P
0 g
s
.399 .712 .986 r
.61742 .16562 m .62339 .16691 L p .60213 .16827 L F P
0 g
s
.399 .712 .986 r
.60213 .16827 m .59929 .16569 L .61742 .16562 L p F P
0 g
s
.529 .777 .989 r
.59251 .1668 m .60213 .16827 L .59929 .16569 L closepath p F P
0 g
s
.692 .526 .658 r
.51836 .77257 m .54521 .77171 L p .53621 .78513 L F P
0 g
s
.692 .526 .658 r
.53621 .78513 m .52109 .78567 L .51836 .77257 L p F P
0 g
s
.73 .55 .649 r
.51809 .77255 m .51836 .77257 L .52109 .78567 L p F P
0 g
s
.779 .83 .892 r
.3471 .67405 m .3355 .6819 L .33273 .67474 L p F P
0 g
s
.755 .568 .642 r
.49928 .77062 m .51809 .77255 L .51103 .785 L p F P
0 g
s
.73 .55 .649 r
.52109 .78567 m .51103 .785 L .51809 .77255 L p F P
0 g
s
.89 .835 .786 r
.2531 .75744 m .2487 .751 L .23871 .76419 L p F P
0 g
s
.89 .835 .786 r
.23871 .76419 m .24323 .77056 L .2531 .75744 L p F P
0 g
s
.594 .819 .986 r
.49015 .16505 m .50359 .16136 L .48704 .16266 L closepath p F P
0 g
s
.745 .721 .83 r
.43412 .95135 m .43514 .95068 L .44838 .95382 L p F P
0 g
s
.717 .692 .826 r
.45548 .93778 m .43514 .95068 L .44838 .95382 L p F P
0 g
s
.717 .692 .826 r
.44838 .95382 m .46149 .94657 L .45548 .93778 L p F P
0 g
s
.762 .758 .849 r
.66475 .45071 m .68418 .43741 L .67712 .43111 L p F P
0 g
s
.762 .758 .849 r
.67712 .43111 m .65943 .44321 L .66475 .45071 L p F P
0 g
s
.754 .756 .854 r
.64838 .4504 m .65943 .44321 L .66475 .45071 L p F P
0 g
s
.597 .84 .99 r
.46291 .16677 m .469 .16497 L .46185 .16607 L closepath p F P
0 g
s
.63 .212 0 r
.45621 .66545 m .4565 .66613 L .45238 .65948 L p F P
0 g
s
.63 .212 0 r
.45238 .65948 m .4502 .65585 L .45258 .65966 L p F P
0 g
s
0 .176 .712 r
.4502 .65585 m .45238 .65948 L .45038 .65209 L p F P
0 g
s
.737 .51 0 r
.45238 .65948 m .45038 .65209 L .45185 .65902 L p F P
0 g
s
.737 .51 0 r
.45185 .65902 m .45239 .66157 L p .45238 .65948 L F P
0 g
s
.63 .212 0 r
.45258 .65966 m .45621 .66545 L p .45238 .65948 L F P
0 g
s
.956 .731 .558 r
.23154 .84793 m .22553 .84231 L .22372 .85328 L p F P
0 g
s
.956 .731 .558 r
.22372 .85328 m .22976 .85887 L .23154 .84793 L p F P
0 g
s
.227 .044 .412 r
.80605 .89289 m .80998 .88987 L .8129 .87812 L p F P
0 g
s
.199 .015 .392 r
.82241 .87046 m .8129 .87812 L .80998 .88987 L p F P
0 g
s
.275 .132 .498 r
.8129 .87812 m .82241 .87046 L .82173 .85999 L p F P
0 g
s
.359 .339 .701 r
.82583 .79432 m .81874 .80252 L .82748 .81104 L p F P
0 g
s
.393 .389 .736 r
.82545 .79314 m .81564 .78581 L p .81874 .80252 L F P
0 g
s
.393 .389 .736 r
.81874 .80252 m .82583 .79432 L .82545 .79314 L p F P
0 g
s
.582 .803 .984 r
.51739 .16407 m .5307 .16078 L .51346 .16079 L closepath p F P
0 g
s
0 .279 .659 r
.69247 .19129 m .69691 .19345 L .68896 .18941 L closepath p F P
0 g
s
.711 .744 .878 r
.6105 .4615 m .59341 .46987 L .58384 .46443 L p F P
0 g
s
.587 .604 .836 r
.36787 .41681 m .34723 .4207 L .35347 .43173 L p F P
0 g
s
.587 .604 .836 r
.35347 .43173 m .37408 .42808 L .36787 .41681 L p F P
0 g
s
.575 .601 .842 r
.34558 .42094 m .34723 .4207 L .35347 .43173 L p F P
0 g
s
.304 .776 .663 r
.37776 .18334 m .3806 .18219 L .35972 .19149 L p F P
0 g
s
.304 .776 .663 r
.35972 .19149 m .35738 .19249 L .37776 .18334 L p F P
0 g
s
.701 .632 .777 r
.54271 .93778 m .5433 .939 L p .51605 .93964 L F P
0 g
s
.701 .632 .777 r
.51605 .93964 m .51883 .93801 L .54271 .93778 L p F P
0 g
s
.705 .643 .785 r
.51605 .93964 m .51883 .93801 L .51519 .93797 L closepath p F P
0 g
s
.716 .647 .779 r
.51519 .93797 m .51605 .93964 L p .48879 .94235 L F P
0 g
s
.646 .673 .861 r
.62614 .94868 m .63098 .9562 L p .6036 .95346 L F P
0 g
s
.646 .673 .861 r
.6036 .95346 m .60571 .95289 L .62614 .94868 L p F P
0 g
s
.643 .64 .832 r
.6036 .95346 m .60571 .95289 L .60355 .95336 L closepath p F P
0 g
s
.283 .181 .558 r
.82173 .85999 m .82401 .8579 L .82153 .84758 L p F P
0 g
s
.264 .169 .556 r
.83058 .83871 m .82153 .84758 L .82401 .8579 L p F P
0 g
s
.333 .253 .615 r
.82591 .82899 m .83058 .83871 L .82153 .84758 L p F P
0 g
s
.614 .708 .911 r
.42314 .64967 m .4169 .64386 L p .4389 .63868 L F P
0 g
s
.614 .708 .911 r
.4389 .63868 m .43336 .64739 L .42314 .64967 L p F P
0 g
s
.706 .782 .911 r
.41241 .64591 m .4169 .64386 L .42314 .64967 L p F P
0 g
s
.643 .642 .834 r
.60571 .95289 m .60355 .95336 L .59797 .94366 L p F P
0 g
s
.14 0 .288 r
.80521 .89977 m .80998 .88987 L .80605 .89289 L closepath p F P
0 g
s
.957 .654 .227 r
.4565 .66613 m .45238 .65948 L .4538 .66912 L p F P
0 g
s
.957 .654 .227 r
.4538 .66912 m .45758 .67586 L .4565 .66613 L p F P
0 g
s
.537 .642 .901 r
.68719 .66605 m .70215 .66577 L .69686 .65762 L p F P
0 g
s
.537 .642 .901 r
.69686 .65762 m .68947 .65778 L .68719 .66605 L p F P
0 g
s
.553 .658 .906 r
.67439 .65869 m .68947 .65778 L .68719 .66605 L p F P
0 g
s
.61 .631 .847 r
.40118 .43366 m .3803 .43868 L .3865 .44893 L p F P
0 g
s
.61 .631 .847 r
.3865 .44893 m .40734 .44408 L .40118 .43366 L p F P
0 g
s
.938 .786 .666 r
.22297 .82523 m .22353 .82582 L .23013 .82697 L p F P
0 g
s
.939 .782 .66 r
.22353 .82582 m .23013 .82697 L .22859 .83104 L closepath p F P
0 g
s
.682 .625 .785 r
.56841 .93598 m .57059 .9405 L p .5433 .939 L F P
0 g
s
.682 .625 .785 r
.5433 .939 m .54638 .93752 L .56841 .93598 L p F P
0 g
s
.682 .623 .784 r
.5433 .939 m .54638 .93752 L .54271 .93778 L closepath p F P
0 g
s
.627 .466 .646 r
.54554 .77365 m .54997 .77078 L .54521 .77171 L closepath p F P
0 g
s
.692 .526 .658 r
.54521 .77171 m .54554 .77365 L .53621 .78513 L p F P
0 g
s
.7 .634 .779 r
.54271 .93778 m .53751 .92716 L .51883 .93801 L closepath p F P
0 g
s
.705 .645 .787 r
.53402 .9193 m .53751 .92716 L .51883 .93801 L p F P
0 g
s
.705 .645 .787 r
.52392 .91926 m .53402 .9193 L p .51883 .93801 L F P
0 g
s
.705 .645 .787 r
.51021 .92842 m .52392 .91926 L p .51883 .93801 L F P
0 g
s
.705 .645 .787 r
.51883 .93801 m .51519 .93797 L .51021 .92842 L p F P
0 g
s
.716 .647 .779 r
.48879 .94235 m .49678 .93711 L .51519 .93797 L p F P
0 g
s
.716 .649 .782 r
.51519 .93797 m .51021 .92842 L .49678 .93711 L closepath p F P
0 g
s
.369 .253 .589 r
.59254 .70211 m .58127 .71119 L .58263 .72269 L p F P
0 g
s
.351 .225 .565 r
.58127 .71119 m .59254 .70211 L .5893 .69276 L p F P
0 g
s
.527 .367 .607 r
.58126 .72325 m .58263 .72269 L .58127 .71119 L p F P
0 g
s
.508 .884 .971 r
.43909 .16467 m .42924 .16735 L .43562 .16965 L p F P
0 g
s
.508 .884 .971 r
.4519 .16192 m .43909 .16467 L p .43562 .16965 L F P
0 g
s
.508 .884 .971 r
.43562 .16965 m .45673 .16322 L .4519 .16192 L p F P
0 g
s
.726 .67 .795 r
.48879 .94235 m .49678 .93711 L .48507 .93598 L closepath p F P
0 g
s
.728 .669 .792 r
.48507 .93598 m .48879 .94235 L p .46149 .94657 L F P
0 g
s
.558 .791 .986 r
.54464 .16373 m .55371 .16184 L .54133 .16087 L closepath p F P
0 g
s
.44 .777 .998 r
.59929 .16569 m .59251 .1668 L .57467 .16371 L p F P
0 g
s
.067 .547 .896 r
.32359 .953 m .32514 .95345 L .31847 .94953 L p F P
0 g
s
.067 .547 .896 r
.31847 .94953 m .31486 .9486 L .32359 .953 L p F P
0 g
s
.415 .864 .849 r
.38397 .18185 m .3806 .18219 L .40157 .17439 L p F P
0 g
s
0 0 0 r
.37776 .18334 m .39932 .17535 L p .38241 .18153 L F P
0 g
s
0 0 0 r
.3806 .18219 m .38034 .1823 L p .38241 .18153 L F P
0 g
s
0 0 0 r
.38034 .1823 m .37776 .18334 L p .38241 .18153 L F P
0 g
s
.415 .864 .849 r
.40543 .17393 m .38397 .18185 L p .40079 .17472 L F P
0 g
s
.415 .864 .849 r
.40157 .17439 m .40174 .17437 L p .40079 .17472 L F P
0 g
s
.415 .864 .849 r
.40174 .17437 m .40543 .17393 L p .40079 .17472 L F P
0 g
s
.682 .625 .786 r
.54638 .93752 m .54271 .93778 L .53751 .92716 L p F P
0 g
s
.646 .672 .86 r
.62614 .94868 m .62544 .94759 L .60571 .95289 L closepath p F P
0 g
s
.643 .642 .834 r
.61983 .93754 m .62544 .94759 L .60571 .95289 L p F P
0 g
s
.643 .642 .834 r
.59797 .94366 m .61983 .93754 L p .60571 .95289 L F P
0 g
s
.933 .807 .698 r
.23304 .80165 m .22791 .79558 L .22223 .80756 L p F P
0 g
s
.933 .807 .698 r
.22223 .80756 m .22741 .81359 L .23304 .80165 L p F P
0 g
s
.558 .561 .813 r
.3145 .39856 m .33478 .39672 L p .31725 .38484 L F P
0 g
s
.558 .561 .813 r
.31725 .38484 m .31096 .39132 L .3145 .39856 L p F P
0 g
s
.458 .517 .831 r
.7795 .72668 m .77678 .72596 L .77812 .72372 L closepath p F P
0 g
s
.486 .543 .84 r
.77426 .71599 m .77812 .72372 L .77678 .72596 L p F P
0 g
s
.635 .482 .658 r
.54765 .7845 m .54554 .77365 L .54997 .77078 L p F P
0 g
s
.684 .514 .651 r
.54765 .7845 m .54554 .77365 L .53621 .78513 L closepath p F P
0 g
s
.455 .397 .703 r
.28186 .3103 m .2844 .32014 L .27496 .31757 L closepath p F P
0 g
s
.452 .4 .709 r
.28538 .32402 m .2844 .32014 L .27496 .31757 L p F P
0 g
s
.914 .721 .627 r
.77813 .30244 m .77125 .29572 L .77433 .2854 L p F P
0 g
s
.898 .733 .669 r
.77125 .29572 m .77813 .30244 L .7737 .31327 L p F P
0 g
s
.772 .832 .898 r
.36173 .65578 m .3405 .6695 L .3471 .67405 L p F P
0 g
s
.772 .832 .898 r
.3624 .65624 m .36173 .65578 L p .3471 .67405 L F P
0 g
s
.772 .832 .898 r
.3471 .67405 m .36426 .66294 L .3624 .65624 L p F P
0 g
s
.779 .83 .892 r
.33273 .67474 m .3405 .6695 L .3471 .67405 L p F P
0 g
s
.514 0 0 r
.29025 .93752 m .29192 .93878 L .2851 .935 L p F P
0 g
s
.514 0 0 r
.2851 .935 m .28217 .93286 L .29025 .93752 L p F P
0 g
s
.682 .626 .787 r
.56841 .93598 m .56485 .92867 L .54638 .93752 L closepath p F P
0 g
s
.682 .625 .786 r
.56008 .91773 m .56485 .92867 L .54638 .93752 L p F P
0 g
s
.682 .625 .786 r
.55417 .9181 m .56008 .91773 L p .54638 .93752 L F P
0 g
s
.682 .625 .786 r
.53751 .92716 m .55417 .9181 L p .54638 .93752 L F P
0 g
s
.532 .839 .999 r
.48413 .16069 m .469 .16497 L .46185 .16607 L p F P
0 g
s
.532 .839 .999 r
.47801 .15815 m .48413 .16069 L p .46185 .16607 L F P
0 g
s
.532 .839 .999 r
.46185 .16607 m .45673 .16322 L .47801 .15815 L p F P
0 g
s
.845 .77 .778 r
.7579 .3559 m .76403 .36269 L .75325 .37584 L p F P
0 g
s
.785 .6 .651 r
.4851 .76703 m .4893 .75574 L p .49928 .77062 L F P
0 g
s
.814 .622 .643 r
.4851 .76703 m .4893 .75574 L .4813 .75318 L closepath p F P
0 g
s
.814 .618 .637 r
.47932 .74559 m .48088 .74041 L p .4893 .75574 L F P
0 g
s
.814 .618 .637 r
.4893 .75574 m .4813 .75318 L .47932 .74559 L p F P
0 g
s
.649 .678 .864 r
.46192 .45011 m .44067 .45712 L .44675 .46616 L p F P
0 g
s
.649 .678 .864 r
.44675 .46616 m .46796 .45918 L .46192 .45011 L p F P
0 g
s
.651 .691 .874 r
.47141 .46401 m .46796 .45918 L .44675 .46616 L p F P
0 g
s
.635 .482 .658 r
.54997 .77078 m .5685 .76727 L p .54765 .7845 L F P
0 g
s
.63 .471 .648 r
.5685 .76727 m .56706 .75928 L .54997 .77078 L closepath p F P
0 g
s
.625 .462 .641 r
.56636 .75484 m .56706 .75928 L .54997 .77078 L p F P
0 g
s
.715 .795 .915 r
.41 .63854 m .3894 .64878 L .39578 .65384 L p F P
0 g
s
.715 .795 .915 r
.39578 .65384 m .41241 .64591 L .41 .63854 L p F P
0 g
s
.286 .691 .973 r
.35211 .95786 m .34558 .95333 L .32514 .95345 L p F P
0 g
s
.475 .738 .985 r
.34558 .95333 m .32514 .95345 L .31847 .94953 L p F P
0 g
s
0 0 0 r
.74003 .94895 m .76209 .9381 L .76373 .93685 L p F P
0 g
s
.583 .943 .9 r
.73776 .94897 m .74003 .94895 L .76209 .9381 L p F P
0 g
s
.803 .311 0 r
.73049 .21799 m .73974 .22415 L p .72581 .21096 L F P
0 g
s
.803 .311 0 r
.72581 .21096 m .72574 .21096 L .73049 .21799 L p F P
0 g
s
.744 .222 0 r
.72566 .21087 m .72581 .21096 L .72574 .21096 L closepath p F P
0 g
s
.726 .671 .796 r
.50553 .91871 m .51021 .92842 L .49678 .93711 L p F P
0 g
s
.726 .671 .796 r
.5014 .91845 m .50553 .91871 L p .49678 .93711 L F P
0 g
s
.726 .671 .796 r
.48288 .93225 m .5014 .91845 L p .49678 .93711 L F P
0 g
s
.726 .671 .796 r
.49678 .93711 m .48507 .93598 L .48288 .93225 L p F P
0 g
s
.376 .379 .735 r
.82545 .79314 m .81564 .78581 L .82094 .7791 L closepath p F P
0 g
s
.409 .424 .764 r
.81967 .77554 m .80991 .76977 L p .81564 .78581 L F P
0 g
s
.409 .424 .764 r
.81564 .78581 m .82094 .7791 L .81967 .77554 L p F P
0 g
s
.849 .647 .63 r
.47932 .74559 m .48088 .74041 L .47725 .73879 L closepath p F P
0 g
s
.85 .643 .621 r
.47353 .72564 m .47376 .72469 L p .48088 .74041 L F P
0 g
s
.85 .643 .621 r
.48088 .74041 m .47725 .73879 L .47353 .72564 L p F P
0 g
s
.491 .571 .864 r
.74198 .69502 m .74294 .69285 L p .76392 .70464 L F P
0 g
s
.507 .594 .876 r
.74198 .69502 m .74064 .69267 L .74294 .69285 L closepath p F P
0 g
s
.751 .234 0 r
.71536 .20506 m .72566 .21087 L .72574 .21096 L p F P
0 g
s
.755 .568 .642 r
.51103 .785 m .49372 .78264 L .49928 .77062 L p F P
0 g
s
.783 .603 .656 r
.48521 .76743 m .49928 .77062 L .49372 .78264 L p F P
0 g
s
.785 .6 .651 r
.49928 .77062 m .48521 .76743 L .4851 .76703 L p F P
0 g
s
.908 .834 .761 r
.2395 .77623 m .24323 .77056 L .23871 .76419 L p F P
0 g
s
.808 .325 .049 r
.72574 .21096 m .73049 .21799 L .72187 .21266 L closepath p F P
0 g
s
.751 .234 0 r
.72574 .21096 m .72187 .21266 L p .71536 .20506 L F P
0 g
s
.692 .528 .66 r
.52109 .78567 m .53621 .78513 L .52486 .79883 L p F P
0 g
s
.692 .528 .66 r
.52486 .79883 m .52389 .79886 L .52109 .78567 L p F P
0 g
s
.73 .552 .65 r
.51103 .785 m .52109 .78567 L .52389 .79886 L p F P
0 g
s
.515 .777 .991 r
.57193 .16413 m .57467 .16371 L .57074 .1631 L closepath p F P
0 g
s
.955 .768 .612 r
.22859 .83104 m .22553 .84231 L .21986 .83654 L p F P
0 g
s
.955 .768 .612 r
.22353 .82582 m .22859 .83104 L p .21986 .83654 L F P
0 g
s
.525 .629 .896 r
.72001 .67424 m .70742 .67409 L .70215 .66577 L p F P
0 g
s
.663 .627 .803 r
.57059 .9405 m .59228 .93249 L .59797 .94366 L p F P
0 g
s
.66 .614 .792 r
.59225 .93243 m .59228 .93249 L .57059 .9405 L p F P
0 g
s
.66 .614 .792 r
.57059 .9405 m .56841 .93598 L .59225 .93243 L p F P
0 g
s
.728 .669 .792 r
.46149 .94657 m .47823 .9353 L .48507 .93598 L p F P
0 g
s
.742 .671 .781 r
.47823 .9353 m .46149 .94657 L .45548 .93778 L p F P
0 g
s
0 0 0 r
.76209 .9381 m .77056 .93286 L .76373 .93685 L closepath p F P
0 g
s
0 0 0 r
.78398 .92334 m .77056 .93286 L .76373 .93685 L p F P
0 g
s
0 0 0 r
.78553 .92055 m .78398 .92334 L p .76373 .93685 L F P
0 g
s
.774 .759 .84 r
.68644 .43573 m .68418 .43741 L .67712 .43111 L p F P
0 g
s
.587 .837 .992 r
.469 .16497 m .48704 .16266 L .48413 .16069 L closepath p F P
0 g
s
.89 .752 .704 r
.77434 .33142 m .76786 .32465 L .7737 .31327 L p F P
0 g
s
.87 .755 .732 r
.76701 .34333 m .77434 .33142 L .76786 .32465 L p F P
0 g
s
.384 .25 .573 r
.27764 .28601 m .29222 .27322 L .28659 .26688 L p F P
0 g
s
.43 .321 .628 r
.29222 .27322 m .27764 .28601 L .27907 .29614 L p F P
0 g
s
.633 .706 .899 r
.63098 .9562 m .65298 .95117 L .6584 .95827 L p F P
0 g
s
.631 .663 .863 r
.64748 .94269 m .65298 .95117 L .63098 .9562 L p F P
0 g
s
.631 .663 .863 r
.64534 .94317 m .64748 .94269 L p .63098 .9562 L F P
0 g
s
.631 .663 .863 r
.63098 .9562 m .62614 .94868 L .64534 .94317 L p F P
0 g
s
.742 .749 .858 r
.63769 .45689 m .64838 .4504 L .64008 .44451 L p F P
0 g
s
.742 .749 .858 r
.64008 .44451 m .63225 .44927 L .63769 .45689 L p F P
0 g
s
.779 .761 .837 r
.68644 .43573 m .70649 .42031 L .69973 .41386 L p F P
0 g
s
.779 .761 .837 r
.69973 .41386 m .68118 .42809 L .68644 .43573 L p F P
0 g
s
.774 .759 .84 r
.67712 .43111 m .68118 .42809 L .68644 .43573 L p F P
0 g
s
.102 .577 .91 r
.65961 .17848 m .66098 .17875 L .65868 .17783 L closepath p F P
0 g
s
.889 .679 .612 r
.47353 .72564 m .47376 .72469 L .47299 .72421 L closepath p F P
0 g
s
.892 .672 .598 r
.47376 .72469 m .47299 .72421 L .46775 .70869 L p F P
0 g
s
.443 .482 .805 r
.79063 .73978 m .80705 .74589 L .80158 .75441 L p F P
0 g
s
.426 .486 .818 r
.79548 .73132 m .79063 .73978 L .80705 .74589 L p F P
0 g
s
.457 .513 .828 r
.7795 .72668 m .79548 .73132 L .79063 .73978 L p F P
0 g
s
.684 .516 .652 r
.53621 .78513 m .54765 .7845 L .55021 .79743 L p F P
0 g
s
.684 .516 .652 r
.55021 .79743 m .52486 .79883 L .53621 .78513 L p F P
0 g
s
.552 .406 .637 r
.56636 .75484 m .58648 .74701 L p .58443 .76103 L F P
0 g
s
.552 .406 .637 r
.58443 .76103 m .56706 .75928 L .56636 .75484 L p F P
0 g
s
.539 .392 .63 r
.58447 .73474 m .58648 .74701 L .56636 .75484 L p F P
0 g
s
.446 .51 .831 r
.79548 .73132 m .7795 .72668 L .77812 .72372 L p F P
0 g
s
.55 .664 .912 r
.68947 .65778 m .67439 .65869 L .66905 .65108 L p F P
0 g
s
.489 .889 .945 r
.42804 .16723 m .42924 .16735 L .40823 .17433 L p F P
0 g
s
.489 .889 .945 r
.40823 .17433 m .40543 .17393 L .42804 .16723 L p F P
0 g
s
0 .36 .723 r
.29192 .93878 m .30641 .94409 L .31486 .9486 L p F P
0 g
s
0 .427 .8 r
.30641 .94409 m .29192 .93878 L .2851 .935 L p F P
0 g
s
.76 .59 .667 r
.49372 .78264 m .51103 .785 L .50384 .79753 L p F P
0 g
s
.73 .552 .65 r
.52389 .79886 m .50384 .79753 L .51103 .785 L p F P
0 g
s
.918 .691 .579 r
.77433 .2854 m .76699 .27878 L .7687 .269 L p F P
0 g
s
.905 .709 .627 r
.76699 .27878 m .77433 .2854 L .77125 .29572 L p F P
0 g
s
.542 .535 .797 r
.30832 .38535 m .31725 .38484 L .31096 .39132 L closepath p F P
0 g
s
.392 .415 .764 r
.81967 .77554 m .80991 .76977 L .81502 .76263 L closepath p F P
0 g
s
.429 .45 .78 r
.81409 .76029 m .81502 .76263 L .80991 .76977 L p F P
0 g
s
.429 .45 .78 r
.80158 .75441 m .81409 .76029 L p .80991 .76977 L F P
0 g
s
.832 .633 .634 r
.47725 .73879 m .47353 .72564 L .47011 .73604 L closepath p F P
0 g
s
.863 .67 .64 r
.47011 .73604 m .47353 .72564 L .47299 .72421 L p F P
0 g
s
.863 .67 .64 r
.47299 .72421 m .46457 .7198 L p .47011 .73604 L F P
0 g
s
.868 .663 .623 r
.46767 .70865 m .46775 .70869 L .47299 .72421 L p F P
0 g
s
.868 .663 .623 r
.47299 .72421 m .46457 .7198 L .46767 .70865 L p F P
0 g
s
.504 .599 .881 r
.74294 .69285 m .74064 .69267 L .73542 .6837 L p F P
0 g
s
.402 .441 .786 r
.80158 .75441 m .81409 .76029 L .80865 .74668 L p F P
0 g
s
.402 .441 .786 r
.80865 .74668 m .80705 .74589 L .80158 .75441 L p F P
0 g
s
.906 .506 .228 r
.25315 .90543 m .25294 .90482 L .24601 .90022 L p F P
0 g
s
.845 .77 .778 r
.75325 .37584 m .74701 .36911 L .7579 .3559 L p F P
0 g
s
.827 .769 .797 r
.75097 .37828 m .75325 .37584 L .74701 .36911 L p F P
0 g
s
.908 .834 .761 r
.23871 .76419 m .23228 .77384 L .2395 .77623 L p F P
0 g
s
.905 .833 .764 r
.2395 .77623 m .23485 .78327 L .23018 .77697 L p F P
0 g
s
.905 .833 .764 r
.23018 .77697 m .23228 .77384 L .2395 .77623 L p F P
0 g
s
.727 .671 .796 r
.48507 .93598 m .48288 .93225 L .47823 .9353 L closepath p F P
0 g
s
.668 .62 .791 r
.58654 .9198 m .59225 .93243 L .56841 .93598 L p F P
0 g
s
.668 .62 .791 r
.56841 .93598 m .56485 .92867 L .58654 .9198 L p F P
0 g
s
.661 .707 .881 r
.47141 .46401 m .47397 .46747 L .49532 .45986 L p F P
0 g
s
.397 .737 .992 r
.59383 .16174 m .57467 .16371 L .57074 .1631 L p F P
0 g
s
.44 .777 .998 r
.57467 .16371 m .59383 .16174 L .59929 .16569 L p F P
0 g
s
.626 .477 .66 r
.54765 .7845 m .57084 .77995 L p .57021 .79337 L F P
0 g
s
.626 .477 .66 r
.57021 .79337 m .55021 .79743 L .54765 .7845 L p F P
0 g
s
.635 .482 .658 r
.5685 .76727 m .57084 .77995 L .54765 .7845 L p F P
0 g
s
.827 .769 .797 r
.74701 .36911 m .74592 .37028 L .75097 .37828 L p F P
0 g
s
.827 .768 .796 r
.73389 .38312 m .74592 .37028 L .75097 .37828 L p F P
0 g
s
.827 .768 .796 r
.75097 .37828 m .74025 .38977 L .73389 .38312 L p F P
0 g
s
.928 .555 .28 r
.24601 .90022 m .24342 .89046 L .23668 .88521 L p F P
0 g
s
0 .355 .72 r
.67302 .18287 m .66098 .17875 L .65868 .17783 L p F P
0 g
s
0 .459 .815 r
.68557 .18795 m .67302 .18287 L .66098 .17875 L p F P
0 g
s
.878 .475 .26 r
.73049 .21799 m .73974 .22415 L .74272 .23203 L p F P
0 g
s
.885 .477 .239 r
.75151 .2383 m .74272 .23203 L .73974 .22415 L p F P
0 g
s
.871 .647 .597 r
.46775 .70869 m .4677 .7085 L .46767 .70865 L closepath p F P
0 g
s
.92 .703 .593 r
.46767 .70865 m .4677 .7085 L .46175 .69687 L p F P
0 g
s
.255 0 .267 r
.32837 .21414 m .31262 .22412 L .31061 .23133 L p F P
0 g
s
.575 .599 .839 r
.34668 .41972 m .34723 .4207 L .34558 .42094 L closepath p F P
0 g
s
.916 .717 .62 r
.46045 .70311 m .46767 .70865 L .46457 .7198 L p F P
0 g
s
.92 .703 .593 r
.46175 .69687 m .46045 .70311 L .46767 .70865 L p F P
0 g
s
.446 .51 .831 r
.77812 .72372 m .78128 .71752 L p .79548 .73132 L F P
0 g
s
.464 .539 .849 r
.77812 .72372 m .77426 .71599 L .78128 .71752 L closepath p F P
0 g
s
.84 .373 .056 r
.26607 .91956 m .2586 .91464 L .25315 .90543 L p F P
0 g
s
.835 .365 .02 r
.24605 .90035 m .25315 .90543 L .2586 .91464 L p F P
0 g
s
.906 .506 .228 r
.24601 .90022 m .24605 .90035 L .25315 .90543 L p F P
0 g
s
.713 .635 .769 r
.51021 .92842 m .52392 .91926 L .50553 .91871 L closepath p F P
0 g
s
.225 .096 .486 r
.82401 .8579 m .82173 .85999 L .82241 .87046 L p F P
0 g
s
0 0 0 r
.78398 .92334 m .79134 .91666 L .78553 .92055 L closepath p F P
0 g
s
0 0 .067 r
.8035 .90255 m .79134 .91666 L .78553 .92055 L p F P
0 g
s
.824 .635 .647 r
.47725 .73879 m .47011 .73604 L p .47693 .75189 L F P
0 g
s
.824 .635 .647 r
.47693 .75189 m .47932 .74559 L .47725 .73879 L p F P
0 g
s
.748 .73 .836 r
.43412 .95135 m .43514 .95068 L .43314 .95014 L closepath p F P
0 g
s
.725 .722 .847 r
.43314 .95014 m .43412 .95135 L p .40673 .95554 L F P
0 g
s
.686 .611 .766 r
.53751 .92716 m .55417 .9181 L .53402 .9193 L closepath p F P
0 g
s
.596 .028 0 r
.70462 .19937 m .69691 .19345 L .68896 .18941 L p F P
0 g
s
.554 0 0 r
.71536 .20506 m .70462 .19937 L .69691 .19345 L p F P
0 g
s
.757 .824 .904 r
.3624 .65624 m .36825 .66054 L .36426 .66294 L closepath p F P
0 g
s
.397 .737 .992 r
.59071 .16015 m .59383 .16174 L p .57074 .1631 L F P
0 g
s
.397 .737 .992 r
.58231 .15906 m .59071 .16015 L p .57074 .1631 L F P
0 g
s
.397 .737 .992 r
.57074 .1631 m .56632 .15965 L .58231 .15906 L p F P
0 g
s
.517 .797 .996 r
.55371 .16184 m .57074 .1631 L .56632 .15965 L closepath p F P
0 g
s
.806 .613 .642 r
.4813 .75318 m .47932 .74559 L .47693 .75189 L closepath p F P
0 g
s
.747 .73 .836 r
.45078 .93062 m .45548 .93778 L .43514 .95068 L p F P
0 g
s
.747 .73 .836 r
.44738 .93004 m .45078 .93062 L p .43514 .95068 L F P
0 g
s
.747 .73 .836 r
.428 .94386 m .44738 .93004 L p .43514 .95068 L F P
0 g
s
.747 .73 .836 r
.43514 .95068 m .43314 .95014 L .428 .94386 L p F P
0 g
s
.551 .417 .651 r
.5685 .76727 m .56706 .75928 L .58443 .76103 L closepath p F P
0 g
s
.952 .637 .396 r
.23569 .87493 m .2293 .86951 L .23027 .87982 L p F P
0 g
s
.952 .637 .396 r
.23027 .87982 m .23668 .88521 L .23569 .87493 L p F P
0 g
s
.921 .645 .5 r
.7687 .269 m .76087 .26248 L .76113 .25328 L p F P
0 g
s
.909 .677 .575 r
.76087 .26248 m .7687 .269 L .76699 .27878 L p F P
0 g
s
.319 .725 .979 r
.60052 .1621 m .59383 .16174 L .59929 .16569 L p F P
0 g
s
.319 .725 .979 r
.59929 .16569 m .61742 .16562 L .60052 .1621 L p F P
0 g
s
.547 .538 .796 r
.30832 .38535 m .31725 .38484 L p .30353 .37138 L F P
0 g
s
.547 .538 .796 r
.30353 .37138 m .30255 .37235 L .30832 .38535 L p F P
0 g
s
.674 .73 .893 r
.50125 .46731 m .52273 .45956 L p .50408 .45649 L F P
0 g
s
.674 .73 .893 r
.50408 .45649 m .49532 .45986 L .50125 .46731 L p F P
0 g
s
.793 .763 .826 r
.70809 .41896 m .70649 .42031 L .69973 .41386 L p F P
0 g
s
.534 .382 .621 r
.58276 .7237 m .58126 .72325 L .58263 .72269 L closepath p F P
0 g
s
.03 0 .212 r
.80998 .88987 m .82158 .8806 L p .80492 .90157 L F P
0 g
s
.03 0 .212 r
.80492 .90157 m .80521 .89977 L .80998 .88987 L p F P
0 g
s
.199 .015 .392 r
.8223 .87789 m .82241 .87046 L p .80998 .88987 L F P
0 g
s
.199 .015 .392 r
.80998 .88987 m .82158 .8806 L .8223 .87789 L p F P
0 g
s
.62 .764 .948 r
.6584 .95827 m .68054 .95332 L .68579 .95862 L p F P
0 g
s
.621 .716 .914 r
.68054 .95332 m .6584 .95827 L .65298 .95117 L p F P
0 g
s
.795 .764 .824 r
.70809 .41896 m .72484 .40454 L .71831 .39797 L p F P
0 g
s
.795 .764 .824 r
.71831 .39797 m .7029 .4112 L .70809 .41896 L p F P
0 g
s
.793 .763 .826 r
.69973 .41386 m .7029 .4112 L .70809 .41896 L p F P
0 g
s
.742 .671 .781 r
.45548 .93778 m .46174 .93296 L .47823 .9353 L p F P
0 g
s
.722 .659 .787 r
.47695 .9215 m .46174 .93296 L .47823 .9353 L p F P
0 g
s
.722 .659 .787 r
.47823 .9353 m .48288 .93225 L .47695 .9215 L p F P
0 g
s
.632 .658 .857 r
.4135 .45384 m .43457 .44772 L p .4181 .44107 L F P
0 g
s
.632 .658 .857 r
.4181 .44107 m .40887 .4466 L .4135 .45384 L p F P
0 g
s
0 .355 .72 r
.66013 .17786 m .67302 .18287 L p .65868 .17783 L F P
0 g
s
0 .355 .72 r
.65868 .17783 m .65452 .17559 L .66013 .17786 L p F P
0 g
s
.034 .557 .864 r
.64708 .17418 m .65868 .17783 L .65452 .17559 L closepath p F P
0 g
s
.53 .814 .998 r
.51151 .15932 m .50359 .16136 L .48704 .16266 L p F P
0 g
s
.53 .814 .998 r
.50556 .15625 m .51151 .15932 L p .48704 .16266 L F P
0 g
s
.53 .814 .998 r
.48704 .16266 m .48413 .16069 L .50556 .15625 L p F P
0 g
s
.728 .738 .859 r
.62677 .44137 m .60495 .45369 L .6105 .4615 L p F P
0 g
s
.728 .738 .859 r
.6105 .4615 m .63225 .44927 L .62677 .44137 L p F P
0 g
s
.711 .744 .878 r
.58384 .46443 m .60495 .45369 L .6105 .4615 L p F P
0 g
s
.491 .571 .864 r
.74294 .69285 m .7638 .69581 L p .76392 .70464 L F P
0 g
s
.476 .571 .871 r
.74294 .69285 m .7638 .69581 L .75859 .6865 L p F P
0 g
s
.476 .571 .871 r
.75859 .6865 m .74588 .6846 L .74294 .69285 L p F P
0 g
s
.504 .599 .881 r
.73542 .6837 m .74588 .6846 L .74294 .69285 L p F P
0 g
s
.572 .65 .889 r
.44416 .64615 m .43336 .64739 L .4389 .63868 L closepath p F P
0 g
s
.452 .625 .927 r
.43336 .64739 m .44416 .64615 L .4502 .65585 L p F P
0 g
s
.836 .847 .854 r
.29028 .70799 m .28711 .70097 L .27064 .71615 L p F P
0 g
s
.836 .847 .854 r
.27648 .72081 m .29028 .70799 L p .27064 .71615 L F P
0 g
s
.82 .846 .868 r
.29794 .70153 m .29028 .70799 L .28711 .70097 L p F P
0 g
s
.904 .571 .405 r
.74272 .23203 m .75151 .2383 L .75281 .24688 L p F P
0 g
s
.914 .579 .395 r
.76113 .25328 m .75281 .24688 L .75151 .2383 L p F P
0 g
s
.752 .748 .849 r
.65943 .44321 m .64838 .4504 L .64008 .44451 L p F P
0 g
s
.59 .606 .836 r
.34668 .41972 m .34723 .4207 L .36787 .41681 L p F P
0 g
s
.692 .53 .662 r
.52409 .79974 m .52486 .79883 L .52389 .79886 L closepath p F P
0 g
s
.741 .583 .679 r
.52389 .79886 m .52409 .79974 L .51539 .81202 L p F P
0 g
s
.741 .583 .679 r
.50384 .79753 m .52389 .79886 L p .51539 .81202 L F P
0 g
s
.812 .766 .811 r
.72963 .39998 m .74025 .38977 L .73389 .38312 L p F P
0 g
s
.682 .531 .674 r
.52486 .79883 m .55021 .79743 L p .54328 .81142 L F P
0 g
s
.682 .531 .674 r
.52409 .79974 m .52486 .79883 L p .54328 .81142 L F P
0 g
s
.275 .184 .567 r
.59518 .68643 m .5893 .69276 L .59254 .70211 L p F P
0 g
s
.213 .1 .5 r
.5893 .69276 m .59518 .68643 L .59459 .67584 L p F P
0 g
s
.836 .847 .854 r
.27064 .71615 m .2717 .71833 L .27648 .72081 L p F P
0 g
s
.84 .846 .849 r
.2717 .71833 m .27648 .72081 L .27412 .72302 L closepath p F P
0 g
s
.859 .853 .835 r
.27412 .72302 m .26045 .7373 L .25671 .73054 L p F P
0 g
s
.859 .853 .835 r
.2717 .71833 m .27412 .72302 L p .25671 .73054 L F P
0 g
s
.765 .837 .907 r
.61348 .64724 m .61334 .64621 L .61409 .64686 L closepath p F P
0 g
s
.644 .617 .808 r
.61983 .93754 m .59797 .94366 L .59228 .93249 L p F P
0 g
s
.682 .531 .674 r
.54328 .81142 m .52709 .81246 L .52409 .79974 L p F P
0 g
s
.72 .554 .665 r
.52709 .81246 m .52409 .79974 L .51539 .81202 L closepath p F P
0 g
s
.911 .634 .504 r
.75281 .24688 m .76113 .25328 L .76087 .26248 L p F P
0 g
s
.585 .702 .923 r
.64205 .64722 m .64145 .64644 L .64208 .64635 L closepath p F P
0 g
s
0 .176 .712 r
.45038 .65209 m .44416 .64615 L .4502 .65585 L p F P
0 g
s
.297 .233 .615 r
.8329 .82161 m .82591 .82899 L .83058 .83871 L p F P
0 g
s
.341 .298 .664 r
.8318 .81698 m .82748 .81104 L p .82591 .82899 L F P
0 g
s
.341 .298 .664 r
.82591 .82899 m .8329 .82161 L .8318 .81698 L p F P
0 g
s
.66 .742 .911 r
.61409 .64686 m .63602 .63976 L .64145 .64644 L p F P
0 g
s
.652 .81 .959 r
.61334 .64621 m .61409 .64686 L .63602 .63976 L p F P
0 g
s
.74 .822 .915 r
.36825 .66054 m .3894 .64878 L p .3623 .65544 L F P
0 g
s
.74 .822 .915 r
.3623 .65544 m .3624 .65624 L .36825 .66054 L p F P
0 g
s
.793 .61 .654 r
.4813 .75318 m .47693 .75189 L p .48495 .76738 L F P
0 g
s
.793 .61 .654 r
.48495 .76738 m .4851 .76703 L .4813 .75318 L p F P
0 g
s
.499 .898 .936 r
.71306 .95606 m .73529 .94864 L .73776 .94897 L p F P
0 g
s
.575 .883 .992 r
.73529 .94864 m .71306 .95606 L .70802 .95292 L p F P
0 g
s
.594 .848 .993 r
.68579 .95862 m .70802 .95292 L .71306 .95606 L p F P
0 g
s
.812 .766 .811 r
.73389 .38312 m .72451 .3921 L .72963 .39998 L p F P
0 g
s
.81 .766 .811 r
.71831 .39797 m .72451 .3921 L .72963 .39998 L p F P
0 g
s
.81 .766 .811 r
.72963 .39998 m .72484 .40454 L .71831 .39797 L p F P
0 g
s
.82 .85 .871 r
.30675 .6848 m .29107 .69766 L .29794 .70153 L p F P
0 g
s
.82 .85 .871 r
.29794 .70153 m .30945 .69201 L .30675 .6848 L p F P
0 g
s
.82 .846 .868 r
.28711 .70097 m .29107 .69766 L .29794 .70153 L p F P
0 g
s
.725 .722 .847 r
.40673 .95554 m .4206 .94785 L .43314 .95014 L p F P
0 g
s
.723 .725 .851 r
.43314 .95014 m .428 .94386 L .4206 .94785 L closepath p F P
0 g
s
0 0 0 r
.37349 .18734 m .37776 .18334 L .35738 .19249 L p F P
0 g
s
0 0 0 r
.35738 .19249 m .35303 .19653 L .37349 .18734 L p F P
0 g
s
.683 .742 .895 r
.52856 .46675 m .55015 .45872 L p .53237 .45563 L F P
0 g
s
.683 .742 .895 r
.53237 .45563 m .52273 .45956 L .52856 .46675 L p F P
0 g
s
.581 .587 .823 r
.34101 .40881 m .34668 .41972 L .36203 .40615 L p F P
0 g
s
.59 .606 .836 r
.36787 .41681 m .36203 .40615 L .34668 .41972 L p F P
0 g
s
.622 .766 .949 r
.35211 .95786 m .37296 .95279 L .37936 .9581 L p F P
0 g
s
.644 .767 .938 r
.37296 .95279 m .35211 .95786 L .34558 .95333 L p F P
0 g
s
.444 .318 .614 r
.58263 .72269 m .59703 .71117 L p .58935 .7313 L F P
0 g
s
.444 .318 .614 r
.58935 .7313 m .58276 .7237 L .58263 .72269 L p F P
0 g
s
.369 .253 .589 r
.58263 .72269 m .59703 .71117 L .59254 .70211 L p F P
0 g
s
.735 .636 .75 r
.5014 .91845 m .48288 .93225 L .47695 .9215 L p F P
0 g
s
.948 .798 .661 r
.22741 .81359 m .22223 .80756 L .21776 .81923 L p F P
0 g
s
.948 .798 .661 r
.21776 .81923 m .22297 .82523 L .22741 .81359 L p F P
0 g
s
.97 .742 .537 r
.46175 .69687 m .46238 .69234 L .457 .68617 L p F P
0 g
s
.924 .827 .731 r
.23485 .78327 m .23018 .77697 L .22315 .78934 L p F P
0 g
s
.924 .827 .731 r
.22315 .78934 m .22791 .79558 L .23485 .78327 L p F P
0 g
s
.467 .768 .996 r
.56632 .15965 m .55371 .16184 L .54133 .16087 L p F P
0 g
s
.683 .143 0 r
.28217 .93286 m .27441 .92808 L .26607 .91956 L p F P
0 g
s
.662 .121 0 r
.2586 .91464 m .26607 .91956 L .27441 .92808 L p F P
0 g
s
.898 .733 .669 r
.7737 .31327 m .76678 .30658 L .77125 .29572 L p F P
0 g
s
.882 .741 .702 r
.76678 .30658 m .7737 .31327 L .76786 .32465 L p F P
0 g
s
.43 .321 .628 r
.27907 .29614 m .28018 .29681 L p .29222 .27322 L F P
0 g
s
.42 .312 .625 r
.27907 .29614 m .28018 .29681 L .27927 .29762 L closepath p F P
0 g
s
.963 .697 .484 r
.22976 .85887 m .22372 .85328 L .22323 .86395 L p F P
0 g
s
.963 .697 .484 r
.22323 .86395 m .2293 .86951 L .22976 .85887 L p F P
0 g
s
.744 .734 .843 r
.4206 .94785 m .40673 .95554 L .40047 .94926 L p F P
0 g
s
.696 .752 .895 r
.37936 .9581 m .40047 .94926 L .40673 .95554 L p F P
0 g
s
.613 .632 .846 r
.3803 .43868 m .40118 .43366 L p .38165 .42637 L F P
0 g
s
.613 .632 .846 r
.38165 .42637 m .37564 .43086 L .3803 .43868 L p F P
0 g
s
.611 .79 .967 r
.70802 .95292 m .68579 .95862 L .68054 .95332 L p F P
0 g
s
.424 .314 .625 r
.58447 .73474 m .58276 .7237 L .58935 .7313 L closepath p F P
0 g
s
.582 .711 .931 r
.64208 .64635 m .64145 .64644 L .63602 .63976 L p F P
0 g
s
.696 .74 .885 r
.55589 .46611 m .56749 .46125 L .55341 .45726 L p F P
0 g
s
.696 .74 .885 r
.55341 .45726 m .55015 .45872 L .55589 .46611 L p F P
0 g
s
.8 .843 .884 r
.31926 .68461 m .30945 .69201 L .30675 .6848 L p F P
0 g
s
.87 .755 .732 r
.76647 .34278 m .76701 .34333 L p .76786 .32465 L F P
0 g
s
.854 .759 .758 r
.76647 .34278 m .76689 .3435 L .76701 .34333 L closepath p F P
0 g
s
.708 .737 .874 r
.58259 .46389 m .58322 .46473 L .58384 .46443 L closepath p F P
0 g
s
.69 .756 .902 r
.58322 .46473 m .58259 .46389 L .56749 .46125 L p F P
0 g
s
.151 0 .038 r
.35235 .19771 m .35303 .19653 L .33378 .20688 L p F P
0 g
s
.151 0 .038 r
.33378 .20688 m .33113 .21178 L .35235 .19771 L p F P
0 g
s
.851 .759 .76 r
.76689 .3435 m .7579 .3559 L p .76042 .33662 L F P
0 g
s
.851 .759 .76 r
.76042 .33662 m .76647 .34278 L .76689 .3435 L p F P
0 g
s
.665 .599 .771 r
.58443 .91455 m .58654 .9198 L .56485 .92867 L p F P
0 g
s
.665 .599 .771 r
.56485 .92867 m .56008 .91773 L .58443 .91455 L p F P
0 g
s
.578 .82 .99 r
.50359 .16136 m .51346 .16079 L .51151 .15932 L closepath p F P
0 g
s
.686 .613 .768 r
.55417 .9181 m .53402 .9193 L .5317 .91411 L p F P
0 g
s
.706 .622 .761 r
.53402 .9193 m .5317 .91411 L .52392 .91926 L closepath p F P
0 g
s
.381 .201 .508 r
.30951 .2493 m .3096 .23976 L .29264 .25227 L p F P
0 g
s
.381 .201 .508 r
.29264 .25227 m .2925 .26179 L .30951 .2493 L p F P
0 g
s
.328 .159 .495 r
.28659 .26688 m .2925 .26179 L .29264 .25227 L p F P
0 g
s
.713 .636 .771 r
.52678 .90203 m .5317 .91411 L .52392 .91926 L p F P
0 g
s
.713 .636 .771 r
.52305 .90196 m .52678 .90203 L p .52392 .91926 L F P
0 g
s
.713 .636 .771 r
.50436 .91629 m .52305 .90196 L p .52392 .91926 L F P
0 g
s
.713 .636 .771 r
.52392 .91926 m .50553 .91871 L .50436 .91629 L p F P
0 g
s
.582 .711 .931 r
.63602 .63976 m .64073 .63899 L .64208 .64635 L p F P
0 g
s
.581 .707 .93 r
.64208 .64635 m .66368 .64367 L .65829 .63645 L p F P
0 g
s
.581 .707 .93 r
.65829 .63645 m .64073 .63899 L .64208 .64635 L p F P
0 g
s
.717 .734 .864 r
.58384 .46443 m .60495 .45369 L p .57757 .4569 L F P
0 g
s
.717 .734 .864 r
.57757 .4569 m .58259 .46389 L .58384 .46443 L p F P
0 g
s
.878 .852 .814 r
.2547 .744 m .26045 .7373 L .25671 .73054 L p F P
0 g
s
.459 .373 .671 r
.28018 .29681 m .27927 .29762 L .28186 .3103 L p F P
0 g
s
.652 .81 .959 r
.63057 .63329 m .61986 .63749 L .61334 .64621 L p F P
0 g
s
.652 .81 .959 r
.63602 .63976 m .63057 .63329 L p .61334 .64621 L F P
0 g
s
.724 .875 .951 r
.60865 .64308 m .61986 .63749 L .61334 .64621 L closepath p F P
0 g
s
.76 .59 .667 r
.49089 .78852 m .49372 .78264 L p .50384 .79753 L F P
0 g
s
.783 .604 .658 r
.49089 .78852 m .49372 .78264 L .48899 .7816 L closepath p F P
0 g
s
.783 .603 .656 r
.49372 .78264 m .48899 .7816 L .48521 .76743 L p F P
0 g
s
.785 .6 .65 r
.48521 .76743 m .4851 .76703 L .48495 .76738 L closepath p F P
0 g
s
.711 .751 .884 r
.40047 .94926 m .37936 .9581 L .37296 .95279 L p F P
0 g
s
.786 .604 .654 r
.48495 .76738 m .48521 .76743 L .48899 .7816 L p F P
0 g
s
.786 .604 .654 r
.48899 .7816 m .47942 .7794 L .48495 .76738 L p F P
0 g
s
.818 .632 .651 r
.47229 .76362 m .48495 .76738 L .47942 .7794 L p F P
0 g
s
.793 .61 .654 r
.47693 .75189 m .47229 .76362 L .48495 .76738 L p F P
0 g
s
.467 .768 .996 r
.56068 .15656 m .56632 .15965 L p .54133 .16087 L F P
0 g
s
.467 .768 .996 r
.54133 .16087 m .5389 .15895 L .56068 .15656 L p F P
0 g
s
.557 .808 .992 r
.5307 .16078 m .54133 .16087 L .5389 .15895 L closepath p F P
0 g
s
.87 .755 .732 r
.76786 .32465 m .76181 .33437 L .76647 .34278 L p F P
0 g
s
.871 .755 .732 r
.76181 .33437 m .76042 .33662 L .76647 .34278 L closepath p F P
0 g
s
.511 .792 .996 r
.5389 .15895 m .5307 .16078 L .51346 .16079 L p F P
0 g
s
.511 .792 .996 r
.5331 .15571 m .5389 .15895 L p .51346 .16079 L F P
0 g
s
.511 .792 .996 r
.51346 .16079 m .51151 .15932 L .5331 .15571 L p F P
0 g
s
.662 .699 .874 r
.46796 .45918 m .47141 .46401 L .4939 .45789 L p F P
0 g
s
.661 .707 .881 r
.49532 .45986 m .4939 .45789 L .47141 .46401 L p F P
0 g
s
.389 .251 .57 r
.2925 .26179 m .28659 .26688 L .29222 .27322 L p F P
0 g
s
.552 .421 .655 r
.57084 .77995 m .5685 .76727 L .58443 .76103 L p F P
0 g
s
.712 .792 .914 r
.4169 .64386 m .41241 .64591 L .41 .63854 L p F P
0 g
s
.741 .583 .679 r
.4967 .80974 m .50384 .79753 L p .51539 .81202 L F P
0 g
s
.76 .592 .669 r
.4967 .80974 m .50384 .79753 L .49288 .79586 L closepath p F P
0 g
s
.76 .59 .667 r
.50384 .79753 m .49288 .79586 L .49089 .78852 L p F P
0 g
s
.69 .725 .876 r
.57757 .4569 m .56749 .46125 L .58259 .46389 L closepath p F P
0 g
s
.759 .75 .845 r
.65943 .44321 m .67712 .43111 L .66927 .42501 L p F P
0 g
s
.759 .75 .845 r
.66927 .42501 m .65405 .4354 L .65943 .44321 L p F P
0 g
s
.752 .748 .849 r
.64008 .44451 m .65405 .4354 L .65943 .44321 L p F P
0 g
s
.627 .48 .663 r
.55144 .80348 m .57021 .79337 L .55021 .79743 L closepath p F P
0 g
s
.682 .531 .674 r
.55021 .79743 m .55144 .80348 L .54328 .81142 L p F P
0 g
s
.846 .656 .645 r
.46616 .74754 m .47693 .75189 L .47229 .76362 L p F P
0 g
s
.824 .635 .647 r
.47011 .73604 m .46616 .74754 L .47693 .75189 L p F P
0 g
s
.723 .641 .766 r
.50553 .91871 m .50436 .91629 L .5014 .91845 L closepath p F P
0 g
s
.797 .847 .888 r
.33068 .66727 m .31249 .68051 L .31926 .68461 L p F P
0 g
s
.797 .847 .888 r
.31926 .68461 m .33273 .67474 L .33068 .66727 L p F P
0 g
s
.8 .843 .884 r
.30675 .6848 m .31249 .68051 L .31926 .68461 L p F P
0 g
s
.43 .321 .628 r
.28018 .29681 m .29487 .28396 L p .29222 .27322 L F P
0 g
s
.461 .37 .666 r
.29487 .28396 m .28018 .29681 L .29282 .30053 L p F P
0 g
s
.459 .373 .671 r
.28186 .3103 m .29282 .30053 L .28018 .29681 L p F P
0 g
s
.565 .927 .941 r
.73529 .94864 m .74932 .94298 L .73776 .94897 L closepath p F P
0 g
s
.583 .943 .9 r
.75757 .93946 m .74932 .94298 L .73776 .94897 L p F P
0 g
s
.583 .943 .9 r
.76209 .9381 m .75757 .93946 L p .73776 .94897 L F P
0 g
s
.682 .532 .675 r
.52991 .82426 m .54328 .81142 L .52709 .81246 L closepath p F P
0 g
s
.701 .543 .671 r
.52709 .81246 m .51539 .81202 L p .52829 .82617 L F P
0 g
s
.701 .543 .671 r
.52829 .82617 m .52991 .82426 L .52709 .81246 L p F P
0 g
s
0 0 0 r
.77056 .93286 m .76209 .9381 L .75757 .93946 L p F P
0 g
s
.878 .852 .814 r
.25671 .73054 m .24756 .74109 L .2547 .744 L p F P
0 g
s
.875 .849 .815 r
.2547 .744 m .2487 .751 L .24473 .74436 L p F P
0 g
s
.875 .849 .815 r
.24473 .74436 m .24756 .74109 L .2547 .744 L p F P
0 g
s
.225 .096 .486 r
.82241 .87046 m .82414 .86888 L .82401 .8579 L p F P
0 g
s
.201 .077 .478 r
.83308 .84907 m .82401 .8579 L .82414 .86888 L p F P
0 g
s
.264 .169 .556 r
.82401 .8579 m .83308 .84907 L .83058 .83871 L p F P
0 g
s
.994 .753 .413 r
.45758 .67586 m .4538 .66912 L .45324 .67944 L p F P
0 g
s
.994 .753 .413 r
.45324 .67944 m .457 .68617 L .45758 .67586 L p F P
0 g
s
.064 0 .45 r
.59679 .67264 m .59459 .67584 L .59518 .68643 L p F P
0 g
s
.686 .613 .768 r
.5317 .91411 m .55303 .90086 L p .55417 .9181 L F P
0 g
s
.692 .601 .75 r
.5317 .91411 m .55303 .90086 L .52678 .90203 L closepath p F P
0 g
s
.735 .636 .75 r
.47695 .9215 m .48257 .91668 L .5014 .91845 L p F P
0 g
s
.716 .627 .756 r
.49848 .90326 m .48257 .91668 L .5014 .91845 L p F P
0 g
s
.716 .627 .756 r
.5014 .91845 m .50436 .91629 L .49848 .90326 L p F P
0 g
s
.529 .508 .777 r
.30217 .3714 m .30353 .37138 L .30255 .37235 L closepath p F P
0 g
s
.529 .503 .771 r
.31626 .35533 m .2961 .35617 L .30217 .3714 L p F P
0 g
s
.529 .503 .771 r
.31735 .35816 m .31626 .35533 L p .30217 .3714 L F P
0 g
s
.529 .503 .771 r
.30217 .3714 m .30353 .37138 L .31735 .35816 L p F P
0 g
s
.515 .506 .785 r
.30217 .3714 m .2961 .35617 L .29452 .35615 L p F P
0 g
s
.631 .665 .865 r
.62614 .94868 m .62544 .94759 L .64534 .94317 L closepath p F P
0 g
s
.126 .577 .922 r
.31486 .9486 m .31847 .94953 L .31177 .94531 L p F P
0 g
s
.126 .577 .922 r
.31177 .94531 m .30641 .94409 L .31486 .9486 L p F P
0 g
s
.461 .541 .853 r
.78128 .71752 m .77426 .71599 L .76902 .70568 L p F P
0 g
s
.721 .606 .728 r
.52305 .90196 m .50436 .91629 L .49848 .90326 L p F P
0 g
s
.701 .543 .671 r
.51539 .81202 m .506 .82523 L .52829 .82617 L p F P
0 g
s
.741 .584 .681 r
.49683 .8102 m .51539 .81202 L .506 .82523 L p F P
0 g
s
.741 .583 .679 r
.51539 .81202 m .49683 .8102 L .4967 .80974 L p F P
0 g
s
.151 0 .254 r
.8035 .90255 m .80492 .90157 L .80521 .89977 L closepath p F P
0 g
s
.965 .742 .553 r
.22553 .84231 m .21986 .83654 L .21802 .84754 L p F P
0 g
s
.965 .742 .553 r
.21802 .84754 m .22372 .85328 L .22553 .84231 L p F P
0 g
s
.78 .288 .042 r
.70462 .19937 m .71536 .20506 L .72068 .21198 L p F P
0 g
s
.751 .234 0 r
.72187 .21266 m .72068 .21198 L .71536 .20506 L p F P
0 g
s
.771 .598 .664 r
.48899 .7816 m .47942 .7794 L p .4875 .7949 L F P
0 g
s
.771 .598 .664 r
.4875 .7949 m .49089 .78852 L .48899 .7816 L p F P
0 g
s
0 0 0 r
.39932 .17535 m .40157 .17439 L .3806 .18219 L p F P
0 g
s
.754 .697 .797 r
.45548 .93778 m .46174 .93296 L .45078 .93062 L closepath p F P
0 g
s
.878 .685 .639 r
.46114 .7311 m .47011 .73604 L .46616 .74754 L p F P
0 g
s
.863 .67 .64 r
.46457 .7198 m .46114 .7311 L .47011 .73604 L p F P
0 g
s
.686 .611 .766 r
.56008 .91773 m .55907 .91544 L .55417 .9181 L closepath p F P
0 g
s
.686 .613 .768 r
.55332 .90085 m .55907 .91544 L .55417 .9181 L p F P
0 g
s
.686 .613 .768 r
.55303 .90086 m .55332 .90085 L p .55417 .9181 L F P
0 g
s
.647 .669 .858 r
.45586 .44066 m .43457 .44772 L .44067 .45712 L p F P
0 g
s
.647 .669 .858 r
.44067 .45712 m .46192 .45011 L .45586 .44066 L p F P
0 g
s
.97 .742 .537 r
.457 .68617 m .45552 .69667 L .46175 .69687 L p F P
0 g
s
.973 .771 .572 r
.46175 .69687 m .46045 .70311 L .45549 .69682 L p F P
0 g
s
.973 .771 .572 r
.45549 .69682 m .45552 .69667 L .46175 .69687 L p F P
0 g
s
.643 .73 .912 r
.43186 .63069 m .41061 .63825 L .4169 .64386 L p F P
0 g
s
.643 .73 .912 r
.4169 .64386 m .43805 .63764 L .43186 .63069 L p F P
0 g
s
.614 .708 .911 r
.4169 .64386 m .43805 .63764 L .4389 .63868 L p F P
0 g
s
.712 .792 .914 r
.41 .63854 m .41061 .63825 L .4169 .64386 L p F P
0 g
s
.895 .847 .79 r
.2487 .751 m .24473 .74436 L .2346 .75762 L p F P
0 g
s
.895 .847 .79 r
.2346 .75762 m .23871 .76419 L .2487 .751 L p F P
0 g
s
.905 .709 .627 r
.77125 .29572 m .76388 .28912 L .76699 .27878 L p F P
0 g
s
.889 .721 .668 r
.76388 .28912 m .77125 .29572 L .76678 .30658 L p F P
0 g
s
.176 .641 .935 r
.62678 .16905 m .63278 .16971 L .62339 .16691 L closepath p F P
0 g
s
.63 .632 .834 r
.64534 .94317 m .62544 .94759 L .61983 .93754 L p F P
0 g
s
.596 .028 0 r
.69343 .19379 m .70462 .19937 L p .68896 .18941 L F P
0 g
s
.596 .028 0 r
.68896 .18941 m .68761 .18907 L .69343 .19379 L p F P
0 g
s
.442 0 0 r
.68557 .18795 m .68896 .18941 L .68761 .18907 L closepath p F P
0 g
s
.634 .496 .676 r
.55308 .81069 m .55144 .80348 L .57021 .79337 L p F P
0 g
s
.678 .524 .669 r
.55308 .81069 m .55144 .80348 L .54328 .81142 L closepath p F P
0 g
s
.032 .556 .863 r
.63278 .16971 m .64708 .17418 L .65452 .17559 L p F P
0 g
s
.754 .697 .798 r
.47372 .91534 m .47695 .9215 L .46174 .93296 L p F P
0 g
s
.754 .697 .798 r
.46617 .91426 m .47372 .91534 L p .46174 .93296 L F P
0 g
s
.754 .697 .798 r
.44945 .9286 m .46617 .91426 L p .46174 .93296 L F P
0 g
s
.754 .697 .798 r
.46174 .93296 m .45078 .93062 L .44945 .9286 L p F P
0 g
s
.769 .596 .663 r
.49288 .79586 m .49089 .78852 L .4875 .7949 L closepath p F P
0 g
s
.547 .533 .791 r
.31735 .35816 m .3224 .3699 L .30353 .37138 L closepath p F P
0 g
s
.547 .538 .796 r
.32538 .37685 m .3224 .3699 L .30353 .37138 L p F P
0 g
s
.547 .538 .796 r
.31725 .38484 m .32538 .37685 L p .30353 .37138 L F P
0 g
s
.67 .603 .772 r
.58077 .90555 m .58443 .91455 L .56008 .91773 L p F P
0 g
s
.67 .603 .772 r
.56008 .91773 m .55907 .91544 L .58077 .90555 L p F P
0 g
s
.023 0 .063 r
.80492 .90157 m .8035 .90255 L .79134 .91666 L p F P
0 g
s
.5 .477 .763 r
.29452 .35615 m .29561 .35494 L p .28942 .33942 L F P
0 g
s
.516 .501 .778 r
.29561 .35494 m .2961 .35617 L .29452 .35615 L closepath p F P
0 g
s
.47 0 0 r
.28217 .93286 m .2851 .935 L .27825 .93081 L p F P
0 g
s
.47 0 0 r
.27825 .93081 m .27441 .92808 L .28217 .93286 L p F P
0 g
s
0 0 0 r
.77056 .93286 m .78138 .92633 L .78398 .92334 L closepath p F P
0 g
s
0 0 0 r
.78138 .92633 m .77056 .93286 L p .75757 .93946 L F P
0 g
s
.525 .629 .896 r
.70215 .66577 m .72217 .66607 L .72001 .67424 L p F P
0 g
s
.52 .633 .902 r
.72217 .66607 m .70215 .66577 L .69686 .65762 L p F P
0 g
s
.692 .547 .684 r
.54328 .81142 m .55308 .81069 L p .53042 .82619 L F P
0 g
s
.692 .547 .684 r
.53042 .82619 m .52991 .82426 L .54328 .81142 L p F P
0 g
s
.307 .799 .804 r
.42804 .16723 m .40543 .17393 L p .42207 .16841 L F P
0 g
s
.307 .799 .804 r
.40543 .17393 m .40157 .17439 L .42266 .16822 L p F P
0 g
s
0 0 0 r
.39932 .17535 m .42201 .16854 L p .41305 .1711 L F P
0 g
s
0 0 0 r
.40157 .17439 m .40048 .17486 L p .41305 .1711 L F P
0 g
s
0 0 0 r
.40048 .17486 m .39932 .17535 L p .41305 .1711 L F P
0 g
s
.307 .799 .804 r
.42266 .16822 m .42284 .16818 L p .42207 .16841 L F P
0 g
s
.307 .799 .804 r
.42284 .16818 m .42804 .16723 L p .42207 .16841 L F P
0 g
s
.779 .839 .898 r
.3405 .6695 m .33273 .67474 L .33068 .66727 L p F P
0 g
s
.851 .759 .76 r
.7579 .3559 m .75122 .34924 L .76042 .33662 L p F P
0 g
s
.838 .758 .775 r
.74701 .36911 m .7579 .3559 L .75122 .34924 L p F P
0 g
s
.737 .51 0 r
.45239 .66157 m .4538 .66912 L .45238 .65948 L p F P
0 g
s
.744 .734 .843 r
.40047 .94926 m .40817 .94444 L .4206 .94785 L p F P
0 g
s
.721 .719 .848 r
.42184 .93615 m .40817 .94444 L .4206 .94785 L p F P
0 g
s
.721 .719 .848 r
.4206 .94785 m .428 .94386 L .42184 .93615 L p F P
0 g
s
.488 .418 .704 r
.29282 .30053 m .28186 .3103 L .2844 .32014 L p F P
0 g
s
.711 .558 .679 r
.53042 .82619 m .52991 .82426 L .52829 .82617 L closepath p F P
0 g
s
.668 .584 .752 r
.57799 .8979 m .58077 .90555 L .55907 .91544 L p F P
0 g
s
.668 .584 .752 r
.55907 .91544 m .55332 .90085 L .57799 .8979 L p F P
0 g
s
.753 .588 .672 r
.49288 .79586 m .4875 .7949 L p .49644 .81015 L F P
0 g
s
.753 .588 .672 r
.49644 .81015 m .4967 .80974 L .49288 .79586 L p F P
0 g
s
.321 .284 .661 r
.8318 .81698 m .82748 .81104 L .82977 .80843 L closepath p F P
0 g
s
.359 .339 .701 r
.82748 .81104 m .82977 .80843 L .82583 .79432 L p F P
0 g
s
.676 .538 .689 r
.53042 .82619 m .55619 .82421 L p .54442 .83946 L F P
0 g
s
.676 .538 .689 r
.54442 .83946 m .53416 .84034 L .53042 .82619 L p F P
0 g
s
.692 .547 .684 r
.55308 .81069 m .55619 .82421 L .53042 .82619 L p F P
0 g
s
.711 .559 .68 r
.52829 .82617 m .53042 .82619 L .53416 .84034 L p F P
0 g
s
.711 .559 .68 r
.53416 .84034 m .51631 .8401 L .52829 .82617 L p F P
0 g
s
.726 .582 .693 r
.506 .82523 m .52829 .82617 L .51631 .8401 L p F P
0 g
s
.644 .617 .808 r
.61497 .92771 m .61983 .93754 L p .59228 .93249 L F P
0 g
s
.644 .617 .808 r
.59228 .93249 m .59308 .93225 L .61497 .92771 L p F P
0 g
s
.639 .592 .785 r
.59228 .93249 m .59308 .93225 L .59225 .93243 L closepath p F P
0 g
s
.626 .643 .847 r
.40734 .44408 m .4181 .44107 L .40887 .4466 L closepath p F P
0 g
s
.64 .594 .787 r
.59308 .93225 m .59225 .93243 L .58654 .9198 L p F P
0 g
s
.692 .602 .751 r
.55303 .90086 m .52678 .90203 L .52588 .89982 L p F P
0 g
s
.712 .612 .743 r
.52678 .90203 m .52588 .89982 L .52305 .90196 L closepath p F P
0 g
s
.584 .588 .822 r
.34101 .40881 m .36163 .40536 L p .33576 .39658 L F P
0 g
s
.584 .588 .822 r
.33576 .39658 m .33501 .39722 L .34101 .40881 L p F P
0 g
s
.581 .587 .823 r
.36203 .40615 m .36163 .40536 L .34101 .40881 L p F P
0 g
s
.463 .547 .857 r
.76902 .70568 m .76392 .70464 L .76599 .69981 L closepath p F P
0 g
s
.491 .571 .864 r
.7638 .69581 m .76599 .69981 L .76392 .70464 L p F P
0 g
s
.915 .724 .63 r
.45745 .71424 m .46457 .7198 L .46114 .7311 L p F P
0 g
s
.916 .717 .62 r
.46457 .7198 m .45745 .71424 L .46045 .70311 L p F P
0 g
s
.502 .608 .891 r
.72001 .67424 m .73019 .67489 L .72494 .66625 L p F P
0 g
s
.502 .608 .891 r
.72494 .66625 m .72217 .66607 L .72001 .67424 L p F P
0 g
s
.497 .6 .887 r
.74588 .6846 m .73542 .6837 L .73019 .67489 L p F P
0 g
s
.721 .606 .728 r
.49848 .90326 m .50103 .901 L .52305 .90196 L p F P
0 g
s
.703 .595 .732 r
.51856 .88555 m .50103 .901 L .52305 .90196 L p F P
0 g
s
.703 .595 .732 r
.52055 .88563 m .51856 .88555 L p .52305 .90196 L F P
0 g
s
.703 .595 .732 r
.52305 .90196 m .52588 .89982 L .52055 .88563 L p F P
0 g
s
.644 .616 .807 r
.61497 .92771 m .61416 .92607 L .59308 .93225 L closepath p F P
0 g
s
.64 .594 .787 r
.60843 .91305 m .61416 .92607 L .59308 .93225 L p F P
0 g
s
.64 .594 .787 r
.58654 .9198 m .60843 .91305 L p .59308 .93225 L F P
0 g
s
.94 .82 .699 r
.22791 .79558 m .22315 .78934 L .21741 .80136 L p F P
0 g
s
.94 .82 .699 r
.21741 .80136 m .22223 .80756 L .22791 .79558 L p F P
0 g
s
.77 .751 .836 r
.68118 .42809 m .67712 .43111 L .66927 .42501 L p F P
0 g
s
.627 .492 .678 r
.55308 .81069 m .57621 .80607 L p .57733 .81982 L F P
0 g
s
.627 .492 .678 r
.57733 .81982 m .55619 .82421 L .55308 .81069 L p F P
0 g
s
.634 .496 .676 r
.57329 .79276 m .57621 .80607 L .55308 .81069 L p F P
0 g
s
.634 .496 .676 r
.57021 .79337 m .57329 .79276 L p .55308 .81069 L F P
0 g
s
.43 .323 .632 r
.58935 .7313 m .58447 .73474 L .58648 .74701 L p F P
0 g
s
.535 .512 .777 r
.29561 .35494 m .2961 .35617 L .31626 .35533 L p F P
0 g
s
.692 .602 .751 r
.52588 .89982 m .54666 .88494 L p .55303 .90086 L F P
0 g
s
.698 .592 .734 r
.52588 .89982 m .54666 .88494 L .52055 .88563 L closepath p F P
0 g
s
.955 .768 .612 r
.22276 .82597 m .22297 .82523 L .22353 .82582 L closepath p F P
0 g
s
.955 .768 .612 r
.21986 .83654 m .22276 .82597 L .22353 .82582 L p F P
0 g
s
.882 .741 .702 r
.76786 .32465 m .76086 .318 L .76678 .30658 L p F P
0 g
s
.863 .744 .731 r
.76181 .33437 m .76786 .32465 L .76086 .318 L p F P
0 g
s
.464 0 0 r
.67302 .18287 m .68557 .18795 L .68761 .18907 L p F P
0 g
s
.691 .733 .883 r
.57757 .4569 m .56749 .46125 L .55341 .45726 L p F P
0 g
s
.521 .483 .755 r
.29014 .33947 m .29561 .35494 L .31068 .34093 L p F P
0 g
s
.535 .512 .777 r
.31626 .35533 m .31068 .34093 L .29561 .35494 L p F P
0 g
s
.5 .477 .763 r
.29561 .35494 m .29014 .33947 L .28942 .33942 L p F P
0 g
s
.604 .614 .834 r
.37408 .42808 m .38165 .42637 L .37564 .43086 L closepath p F P
0 g
s
.549 .671 .919 r
.69095 .64967 m .66905 .65108 L .66368 .64367 L p F P
0 g
s
.55 .664 .912 r
.66905 .65108 m .69095 .64967 L .68947 .65778 L p F P
0 g
s
.748 .661 .765 r
.47695 .9215 m .48257 .91668 L .47372 .91534 L closepath p F P
0 g
s
.488 .418 .704 r
.2844 .32014 m .28877 .32093 L p .29282 .30053 L F P
0 g
s
.48 .411 .702 r
.2844 .32014 m .28877 .32093 L .28538 .32402 L closepath p F P
0 g
s
.393 .831 .948 r
.48289 .15738 m .47801 .15815 L .48413 .16069 L p F P
0 g
s
.393 .831 .948 r
.50329 .15566 m .48289 .15738 L p .48413 .16069 L F P
0 g
s
.393 .831 .948 r
.48413 .16069 m .50556 .15625 L .50329 .15566 L p F P
0 g
s
.74 .742 .854 r
.63225 .44927 m .64008 .44451 L .63089 .43887 L p F P
0 g
s
.74 .742 .854 r
.63089 .43887 m .62677 .44137 L .63225 .44927 L p F P
0 g
s
.773 .844 .905 r
.35513 .6515 m .33383 .66516 L .3405 .6695 L p F P
0 g
s
.773 .844 .905 r
.3405 .6695 m .36173 .65578 L .35513 .6515 L p F P
0 g
s
.779 .839 .898 r
.33068 .66727 m .33383 .66516 L .3405 .6695 L p F P
0 g
s
0 0 .03 r
.81524 .89331 m .80492 .90157 L .80249 .90895 L p F P
0 g
s
.03 0 .212 r
.82158 .8806 m .81524 .89331 L .80492 .90157 L p F P
0 g
s
.023 0 .063 r
.79134 .91666 m .80249 .90895 L .80492 .90157 L p F P
0 g
s
.775 .753 .833 r
.68118 .42809 m .69973 .41386 L .69227 .40759 L p F P
0 g
s
.775 .753 .833 r
.69227 .40759 m .67587 .42013 L .68118 .42809 L p F P
0 g
s
.77 .751 .836 r
.66927 .42501 m .67587 .42013 L .68118 .42809 L p F P
0 g
s
.909 .677 .575 r
.76699 .27878 m .75914 .27228 L .76087 .26248 L p F P
0 g
s
.895 .697 .627 r
.75914 .27228 m .76699 .27878 L .76388 .28912 L p F P
0 g
s
.368 .812 .952 r
.51389 .15533 m .50556 .15625 L .51151 .15932 L p F P
0 g
s
.368 .812 .952 r
.53092 .15503 m .51389 .15533 L p .51151 .15932 L F P
0 g
s
.368 .812 .952 r
.51151 .15932 m .5331 .15571 L .53092 .15503 L p F P
0 g
s
0 0 0 r
.78138 .92633 m .78398 .92334 L .79134 .91666 L p F P
0 g
s
.748 .662 .766 r
.49741 .90071 m .49848 .90326 L .48257 .91668 L p F P
0 g
s
.748 .662 .766 r
.48241 .89914 m .49741 .90071 L p .48257 .91668 L F P
0 g
s
.748 .662 .766 r
.47101 .91021 m .48241 .89914 L p .48257 .91668 L F P
0 g
s
.748 .662 .766 r
.48257 .91668 m .47372 .91534 L .47101 .91021 L p F P
0 g
s
.876 .479 .275 r
.73343 .22588 m .73049 .21799 L .72187 .21266 L p F P
0 g
s
.878 .475 .26 r
.74272 .23203 m .73343 .22588 L .73049 .21799 L p F P
0 g
s
0 0 0 r
.79134 .91666 m .80249 .90895 L p .78138 .92633 L F P
0 g
s
.565 .431 .657 r
.57084 .77995 m .59115 .77231 L p .57598 .79176 L F P
0 g
s
.565 .431 .657 r
.57598 .79176 m .57308 .79179 L .57084 .77995 L p F P
0 g
s
.552 .421 .655 r
.58896 .76139 m .59115 .77231 L .57084 .77995 L p F P
0 g
s
.552 .421 .655 r
.58443 .76103 m .58896 .76139 L p .57084 .77995 L F P
0 g
s
.626 .477 .66 r
.57084 .77995 m .57308 .79179 L .57021 .79337 L p F P
0 g
s
.475 .433 .732 r
.28942 .33942 m .28993 .33887 L .28538 .32402 L p F P
0 g
s
.501 .473 .758 r
.28993 .33887 m .29014 .33947 L .28942 .33942 L closepath p F P
0 g
s
.756 .591 .673 r
.49683 .8102 m .4967 .80974 L .49644 .81015 L closepath p F P
0 g
s
.475 .738 .985 r
.31847 .94953 m .33901 .94859 L .34558 .95333 L p F P
0 g
s
.505 .745 .981 r
.33901 .94859 m .31847 .94953 L .31177 .94531 L p F P
0 g
s
.741 .584 .681 r
.506 .82523 m .50099 .82474 L .49683 .8102 L p F P
0 g
s
.756 .593 .675 r
.49644 .81015 m .49683 .8102 L .50099 .82474 L p F P
0 g
s
.722 .81 .919 r
.40425 .63312 m .38296 .64392 L .3894 .64878 L p F P
0 g
s
.722 .81 .919 r
.40991 .63766 m .40425 .63312 L p .3894 .64878 L F P
0 g
s
.722 .81 .919 r
.3894 .64878 m .41 .63854 L .40991 .63766 L p F P
0 g
s
.74 .822 .915 r
.3894 .64878 m .38296 .64392 L .3623 .65544 L p F P
0 g
s
.558 .556 .808 r
.32538 .37685 m .32858 .38362 L .31725 .38484 L closepath p F P
0 g
s
.558 .561 .813 r
.33478 .39672 m .32858 .38362 L .31725 .38484 L p F P
0 g
s
.756 .593 .675 r
.50099 .82474 m .48838 .82299 L .49644 .81015 L p F P
0 g
s
.783 .615 .672 r
.48083 .80732 m .49644 .81015 L .48838 .82299 L p F P
0 g
s
.753 .588 .672 r
.4875 .7949 m .48083 .80732 L .49644 .81015 L p F P
0 g
s
.505 .452 .731 r
.28877 .32093 m .28538 .32402 L .28993 .33887 L p F P
0 g
s
.804 .629 .664 r
.47383 .79148 m .4875 .7949 L .48083 .80732 L p F P
0 g
s
.771 .598 .664 r
.47942 .7794 m .47383 .79148 L .4875 .7949 L p F P
0 g
s
.661 .682 .859 r
.48337 .44217 m .46192 .45011 L .46796 .45918 L p F P
0 g
s
.661 .682 .859 r
.46796 .45918 m .48936 .45133 L .48337 .44217 L p F P
0 g
s
.662 .699 .874 r
.4939 .45789 m .48936 .45133 L .46796 .45918 L p F P
0 g
s
.756 .693 .791 r
.44738 .93004 m .428 .94386 L .42184 .93615 L p F P
0 g
s
.964 .781 .609 r
.22276 .82597 m .22297 .82523 L .21776 .81923 L p F P
0 g
s
.726 .582 .693 r
.50252 .83006 m .506 .82523 L p .51631 .8401 L F P
0 g
s
.741 .585 .682 r
.50252 .83006 m .506 .82523 L .50099 .82474 L closepath p F P
0 g
s
.626 .636 .841 r
.4223 .42763 m .40118 .43366 L .40734 .44408 L p F P
0 g
s
.626 .636 .841 r
.42711 .43588 m .4223 .42763 L p .40734 .44408 L F P
0 g
s
.626 .636 .841 r
.40734 .44408 m .4181 .44107 L .42711 .43588 L p F P
0 g
s
.178 .278 .729 r
.44416 .64615 m .4389 .63868 L p .45223 .64343 L F P
0 g
s
.178 .278 .729 r
.45223 .64343 m .45038 .65209 L .44416 .64615 L p F P
0 g
s
.676 .538 .69 r
.53576 .84634 m .54442 .83946 L .53416 .84034 L closepath p F P
0 g
s
.715 .583 .706 r
.53416 .84034 m .53576 .84634 L .52701 .85489 L p F P
0 g
s
.715 .583 .706 r
.51631 .8401 m .53416 .84034 L p .52701 .85489 L F P
0 g
s
.521 .485 .757 r
.28993 .33887 m .29014 .33947 L .3102 .33951 L p F P
0 g
s
.521 .483 .755 r
.31068 .34093 m .3102 .33951 L .29014 .33947 L p F P
0 g
s
.434 .849 .963 r
.47694 .15798 m .47801 .15815 L .45673 .16322 L p F P
0 g
s
.434 .849 .963 r
.45673 .16322 m .4519 .16192 L .47694 .15798 L p F P
0 g
s
.505 .452 .731 r
.28993 .33887 m .30521 .325 L p .28877 .32093 L F P
0 g
s
.521 .485 .757 r
.3102 .33951 m .30521 .325 L .28993 .33887 L p F P
0 g
s
.732 .624 .739 r
.49848 .90326 m .50103 .901 L .49741 .90071 L closepath p F P
0 g
s
.731 .625 .74 r
.4976 .88429 m .51856 .88555 L .50103 .901 L p F P
0 g
s
.731 .625 .74 r
.4926 .88941 m .4976 .88429 L p .50103 .901 L F P
0 g
s
.731 .625 .74 r
.50103 .901 m .49741 .90071 L .4926 .88941 L p F P
0 g
s
.828 .646 .657 r
.46754 .77543 m .47942 .7794 L .47383 .79148 L p F P
0 g
s
.818 .632 .651 r
.47942 .7794 m .46754 .77543 L .47229 .76362 L p F P
0 g
s
.908 .847 .771 r
.23871 .76419 m .2346 .75762 L .22593 .77048 L p F P
0 g
s
.908 .847 .771 r
.23228 .77384 m .23871 .76419 L p .22593 .77048 L F P
0 g
s
.964 .781 .609 r
.21776 .81923 m .21493 .82918 L .22276 .82597 L p F P
0 g
s
.962 .782 .612 r
.22276 .82597 m .21986 .83654 L .21453 .8306 L p F P
0 g
s
.962 .782 .612 r
.21453 .8306 m .21493 .82918 L .22276 .82597 L p F P
0 g
s
.838 .758 .775 r
.74262 .36485 m .74701 .36911 L p .75122 .34924 L F P
0 g
s
.823 .76 .793 r
.74262 .36485 m .74592 .37028 L .74701 .36911 L closepath p F P
0 g
s
.305 .774 .938 r
.53974 .15536 m .5331 .15571 L .5389 .15895 L p F P
0 g
s
.305 .774 .938 r
.55995 .15632 m .53974 .15536 L p .5389 .15895 L F P
0 g
s
.305 .774 .938 r
.5389 .15895 m .56068 .15656 L .55995 .15632 L p F P
0 g
s
.536 .648 .907 r
.68947 .65778 m .69686 .65762 L .69155 .64966 L p F P
0 g
s
.536 .648 .907 r
.69155 .64966 m .69095 .64967 L .68947 .65778 L p F P
0 g
s
.715 .583 .706 r
.50835 .84934 m .51631 .8401 L p .52701 .85489 L F P
0 g
s
.726 .582 .693 r
.50835 .84934 m .51631 .8401 L .50537 .8395 L closepath p F P
0 g
s
.726 .582 .693 r
.51631 .8401 m .50537 .8395 L .50252 .83006 L p F P
0 g
s
.82 .759 .795 r
.74592 .37028 m .73389 .38312 L p .74021 .36252 L F P
0 g
s
.82 .759 .795 r
.74021 .36252 m .74262 .36485 L .74592 .37028 L p F P
0 g
s
.69 .597 .747 r
.55332 .90085 m .55327 .90071 L .55303 .90086 L closepath p F P
0 g
s
.692 .602 .751 r
.54763 .8849 m .55327 .90071 L .55303 .90086 L p F P
0 g
s
.692 .602 .751 r
.54666 .88494 m .54763 .8849 L p .55303 .90086 L F P
0 g
s
.15 0 .388 r
.8223 .87789 m .82414 .86888 L .82241 .87046 L closepath p F P
0 g
s
.673 .588 .752 r
.57495 .88959 m .57799 .8979 L .55332 .90085 L p F P
0 g
s
.673 .588 .752 r
.55332 .90085 m .55327 .90071 L .57495 .88959 L p F P
0 g
s
.604 .609 .829 r
.38878 .41191 m .36787 .41681 L .37408 .42808 L p F P
0 g
s
.604 .609 .829 r
.39242 .41865 m .38878 .41191 L p .37408 .42808 L F P
0 g
s
.604 .609 .829 r
.37408 .42808 m .38165 .42637 L .39242 .41865 L p F P
0 g
s
.669 .57 .735 r
.57251 .88212 m .57495 .88959 L .55327 .90071 L p F P
0 g
s
.669 .57 .735 r
.55327 .90071 m .54763 .8849 L .57251 .88212 L p F P
0 g
s
.698 .593 .735 r
.54666 .88494 m .52055 .88563 L .52004 .88427 L p F P
0 g
s
.719 .604 .727 r
.52055 .88563 m .52004 .88427 L .51856 .88555 L closepath p F P
0 g
s
.911 .634 .504 r
.76087 .26248 m .75254 .25609 L .75281 .24688 L p F P
0 g
s
.899 .665 .576 r
.75254 .25609 m .76087 .26248 L .75914 .27228 L p F P
0 g
s
.71 .589 .718 r
.51198 .86967 m .4976 .88429 L .51856 .88555 L p F P
0 g
s
.71 .589 .718 r
.51503 .86984 m .51198 .86967 L p .51856 .88555 L F P
0 g
s
.71 .589 .718 r
.51856 .88555 m .52004 .88427 L .51503 .86984 L p F P
0 g
s
.739 .584 .682 r
.50099 .82474 m .48838 .82299 L p .49632 .83854 L F P
0 g
s
.739 .584 .682 r
.49632 .83854 m .50252 .83006 L .50099 .82474 L p F P
0 g
s
.698 .593 .735 r
.52004 .88427 m .53747 .86974 L p .54666 .88494 L F P
0 g
s
.705 .586 .719 r
.52004 .88427 m .53747 .86974 L .51503 .86984 L closepath p F P
0 g
s
.893 .563 .415 r
.73343 .22588 m .74272 .23203 L .744 .24061 L p F P
0 g
s
.904 .571 .405 r
.75281 .24688 m .744 .24061 L .74272 .23203 L p F P
0 g
s
.621 .716 .914 r
.65298 .95117 m .67519 .94663 L .68054 .95332 L p F P
0 g
s
.616 .675 .883 r
.67519 .94663 m .65298 .95117 L .64748 .94269 L p F P
0 g
s
.74 .629 .736 r
.49741 .90071 m .4926 .88941 L .48241 .89914 L closepath p F P
0 g
s
.325 .317 .696 r
.82625 .79377 m .82583 .79432 L .82977 .80843 L p F P
0 g
s
.365 .371 .733 r
.82583 .79432 m .82545 .79314 L .82625 .79377 L closepath p F P
0 g
s
.364 .371 .733 r
.82625 .79377 m .82545 .79314 L .82094 .7791 L p F P
0 g
s
.857 .854 .837 r
.26949 .71732 m .27064 .71615 L .2717 .71833 L closepath p F P
0 g
s
.859 .853 .835 r
.25671 .73054 m .26949 .71732 L .2717 .71833 L p F P
0 g
s
.67 .546 .704 r
.53576 .84634 m .54442 .83946 L p .56231 .85234 L F P
0 g
s
.67 .546 .704 r
.56231 .85234 m .53824 .8548 L .53576 .84634 L p F P
0 g
s
.704 .566 .695 r
.53824 .8548 m .53576 .84634 L .52701 .85489 L closepath p F P
0 g
s
.364 .371 .733 r
.82094 .7791 m .82229 .77717 L p .82625 .79377 L F P
0 g
s
.382 .408 .763 r
.82094 .7791 m .81967 .77554 L .82229 .77717 L closepath p F P
0 g
s
.962 .78 .609 r
.46045 .70311 m .45549 .69682 L .45234 .70802 L p F P
0 g
s
.962 .78 .609 r
.45234 .70802 m .45745 .71424 L .46045 .70311 L p F P
0 g
s
.064 0 .45 r
.59518 .68643 m .59771 .68265 L .59679 .67264 L p F P
0 g
s
.744 .592 .686 r
.50537 .8395 m .50252 .83006 L .49632 .83854 L closepath p F P
0 g
s
.749 .741 .845 r
.65405 .4354 m .64008 .44451 L .63089 .43887 L p F P
0 g
s
0 .427 .8 r
.2851 .935 m .29827 .93944 L .30641 .94409 L p F P
0 g
s
0 .476 .852 r
.29827 .93944 m .2851 .935 L .27825 .93081 L p F P
0 g
s
.9 .623 .508 r
.744 .24061 m .75281 .24688 L .75254 .25609 L p F P
0 g
s
.705 .586 .72 r
.52701 .85489 m .53824 .8548 L p .53747 .86974 L F P
0 g
s
.705 .586 .72 r
.51419 .86743 m .52701 .85489 L p .53747 .86974 L F P
0 g
s
.715 .583 .706 r
.51419 .86743 m .52701 .85489 L .51002 .85451 L closepath p F P
0 g
s
.715 .583 .706 r
.52701 .85489 m .51002 .85451 L .50835 .84934 L p F P
0 g
s
.381 .408 .763 r
.82229 .77717 m .81967 .77554 L .81502 .76263 L p F P
0 g
s
.853 .668 .65 r
.46204 .75913 m .47229 .76362 L .46754 .77543 L p F P
0 g
s
.846 .656 .645 r
.47229 .76362 m .46204 .75913 L .46616 .74754 L p F P
0 g
s
.91 .507 .201 r
.24601 .90022 m .24605 .90035 L .23933 .89512 L p F P
0 g
s
.91 .507 .201 r
.23933 .89512 m .23911 .8945 L .24601 .90022 L p F P
0 g
s
.928 .555 .28 r
.23668 .88521 m .23911 .8945 L .24601 .90022 L p F P
0 g
s
.932 .559 .26 r
.23911 .8945 m .23668 .88521 L .23027 .87982 L p F P
0 g
s
.67 .546 .704 r
.5416 .86631 m .56231 .85234 L .53824 .8548 L closepath p F P
0 g
s
.705 .586 .72 r
.53824 .8548 m .5416 .86631 L .53747 .86974 L p F P
0 g
s
.835 .365 .02 r
.2586 .91464 m .2515 .90957 L .24605 .90035 L p F P
0 g
s
.828 .355 0 r
.24605 .90035 m .23933 .89512 L .24476 .90434 L p F P
0 g
s
.828 .355 0 r
.24476 .90434 m .2515 .90957 L .24605 .90035 L p F P
0 g
s
.788 .754 .822 r
.7029 .4112 m .69973 .41386 L .69227 .40759 L p F P
0 g
s
.728 .583 .693 r
.50537 .8395 m .49632 .83854 L p .50433 .85406 L F P
0 g
s
.728 .583 .693 r
.50433 .85406 m .50835 .84934 L .50537 .8395 L p F P
0 g
s
.636 .074 0 r
.68761 .18907 m .69343 .19379 L .6836 .18922 L closepath p F P
0 g
s
.464 0 0 r
.68761 .18907 m .6836 .18922 L p .67302 .18287 L F P
0 g
s
.432 .283 .578 r
.31028 .25989 m .30951 .2493 L .2925 .26179 L p F P
0 g
s
.432 .283 .578 r
.2925 .26179 m .29324 .27235 L .31028 .25989 L p F P
0 g
s
.389 .251 .57 r
.29222 .27322 m .29324 .27235 L .2925 .26179 L p F P
0 g
s
.67 .546 .704 r
.54442 .83946 m .55968 .83811 L p .56231 .85234 L F P
0 g
s
.674 .535 .687 r
.55968 .83811 m .55734 .82915 L .54442 .83946 L closepath p F P
0 g
s
.676 .538 .689 r
.55619 .82421 m .55734 .82915 L .54442 .83946 L p F P
0 g
s
.727 .732 .855 r
.60495 .45369 m .62677 .44137 L p .62066 .43352 L F P
0 g
s
.727 .732 .855 r
.62066 .43352 m .59936 .44559 L .60495 .45369 L p F P
0 g
s
.717 .734 .864 r
.60495 .45369 m .59936 .44559 L .57757 .4569 L p F P
0 g
s
.255 0 .267 r
.31061 .23133 m .31726 .22713 L .32837 .21414 L p F P
0 g
s
.363 .13 .422 r
.31726 .22713 m .31061 .23133 L .3096 .23976 L p F P
0 g
s
.705 .586 .72 r
.53747 .86974 m .51503 .86984 L .51419 .86743 L p F P
0 g
s
.726 .597 .712 r
.51503 .86984 m .51419 .86743 L .51198 .86967 L closepath p F P
0 g
s
.628 .494 .68 r
.55734 .82915 m .57733 .81982 L .55619 .82421 L closepath p F P
0 g
s
.791 .755 .82 r
.7029 .4112 m .71831 .39797 L .71115 .39157 L p F P
0 g
s
.791 .755 .82 r
.71115 .39157 m .69765 .40309 L .7029 .4112 L p F P
0 g
s
.788 .754 .822 r
.69227 .40759 m .69765 .40309 L .7029 .4112 L p F P
0 g
s
.671 .707 .875 r
.4939 .45789 m .49532 .45986 L .50408 .45649 L closepath p F P
0 g
s
.741 .693 .806 r
.45078 .93062 m .44945 .9286 L .44738 .93004 L closepath p F P
0 g
s
.325 .317 .696 r
.82977 .80843 m .83436 .80249 L .82625 .79377 L p F P
0 g
s
.306 .309 .699 r
.83219 .78535 m .82625 .79377 L .83436 .80249 L p F P
0 g
s
.364 .371 .733 r
.82229 .77717 m .83219 .78535 L .82625 .79377 L p F P
0 g
s
.718 .584 .705 r
.51198 .86967 m .51419 .86743 L .51002 .85451 L p F P
0 g
s
.698 .593 .735 r
.53747 .86974 m .54268 .86962 L p .54666 .88494 L F P
0 g
s
.699 .574 .712 r
.54268 .86962 m .5416 .86631 L .53747 .86974 L closepath p F P
0 g
s
.694 .585 .729 r
.54763 .8849 m .54744 .88438 L .54666 .88494 L closepath p F P
0 g
s
.698 .593 .735 r
.54268 .86962 m .54744 .88438 L .54666 .88494 L p F P
0 g
s
.746 .661 .767 r
.47372 .91534 m .47101 .91021 L .46617 .91426 L closepath p F P
0 g
s
.718 .584 .705 r
.51002 .85451 m .50433 .85406 L p .51198 .86967 L F P
0 g
s
.735 .593 .699 r
.51002 .85451 m .50835 .84934 L .50433 .85406 L closepath p F P
0 g
s
.676 .575 .734 r
.5691 .87173 m .57251 .88212 L .54763 .8849 L p F P
0 g
s
.676 .575 .734 r
.54763 .8849 m .54744 .88438 L .5691 .87173 L p F P
0 g
s
.743 .624 .727 r
.49253 .86799 m .51198 .86967 L .4976 .88429 L p F P
0 g
s
.718 .584 .705 r
.50433 .85406 m .49253 .86799 L .51198 .86967 L p F P
0 g
s
.82 .759 .795 r
.73389 .38312 m .72694 .3766 L .74021 .36252 L p F P
0 g
s
.807 .758 .807 r
.72451 .3921 m .73389 .38312 L .72694 .3766 L p F P
0 g
s
.67 .558 .719 r
.5677 .86694 m .5691 .87173 L .54744 .88438 L p F P
0 g
s
.67 .558 .719 r
.54744 .88438 m .54268 .86962 L .5677 .86694 L p F P
0 g
s
.679 .563 .717 r
.56338 .85223 m .5677 .86694 L .54268 .86962 L p F P
0 g
s
.679 .563 .717 r
.56231 .85234 m .56338 .85223 L p .54268 .86962 L F P
0 g
s
.679 .563 .717 r
.54268 .86962 m .5416 .86631 L .56231 .85234 L p F P
0 g
s
.446 .51 .831 r
.78128 .71752 m .79798 .72256 L p .79548 .73132 L F P
0 g
s
.424 .506 .839 r
.78128 .71752 m .79798 .72256 L .79273 .7118 L p F P
0 g
s
.424 .506 .839 r
.79273 .7118 m .78475 .70928 L .78128 .71752 L p F P
0 g
s
.461 .541 .853 r
.76902 .70568 m .78475 .70928 L .78128 .71752 L p F P
0 g
s
.546 .911 .958 r
.74932 .94298 m .73529 .94864 L .7304 .94644 L p F P
0 g
s
.575 .883 .992 r
.70802 .95292 m .7304 .94644 L .73529 .94864 L p F P
0 g
s
.96 .644 .382 r
.2293 .86951 m .22323 .86395 L .22418 .87428 L p F P
0 g
s
.96 .644 .382 r
.22418 .87428 m .23027 .87982 L .2293 .86951 L p F P
0 g
s
.807 .758 .807 r
.72694 .3766 m .71933 .38385 L .72451 .3921 L p F P
0 g
s
.806 .756 .807 r
.71115 .39157 m .71933 .38385 L .72451 .3921 L p F P
0 g
s
.806 .756 .807 r
.72451 .3921 m .71831 .39797 L .71115 .39157 L p F P
0 g
s
.638 .573 .765 r
.60712 .90972 m .60843 .91305 L .58654 .9198 L p F P
0 g
s
.638 .573 .765 r
.58654 .9198 m .58443 .91455 L .60712 .90972 L p F P
0 g
s
.863 .744 .731 r
.76086 .318 m .75666 .32466 L .76181 .33437 L p F P
0 g
s
.864 .744 .729 r
.75329 .33004 m .75666 .32466 L .76181 .33437 L p F P
0 g
s
.864 .744 .729 r
.76181 .33437 m .76042 .33662 L .75329 .33004 L p F P
0 g
s
.631 .487 .668 r
.57329 .79276 m .57308 .79179 L .57021 .79337 L closepath p F P
0 g
s
.304 .224 .599 r
.59652 .69789 m .59254 .70211 L .59703 .71117 L p F P
0 g
s
.275 .184 .567 r
.59254 .70211 m .59652 .69789 L .59518 .68643 L p F P
0 g
s
.309 .743 .969 r
.56257 .1566 m .56068 .15656 L .56632 .15965 L p F P
0 g
s
.309 .743 .969 r
.56632 .15965 m .58231 .15906 L .56257 .1566 L p F P
0 g
s
.451 .54 .857 r
.78475 .70928 m .76902 .70568 L .76599 .69981 L p F P
0 g
s
.402 .85 .914 r
.42924 .16735 m .43909 .16467 L .42804 .16723 L closepath p F P
0 g
s
0 .431 .757 r
.64632 .17317 m .63278 .16971 L .62339 .16691 L p F P
0 g
s
.032 .556 .863 r
.65109 .17458 m .64632 .17317 L .63278 .16971 L p F P
0 g
s
.032 .556 .863 r
.65452 .17559 m .65109 .17458 L p .63278 .16971 L F P
0 g
s
.889 .721 .668 r
.76678 .30658 m .75935 .30001 L .76388 .28912 L p F P
0 g
s
.874 .73 .7 r
.75935 .30001 m .76678 .30658 L .76086 .318 L p F P
0 g
s
.756 .626 .716 r
.48659 .85189 m .50433 .85406 L .49253 .86799 L p F P
0 g
s
.728 .583 .693 r
.49632 .83854 m .48659 .85189 L .50433 .85406 L p F P
0 g
s
.306 .274 .658 r
.82977 .80843 m .83436 .80249 L p .83406 .82022 L F P
0 g
s
.306 .274 .658 r
.83406 .82022 m .8318 .81698 L .82977 .80843 L p F P
0 g
s
.761 .746 .839 r
.40817 .94444 m .40047 .94926 L .39418 .94281 L p F P
0 g
s
.711 .751 .884 r
.37296 .95279 m .39418 .94281 L .40047 .94926 L p F P
0 g
s
.68 .719 .878 r
.51952 .4552 m .52273 .45956 L .53237 .45563 L closepath p F P
0 g
s
.674 .73 .893 r
.52273 .45956 m .51952 .4552 L .50408 .45649 L p F P
0 g
s
.635 .511 .694 r
.55968 .83811 m .55734 .82915 L .57733 .81982 L p F P
0 g
s
.882 .694 .644 r
.45748 .74253 m .46616 .74754 L .46204 .75913 L p F P
0 g
s
.878 .685 .639 r
.46616 .74754 m .45748 .74253 L .46114 .7311 L p F P
0 g
s
.756 .693 .791 r
.42184 .93615 m .43323 .92704 L .44738 .93004 L p F P
0 g
s
.738 .688 .802 r
.44339 .91913 m .43323 .92704 L .44738 .93004 L p F P
0 g
s
.738 .688 .802 r
.44738 .93004 m .44945 .9286 L .44339 .91913 L p F P
0 g
s
.757 .833 .91 r
.36173 .65578 m .3623 .65544 L .3624 .65624 L closepath p F P
0 g
s
.246 .158 .554 r
.83523 .83387 m .83058 .83871 L .83308 .84907 L p F P
0 g
s
.297 .233 .615 r
.83058 .83871 m .83523 .83387 L .8329 .82161 L p F P
0 g
s
.381 .408 .763 r
.81502 .76263 m .81592 .76119 L p .82229 .77717 L F P
0 g
s
.4 .443 .789 r
.81502 .76263 m .81409 .76029 L .81592 .76119 L closepath p F P
0 g
s
.63 .632 .834 r
.61983 .93754 m .64191 .93279 L p .64534 .94317 L F P
0 g
s
.622 .603 .811 r
.63626 .9215 m .64191 .93279 L .61983 .93754 L p F P
0 g
s
.622 .603 .811 r
.63545 .92167 m .63626 .9215 L p .61983 .93754 L F P
0 g
s
.622 .603 .811 r
.61983 .93754 m .61497 .92771 L .63545 .92167 L p F P
0 g
s
.743 .624 .727 r
.4926 .88941 m .4976 .88429 L .4902 .88347 L closepath p F P
0 g
s
.743 .624 .727 r
.48672 .87487 m .49253 .86799 L p .4976 .88429 L F P
0 g
s
.743 .624 .727 r
.4976 .88429 m .4902 .88347 L .48672 .87487 L p F P
0 g
s
.713 .721 .857 r
.59372 .4372 m .57188 .44867 L .57757 .4569 L p F P
0 g
s
.713 .721 .857 r
.57757 .4569 m .59936 .44559 L .59372 .4372 L p F P
0 g
s
.691 .733 .883 r
.55341 .45726 m .57188 .44867 L .57757 .4569 L p F P
0 g
s
.848 .748 .753 r
.75329 .33004 m .76042 .33662 L .75122 .34924 L p F P
0 g
s
.762 .667 .757 r
.46617 .91426 m .44945 .9286 L .44339 .91913 L p F P
0 g
s
.662 .121 0 r
.27441 .92808 m .26698 .92315 L .2586 .91464 L p F P
0 g
s
.638 .1 0 r
.2515 .90957 m .2586 .91464 L .26698 .92315 L p F P
0 g
s
.13 .079 .527 r
.59771 .68265 m .59518 .68643 L .59652 .69789 L p F P
0 g
s
.566 .444 .673 r
.57329 .79276 m .57308 .79179 L .57598 .79176 L closepath p F P
0 g
s
.772 .631 .705 r
.48032 .83586 m .49632 .83854 L .48659 .85189 L p F P
0 g
s
.739 .584 .682 r
.48838 .82299 m .48032 .83586 L .49632 .83854 L p F P
0 g
s
.694 .725 .874 r
.54834 .45622 m .55015 .45872 L .55341 .45726 L closepath p F P
0 g
s
.683 .742 .895 r
.55015 .45872 m .54834 .45622 L .53237 .45563 L p F P
0 g
s
.587 .723 .937 r
.64073 .63899 m .63602 .63976 L .63057 .63329 L p F P
0 g
s
.641 .576 .766 r
.60264 .89839 m .60712 .90972 L .58443 .91455 L p F P
0 g
s
.641 .576 .766 r
.58443 .91455 m .58077 .90555 L .60264 .89839 L p F P
0 g
s
.066 0 .347 r
.82414 .86888 m .83323 .8601 L p .82224 .88006 L F P
0 g
s
.066 0 .347 r
.82224 .88006 m .8223 .87789 L .82414 .86888 L p F P
0 g
s
.201 .077 .478 r
.82414 .86888 m .83323 .8601 L .83308 .84907 L p F P
0 g
s
.735 .62 .731 r
.48241 .89914 m .4926 .88941 L .4902 .88347 L p F P
0 g
s
.611 .79 .967 r
.68054 .95332 m .70287 .94829 L .70802 .95292 L p F P
0 g
s
.611 .737 .935 r
.70287 .94829 m .68054 .95332 L .67519 .94663 L p F P
0 g
s
.644 .767 .938 r
.34558 .95333 m .36653 .94731 L .37296 .95279 L p F P
0 g
s
.66 .769 .93 r
.36653 .94731 m .34558 .95333 L .33901 .94859 L p F P
0 g
s
.572 .565 .807 r
.33478 .39672 m .33576 .39658 L .33501 .39722 L closepath p F P
0 g
s
.908 .847 .771 r
.22593 .77048 m .22725 .77253 L .23228 .77384 L p F P
0 g
s
.91 .844 .766 r
.22725 .77253 m .23228 .77384 L .23018 .77697 L closepath p F P
0 g
s
.567 .447 .676 r
.57621 .80607 m .57329 .79276 L .57598 .79176 L p F P
0 g
s
.781 .297 .074 r
.69343 .19379 m .70462 .19937 L .70987 .20629 L p F P
0 g
s
.78 .288 .042 r
.72068 .21198 m .70987 .20629 L .70462 .19937 L p F P
0 g
s
.397 .443 .792 r
.81592 .76119 m .81409 .76029 L .80865 .74668 L p F P
0 g
s
.572 .56 .802 r
.34919 .38033 m .32858 .38362 L .33478 .39672 L p F P
0 g
s
.572 .56 .802 r
.35091 .38405 m .34919 .38033 L p .33478 .39672 L F P
0 g
s
.572 .56 .802 r
.33478 .39672 m .33576 .39658 L .35091 .38405 L p F P
0 g
s
.996 .788 .503 r
.457 .68617 m .45324 .67944 L .45162 .69014 L p F P
0 g
s
.996 .788 .503 r
.45552 .69667 m .457 .68617 L p .45162 .69014 L F P
0 g
s
.434 .33 .638 r
.58861 .75943 m .58648 .74701 L .59718 .73953 L p F P
0 g
s
.43 .323 .632 r
.58648 .74701 m .59718 .73953 L .58935 .7313 L p F P
0 g
s
.552 .406 .637 r
.58648 .74701 m .58861 .75943 L .58443 .76103 L p F P
0 g
s
.762 .645 .732 r
.48241 .89914 m .47101 .91021 L .46504 .89853 L p F P
0 g
s
.762 .645 .732 r
.46504 .89853 m .46694 .89643 L .48241 .89914 L p F P
0 g
s
.735 .62 .731 r
.47998 .88214 m .46694 .89643 L .48241 .89914 L p F P
0 g
s
.735 .62 .731 r
.4902 .88347 m .47998 .88214 L p .48241 .89914 L F P
0 g
s
.672 .699 .867 r
.48936 .45133 m .4939 .45789 L .50408 .45649 L p F P
0 g
s
.488 .418 .704 r
.28877 .32093 m .30081 .31025 L p .29282 .30053 L F P
0 g
s
.507 .45 .727 r
.30081 .31025 m .30427 .32181 L .28877 .32093 L closepath p F P
0 g
s
.505 .452 .731 r
.30521 .325 m .30427 .32181 L .28877 .32093 L p F P
0 g
s
.79 .639 .695 r
.47408 .8198 m .48838 .82299 L .48032 .83586 L p F P
0 g
s
.783 .615 .672 r
.48838 .82299 m .47408 .8198 L .48083 .80732 L p F P
0 g
s
.762 .667 .757 r
.44339 .91913 m .45141 .91139 L .46617 .91426 L p F P
0 g
s
.742 .655 .763 r
.46504 .89853 m .45141 .91139 L .46617 .91426 L p F P
0 g
s
.742 .655 .763 r
.46617 .91426 m .47101 .91021 L .46504 .89853 L p F P
0 g
s
.758 .842 .915 r
.3621 .64731 m .35513 .6515 L .36173 .65578 L p F P
0 g
s
.758 .842 .915 r
.36173 .65578 m .3623 .65544 L .3621 .64731 L p F P
0 g
s
.631 .509 .695 r
.56323 .85172 m .55968 .83811 L .58269 .83338 L p F P
0 g
s
.635 .511 .694 r
.57918 .81945 m .58269 .83338 L .55968 .83811 L p F P
0 g
s
.635 .511 .694 r
.57733 .81982 m .57918 .81945 L p .55968 .83811 L F P
0 g
s
.67 .546 .704 r
.55968 .83811 m .56323 .85172 L .56231 .85234 L p F P
0 g
s
.13 0 .081 r
.33113 .21178 m .32837 .21414 L .33072 .21268 L closepath p F P
0 g
s
.271 0 .281 r
.33072 .21268 m .32837 .21414 L .31726 .22713 L p F P
0 g
s
.971 .707 .474 r
.22372 .85328 m .21802 .84754 L .2175 .85823 L p F P
0 g
s
.971 .707 .474 r
.2175 .85823 m .22323 .86395 L .22372 .85328 L p F P
0 g
s
.745 .831 .917 r
.38296 .64392 m .3623 .65544 L .3621 .64731 L p F P
0 g
s
.327 .354 .736 r
.82759 .76882 m .82229 .77717 L .83219 .78535 L p F P
0 g
s
.381 .408 .763 r
.81592 .76119 m .82759 .76882 L .82229 .77717 L p F P
0 g
s
.723 .75 .873 r
.39418 .94281 m .37296 .95279 L .36653 .94731 L p F P
0 g
s
.755 .743 .841 r
.65405 .4354 m .66927 .42501 L .66064 .41912 L p F P
0 g
s
.755 .743 .841 r
.66064 .41912 m .64863 .4273 L .65405 .4354 L p F P
0 g
s
.749 .741 .845 r
.63089 .43887 m .64863 .4273 L .65405 .4354 L p F P
0 g
s
.956 .811 .659 r
.22223 .80756 m .21741 .80136 L .21291 .81307 L p F P
0 g
s
.956 .811 .659 r
.21291 .81307 m .21776 .81923 L .22223 .80756 L p F P
0 g
s
.603 .829 .986 r
.7304 .94644 m .70802 .95292 L .70287 .94829 L p F P
0 g
s
.213 0 .12 r
.35012 .20241 m .35235 .19771 L .33113 .21178 L p F P
0 g
s
.213 0 .12 r
.33113 .21178 m .33072 .21268 L .35012 .20241 L p F P
0 g
s
.646 .663 .853 r
.44976 .43091 m .42844 .43804 L .43457 .44772 L p F P
0 g
s
.646 .663 .853 r
.43457 .44772 m .45586 .44066 L .44976 .43091 L p F P
0 g
s
.632 .658 .857 r
.43457 .44772 m .42844 .43804 L .4181 .44107 L p F P
0 g
s
.841 .865 .861 r
.28711 .70097 m .27064 .71615 L .26776 .70902 L p F P
0 g
s
.841 .865 .861 r
.28475 .69437 m .28711 .70097 L p .26776 .70902 L F P
0 g
s
.822 .855 .872 r
.28475 .69437 m .29107 .69766 L .28711 .70097 L closepath p F P
0 g
s
.584 .583 .817 r
.35091 .38405 m .35541 .39303 L .33576 .39658 L closepath p F P
0 g
s
.584 .588 .822 r
.36163 .40536 m .35541 .39303 L .33576 .39658 L p F P
0 g
s
.861 .866 .841 r
.26949 .71732 m .27064 .71615 L .26776 .70902 L p F P
0 g
s
.761 .746 .839 r
.39418 .94281 m .3974 .94057 L .40817 .94444 L p F P
0 g
s
.736 .721 .838 r
.41565 .92832 m .3974 .94057 L .40817 .94444 L p F P
0 g
s
.736 .721 .838 r
.40817 .94444 m .42184 .93615 L .41565 .92832 L p F P
0 g
s
.426 .486 .818 r
.8033 .73436 m .79548 .73132 L p .80705 .74589 L F P
0 g
s
.41 .479 .82 r
.8033 .73436 m .79548 .73132 L .79887 .72442 L closepath p F P
0 g
s
.446 .51 .831 r
.79798 .72256 m .79887 .72442 L .79548 .73132 L p F P
0 g
s
.931 .845 .736 r
.23018 .77697 m .22315 .78934 L .21878 .78291 L p F P
0 g
s
.931 .845 .736 r
.22725 .77253 m .23018 .77697 L p .21878 .78291 L F P
0 g
s
.861 .866 .841 r
.26776 .70902 m .26239 .71445 L .26949 .71732 L p F P
0 g
s
.861 .864 .841 r
.26949 .71732 m .25671 .73054 L .25347 .72357 L p F P
0 g
s
.861 .864 .841 r
.25347 .72357 m .26239 .71445 L .26949 .71732 L p F P
0 g
s
.406 .32 .646 r
.60046 .72226 m .58935 .7313 L .59718 .73953 L p F P
0 g
s
.444 .318 .614 r
.59909 .71452 m .60046 .72226 L .58935 .7313 L p F P
0 g
s
.444 .318 .614 r
.59703 .71117 m .59909 .71452 L p .58935 .7313 L F P
0 g
s
.073 0 0 r
.39516 .17934 m .39932 .17535 L .37776 .18334 L p F P
0 g
s
.073 0 0 r
.37776 .18334 m .37349 .18734 L .39516 .17934 L p F P
0 g
s
.749 .627 .724 r
.4902 .88347 m .48672 .87487 L .47998 .88214 L closepath p F P
0 g
s
.816 .856 .878 r
.29107 .69766 m .30675 .6848 L p .28454 .6937 L F P
0 g
s
.816 .856 .878 r
.28454 .6937 m .28475 .69437 L .29107 .69766 L p F P
0 g
s
.309 0 0 r
.65452 .17559 m .66013 .17786 L .65109 .17458 L closepath p F P
0 g
s
.7 .72 .865 r
.55341 .45726 m .57188 .44867 L p .54437 .45059 L F P
0 g
s
.7 .72 .865 r
.54437 .45059 m .54834 .45622 L .55341 .45726 L p F P
0 g
s
.811 .652 .685 r
.46813 .80365 m .48083 .80732 L .47408 .8198 L p F P
0 g
s
.804 .629 .664 r
.48083 .80732 m .46813 .80365 L .47383 .79148 L p F P
0 g
s
.787 .844 .895 r
.61986 .63749 m .60865 .64308 L .60318 .64052 L p F P
0 g
s
.93 .882 .765 r
.60222 .65304 m .60865 .64308 L .60318 .64052 L p F P
0 g
s
.915 .73 .638 r
.4541 .72554 m .46114 .7311 L .45748 .74253 L p F P
0 g
s
.915 .724 .63 r
.46114 .7311 m .4541 .72554 L .45745 .71424 L p F P
0 g
s
.756 .626 .716 r
.48672 .87487 m .49253 .86799 L .4835 .86664 L closepath p F P
0 g
s
.756 .626 .716 r
.48082 .85979 m .48659 .85189 L p .49253 .86799 L F P
0 g
s
.756 .626 .716 r
.49253 .86799 m .4835 .86664 L .48082 .85979 L p F P
0 g
s
.304 .274 .659 r
.8329 .82161 m .8318 .81698 L .83406 .82022 L closepath p F P
0 g
s
.173 .599 .939 r
.30641 .94409 m .31177 .94531 L .30503 .94084 L p F P
0 g
s
.173 .599 .939 r
.30503 .94084 m .29827 .93944 L .30641 .94409 L p F P
0 g
s
.563 0 0 r
.66013 .17786 m .67302 .18287 L .68158 .18841 L p F P
0 g
s
.464 0 0 r
.6836 .18922 m .68158 .18841 L .67302 .18287 L p F P
0 g
s
.567 .447 .676 r
.57598 .79176 m .59506 .79143 L p .57621 .80607 L F P
0 g
s
.567 .44 .667 r
.59506 .79143 m .57598 .79176 L .5938 .78533 L closepath p F P
0 g
s
.565 .431 .657 r
.59115 .77231 m .5938 .78533 L .57598 .79176 L p F P
0 g
s
.612 .627 .841 r
.39242 .41865 m .39498 .42308 L .38165 .42637 L closepath p F P
0 g
s
.613 .632 .846 r
.40118 .43366 m .39498 .42308 L .38165 .42637 L p F P
0 g
s
.636 .555 .746 r
.60078 .89309 m .60264 .89839 L .58077 .90555 L p F P
0 g
s
.636 .555 .746 r
.58077 .90555 m .57799 .8979 L .60078 .89309 L p F P
0 g
s
.52 .633 .902 r
.69686 .65762 m .71969 .65803 L p .72217 .66607 L F P
0 g
s
.509 .639 .912 r
.71969 .65803 m .69686 .65762 L .69155 .64966 L p F P
0 g
s
.347 .395 .769 r
.82061 .7529 m .81592 .76119 L .82759 .76882 L p F P
0 g
s
.397 .443 .792 r
.80865 .74668 m .82061 .7529 L .81592 .76119 L p F P
0 g
s
.895 .697 .627 r
.76388 .28912 m .75599 .28264 L .75914 .27228 L p F P
0 g
s
.88 .71 .667 r
.75599 .28264 m .76388 .28912 L .75935 .30001 L p F P
0 g
s
.393 .443 .794 r
.80865 .74668 m .80705 .74589 L .8078 .74458 L closepath p F P
0 g
s
.426 .486 .818 r
.80705 .74589 m .8078 .74458 L .8033 .73436 L p F P
0 g
s
.153 .691 .708 r
.45041 .16186 m .43909 .16467 L .42804 .16723 L p F P
0 g
s
.153 .691 .708 r
.44595 .1631 m .45041 .16186 L p .42804 .16723 L F P
0 g
s
.337 .817 .872 r
.43909 .16467 m .4519 .16192 L .45041 .16186 L closepath p F P
0 g
s
.153 .691 .708 r
.42799 .16713 m .44595 .1631 L p .42804 .16723 L F P
0 g
s
.153 .691 .708 r
.42804 .16723 m .42266 .16822 L .42799 .16713 L p F P
0 g
s
.672 .699 .867 r
.50408 .45649 m .51685 .45146 L p .48936 .45133 L F P
0 g
s
.674 .71 .875 r
.51685 .45146 m .50408 .45649 L .51952 .4552 L closepath p F P
0 g
s
.554 .417 .649 r
.58896 .76139 m .58443 .76103 L .58861 .75943 L closepath p F P
0 g
s
.837 .66 .663 r
.46264 .78733 m .47383 .79148 L .46813 .80365 L p F P
0 g
s
.828 .646 .657 r
.47383 .79148 m .46264 .78733 L .46754 .77543 L p F P
0 g
s
.876 .862 .823 r
.25671 .73054 m .25347 .72357 L .24124 .73749 L p F P
0 g
s
.876 .862 .823 r
.24756 .74109 m .25671 .73054 L p .24124 .73749 L F P
0 g
s
.671 .546 .704 r
.56338 .85223 m .56323 .85172 L .56231 .85234 L closepath p F P
0 g
s
.497 .6 .887 r
.73019 .67489 m .74796 .67653 L .74588 .6846 L p F P
0 g
s
.489 .603 .892 r
.74796 .67653 m .73019 .67489 L .72494 .66625 L p F P
0 g
s
.816 .856 .878 r
.30675 .6848 m .30471 .67731 L .28454 .6937 L p F P
0 g
s
.8 .852 .889 r
.31249 .68051 m .30675 .6848 L .30471 .67731 L p F P
0 g
s
.192 .673 .93 r
.59383 .16174 m .60052 .1621 L .59071 .16015 L closepath p F P
0 g
s
.335 .039 .305 r
.3483 .20967 m .35012 .20241 L .33072 .21268 L p F P
0 g
s
.335 .039 .305 r
.33072 .21268 m .32883 .21995 L .3483 .20967 L p F P
0 g
s
.271 0 .281 r
.31726 .22713 m .32883 .21995 L .33072 .21268 L p F P
0 g
s
.876 .479 .275 r
.72363 .21986 m .73343 .22588 L p .72187 .21266 L F P
0 g
s
.876 .479 .275 r
.72187 .21266 m .72143 .21374 L .72363 .21986 L p F P
0 g
s
.854 .447 .265 r
.72068 .21198 m .72187 .21266 L .72143 .21374 L closepath p F P
0 g
s
.632 .652 .852 r
.42711 .43588 m .42844 .43804 L .4181 .44107 L closepath p F P
0 g
s
.636 .526 .711 r
.56338 .85223 m .56323 .85172 L .58502 .84261 L p F P
0 g
s
.631 .509 .695 r
.58269 .83338 m .58502 .84261 L .56323 .85172 L p F P
0 g
s
.635 .525 .712 r
.5677 .86694 m .56338 .85223 L .58642 .84755 L p F P
0 g
s
.636 .526 .711 r
.58502 .84261 m .58642 .84755 L .56338 .85223 L p F P
0 g
s
0 .431 .757 r
.63114 .16897 m .64632 .17317 L p .62339 .16691 L F P
0 g
s
0 .431 .757 r
.62339 .16691 m .62149 .16605 L .63114 .16897 L p F P
0 g
s
.099 .618 .884 r
.61742 .16562 m .62339 .16691 L .62149 .16605 L closepath p F P
0 g
s
.639 .558 .747 r
.59681 .88193 m .60078 .89309 L .57799 .8979 L p F P
0 g
s
.639 .558 .747 r
.57799 .8979 m .57495 .88959 L .59681 .88193 L p F P
0 g
s
.587 .723 .937 r
.63057 .63329 m .63837 .63186 L .64073 .63899 L p F P
0 g
s
.589 .719 .933 r
.64073 .63899 m .65829 .63645 L .65287 .62942 L p F P
0 g
s
.589 .719 .933 r
.65287 .62942 m .63837 .63186 L .64073 .63899 L p F P
0 g
s
.838 .758 .775 r
.75122 .34924 m .74081 .36179 L .74262 .36485 L p F P
0 g
s
.837 .757 .775 r
.74081 .36179 m .74021 .36252 L .74262 .36485 L closepath p F P
0 g
s
.683 .714 .872 r
.54437 .45059 m .53237 .45563 L .54834 .45622 L closepath p F P
0 g
s
.466 .574 .879 r
.74588 .6846 m .75859 .6865 L .75337 .67737 L p F P
0 g
s
.466 .574 .879 r
.75337 .67737 m .74796 .67653 L .74588 .6846 L p F P
0 g
s
.745 .621 .721 r
.47998 .88214 m .48672 .87487 L .4835 .86664 L p F P
0 g
s
.451 .54 .857 r
.76599 .69981 m .76721 .69637 L p .78475 .70928 L F P
0 g
s
.471 .567 .871 r
.76599 .69981 m .7638 .69581 L .76721 .69637 L closepath p F P
0 g
s
.254 .204 .606 r
.83406 .82022 m .8329 .82161 L .83523 .83387 L p F P
0 g
s
.436 .325 .629 r
.29324 .27235 m .29345 .27382 L .29222 .27322 L closepath p F P
0 g
s
.43 .321 .628 r
.29487 .28396 m .29345 .27382 L .29222 .27322 L p F P
0 g
s
.608 .612 .83 r
.36787 .41681 m .38878 .41191 L p .36384 .40488 L F P
0 g
s
.608 .612 .83 r
.36384 .40488 m .36203 .40615 L .36787 .41681 L p F P
0 g
s
.178 .278 .729 r
.4389 .63868 m .43865 .63764 L .45223 .64343 L p F P
0 g
s
.5 .652 .927 r
.43865 .63764 m .4389 .63868 L .43805 .63764 L closepath p F P
0 g
s
.848 .748 .753 r
.75122 .34924 m .74399 .34271 L .75329 .33004 L p F P
0 g
s
.831 .748 .772 r
.74081 .36179 m .75122 .34924 L .74399 .34271 L p F P
0 g
s
.429 0 0 r
.27441 .92808 m .27825 .93081 L .27137 .92622 L p F P
0 g
s
.429 0 0 r
.27137 .92622 m .26698 .92315 L .27441 .92808 L p F P
0 g
s
.912 .731 .234 r
.4538 .66912 m .45239 .66157 L .4518 .67192 L p F P
0 g
s
.912 .731 .234 r
.4518 .67192 m .45324 .67944 L .4538 .66912 L p F P
0 g
s
.626 .635 .839 r
.41613 .41692 m .39498 .42308 L .40118 .43366 L p F P
0 g
s
.626 .635 .839 r
.40118 .43366 m .4223 .42763 L .41613 .41692 L p F P
0 g
s
.772 .631 .705 r
.48082 .85979 m .48659 .85189 L .47707 .85002 L closepath p F P
0 g
s
.772 .631 .705 r
.47492 .84441 m .48032 .83586 L p .48659 .85189 L F P
0 g
s
.772 .631 .705 r
.48659 .85189 m .47707 .85002 L .47492 .84441 L p F P
0 g
s
.798 .858 .894 r
.32707 .66117 m .30564 .67662 L .31249 .68051 L p F P
0 g
s
.798 .858 .894 r
.32991 .66275 m .32707 .66117 L p .31249 .68051 L F P
0 g
s
.798 .858 .894 r
.31249 .68051 m .33068 .66727 L .32991 .66275 L p F P
0 g
s
.8 .852 .889 r
.30471 .67731 m .30564 .67662 L .31249 .68051 L p F P
0 g
s
.713 .803 .921 r
.40991 .63766 m .41061 .63825 L .41 .63854 L closepath p F P
0 g
s
.845 .444 .282 r
.70987 .20629 m .72068 .21198 L .72143 .21374 L p F P
0 g
s
.576 .454 .676 r
.57621 .80607 m .59675 .79869 L p .58081 .81887 L F P
0 g
s
.576 .454 .676 r
.58081 .81887 m .57907 .819 L .57621 .80607 L p F P
0 g
s
.567 .447 .676 r
.59506 .79143 m .59675 .79869 L .57621 .80607 L p F P
0 g
s
.627 .492 .678 r
.57621 .80607 m .57907 .819 L .57733 .81982 L p F P
0 g
s
.973 .754 .547 r
.21986 .83654 m .21453 .8306 L .21265 .84164 L p F P
0 g
s
.973 .754 .547 r
.21265 .84164 m .21802 .84754 L .21986 .83654 L p F P
0 g
s
.63 .634 .836 r
.64748 .94269 m .64534 .94317 L .64743 .94259 L closepath p F P
0 g
s
.63 .632 .834 r
.64191 .93279 m .64743 .94259 L .64534 .94317 L p F P
0 g
s
.37 .137 .425 r
.32883 .21995 m .31726 .22713 L .31409 .23694 L p F P
0 g
s
.363 .13 .422 r
.3096 .23976 m .31409 .23694 L .31726 .22713 L p F P
0 g
s
.684 .713 .871 r
.53237 .45563 m .54437 .45059 L p .51685 .45146 L F P
0 g
s
.684 .713 .871 r
.51685 .45146 m .51952 .4552 L .53237 .45563 L p F P
0 g
s
.631 .522 .712 r
.5691 .87173 m .5677 .86694 L .59055 .86211 L p F P
0 g
s
.635 .525 .712 r
.58642 .84755 m .59055 .86211 L .5677 .86694 L p F P
0 g
s
.634 .538 .729 r
.59535 .8773 m .59681 .88193 L .57495 .88959 L p F P
0 g
s
.634 .538 .729 r
.57495 .88959 m .57251 .88212 L .59535 .8773 L p F P
0 g
s
.682 .797 .935 r
.41061 .63825 m .43186 .63069 L p .41414 .62901 L F P
0 g
s
.682 .797 .935 r
.41414 .62901 m .40991 .63766 L .41061 .63825 L p F P
0 g
s
.773 .664 .743 r
.46496 .87927 m .47998 .88214 L .46694 .89643 L p F P
0 g
s
.745 .621 .721 r
.47616 .86546 m .46496 .87927 L .47998 .88214 L p F P
0 g
s
.745 .621 .721 r
.4835 .86664 m .47616 .86546 L p .47998 .88214 L F P
0 g
s
.214 0 .045 r
.37345 .18741 m .37349 .18734 L .35303 .19653 L p F P
0 g
s
.214 0 .045 r
.35303 .19653 m .35235 .19771 L .37345 .18741 L p F P
0 g
s
.638 .541 .729 r
.59094 .86345 m .59535 .8773 L .57251 .88212 L p F P
0 g
s
.638 .541 .729 r
.57251 .88212 m .5691 .87173 L .59094 .86345 L p F P
0 g
s
.767 .743 .831 r
.67587 .42013 m .66927 .42501 L .66064 .41912 L p F P
0 g
s
.86 .679 .656 r
.45774 .77082 m .46754 .77543 L .46264 .78733 L p F P
0 g
s
.853 .668 .65 r
.46754 .77543 m .45774 .77082 L .46204 .75913 L p F P
0 g
s
.382 .436 .793 r
.82061 .7529 m .80865 .74668 L .8078 .74458 L p F P
0 g
s
.546 .911 .958 r
.75603 .93931 m .74932 .94298 L p .7304 .94644 L F P
0 g
s
.565 .931 .927 r
.74932 .94298 m .75603 .93931 L .75757 .93946 L closepath p F P
0 g
s
.631 .522 .712 r
.59055 .86211 m .59094 .86345 L .5691 .87173 L p F P
0 g
s
.622 .606 .813 r
.61497 .92771 m .61416 .92607 L .63545 .92167 L closepath p F P
0 g
s
.466 .346 .632 r
.31188 .27147 m .31028 .25989 L .29324 .27235 L p F P
0 g
s
.466 .346 .632 r
.30398 .27722 m .31188 .27147 L p .29324 .27235 L F P
0 g
s
.466 .346 .632 r
.29324 .27235 m .29345 .27382 L .30398 .27722 L p F P
0 g
s
.76 .628 .714 r
.4835 .86664 m .48082 .85979 L .47616 .86546 L closepath p F P
0 g
s
.956 .78 .624 r
.45745 .71424 m .45234 .70802 L .44885 .71938 L p F P
0 g
s
.956 .78 .624 r
.44885 .71938 m .4541 .72554 L .45745 .71424 L p F P
0 g
s
.876 .862 .823 r
.24124 .73749 m .24204 .73913 L .24756 .74109 L p F P
0 g
s
.879 .859 .817 r
.24204 .73913 m .24756 .74109 L .24473 .74436 L closepath p F P
0 g
s
.088 .613 .875 r
.60052 .1621 m .61742 .16562 L .62149 .16605 L p F P
0 g
s
.775 .71 .79 r
.43323 .92704 m .42184 .93615 L .41565 .92832 L p F P
0 g
s
.874 .73 .7 r
.76086 .318 m .75334 .31147 L .75935 .30001 L p F P
0 g
s
.855 .735 .73 r
.75666 .32466 m .76086 .318 L .75334 .31147 L p F P
0 g
s
.899 .665 .576 r
.75914 .27228 m .75078 .2659 L .75254 .25609 L p F P
0 g
s
.886 .686 .627 r
.75078 .2659 m .75914 .27228 L .75599 .28264 L p F P
0 g
s
.66 .675 .853 r
.47734 .43265 m .45586 .44066 L .46192 .45011 L p F P
0 g
s
.66 .675 .853 r
.46192 .45011 m .48337 .44217 L .47734 .43265 L p F P
0 g
s
.549 .671 .919 r
.66368 .64367 m .68623 .64216 L p .69095 .64967 L F P
0 g
s
.547 .678 .924 r
.68623 .64216 m .66368 .64367 L .65829 .63645 L p F P
0 g
s
.586 .709 .928 r
.43805 .63764 m .43865 .63764 L .43835 .62956 L p F P
0 g
s
.586 .709 .928 r
.43835 .62956 m .43186 .63069 L .43805 .63764 L p F P
0 g
s
0 0 0 r
.42201 .16854 m .42266 .16822 L .40157 .17439 L p F P
0 g
s
.382 .436 .793 r
.8078 .74458 m .81125 .73763 L p .82061 .7529 L F P
0 g
s
.404 .472 .817 r
.8078 .74458 m .8033 .73436 L .81125 .73763 L closepath p F P
0 g
s
.616 .675 .883 r
.64748 .94269 m .66975 .93861 L .67519 .94663 L p F P
0 g
s
.615 .627 .839 r
.66796 .93554 m .66975 .93861 L .64748 .94269 L p F P
0 g
s
.615 .627 .839 r
.64748 .94269 m .64743 .94259 L .66796 .93554 L p F P
0 g
s
.93 .882 .765 r
.60318 .64052 m .60092 .64559 L .60222 .65304 L p F P
0 g
s
.61 .627 .843 r
.66423 .92925 m .66796 .93554 L .64743 .94259 L p F P
0 g
s
.61 .627 .843 r
.64743 .94259 m .64191 .93279 L .66423 .92925 L p F P
0 g
s
.738 .736 .849 r
.6218 .43404 m .62677 .44137 L .63089 .43887 L closepath p F P
0 g
s
.727 .732 .855 r
.62677 .44137 m .6218 .43404 L .62066 .43352 L p F P
0 g
s
.619 .58 .788 r
.63545 .92167 m .61416 .92607 L .60843 .91305 L p F P
0 g
s
.79 .64 .696 r
.47492 .84441 m .48032 .83586 L .47067 .83342 L closepath p F P
0 g
s
.79 .639 .695 r
.46901 .82907 m .47408 .8198 L p .48032 .83586 L F P
0 g
s
.79 .639 .695 r
.48032 .83586 m .47067 .83342 L .46901 .82907 L p F P
0 g
s
.771 .745 .829 r
.67587 .42013 m .69227 .40759 L .68411 .4015 L p F P
0 g
s
.771 .745 .829 r
.68411 .4015 m .6705 .41184 L .67587 .42013 L p F P
0 g
s
.767 .743 .831 r
.66064 .41912 m .6705 .41184 L .67587 .42013 L p F P
0 g
s
.466 .344 .63 r
.29345 .27382 m .30398 .27722 L .29487 .28396 L closepath p F P
0 g
s
.579 .567 .805 r
.32858 .38362 m .34919 .38033 L p .33635 .36802 L F P
0 g
s
.579 .567 .805 r
.33635 .36802 m .32538 .37685 L .32858 .38362 L p F P
0 g
s
.69 .807 .937 r
.40425 .63312 m .41414 .62901 L .40991 .63766 L closepath p F P
0 g
s
.9 .866 .797 r
.24473 .74436 m .2346 .75762 L .23093 .75085 L p F P
0 g
s
.9 .866 .797 r
.24204 .73913 m .24473 .74436 L p .23093 .75085 L F P
0 g
s
.402 .431 .775 r
.43865 .63764 m .43835 .62956 L p .45573 .63779 L F P
0 g
s
.402 .431 .775 r
.45573 .63779 m .45223 .64343 L .43865 .63764 L p F P
0 g
s
.686 .766 .912 r
.62508 .62696 m .6183 .63007 L .61986 .63749 L p F P
0 g
s
.686 .766 .912 r
.61986 .63749 m .63057 .63329 L .62508 .62696 L p F P
0 g
s
.787 .844 .895 r
.60318 .64052 m .6183 .63007 L .61986 .63749 L p F P
0 g
s
.482 .368 .647 r
.58861 .75943 m .6054 .74784 L p .5987 .76758 L F P
0 g
s
.482 .368 .647 r
.5987 .76758 m .58896 .76139 L .58861 .75943 L p F P
0 g
s
.434 .33 .638 r
.60532 .74746 m .6054 .74784 L .58861 .75943 L p F P
0 g
s
.434 .33 .638 r
.59718 .73953 m .60532 .74746 L p .58861 .75943 L F P
0 g
s
.174 0 .38 r
.82158 .8806 m .82224 .88006 L .8223 .87789 L closepath p F P
0 g
s
.883 .555 .424 r
.72363 .21986 m .73343 .22588 L .73468 .23447 L p F P
0 g
s
.893 .563 .415 r
.744 .24061 m .73468 .23447 L .73343 .22588 L p F P
0 g
s
.775 .71 .79 r
.41565 .92832 m .42112 .92347 L .43323 .92704 L p F P
0 g
s
.752 .691 .793 r
.43731 .90954 m .42112 .92347 L .43323 .92704 L p F P
0 g
s
.752 .691 .793 r
.43323 .92704 m .44339 .91913 L .43731 .90954 L p F P
0 g
s
.758 .625 .712 r
.47616 .86546 m .48082 .85979 L .47707 .85002 L p F P
0 g
s
.254 .204 .606 r
.83523 .83387 m .83844 .83006 L .83406 .82022 L p F P
0 g
s
.231 .191 .605 r
.84062 .81179 m .83406 .82022 L .83844 .83006 L p F P
0 g
s
.306 .274 .658 r
.83436 .80249 m .84062 .81179 L .83406 .82022 L p F P
0 g
s
.773 .664 .742 r
.46504 .89853 m .46694 .89643 L .46362 .89569 L closepath p F P
0 g
s
.773 .664 .743 r
.45906 .88659 m .46496 .87927 L p .46694 .89643 L F P
0 g
s
.773 .664 .743 r
.46694 .89643 m .46362 .89569 L .45906 .88659 L p F P
0 g
s
.9 .623 .508 r
.75254 .25609 m .7437 .24983 L .744 .24061 L p F P
0 g
s
.889 .654 .577 r
.7437 .24983 m .75254 .25609 L .75078 .2659 L p F P
0 g
s
.861 .472 .304 r
.72143 .21374 m .72363 .21986 L .7202 .21791 L closepath p F P
0 g
s
.845 .444 .282 r
.72143 .21374 m .7202 .21791 L p .70987 .20629 L F P
0 g
s
.886 .703 .65 r
.45361 .75406 m .46204 .75913 L .45774 .77082 L p F P
0 g
s
.882 .694 .644 r
.46204 .75913 m .45361 .75406 L .45748 .74253 L p F P
0 g
s
.831 .748 .772 r
.74399 .34271 m .73563 .3527 L .74081 .36179 L p F P
0 g
s
.832 .747 .771 r
.73279 .35608 m .73563 .3527 L .74081 .36179 L p F P
0 g
s
.832 .747 .771 r
.74081 .36179 m .74021 .36252 L .73279 .35608 L p F P
0 g
s
.749 .733 .837 r
.63089 .43887 m .64863 .4273 L p .62124 .43317 L F P
0 g
s
.749 .733 .837 r
.62124 .43317 m .6218 .43404 L .63089 .43887 L p F P
0 g
s
.754 .657 .753 r
.45141 .91139 m .46504 .89853 L .46362 .89569 L p F P
0 g
s
.889 .613 .512 r
.73468 .23447 m .744 .24061 L .7437 .24983 L p F P
0 g
s
.467 .571 .876 r
.76721 .69637 m .7638 .69581 L .75859 .6865 L p F P
0 g
s
.47 .371 .661 r
.59115 .77231 m .58896 .76139 L .5987 .76758 L closepath p F P
0 g
s
.817 .75 .789 r
.73279 .35608 m .74021 .36252 L .72694 .3766 L p F P
0 g
s
.754 .657 .753 r
.45246 .89343 m .43882 .90792 L .45141 .91139 L p F P
0 g
s
.754 .657 .753 r
.46362 .89569 m .45246 .89343 L p .45141 .91139 L F P
0 g
s
.783 .686 .756 r
.45141 .91139 m .44339 .91913 L .43731 .90954 L p F P
0 g
s
.783 .686 .756 r
.43731 .90954 m .43882 .90792 L .45141 .91139 L p F P
0 g
s
.13 .079 .527 r
.59652 .69789 m .60022 .69225 L .59771 .68265 L p F P
0 g
s
.158 .119 .561 r
.60022 .69225 m .59652 .69789 L .5983 .70985 L p F P
0 g
s
.304 .224 .599 r
.59703 .71117 m .5983 .70985 L .59652 .69789 L p F P
0 g
s
0 0 .425 r
.45038 .65209 m .45223 .64343 L .45496 .65271 L p F P
0 g
s
0 0 .425 r
.45496 .65271 m .45239 .66157 L .45038 .65209 L p F P
0 g
s
.947 .833 .699 r
.22315 .78934 m .21878 .78291 L .21297 .79499 L p F P
0 g
s
.947 .833 .699 r
.21297 .79499 m .21741 .80136 L .22315 .78934 L p F P
0 g
s
.632 .504 .688 r
.57918 .81945 m .57907 .819 L .57733 .81982 L closepath p F P
0 g
s
.81 .653 .687 r
.46901 .82907 m .47408 .8198 L .46399 .81653 L closepath p F P
0 g
s
.811 .652 .685 r
.46307 .81421 m .46813 .80365 L p .47408 .8198 L F P
0 g
s
.811 .652 .685 r
.47408 .8198 m .46399 .81653 L .46307 .81421 L p F P
0 g
s
.78 .847 .902 r
.32991 .66275 m .33383 .66516 L .33068 .66727 L closepath p F P
0 g
s
.27 0 .129 r
.37069 .19324 m .37345 .18741 L .35235 .19771 L p F P
0 g
s
.27 0 .129 r
.35235 .19771 m .35012 .20241 L .37069 .19324 L p F P
0 g
s
.788 .67 .733 r
.46189 .86234 m .47616 .86546 L .46496 .87927 L p F P
0 g
s
.758 .625 .712 r
.4716 .84895 m .46189 .86234 L .47616 .86546 L p F P
0 g
s
.758 .625 .712 r
.47707 .85002 m .4716 .84895 L p .47616 .86546 L F P
0 g
s
.505 .745 .981 r
.31177 .94531 m .33239 .94369 L .33901 .94859 L p F P
0 g
s
.526 .75 .978 r
.33239 .94369 m .31177 .94531 L .30503 .94084 L p F P
0 g
s
.069 0 .233 r
.82224 .88006 m .82158 .8806 L .81524 .89331 L p F P
0 g
s
.855 .735 .73 r
.75334 .31147 m .75145 .31443 L .75666 .32466 L p F P
0 g
s
.856 .733 .727 r
.74561 .32358 m .75145 .31443 L .75666 .32466 L p F P
0 g
s
.856 .733 .727 r
.75666 .32466 m .75329 .33004 L .74561 .32358 L p F P
0 g
s
0 0 0 r
.8017 .91036 m .78651 .92275 L .78138 .92633 L p F P
0 g
s
0 0 0 r
.80249 .90895 m .8017 .91036 L p .78138 .92633 L F P
0 g
s
0 0 0 r
.75757 .93946 m .77978 .92742 L .78138 .92633 L p F P
0 g
s
.41 .809 .588 r
.77978 .92742 m .78651 .92275 L .78138 .92633 L closepath p F P
0 g
s
.673 .685 .854 r
.50499 .43328 m .48337 .44217 L .48936 .45133 L p F P
0 g
s
.673 .685 .854 r
.48936 .45133 m .51094 .44257 L .50499 .43328 L p F P
0 g
s
.672 .699 .867 r
.51685 .45146 m .51094 .44257 L .48936 .45133 L p F P
0 g
s
.771 .631 .705 r
.47707 .85002 m .47492 .84441 L .4716 .84895 L closepath p F P
0 g
s
.657 .963 .925 r
.75603 .93931 m .75757 .93946 L .77978 .92742 L p F P
0 g
s
.578 .469 .694 r
.57918 .81945 m .57907 .819 L .58081 .81887 L closepath p F P
0 g
s
.578 .47 .695 r
.58269 .83338 m .57918 .81945 L .58081 .81887 L p F P
0 g
s
.784 .746 .817 r
.69765 .40309 m .69227 .40759 L .68411 .4015 L p F P
0 g
s
.428 .237 .518 r
.31409 .23694 m .3096 .23976 L .30951 .2493 L p F P
0 g
s
.766 .662 .747 r
.46362 .89569 m .45906 .88659 L .45246 .89343 L closepath p F P
0 g
s
.769 .847 .91 r
.33383 .66516 m .35513 .6515 L p .32965 .65939 L F P
0 g
s
.769 .847 .91 r
.32965 .65939 m .32991 .66275 L .33383 .66516 L p F P
0 g
s
.726 .726 .85 r
.59936 .44559 m .62066 .43352 L .60847 .4288 L p F P
0 g
s
.726 .726 .85 r
.60847 .4288 m .59372 .4372 L .59936 .44559 L p F P
0 g
s
.727 .825 .926 r
.39782 .62831 m .37645 .63927 L .38296 .64392 L p F P
0 g
s
.727 .825 .926 r
.38296 .64392 m .40425 .63312 L .39782 .62831 L p F P
0 g
s
.745 .831 .917 r
.3621 .64731 m .37645 .63927 L .38296 .64392 L p F P
0 g
s
.79 .314 .096 r
.69859 .20074 m .69343 .19379 L .6836 .18922 L p F P
0 g
s
.781 .297 .074 r
.70987 .20629 m .69859 .20074 L .69343 .19379 L p F P
0 g
s
.565 .542 .788 r
.3224 .3699 m .33635 .36802 L .32538 .37685 L closepath p F P
0 g
s
.787 .747 .817 r
.69765 .40309 m .71115 .39157 L .70333 .38532 L p F P
0 g
s
.787 .747 .817 r
.70333 .38532 m .69235 .39464 L .69765 .40309 L p F P
0 g
s
.784 .746 .817 r
.68411 .4015 m .69235 .39464 L .69765 .40309 L p F P
0 g
s
.461 .37 .666 r
.29282 .30053 m .29737 .29658 L .29487 .28396 L p F P
0 g
s
.49 .417 .701 r
.29737 .29658 m .29857 .30127 L .29282 .30053 L closepath p F P
0 g
s
.488 .418 .704 r
.30081 .31025 m .29857 .30127 L .29282 .30053 L p F P
0 g
s
.97 .798 .614 r
.21776 .81923 m .21291 .81307 L .20964 .82447 L p F P
0 g
s
.97 .798 .614 r
.21493 .82918 m .21776 .81923 L p .20964 .82447 L F P
0 g
s
.913 .51 .179 r
.23911 .8945 m .23933 .89512 L .23298 .88972 L p F P
0 g
s
.913 .51 .179 r
.23298 .88972 m .23226 .88764 L .23911 .8945 L p F P
0 g
s
.932 .559 .26 r
.23027 .87982 m .23226 .88764 L .23911 .8945 L p F P
0 g
s
.817 .75 .789 r
.72694 .3766 m .71938 .37024 L .73279 .35608 L p F P
0 g
s
.802 .749 .804 r
.71933 .38385 m .72694 .3766 L .71938 .37024 L p F P
0 g
s
.772 .632 .706 r
.4716 .84895 m .47492 .84441 L .47067 .83342 L p F P
0 g
s
0 0 .203 r
.83076 .87185 m .82224 .88006 L .82099 .88854 L p F P
0 g
s
.066 0 .347 r
.83323 .8601 m .83076 .87185 L .82224 .88006 L p F P
0 g
s
.069 0 .233 r
.81524 .89331 m .82099 .88854 L .82224 .88006 L p F P
0 g
s
.802 .749 .804 r
.71938 .37024 m .7141 .37523 L .71933 .38385 L p F P
0 g
s
.801 .747 .803 r
.70333 .38532 m .7141 .37523 L .71933 .38385 L p F P
0 g
s
.801 .747 .803 r
.71933 .38385 m .71115 .39157 L .70333 .38532 L p F P
0 g
s
.996 .788 .503 r
.45162 .69014 m .45547 .69676 L .45552 .69667 L p F P
0 g
s
1 .831 .512 r
.45547 .69676 m .45552 .69667 L .45549 .69682 L closepath p F P
0 g
s
.836 .662 .666 r
.46813 .80365 m .46307 .81421 L .45711 .80038 L p F P
0 g
s
.836 .662 .666 r
.45711 .80038 m .45756 .79933 L .46813 .80365 L p F P
0 g
s
.837 .66 .663 r
.46813 .80365 m .45756 .79933 L .46264 .78733 L p F P
0 g
s
.996 .849 .577 r
.45549 .69682 m .45547 .69676 L .44969 .70173 L p F P
0 g
s
.996 .849 .577 r
.44969 .70173 m .45234 .70802 L .45549 .69682 L p F P
0 g
s
.578 .47 .695 r
.58081 .81887 m .60111 .81728 L p .58269 .83338 L F P
0 g
s
.577 .461 .684 r
.60111 .81728 m .58081 .81887 L .59993 .8123 L closepath p F P
0 g
s
.576 .454 .676 r
.59675 .79869 m .59993 .8123 L .58081 .81887 L p F P
0 g
s
.88 .71 .667 r
.75935 .30001 m .75139 .29357 L .75599 .28264 L p F P
0 g
s
.862 .716 .699 r
.75334 .31147 m .75935 .30001 L .75139 .29357 L p F P
0 g
s
.993 .807 .551 r
.45547 .69676 m .45162 .69014 L .44933 .70111 L p F P
0 g
s
.993 .807 .551 r
.44933 .70111 m .44969 .70173 L .45547 .69676 L p F P
0 g
s
.915 .735 .644 r
.45051 .73696 m .45748 .74253 L .45361 .75406 L p F P
0 g
s
.915 .73 .638 r
.45748 .74253 m .45051 .73696 L .4541 .72554 L p F P
0 g
s
.606 .037 0 r
.66845 .18347 m .66013 .17786 L .65109 .17458 L p F P
0 g
s
.563 0 0 r
.68158 .18841 m .66845 .18347 L .66013 .17786 L p F P
0 g
s
.817 .344 0 r
.23933 .89512 m .23298 .88972 L .23838 .89896 L p F P
0 g
s
.817 .344 0 r
.23838 .89896 m .24476 .90434 L .23933 .89512 L p F P
0 g
s
.936 .563 .242 r
.23226 .88764 m .23027 .87982 L .22418 .87428 L p F P
0 g
s
.766 .76 .848 r
.39418 .94281 m .3974 .94057 L .38816 .93661 L closepath p F P
0 g
s
.723 .75 .873 r
.38816 .93661 m .39418 .94281 L p .36653 .94731 L F P
0 g
s
.088 .613 .875 r
.62149 .16605 m .6165 .16508 L p .60052 .1621 L F P
0 g
s
.25 0 0 r
.62149 .16605 m .63114 .16897 L .6165 .16508 L closepath p F P
0 g
s
.685 .695 .854 r
.53268 .43281 m .51094 .44257 L .51685 .45146 L p F P
0 g
s
.685 .695 .854 r
.51685 .45146 m .53854 .44188 L .53268 .43281 L p F P
0 g
s
.684 .713 .871 r
.54437 .45059 m .53854 .44188 L .51685 .45146 L p F P
0 g
s
.497 .614 .898 r
.72494 .66625 m .72217 .66607 L .72274 .66273 L closepath p F P
0 g
s
.52 .633 .902 r
.71969 .65803 m .72274 .66273 L .72217 .66607 L p F P
0 g
s
0 .476 .852 r
.27825 .93081 m .29046 .93467 L .29827 .93944 L p F P
0 g
s
.043 .508 .887 r
.29046 .93467 m .27825 .93081 L .27137 .92622 L p F P
0 g
s
.917 .859 .769 r
.2346 .75762 m .23093 .75085 L .22216 .76377 L p F P
0 g
s
.917 .859 .769 r
.22216 .76377 m .22593 .77048 L .2346 .75762 L p F P
0 g
s
.194 .122 .542 r
.83844 .83006 m .83523 .83387 L .83677 .84527 L p F P
0 g
s
.246 .158 .554 r
.83308 .84907 m .83677 .84527 L .83523 .83387 L p F P
0 g
s
.712 .716 .852 r
.58805 .42854 m .56615 .4401 L .57188 .44867 L p F P
0 g
s
.712 .716 .852 r
.57188 .44867 m .59372 .4372 L .58805 .42854 L p F P
0 g
s
.7 .72 .865 r
.57188 .44867 m .56615 .4401 L .54437 .45059 L p F P
0 g
s
.645 .658 .848 r
.42711 .43588 m .42844 .43804 L .44976 .43091 L p F P
0 g
s
.178 .061 .472 r
.83677 .84527 m .83308 .84907 L .83323 .8601 L p F P
0 g
s
.842 .738 .75 r
.74561 .32358 m .75329 .33004 L .74399 .34271 L p F P
0 g
s
.4 .473 .82 r
.81125 .73763 m .8033 .73436 L .79887 .72442 L p F P
0 g
s
.451 .54 .857 r
.76721 .69637 m .78744 .70118 L .78475 .70928 L p F P
0 g
s
.437 .547 .87 r
.76936 .68834 m .76721 .69637 L .78744 .70118 L p F P
0 g
s
.467 .571 .876 r
.75859 .6865 m .76936 .68834 L .76721 .69637 L p F P
0 g
s
0 .452 .729 r
.61554 .16489 m .60052 .1621 L .59071 .16015 L p F P
0 g
s
.088 .613 .875 r
.6165 .16508 m .61554 .16489 L .60052 .1621 L p F P
0 g
s
.766 .76 .847 r
.40942 .92047 m .41565 .92832 L .3974 .94057 L p F P
0 g
s
.766 .76 .847 r
.38784 .93627 m .40942 .92047 L p .3974 .94057 L F P
0 g
s
.766 .76 .847 r
.3974 .94057 m .38816 .93661 L .38784 .93627 L p F P
0 g
s
.611 .737 .935 r
.67519 .94663 m .69761 .94229 L .70287 .94829 L p F P
0 g
s
.604 .693 .906 r
.69761 .94229 m .67519 .94663 L .66975 .93861 L p F P
0 g
s
.619 .58 .788 r
.60843 .91305 m .63055 .90869 L p .63545 .92167 L F P
0 g
s
.612 .555 .766 r
.62844 .90339 m .63055 .90869 L .60843 .91305 L p F P
0 g
s
.612 .555 .766 r
.60843 .91305 m .60712 .90972 L .62844 .90339 L p F P
0 g
s
.804 .663 .708 r
.45826 .84554 m .4716 .84895 L .46189 .86234 L p F P
0 g
s
.772 .632 .706 r
.46677 .83249 m .45826 .84554 L .4716 .84895 L p F P
0 g
s
.772 .632 .706 r
.47067 .83342 m .46677 .83249 L p .4716 .84895 L F P
0 g
s
.698 .705 .853 r
.56038 .43123 m .53854 .44188 L .54437 .45059 L p F P
0 g
s
.698 .705 .853 r
.54437 .45059 m .56615 .4401 L .56038 .43123 L p F P
0 g
s
.217 .74 .829 r
.47694 .15798 m .4519 .16192 L p .46775 .15927 L F P
0 g
s
.217 .74 .829 r
.4519 .16192 m .45041 .16186 L .47176 .1586 L p F P
0 g
s
0 0 0 r
.44595 .1631 m .47099 .15894 L p .46054 .16042 L F P
0 g
s
0 0 0 r
.45041 .16186 m .44891 .16228 L p .46054 .16042 L F P
0 g
s
0 0 0 r
.44891 .16228 m .44595 .1631 L p .46054 .16042 L F P
0 g
s
.217 .74 .829 r
.47176 .1586 m .4725 .15851 L p .46775 .15927 L F P
0 g
s
.217 .74 .829 r
.4725 .15851 m .47694 .15798 L p .46775 .15927 L F P
0 g
s
.598 .592 .817 r
.36163 .40536 m .36384 .40488 L .36203 .40615 L closepath p F P
0 g
s
.931 .845 .736 r
.2249 .77227 m .22593 .77048 L .22725 .77253 L closepath p F P
0 g
s
.931 .845 .736 r
.21878 .78291 m .2249 .77227 L .22725 .77253 L p F P
0 g
s
.569 .545 .788 r
.3224 .3699 m .33635 .36802 L p .32167 .35476 L F P
0 g
s
.569 .545 .788 r
.32167 .35476 m .31735 .35816 L .3224 .3699 L p F P
0 g
s
.495 .393 .668 r
.30398 .27722 m .29487 .28396 L .29737 .29658 L p F P
0 g
s
.788 .67 .733 r
.45906 .88659 m .46496 .87927 L .45387 .87625 L closepath p F P
0 g
s
.788 .67 .733 r
.45305 .87463 m .46189 .86234 L p .46496 .87927 L F P
0 g
s
.788 .67 .733 r
.46496 .87927 m .45387 .87625 L .45305 .87463 L p F P
0 g
s
.785 .637 .698 r
.47067 .83342 m .46901 .82907 L .46677 .83249 L closepath p F P
0 g
s
.966 .651 .366 r
.22323 .86395 m .2175 .85823 L .21842 .86858 L p F P
0 g
s
.966 .651 .366 r
.21842 .86858 m .22418 .87428 L .22323 .86395 L p F P
0 g
s
.598 .588 .812 r
.37634 .3882 m .35541 .39303 L .36163 .40536 L p F P
0 g
s
.598 .588 .812 r
.37936 .39431 m .37634 .3882 L p .36163 .40536 L F P
0 g
s
.598 .588 .812 r
.36163 .40536 m .36384 .40488 L .37936 .39431 L p F P
0 g
s
.581 .472 .695 r
.58502 .84261 m .58269 .83338 L .60349 .8263 L p F P
0 g
s
.578 .47 .695 r
.60111 .81728 m .60349 .8263 L .58269 .83338 L p F P
0 g
s
.472 .374 .664 r
.5987 .76758 m .59115 .77231 L .5938 .78533 L p F P
0 g
s
.61 .556 .768 r
.62478 .89431 m .62844 .90339 L .60712 .90972 L p F P
0 g
s
.61 .556 .768 r
.60712 .90972 m .60264 .89839 L .62478 .89431 L p F P
0 g
s
.322 .25 .619 r
.59909 .71452 m .59703 .71117 L .5983 .70985 L closepath p F P
0 g
s
.638 .1 0 r
.26698 .92315 m .25989 .91808 L .2515 .90957 L p F P
0 g
s
.612 .079 0 r
.2515 .90957 m .24476 .90434 L .25313 .91287 L p F P
0 g
s
.612 .079 0 r
.25313 .91287 m .25989 .91808 L .2515 .90957 L p F P
0 g
s
.594 .732 .94 r
.63837 .63186 m .63057 .63329 L .62508 .62696 L p F P
0 g
s
.86 .69 .671 r
.45326 .78262 m .46264 .78733 L .45756 .79933 L p F P
0 g
s
.86 .679 .656 r
.46264 .78733 m .45326 .78262 L .45774 .77082 L p F P
0 g
s
.752 .736 .838 r
.64863 .4273 m .66064 .41912 L .65119 .41346 L p F P
0 g
s
.752 .736 .838 r
.65119 .41346 m .64315 .41891 L .64863 .4273 L p F P
0 g
s
.749 .733 .837 r
.64863 .4273 m .64315 .41891 L .62124 .43317 L p F P
0 g
s
.789 .644 .701 r
.46677 .83249 m .46901 .82907 L .46399 .81653 L p F P
0 g
s
.268 .26 .665 r
.84025 .79411 m .83436 .80249 L .84062 .81179 L p F P
0 g
s
.306 .309 .699 r
.83436 .80249 m .84025 .79411 L .83219 .78535 L p F P
0 g
s
.642 .644 .837 r
.4223 .42763 m .42711 .43588 L .44754 .42727 L p F P
0 g
s
.645 .658 .848 r
.44976 .43091 m .44754 .42727 L .42711 .43588 L p F P
0 g
s
.627 .634 .838 r
.39242 .41865 m .39498 .42308 L .41613 .41692 L p F P
0 g
s
.533 .655 .913 r
.69155 .64966 m .69095 .64967 L .69101 .64887 L closepath p F P
0 g
s
.549 .671 .919 r
.68623 .64216 m .69101 .64887 L .69095 .64967 L p F P
0 g
s
.66 .769 .93 r
.33901 .94859 m .36005 .94174 L .36653 .94731 L p F P
0 g
s
.673 .773 .925 r
.36005 .94174 m .33901 .94859 L .33239 .94369 L p F P
0 g
s
.489 .603 .892 r
.72494 .66625 m .74815 .6685 L p .74796 .67653 L F P
0 g
s
.473 .601 .899 r
.74293 .6602 m .74815 .6685 L .72494 .66625 L p F P
0 g
s
.473 .601 .899 r
.7231 .65818 m .74293 .6602 L p .72494 .66625 L F P
0 g
s
.473 .601 .899 r
.72494 .66625 m .72274 .66273 L .7231 .65818 L p F P
0 g
s
.723 .75 .873 r
.36653 .94731 m .38753 .93643 L .38816 .93661 L p F P
0 g
s
.736 .754 .867 r
.38753 .93643 m .36653 .94731 L .36005 .94174 L p F P
0 g
s
.278 .764 .918 r
.50556 .15625 m .51389 .15533 L .50329 .15566 L closepath p F P
0 g
s
.498 .637 .916 r
.70914 .64246 m .71442 .65015 L .69155 .64966 L p F P
0 g
s
.498 .637 .916 r
.69052 .64206 m .70914 .64246 L p .69155 .64966 L F P
0 g
s
.498 .637 .916 r
.69155 .64966 m .69101 .64887 L .69052 .64206 L p F P
0 g
s
.509 .639 .912 r
.69155 .64966 m .71442 .65015 L .71969 .65803 L p F P
0 g
s
.37 .137 .425 r
.31409 .23694 m .32789 .2284 L .32883 .21995 L p F P
0 g
s
.431 .239 .517 r
.32789 .2284 m .31409 .23694 L .3182 .24388 L p F P
0 g
s
.428 .237 .518 r
.30951 .2493 m .3182 .24388 L .31409 .23694 L p F P
0 g
s
.766 .662 .747 r
.45246 .89343 m .45906 .88659 L .45387 .87625 L p F P
0 g
s
.84 .448 .307 r
.69859 .20074 m .70987 .20629 L .71298 .2141 L p F P
0 g
s
.845 .444 .282 r
.7202 .21791 m .71298 .2141 L .70987 .20629 L p F P
0 g
s
.607 .608 .826 r
.37936 .39431 m .38256 .40032 L .36384 .40488 L closepath p F P
0 g
s
.608 .612 .83 r
.38878 .41191 m .38256 .40032 L .36384 .40488 L p F P
0 g
s
.886 .686 .627 r
.75599 .28264 m .74757 .27629 L .75078 .2659 L p F P
0 g
s
.872 .699 .665 r
.74757 .27629 m .75599 .28264 L .75139 .29357 L p F P
0 g
s
0 0 .03 r
.80249 .90895 m .80487 .90705 L .81524 .89331 L p F P
0 g
s
0 0 0 r
.8017 .91036 m .80487 .90705 L .80249 .90895 L closepath p F P
0 g
s
.546 .911 .958 r
.7304 .94644 m .75286 .93861 L .75603 .93931 L p F P
0 g
s
.592 .878 .993 r
.75286 .93861 m .7304 .94644 L .72537 .94273 L p F P
0 g
s
.603 .829 .986 r
.70287 .94829 m .72537 .94273 L .7304 .94644 L p F P
0 g
s
.29 .78 .897 r
.47801 .15815 m .48289 .15738 L .47694 .15798 L closepath p F P
0 g
s
.588 .492 .713 r
.58642 .84755 m .58502 .84261 L .60711 .84002 L p F P
0 g
s
.581 .472 .695 r
.60349 .8263 m .60711 .84002 L .58502 .84261 L p F P
0 g
s
.209 .613 .95 r
.29827 .93944 m .30503 .94084 L .29824 .93615 L p F P
0 g
s
.209 .613 .95 r
.29824 .93615 m .29046 .93467 L .29827 .93944 L p F P
0 g
s
.601 .609 .832 r
.66423 .92925 m .64191 .93279 L .63626 .9215 L p F P
0 g
s
.816 .669 .7 r
.45445 .82873 m .46677 .83249 L .45826 .84554 L p F P
0 g
s
.789 .644 .701 r
.46204 .81596 m .45445 .82873 L .46677 .83249 L p F P
0 g
s
.789 .644 .701 r
.46399 .81653 m .46204 .81596 L p .46677 .83249 L F P
0 g
s
.951 .78 .634 r
.4541 .72554 m .44885 .71938 L .44513 .73087 L p F P
0 g
s
.951 .78 .634 r
.44513 .73087 m .45051 .73696 L .4541 .72554 L p F P
0 g
s
0 .452 .729 r
.59773 .16164 m .61554 .16489 L p .59071 .16015 L F P
0 g
s
0 .452 .729 r
.59071 .16015 m .58835 .15942 L .59773 .16164 L p F P
0 g
s
.085 .627 .849 r
.58231 .15906 m .59071 .16015 L .58835 .15942 L closepath p F P
0 g
s
.605 .773 .961 r
.72537 .94273 m .70287 .94829 L .69761 .94229 L p F P
0 g
s
.166 0 0 r
.418 .17255 m .42201 .16854 L .39932 .17535 L p F P
0 g
s
.166 0 0 r
.39932 .17535 m .39516 .17934 L .418 .17255 L p F P
0 g
s
.62 .939 .957 r
.75286 .93861 m .76678 .93252 L .75603 .93931 L closepath p F P
0 g
s
.657 .963 .925 r
.77531 .92852 m .76678 .93252 L .75603 .93931 L p F P
0 g
s
.657 .963 .925 r
.77978 .92742 m .77531 .92852 L p .75603 .93931 L F P
0 g
s
.793 .703 .765 r
.43972 .88994 m .45246 .89343 L .43882 .90792 L p F P
0 g
s
.766 .662 .747 r
.45201 .87581 m .43972 .88994 L .45246 .89343 L p F P
0 g
s
.766 .662 .747 r
.45387 .87625 m .45201 .87581 L p .45246 .89343 L F P
0 g
s
.588 .491 .712 r
.59055 .86211 m .58642 .84755 L .60726 .84054 L p F P
0 g
s
.588 .492 .713 r
.60711 .84002 m .60726 .84054 L .58642 .84755 L p F P
0 g
s
.978 .717 .464 r
.21802 .84754 m .21265 .84164 L .2121 .85235 L p F P
0 g
s
.978 .717 .464 r
.2121 .85235 m .2175 .85823 L .21802 .84754 L p F P
0 g
s
.97 .81 .387 r
.45324 .67944 m .4518 .67192 L .44992 .68273 L p F P
0 g
s
.97 .81 .387 r
.44992 .68273 m .45162 .69014 L .45324 .67944 L p F P
0 g
s
.526 .66 .921 r
.69101 .64887 m .68623 .64216 L .69052 .64206 L closepath p F P
0 g
s
.232 .728 .913 r
.5331 .15571 m .53974 .15536 L .53092 .15503 L closepath p F P
0 g
s
.605 .534 .747 r
.62199 .88659 m .62478 .89431 L .60264 .89839 L p F P
0 g
s
.605 .534 .747 r
.60264 .89839 m .60078 .89309 L .62199 .88659 L p F P
0 g
s
0 0 0 r
.82099 .88854 m .81524 .89331 L .80487 .90705 L p F P
0 g
s
.288 .227 .613 r
.5983 .70985 m .60358 .70167 L p .6022 .72012 L F P
0 g
s
.288 .227 .613 r
.6022 .72012 m .59909 .71452 L .5983 .70985 L p F P
0 g
s
.158 .119 .561 r
.5983 .70985 m .60358 .70167 L .60022 .69225 L p F P
0 g
s
.907 .778 .291 r
.60015 .6639 m .59944 .6563 L .60092 .64559 L p F P
0 g
s
.889 .712 .655 r
.44955 .76571 m .45774 .77082 L .45326 .78262 L p F P
0 g
s
.886 .703 .65 r
.45774 .77082 m .44955 .76571 L .45361 .75406 L p F P
0 g
s
.554 .518 .769 r
.31626 .35533 m .32167 .35476 L .31735 .35816 L closepath p F P
0 g
s
.603 .534 .749 r
.61894 .8782 m .62199 .88659 L .60078 .89309 L p F P
0 g
s
.603 .534 .749 r
.60078 .89309 m .59681 .88193 L .61894 .8782 L p F P
0 g
s
.963 .824 .657 r
.21741 .80136 m .21297 .79499 L .20843 .80673 L p F P
0 g
s
.963 .824 .657 r
.20843 .80673 m .21291 .81307 L .21741 .80136 L p F P
0 g
s
.838 .866 .865 r
.28412 .69408 m .28454 .6937 L .28475 .69437 L closepath p F P
0 g
s
.841 .865 .861 r
.26776 .70902 m .28412 .69408 L .28475 .69437 L p F P
0 g
s
.76 .851 .919 r
.36269 .63885 m .34846 .64742 L .35513 .6515 L p F P
0 g
s
.76 .851 .919 r
.35513 .6515 m .3621 .64731 L .36269 .63885 L p F P
0 g
s
.769 .847 .91 r
.35513 .6515 m .34846 .64742 L .32965 .65939 L p F P
0 g
s
.659 .669 .848 r
.47129 .42284 m .44976 .43091 L .45586 .44066 L p F P
0 g
s
.659 .669 .848 r
.45586 .44066 m .47734 .43265 L .47129 .42284 L p F P
0 g
s
.606 .037 0 r
.65489 .17865 m .66845 .18347 L p .65109 .17458 L F P
0 g
s
.606 .037 0 r
.65109 .17458 m .64947 .17469 L .65489 .17865 L p F P
0 g
s
.475 0 0 r
.64632 .17317 m .65109 .17458 L .64947 .17469 L closepath p F P
0 g
s
.842 .738 .75 r
.74399 .34271 m .73621 .33632 L .74561 .32358 L p F P
0 g
s
.825 .739 .769 r
.73563 .3527 m .74399 .34271 L .73621 .33632 L p F P
0 g
s
.793 .724 .788 r
.42112 .92347 m .41565 .92832 L .40942 .92047 L p F P
0 g
s
.763 .735 .827 r
.6705 .41184 m .66064 .41912 L .65119 .41346 L p F P
0 g
s
.8 .647 .692 r
.46399 .81653 m .46307 .81421 L .46204 .81596 L closepath p F P
0 g
s
.804 .664 .708 r
.46189 .86234 m .45305 .87463 L .44702 .86287 L p F P
0 g
s
.804 .664 .708 r
.44702 .86287 m .44979 .85861 L .46189 .86234 L p F P
0 g
s
.804 .663 .708 r
.46189 .86234 m .44979 .85861 L .45826 .84554 L p F P
0 g
s
.793 .724 .788 r
.40942 .92047 m .41043 .9195 L .42112 .92347 L p F P
0 g
s
.765 .695 .785 r
.42639 .90437 m .41043 .9195 L .42112 .92347 L p F P
0 g
s
.765 .695 .785 r
.4356 .90686 m .42639 .90437 L p .42112 .92347 L F P
0 g
s
.765 .695 .785 r
.42112 .92347 m .43731 .90954 L .4356 .90686 L p F P
0 g
s
.559 .521 .769 r
.31626 .35533 m .32167 .35476 L p .31276 .33933 L F P
0 g
s
.559 .521 .769 r
.31276 .33933 m .31068 .34093 L .31626 .35533 L p F P
0 g
s
.078 .623 .841 r
.56257 .1566 m .58231 .15906 L .58835 .15942 L p F P
0 g
s
.495 .393 .668 r
.29737 .29658 m .31435 .28407 L p .30398 .27722 L F P
0 g
s
.514 .432 .702 r
.31772 .2977 m .31435 .28407 L .29737 .29658 L p F P
0 g
s
.514 .432 .702 r
.31226 .3017 m .31772 .2977 L p .29737 .29658 L F P
0 g
s
.514 .432 .702 r
.29737 .29658 m .29857 .30127 L .31226 .3017 L p F P
0 g
s
.938 .858 .736 r
.2249 .77227 m .22593 .77048 L .22216 .76377 L p F P
0 g
s
.81 .661 .697 r
.46204 .81596 m .46307 .81421 L .45711 .80038 L p F P
0 g
s
.409 .505 .845 r
.78475 .70928 m .79273 .7118 L .78747 .7012 L p F P
0 g
s
.409 .505 .845 r
.78747 .7012 m .78744 .70118 L .78475 .70928 L p F P
0 g
s
0 0 0 r
.78651 .92275 m .77978 .92742 L .77531 .92852 L p F P
0 g
s
.889 .654 .577 r
.75078 .2659 m .7419 .25966 L .7437 .24983 L p F P
0 g
s
.877 .675 .626 r
.7419 .25966 m .75078 .2659 L .74757 .27629 L p F P
0 g
s
.592 .494 .712 r
.59094 .86345 m .59055 .86211 L .61163 .85537 L p F P
0 g
s
.588 .491 .712 r
.60726 .84054 m .61163 .85537 L .59055 .86211 L p F P
0 g
s
.734 .728 .845 r
.62124 .43317 m .62066 .43352 L .6218 .43404 L closepath p F P
0 g
s
.419 .177 .439 r
.34741 .21813 m .3483 .20967 L .32883 .21995 L p F P
0 g
s
.419 .177 .439 r
.32883 .21995 m .32789 .2284 L .34741 .21813 L p F P
0 g
s
.793 .703 .765 r
.43119 .89995 m .43972 .88994 L p .43882 .90792 L F P
0 g
s
.793 .703 .765 r
.43882 .90792 m .4356 .90686 L .43119 .89995 L p F P
0 g
s
.793 .702 .765 r
.43731 .90954 m .43882 .90792 L .4356 .90686 L closepath p F P
0 g
s
.596 .513 .731 r
.59535 .8773 m .59094 .86345 L .61305 .86019 L p F P
0 g
s
.592 .494 .712 r
.61163 .85537 m .61305 .86019 L .59094 .86345 L p F P
0 g
s
.621 .618 .826 r
.38878 .41191 m .39242 .41865 L .41119 .40824 L p F P
0 g
s
.627 .634 .838 r
.41613 .41692 m .41119 .40824 L .39242 .41865 L p F P
0 g
s
.4 .473 .82 r
.79887 .72442 m .79946 .72303 L p .81125 .73763 L F P
0 g
s
.422 .506 .84 r
.79887 .72442 m .79798 .72256 L .79946 .72303 L closepath p F P
0 g
s
.599 .513 .729 r
.59681 .88193 m .59535 .8773 L .61649 .87067 L p F P
0 g
s
.596 .513 .731 r
.61305 .86019 m .61649 .87067 L .59535 .8773 L p F P
0 g
s
.872 .547 .433 r
.7202 .21791 m .72363 .21986 L .72482 .22846 L p F P
0 g
s
.883 .555 .424 r
.73468 .23447 m .72482 .22846 L .72363 .21986 L p F P
0 g
s
0 .151 .592 r
.26698 .92315 m .27137 .92622 L .26446 .92127 L p F P
0 g
s
0 .151 .592 r
.26446 .92127 m .25989 .91808 L .26698 .92315 L p F P
0 g
s
.599 .513 .729 r
.61649 .87067 m .61894 .8782 L .59681 .88193 L p F P
0 g
s
.79 .314 .096 r
.68679 .19532 m .69859 .20074 L p .6836 .18922 L F P
0 g
s
.79 .314 .096 r
.6836 .18922 m .68287 .18981 L .68679 .19532 L p F P
0 g
s
.738 .24 .048 r
.68158 .18841 m .6836 .18922 L .68287 .18981 L closepath p F P
0 g
s
0 0 0 r
.47099 .15894 m .47176 .1586 L .45041 .16186 L p F P
0 g
s
.862 .716 .699 r
.74783 .30709 m .75334 .31147 L p .75139 .29357 L F P
0 g
s
.85 .726 .727 r
.74783 .30709 m .75145 .31443 L .75334 .31147 L closepath p F P
0 g
s
.863 .878 .847 r
.26239 .71445 m .26776 .70902 L .26544 .70164 L p F P
0 g
s
.842 .875 .866 r
.28412 .69408 m .26776 .70902 L .26544 .70164 L p F P
0 g
s
.841 .877 .869 r
.2828 .68609 m .27704 .69117 L .28412 .69408 L p F P
0 g
s
.841 .877 .869 r
.28412 .69408 m .28454 .6937 L .2828 .68609 L p F P
0 g
s
.842 .875 .866 r
.26544 .70164 m .27704 .69117 L .28412 .69408 L p F P
0 g
s
.819 .873 .885 r
.30471 .67731 m .28454 .6937 L .2828 .68609 L p F P
0 g
s
.457 .572 .882 r
.76936 .68834 m .75859 .6865 L .75337 .67737 L p F P
0 g
s
.411 .328 .652 r
.60532 .74746 m .59718 .73953 L .60286 .73496 L closepath p F P
0 g
s
.406 .32 .646 r
.59718 .73953 m .60286 .73496 L .60046 .72226 L p F P
0 g
s
.831 .68 .695 r
.45082 .81185 m .46204 .81596 L .45445 .82873 L p F P
0 g
s
.81 .661 .697 r
.45711 .80038 m .45082 .81185 L .46204 .81596 L p F P
0 g
s
.514 .431 .699 r
.29857 .30127 m .31226 .3017 L .30081 .31025 L closepath p F P
0 g
s
.938 .858 .736 r
.22216 .76377 m .21733 .772 L .2249 .77227 L p F P
0 g
s
.935 .858 .741 r
.2249 .77227 m .21878 .78291 L .21481 .7763 L p F P
0 g
s
.935 .858 .741 r
.21481 .7763 m .21733 .772 L .2249 .77227 L p F P
0 g
s
.292 .308 .706 r
.83741 .77704 m .83219 .78535 L .84025 .79411 L p F P
0 g
s
.327 .354 .736 r
.83219 .78535 m .83741 .77704 L .82759 .76882 L p F P
0 g
s
.507 .4 .668 r
.5938 .78533 m .61064 .77491 L p .60355 .79482 L F P
0 g
s
.507 .4 .668 r
.60355 .79482 m .59506 .79143 L .5938 .78533 L p F P
0 g
s
.472 .374 .664 r
.5938 .78533 m .61064 .77491 L .5987 .76758 L p F P
0 g
s
.732 .721 .841 r
.62124 .43317 m .62066 .43352 L .60847 .4288 L p F P
0 g
s
.547 .678 .924 r
.65829 .63645 m .68088 .63487 L .68623 .64216 L p F P
0 g
s
.544 .685 .931 r
.68088 .63487 m .65829 .63645 L .65287 .62942 L p F P
0 g
s
.863 .878 .847 r
.26544 .70164 m .25519 .71187 L .26239 .71445 L p F P
0 g
s
.861 .874 .846 r
.26239 .71445 m .25347 .72357 L .25074 .71636 L p F P
0 g
s
.861 .874 .846 r
.25074 .71636 m .25519 .71187 L .26239 .71445 L p F P
0 g
s
.97 .798 .614 r
.20964 .82447 m .21387 .8298 L .21493 .82918 L p F P
0 g
s
.969 .792 .61 r
.21387 .8298 m .21493 .82918 L .21453 .8306 L closepath p F P
0 g
s
.271 .22 .615 r
.60046 .72226 m .59909 .71452 L .6022 .72012 L closepath p F P
0 g
s
.744 .728 .837 r
.63764 .41023 m .61565 .42444 L .62124 .43317 L p F P
0 g
s
.744 .728 .837 r
.62124 .43317 m .64315 .41891 L .63764 .41023 L p F P
0 g
s
.732 .721 .841 r
.60847 .4288 m .61565 .42444 L .62124 .43317 L p F P
0 g
s
.767 .738 .826 r
.6705 .41184 m .68411 .4015 L .67521 .39561 L p F P
0 g
s
.767 .738 .826 r
.67521 .39561 m .66509 .40325 L .6705 .41184 L p F P
0 g
s
.763 .735 .827 r
.65119 .41346 m .66509 .40325 L .6705 .41184 L p F P
0 g
s
.889 .613 .512 r
.7437 .24983 m .73433 .2437 L .73468 .23447 L p F P
0 g
s
.879 .644 .578 r
.73433 .2437 m .7437 .24983 L .7419 .25966 L p F P
0 g
s
0 0 0 r
.78651 .92275 m .79816 .91441 L .8017 .91036 L closepath p F P
0 g
s
0 0 0 r
.79816 .91441 m .78651 .92275 L p .77531 .92852 L F P
0 g
s
.788 .86 .904 r
.32707 .66117 m .32965 .65939 L .32991 .66275 L closepath p F P
0 g
s
.501 .627 .907 r
.72274 .66273 m .71969 .65803 L .7231 .65818 L closepath p F P
0 g
s
.879 .603 .516 r
.72482 .22846 m .73468 .23447 L .73433 .2437 L p F P
0 g
s
.594 .665 .889 r
.43186 .63069 m .42559 .62441 L p .44748 .61902 L F P
0 g
s
.594 .665 .889 r
.44748 .61902 m .43835 .62956 L .43186 .63069 L p F P
0 g
s
.682 .797 .935 r
.43186 .63069 m .42559 .62441 L .41414 .62901 L p F P
0 g
s
.016 0 0 r
.49951 .15566 m .48289 .15738 L .47694 .15798 L p F P
0 g
s
.131 .679 .775 r
.48289 .15738 m .50329 .15566 L .49951 .15566 L closepath p F P
0 g
s
.016 0 0 r
.49732 .15635 m .49951 .15566 L p .47694 .15798 L F P
0 g
s
.016 0 0 r
.47533 .15846 m .49732 .15635 L p .47694 .15798 L F P
0 g
s
.016 0 0 r
.47694 .15798 m .47176 .1586 L .47533 .15846 L p F P
0 g
s
.146 .668 .882 r
.56068 .15656 m .56257 .1566 L .55995 .15632 L closepath p F P
0 g
s
.899 .866 .798 r
.24031 .7387 m .24124 .73749 L .24204 .73913 L closepath p F P
0 g
s
.9 .866 .797 r
.23093 .75085 m .24031 .7387 L .24204 .73913 L p F P
0 g
s
.418 .508 .844 r
.79946 .72303 m .79798 .72256 L .79273 .7118 L p F P
0 g
s
.488 0 0 r
.63114 .16897 m .64632 .17317 L .64947 .17469 L p F P
0 g
s
.746 .84 .922 r
.37645 .63927 m .3621 .64731 L .36269 .63885 L p F P
0 g
s
.736 .246 .074 r
.66845 .18347 m .68158 .18841 L .68287 .18981 L p F P
0 g
s
.845 .725 .73 r
.75145 .31443 m .74561 .32358 L p .74526 .30509 L F P
0 g
s
.845 .725 .73 r
.74526 .30509 m .74783 .30709 L .75145 .31443 L p F P
0 g
s
.825 .739 .769 r
.73621 .33632 m .73038 .34319 L .73563 .3527 L p F P
0 g
s
.825 .738 .768 r
.72479 .34979 m .73038 .34319 L .73563 .3527 L p F P
0 g
s
.825 .738 .768 r
.73563 .3527 m .73279 .35608 L .72479 .34979 L p F P
0 g
s
.598 .728 .936 r
.63837 .63186 m .65287 .62942 L .64742 .62259 L p F P
0 g
s
.598 .728 .936 r
.64742 .62259 m .63513 .62493 L .63837 .63186 L p F P
0 g
s
.594 .732 .94 r
.62508 .62696 m .63513 .62493 L .63837 .63186 L p F P
0 g
s
.882 .874 .824 r
.25347 .72357 m .25074 .71636 L .23832 .73039 L p F P
0 g
s
.882 .874 .824 r
.23832 .73039 m .24124 .73749 L .25347 .72357 L p F P
0 g
s
.821 .827 .853 r
.6183 .63007 m .60318 .64052 L .59766 .63788 L p F P
0 g
s
.958 .845 .689 r
.60092 .64559 m .60318 .64052 L .59766 .63788 L p F P
0 g
s
.471 .312 .583 r
.3182 .24388 m .30951 .2493 L .31028 .25989 L p F P
0 g
s
.981 .766 .54 r
.21453 .8306 m .21387 .8298 L .20989 .8383 L p F P
0 g
s
.981 .766 .54 r
.20989 .8383 m .21265 .84164 L .21453 .8306 L p F P
0 g
s
0 0 0 r
.80487 .90705 m .81573 .89801 L p .79816 .91441 L F P
0 g
s
0 0 0 r
.79816 .91441 m .8017 .91036 L .80487 .90705 L p F P
0 g
s
0 0 0 r
.81937 .89359 m .82099 .88854 L p .80487 .90705 L F P
0 g
s
0 0 0 r
.80487 .90705 m .81573 .89801 L .81937 .89359 L p F P
0 g
s
.915 .74 .65 r
.4467 .7485 m .45361 .75406 L .44955 .76571 L p F P
0 g
s
.915 .735 .644 r
.45361 .75406 m .4467 .7485 L .45051 .73696 L p F P
0 g
s
.691 .796 .93 r
.41603 .62011 m .39782 .62831 L .40425 .63312 L p F P
0 g
s
.691 .796 .93 r
.40425 .63312 m .41414 .62901 L .41603 .62011 L p F P
0 g
s
.542 .491 .748 r
.3102 .33951 m .31276 .33933 L .31068 .34093 L closepath p F P
0 g
s
.602 .592 .814 r
.35541 .39303 m .37634 .3882 L p .35995 .37802 L F P
0 g
s
.602 .592 .814 r
.35995 .37802 m .35091 .38405 L .35541 .39303 L p F P
0 g
s
.547 .495 .749 r
.3102 .33951 m .31276 .33933 L p .30959 .32168 L F P
0 g
s
.547 .495 .749 r
.30959 .32168 m .30521 .325 L .3102 .33951 L p F P
0 g
s
.534 .467 .726 r
.31226 .3017 m .30081 .31025 L .30427 .32181 L p F P
0 g
s
.99 .861 .614 r
.45234 .70802 m .44885 .71938 L .44556 .71258 L p F P
0 g
s
.99 .861 .614 r
.44969 .70173 m .45234 .70802 L p .44556 .71258 L F P
0 g
s
.672 .679 .848 r
.49901 .42369 m .47734 .43265 L .48337 .44217 L p F P
0 g
s
.672 .679 .848 r
.48337 .44217 m .50499 .43328 L .49901 .42369 L p F P
0 g
s
.812 .741 .785 r
.72479 .34979 m .73279 .35608 L .71938 .37024 L p F P
0 g
s
.773 .698 .779 r
.4356 .90686 m .43119 .89995 L .42639 .90437 L closepath p F P
0 g
s
.777 .666 .74 r
.45387 .87625 m .45305 .87463 L .45201 .87581 L closepath p F P
0 g
s
.819 .873 .885 r
.30447 .676 m .30471 .67731 L p .2828 .68609 L F P
0 g
s
.802 .86 .893 r
.30447 .676 m .30564 .67662 L .30471 .67731 L closepath p F P
0 g
s
.793 .861 .9 r
.30564 .67662 m .32707 .66117 L p .30369 .66941 L F P
0 g
s
.793 .861 .9 r
.30369 .66941 m .30447 .676 L .30564 .67662 L p F P
0 g
s
.821 .689 .718 r
.4469 .84153 m .45826 .84554 L .44979 .85861 L p F P
0 g
s
.816 .669 .7 r
.45826 .84554 m .4469 .84153 L .45445 .82873 L p F P
0 g
s
.499 .408 .684 r
.59675 .79869 m .59506 .79143 L .60355 .79482 L closepath p F P
0 g
s
.4 .473 .82 r
.79946 .72303 m .81462 .72952 L .81125 .73763 L p F P
0 g
s
.38 .477 .833 r
.80229 .71499 m .79946 .72303 L .81462 .72952 L p F P
0 g
s
.418 .508 .844 r
.79273 .7118 m .80229 .71499 L .79946 .72303 L p F P
0 g
s
.534 .467 .726 r
.30427 .32181 m .30959 .32168 L p .31226 .3017 L F P
0 g
s
.529 .462 .725 r
.30427 .32181 m .30959 .32168 L .30521 .325 L closepath p F P
0 g
s
.285 0 .072 r
.39452 .18051 m .39516 .17934 L .37349 .18734 L p F P
0 g
s
.285 0 .072 r
.37349 .18734 m .37345 .18741 L .39452 .18051 L p F P
0 g
s
.872 .547 .433 r
.72482 .22846 m .72029 .2259 L .7202 .21791 L p F P
0 g
s
.862 .538 .438 r
.71298 .2141 m .7202 .21791 L .72029 .2259 L p F P
0 g
s
.194 .122 .542 r
.83677 .84527 m .84083 .84049 L .83844 .83006 L p F P
0 g
s
.167 .105 .537 r
.845 .82167 m .83844 .83006 L .84083 .84049 L p F P
0 g
s
.231 .191 .605 r
.83844 .83006 m .845 .82167 L .84062 .81179 L p F P
0 g
s
.641 .641 .835 r
.43751 .40972 m .41613 .41692 L .4223 .42763 L p F P
0 g
s
.641 .641 .835 r
.4223 .42763 m .44365 .42051 L .43751 .40972 L p F P
0 g
s
.642 .644 .837 r
.44754 .42727 m .44365 .42051 L .4223 .42763 L p F P
0 g
s
.315 .354 .743 r
.83216 .76058 m .82759 .76882 L .83741 .77704 L p F P
0 g
s
.347 .395 .769 r
.82759 .76882 m .83216 .76058 L .82061 .7529 L p F P
0 g
s
.78 .737 .814 r
.69235 .39464 m .68411 .4015 L .67521 .39561 L p F P
0 g
s
.195 0 0 r
.57904 .15872 m .56257 .1566 L .55995 .15632 L p F P
0 g
s
.078 .623 .841 r
.58428 .15932 m .57904 .15872 L .56257 .1566 L p F P
0 g
s
.078 .623 .841 r
.58835 .15942 m .58428 .15932 L p .56257 .1566 L F P
0 g
s
.332 0 .152 r
.39242 .18519 m .39452 .18051 L .37345 .18741 L p F P
0 g
s
.332 0 .152 r
.37345 .18741 m .37069 .19324 L .39242 .18519 L p F P
0 g
s
0 0 .459 r
.60268 .68383 m .60022 .69225 L .60358 .70167 L p F P
0 g
s
.779 .67 .742 r
.45201 .87581 m .45305 .87463 L .44702 .86287 L p F P
0 g
s
.117 .017 .454 r
.84083 .84049 m .83677 .84527 L .83747 .85577 L p F P
0 g
s
.178 .061 .472 r
.83323 .8601 m .83747 .85577 L .83677 .84527 L p F P
0 g
s
.859 .691 .673 r
.45711 .80038 m .45756 .79933 L .45625 .79866 L closepath p F P
0 g
s
.86 .69 .671 r
.45109 .78814 m .45326 .78262 L p .45756 .79933 L F P
0 g
s
.86 .69 .671 r
.45756 .79933 m .45625 .79866 L .45109 .78814 L p F P
0 g
s
.391 .087 .325 r
.36894 .20049 m .37069 .19324 L .35012 .20241 L p F P
0 g
s
.391 .087 .325 r
.35012 .20241 m .3483 .20967 L .36894 .20049 L p F P
0 g
s
0 0 .126 r
.45239 .66157 m .45496 .65271 L .45406 .66319 L p F P
0 g
s
0 0 .126 r
.45406 .66319 m .4518 .67192 L .45239 .66157 L p F P
0 g
s
.807 .697 .743 r
.4395 .8722 m .45201 .87581 L .43972 .88994 L p F P
0 g
s
.779 .67 .742 r
.44702 .86287 m .4395 .8722 L .45201 .87581 L p F P
0 g
s
.724 .72 .846 r
.59372 .4372 m .60847 .4288 L .59541 .42434 L p F P
0 g
s
.724 .72 .846 r
.59541 .42434 m .58805 .42854 L .59372 .4372 L p F P
0 g
s
.62 .582 .789 r
.63626 .9215 m .63545 .92167 L .63624 .92144 L closepath p F P
0 g
s
.619 .58 .788 r
.63055 .90869 m .63624 .92144 L .63545 .92167 L p F P
0 g
s
.195 0 0 r
.55826 .1566 m .57904 .15872 L p .55995 .15632 L F P
0 g
s
0 .571 .732 r
.53974 .15536 m .55995 .15632 L .55499 .15594 L closepath p F P
0 g
s
.195 0 0 r
.55995 .15632 m .55499 .15594 L .55826 .1566 L p F P
0 g
s
.983 .772 .541 r
.21387 .8298 m .20964 .82447 L .20769 .83555 L p F P
0 g
s
.983 .772 .541 r
.20769 .83555 m .20989 .8383 L .21387 .8298 L p F P
0 g
s
.782 .739 .813 r
.69235 .39464 m .70333 .38532 L .69484 .37925 L p F P
0 g
s
.782 .739 .813 r
.69484 .37925 m .687 .38585 L .69235 .39464 L p F P
0 g
s
.78 .737 .814 r
.67521 .39561 m .687 .38585 L .69235 .39464 L p F P
0 g
s
.834 .685 .697 r
.45082 .81185 m .45711 .80038 L .45625 .79866 L p F P
0 g
s
.916 .516 .158 r
.23226 .88764 m .23298 .88972 L .22699 .88416 L p F P
0 g
s
.916 .516 .158 r
.22699 .88416 m .22547 .87954 L .23226 .88764 L p F P
0 g
s
.936 .563 .242 r
.22418 .87428 m .22547 .87954 L .23226 .88764 L p F P
0 g
s
.459 .58 .887 r
.75337 .67737 m .74796 .67653 L .74903 .66995 L closepath p F P
0 g
s
.489 .603 .892 r
.74815 .6685 m .74903 .66995 L .74796 .67653 L p F P
0 g
s
.601 .609 .832 r
.63626 .9215 m .65863 .91855 L .66423 .92925 L p F P
0 g
s
.597 .57 .794 r
.65648 .91393 m .65863 .91855 L .63626 .9215 L p F P
0 g
s
.597 .57 .794 r
.63626 .9215 m .63624 .92144 L .65648 .91393 L p F P
0 g
s
.591 .569 .797 r
.65296 .90648 m .65648 .91393 L .63624 .92144 L p F P
0 g
s
.591 .569 .797 r
.63624 .92144 m .63055 .90869 L .65296 .90648 L p F P
0 g
s
.782 .321 .151 r
.68287 .18981 m .68679 .19532 L .68061 .19269 L closepath p F P
0 g
s
.736 .246 .074 r
.68287 .18981 m .68061 .19269 L p .66845 .18347 L F P
0 g
s
.812 .741 .785 r
.71938 .37024 m .7112 .36403 L .72479 .34979 L p F P
0 g
s
.797 .741 .801 r
.7141 .37523 m .71938 .37024 L .7112 .36403 L p F P
0 g
s
.621 .614 .823 r
.40375 .39416 m .38256 .40032 L .38878 .41191 L p F P
0 g
s
.621 .614 .823 r
.38878 .41191 m .40994 .4059 L .40375 .39416 L p F P
0 g
s
.621 .618 .826 r
.41119 .40824 m .40994 .4059 L .38878 .41191 L p F P
0 g
s
.382 .436 .793 r
.81125 .73763 m .82456 .74473 L .82061 .7529 L p F P
0 g
s
.359 .439 .807 r
.81462 .72952 m .81125 .73763 L .82456 .74473 L p F P
0 g
s
.604 .693 .906 r
.66975 .93861 m .69226 .93501 L .69761 .94229 L p F P
0 g
s
.596 .632 .857 r
.68693 .9267 m .69226 .93501 L .66975 .93861 L p F P
0 g
s
.596 .632 .857 r
.66975 .93861 m .66796 .93554 L .68693 .9267 L p F P
0 g
s
.685 .69 .848 r
.52678 .42343 m .50499 .43328 L .51094 .44257 L p F P
0 g
s
.685 .69 .848 r
.51094 .44257 m .53268 .43281 L .52678 .42343 L p F P
0 g
s
.086 0 .354 r
.83747 .85577 m .83323 .8601 L .83076 .87185 L p F P
0 g
s
.797 .741 .801 r
.7112 .36403 m .70881 .36627 L .7141 .37523 L p F P
0 g
s
.796 .739 .8 r
.69484 .37925 m .70881 .36627 L .7141 .37523 L p F P
0 g
s
.796 .739 .8 r
.7141 .37523 m .70333 .38532 L .69484 .37925 L p F P
0 g
s
.338 .398 .777 r
.82456 .74473 m .82061 .7529 L .83216 .76058 L p F P
0 g
s
.872 .699 .665 r
.75139 .29357 m .7429 .28726 L .74757 .27629 L p F P
0 g
s
.854 .707 .699 r
.74614 .30342 m .75139 .29357 L .7429 .28726 L p F P
0 g
s
.862 .716 .699 r
.75139 .29357 m .74614 .30342 L .74783 .30709 L p F P
0 g
s
.279 .232 .625 r
.6022 .72012 m .60046 .72226 L .60286 .73496 L p F P
0 g
s
.719 .752 .878 r
.38816 .93661 m .38784 .93627 L .38753 .93643 L closepath p F P
0 g
s
.559 .521 .769 r
.32167 .35476 m .33386 .34539 L p .31276 .33933 L F P
0 g
s
.569 .542 .784 r
.33386 .34539 m .33682 .35245 L .32167 .35476 L closepath p F P
0 g
s
.569 .545 .788 r
.34162 .3639 m .33682 .35245 L .32167 .35476 L p F P
0 g
s
.569 .545 .788 r
.33635 .36802 m .34162 .3639 L p .32167 .35476 L F P
0 g
s
.033 0 0 r
.52723 .15478 m .51389 .15533 L .50329 .15566 L p F P
0 g
s
.086 .644 .777 r
.51389 .15533 m .53092 .15503 L .52723 .15478 L closepath p F P
0 g
s
.033 0 0 r
.52489 .15536 m .52723 .15478 L p .50329 .15566 L F P
0 g
s
.033 0 0 r
.5078 .15588 m .52489 .15536 L p .50329 .15566 L F P
0 g
s
.033 0 0 r
.50329 .15566 m .49951 .15566 L .5078 .15588 L p F P
0 g
s
.904 .879 .8 r
.24031 .7387 m .24124 .73749 L .23832 .73039 L p F P
0 g
s
.998 .785 .438 r
.59736 .63876 m .60092 .64559 L .59944 .6563 L p F P
0 g
s
.958 .845 .689 r
.59766 .63788 m .59736 .63876 L .60092 .64559 L p F P
0 g
s
.547 .495 .749 r
.31276 .33933 m .32738 .32827 L p .30959 .32168 L F P
0 g
s
.559 .518 .766 r
.32738 .32827 m .33071 .33704 L .31276 .33933 L closepath p F P
0 g
s
.559 .521 .769 r
.33386 .34539 m .33071 .33704 L .31276 .33933 L p F P
0 g
s
.499 .409 .685 r
.59993 .8123 m .59675 .79869 L .60355 .79482 L p F P
0 g
s
.834 .685 .697 r
.45625 .79866 m .44768 .79478 L p .45082 .81185 L F P
0 g
s
.841 .685 .69 r
.45625 .79866 m .45109 .78814 L .44768 .79478 L closepath p F P
0 g
s
.736 .754 .867 r
.36005 .94174 m .37611 .93265 L .38753 .93643 L p F P
0 g
s
.72 .753 .879 r
.38146 .92973 m .37611 .93265 L .38753 .93643 L p F P
0 g
s
.72 .753 .879 r
.38753 .93643 m .38784 .93627 L .38146 .92973 L p F P
0 g
s
.904 .879 .8 r
.23832 .73039 m .2329 .73726 L .24031 .7387 L p F P
0 g
s
.902 .878 .802 r
.24031 .7387 m .23093 .75085 L .22771 .74387 L p F P
0 g
s
.902 .878 .802 r
.22771 .74387 m .2329 .73726 L .24031 .7387 L p F P
0 g
s
.526 .75 .978 r
.30503 .94084 m .32572 .93867 L .33239 .94369 L p F P
0 g
s
.539 .753 .975 r
.32572 .93867 m .30503 .94084 L .29824 .93615 L p F P
0 g
s
.711 .71 .847 r
.56615 .4401 m .58805 .42854 L p .581 .42029 L F P
0 g
s
.711 .71 .847 r
.581 .42029 m .56038 .43123 L .56615 .4401 L p F P
0 g
s
.771 .73 .815 r
.40942 .92047 m .38784 .93627 L .38146 .92973 L p F P
0 g
s
.093 0 0 r
.55499 .15594 m .53974 .15536 L .53092 .15503 L p F P
0 g
s
.709 .776 .904 r
.61955 .62067 m .61444 .62329 L .6183 .63007 L p F P
0 g
s
.709 .776 .904 r
.6183 .63007 m .62508 .62696 L .61955 .62067 L p F P
0 g
s
.821 .827 .853 r
.59766 .63788 m .61444 .62329 L .6183 .63007 L p F P
0 g
s
.814 .874 .89 r
.29869 .67331 m .30369 .66941 L .30447 .676 L closepath p F P
0 g
s
.819 .873 .885 r
.2828 .68609 m .29869 .67331 L .30447 .676 L p F P
0 g
s
.698 .7 .848 r
.55456 .42206 m .53268 .43281 L .53854 .44188 L p F P
0 g
s
.698 .7 .848 r
.53854 .44188 m .56038 .43123 L .55456 .42206 L p F P
0 g
s
.845 .725 .73 r
.74561 .32358 m .73738 .31727 L .74526 .30509 L p F P
0 g
s
.835 .729 .747 r
.73738 .31727 m .74561 .32358 L .73621 .33632 L p F P
0 g
s
.093 0 0 r
.55381 .15621 m .55499 .15594 L p .53092 .15503 L F P
0 g
s
.093 0 0 r
.53471 .15557 m .55381 .15621 L p .53092 .15503 L F P
0 g
s
.093 0 0 r
.53092 .15503 m .52723 .15478 L .53471 .15557 L p F P
0 g
s
.953 .847 .699 r
.21878 .78291 m .21481 .7763 L .20892 .78843 L p F P
0 g
s
.953 .847 .699 r
.20892 .78843 m .21297 .79499 L .21878 .78291 L p F P
0 g
s
.947 .779 .642 r
.45051 .73696 m .44513 .73087 L .4412 .74246 L p F P
0 g
s
.947 .779 .642 r
.4412 .74246 m .4467 .7485 L .45051 .73696 L p F P
0 g
s
.462 .377 .674 r
.6083 .76112 m .5987 .76758 L .61064 .77491 L p F P
0 g
s
.482 .368 .647 r
.6054 .74784 m .6083 .76112 L .5987 .76758 L p F P
0 g
s
.018 0 0 r
.42266 .16822 m .42799 .16713 L .42201 .16854 L closepath p F P
0 g
s
.831 .445 .32 r
.68679 .19532 m .69859 .20074 L .70166 .20855 L p F P
0 g
s
.84 .448 .307 r
.71298 .2141 m .70166 .20855 L .69859 .20074 L p F P
0 g
s
.841 .694 .7 r
.44396 .82444 m .45445 .82873 L .4469 .84153 L p F P
0 g
s
.831 .68 .695 r
.45445 .82873 m .44396 .82444 L .45082 .81185 L p F P
0 g
s
.53 .567 .836 r
.45311 .62974 m .43835 .62956 L .44748 .61902 L closepath p F P
0 g
s
.402 .431 .775 r
.43835 .62956 m .45311 .62974 L .45573 .63779 L p F P
0 g
s
.497 .394 .667 r
.31188 .27147 m .31322 .27824 L .30398 .27722 L closepath p F P
0 g
s
.495 .393 .668 r
.31435 .28407 m .31322 .27824 L .30398 .27722 L p F P
0 g
s
.807 .696 .742 r
.43972 .88994 m .43119 .89995 L .42503 .89056 L p F P
0 g
s
.807 .696 .742 r
.42503 .89056 m .42862 .88598 L .43972 .88994 L p F P
0 g
s
.807 .697 .743 r
.43972 .88994 m .42862 .88598 L .4395 .8722 L p F P
0 g
s
.633 .083 0 r
.64947 .17469 m .65489 .17865 L .64651 .17589 L closepath p F P
0 g
s
.488 0 0 r
.64947 .17469 m .64651 .17589 L p .63114 .16897 L F P
0 g
s
.252 0 0 r
.58835 .15942 m .59773 .16164 L .58428 .15932 L closepath p F P
0 g
s
.888 .713 .659 r
.45326 .78262 m .45109 .78814 L .44498 .77825 L p F P
0 g
s
.888 .713 .659 r
.44498 .77825 m .44528 .77746 L .45326 .78262 L p F P
0 g
s
.889 .712 .655 r
.45326 .78262 m .44528 .77746 L .44955 .76571 L p F P
0 g
s
.729 .836 .931 r
.39132 .62376 m .36987 .63482 L .37645 .63927 L p F P
0 g
s
.729 .836 .931 r
.37645 .63927 m .39782 .62831 L .39132 .62376 L p F P
0 g
s
.746 .84 .922 r
.36269 .63885 m .36987 .63482 L .37645 .63927 L p F P
0 g
s
.802 .332 0 r
.23298 .88972 m .22699 .88416 L .23237 .89343 L p F P
0 g
s
.802 .332 0 r
.23237 .89343 m .23838 .89896 L .23298 .88972 L p F P
0 g
s
.979 .809 .604 r
.21291 .81307 m .20843 .80673 L .20514 .81816 L p F P
0 g
s
.979 .809 .604 r
.20514 .81816 m .20964 .82447 L .21291 .81307 L p F P
0 g
s
.592 .571 .799 r
.34919 .38033 m .35995 .37802 L .35091 .38405 L closepath p F P
0 g
s
.749 .73 .834 r
.64315 .41891 m .65119 .41346 L .64089 .40804 L p F P
0 g
s
.749 .73 .834 r
.64089 .40804 m .63764 .41023 L .64315 .41891 L p F P
0 g
s
.939 .569 .225 r
.22547 .87954 m .22418 .87428 L .21842 .86858 L p F P
0 g
s
.497 .633 .913 r
.7231 .65818 m .71969 .65803 L .71442 .65015 L p F P
0 g
s
.596 .634 .859 r
.68681 .92651 m .68693 .9267 L .66796 .93554 L p F P
0 g
s
.596 .634 .859 r
.66796 .93554 m .66423 .92925 L .68681 .92651 L p F P
0 g
s
.043 .508 .887 r
.27137 .92622 m .283 .92974 L .29046 .93467 L p F P
0 g
s
.092 .528 .907 r
.283 .92974 m .27137 .92622 L .26446 .92127 L p F P
0 g
s
.789 .87 .908 r
.32978 .65106 m .32022 .65761 L .32707 .66117 L p F P
0 g
s
.789 .87 .908 r
.32707 .66117 m .32965 .65939 L .32978 .65106 L p F P
0 g
s
.793 .861 .9 r
.32707 .66117 m .32022 .65761 L .30369 .66941 L p F P
0 g
s
.696 .79 .923 r
.42559 .62441 m .41414 .62901 L .41603 .62011 L p F P
0 g
s
.862 .716 .699 r
.74614 .30342 m .74526 .30509 L .74783 .30709 L closepath p F P
0 g
s
.991 .841 .474 r
.45162 .69014 m .44992 .68273 L .44728 .69383 L p F P
0 g
s
.991 .841 .474 r
.44728 .69383 m .44933 .70111 L .45162 .69014 L p F P
0 g
s
.877 .675 .626 r
.74757 .27629 m .73862 .27008 L .7419 .25966 L p F P
0 g
s
.858 .685 .666 r
.7429 .28726 m .74757 .27629 L .73862 .27008 L p F P
0 g
s
.564 0 0 r
.6403 .17419 m .63114 .16897 L .6165 .16508 L p F P
0 g
s
.488 0 0 r
.64651 .17589 m .6403 .17419 L .63114 .16897 L p F P
0 g
s
.77 .86 .916 r
.34846 .64742 m .32965 .65939 L .32978 .65106 L p F P
0 g
s
.821 .689 .718 r
.44702 .86287 m .44979 .85861 L .44337 .8561 L closepath p F P
0 g
s
.821 .689 .718 r
.44094 .85161 m .4469 .84153 L p .44979 .85861 L F P
0 g
s
.821 .689 .718 r
.44979 .85861 m .44337 .8561 L .44094 .85161 L p F P
0 g
s
.578 .563 .801 r
.34162 .3639 m .34299 .36687 L .33635 .36802 L closepath p F P
0 g
s
.579 .567 .805 r
.34919 .38033 m .34299 .36687 L .33635 .36802 L p F P
0 g
s
.522 .666 .927 r
.69052 .64206 m .68623 .64216 L .68088 .63487 L p F P
0 g
s
.602 .739 .941 r
.63513 .62493 m .62508 .62696 L .61955 .62067 L p F P
0 g
s
.776 .702 .782 r
.42639 .90437 m .43119 .89995 L .42503 .89056 L p F P
0 g
s
.776 .702 .782 r
.42503 .89056 m .41505 .9005 L .42639 .90437 L p F P
0 g
s
.799 .737 .795 r
.41505 .9005 m .42639 .90437 L .41043 .9195 L p F P
0 g
s
.658 .663 .844 r
.44754 .42727 m .44976 .43091 L .47129 .42284 L p F P
0 g
s
.592 .567 .795 r
.36391 .36211 m .34299 .36687 L .34919 .38033 L p F P
0 g
s
.592 .567 .795 r
.36856 .37239 m .36391 .36211 L p .34919 .38033 L F P
0 g
s
.592 .567 .795 r
.34919 .38033 m .35995 .37802 L .36856 .37239 L p F P
0 g
s
.221 0 0 r
.44196 .16696 m .418 .17255 L .42201 .16854 L p F P
0 g
s
.221 0 0 r
.44389 .16474 m .44196 .16696 L p .42201 .16854 L F P
0 g
s
.221 0 0 r
.42201 .16854 m .42799 .16713 L .44389 .16474 L p F P
0 g
s
.585 .059 0 r
.24476 .90434 m .23838 .89896 L .24671 .90751 L p F P
0 g
s
.585 .059 0 r
.24671 .90751 m .25313 .91287 L .24476 .90434 L p F P
0 g
s
.527 .429 .686 r
.59993 .8123 m .61808 .80224 L p .61453 .82054 L F P
0 g
s
.527 .429 .686 r
.61453 .82054 m .60111 .81728 L .59993 .8123 L p F P
0 g
s
.499 .409 .685 r
.61756 .80028 m .61808 .80224 L .59993 .8123 L p F P
0 g
s
.499 .409 .685 r
.60355 .79482 m .61756 .80028 L p .59993 .8123 L F P
0 g
s
.576 .92 .962 r
.76678 .93252 m .75286 .93861 L .74798 .93607 L p F P
0 g
s
.592 .878 .993 r
.72537 .94273 m .74798 .93607 L .75286 .93861 L p F P
0 g
s
.534 .467 .726 r
.30959 .32168 m .32204 .31241 L p .31226 .3017 L F P
0 g
s
.548 .493 .746 r
.32204 .31241 m .32468 .32021 L .30959 .32168 L closepath p F P
0 g
s
.547 .495 .749 r
.32738 .32827 m .32468 .32021 L .30959 .32168 L p F P
0 g
s
.748 .766 .867 r
.37611 .93265 m .36005 .94174 L .35352 .93613 L p F P
0 g
s
.673 .773 .925 r
.33239 .94369 m .35352 .93613 L .36005 .94174 L p F P
0 g
s
.971 .658 .35 r
.2175 .85823 m .2121 .85235 L p .21687 .86691 L F P
0 g
s
.971 .658 .35 r
.21687 .86691 m .21842 .86858 L .2175 .85823 L p F P
0 g
s
.405 .505 .848 r
.80229 .71499 m .79273 .7118 L .78747 .7012 L p F P
0 g
s
.922 .873 .772 r
.23093 .75085 m .22771 .74387 L .21881 .75687 L p F P
0 g
s
.922 .873 .772 r
.21881 .75687 m .22216 .76377 L .23093 .75085 L p F P
0 g
s
.799 .737 .795 r
.40942 .92047 m .41043 .9195 L .40771 .91835 L closepath p F P
0 g
s
.799 .737 .795 r
.40315 .91271 m .41505 .9005 L p .41043 .9195 L F P
0 g
s
.799 .737 .795 r
.41043 .9195 m .40771 .91835 L .40315 .91271 L p F P
0 g
s
.771 .73 .815 r
.40771 .91835 m .40942 .92047 L p .38146 .92973 L F P
0 g
s
.279 .232 .625 r
.60286 .73496 m .60764 .72907 L .6022 .72012 L p F P
0 g
s
.109 .122 .591 r
.60749 .71102 m .6022 .72012 L .60764 .72907 L p F P
0 g
s
.288 .227 .613 r
.60358 .70167 m .60749 .71102 L .6022 .72012 L p F P
0 g
s
.731 .715 .836 r
.61565 .42444 m .60847 .4288 L .59541 .42434 L p F P
0 g
s
.759 .727 .823 r
.66509 .40325 m .65119 .41346 L .64089 .40804 L p F P
0 g
s
.749 .281 .136 r
.65489 .17865 m .66845 .18347 L .67404 .19022 L p F P
0 g
s
.736 .246 .074 r
.68061 .19269 m .67404 .19022 L .66845 .18347 L p F P
0 g
s
.104 .065 .524 r
.45223 .64343 m .45573 .63779 L .45691 .64941 L p F P
0 g
s
.104 .065 .524 r
.45691 .64941 m .45496 .65271 L .45223 .64343 L p F P
0 g
s
.852 .53 .442 r
.70166 .20855 m .71298 .2141 L .7142 .22269 L p F P
0 g
s
.862 .538 .438 r
.72029 .2259 m .7142 .22269 L .71298 .2141 L p F P
0 g
s
.683 .777 .922 r
.35352 .93613 m .33239 .94369 L .32572 .93867 L p F P
0 g
s
.605 .773 .961 r
.69761 .94229 m .72022 .93767 L .72537 .94273 L p F P
0 g
s
.596 .724 .933 r
.72022 .93767 m .69761 .94229 L .69226 .93501 L p F P
0 g
s
.235 .62 .956 r
.29046 .93467 m .29824 .93615 L .29141 .93126 L p F P
0 g
s
.235 .62 .956 r
.29141 .93126 m .283 .92974 L .29046 .93467 L p F P
0 g
s
.582 .542 .776 r
.64822 .89533 m .65296 .90648 L .63055 .90869 L p F P
0 g
s
.582 .542 .776 r
.63055 .90869 m .62844 .90339 L .64822 .89533 L p F P
0 g
s
.471 .312 .583 r
.31028 .25989 m .3286 .24851 L p .3182 .24388 L F P
0 g
s
.502 .367 .629 r
.33024 .26012 m .3286 .24851 L .31028 .25989 L p F P
0 g
s
.502 .367 .629 r
.31028 .25989 m .31188 .27147 L .33024 .26012 L p F P
0 g
s
.796 .682 .739 r
.4395 .8722 m .44702 .86287 L .44337 .8561 L p F P
0 g
s
0 0 0 r
.81937 .89359 m .82531 .8844 L .82099 .88854 L closepath p F P
0 g
s
0 0 .203 r
.82099 .88854 m .82531 .8844 L .83076 .87185 L p F P
0 g
s
.457 .572 .882 r
.75337 .67737 m .77073 .68047 L .76936 .68834 L p F P
0 g
s
.447 .573 .887 r
.77073 .68047 m .75337 .67737 L .74903 .66995 L p F P
0 g
s
.856 .707 .696 r
.4413 .80721 m .45082 .81185 L .44396 .82444 L p F P
0 g
s
.834 .685 .697 r
.44768 .79478 m .4413 .80721 L .45082 .81185 L p F P
0 g
s
.209 .181 .605 r
.84614 .804 m .84062 .81179 L .845 .82167 L p F P
0 g
s
.268 .26 .665 r
.8457 .80227 m .84025 .79411 L p .84062 .81179 L F P
0 g
s
.268 .26 .665 r
.84062 .81179 m .84614 .804 L .8457 .80227 L p F P
0 g
s
.879 .644 .578 r
.7419 .25966 m .73247 .25355 L .73433 .2437 L p F P
0 g
s
.862 .66 .628 r
.73862 .27008 m .7419 .25966 L .73247 .25355 L p F P
0 g
s
.835 .729 .747 r
.73621 .33632 m .72783 .33007 L .73738 .31727 L p F P
0 g
s
.819 .731 .767 r
.73038 .34319 m .73621 .33632 L .72783 .33007 L p F P
0 g
s
.854 .707 .699 r
.7429 .28726 m .74072 .29123 L .74614 .30342 L p F P
0 g
s
.855 .705 .696 r
.73655 .29886 m .74072 .29123 L .74614 .30342 L p F P
0 g
s
.855 .705 .696 r
.74614 .30342 m .74526 .30509 L .73655 .29886 L p F P
0 g
s
.914 .745 .658 r
.44269 .76015 m .44955 .76571 L .44528 .77746 L p F P
0 g
s
.915 .74 .65 r
.44955 .76571 m .44269 .76015 L .4467 .7485 L p F P
0 g
s
.522 .439 .704 r
.60349 .8263 m .60111 .81728 L .61453 .82054 L closepath p F P
0 g
s
.862 .715 .698 r
.44768 .79478 m .45109 .78814 L .44498 .77825 L p F P
0 g
s
.367 .298 .647 r
.60286 .73496 m .60764 .72907 L p .60552 .74771 L F P
0 g
s
.367 .298 .647 r
.60552 .74771 m .60532 .74746 L .60286 .73496 L p F P
0 g
s
.467 .608 .908 r
.7231 .65818 m .74293 .6602 L .7377 .65211 L p F P
0 g
s
.467 .608 .908 r
.7377 .65211 m .72289 .65056 L .7231 .65818 L p F P
0 g
s
.497 .633 .913 r
.71442 .65015 m .72289 .65056 L .7231 .65818 L p F P
0 g
s
.431 .239 .517 r
.3182 .24388 m .32783 .23794 L .32789 .2284 L p F P
0 g
s
.473 .311 .581 r
.32783 .23794 m .32855 .24781 L .3182 .24388 L closepath p F P
0 g
s
.471 .312 .583 r
.3286 .24851 m .32855 .24781 L .3182 .24388 L p F P
0 g
s
.983 .838 .621 r
.44885 .71938 m .44556 .71258 L .44149 .72419 L p F P
0 g
s
.983 .838 .621 r
.44149 .72419 m .44513 .73087 L .44885 .71938 L p F P
0 g
s
.182 0 0 r
.42799 .16713 m .44595 .1631 L .44389 .16474 L closepath p F P
0 g
s
.868 .594 .52 r
.72029 .2259 m .72482 .22846 L .72442 .23772 L p F P
0 g
s
.879 .603 .516 r
.73433 .2437 m .72442 .23772 L .72482 .22846 L p F P
0 g
s
.581 .544 .778 r
.64721 .89299 m .64822 .89533 L .62844 .90339 L p F P
0 g
s
.581 .544 .778 r
.62844 .90339 m .62478 .89431 L .64721 .89299 L p F P
0 g
s
.471 .27 .525 r
.3474 .22768 m .34741 .21813 L .32789 .2284 L p F P
0 g
s
.471 .27 .525 r
.32789 .2284 m .32783 .23794 L .3474 .22768 L p F P
0 g
s
.841 .714 .724 r
.73655 .29886 m .74526 .30509 L .73738 .31727 L p F P
0 g
s
.863 .629 .583 r
.73247 .25355 m .73433 .2437 L .72442 .23772 L p F P
0 g
s
.603 .823 .984 r
.74798 .93607 m .72537 .94273 L .72022 .93767 L p F P
0 g
s
.437 .547 .87 r
.78227 .69154 m .76936 .68834 L p .78744 .70118 L F P
0 g
s
.418 .539 .872 r
.76936 .68834 m .78227 .69154 L .77706 .68209 L p F P
0 g
s
.418 .539 .872 r
.77706 .68209 m .77073 .68047 L .76936 .68834 L p F P
0 g
s
.738 .718 .832 r
.61565 .42444 m .63764 .41023 L p .62942 .40297 L F P
0 g
s
.738 .718 .832 r
.62942 .40297 m .61003 .41542 L .61565 .42444 L p F P
0 g
s
.731 .715 .836 r
.59541 .42434 m .61003 .41542 L .61565 .42444 L p F P
0 g
s
.819 .731 .767 r
.72783 .33007 m .72508 .33328 L .73038 .34319 L p F P
0 g
s
.819 .729 .765 r
.71617 .34364 m .72508 .33328 L .73038 .34319 L p F P
0 g
s
.819 .729 .765 r
.73038 .34319 m .72479 .34979 L .71617 .34364 L p F P
0 g
s
.641 .639 .833 r
.41119 .40824 m .41613 .41692 L .43751 .40972 L p F P
0 g
s
.543 .453 .703 r
.60349 .8263 m .61453 .82054 L p .60805 .84015 L F P
0 g
s
.543 .453 .703 r
.60805 .84015 m .60711 .84002 L .60349 .8263 L p F P
0 g
s
.985 .727 .452 r
.21265 .84164 m .20989 .8383 L .21042 .85036 L p F P
0 g
s
.985 .727 .452 r
.21042 .85036 m .2121 .85235 L .21265 .84164 L p F P
0 g
s
.771 .73 .815 r
.38146 .92973 m .39938 .91558 L .40771 .91835 L p F P
0 g
s
.767 .732 .821 r
.40771 .91835 m .40315 .91271 L .39938 .91558 L closepath p F P
0 g
s
.763 .731 .823 r
.66509 .40325 m .67521 .39561 L .66555 .38992 L p F P
0 g
s
.763 .731 .823 r
.66555 .38992 m .65963 .39436 L .66509 .40325 L p F P
0 g
s
.759 .727 .823 r
.64089 .40804 m .65963 .39436 L .66509 .40325 L p F P
0 g
s
.656 .65 .833 r
.44365 .42051 m .44754 .42727 L .46997 .42066 L p F P
0 g
s
.658 .663 .844 r
.47129 .42284 m .46997 .42066 L .44754 .42727 L p F P
0 g
s
.499 .649 .925 r
.69052 .64206 m .70914 .64246 L .70383 .63497 L p F P
0 g
s
.499 .649 .925 r
.70383 .63497 m .68908 .63467 L .69052 .64206 L p F P
0 g
s
.522 .666 .927 r
.68088 .63487 m .68908 .63467 L .69052 .64206 L p F P
0 g
s
.84 .694 .701 r
.4469 .84153 m .44094 .85161 L .43482 .84115 L p F P
0 g
s
.84 .694 .701 r
.43482 .84115 m .43706 .83708 L .4469 .84153 L p F P
0 g
s
.841 .694 .7 r
.4469 .84153 m .43706 .83708 L .44396 .82444 L p F P
0 g
s
.622 .615 .822 r
.37936 .39431 m .38256 .40032 L .40375 .39416 L p F P
0 g
s
.821 .719 .752 r
.42865 .86811 m .4395 .8722 L .42862 .88598 L p F P
0 g
s
.796 .682 .739 r
.43873 .85454 m .42865 .86811 L .4395 .8722 L p F P
0 g
s
.796 .682 .739 r
.44337 .8561 m .43873 .85454 L p .4395 .8722 L F P
0 g
s
.671 .674 .844 r
.47734 .43265 m .49901 .42369 L p .48188 .41844 L F P
0 g
s
.671 .674 .844 r
.48188 .41844 m .47129 .42284 L .47734 .43265 L p F P
0 g
s
0 .171 .626 r
.26446 .92127 m .25989 .91808 L .25313 .91287 L p F P
0 g
s
.544 .685 .931 r
.65287 .62942 m .67551 .62777 L .68088 .63487 L p F P
0 g
s
.542 .692 .937 r
.67551 .62777 m .65287 .62942 L .64742 .62259 L p F P
0 g
s
0 0 .151 r
.83726 .86529 m .83076 .87185 L .82531 .8844 L p F P
0 g
s
.086 0 .354 r
.83076 .87185 m .83726 .86529 L .83747 .85577 L p F P
0 g
s
.582 .62 .855 r
.68681 .92651 m .66423 .92925 L .65863 .91855 L p F P
0 g
s
.97 .837 .655 r
.21297 .79499 m .20892 .78843 L .20432 .80022 L p F P
0 g
s
.97 .837 .655 r
.20432 .80022 m .20843 .80673 L .21297 .79499 L p F P
0 g
s
.804 .729 .781 r
.7112 .36403 m .72479 .34979 L .71617 .34364 L p F P
0 g
s
.568 .517 .758 r
.64146 .87813 m .64721 .89299 L .62478 .89431 L p F P
0 g
s
.568 .517 .758 r
.62478 .89431 m .62199 .88659 L .64146 .87813 L p F P
0 g
s
.496 .413 .692 r
.61756 .80028 m .60355 .79482 L .61461 .7883 L closepath p F P
0 g
s
.507 .4 .668 r
.61146 .7754 m .61461 .7883 L .60355 .79482 L p F P
0 g
s
.507 .4 .668 r
.61064 .77491 m .61146 .7754 L p .60355 .79482 L F P
0 g
s
.775 .729 .81 r
.687 .38585 m .67521 .39561 L .66555 .38992 L p F P
0 g
s
.874 .726 .695 r
.43927 .78976 m .44768 .79478 L .4413 .80721 L p F P
0 g
s
.862 .715 .698 r
.44498 .77825 m .43927 .78976 L .44768 .79478 L p F P
0 g
s
.761 .861 .924 r
.36322 .63062 m .34171 .64352 L .34846 .64742 L p F P
0 g
s
.761 .861 .924 r
.36406 .6311 m .36322 .63062 L p .34846 .64742 L F P
0 g
s
.761 .861 .924 r
.34846 .64742 m .36269 .63885 L .36406 .6311 L p F P
0 g
s
.77 .86 .916 r
.32978 .65106 m .34171 .64352 L .34846 .64742 L p F P
0 g
s
.637 .725 .912 r
.44079 .61116 m .41926 .61872 L .42559 .62441 L p F P
0 g
s
.637 .725 .912 r
.42559 .62441 m .44702 .61836 L .44079 .61116 L p F P
0 g
s
.696 .79 .923 r
.41603 .62011 m .41926 .61872 L .42559 .62441 L p F P
0 g
s
.594 .665 .889 r
.42559 .62441 m .44702 .61836 L .44748 .61902 L p F P
0 g
s
0 0 0 r
.4518 .67192 m .45406 .66319 L .45158 .67422 L p F P
0 g
s
0 0 0 r
.45158 .67422 m .44992 .68273 L .4518 .67192 L p F P
0 g
s
.804 .684 .732 r
.44337 .8561 m .44094 .85161 L .43873 .85454 L closepath p F P
0 g
s
.917 .523 .139 r
.22547 .87954 m .22699 .88416 L .22138 .87844 L p F P
0 g
s
.917 .523 .139 r
.22138 .87844 m .21876 .87005 L .22547 .87954 L p F P
0 g
s
.939 .569 .225 r
.21842 .86858 m .21876 .87005 L .22547 .87954 L p F P
0 g
s
.564 0 0 r
.62449 .17016 m .6403 .17419 L p .6165 .16508 L F P
0 g
s
.564 0 0 r
.6165 .16508 m .61621 .16514 L .62449 .17016 L p F P
0 g
s
.428 0 0 r
.61554 .16489 m .6165 .16508 L .61621 .16514 L closepath p F P
0 g
s
.595 .572 .798 r
.34162 .3639 m .34299 .36687 L .36391 .36211 L p F P
0 g
s
.943 .779 .648 r
.4467 .7485 m .4412 .74246 L .43707 .75417 L p F P
0 g
s
.943 .779 .648 r
.43707 .75417 m .44269 .76015 L .4467 .7485 L p F P
0 g
s
.958 .687 .245 r
.59623 .64939 m .59944 .6563 L .60002 .66646 L p F P
0 g
s
.998 .785 .438 r
.59944 .6563 m .59623 .64939 L .59736 .63876 L p F P
0 g
s
.444 0 0 r
.59773 .16164 m .61554 .16489 L .61621 .16514 L p F P
0 g
s
.937 .872 .748 r
.22216 .76377 m .21881 .75687 L .21131 .76947 L p F P
0 g
s
.937 .872 .748 r
.21733 .772 m .22216 .76377 L p .21131 .76947 L F P
0 g
s
.54 .467 .722 r
.60726 .84054 m .60711 .84002 L .60805 .84015 L closepath p F P
0 g
s
.54 .467 .722 r
.61163 .85537 m .60726 .84054 L .60805 .84015 L p F P
0 g
s
.569 .518 .759 r
.6414 .87799 m .64146 .87813 L .62199 .88659 L p F P
0 g
s
.569 .518 .759 r
.62199 .88659 m .61894 .8782 L .6414 .87799 L p F P
0 g
s
.722 .714 .842 r
.58305 .42072 m .58805 .42854 L .59541 .42434 L closepath p F P
0 g
s
.711 .71 .847 r
.58805 .42854 m .58305 .42072 L .581 .42029 L p F P
0 g
s
.748 .766 .867 r
.35352 .93613 m .3662 .92843 L .37611 .93265 L p F P
0 g
s
.732 .76 .874 r
.37503 .92327 m .3662 .92843 L .37611 .93265 L p F P
0 g
s
.732 .76 .874 r
.37611 .93265 m .38146 .92973 L .37503 .92327 L p F P
0 g
s
.117 .017 .454 r
.83747 .85577 m .84108 .85154 L .84083 .84049 L p F P
0 g
s
.083 0 .442 r
.84741 .83214 m .84083 .84049 L .84108 .85154 L p F P
0 g
s
.167 .105 .537 r
.84083 .84049 m .84741 .83214 L .845 .82167 L p F P
0 g
s
.684 .684 .844 r
.50499 .43328 m .52678 .42343 L p .51961 .41434 L F P
0 g
s
.684 .684 .844 r
.51961 .41434 m .49901 .42369 L .50499 .43328 L p F P
0 g
s
.013 0 .329 r
.84108 .85154 m .83747 .85577 L .83726 .86529 L p F P
0 g
s
.822 .442 .334 r
.68061 .19269 m .68679 .19532 L .6898 .20314 L p F P
0 g
s
.831 .445 .32 r
.70166 .20855 m .6898 .20314 L .68679 .19532 L p F P
0 g
s
.576 .92 .962 r
.77336 .92826 m .76678 .93252 L p .74798 .93607 L F P
0 g
s
.609 .946 .934 r
.76678 .93252 m .77336 .92826 L .77531 .92852 L closepath p F P
0 g
s
.778 .732 .81 r
.687 .38585 m .69484 .37925 L .68566 .37336 L p F P
0 g
s
.778 .732 .81 r
.68566 .37336 m .6816 .37675 L .687 .38585 L p F P
0 g
s
.775 .729 .81 r
.66555 .38992 m .6816 .37675 L .687 .38585 L p F P
0 g
s
.868 .594 .52 r
.72442 .23772 m .72195 .23633 L .72029 .2259 L p F P
0 g
s
.859 .588 .526 r
.7142 .22269 m .72029 .2259 L .72195 .23633 L p F P
0 g
s
.858 .685 .666 r
.73738 .28349 m .7429 .28726 L p .73862 .27008 L F P
0 g
s
.849 .7 .697 r
.73738 .28349 m .74072 .29123 L .7429 .28726 L closepath p F P
0 g
s
.804 .729 .781 r
.70515 .35989 m .7112 .36403 L p .71617 .34364 L F P
0 g
s
.794 .734 .797 r
.70515 .35989 m .70881 .36627 L .7112 .36403 L closepath p F P
0 g
s
.241 .242 .66 r
.8457 .80227 m .84025 .79411 L .84266 .79034 L closepath p F P
0 g
s
.292 .308 .706 r
.83935 .77923 m .83741 .77704 L p .84025 .79411 L F P
0 g
s
.292 .308 .706 r
.84025 .79411 m .84266 .79034 L .83935 .77923 L p F P
0 g
s
.789 .733 .8 r
.70881 .36627 m .69484 .37925 L p .70232 .358 L F P
0 g
s
.789 .733 .8 r
.70232 .358 m .70515 .35989 L .70881 .36627 L p F P
0 g
s
.54 .467 .722 r
.60805 .84015 m .62959 .843 L p .61163 .85537 L F P
0 g
s
.54 .467 .722 r
.62959 .843 m .60805 .84015 L .62614 .83131 L closepath p F P
0 g
s
.543 .453 .703 r
.6236 .82271 m .62614 .83131 L .60805 .84015 L p F P
0 g
s
.543 .453 .703 r
.61453 .82054 m .6236 .82271 L p .60805 .84015 L F P
0 g
s
.592 .045 0 r
.61621 .16514 m .62449 .17016 L .61231 .16727 L closepath p F P
0 g
s
.444 0 0 r
.61621 .16514 m .61231 .16727 L p .59773 .16164 L F P
0 g
s
.586 .55 .781 r
.33682 .35245 m .34162 .3639 L .35952 .35238 L p F P
0 g
s
.595 .572 .798 r
.36391 .36211 m .35952 .35238 L .34162 .3639 L p F P
0 g
s
.789 .733 .8 r
.69484 .37925 m .68566 .37336 L .70232 .358 L p F P
0 g
s
.348 .293 .654 r
.6054 .74784 m .60532 .74746 L .60552 .74771 L closepath p F P
0 g
s
.353 .301 .661 r
.60552 .74771 m .6054 .74784 L .6083 .76112 L p F P
0 g
s
.543 .469 .722 r
.61305 .86019 m .61163 .85537 L .63068 .84636 L p F P
0 g
s
.54 .467 .722 r
.62959 .843 m .63068 .84636 L .61163 .85537 L p F P
0 g
s
.555 .492 .739 r
.63572 .8619 m .6414 .87799 L .61894 .8782 L p F P
0 g
s
.555 .492 .739 r
.61894 .8782 m .61649 .87067 L .63572 .8619 L p F P
0 g
s
.605 .735 .937 r
.63513 .62493 m .64742 .62259 L .64194 .61594 L p F P
0 g
s
.605 .735 .937 r
.64194 .61594 m .63103 .61819 L .63513 .62493 L p F P
0 g
s
.602 .739 .941 r
.61955 .62067 m .63103 .61819 L .63513 .62493 L p F P
0 g
s
.99 .816 .577 r
.44909 .70206 m .44933 .70111 L .44969 .70173 L closepath p F P
0 g
s
.99 .861 .614 r
.44556 .71258 m .44909 .70206 L .44969 .70173 L p F P
0 g
s
.709 .704 .843 r
.56038 .43123 m .581 .42029 L .56357 .41727 L p F P
0 g
s
.709 .704 .843 r
.56357 .41727 m .55456 .42206 L .56038 .43123 L p F P
0 g
s
.368 0 .121 r
.41565 .17739 m .418 .17255 L .39516 .17934 L p F P
0 g
s
.368 0 .121 r
.39516 .17934 m .39452 .18051 L .41565 .17739 L p F P
0 g
s
.697 .694 .843 r
.53268 .43281 m .55456 .42206 L p .54384 .41502 L F P
0 g
s
.697 .694 .843 r
.54384 .41502 m .52678 .42343 L .53268 .43281 L p F P
0 g
s
.555 .493 .741 r
.63553 .86137 m .63572 .8619 L .61649 .87067 L p F P
0 g
s
.555 .493 .741 r
.61649 .87067 m .61305 .86019 L .63553 .86137 L p F P
0 g
s
0 0 .478 r
.60538 .69348 m .60358 .70167 L .60749 .71102 L p F P
0 g
s
0 0 .459 r
.60358 .70167 m .60538 .69348 L .60268 .68383 L p F P
0 g
s
.523 .411 .668 r
.3327 .27271 m .33024 .26012 L .31188 .27147 L p F P
0 g
s
.523 .411 .668 r
.32404 .27804 m .3327 .27271 L p .31188 .27147 L F P
0 g
s
.523 .411 .668 r
.31188 .27147 m .31322 .27824 L .32404 .27804 L p F P
0 g
s
.858 .886 .856 r
.26544 .70164 m .26372 .69399 L .24859 .70889 L p F P
0 g
s
.858 .886 .856 r
.25519 .71187 m .26544 .70164 L p .24859 .70889 L F P
0 g
s
.841 .884 .872 r
.27704 .69117 m .26544 .70164 L .26372 .69399 L p F P
0 g
s
.821 .719 .752 r
.42503 .89056 m .42862 .88598 L .41898 .88175 L closepath p F P
0 g
s
.821 .719 .752 r
.41883 .88154 m .42865 .86811 L p .42862 .88598 L F P
0 g
s
.821 .719 .752 r
.42862 .88598 m .41898 .88175 L .41883 .88154 L p F P
0 g
s
.353 .301 .661 r
.6083 .76112 m .61307 .75621 L .60552 .74771 L p F P
0 g
s
.248 .232 .644 r
.61337 .73803 m .60552 .74771 L .61307 .75621 L p F P
0 g
s
.367 .298 .647 r
.60764 .72907 m .61337 .73803 L .60552 .74771 L p F P
0 g
s
.616 .597 .809 r
.37634 .3882 m .37936 .39431 L .39843 .38404 L p F P
0 g
s
.622 .615 .822 r
.40375 .39416 m .39843 .38404 L .37936 .39431 L p F P
0 g
s
.99 .783 .531 r
.20964 .82447 m .20514 .81816 L .20318 .82927 L p F P
0 g
s
.99 .783 .531 r
.20318 .82927 m .20769 .83555 L .20964 .82447 L p F P
0 g
s
.841 .889 .874 r
.28171 .67819 m .26988 .68851 L .27704 .69117 L p F P
0 g
s
.841 .889 .874 r
.27704 .69117 m .2828 .68609 L .28171 .67819 L p F P
0 g
s
.841 .884 .872 r
.26372 .69399 m .26988 .68851 L .27704 .69117 L p F P
0 g
s
.543 .469 .722 r
.63068 .84636 m .63553 .86137 L .61305 .86019 L p F P
0 g
s
.86 .72 .708 r
.4349 .81969 m .44396 .82444 L .43706 .83708 L p F P
0 g
s
.856 .707 .696 r
.44396 .82444 m .4349 .81969 L .4413 .80721 L p F P
0 g
s
.704 .819 .936 r
.41285 .61371 m .39132 .62376 L .39782 .62831 L p F P
0 g
s
.704 .819 .936 r
.41725 .61709 m .41285 .61371 L p .39782 .62831 L F P
0 g
s
.704 .819 .936 r
.39782 .62831 m .41603 .62011 L .41725 .61709 L p F P
0 g
s
.819 .882 .89 r
.29869 .67331 m .2828 .68609 L .28171 .67819 L p F P
0 g
s
.841 .714 .724 r
.73738 .31727 m .72857 .31109 L .73655 .29886 L p F P
0 g
s
.825 .715 .744 r
.72783 .33007 m .73738 .31727 L .72857 .31109 L p F P
0 g
s
.463 .214 .45 r
.36813 .20896 m .36894 .20049 L .3483 .20967 L p F P
0 g
s
.463 .214 .45 r
.3483 .20967 m .34741 .21813 L .36813 .20896 L p F P
0 g
s
.784 .743 .815 r
.39938 .91558 m .38146 .92973 L .37503 .92327 L p F P
0 g
s
.812 .697 .738 r
.43873 .85454 m .44094 .85161 L .43482 .84115 L p F P
0 g
s
.536 .466 .725 r
.31772 .2977 m .31879 .30131 L .31226 .3017 L closepath p F P
0 g
s
.534 .467 .726 r
.32204 .31241 m .31879 .30131 L .31226 .3017 L p F P
0 g
s
.858 .886 .856 r
.24859 .70889 m .24884 .70987 L .25519 .71187 L p F P
0 g
s
.864 .883 .849 r
.24884 .70987 m .25519 .71187 L .25074 .71636 L closepath p F P
0 g
s
.401 .509 .853 r
.78747 .7012 m .78744 .70118 L .78745 .70115 L closepath p F P
0 g
s
.437 .547 .87 r
.78744 .70118 m .78745 .70115 L .78227 .69154 L p F P
0 g
s
.764 .309 .169 r
.66036 .18542 m .65489 .17865 L .64651 .17589 L p F P
0 g
s
.749 .281 .136 r
.67404 .19022 m .66036 .18542 L .65489 .17865 L p F P
0 g
s
.405 .505 .848 r
.78747 .7012 m .80438 .70707 L .80229 .71499 L p F P
0 g
s
.39 .503 .852 r
.80438 .70707 m .78747 .7012 L .78745 .70115 L p F P
0 g
s
.39 .503 .852 r
.78745 .70115 m .78904 .69332 L p .80438 .70707 L F P
0 g
s
.418 .536 .869 r
.78745 .70115 m .78227 .69154 L .78904 .69332 L closepath p F P
0 g
s
.994 .869 .545 r
.44933 .70111 m .44728 .69383 L .44413 .70514 L p F P
0 g
s
.994 .869 .545 r
.44909 .70206 m .44933 .70111 L p .44413 .70514 L F P
0 g
s
.294 0 0 r
.46709 .16271 m .47099 .15894 L .44595 .1631 L p F P
0 g
s
.294 0 0 r
.45505 .16468 m .46709 .16271 L p .44595 .1631 L F P
0 g
s
.294 0 0 r
.44595 .1631 m .44389 .16474 L .45505 .16468 L p F P
0 g
s
.79 .713 .779 r
.41505 .9005 m .42503 .89056 L .41898 .88175 L p F P
0 g
s
.73 .708 .83 r
.59541 .42434 m .61003 .41542 L p .58233 .41955 L F P
0 g
s
.73 .708 .83 r
.58233 .41955 m .58305 .42072 L .59541 .42434 L p F P
0 g
s
.885 .894 .832 r
.25074 .71636 m .23832 .73039 L .23589 .72305 L p F P
0 g
s
.885 .894 .832 r
.24884 .70987 m .25074 .71636 L p .23589 .72305 L F P
0 g
s
.844 .698 .702 r
.74072 .29123 m .73655 .29886 L p .73379 .28111 L F P
0 g
s
.844 .698 .702 r
.73379 .28111 m .73738 .28349 L .74072 .29123 L p F P
0 g
s
.655 .648 .831 r
.4591 .40146 m .43751 .40972 L .44365 .42051 L p F P
0 g
s
.655 .648 .831 r
.44365 .42051 m .46521 .4123 L .4591 .40146 L p F P
0 g
s
.656 .65 .833 r
.46997 .42066 m .46521 .4123 L .44365 .42051 L p F P
0 g
s
.833 .717 .737 r
.42839 .85025 m .43873 .85454 L .42865 .86811 L p F P
0 g
s
.812 .697 .738 r
.43482 .84115 m .42839 .85025 L .43873 .85454 L p F P
0 g
s
.602 .589 .811 r
.36856 .37239 m .37012 .37557 L .35995 .37802 L closepath p F P
0 g
s
.602 .592 .814 r
.37634 .3882 m .37012 .37557 L .35995 .37802 L p F P
0 g
s
.994 .869 .545 r
.44413 .70514 m .44486 .70775 L .44909 .70206 L p F P
0 g
s
.98 .896 .552 r
.44486 .70775 m .44909 .70206 L .44556 .71258 L closepath p F P
0 g
s
.447 .573 .887 r
.74903 .66995 m .74916 .66862 L p .77073 .68047 L F P
0 g
s
.471 .598 .898 r
.74903 .66995 m .74815 .6685 L .74916 .66862 L closepath p F P
0 g
s
.809 .727 .775 r
.41505 .9005 m .40315 .91271 L .39683 .90518 L p F P
0 g
s
.809 .727 .775 r
.39683 .90518 m .405 .89625 L .41505 .9005 L p F P
0 g
s
.79 .713 .779 r
.41872 .88166 m .405 .89625 L .41505 .9005 L p F P
0 g
s
.79 .713 .779 r
.41898 .88175 m .41872 .88166 L p .41505 .9005 L F P
0 g
s
.747 .724 .831 r
.63441 .40503 m .63764 .41023 L .64089 .40804 L closepath p F P
0 g
s
.738 .718 .832 r
.63764 .41023 m .63441 .40503 L .62942 .40297 L p F P
0 g
s
.913 .746 .662 r
.44498 .77825 m .44528 .77746 L .44198 .77478 L closepath p F P
0 g
s
.914 .745 .658 r
.43878 .77104 m .44269 .76015 L p .44528 .77746 L F P
0 g
s
.914 .745 .658 r
.44528 .77746 m .44198 .77478 L .43878 .77104 L p F P
0 g
s
.441 .131 .342 r
.39075 .19244 m .39242 .18519 L .37069 .19324 L p F P
0 g
s
.441 .131 .342 r
.37069 .19324 m .36894 .20049 L .39075 .19244 L p F P
0 g
s
.49 .637 .919 r
.72289 .65056 m .71442 .65015 L .70914 .64246 L p F P
0 g
s
.828 .846 .861 r
.59479 .63547 m .59766 .63788 L .61444 .62329 L p F P
0 g
s
.952 .792 .647 r
.59736 .63876 m .59479 .63547 L .59766 .63788 L closepath p F P
0 g
s
.862 .66 .628 r
.73018 .26469 m .73862 .27008 L p .73247 .25355 L F P
0 g
s
.854 .679 .665 r
.73018 .26469 m .7352 .27789 L .73862 .27008 L closepath p F P
0 g
s
.858 .685 .666 r
.73862 .27008 m .7352 .27789 L .73738 .28349 L p F P
0 g
s
.539 .753 .975 r
.29824 .93615 m .319 .93358 L .32572 .93867 L p F P
0 g
s
.547 .755 .974 r
.319 .93358 m .29824 .93615 L .29141 .93126 L p F P
0 g
s
.842 .522 .447 r
.6898 .20314 m .70166 .20855 L .70286 .21713 L p F P
0 g
s
.852 .53 .442 r
.7142 .22269 m .70286 .21713 L .70166 .20855 L p F P
0 g
s
0 0 0 r
.77531 .92852 m .79762 .91477 L .79816 .91441 L p F P
0 g
s
.71 .975 .921 r
.77336 .92826 m .77531 .92852 L .79762 .91477 L p F P
0 g
s
.816 .886 .895 r
.30348 .66118 m .29165 .6703 L .29869 .67331 L p F P
0 g
s
.816 .886 .895 r
.29869 .67331 m .30369 .66941 L .30348 .66118 L p F P
0 g
s
.819 .882 .89 r
.28171 .67819 m .29165 .6703 L .29869 .67331 L p F P
0 g
s
.523 .409 .665 r
.31322 .27824 m .32404 .27804 L .31435 .28407 L closepath p F P
0 g
s
.637 .624 .82 r
.40994 .4059 m .41119 .40824 L .4318 .39957 L p F P
0 g
s
.641 .639 .833 r
.43751 .40972 m .4318 .39957 L .41119 .40824 L p F P
0 g
s
.937 .872 .748 r
.21131 .76947 m .21263 .77215 L .21733 .772 L p F P
0 g
s
.939 .867 .741 r
.21263 .77215 m .21733 .772 L .21481 .7763 L closepath p F P
0 g
s
.746 .848 .926 r
.36406 .6311 m .36987 .63482 L .36269 .63885 L closepath p F P
0 g
s
.892 .754 .702 r
.43927 .78976 m .44498 .77825 L .44198 .77478 L p F P
0 g
s
.784 .743 .815 r
.37503 .92327 m .38914 .91141 L .39938 .91558 L p F P
0 g
s
.77 .739 .825 r
.39683 .90518 m .38914 .91141 L .39938 .91558 L p F P
0 g
s
.77 .739 .825 r
.39938 .91558 m .40315 .91271 L .39683 .90518 L p F P
0 g
s
.587 .551 .782 r
.33386 .34539 m .33682 .35245 L .35772 .34801 L p F P
0 g
s
.586 .55 .781 r
.35952 .35238 m .35772 .34801 L .33682 .35245 L p F P
0 g
s
.983 .743 .494 r
.59479 .63547 m .59736 .63876 L .59623 .64939 L p F P
0 g
s
.174 0 0 r
.49951 .15566 m .5078 .15588 L .49732 .15635 L closepath p F P
0 g
s
.757 .719 .817 r
.64089 .40804 m .65963 .39436 L p .63207 .40113 L F P
0 g
s
.757 .719 .817 r
.63207 .40113 m .63441 .40503 L .64089 .40804 L p F P
0 g
s
.828 .846 .861 r
.61444 .62329 m .60934 .61682 L p .59479 .63547 L F P
0 g
s
.726 .781 .897 r
.61398 .61436 m .60934 .61682 L .61444 .62329 L p F P
0 g
s
.726 .781 .897 r
.61444 .62329 m .61955 .62067 L .61398 .61436 L p F P
0 g
s
.794 .876 .907 r
.32022 .65761 m .30369 .66941 L .30348 .66118 L p F P
0 g
s
.822 .442 .334 r
.6898 .20314 m .67925 .19869 L .68061 .19269 L p F P
0 g
s
.805 .424 .333 r
.67404 .19022 m .68061 .19269 L .67925 .19869 L p F P
0 g
s
.265 .292 .702 r
.83935 .77923 m .83741 .77704 L .83825 .77556 L closepath p F P
0 g
s
.315 .354 .743 r
.83353 .76178 m .83216 .76058 L p .83741 .77704 L F P
0 g
s
.315 .354 .743 r
.83741 .77704 m .83825 .77556 L .83353 .76178 L p F P
0 g
s
.396 .011 .187 r
.41528 .17829 m .41565 .17739 L .39452 .18051 L p F P
0 g
s
.396 .011 .187 r
.39452 .18051 m .39242 .18519 L .41528 .17829 L p F P
0 g
s
.976 .831 .633 r
.44513 .73087 m .44149 .72419 L .43724 .73591 L p F P
0 g
s
.976 .831 .633 r
.43724 .73591 m .4412 .74246 L .44513 .73087 L p F P
0 g
s
.616 .595 .807 r
.39133 .36939 m .37012 .37557 L .37634 .3882 L p F P
0 g
s
.616 .595 .807 r
.37634 .3882 m .39754 .38219 L .39133 .36939 L p F P
0 g
s
.616 .597 .809 r
.39843 .38404 m .39754 .38219 L .37634 .3882 L p F P
0 g
s
.553 0 0 r
.60778 .16645 m .59773 .16164 L .58428 .15932 L p F P
0 g
s
.444 0 0 r
.61231 .16727 m .60778 .16645 L .59773 .16164 L p F P
0 g
s
.987 .73 .443 r
.20989 .8383 m .20769 .83555 L .20716 .84628 L p F P
0 g
s
.987 .73 .443 r
.20716 .84628 m .21042 .85036 L .20989 .8383 L p F P
0 g
s
.466 .603 .904 r
.74916 .66862 m .74815 .6685 L .74293 .6602 L p F P
0 g
s
.223 0 0 r
.52723 .15478 m .53471 .15557 L .52489 .15536 L closepath p F P
0 g
s
0 0 0 r
.82531 .8844 m .83387 .87577 L p .81842 .89568 L F P
0 g
s
0 0 0 r
.81842 .89568 m .81937 .89359 L .82531 .8844 L p F P
0 g
s
0 0 .151 r
.83664 .86977 m .83726 .86529 L p .82531 .8844 L F P
0 g
s
0 0 .151 r
.82531 .8844 m .83387 .87577 L .83664 .86977 L p F P
0 g
s
.518 .672 .934 r
.68908 .63467 m .68088 .63487 L .67551 .62777 L p F P
0 g
s
.596 .724 .933 r
.69226 .93501 m .71497 .93136 L .72022 .93767 L p F P
0 g
s
.59 .653 .88 r
.70962 .9239 m .71497 .93136 L .69226 .93501 L p F P
0 g
s
.59 .653 .88 r
.6874 .92644 m .70962 .9239 L p .69226 .93501 L F P
0 g
s
.59 .653 .88 r
.69226 .93501 m .68693 .9267 L .6874 .92644 L p F P
0 g
s
.863 .629 .583 r
.72521 .24921 m .73247 .25355 L p .72442 .23772 L F P
0 g
s
.858 .655 .627 r
.72521 .24921 m .72952 .26268 L .73247 .25355 L closepath p F P
0 g
s
.862 .66 .628 r
.73247 .25355 m .72952 .26268 L .73018 .26469 L p F P
0 g
s
.636 .621 .818 r
.42518 .38687 m .40375 .39416 L .40994 .4059 L p F P
0 g
s
.636 .621 .818 r
.40994 .4059 m .43135 .39871 L .42518 .38687 L p F P
0 g
s
.637 .624 .82 r
.4318 .39957 m .43135 .39871 L .40994 .4059 L p F P
0 g
s
.092 .528 .907 r
.26446 .92127 m .2759 .92467 L .283 .92974 L p F P
0 g
s
.121 .534 .917 r
.26446 .92127 m .2759 .92467 L .26918 .91945 L p F P
0 g
s
.121 .534 .917 r
.26918 .91945 m .25752 .91594 L .26446 .92127 L p F P
0 g
s
0 .171 .626 r
.25313 .91287 m .25752 .91594 L .26446 .92127 L p F P
0 g
s
.906 .893 .805 r
.2329 .73726 m .23832 .73039 L .23589 .72305 L p F P
0 g
s
.38 .477 .833 r
.81714 .72148 m .80229 .71499 L p .81462 .72952 L F P
0 g
s
.356 .462 .831 r
.80229 .71499 m .81714 .72148 L .81186 .71045 L p F P
0 g
s
.356 .462 .831 r
.81186 .71045 m .80438 .70707 L .80229 .71499 L p F P
0 g
s
.85 .579 .527 r
.70286 .21713 m .7142 .22269 L .7137 .23198 L p F P
0 g
s
.859 .588 .526 r
.72195 .23633 m .7137 .23198 L .7142 .22269 L p F P
0 g
s
.354 .304 .663 r
.61307 .75621 m .6083 .76112 L .61126 .7745 L p F P
0 g
s
.462 .377 .674 r
.61064 .77491 m .61126 .7745 L .6083 .76112 L p F P
0 g
s
.785 .32 0 r
.22699 .88416 m .22138 .87844 L .22671 .88773 L p F P
0 g
s
.785 .32 0 r
.22671 .88773 m .23237 .89343 L .22699 .88416 L p F P
0 g
s
.878 .733 .698 r
.43317 .80214 m .4413 .80721 L .4349 .81969 L p F P
0 g
s
.874 .726 .695 r
.4413 .80721 m .43317 .80214 L .43927 .78976 L p F P
0 g
s
.504 .335 .584 r
.34822 .23827 m .3474 .22768 L .32783 .23794 L p F P
0 g
s
.504 .335 .584 r
.32974 .24791 m .34822 .23827 L p .32783 .23794 L F P
0 g
s
.504 .335 .584 r
.32783 .23794 m .32855 .24781 L .32974 .24791 L p F P
0 g
s
.582 .62 .855 r
.65863 .91855 m .68128 .91674 L .68681 .92651 L p F P
0 g
s
.57 .568 .812 r
.67567 .90579 m .68128 .91674 L .65863 .91855 L p F P
0 g
s
.57 .568 .812 r
.6724 .90588 m .67567 .90579 L p .65863 .91855 L F P
0 g
s
.57 .568 .812 r
.65863 .91855 m .65648 .91393 L .6724 .90588 L p F P
0 g
s
.543 .447 .696 r
.32404 .27804 m .31435 .28407 L .31772 .2977 L p F P
0 g
s
.158 0 0 r
.47176 .1586 m .47533 .15846 L .47099 .15894 L closepath p F P
0 g
s
.447 .573 .887 r
.74916 .66862 m .77137 .67273 L .77073 .68047 L p F P
0 g
s
.435 .581 .899 r
.74925 .66097 m .74916 .66862 L .77137 .67273 L p F P
0 g
s
.466 .603 .904 r
.74293 .6602 m .74925 .66097 L .74916 .66862 L p F P
0 g
s
.96 .868 .702 r
.21481 .7763 m .20892 .78843 L .20527 .78167 L p F P
0 g
s
.96 .868 .702 r
.21263 .77215 m .21481 .7763 L p .20527 .78167 L F P
0 g
s
.825 .715 .744 r
.72099 .32542 m .72783 .33007 L p .72857 .31109 L F P
0 g
s
.815 .723 .764 r
.72099 .32542 m .72508 .33328 L .72783 .33007 L closepath p F P
0 g
s
.221 .143 .551 r
.45573 .63779 m .45956 .63295 L .46284 .64209 L p F P
0 g
s
.221 .143 .551 r
.46284 .64209 m .45691 .64941 L .45573 .63779 L p F P
0 g
s
.405 .4 .74 r
.45956 .63295 m .45573 .63779 L .45311 .62974 L closepath p F P
0 g
s
.941 .576 .209 r
.21876 .87005 m .21842 .86858 L .21687 .86691 L closepath p F P
0 g
s
.859 .625 .583 r
.72195 .23633 m .72347 .24243 L .72442 .23772 L closepath p F P
0 g
s
.863 .629 .583 r
.72442 .23772 m .72347 .24243 L .72521 .24921 L p F P
0 g
s
.577 .527 .763 r
.33071 .33704 m .33386 .34539 L .35191 .33393 L p F P
0 g
s
.587 .551 .782 r
.35772 .34801 m .35191 .33393 L .33386 .34539 L p F P
0 g
s
.439 .385 .701 r
.45311 .62974 m .44748 .61902 L p .47007 .62352 L F P
0 g
s
.439 .385 .701 r
.47007 .62352 m .45956 .63295 L .45311 .62974 L p F P
0 g
s
.758 .776 .867 r
.3662 .92843 m .35352 .93613 L .34694 .93053 L p F P
0 g
s
.683 .777 .922 r
.32572 .93867 m .34694 .93053 L .35352 .93613 L p F P
0 g
s
.608 .742 .94 r
.63103 .61819 m .61955 .62067 L .61398 .61436 L p F P
0 g
s
.764 .309 .169 r
.64616 .18079 m .66036 .18542 L p .64651 .17589 L F P
0 g
s
.764 .309 .169 r
.64651 .17589 m .64456 .17863 L .64616 .18079 L p F P
0 g
s
.713 .245 .137 r
.6403 .17419 m .64651 .17589 L .64456 .17863 L closepath p F P
0 g
s
.728 .846 .937 r
.36987 .63482 m .39132 .62376 L p .36452 .6299 L F P
0 g
s
.728 .846 .937 r
.36452 .6299 m .36406 .6311 L .36987 .63482 L p F P
0 g
s
.289 .339 .741 r
.83353 .76178 m .83216 .76058 L .83272 .75944 L closepath p F P
0 g
s
.338 .398 .777 r
.82796 .74709 m .82456 .74473 L p .83216 .76058 L F P
0 g
s
.338 .398 .777 r
.83216 .76058 m .83272 .75944 L .82796 .74709 L p F P
0 g
s
.858 .685 .666 r
.7352 .27789 m .73379 .28111 L .73738 .28349 L closepath p F P
0 g
s
.985 .821 .597 r
.20843 .80673 m .20432 .80022 L .20101 .81168 L p F P
0 g
s
.985 .821 .597 r
.20101 .81168 m .20514 .81816 L .20843 .80673 L p F P
0 g
s
.844 .698 .702 r
.73655 .29886 m .72728 .29279 L .73379 .28111 L p F P
0 g
s
.834 .705 .721 r
.72728 .29279 m .73655 .29886 L .72857 .31109 L p F P
0 g
s
.811 .722 .767 r
.72508 .33328 m .71617 .34364 L p .71883 .32398 L F P
0 g
s
.811 .722 .767 r
.71883 .32398 m .72099 .32542 L .72508 .33328 L p F P
0 g
s
.503 .862 .619 r
.79762 .91477 m .79952 .91326 L .79816 .91441 L closepath p F P
0 g
s
0 0 0 r
.81573 .89801 m .79952 .91326 L .79816 .91441 L p F P
0 g
s
.557 .042 0 r
.23838 .89896 m .23237 .89343 L .24063 .902 L p F P
0 g
s
.557 .042 0 r
.24063 .902 m .24671 .90751 L .23838 .89896 L p F P
0 g
s
0 0 .282 r
.45496 .65271 m .45691 .64941 L .45627 .65929 L p F P
0 g
s
0 0 .282 r
.45627 .65929 m .45406 .66319 L .45496 .65271 L p F P
0 g
s
.253 .623 .959 r
.283 .92974 m .29141 .93126 L .28453 .92619 L p F P
0 g
s
.253 .623 .959 r
.28453 .92619 m .2759 .92467 L .283 .92974 L p F P
0 g
s
.67 .668 .84 r
.46997 .42066 m .47129 .42284 L .48188 .41844 L closepath p F P
0 g
s
.833 .716 .735 r
.42865 .86811 m .41883 .88154 L .41257 .87304 L p F P
0 g
s
.833 .716 .735 r
.41257 .87304 m .41908 .86362 L .42865 .86811 L p F P
0 g
s
.833 .717 .737 r
.42865 .86811 m .41908 .86362 L .42839 .85025 L p F P
0 g
s
.359 .439 .807 r
.82252 .73388 m .81462 .72952 L p .82456 .74473 L F P
0 g
s
.337 .429 .808 r
.82252 .73388 m .81462 .72952 L .81723 .72168 L closepath p F P
0 g
s
.38 .477 .833 r
.81462 .72952 m .81723 .72168 L .81714 .72148 L p F P
0 g
s
.69 .782 .921 r
.34694 .93053 m .32572 .93867 L .319 .93358 L p F P
0 g
s
.735 .712 .829 r
.61003 .41542 m .62942 .40297 L .61662 .39831 L p F P
0 g
s
.735 .712 .829 r
.61662 .39831 m .60436 .40615 L .61003 .41542 L p F P
0 g
s
.73 .708 .83 r
.61003 .41542 m .60436 .40615 L .58233 .41955 L p F P
0 g
s
.906 .893 .805 r
.23589 .72305 m .22538 .73616 L .2329 .73726 L p F P
0 g
s
.903 .888 .807 r
.2329 .73726 m .22771 .74387 L .22498 .73667 L p F P
0 g
s
.903 .888 .807 r
.22498 .73667 m .22538 .73616 L .2329 .73726 L p F P
0 g
s
.578 .529 .764 r
.32738 .32827 m .33071 .33704 L .35157 .333 L p F P
0 g
s
.577 .527 .763 r
.35191 .33393 m .35157 .333 L .33071 .33704 L p F P
0 g
s
.253 .284 .7 r
.83825 .77556 m .8415 .76896 L p .84513 .78593 L F P
0 g
s
.253 .284 .7 r
.84513 .78593 m .83935 .77923 L .83825 .77556 L p F P
0 g
s
.283 .333 .738 r
.83825 .77556 m .83353 .76178 L .8415 .76896 L closepath p F P
0 g
s
.938 .779 .657 r
.44269 .76015 m .43707 .75417 L .43274 .76599 L p F P
0 g
s
.938 .779 .657 r
.43878 .77104 m .44269 .76015 L p .43274 .76599 L F P
0 g
s
.804 .729 .781 r
.71617 .34364 m .70346 .35683 L .70515 .35989 L p F P
0 g
s
.802 .728 .783 r
.70346 .35683 m .70232 .358 L .70515 .35989 L closepath p F P
0 g
s
.313 .385 .777 r
.82796 .74709 m .82456 .74473 L .82584 .74164 L closepath p F P
0 g
s
.359 .439 .807 r
.82456 .74473 m .82584 .74164 L .82252 .73388 L p F P
0 g
s
.859 .721 .709 r
.43482 .84115 m .43706 .83708 L .42924 .83272 L closepath p F P
0 g
s
.86 .72 .708 r
.42864 .8318 m .4349 .81969 L p .43706 .83708 L F P
0 g
s
.86 .72 .708 r
.43706 .83708 m .42924 .83272 L .42864 .8318 L p F P
0 g
s
.141 .089 .533 r
.84868 .81656 m .845 .82167 L .84741 .83214 L p F P
0 g
s
.209 .181 .605 r
.845 .82167 m .84868 .81656 L .84614 .804 L p F P
0 g
s
.911 .52 .11 r
.21876 .87005 m .21687 .86691 L p .21613 .87256 L F P
0 g
s
.911 .52 .11 r
.21613 .87256 m .22138 .87844 L .21876 .87005 L p F P
0 g
s
.256 .284 .699 r
.84266 .79034 m .83935 .77923 L .84513 .78593 L closepath p F P
0 g
s
.789 .881 .913 r
.3308 .64237 m .31329 .65425 L .32022 .65761 L p F P
0 g
s
.789 .881 .913 r
.32022 .65761 m .32978 .65106 L .3308 .64237 L p F P
0 g
s
.794 .876 .907 r
.30348 .66118 m .31329 .65425 L .32022 .65761 L p F P
0 g
s
.759 .724 .82 r
.65963 .39436 m .66555 .38992 L .65509 .38446 L p F P
0 g
s
.759 .724 .82 r
.65509 .38446 m .65413 .38517 L .65963 .39436 L p F P
0 g
s
.757 .719 .817 r
.65963 .39436 m .65413 .38517 L .63207 .40113 L p F P
0 g
s
.975 .667 .337 r
.21241 .85628 m .2121 .85235 L .21042 .85036 L closepath p F P
0 g
s
.971 .658 .35 r
.2121 .85235 m .21241 .85628 L .21687 .86691 L p F P
0 g
s
.571 .571 .814 r
.65648 .91393 m .65296 .90648 L .6724 .90588 L closepath p F P
0 g
s
.797 .42 .342 r
.66036 .18542 m .67404 .19022 L .67727 .19794 L p F P
0 g
s
.805 .424 .333 r
.67925 .19869 m .67727 .19794 L .67404 .19022 L p F P
0 g
s
.304 0 0 r
.55499 .15594 m .55826 .1566 L .55381 .15621 L closepath p F P
0 g
s
.119 .172 .643 r
.61182 .72033 m .60764 .72907 L .61337 .73803 L p F P
0 g
s
.109 .122 .591 r
.60764 .72907 m .61182 .72033 L .60749 .71102 L p F P
0 g
s
.851 .621 .589 r
.7137 .23198 m .72195 .23633 L .72347 .24243 L p F P
0 g
s
0 0 0 r
.81573 .89801 m .81842 .89568 L .81937 .89359 L closepath p F P
0 g
s
.553 0 0 r
.58934 .16338 m .60778 .16645 L p .58428 .15932 L F P
0 g
s
.553 0 0 r
.58428 .15932 m .58286 .15993 L .58934 .16338 L p F P
0 g
s
.433 0 0 r
.57904 .15872 m .58428 .15932 L .58286 .15993 L closepath p F P
0 g
s
.848 .677 .67 r
.7352 .27789 m .73379 .28111 L p .72909 .26402 L F P
0 g
s
.848 .677 .67 r
.72909 .26402 m .73018 .26469 L .7352 .27789 L p F P
0 g
s
.811 .776 .269 r
.44992 .68273 m .45158 .67422 L .44827 .68555 L p F P
0 g
s
.811 .776 .269 r
.44827 .68555 m .44728 .69383 L .44992 .68273 L p F P
0 g
s
.543 .447 .696 r
.31772 .2977 m .33604 .28634 L p .32404 .27804 L F P
0 g
s
.557 .479 .723 r
.33951 .29829 m .33604 .28634 L .31772 .2977 L p F P
0 g
s
.557 .479 .723 r
.31772 .2977 m .31879 .30131 L .33951 .29829 L p F P
0 g
s
.279 .333 .739 r
.8415 .76896 m .83353 .76178 L .83272 .75944 L p F P
0 g
s
.556 .477 .721 r
.3403 .30103 m .33951 .29829 L .31879 .30131 L p F P
0 g
s
.556 .477 .721 r
.31879 .30131 m .32204 .31241 L .3403 .30103 L p F P
0 g
s
.375 0 0 r
.49315 .15987 m .46709 .16271 L .47099 .15894 L p F P
0 g
s
.375 0 0 r
.47099 .15894 m .47533 .15846 L .49315 .15987 L p F P
0 g
s
.228 .233 .657 r
.84266 .79034 m .84513 .78593 L p .84648 .80346 L F P
0 g
s
.228 .233 .657 r
.84648 .80346 m .8457 .80227 L .84266 .79034 L p F P
0 g
s
.716 .703 .836 r
.58233 .41955 m .581 .42029 L .58305 .42072 L closepath p F P
0 g
s
.77 .724 .81 r
.66555 .38992 m .65509 .38446 L .67572 .36768 L p F P
0 g
s
.77 .724 .81 r
.6816 .37675 m .66555 .38992 L p .67572 .36768 L F P
0 g
s
.465 .381 .678 r
.61146 .7754 m .61064 .77491 L .61126 .7745 L closepath p F P
0 g
s
.567 .503 .743 r
.32468 .32021 m .32738 .32827 L .34555 .31686 L p F P
0 g
s
.578 .529 .764 r
.35157 .333 m .34555 .31686 L .32738 .32827 L p F P
0 g
s
.67 .656 .828 r
.46521 .4123 m .46997 .42066 L .48188 .41844 L p F P
0 g
s
.811 .722 .767 r
.71617 .34364 m .70692 .33767 L .71883 .32398 L p F P
0 g
s
.798 .721 .779 r
.70346 .35683 m .71617 .34364 L .70692 .33767 L p F P
0 g
s
.71 .249 .153 r
.62449 .17016 m .6403 .17419 L .64456 .17863 L p F P
0 g
s
.279 .333 .739 r
.83272 .75944 m .83565 .75256 L p .8415 .76896 L F P
0 g
s
.309 .38 .773 r
.83272 .75944 m .82796 .74709 L .83565 .75256 L closepath p F P
0 g
s
.576 .92 .962 r
.74798 .93607 m .77065 .92757 L .77336 .92826 L p F P
0 g
s
.602 .884 .991 r
.77065 .92757 m .74798 .93607 L .74298 .93216 L p F P
0 g
s
.603 .823 .984 r
.72022 .93767 m .74298 .93216 L .74798 .93607 L p F P
0 g
s
.596 .769 .962 r
.74298 .93216 m .72022 .93767 L .71497 .93136 L p F P
0 g
s
.506 .854 .591 r
.81842 .89568 m .81573 .89801 L .79952 .91326 L p F P
0 g
s
.443 0 0 r
.55826 .1566 m .57904 .15872 L .58286 .15993 L p F P
0 g
s
.892 .754 .702 r
.44198 .77478 m .43834 .77195 L p .43927 .78976 L F P
0 g
s
.894 .752 .698 r
.44198 .77478 m .43878 .77104 L .43834 .77195 L closepath p F P
0 g
s
.568 .505 .745 r
.32204 .31241 m .32468 .32021 L .34548 .31664 L p F P
0 g
s
.567 .503 .743 r
.34555 .31686 m .34548 .31664 L .32468 .32021 L p F P
0 g
s
.61 .947 .776 r
.79952 .91326 m .79762 .91477 L .79323 .91601 L p F P
0 g
s
.71 .975 .921 r
.79762 .91477 m .79323 .91601 L p .77336 .92826 L F P
0 g
s
.747 .716 .823 r
.63207 .40113 m .62942 .40297 L .63441 .40503 L closepath p F P
0 g
s
.926 .886 .774 r
.22771 .74387 m .22498 .73667 L .21592 .74975 L p F P
0 g
s
.926 .886 .774 r
.21592 .74975 m .21881 .75687 L .22771 .74387 L p F P
0 g
s
.506 .854 .591 r
.8155 .89935 m .81842 .89568 L p .79952 .91326 L F P
0 g
s
.61 .947 .776 r
.79323 .91601 m .80948 .90443 L .79952 .91326 L p F P
0 g
s
.506 .854 .591 r
.79952 .91326 m .80948 .90443 L .8155 .89935 L p F P
0 g
s
.358 0 0 r
.49336 .15985 m .49315 .15987 L .47533 .15846 L p F P
0 g
s
.358 0 0 r
.47533 .15846 m .49732 .15635 L .49336 .15985 L p F P
0 g
s
.683 .678 .84 r
.49449 .41626 m .49901 .42369 L .51961 .41434 L closepath p F P
0 g
s
.671 .674 .844 r
.49901 .42369 m .49449 .41626 L .48188 .41844 L p F P
0 g
s
.832 .718 .739 r
.42839 .85025 m .43482 .84115 L .42924 .83272 L p F P
0 g
s
.714 .697 .832 r
.58233 .41955 m .581 .42029 L .56357 .41727 L p F P
0 g
s
.568 .505 .745 r
.34548 .31664 m .3403 .30103 L .32204 .31241 L p F P
0 g
s
.013 0 .329 r
.83726 .86529 m .83901 .86325 L .84108 .85154 L p F P
0 g
s
0 0 .304 r
.84769 .84322 m .84108 .85154 L .83901 .86325 L p F P
0 g
s
.083 0 .442 r
.84108 .85154 m .84769 .84322 L .84741 .83214 L p F P
0 g
s
.542 .692 .937 r
.64742 .62259 m .67011 .62085 L .67551 .62777 L p F P
0 g
s
.539 .699 .943 r
.67011 .62085 m .64742 .62259 L .64194 .61594 L p F P
0 g
s
.42 .351 .674 r
.61126 .7745 m .6208 .76476 L p .62073 .78287 L F P
0 g
s
.42 .351 .674 r
.62073 .78287 m .61146 .7754 L .61126 .7745 L p F P
0 g
s
.354 .304 .663 r
.61126 .7745 m .6208 .76476 L .61307 .75621 L p F P
0 g
s
.911 .52 .11 r
.21687 .86691 m .21313 .8627 L .21613 .87256 L p F P
0 g
s
.969 .647 .317 r
.21313 .8627 m .21687 .86691 L .21241 .85628 L closepath p F P
0 g
s
.404 .351 .685 r
.61461 .7883 m .61146 .7754 L .62073 .78287 L closepath p F P
0 g
s
.758 .776 .867 r
.34694 .93053 m .3573 .92391 L .3662 .92843 L p F P
0 g
s
.744 .768 .872 r
.36855 .91698 m .3573 .92391 L .3662 .92843 L p F P
0 g
s
.744 .768 .872 r
.3662 .92843 m .37503 .92327 L .36855 .91698 L p F P
0 g
s
.897 .758 .7 r
.43229 .78429 m .43927 .78976 L .43317 .80214 L p F P
0 g
s
.892 .754 .702 r
.43834 .77195 m .43229 .78429 L .43927 .78976 L p F P
0 g
s
.726 .705 .83 r
.59865 .39661 m .57656 .40992 L .58233 .41955 L p F P
0 g
s
.726 .705 .83 r
.58233 .41955 m .60436 .40615 L .59865 .39661 L p F P
0 g
s
.714 .697 .832 r
.56357 .41727 m .57656 .40992 L .58233 .41955 L p F P
0 g
s
.851 .621 .589 r
.72347 .24243 m .72241 .24763 L p .7137 .23198 L F P
0 g
s
.862 .629 .584 r
.72347 .24243 m .72241 .24763 L .72521 .24921 L closepath p F P
0 g
s
.521 .442 .707 r
.6236 .82271 m .61453 .82054 L .62195 .81661 L closepath p F P
0 g
s
.527 .429 .686 r
.61808 .80224 m .62195 .81661 L .61453 .82054 L p F P
0 g
s
.769 .867 .921 r
.34171 .64352 m .32978 .65106 L .3308 .64237 L p F P
0 g
s
.958 .687 .245 r
.60002 .66646 m .59682 .65956 L .59623 .64939 L p F P
0 g
s
.973 .915 .584 r
.44556 .71258 m .44149 .72419 L .43999 .71681 L p F P
0 g
s
.973 .915 .584 r
.44486 .70775 m .44556 .71258 L p .43999 .71681 L F P
0 g
s
0 .187 .654 r
.25752 .91594 m .25313 .91287 L .24671 .90751 L p F P
0 g
s
.696 .81 .935 r
.41725 .61709 m .41926 .61872 L .41603 .62011 L closepath p F P
0 g
s
.775 .726 .807 r
.67665 .36819 m .6816 .37675 L .68566 .37336 L closepath p F P
0 g
s
.77 .724 .81 r
.67572 .36768 m .67665 .36819 L .6816 .37675 L p F P
0 g
s
.66 .949 .955 r
.77065 .92757 m .78013 .92296 L .77336 .92826 L closepath p F P
0 g
s
.71 .975 .921 r
.79323 .91601 m .78013 .92296 L .77336 .92826 L p F P
0 g
s
.848 .677 .67 r
.73379 .28111 m .72401 .27514 L .72909 .26402 L p F P
0 g
s
.839 .687 .695 r
.72401 .27514 m .73379 .28111 L .72728 .29279 L p F P
0 g
s
.978 .812 .61 r
.59207 .63456 m .59275 .63218 L .59479 .63547 L closepath p F P
0 g
s
.828 .846 .861 r
.60934 .61682 m .59275 .63218 L .59479 .63547 L p F P
0 g
s
.983 .743 .494 r
.59207 .63456 m .59479 .63547 L p .59623 .64939 L F P
0 g
s
.798 .721 .779 r
.70692 .33767 m .69805 .34676 L .70346 .35683 L p F P
0 g
s
.798 .72 .778 r
.69269 .35219 m .69805 .34676 L .70346 .35683 L p F P
0 g
s
.798 .72 .778 r
.70346 .35683 m .70232 .358 L .69269 .35219 L p F P
0 g
s
.784 .72 .793 r
.68566 .37336 m .70232 .358 L .69269 .35219 L p F P
0 g
s
.784 .72 .793 r
.67665 .36819 m .68566 .37336 L p .69269 .35219 L F P
0 g
s
.617 .597 .807 r
.36856 .37239 m .37012 .37557 L .39133 .36939 L p F P
0 g
s
.412 .539 .875 r
.78904 .69332 m .78227 .69154 L .77706 .68209 L p F P
0 g
s
.695 .689 .839 r
.52114 .41425 m .52678 .42343 L .54384 .41502 L closepath p F P
0 g
s
.684 .684 .844 r
.52678 .42343 m .52114 .41425 L .51961 .41434 L p F P
0 g
s
.991 .738 .427 r
.20769 .83555 m .20318 .82927 L .20265 .84002 L p F P
0 g
s
.991 .738 .427 r
.20265 .84002 m .20716 .84628 L .20769 .83555 L p F P
0 g
s
.655 .645 .828 r
.4318 .39957 m .43751 .40972 L .4591 .40146 L p F P
0 g
s
.796 .715 .774 r
.41898 .88175 m .41883 .88154 L .41872 .88166 L closepath p F P
0 g
s
.708 .698 .839 r
.55043 .4154 m .55456 .42206 L .56357 .41727 L closepath p F P
0 g
s
.697 .694 .843 r
.55456 .42206 m .55043 .4154 L .54384 .41502 L p F P
0 g
s
.458 .613 .915 r
.72289 .65056 m .7377 .65211 L .73245 .64422 L p F P
0 g
s
.458 .613 .915 r
.73245 .64422 m .72187 .6431 L .72289 .65056 L p F P
0 g
s
.49 .637 .919 r
.70914 .64246 m .72187 .6431 L .72289 .65056 L p F P
0 g
s
.354 0 0 r
.44389 .16474 m .45505 .16468 L .44196 .16696 L closepath p F P
0 g
s
.802 .726 .78 r
.41872 .88166 m .41883 .88154 L .41257 .87304 L p F P
0 g
s
.821 .744 .779 r
.40869 .87732 m .41872 .88166 L .405 .89625 L p F P
0 g
s
.802 .726 .78 r
.41257 .87304 m .40869 .87732 L .41872 .88166 L p F P
0 g
s
.446 .043 .181 r
.43935 .17269 m .44196 .16696 L .418 .17255 L p F P
0 g
s
.446 .043 .181 r
.41836 .17755 m .43935 .17269 L p .418 .17255 L F P
0 g
s
.446 .043 .181 r
.418 .17255 m .41565 .17739 L .41836 .17755 L p F P
0 g
s
.573 .551 .791 r
.6724 .90588 m .65296 .90648 L .64822 .89533 L p F P
0 g
s
.834 .705 .721 r
.72857 .31109 m .71917 .30508 L .72728 .29279 L p F P
0 g
s
.818 .707 .743 r
.71971 .32282 m .72857 .31109 L .71917 .30508 L p F P
0 g
s
.825 .715 .744 r
.72857 .31109 m .71971 .32282 L .72099 .32542 L p F P
0 g
s
.833 .515 .452 r
.67925 .19869 m .6898 .20314 L .69095 .21173 L p F P
0 g
s
.842 .522 .447 r
.70286 .21713 m .69095 .21173 L .6898 .20314 L p F P
0 g
s
.878 .734 .699 r
.4349 .81969 m .42864 .8318 L .42238 .82381 L p F P
0 g
s
.878 .734 .699 r
.42238 .82381 m .42701 .81458 L .4349 .81969 L p F P
0 g
s
.878 .733 .698 r
.4349 .81969 m .42701 .81458 L .43317 .80214 L p F P
0 g
s
.677 .805 .944 r
.41926 .61872 m .44079 .61116 L p .4248 .6089 L F P
0 g
s
.677 .805 .944 r
.4248 .6089 m .41725 .61709 L .41926 .61872 L p F P
0 g
s
.861 .659 .628 r
.72952 .26268 m .72909 .26402 L .73018 .26469 L closepath p F P
0 g
s
.494 .656 .932 r
.68908 .63467 m .70383 .63497 L .69851 .6277 L p F P
0 g
s
.494 .656 .932 r
.69851 .6277 m .68677 .62748 L .68908 .63467 L p F P
0 g
s
.518 .672 .934 r
.67551 .62777 m .68677 .62748 L .68908 .63467 L p F P
0 g
s
.851 .652 .633 r
.72952 .26268 m .72909 .26402 L p .72241 .24763 L F P
0 g
s
.851 .652 .633 r
.72241 .24763 m .72521 .24921 L .72952 .26268 L p F P
0 g
s
.229 .234 .657 r
.84614 .804 m .8457 .80227 L .84648 .80346 L closepath p F P
0 g
s
.969 .651 .293 r
.21241 .85628 m .21042 .85036 L p .20825 .85663 L F P
0 g
s
.969 .651 .293 r
.20825 .85663 m .21313 .8627 L .21241 .85628 L p F P
0 g
s
.513 0 0 r
.55381 .15621 m .55826 .1566 L .56927 .16093 L p F P
0 g
s
.443 0 0 r
.58025 .16202 m .56927 .16093 L .55826 .1566 L p F P
0 g
s
.443 0 0 r
.58286 .15993 m .58025 .16202 L p .55826 .1566 L F P
0 g
s
.969 .824 .644 r
.4412 .74246 m .43724 .73591 L .43281 .74773 L p F P
0 g
s
.969 .824 .644 r
.43281 .74773 m .43707 .75417 L .4412 .74246 L p F P
0 g
s
.969 .651 .293 r
.21042 .85036 m .20716 .84628 L .20825 .85663 L p F P
0 g
s
.61 .578 .792 r
.36391 .36211 m .36856 .37239 L .38785 .3622 L p F P
0 g
s
.617 .597 .807 r
.39133 .36939 m .38785 .3622 L .36856 .37239 L p F P
0 g
s
.304 .38 .775 r
.83565 .75256 m .82796 .74709 L .82584 .74164 L p F P
0 g
s
.598 .661 .882 r
.44842 .61811 m .44748 .61902 L .44702 .61836 L closepath p F P
0 g
s
.439 .385 .701 r
.44748 .61902 m .44842 .61811 L p .47007 .62352 L F P
0 g
s
.508 .298 .53 r
.36818 .21853 m .36813 .20896 L .34741 .21813 L p F P
0 g
s
.508 .298 .53 r
.34741 .21813 m .3474 .22768 L .36818 .21853 L p F P
0 g
s
.637 .621 .817 r
.39843 .38404 m .40375 .39416 L .42518 .38687 L p F P
0 g
s
.161 .148 .594 r
.84648 .80346 m .84614 .804 L .84868 .81656 L p F P
0 g
s
.85 .737 .738 r
.41935 .84554 m .42839 .85025 L .41908 .86362 L p F P
0 g
s
.832 .718 .739 r
.42832 .83227 m .41935 .84554 L .42839 .85025 L p F P
0 g
s
.832 .718 .739 r
.42924 .83272 m .42832 .83227 L p .42839 .85025 L F P
0 g
s
.414 0 0 r
.52094 .15865 m .49336 .15985 L .49732 .15635 L p F P
0 g
s
.414 0 0 r
.52128 .15825 m .52094 .15865 L p .49732 .15635 L F P
0 g
s
.414 0 0 r
.49732 .15635 m .5078 .15588 L .52128 .15825 L p F P
0 g
s
.504 .333 .582 r
.32855 .24781 m .32974 .24791 L .3286 .24851 L closepath p F P
0 g
s
.67 .656 .828 r
.48188 .41844 m .493 .41367 L p .46521 .4123 L F P
0 g
s
.672 .662 .832 r
.493 .41367 m .48188 .41844 L .49449 .41626 L closepath p F P
0 g
s
.797 .757 .817 r
.38914 .91141 m .37503 .92327 L .36855 .91698 L p F P
0 g
s
.744 .709 .818 r
.63207 .40113 m .62942 .40297 L .61662 .39831 L p F P
0 g
s
.513 0 0 r
.56927 .16093 m .54985 .15926 L .55381 .15621 L p F P
0 g
s
.458 0 0 r
.53471 .15557 m .55381 .15621 L .54985 .15926 L p F P
0 g
s
.976 .851 .651 r
.20892 .78843 m .20527 .78167 L .20061 .79351 L p F P
0 g
s
.976 .851 .651 r
.20061 .79351 m .20432 .80022 L .20892 .78843 L p F P
0 g
s
.404 .54 .879 r
.77073 .68047 m .77706 .68209 L .77184 .67285 L p F P
0 g
s
.404 .54 .879 r
.77184 .67285 m .77137 .67273 L .77073 .68047 L p F P
0 g
s
.851 .652 .633 r
.72909 .26402 m .7188 .25818 L .72241 .24763 L p F P
0 g
s
.842 .667 .665 r
.7188 .25818 m .72909 .26402 L .72401 .27514 L p F P
0 g
s
.456 .386 .69 r
.61461 .7883 m .62073 .78287 L p .61928 .8013 L F P
0 g
s
.456 .386 .69 r
.61928 .8013 m .61756 .80028 L .61461 .7883 L p F P
0 g
s
.599 .649 .871 r
.44702 .61836 m .44079 .61116 L p .46313 .60596 L F P
0 g
s
.599 .649 .871 r
.46313 .60596 m .44842 .61811 L .44702 .61836 L p F P
0 g
s
.823 .743 .776 r
.405 .89625 m .39683 .90518 L .39045 .89799 L p F P
0 g
s
.823 .743 .776 r
.39045 .89799 m .39594 .89168 L .405 .89625 L p F P
0 g
s
.821 .744 .779 r
.405 .89625 m .39594 .89168 L .40869 .87732 L p F P
0 g
s
.532 .388 .63 r
.32974 .24791 m .3286 .24851 L .33024 .26012 L p F P
0 g
s
.051 0 .357 r
.45691 .64941 m .46284 .64209 L .46172 .65268 L p F P
0 g
s
.051 0 .357 r
.46172 .65268 m .45627 .65929 L .45691 .64941 L p F P
0 g
s
.402 0 0 r
.5078 .15588 m .52489 .15536 L .52128 .15825 L closepath p F P
0 g
s
.979 .683 .362 r
.59128 .64294 m .59623 .64939 L .59682 .65956 L p F P
0 g
s
.983 .743 .494 r
.59623 .64939 m .59128 .64294 L .59207 .63456 L p F P
0 g
s
.75 .712 .816 r
.63207 .40113 m .65413 .38517 L p .64344 .37936 L F P
0 g
s
.75 .712 .816 r
.64344 .37936 m .62645 .39154 L .63207 .40113 L p F P
0 g
s
.744 .709 .818 r
.61662 .39831 m .62645 .39154 L .63207 .40113 L p F P
0 g
s
0 0 .167 r
.83664 .86977 m .83901 .86325 L .83726 .86529 L closepath p F P
0 g
s
0 .004 .555 r
.60863 .70305 m .60749 .71102 L .61182 .72033 L p F P
0 g
s
0 0 .478 r
.60749 .71102 m .60863 .70305 L .60538 .69348 L p F P
0 g
s
.825 .715 .744 r
.71971 .32282 m .71883 .32398 L .72099 .32542 L closepath p F P
0 g
s
.76 .873 .929 r
.35648 .627 m .33489 .6398 L .34171 .64352 L p F P
0 g
s
.76 .873 .929 r
.34171 .64352 m .36322 .63062 L .35648 .627 L p F P
0 g
s
.769 .867 .921 r
.3308 .64237 m .33489 .6398 L .34171 .64352 L p F P
0 g
s
.161 .148 .594 r
.84868 .81656 m .85064 .81343 L .84648 .80346 L p F P
0 g
s
.129 .129 .589 r
.85101 .7954 m .84648 .80346 L .85064 .81343 L p F P
0 g
s
.228 .233 .657 r
.84513 .78593 m .85101 .7954 L .84648 .80346 L p F P
0 g
s
.797 .757 .817 r
.36855 .91698 m .37996 .90691 L .38914 .91141 L p F P
0 g
s
.782 .75 .824 r
.39045 .89799 m .37996 .90691 L .38914 .91141 L p F P
0 g
s
.782 .75 .824 r
.38914 .91141 m .39683 .90518 L .39045 .89799 L p F P
0 g
s
.503 0 0 r
.5474 .15918 m .53471 .15557 L .52489 .15536 L p F P
0 g
s
.458 0 0 r
.54985 .15926 m .5474 .15918 L .53471 .15557 L p F P
0 g
s
.304 .38 .775 r
.82584 .74164 m .82759 .73674 L p .83565 .75256 L F P
0 g
s
.335 .424 .804 r
.82584 .74164 m .82252 .73388 L .82759 .73674 L closepath p F P
0 g
s
.841 .569 .528 r
.69095 .21173 m .70286 .21713 L .70233 .22643 L p F P
0 g
s
.85 .579 .527 r
.7137 .23198 m .70233 .22643 L .70286 .21713 L p F P
0 g
s
.607 .739 .939 r
.63103 .61819 m .64194 .61594 L .63642 .60945 L p F P
0 g
s
.607 .739 .939 r
.63642 .60945 m .62599 .61168 L .63103 .61819 L p F P
0 g
s
.608 .742 .94 r
.61398 .61436 m .62599 .61168 L .63103 .61819 L p F P
0 g
s
.591 .655 .882 r
.68693 .9267 m .68681 .92651 L .6874 .92644 L closepath p F P
0 g
s
.503 0 0 r
.52242 .15866 m .5474 .15918 L p .52489 .15536 L F P
0 g
s
.503 0 0 r
.52489 .15536 m .52128 .15825 L .52242 .15866 L p F P
0 g
s
.483 .641 .926 r
.72187 .6431 m .70914 .64246 L .70383 .63497 L p F P
0 g
s
.533 .388 .63 r
.34822 .23827 m .34928 .24568 L .32974 .24791 L closepath p F P
0 g
s
.532 .388 .63 r
.34986 .24988 m .34928 .24568 L .32974 .24791 L p F P
0 g
s
.532 .388 .63 r
.33024 .26012 m .34986 .24988 L p .32974 .24791 L F P
0 g
s
.549 .554 .812 r
.46854 .61749 m .44842 .61811 L .46313 .60596 L closepath p F P
0 g
s
.439 .385 .701 r
.44842 .61811 m .46854 .61749 L .47007 .62352 L p F P
0 g
s
.595 .626 .852 r
.6874 .92644 m .68681 .92651 L .68128 .91674 L p F P
0 g
s
.945 .885 .743 r
.21881 .75687 m .21592 .74975 L .20832 .76241 L p F P
0 g
s
.945 .885 .743 r
.20832 .76241 m .21131 .76947 L .21881 .75687 L p F P
0 g
s
0 0 0 r
.83387 .87577 m .82458 .88937 L .81842 .89568 L p F P
0 g
s
0 0 0 r
.8155 .89935 m .82458 .88937 L .81842 .89568 L closepath p F P
0 g
s
.573 .046 0 r
.58286 .15993 m .58934 .16338 L .58025 .16202 L closepath p F P
0 g
s
.851 .621 .589 r
.72241 .24763 m .71159 .24192 L .7137 .23198 L p F P
0 g
s
.843 .641 .63 r
.71159 .24192 m .72241 .24763 L .7188 .25818 L p F P
0 g
s
.938 .779 .657 r
.43274 .76599 m .43552 .76886 L .43878 .77104 L p F P
0 g
s
.924 .799 .704 r
.43552 .76886 m .43878 .77104 L .43834 .77195 L closepath p F P
0 g
s
.96 .868 .702 r
.20955 .77302 m .21131 .76947 L .21263 .77215 L closepath p F P
0 g
s
.96 .868 .702 r
.20527 .78167 m .20955 .77302 L .21263 .77215 L p F P
0 g
s
.713 .69 .826 r
.56357 .41727 m .57656 .40992 L p .54871 .41248 L F P
0 g
s
.713 .69 .826 r
.54871 .41248 m .55043 .4154 L .56357 .41727 L p F P
0 g
s
.59 .654 .881 r
.70962 .9239 m .6874 .92644 L .70495 .91653 L closepath p F P
0 g
s
.595 .626 .852 r
.70419 .91534 m .70495 .91653 L .6874 .92644 L p F P
0 g
s
.595 .626 .852 r
.68128 .91674 m .70419 .91534 L p .6874 .92644 L F P
0 g
s
.457 .606 .91 r
.74925 .66097 m .74293 .6602 L .7377 .65211 L p F P
0 g
s
.843 .61 .585 r
.70233 .22643 m .7137 .23198 L .71159 .24192 L p F P
0 g
s
.728 .279 .184 r
.63041 .17671 m .62449 .17016 L .61231 .16727 L p F P
0 g
s
.71 .249 .153 r
.64381 .18008 m .63041 .17671 L .62449 .17016 L p F P
0 g
s
.71 .249 .153 r
.64456 .17863 m .64381 .18008 L p .62449 .17016 L F P
0 g
s
.921 .8 .709 r
.43834 .77195 m .43229 .78429 L .42666 .77836 L p F P
0 g
s
.921 .8 .709 r
.43552 .76886 m .43834 .77195 L p .42666 .77836 L F P
0 g
s
.544 .448 .696 r
.3327 .27271 m .33375 .27694 L .32404 .27804 L closepath p F P
0 g
s
.543 .447 .696 r
.33604 .28634 m .33375 .27694 L .32404 .27804 L p F P
0 g
s
.573 .551 .791 r
.64822 .89533 m .65236 .89312 L p .6724 .90588 L F P
0 g
s
.556 .544 .796 r
.64822 .89533 m .64721 .89299 L .65236 .89312 L closepath p F P
0 g
s
.995 .793 .519 r
.20514 .81816 m .20101 .81168 L .19903 .82281 L p F P
0 g
s
.995 .793 .519 r
.19903 .82281 m .20318 .82927 L .20514 .81816 L p F P
0 g
s
.79 .417 .35 r
.64616 .18079 m .66036 .18542 L .66355 .19315 L p F P
0 g
s
.797 .42 .342 r
.67727 .19794 m .66355 .19315 L .66036 .18542 L p F P
0 g
s
.317 .197 .554 r
.45956 .63295 m .47007 .62352 L .47094 .63486 L p F P
0 g
s
.317 .197 .554 r
.47094 .63486 m .46284 .64209 L .45956 .63295 L p F P
0 g
s
.669 .655 .827 r
.48088 .39216 m .4591 .40146 L .46521 .4123 L p F P
0 g
s
.669 .655 .827 r
.46521 .4123 m .48696 .403 L .48088 .39216 L p F P
0 g
s
.67 .656 .828 r
.493 .41367 m .48696 .403 L .46521 .4123 L p F P
0 g
s
.71 .839 .944 r
.40636 .60921 m .38475 .61943 L .39132 .62376 L p F P
0 g
s
.71 .839 .944 r
.39132 .62376 m .41285 .61371 L .40636 .60921 L p F P
0 g
s
.728 .846 .937 r
.39132 .62376 m .38475 .61943 L .36452 .6299 L p F P
0 g
s
.818 .707 .743 r
.71917 .30508 m .71426 .31145 L .71971 .32282 L p F P
0 g
s
.819 .706 .74 r
.70912 .31809 m .71426 .31145 L .71971 .32282 L p F P
0 g
s
.819 .706 .74 r
.71971 .32282 m .71883 .32398 L .70912 .31809 L p F P
0 g
s
.486 .171 .357 r
.4137 .18554 m .41528 .17829 L .39242 .18519 L p F P
0 g
s
.486 .171 .357 r
.39242 .18519 m .39075 .19244 L .4137 .18554 L p F P
0 g
s
.275 .285 .69 r
.61939 .74701 m .61307 .75621 L .6208 .76476 L p F P
0 g
s
.248 .232 .644 r
.61307 .75621 m .61939 .74701 L .61337 .73803 L p F P
0 g
s
.547 .755 .974 r
.29141 .93126 m .31223 .92843 L .319 .93358 L p F P
0 g
s
.549 .756 .973 r
.31223 .92843 m .29141 .93126 L .28453 .92619 L p F P
0 g
s
.883 .896 .835 r
.24788 .70967 m .24859 .70889 L .24884 .70987 L closepath p F P
0 g
s
.885 .894 .832 r
.23589 .72305 m .24788 .70967 L .24884 .70987 L p F P
0 g
s
.808 .713 .761 r
.70912 .31809 m .71883 .32398 L .70692 .33767 L p F P
0 g
s
.503 .246 .459 r
.39001 .20091 m .39075 .19244 L .36894 .20049 L p F P
0 g
s
.503 .246 .459 r
.36894 .20049 m .36813 .20896 L .39001 .20091 L p F P
0 g
s
.443 .39 .704 r
.61808 .80224 m .61756 .80028 L .61928 .8013 L closepath p F P
0 g
s
.56 .525 .774 r
.65236 .89312 m .64721 .89299 L .64146 .87813 L p F P
0 g
s
.683 .817 .947 r
.41285 .61371 m .4248 .6089 L .41725 .61709 L closepath p F P
0 g
s
.611 .578 .792 r
.35952 .35238 m .36391 .36211 L .38512 .35607 L p F P
0 g
s
.61 .578 .792 r
.38785 .3622 m .38512 .35607 L .36391 .36211 L p F P
0 g
s
.443 .392 .706 r
.61928 .8013 m .61808 .80224 L .62195 .81661 L p F P
0 g
s
.839 .687 .695 r
.72728 .29279 m .71741 .28687 L .72401 .27514 L p F P
0 g
s
.827 .695 .718 r
.71741 .28687 m .72728 .29279 L .71917 .30508 L p F P
0 g
s
.513 .678 .94 r
.68677 .62748 m .67551 .62777 L .67011 .62085 L p F P
0 g
s
.684 .668 .828 r
.493 .41367 m .49449 .41626 L .51961 .41434 L p F P
0 g
s
.898 .761 .701 r
.42624 .79667 m .43317 .80214 L .42701 .81458 L p F P
0 g
s
.897 .758 .7 r
.43317 .80214 m .42624 .79667 L .43229 .78429 L p F P
0 g
s
0 0 .126 r
.45406 .66319 m .45627 .65929 L .45479 .6684 L p F P
0 g
s
0 0 .126 r
.45479 .6684 m .45158 .67422 L .45406 .66319 L p F P
0 g
s
.726 .781 .896 r
.61398 .61436 m .60934 .61682 L .60322 .61061 L p F P
0 g
s
.793 .754 .817 r
.60934 .61682 m .59275 .63218 L .58925 .62934 L p F P
0 g
s
.793 .754 .817 r
.60322 .61061 m .60934 .61682 L p .58925 .62934 L F P
0 g
s
.863 .907 .861 r
.26372 .69399 m .24859 .70889 L .24719 .70111 L p F P
0 g
s
.863 .907 .861 r
.26266 .68609 m .26372 .69399 L p .24719 .70111 L F P
0 g
s
.843 .892 .874 r
.26266 .68609 m .26988 .68851 L .26372 .69399 L closepath p F P
0 g
s
.914 .721 .628 r
.59207 .63456 m .59275 .63218 L .58925 .62934 L closepath p F P
0 g
s
.835 .895 .883 r
.26988 .68851 m .28171 .67819 L p .26265 .68605 L F P
0 g
s
.835 .895 .883 r
.26265 .68605 m .26266 .68609 L .26988 .68851 L p F P
0 g
s
.899 .847 .391 r
.44728 .69383 m .44827 .68555 L .44442 .69711 L p F P
0 g
s
.899 .847 .391 r
.44442 .69711 m .44413 .70514 L .44728 .69383 L p F P
0 g
s
.732 .707 .827 r
.60436 .40615 m .61662 .39831 L .60284 .39395 L p F P
0 g
s
.732 .707 .827 r
.60284 .39395 m .59865 .39661 L .60436 .40615 L p F P
0 g
s
.851 .737 .737 r
.41908 .86362 m .41257 .87304 L .40625 .86527 L p F P
0 g
s
.851 .737 .737 r
.40625 .86527 m .41053 .85881 L .41908 .86362 L p F P
0 g
s
.85 .737 .738 r
.41908 .86362 m .41053 .85881 L .41935 .84554 L p F P
0 g
s
.836 .718 .734 r
.42924 .83272 m .42864 .8318 L .42832 .83227 L closepath p F P
0 g
s
.135 .53 .918 r
.25752 .91594 m .26918 .91945 L .26283 .91406 L p F P
0 g
s
.135 .53 .918 r
.26283 .91406 m .25056 .91024 L .25752 .91594 L p F P
0 g
s
0 .187 .654 r
.24671 .90751 m .25056 .91024 L .25752 .91594 L p F P
0 g
s
.835 .895 .883 r
.28171 .67819 m .28134 .66998 L .26265 .68605 L p F P
0 g
s
.817 .89 .896 r
.29165 .6703 m .28171 .67819 L .28134 .66998 L p F P
0 g
s
.329 .424 .807 r
.82759 .73674 m .82252 .73388 L .81723 .72168 L p F P
0 g
s
.757 .718 .816 r
.65319 .38357 m .65413 .38517 L .65509 .38446 L closepath p F P
0 g
s
.75 .712 .816 r
.65413 .38517 m .65319 .38357 L .64344 .37936 L p F P
0 g
s
.886 .908 .837 r
.24788 .70967 m .24859 .70889 L .24719 .70111 L p F P
0 g
s
.701 .685 .832 r
.54871 .41248 m .54384 .41502 L .55043 .4154 L closepath p F P
0 g
s
.766 .785 .868 r
.3573 .92391 m .34694 .93053 L .3403 .92501 L p F P
0 g
s
.69 .782 .921 r
.319 .93358 m .3403 .92501 L .34694 .93053 L p F P
0 g
s
.886 .908 .837 r
.24719 .70111 m .24042 .70845 L .24788 .70967 L p F P
0 g
s
.885 .905 .837 r
.24788 .70967 m .23589 .72305 L .23401 .71546 L p F P
0 g
s
.885 .905 .837 r
.23401 .71546 m .24042 .70845 L .24788 .70967 L p F P
0 g
s
.764 .712 .803 r
.65509 .38446 m .67572 .36768 L .66481 .36229 L p F P
0 g
s
.764 .712 .803 r
.65319 .38357 m .65509 .38446 L p .66481 .36229 L F P
0 g
s
0 0 .057 r
.83901 .86325 m .84559 .85498 L p .83591 .87361 L F P
0 g
s
0 0 .057 r
.83591 .87361 m .83664 .86977 L .83901 .86325 L p F P
0 g
s
0 0 .304 r
.83901 .86325 m .84559 .85498 L .84769 .84322 L p F P
0 g
s
.851 .743 .743 r
.42832 .83227 m .42864 .8318 L .42238 .82381 L p F P
0 g
s
.39 .503 .852 r
.78904 .69332 m .80579 .69927 L .80438 .70707 L p F P
0 g
s
.372 .509 .866 r
.78991 .68559 m .78904 .69332 L .80579 .69927 L p F P
0 g
s
.412 .539 .875 r
.77706 .68209 m .78991 .68559 L .78904 .69332 L p F P
0 g
s
.99 .888 .61 r
.44149 .72419 m .43999 .71681 L .43516 .72873 L p F P
0 g
s
.99 .888 .61 r
.43516 .72873 m .43724 .73591 L .44149 .72419 L p F P
0 g
s
.168 .199 .65 r
.84906 .77792 m .84513 .78593 L .85101 .7954 L p F P
0 g
s
.253 .284 .7 r
.8415 .76896 m .84906 .77792 L .84513 .78593 L p F P
0 g
s
.86 .75 .74 r
.42009 .82727 m .42832 .83227 L .41935 .84554 L p F P
0 g
s
.851 .743 .743 r
.42238 .82381 m .42009 .82727 L .42832 .83227 L p F P
0 g
s
.749 .313 .215 r
.64456 .17863 m .64616 .18079 L .64381 .18008 L closepath p F P
0 g
s
.443 .392 .706 r
.62195 .81661 m .63205 .80871 L .61928 .8013 L p F P
0 g
s
.421 .397 .727 r
.63082 .79094 m .61928 .8013 L .63205 .80871 L p F P
0 g
s
.456 .386 .69 r
.62073 .78287 m .63082 .79094 L .61928 .8013 L p F P
0 g
s
.608 .741 .939 r
.61398 .61436 m .62599 .61168 L .61991 .60543 L p F P
0 g
s
.608 .741 .939 r
.61991 .60543 m .60836 .60797 L .61398 .61436 L p F P
0 g
s
.726 .781 .896 r
.60322 .61061 m .60836 .60797 L .61398 .61436 L p F P
0 g
s
.051 0 .431 r
.85034 .82813 m .84741 .83214 L .84769 .84322 L p F P
0 g
s
.141 .089 .533 r
.84741 .83214 m .85034 .82813 L .84868 .81656 L p F P
0 g
s
.952 .703 .525 r
.59207 .63456 m .58925 .62934 L p .58483 .63688 L F P
0 g
s
.952 .703 .525 r
.58483 .63688 m .59128 .64294 L .59207 .63456 L p F P
0 g
s
.652 .63 .816 r
.43135 .39871 m .4318 .39957 L .45421 .39268 L p F P
0 g
s
.655 .645 .828 r
.4591 .40146 m .45421 .39268 L .4318 .39957 L p F P
0 g
s
.699 .679 .827 r
.54384 .41502 m .54871 .41248 L p .52084 .41375 L F P
0 g
s
.699 .679 .827 r
.52084 .41375 m .52114 .41425 L .54384 .41502 L p F P
0 g
s
.683 .665 .826 r
.50887 .39266 m .48696 .403 L .493 .41367 L p F P
0 g
s
.683 .665 .826 r
.493 .41367 m .51487 .40329 L .50887 .39266 L p F P
0 g
s
.684 .668 .828 r
.52084 .41375 m .51487 .40329 L .493 .41367 L p F P
0 g
s
.684 .668 .828 r
.51961 .41434 m .52084 .41375 L p .493 .41367 L F P
0 g
s
.765 .307 0 r
.22138 .87844 m .21613 .87256 L .2214 .88188 L p F P
0 g
s
.765 .307 0 r
.2214 .88188 m .22671 .88773 L .22138 .87844 L p F P
0 g
s
.833 .515 .452 r
.69095 .21173 m .6793 .20686 L .67925 .19869 L p F P
0 g
s
.819 .504 .457 r
.67727 .19794 m .67925 .19869 L .6793 .20686 L p F P
0 g
s
.632 .604 .803 r
.39754 .38219 m .39843 .38404 L .41918 .37532 L p F P
0 g
s
.637 .621 .817 r
.42518 .38687 m .41918 .37532 L .39843 .38404 L p F P
0 g
s
.484 .419 .708 r
.62195 .81661 m .63205 .80871 L p .63288 .82653 L F P
0 g
s
.484 .419 .708 r
.63288 .82653 m .6236 .82271 L .62195 .81661 L p F P
0 g
s
.808 .713 .761 r
.70692 .33767 m .69701 .33187 L .70912 .31809 L p F P
0 g
s
.793 .714 .777 r
.69805 .34676 m .70692 .33767 L .69701 .33187 L p F P
0 g
s
.815 .898 .901 r
.3041 .65259 m .28452 .66749 L .29165 .6703 L p F P
0 g
s
.815 .898 .901 r
.29165 .6703 m .30348 .66118 L .3041 .65259 L p F P
0 g
s
.817 .89 .896 r
.28134 .66998 m .28452 .66749 L .29165 .6703 L p F P
0 g
s
.082 .047 .515 r
.85064 .81343 m .84868 .81656 L .85034 .82813 L p F P
0 g
s
.266 .623 .96 r
.28453 .92619 m .2759 .92467 L .26918 .91945 L p F P
0 g
s
.743 .863 .936 r
.36322 .63062 m .36452 .6299 L .36406 .6311 L closepath p F P
0 g
s
.651 .629 .814 r
.44682 .37844 m .42518 .38687 L .43135 .39871 L p F P
0 g
s
.651 .629 .814 r
.43135 .39871 m .45297 .39031 L .44682 .37844 L p F P
0 g
s
.652 .63 .816 r
.45421 .39268 m .45297 .39031 L .43135 .39871 L p F P
0 g
s
.551 .427 .664 r
.35235 .2625 m .34986 .24988 L .33024 .26012 L p F P
0 g
s
.551 .427 .664 r
.33024 .26012 m .3327 .27271 L .35235 .2625 L p F P
0 g
s
.903 .518 .083 r
.21313 .8627 m .20825 .85663 L .21123 .86652 L p F P
0 g
s
.903 .518 .083 r
.21123 .86652 m .21613 .87256 L .21313 .8627 L p F P
0 g
s
.694 .788 .923 r
.3403 .92501 m .319 .93358 L .31223 .92843 L p F P
0 g
s
.56 .525 .774 r
.64146 .87813 m .64166 .87802 L p .65236 .89312 L F P
0 g
s
.54 .516 .777 r
.64146 .87813 m .6414 .87799 L .64166 .87802 L closepath p F P
0 g
s
.784 .72 .793 r
.69269 .35219 m .67615 .3673 L .67665 .36819 L p F P
0 g
s
.781 .719 .795 r
.67615 .3673 m .67572 .36768 L .67665 .36819 L closepath p F P
0 g
s
.545 .5 .756 r
.64166 .87802 m .6414 .87799 L .63572 .8619 L p F P
0 g
s
.728 .279 .184 r
.61397 .17286 m .63041 .17671 L p .61231 .16727 L F P
0 g
s
.728 .279 .184 r
.61231 .16727 m .61102 .16934 L .61397 .17286 L p F P
0 g
s
.674 .215 .153 r
.60778 .16645 m .61231 .16727 L .61102 .16934 L closepath p F P
0 g
s
.764 .712 .803 r
.66481 .36229 m .64856 .37536 L .65319 .38357 L p F P
0 g
s
.76 .711 .806 r
.64856 .37536 m .64344 .37936 L .65319 .38357 L closepath p F P
0 g
s
.604 .935 .955 r
.78013 .92296 m .77065 .92757 L .76582 .92503 L p F P
0 g
s
.602 .884 .991 r
.74298 .93216 m .76582 .92503 L .77065 .92757 L p F P
0 g
s
.721 .695 .825 r
.57656 .40992 m .59865 .39661 L p .58724 .3902 L F P
0 g
s
.721 .695 .825 r
.58724 .3902 m .57075 .40006 L .57656 .40992 L p F P
0 g
s
.713 .69 .826 r
.57656 .40992 m .57075 .40006 L .54871 .41248 L p F P
0 g
s
.56 .525 .774 r
.64166 .87802 m .66423 .88015 L p .65236 .89312 L F P
0 g
s
.538 .518 .781 r
.66423 .88015 m .64166 .87802 L .65931 .86773 L closepath p F P
0 g
s
.545 .5 .756 r
.65841 .86546 m .65931 .86773 L .64166 .87802 L p F P
0 g
s
.545 .5 .756 r
.63635 .86152 m .65841 .86546 L p .64166 .87802 L F P
0 g
s
.545 .5 .756 r
.63572 .8619 m .63635 .86152 L p .64166 .87802 L F P
0 g
s
.632 .602 .802 r
.41279 .362 m .39133 .36939 L .39754 .38219 L p F P
0 g
s
.632 .602 .802 r
.39754 .38219 m .41898 .37491 L .41279 .362 L p F P
0 g
s
.632 .604 .803 r
.41918 .37532 m .41898 .37491 L .39754 .38219 L p F P
0 g
s
.474 .426 .724 r
.62614 .83131 m .6236 .82271 L .63288 .82653 L closepath p F P
0 g
s
.53 .028 0 r
.23237 .89343 m .22671 .88773 L .23489 .89634 L p F P
0 g
s
.53 .028 0 r
.23489 .89634 m .24063 .902 L .23237 .89343 L p F P
0 g
s
.398 .539 .88 r
.78991 .68559 m .77706 .68209 L .77184 .67285 L p F P
0 g
s
.686 .674 .832 r
.52084 .41375 m .51961 .41434 L .52114 .41425 L closepath p F P
0 g
s
.793 .714 .777 r
.69701 .33187 m .69259 .33634 L .69805 .34676 L p F P
0 g
s
.792 .711 .775 r
.68236 .34656 m .69259 .33634 L .69805 .34676 L p F P
0 g
s
.792 .711 .775 r
.69805 .34676 m .69269 .35219 L .68236 .34656 L p F P
0 g
s
.81 .497 .461 r
.66355 .19315 m .67727 .19794 L .67842 .20653 L p F P
0 g
s
.819 .504 .457 r
.6793 .20686 m .67842 .20653 L .67727 .19794 L p F P
0 g
s
.482 .078 .197 r
.46451 .16833 m .43935 .17269 L .44196 .16696 L p F P
0 g
s
.482 .078 .197 r
.46525 .16648 m .46451 .16833 L p .44196 .16696 L F P
0 g
s
.482 .078 .197 r
.44196 .16696 m .45505 .16468 L .46525 .16648 L p F P
0 g
s
.842 .667 .665 r
.72401 .27514 m .71365 .26933 L .7188 .25818 L p F P
0 g
s
.831 .678 .693 r
.71365 .26933 m .72401 .27514 L .71741 .28687 L p F P
0 g
s
.604 .557 .775 r
.35772 .34801 m .35952 .35238 L .37893 .3422 L p F P
0 g
s
.611 .578 .792 r
.38512 .35607 m .37893 .3422 L .35952 .35238 L p F P
0 g
s
.963 .818 .653 r
.43707 .75417 m .43281 .74773 L .4282 .75966 L p F P
0 g
s
.963 .818 .653 r
.4282 .75966 m .43274 .76599 L .43707 .75417 L p F P
0 g
s
.596 .769 .962 r
.71497 .93136 m .73786 .92701 L .74298 .93216 L p F P
0 g
s
.582 .722 .939 r
.73786 .92701 m .71497 .93136 L .70962 .9239 L p F P
0 g
s
.993 .876 .569 r
.44249 .71041 m .44413 .70514 L .44486 .70775 L closepath p F P
0 g
s
.973 .915 .584 r
.43999 .71681 m .44249 .71041 L .44486 .70775 L p F P
0 g
s
.777 .711 .79 r
.67615 .3673 m .67572 .36768 L .66481 .36229 L p F P
0 g
s
.779 .713 .79 r
.67615 .3673 m .69269 .35219 L .68236 .34656 L p F P
0 g
s
.779 .713 .79 r
.68236 .34656 m .67063 .35714 L .67615 .3673 L p F P
0 g
s
.777 .711 .79 r
.66481 .36229 m .67063 .35714 L .67615 .3673 L p F P
0 g
s
.698 .677 .826 r
.53689 .39193 m .51487 .40329 L .52084 .41375 L p F P
0 g
s
.698 .677 .826 r
.52084 .41375 m .54282 .40231 L .53689 .39193 L p F P
0 g
s
.699 .679 .827 r
.54871 .41248 m .54282 .40231 L .52084 .41375 L p F P
0 g
s
.508 .447 .723 r
.62614 .83131 m .63288 .82653 L p .63396 .84422 L F P
0 g
s
.508 .447 .723 r
.63396 .84422 m .62959 .843 L .62614 .83131 L p F P
0 g
s
.962 .883 .708 r
.21131 .76947 m .20832 .76241 L .20207 .77471 L p F P
0 g
s
.962 .883 .708 r
.20955 .77302 m .21131 .76947 L p .20207 .77471 L F P
0 g
s
.573 .551 .791 r
.65236 .89312 m .66998 .89359 L p .6724 .90588 L F P
0 g
s
.556 .543 .796 r
.66998 .89359 m .65236 .89312 L .66652 .88549 L closepath p F P
0 g
s
.56 .525 .774 r
.66423 .88015 m .66652 .88549 L .65236 .89312 L p F P
0 g
s
.901 .902 .816 r
.23589 .72305 m .23401 .71546 L .2229 .72918 L p F P
0 g
s
.901 .902 .816 r
.22538 .73616 m .23589 .72305 L p .2229 .72918 L F P
0 g
s
.818 .743 .782 r
.40869 .87732 m .41257 .87304 L .40625 .86527 L p F P
0 g
s
.792 .883 .912 r
.31329 .65425 m .30348 .66118 L .3041 .65259 L p F P
0 g
s
.711 .688 .826 r
.56491 .38997 m .54282 .40231 L .54871 .41248 L p F P
0 g
s
.711 .688 .826 r
.54871 .41248 m .57075 .40006 L .56491 .38997 L p F P
0 g
s
.671 .219 .169 r
.58934 .16338 m .60778 .16645 L .61102 .16934 L p F P
0 g
s
.741 .702 .814 r
.62645 .39154 m .61662 .39831 L .60284 .39395 L p F P
0 g
s
.766 .785 .868 r
.3403 .92501 m .34914 .91914 L .3573 .92391 L p F P
0 g
s
.753 .777 .872 r
.362 .91092 m .34914 .91914 L .3573 .92391 L p F P
0 g
s
.753 .777 .872 r
.3573 .92391 m .36855 .91698 L .362 .91092 L p F P
0 g
s
.991 .833 .589 r
.20432 .80022 m .20061 .79351 L .19726 .80501 L p F P
0 g
s
.991 .833 .589 r
.19726 .80501 m .20101 .81168 L .20432 .80022 L p F P
0 g
s
.742 .871 .94 r
.36923 .61993 m .35648 .627 L .36322 .63062 L p F P
0 g
s
.742 .871 .94 r
.36322 .63062 m .36452 .6299 L .36923 .61993 L p F P
0 g
s
.435 .581 .899 r
.76664 .66428 m .74925 .66097 L p .77137 .67273 L F P
0 g
s
.417 .576 .903 r
.74925 .66097 m .76664 .66428 L .76143 .65597 L p F P
0 g
s
.417 .576 .903 r
.76143 .65597 m .74857 .65347 L .74925 .66097 L p F P
0 g
s
.457 .606 .91 r
.7377 .65211 m .74857 .65347 L .74925 .66097 L p F P
0 g
s
.521 .487 .759 r
.63572 .8619 m .63553 .86137 L .63635 .86152 L closepath p F P
0 g
s
.605 .559 .776 r
.35772 .34801 m .37892 .34216 L p .3559 .33184 L F P
0 g
s
.605 .559 .776 r
.3559 .33184 m .35191 .33393 L .35772 .34801 L p F P
0 g
s
.604 .557 .775 r
.37893 .3422 m .37892 .34216 L .35772 .34801 L p F P
0 g
s
.907 .597 .107 r
.59837 .66937 m .59682 .65956 L p .60169 .67636 L F P
0 g
s
.907 .597 .107 r
.60169 .67636 m .59842 .66957 L .59837 .66937 L p F P
0 g
s
.528 .474 .74 r
.63635 .86152 m .63553 .86137 L .63068 .84636 L p F P
0 g
s
.834 .759 .78 r
.39982 .87263 m .40869 .87732 L .39594 .89168 L p F P
0 g
s
.818 .743 .782 r
.40625 .86527 m .39982 .87263 L .40869 .87732 L p F P
0 g
s
.73 .855 .94 r
.38475 .61943 m .36452 .6299 L .36923 .61993 L p F P
0 g
s
.528 .474 .74 r
.63068 .84636 m .63396 .84422 L p .63635 .86152 L F P
0 g
s
.5 .457 .741 r
.63068 .84636 m .62959 .843 L .63396 .84422 L closepath p F P
0 g
s
.968 .656 .273 r
.20716 .84628 m .20265 .84002 L .20373 .85039 L p F P
0 g
s
.968 .656 .273 r
.20373 .85039 m .20825 .85663 L .20716 .84628 L p F P
0 g
s
.827 .695 .718 r
.71917 .30508 m .70914 .29923 L .71741 .28687 L p F P
0 g
s
.812 .701 .742 r
.71426 .31145 m .71917 .30508 L .70914 .29923 L p F P
0 g
s
.202 .261 .701 r
.84484 .76101 m .8415 .76896 L .84906 .77792 L p F P
0 g
s
.279 .333 .739 r
.83565 .75256 m .84484 .76101 L .8415 .76896 L p F P
0 g
s
.139 .192 .656 r
.61649 .72976 m .61337 .73803 L .61939 .74701 L p F P
0 g
s
.119 .172 .643 r
.61638 .72935 m .61182 .72033 L p .61337 .73803 L F P
0 g
s
.119 .172 .643 r
.61337 .73803 m .61649 .72976 L .61638 .72935 L p F P
0 g
s
.335 .458 .837 r
.80438 .70707 m .81186 .71045 L .80658 .69964 L p F P
0 g
s
.335 .458 .837 r
.80658 .69964 m .80579 .69927 L .80438 .70707 L p F P
0 g
s
.539 .699 .943 r
.64194 .61594 m .66468 .61412 L .67011 .62085 L p F P
0 g
s
.535 .706 .949 r
.66468 .61412 m .64194 .61594 L .63642 .60945 L p F P
0 g
s
.537 .359 .587 r
.36905 .22914 m .36818 .21853 L .3474 .22768 L p F P
0 g
s
.537 .359 .587 r
.3474 .22768 m .34822 .23827 L .36905 .22914 L p F P
0 g
s
.936 .781 .663 r
.43244 .76678 m .43274 .76599 L .43552 .76886 L closepath p F P
0 g
s
.921 .8 .709 r
.42666 .77836 m .43244 .76678 L .43552 .76886 L p F P
0 g
s
.919 .793 .705 r
.43229 .78429 m .42666 .77836 L .42048 .79081 L p F P
0 g
s
.919 .793 .705 r
.42048 .79081 m .42624 .79667 L .43229 .78429 L p F P
0 g
s
0 0 .12 r
.83387 .87577 m .83591 .87361 L .83664 .86977 L closepath p F P
0 g
s
.518 .492 .767 r
.65841 .86546 m .63635 .86152 L .65304 .85087 L closepath p F P
0 g
s
.528 .474 .74 r
.65252 .84948 m .65304 .85087 L .63635 .86152 L p F P
0 g
s
.528 .474 .74 r
.63396 .84422 m .65252 .84948 L p .63635 .86152 L F P
0 g
s
.604 .831 .986 r
.76582 .92503 m .74298 .93216 L .73786 .92701 L p F P
0 g
s
.843 .641 .63 r
.7188 .25818 m .70792 .2525 L .71159 .24192 L p F P
0 g
s
.834 .657 .663 r
.70792 .2525 m .7188 .25818 L .71365 .26933 L p F P
0 g
s
.55 .609 .865 r
.70419 .91534 m .68128 .91674 L .67567 .90579 L p F P
0 g
s
.831 .561 .53 r
.6793 .20686 m .69095 .21173 L .69038 .22104 L p F P
0 g
s
.841 .569 .528 r
.70233 .22643 m .69038 .22104 L .69095 .21173 L p F P
0 g
s
.793 .754 .817 r
.58925 .62934 m .58631 .62532 L .60322 .61061 L p F P
0 g
s
.952 .703 .525 r
.58925 .62934 m .586 .6262 L .58483 .63688 L p F P
0 g
s
.926 .754 .65 r
.586 .6262 m .58925 .62934 L .58631 .62532 L closepath p F P
0 g
s
.781 .414 .361 r
.64381 .18008 m .64616 .18079 L .64926 .18852 L p F P
0 g
s
.79 .417 .35 r
.66355 .19315 m .64926 .18852 L .64616 .18079 L p F P
0 g
s
.962 .883 .708 r
.20207 .77471 m .20241 .7755 L .20955 .77302 L p F P
0 g
s
.963 .875 .7 r
.20241 .7755 m .20955 .77302 L .20527 .78167 L closepath p F P
0 g
s
.787 .891 .919 r
.32797 .63654 m .30628 .65107 L .31329 .65425 L p F P
0 g
s
.787 .891 .919 r
.3317 .63816 m .32797 .63654 L p .31329 .65425 L F P
0 g
s
.787 .891 .919 r
.31329 .65425 m .3308 .64237 L .3317 .63816 L p F P
0 g
s
.792 .883 .912 r
.3041 .65259 m .30628 .65107 L .31329 .65425 L p F P
0 g
s
0 .196 .673 r
.25056 .91024 m .24671 .90751 L .24063 .902 L p F P
0 g
s
.604 .935 .955 r
.78964 .91561 m .78013 .92296 L p .76582 .92503 L F P
0 g
s
.642 .96 .921 r
.78013 .92296 m .78964 .91561 L .79323 .91601 L closepath p F P
0 g
s
.746 .706 .814 r
.62645 .39154 m .64344 .37936 L .63086 .37454 L p F P
0 g
s
.746 .706 .814 r
.63086 .37454 m .62079 .38168 L .62645 .39154 L p F P
0 g
s
.741 .702 .814 r
.60284 .39395 m .62079 .38168 L .62645 .39154 L p F P
0 g
s
.866 .757 .741 r
.41142 .84049 m .41935 .84554 L .41053 .85881 L p F P
0 g
s
.86 .75 .74 r
.41935 .84554 m .41142 .84049 L .42009 .82727 L p F P
0 g
s
.898 .762 .703 r
.42701 .81458 m .42238 .82381 L .41602 .81739 L p F P
0 g
s
.898 .762 .703 r
.41602 .81739 m .42013 .80912 L .42701 .81458 L p F P
0 g
s
.898 .761 .701 r
.42701 .81458 m .42013 .80912 L .42624 .79667 L p F P
0 g
s
.329 .424 .807 r
.81723 .72168 m .81727 .72154 L p .82759 .73674 L F P
0 g
s
.36 .464 .832 r
.81723 .72168 m .81714 .72148 L .81727 .72154 L closepath p F P
0 g
s
.478 .064 .175 r
.45505 .16468 m .46709 .16271 L .46525 .16648 L closepath p F P
0 g
s
.812 .701 .742 r
.70914 .29923 m .70875 .29971 L .71426 .31145 L p F P
0 g
s
.812 .697 .739 r
.69876 .31238 m .70875 .29971 L .71426 .31145 L p F P
0 g
s
.812 .697 .739 r
.71426 .31145 m .70912 .31809 L .69876 .31238 L p F P
0 g
s
.781 .414 .361 r
.64926 .18852 m .6426 .18655 L .64381 .18008 L p F P
0 g
s
.762 .395 .359 r
.63041 .17671 m .64381 .18008 L .6426 .18655 L p F P
0 g
s
.352 .466 .836 r
.81727 .72154 m .81714 .72148 L .81186 .71045 L p F P
0 g
s
.232 .316 .744 r
.83841 .74466 m .83565 .75256 L .84484 .76101 L p F P
0 g
s
.304 .38 .775 r
.82759 .73674 m .83841 .74466 L .83565 .75256 L p F P
0 g
s
.843 .61 .585 r
.71159 .24192 m .70018 .23639 L .70233 .22643 L p F P
0 g
s
.835 .632 .628 r
.70018 .23639 m .71159 .24192 L .70792 .2525 L p F P
0 g
s
.834 .601 .585 r
.69038 .22104 m .70233 .22643 L .70018 .23639 L p F P
0 g
s
.329 .424 .807 r
.81727 .72154 m .82979 .7289 L .82759 .73674 L p F P
0 g
s
.29 .411 .813 r
.81896 .71375 m .81727 .72154 L .82979 .7289 L p F P
0 g
s
.352 .466 .836 r
.81186 .71045 m .81896 .71375 L .81727 .72154 L p F P
0 g
s
.667 .651 .824 r
.45421 .39268 m .4591 .40146 L .48088 .39216 L p F P
0 g
s
.834 .759 .78 r
.39594 .89168 m .38769 .88685 L .39982 .87263 L p F P
0 g
s
.836 .758 .778 r
.39594 .89168 m .39045 .89799 L .38401 .89123 L p F P
0 g
s
.836 .758 .778 r
.38401 .89123 m .38769 .88685 L .39594 .89168 L p F P
0 g
s
.567 .463 .695 r
.35475 .27229 m .35235 .2625 L .3327 .27271 L p F P
0 g
s
.567 .463 .695 r
.3327 .27271 m .33375 .27694 L .35475 .27229 L p F P
0 g
s
.961 .628 .261 r
.59682 .65956 m .59837 .66937 L .59254 .65737 L p F P
0 g
s
.961 .628 .261 r
.59254 .65737 m .59188 .65312 L .59682 .65956 L p F P
0 g
s
.979 .683 .362 r
.59682 .65956 m .59188 .65312 L .59128 .64294 L p F P
0 g
s
.807 .771 .819 r
.37996 .90691 m .36855 .91698 L .362 .91092 L p F P
0 g
s
.458 .079 .23 r
.41565 .17739 m .41836 .17755 L .41528 .17829 L closepath p F P
0 g
s
.261 .365 .781 r
.82979 .7289 m .82759 .73674 L .83841 .74466 L p F P
0 g
s
.901 .902 .816 r
.2229 .72918 m .2248 .73611 L .22538 .73616 L p F P
0 g
s
.905 .898 .809 r
.2248 .73611 m .22538 .73616 L .22498 .73667 L closepath p F P
0 g
s
0 0 .228 r
.45627 .65929 m .46172 .65268 L .45847 .664 L p F P
0 g
s
0 0 .228 r
.45847 .664 m .45479 .6684 L .45627 .65929 L p F P
0 g
s
.807 .771 .819 r
.362 .91092 m .37161 .90215 L .37996 .90691 L p F P
0 g
s
.794 .763 .825 r
.38401 .89123 m .37161 .90215 L .37996 .90691 L p F P
0 g
s
.794 .763 .825 r
.37996 .90691 m .39045 .89799 L .38401 .89123 L p F P
0 g
s
.927 .907 .782 r
.22498 .73667 m .21592 .74975 L .21351 .7424 L p F P
0 g
s
.927 .907 .782 r
.2248 .73611 m .22498 .73667 L p .21351 .7424 L F P
0 g
s
.638 .73 .915 r
.45623 .59776 m .43447 .60515 L .44079 .61116 L p F P
0 g
s
.638 .73 .915 r
.44079 .61116 m .46246 .60494 L .45623 .59776 L p F P
0 g
s
.599 .649 .871 r
.44079 .61116 m .46246 .60494 L .46313 .60596 L p F P
0 g
s
.677 .805 .944 r
.44079 .61116 m .43447 .60515 L .4248 .6089 L p F P
0 g
s
.565 .46 .693 r
.35568 .27614 m .35475 .27229 L .33375 .27694 L p F P
0 g
s
.565 .46 .693 r
.33375 .27694 m .33604 .28634 L .35568 .27614 L p F P
0 g
s
0 0 0 r
.83591 .87361 m .83387 .87577 L .82458 .88937 L p F P
0 g
s
.365 .353 .713 r
.62866 .77354 m .62073 .78287 L .63082 .79094 L p F P
0 g
s
.42 .351 .674 r
.62852 .77307 m .62866 .77354 L .62073 .78287 L p F P
0 g
s
.42 .351 .674 r
.6208 .76476 m .62852 .77307 L p .62073 .78287 L F P
0 g
s
.596 .535 .757 r
.35157 .333 m .3559 .33184 L .35191 .33393 L closepath p F P
0 g
s
.993 .744 .407 r
.20318 .82927 m .19903 .82281 L .1985 .83359 L p F P
0 g
s
.993 .744 .407 r
.1985 .83359 m .20265 .84002 L .20318 .82927 L p F P
0 g
s
.598 .538 .758 r
.35157 .333 m .3559 .33184 L p .34646 .31639 L F P
0 g
s
.598 .538 .758 r
.34646 .31639 m .34555 .31686 L .35157 .333 L p F P
0 g
s
.483 .641 .926 r
.70383 .63497 m .72006 .6358 L .72187 .6431 L p F P
0 g
s
.475 .646 .933 r
.72006 .6358 m .70383 .63497 L .69851 .6277 L p F P
0 g
s
.447 .609 .917 r
.74857 .65347 m .7377 .65211 L .73245 .64422 L p F P
0 g
s
.677 .243 .211 r
.58025 .16202 m .58934 .16338 L .59576 .16967 L p F P
0 g
s
.671 .219 .169 r
.60979 .17197 m .59576 .16967 L .58934 .16338 L p F P
0 g
s
.671 .219 .169 r
.61102 .16934 m .60979 .17197 L p .58934 .16338 L F P
0 g
s
0 0 .03 r
.45158 .67422 m .45479 .6684 L .45282 .67712 L p F P
0 g
s
0 0 .03 r
.45282 .67712 m .44827 .68555 L .45158 .67422 L p F P
0 g
s
.798 .7 .757 r
.69701 .33187 m .70912 .31809 L .69876 .31238 L p F P
0 g
s
.927 .908 .783 r
.21763 .73658 m .2229 .72918 L .2248 .73611 L closepath p F P
0 g
s
.927 .907 .782 r
.21351 .7424 m .21763 .73658 L .2248 .73611 L p F P
0 g
s
.945 .904 .517 r
.44413 .70514 m .44442 .69711 L .44018 .70884 L p F P
0 g
s
.945 .904 .517 r
.44249 .71041 m .44413 .70514 L p .44018 .70884 L F P
0 g
s
.683 .817 .947 r
.42808 .60001 m .40636 .60921 L .41285 .61371 L p F P
0 g
s
.683 .817 .947 r
.43098 .60227 m .42808 .60001 L p .41285 .61371 L F P
0 g
s
.683 .817 .947 r
.41285 .61371 m .4248 .6089 L .43098 .60227 L p F P
0 g
s
.082 .047 .515 r
.85034 .82813 m .85296 .82396 L .85064 .81343 L p F P
0 g
s
.042 .022 .505 r
.85516 .80541 m .85064 .81343 L .85296 .82396 L p F P
0 g
s
.129 .129 .589 r
.85064 .81343 m .85516 .80541 L .85101 .7954 L p F P
0 g
s
.449 .618 .923 r
.72187 .6431 m .73245 .64422 L .72718 .63656 L p F P
0 g
s
.449 .618 .923 r
.72718 .63656 m .72006 .6358 L .72187 .6431 L p F P
0 g
s
.632 .603 .802 r
.38785 .3622 m .39133 .36939 L .41279 .362 L p F P
0 g
s
.831 .678 .693 r
.71741 .28687 m .70692 .28111 L .71365 .26933 L p F P
0 g
s
.816 .683 .718 r
.70914 .29923 m .71741 .28687 L .70692 .28111 L p F P
0 g
s
.987 .878 .631 r
.43724 .73591 m .43516 .72873 L .4302 .74074 L p F P
0 g
s
.987 .878 .631 r
.4302 .74074 m .43281 .74773 L .43724 .73591 L p F P
0 g
s
.488 .662 .939 r
.68677 .62748 m .69851 .6277 L .69315 .62063 L p F P
0 g
s
.488 .662 .939 r
.69315 .62063 m .68358 .62048 L .68677 .62748 L p F P
0 g
s
.513 .678 .94 r
.67011 .62085 m .68358 .62048 L .68677 .62748 L p F P
0 g
s
.956 .655 .423 r
.59128 .64294 m .58483 .63688 L .58539 .64709 L p F P
0 g
s
.956 .655 .423 r
.58539 .64709 m .59188 .65312 L .59128 .64294 L p F P
0 g
s
.493 .464 .754 r
.65252 .84948 m .63396 .84422 L .64744 .83468 L closepath p F P
0 g
s
.508 .447 .723 r
.64659 .8322 m .64744 .83468 L .63396 .84422 L p F P
0 g
s
.508 .447 .723 r
.63288 .82653 m .64659 .8322 L p .63396 .84422 L F P
0 g
s
0 .029 .574 r
.61638 .72935 m .61182 .72033 L .6124 .71516 L closepath p F P
0 g
s
0 .004 .555 r
.61032 .7074 m .60863 .70305 L p .61182 .72033 L F P
0 g
s
0 .004 .555 r
.61182 .72033 m .6124 .71516 L .61032 .7074 L p F P
0 g
s
.525 .207 .37 r
.42891 .18193 m .4137 .18554 L .41528 .17829 L p F P
0 g
s
.525 .207 .37 r
.41528 .17829 m .41836 .17755 L .42891 .18193 L p F P
0 g
s
.542 .127 .205 r
.49332 .15992 m .49315 .15987 L .46709 .16271 L p F P
0 g
s
.542 .127 .205 r
.49091 .16546 m .49332 .15992 L p .46709 .16271 L F P
0 g
s
.542 .127 .205 r
.46856 .16786 m .49091 .16546 L p .46709 .16271 L F P
0 g
s
.542 .127 .205 r
.46709 .16271 m .46525 .16648 L .46856 .16786 L p F P
0 g
s
.651 .627 .813 r
.41918 .37532 m .42518 .38687 L .44682 .37844 L p F P
0 g
s
.606 .742 .941 r
.63642 .60945 m .62599 .61168 L .61991 .60543 L p F P
0 g
s
.756 .703 .801 r
.64856 .37536 m .64344 .37936 L .63086 .37454 L p F P
0 g
s
.54 .324 .535 r
.39012 .2105 m .39001 .20091 L .36813 .20896 L p F P
0 g
s
.54 .324 .535 r
.36813 .20896 m .36818 .21853 L .39012 .2105 L p F P
0 g
s
.577 .489 .718 r
.35992 .29085 m .35568 .27614 L .33604 .28634 L p F P
0 g
s
.577 .489 .718 r
.35074 .2956 m .35992 .29085 L p .33604 .28634 L F P
0 g
s
.577 .489 .718 r
.33604 .28634 m .33951 .29829 L .35074 .2956 L p F P
0 g
s
.57 .568 .812 r
.67567 .90579 m .6724 .90588 L .67509 .90453 L closepath p F P
0 g
s
.573 .551 .791 r
.66998 .89359 m .67509 .90453 L .6724 .90588 L p F P
0 g
s
.73 .702 .823 r
.59599 .39208 m .59865 .39661 L .60284 .39395 L closepath p F P
0 g
s
.721 .695 .825 r
.59865 .39661 m .59599 .39208 L .58724 .3902 L p F P
0 g
s
.68 .66 .823 r
.48696 .403 m .50887 .39266 L p .49484 .38559 L F P
0 g
s
.68 .66 .823 r
.49484 .38559 m .48088 .39216 L .48696 .403 L p F P
0 g
s
.802 .49 .463 r
.64926 .18852 m .66355 .19315 L .66468 .20173 L p F P
0 g
s
.81 .497 .461 r
.67842 .20653 m .66468 .20173 L .66355 .19315 L p F P
0 g
s
.769 .875 .924 r
.3317 .63816 m .33489 .6398 L .3308 .64237 L closepath p F P
0 g
s
.526 .203 .363 r
.4378 .17987 m .42891 .18193 L .41836 .17755 L p F P
0 g
s
.526 .203 .363 r
.41836 .17755 m .43935 .17269 L .4378 .17987 L p F P
0 g
s
.752 .986 .9 r
.78964 .91561 m .79323 .91601 L .80948 .90443 L p F P
0 g
s
.76 .706 .801 r
.64856 .37536 m .66481 .36229 L .6531 .35713 L p F P
0 g
s
.76 .706 .801 r
.6531 .35713 m .64295 .36519 L .64856 .37536 L p F P
0 g
s
.756 .703 .801 r
.63086 .37454 m .64295 .36519 L .64856 .37536 L p F P
0 g
s
.713 .285 .229 r
.61102 .16934 m .61397 .17286 L .60979 .17197 L closepath p F P
0 g
s
.677 .243 .211 r
.59576 .16967 m .57776 .16699 L .58025 .16202 L p F P
0 g
s
.645 .208 .197 r
.56927 .16093 m .58025 .16202 L .57776 .16699 L p F P
0 g
s
.983 .872 .647 r
.20527 .78167 m .20061 .79351 L .19731 .78661 L p F P
0 g
s
.983 .872 .647 r
.20241 .7755 m .20527 .78167 L p .19731 .78661 L F P
0 g
s
0 0 .407 r
.85296 .82396 m .85034 .82813 L .85107 .83866 L p F P
0 g
s
.051 0 .431 r
.84769 .84322 m .85107 .83866 L .85034 .82813 L p F P
0 g
s
.587 .512 .737 r
.34548 .31664 m .34646 .31639 L .34555 .31686 L closepath p F P
0 g
s
.589 .515 .739 r
.34548 .31664 m .34646 .31639 L p .35074 .2956 L F P
0 g
s
.589 .515 .739 r
.35074 .2956 m .3403 .30103 L .34548 .31664 L p F P
0 g
s
.215 .047 .426 r
.46284 .64209 m .47094 .63486 L .47047 .6449 L p F P
0 g
s
.215 .047 .426 r
.47047 .6449 m .46172 .65268 L .46284 .64209 L p F P
0 g
s
.577 .487 .716 r
.33951 .29829 m .35074 .2956 L .3403 .30103 L closepath p F P
0 g
s
.96 .819 .659 r
.43244 .76678 m .43274 .76599 L .4282 .75966 L p F P
0 g
s
.8 .77 .826 r
.59584 .60473 m .58051 .61537 L .58631 .62532 L p F P
0 g
s
.8 .77 .826 r
.58631 .62532 m .60322 .61061 L .59584 .60473 L p F P
0 g
s
.885 .73 .683 r
.58631 .62532 m .586 .6262 L .57819 .62049 L p F P
0 g
s
.885 .73 .683 r
.57819 .62049 m .58051 .61537 L .58631 .62532 L p F P
0 g
s
.872 .772 .749 r
.42009 .82727 m .42238 .82381 L .41602 .81739 L p F P
0 g
s
.508 .684 .946 r
.68358 .62048 m .67011 .62085 L .66468 .61412 L p F P
0 g
s
.737 .695 .81 r
.60284 .39395 m .62079 .38168 L p .59289 .38657 L F P
0 g
s
.737 .695 .81 r
.59289 .38657 m .59599 .39208 L .60284 .39395 L p F P
0 g
s
.866 .757 .74 r
.41053 .85881 m .40625 .86527 L .39986 .85836 L p F P
0 g
s
.866 .757 .74 r
.39986 .85836 m .40286 .85371 L .41053 .85881 L p F P
0 g
s
.866 .757 .741 r
.41053 .85881 m .40286 .85371 L .41142 .84049 L p F P
0 g
s
.549 .756 .973 r
.28453 .92619 m .30541 .92325 L .31223 .92843 L p F P
0 g
s
.549 .757 .974 r
.29853 .91804 m .27762 .92095 L .28453 .92619 L p F P
0 g
s
.549 .757 .974 r
.28453 .92619 m .30541 .92325 L .29853 .91804 L p F P
0 g
s
.266 .623 .96 r
.26918 .91945 m .27762 .92095 L .28453 .92619 L p F P
0 g
s
.538 .276 .466 r
.41304 .19402 m .4137 .18554 L .39075 .19244 L p F P
0 g
s
.538 .276 .466 r
.39075 .19244 m .39001 .20091 L .41304 .19402 L p F P
0 g
s
.589 .515 .739 r
.34646 .31639 m .36514 .3067 L p .35074 .2956 L F P
0 g
s
.598 .537 .758 r
.36514 .3067 m .36665 .31076 L .34646 .31639 L closepath p F P
0 g
s
.598 .538 .758 r
.37144 .32377 m .36665 .31076 L .34646 .31639 L p F P
0 g
s
.598 .538 .758 r
.3559 .33184 m .37144 .32377 L p .34646 .31639 L F P
0 g
s
.798 .7 .757 r
.68779 .32699 m .69701 .33187 L p .69876 .31238 L F P
0 g
s
.79 .708 .774 r
.68779 .32699 m .69259 .33634 L .69701 .33187 L closepath p F P
0 g
s
.96 .819 .659 r
.4282 .75966 m .42597 .76524 L .43244 .76678 L p F P
0 g
s
.946 .852 .718 r
.43244 .76678 m .42666 .77836 L .42248 .77196 L p F P
0 g
s
.946 .852 .718 r
.42248 .77196 m .42597 .76524 L .43244 .76678 L p F P
0 g
s
.605 .558 .775 r
.37144 .32377 m .37276 .32701 L .3559 .33184 L closepath p F P
0 g
s
.605 .559 .776 r
.37892 .34216 m .37276 .32701 L .3559 .33184 L p F P
0 g
s
0 0 .285 r
.85107 .83866 m .84769 .84322 L .84559 .85498 L p F P
0 g
s
.395 .545 .887 r
.77184 .67285 m .77137 .67273 L .77137 .67204 L closepath p F P
0 g
s
.435 .581 .899 r
.77137 .67273 m .77137 .67204 L .76664 .66428 L p F P
0 g
s
.754 .874 .934 r
.33489 .6398 m .35648 .627 L p .3335 .63303 L F P
0 g
s
.754 .874 .934 r
.3335 .63303 m .3317 .63816 L .33489 .6398 L p F P
0 g
s
.91 .662 .551 r
.586 .6262 m .57819 .62049 L .57662 .6313 L p F P
0 g
s
.91 .662 .551 r
.57662 .6313 m .58483 .63688 L .586 .6262 L p F P
0 g
s
.917 .791 .705 r
.42624 .79667 m .42048 .79081 L .41424 .80332 L p F P
0 g
s
.917 .791 .705 r
.41424 .80332 m .42013 .80912 L .42624 .79667 L p F P
0 g
s
.756 .392 .365 r
.61397 .17286 m .63041 .17671 L .63378 .18432 L p F P
0 g
s
.762 .395 .359 r
.6426 .18655 m .63378 .18432 L .63041 .17671 L p F P
0 g
s
.709 .776 .904 r
.60836 .60797 m .60322 .61061 L .59584 .60473 L p F P
0 g
s
.785 .706 .777 r
.69259 .33634 m .68236 .34656 L p .68638 .32627 L F P
0 g
s
.785 .706 .777 r
.68638 .32627 m .68779 .32699 L .69259 .33634 L p F P
0 g
s
.718 .691 .823 r
.57075 .40006 m .58724 .3902 L .56986 .38703 L p F P
0 g
s
.718 .691 .823 r
.56986 .38703 m .56491 .38997 L .57075 .40006 L p F P
0 g
s
.398 .539 .88 r
.77184 .67285 m .7901 .67798 L .78991 .68559 L p F P
0 g
s
.384 .538 .886 r
.7901 .67798 m .77184 .67285 L .77137 .67204 L p F P
0 g
s
.656 .216 .194 r
.5765 .16686 m .56927 .16093 L .54985 .15926 L p F P
0 g
s
.645 .208 .197 r
.57776 .16699 m .5765 .16686 L .56927 .16093 L p F P
0 g
s
.693 .669 .822 r
.51487 .40329 m .53689 .39193 L p .52598 .38388 L F P
0 g
s
.693 .669 .822 r
.52598 .38388 m .50887 .39266 L .51487 .40329 L p F P
0 g
s
0 0 0 r
.8333 .88002 m .83591 .87361 L p .82458 .88937 L F P
0 g
s
0 0 0 r
.82458 .88937 m .83266 .88085 L .8333 .88002 L p F P
0 g
s
.682 .931 .631 r
.82458 .88937 m .83266 .88085 L p .81372 .90062 L F P
0 g
s
.682 .931 .631 r
.81372 .90062 m .8155 .89935 L .82458 .88937 L p F P
0 g
s
.139 .519 .915 r
.25056 .91024 m .26283 .91406 L .25684 .90853 L p F P
0 g
s
.139 .519 .915 r
.25684 .90853 m .24357 .90414 L .25056 .91024 L p F P
0 g
s
0 .196 .673 r
.24063 .902 m .24357 .90414 L .25056 .91024 L p F P
0 g
s
.834 .657 .663 r
.71365 .26933 m .70268 .2637 L .70792 .2525 L p F P
0 g
s
.818 .664 .691 r
.70692 .28111 m .71365 .26933 L .70268 .2637 L p F P
0 g
s
.772 .703 .787 r
.67063 .35714 m .66481 .36229 L .6531 .35713 L p F P
0 g
s
.559 .406 .63 r
.37052 .23929 m .36905 .22914 L .34822 .23827 L p F P
0 g
s
.559 .406 .63 r
.34822 .23827 m .34928 .24568 L .37052 .23929 L p F P
0 g
s
.945 .904 .517 r
.44018 .70884 m .44018 .71405 L .44249 .71041 L p F P
0 g
s
.922 .907 .511 r
.44018 .71405 m .44249 .71041 L .43999 .71681 L closepath p F P
0 g
s
.55 .609 .865 r
.67567 .90579 m .69867 .90567 L .70419 .91534 L p F P
0 g
s
.539 .551 .816 r
.69307 .89501 m .69867 .90567 L .67567 .90579 L p F P
0 g
s
.539 .551 .816 r
.69006 .89481 m .69307 .89501 L p .67567 .90579 L F P
0 g
s
.539 .551 .816 r
.67567 .90579 m .67509 .90453 L .69006 .89481 L p F P
0 g
s
.876 .775 .746 r
.41308 .82187 m .42009 .82727 L .41142 .84049 L p F P
0 g
s
.872 .772 .749 r
.41602 .81739 m .41308 .82187 L .42009 .82727 L p F P
0 g
s
.949 .899 .743 r
.21592 .74975 m .21351 .7424 L .20579 .75514 L p F P
0 g
s
.949 .899 .743 r
.20579 .75514 m .20832 .76241 L .21592 .74975 L p F P
0 g
s
.627 .584 .787 r
.38512 .35607 m .38785 .3622 L .40869 .35343 L p F P
0 g
s
.632 .603 .802 r
.41279 .362 m .40869 .35343 L .38785 .3622 L p F P
0 g
s
.774 .707 .788 r
.67063 .35714 m .68236 .34656 L .67129 .34114 L p F P
0 g
s
.774 .707 .788 r
.67129 .34114 m .66507 .34668 L .67063 .35714 L p F P
0 g
s
.772 .703 .787 r
.6531 .35713 m .66507 .34668 L .67063 .35714 L p F P
0 g
s
.999 .803 .505 r
.20101 .81168 m .19726 .80501 L .19526 .81618 L p F P
0 g
s
.999 .803 .505 r
.19526 .81618 m .19903 .82281 L .20101 .81168 L p F P
0 g
s
.785 .706 .777 r
.68236 .34656 m .67129 .34114 L .68638 .32627 L p F P
0 g
s
.706 .68 .822 r
.54282 .40231 m .56491 .38997 L p .54966 .38484 L F P
0 g
s
.706 .68 .822 r
.54966 .38484 m .53689 .39193 L .54282 .40231 L p F P
0 g
s
0 0 0 r
.8333 .88002 m .84077 .86748 L .83591 .87361 L closepath p F P
0 g
s
0 0 .057 r
.84559 .85498 m .84077 .86748 L .83591 .87361 L p F P
0 g
s
.711 .851 .949 r
.3998 .60501 m .37811 .61532 L .38475 .61943 L p F P
0 g
s
.711 .851 .949 r
.38475 .61943 m .40636 .60921 L .3998 .60501 L p F P
0 g
s
.73 .855 .94 r
.36923 .61993 m .37811 .61532 L .38475 .61943 L p F P
0 g
s
.384 .538 .886 r
.77137 .67204 m .77107 .66518 L p .7901 .67798 L F P
0 g
s
.417 .571 .899 r
.77137 .67204 m .76664 .66428 L .77107 .66518 L closepath p F P
0 g
s
0 0 .388 r
.61032 .7074 m .60863 .70305 L .60818 .70043 L closepath p F P
0 g
s
0 0 .346 r
.60863 .70305 m .60818 .70043 L .60431 .68696 L p F P
0 g
s
.831 .561 .53 r
.69038 .22104 m .68065 .21701 L .6793 .20686 L p F P
0 g
s
.819 .553 .536 r
.67842 .20653 m .6793 .20686 L .68065 .21701 L p F P
0 g
s
.772 .793 .87 r
.34914 .91914 m .3403 .92501 L .3336 .91958 L p F P
0 g
s
.694 .788 .923 r
.31223 .92843 m .3336 .91958 L .3403 .92501 L p F P
0 g
s
.54 .554 .818 r
.67509 .90453 m .66998 .89359 L .69006 .89481 L closepath p F P
0 g
s
.752 .986 .9 r
.80948 .90443 m .81372 .90062 L p .78964 .91561 L F P
0 g
s
.519 .864 .604 r
.80948 .90443 m .81372 .90062 L .8155 .89935 L closepath p F P
0 g
s
.666 .637 .811 r
.45297 .39031 m .45421 .39268 L .47837 .38761 L p F P
0 g
s
.667 .651 .824 r
.48088 .39216 m .47837 .38761 L .45421 .39268 L p F P
0 g
s
.582 .722 .939 r
.70962 .9239 m .73264 .92075 L .73786 .92701 L p F P
0 g
s
.576 .647 .884 r
.72732 .91348 m .73264 .92075 L .70962 .9239 L p F P
0 g
s
.576 .647 .884 r
.70706 .9151 m .72732 .91348 L p .70962 .9239 L F P
0 g
s
.576 .647 .884 r
.70962 .9239 m .70495 .91653 L .70706 .9151 L p F P
0 g
s
.811 .545 .536 r
.66468 .20173 m .67842 .20653 L .67768 .21589 L p F P
0 g
s
.819 .553 .536 r
.68065 .21701 m .67768 .21589 L .67842 .20653 L p F P
0 g
s
.279 .291 .694 r
.62852 .77307 m .6208 .76476 L .62453 .75886 L closepath p F P
0 g
s
.275 .285 .69 r
.62245 .75135 m .61939 .74701 L p .6208 .76476 L F P
0 g
s
.275 .285 .69 r
.6208 .76476 m .62453 .75886 L .62245 .75135 L p F P
0 g
s
.833 .763 .785 r
.39982 .87263 m .40625 .86527 L .39986 .85836 L p F P
0 g
s
.508 .074 .149 r
.49315 .15987 m .49336 .15985 L .49332 .15992 L closepath p F P
0 g
s
.574 .141 .181 r
.51852 .16413 m .52094 .15865 L .49336 .15985 L p F P
0 g
s
.574 .141 .181 r
.50246 .16482 m .51852 .16413 L p .49336 .15985 L F P
0 g
s
.574 .141 .181 r
.49336 .15985 m .49332 .15992 L .50246 .16482 L p F P
0 g
s
.602 .739 .941 r
.60836 .60797 m .61991 .60543 L .61286 .59942 L p F P
0 g
s
.602 .739 .941 r
.61286 .59942 m .6027 .60154 L .60836 .60797 L p F P
0 g
s
.709 .776 .904 r
.59584 .60473 m .6027 .60154 L .60836 .60797 L p F P
0 g
s
.52 .03 .032 r
.52128 .15825 m .52242 .15866 L .52094 .15865 L closepath p F P
0 g
s
.334 .461 .839 r
.81896 .71375 m .81186 .71045 L .80658 .69964 L p F P
0 g
s
.57 .163 .231 r
.49332 .15992 m .50246 .16482 L .49091 .16546 L closepath p F P
0 g
s
.816 .683 .718 r
.70833 .2988 m .70914 .29923 L p .70692 .28111 L F P
0 g
s
.808 .695 .739 r
.70833 .2988 m .70875 .29971 L .70914 .29923 L closepath p F P
0 g
s
.462 .433 .741 r
.64659 .8322 m .63288 .82653 L .64231 .81895 L closepath p F P
0 g
s
.484 .419 .708 r
.6406 .81365 m .64231 .81895 L .63288 .82653 L p F P
0 g
s
.484 .419 .708 r
.63205 .80871 m .6406 .81365 L p .63288 .82653 L F P
0 g
s
.804 .693 .743 r
.70875 .29971 m .69876 .31238 L p .69829 .29362 L F P
0 g
s
.804 .693 .743 r
.69829 .29362 m .70833 .2988 L .70875 .29971 L p F P
0 g
s
.095 .111 .585 r
.85493 .78742 m .85101 .7954 L .85516 .80541 L p F P
0 g
s
.168 .199 .65 r
.85101 .7954 m .85493 .78742 L .84906 .77792 L p F P
0 g
s
.835 .632 .628 r
.70792 .2525 m .69643 .24699 L .70018 .23639 L p F P
0 g
s
.82 .642 .662 r
.70268 .2637 m .70792 .2525 L .69643 .24699 L p F P
0 g
s
.727 .691 .815 r
.59289 .38657 m .58724 .3902 L .59599 .39208 L closepath p F P
0 g
s
.275 .62 .959 r
.27762 .92095 m .26918 .91945 L .26283 .91406 L p F P
0 g
s
.656 .216 .194 r
.55469 .16505 m .5765 .16686 L p .54985 .15926 L F P
0 g
s
.656 .216 .194 r
.54985 .15926 m .54927 .1603 L .55469 .16505 L p F P
0 g
s
.595 .15 .164 r
.5474 .15918 m .54985 .15926 L .54927 .1603 L closepath p F P
0 g
s
.695 .793 .926 r
.3336 .91958 m .31223 .92843 L .30541 .92325 L p F P
0 g
s
.816 .683 .718 r
.70692 .28111 m .70314 .28661 L .70833 .2988 L p F P
0 g
s
.815 .683 .718 r
.70314 .28661 m .69829 .29362 L .70833 .2988 L closepath p F P
0 g
s
.594 .157 .18 r
.52242 .15866 m .5474 .15918 L .54927 .1603 L p F P
0 g
s
.627 .585 .787 r
.38512 .35607 m .40659 .34869 L p .37946 .34198 L F P
0 g
s
.627 .585 .787 r
.37946 .34198 m .37893 .3422 L .38512 .35607 L p F P
0 g
s
.627 .584 .787 r
.40869 .35343 m .40659 .34869 L .38512 .35607 L p F P
0 g
s
.666 .637 .811 r
.46867 .36886 m .44682 .37844 L .45297 .39031 L p F P
0 g
s
.666 .637 .811 r
.45297 .39031 m .47479 .38071 L .46867 .36886 L p F P
0 g
s
.666 .637 .811 r
.47837 .38761 m .47479 .38071 L .45297 .39031 L p F P
0 g
s
.677 .807 .944 r
.43098 .60227 m .43447 .60515 L .4248 .6089 L closepath p F P
0 g
s
.825 .592 .585 r
.68065 .21701 m .69038 .22104 L .68815 .23103 L p F P
0 g
s
.834 .601 .585 r
.70018 .23639 m .68815 .23103 L .69038 .22104 L p F P
0 g
s
.845 .774 .783 r
.39193 .86762 m .39982 .87263 L .38769 .88685 L p F P
0 g
s
.833 .763 .785 r
.39986 .85836 m .39193 .86762 L .39982 .87263 L p F P
0 g
s
.772 .793 .87 r
.3336 .91958 m .34158 .91416 L .34914 .91914 L p F P
0 g
s
.761 .788 .874 r
.35539 .90514 m .34158 .91416 L .34914 .91914 L p F P
0 g
s
.761 .788 .874 r
.34914 .91914 m .362 .91092 L .35539 .90514 L p F P
0 g
s
.742 .294 0 r
.21613 .87256 m .21123 .86652 L .21644 .87586 L p F P
0 g
s
.742 .294 0 r
.21644 .87586 m .2214 .88188 L .21613 .87256 L p F P
0 g
s
.82 .617 .629 r
.69643 .24699 m .70018 .23639 L .68815 .23103 L p F P
0 g
s
.606 .192 .231 r
.52094 .15865 m .52242 .15866 L .53039 .16421 L p F P
0 g
s
.594 .157 .18 r
.54743 .16455 m .53039 .16421 L .52242 .15866 L p F P
0 g
s
.594 .157 .18 r
.54927 .1603 m .54743 .16455 L p .52242 .15866 L F P
0 g
s
.606 .192 .231 r
.53039 .16421 m .51852 .16413 L .52094 .15865 L p F P
0 g
s
.567 .489 .727 r
.46854 .61749 m .46313 .60596 L p .49004 .61463 L F P
0 g
s
.567 .489 .727 r
.49004 .61463 m .48746 .61587 L .46854 .61749 L p F P
0 g
s
.564 .463 .697 r
.48746 .61587 m .47007 .62352 L .46854 .61749 L closepath p F P
0 g
s
.742 .701 .812 r
.62079 .38168 m .63086 .37454 L .61732 .37001 L p F P
0 g
s
.742 .701 .812 r
.61732 .37001 m .61509 .37157 L .62079 .38168 L p F P
0 g
s
.737 .695 .81 r
.62079 .38168 m .61509 .37157 L .59289 .38657 L p F P
0 g
s
.844 .515 0 r
.60406 .68613 m .60376 .6855 L .59842 .66957 L p F P
0 g
s
.859 .909 .866 r
.26262 .68608 m .26265 .68605 L .26266 .68609 L closepath p F P
0 g
s
.863 .907 .861 r
.24719 .70111 m .26262 .68608 L .26266 .68609 L p F P
0 g
s
.861 .921 .868 r
.26262 .68608 m .26265 .68605 L .2626 .67771 L p F P
0 g
s
.836 .915 .889 r
.28134 .66998 m .26265 .68605 L .2626 .67771 L p F P
0 g
s
.861 .921 .868 r
.2626 .67771 m .25521 .68464 L .26262 .68608 L p F P
0 g
s
.861 .917 .867 r
.26262 .68608 m .24719 .70111 L .24641 .69305 L p F P
0 g
s
.861 .917 .867 r
.24641 .69305 m .25521 .68464 L .26262 .68608 L p F P
0 g
s
0 0 .495 r
.22671 .88773 m .2214 .88188 L .22947 .89052 L p F P
0 g
s
0 0 .495 r
.22947 .89052 m .23489 .89634 L .22671 .88773 L p F P
0 g
s
.889 .511 .048 r
.20825 .85663 m .20373 .85039 L .20668 .8603 L p F P
0 g
s
.889 .511 .048 r
.20668 .8603 m .21123 .86652 L .20825 .85663 L p F P
0 g
s
.558 .403 .628 r
.37073 .24076 m .37052 .23929 L .34928 .24568 L p F P
0 g
s
.558 .403 .628 r
.34928 .24568 m .34986 .24988 L .37073 .24076 L p F P
0 g
s
.891 .92 .527 r
.43999 .71681 m .43516 .72873 L .43558 .72073 L p F P
0 g
s
.891 .92 .527 r
.44018 .71405 m .43999 .71681 L p .43558 .72073 L F P
0 g
s
.647 .611 .799 r
.41898 .37491 m .41918 .37532 L .44155 .36819 L p F P
0 g
s
.651 .627 .813 r
.44682 .37844 m .44155 .36819 L .41918 .37532 L p F P
0 g
s
.647 .61 .799 r
.43448 .35339 m .41279 .362 L .41898 .37491 L p F P
0 g
s
.647 .61 .799 r
.41898 .37491 m .44066 .36633 L .43448 .35339 L p F P
0 g
s
.647 .611 .799 r
.44155 .36819 m .44066 .36633 L .41898 .37491 L p F P
0 g
s
.982 .866 .647 r
.43281 .74773 m .4302 .74074 L .4251 .75284 L p F P
0 g
s
.982 .866 .647 r
.4251 .75284 m .4282 .75966 L .43281 .74773 L p F P
0 g
s
0 0 .484 r
.60818 .70043 m .60431 .68696 L .60798 .69552 L closepath p F P
0 g
s
.509 .337 .584 r
.47094 .63486 m .47007 .62352 L .48746 .61587 L p F P
0 g
s
.372 .509 .866 r
.80136 .68977 m .78991 .68559 L p .80579 .69927 L F P
0 g
s
.346 .498 .867 r
.78991 .68559 m .80136 .68977 L .79615 .68024 L p F P
0 g
s
.346 .498 .867 r
.79615 .68024 m .7901 .67798 L .78991 .68559 L p F P
0 g
s
.886 .922 .842 r
.24042 .70845 m .24719 .70111 L .24641 .69305 L p F P
0 g
s
.535 .706 .949 r
.63642 .60945 m .65922 .60757 L .66468 .61412 L p F P
0 g
s
.531 .713 .955 r
.65373 .60122 m .63087 .60313 L .63642 .60945 L p F P
0 g
s
.531 .713 .955 r
.63642 .60945 m .65922 .60757 L .65373 .60122 L p F P
0 g
s
.606 .742 .941 r
.61991 .60543 m .63087 .60313 L .63642 .60945 L p F P
0 g
s
0 0 .042 r
.44827 .68555 m .44442 .69711 L .44884 .68774 L p F P
0 g
s
0 0 .042 r
.45282 .67712 m .44827 .68555 L p .44884 .68774 L F P
0 g
s
.836 .915 .889 r
.28148 .6664 m .28134 .66998 L p .2626 .67771 L F P
0 g
s
.818 .897 .898 r
.28148 .6664 m .28452 .66749 L .28134 .66998 L closepath p F P
0 g
s
0 0 .354 r
.60376 .6855 m .6017 .67902 L p .60798 .69552 L F P
0 g
s
0 0 .252 r
.5984 .66951 m .59842 .66957 L .60376 .6855 L p F P
0 g
s
0 0 .354 r
.60536 .6885 m .60798 .69552 L p .60233 .68065 L F P
0 g
s
0 0 .354 r
.6017 .67902 m .60536 .6885 L p .60233 .68065 L F P
0 g
s
.666 .321 0 r
.60536 .6885 m .60798 .69552 L .61223 .70489 L p F P
0 g
s
.847 .439 0 r
.60536 .6885 m .60928 .69799 L p .60842 .69641 L F P
0 g
s
0 0 .562 r
.60818 .70043 m .60798 .69552 L p .61291 .71239 L F P
0 g
s
0 0 .562 r
.60798 .69552 m .61223 .70489 L .61291 .71239 L p F P
0 g
s
.847 .439 0 r
.60061 .68204 m .60536 .6885 L p .60842 .69641 L F P
0 g
s
.86 .46 0 r
.6017 .67902 m .60536 .6885 L p .60434 .68652 L F P
0 g
s
0 0 .252 r
.60376 .6855 m .6017 .67902 L p .59912 .67166 L F P
0 g
s
.86 .46 0 r
.59708 .67251 m .6017 .67902 L p .60434 .68652 L F P
0 g
s
0 0 .252 r
.6017 .67902 m .5984 .66951 L p .59912 .67166 L F P
0 g
s
.604 .935 .955 r
.76582 .92503 m .78865 .91537 L .78964 .91561 L p F P
0 g
s
.615 .902 .986 r
.78865 .91537 m .76582 .92503 L .76087 .92122 L p F P
0 g
s
.604 .831 .986 r
.73786 .92701 m .76087 .92122 L .76582 .92503 L p F P
0 g
s
.793 .484 .466 r
.6426 .18655 m .64926 .18852 L .65033 .19711 L p F P
0 g
s
.802 .49 .463 r
.66468 .20173 m .65033 .19711 L .64926 .18852 L p F P
0 g
s
.807 .899 .907 r
.28452 .66749 m .3041 .65259 L p .28207 .66133 L F P
0 g
s
.807 .899 .907 r
.28207 .66133 m .28148 .6664 L .28452 .66749 L p F P
0 g
s
.748 .389 .373 r
.60979 .17197 m .61397 .17286 L .61725 .18048 L p F P
0 g
s
.756 .392 .365 r
.63378 .18432 m .61725 .18048 L .61397 .17286 L p F P
0 g
s
.879 .777 .745 r
.40448 .8351 m .41142 .84049 L .40286 .85371 L p F P
0 g
s
.876 .775 .746 r
.41142 .84049 m .40448 .8351 L .41308 .82187 L p F P
0 g
s
.725 .684 .81 r
.59289 .38657 m .58724 .3902 L .56986 .38703 L p F P
0 g
s
.941 .833 .71 r
.42666 .77836 m .42248 .77196 L .41595 .78454 L p F P
0 g
s
.941 .833 .71 r
.41595 .78454 m .42048 .79081 L .42666 .77836 L p F P
0 g
s
.592 .78 .97 r
.76087 .92122 m .73786 .92701 L .73264 .92075 L p F P
0 g
s
.736 .454 0 r
.59842 .66957 m .59837 .66937 L .5984 .66951 L closepath p F P
0 g
s
.921 .563 .124 r
.5984 .66951 m .59837 .66937 L .59254 .65737 L p F P
0 g
s
.562 .235 .373 r
.46308 .17552 m .46451 .16833 L .43935 .17269 L p F P
0 g
s
.562 .235 .373 r
.43935 .17269 m .4378 .17987 L .46308 .17552 L p F P
0 g
s
.752 .695 .798 r
.64295 .36519 m .63086 .37454 L .61732 .37001 L p F P
0 g
s
.804 .693 .743 r
.69876 .31238 m .68772 .30685 L .69829 .29362 L p F P
0 g
s
.792 .693 .756 r
.68707 .3255 m .69876 .31238 L .68772 .30685 L p F P
0 g
s
.798 .7 .757 r
.69876 .31238 m .68707 .3255 L .68779 .32699 L p F P
0 g
s
.878 .492 .025 r
.59392 .66295 m .5984 .66951 L .6017 .67902 L p F P
0 g
s
.921 .563 .124 r
.59254 .65737 m .59392 .66295 L .5984 .66951 L p F P
0 g
s
.886 .922 .842 r
.24641 .69305 m .23284 .70747 L .24042 .70845 L p F P
0 g
s
.883 .915 .843 r
.24042 .70845 m .23401 .71546 L .23272 .7076 L p F P
0 g
s
.883 .915 .843 r
.23272 .7076 m .23284 .70747 L .24042 .70845 L p F P
0 g
s
.643 .227 .239 r
.54927 .1603 m .55469 .16505 L .54743 .16455 L closepath p F P
0 g
s
.845 .774 .783 r
.38769 .88685 m .38013 .88179 L .39193 .86762 L p F P
0 g
s
.846 .773 .781 r
.38769 .88685 m .38401 .89123 L .3775 .88498 L p F P
0 g
s
.846 .773 .781 r
.3775 .88498 m .38013 .88179 L .38769 .88685 L p F P
0 g
s
0 0 .562 r
.61291 .71239 m .61032 .7074 L .60818 .70043 L p F P
0 g
s
.818 .664 .691 r
.69922 .27725 m .70692 .28111 L p .70268 .2637 L F P
0 g
s
.813 .679 .716 r
.69922 .27725 m .70314 .28661 L .70692 .28111 L closepath p F P
0 g
s
.147 .202 .663 r
.62245 .75135 m .61939 .74701 L .62046 .74425 L closepath p F P
0 g
s
.139 .192 .656 r
.61939 .74701 m .62046 .74425 L .61649 .72976 L p F P
0 g
s
.916 .791 .708 r
.41602 .81739 m .42013 .80912 L .41424 .80332 L p F P
0 g
s
.545 .538 .797 r
.69006 .89481 m .66998 .89359 L .66652 .88549 L p F P
0 g
s
.995 .845 .581 r
.20061 .79351 m .19731 .78661 L .19391 .79816 L p F P
0 g
s
.995 .845 .581 r
.19391 .79816 m .19726 .80501 L .20061 .79351 L p F P
0 g
s
.772 .893 .93 r
.32797 .63654 m .3335 .63303 L .3317 .63816 L closepath p F P
0 g
s
.967 .896 .701 r
.20832 .76241 m .20579 .75514 L .19947 .76749 L p F P
0 g
s
.967 .896 .701 r
.19947 .76749 m .20207 .77471 L .20832 .76241 L p F P
0 g
s
.575 .443 .663 r
.37325 .25343 m .37073 .24076 L .34986 .24988 L p F P
0 g
s
.575 .443 .663 r
.34986 .24988 m .35235 .2625 L .37325 .25343 L p F P
0 g
s
0 .061 .59 r
.6124 .71516 m .61032 .7074 L .61291 .71239 L closepath p F P
0 g
s
.144 .193 .654 r
.85237 .77 m .84906 .77792 L .85493 .78742 L p F P
0 g
s
.202 .261 .701 r
.84906 .77792 m .85237 .77 L .84484 .76101 L p F P
0 g
s
.679 .657 .821 r
.47837 .38761 m .48088 .39216 L .49484 .38559 L closepath p F P
0 g
s
.815 .783 .823 r
.37161 .90215 m .362 .91092 L .35539 .90514 L p F P
0 g
s
.962 .655 .245 r
.20265 .84002 m .1985 .83359 L .19957 .84398 L p F P
0 g
s
.962 .655 .245 r
.19957 .84398 m .20373 .85039 L .20265 .84002 L p F P
0 g
s
.815 .783 .823 r
.35539 .90514 m .36398 .89714 L .37161 .90215 L p F P
0 g
s
.805 .778 .828 r
.3775 .88498 m .36398 .89714 L .37161 .90215 L p F P
0 g
s
.805 .778 .828 r
.37161 .90215 m .38401 .89123 L .3775 .88498 L p F P
0 g
s
.748 .389 .373 r
.61725 .18048 m .60859 .17867 L .60979 .17197 L p F P
0 g
s
.727 .369 .371 r
.59576 .16967 m .60979 .17197 L .60859 .17867 L p F P
0 g
s
.742 .881 .944 r
.37139 .61155 m .34966 .62353 L .35648 .627 L p F P
0 g
s
.742 .881 .944 r
.37337 .61255 m .37139 .61155 L p .35648 .627 L F P
0 g
s
.742 .881 .944 r
.35648 .627 m .36923 .61993 L .37337 .61255 L p F P
0 g
s
.754 .874 .934 r
.35648 .627 m .34966 .62353 L .3335 .63303 L p F P
0 g
s
.405 .579 .91 r
.74857 .65347 m .76143 .65597 L .75621 .64791 L p F P
0 g
s
.405 .579 .91 r
.75621 .64791 m .74716 .64611 L .74857 .65347 L p F P
0 g
s
.447 .609 .917 r
.73245 .64422 m .74716 .64611 L .74857 .65347 L p F P
0 g
s
.565 .379 .588 r
.39105 .22113 m .39012 .2105 L .36818 .21853 L p F P
0 g
s
.565 .379 .588 r
.36818 .21853 m .36905 .22914 L .39105 .22113 L p F P
0 g
s
0 .197 .684 r
.24357 .90414 m .24063 .902 L .23489 .89634 L p F P
0 g
s
.436 .612 .923 r
.74716 .64611 m .73245 .64422 L .72718 .63656 L p F P
0 g
s
.422 .398 .728 r
.6406 .81365 m .63205 .80871 L .63752 .80356 L closepath p F P
0 g
s
.421 .397 .727 r
.63458 .79388 m .63082 .79094 L p .63205 .80871 L F P
0 g
s
.421 .397 .727 r
.63205 .80871 m .63752 .80356 L .63458 .79388 L p F P
0 g
s
.908 .917 .813 r
.23401 .71546 m .23272 .7076 L .22137 .72145 L p F P
0 g
s
.908 .917 .813 r
.22137 .72145 m .2229 .72918 L .23401 .71546 L p F P
0 g
s
.731 .689 .81 r
.59289 .38657 m .61509 .37157 L p .60211 .36603 L F P
0 g
s
.731 .689 .81 r
.60211 .36603 m .5871 .37606 L .59289 .38657 L p F P
0 g
s
.725 .684 .81 r
.56986 .38703 m .5871 .37606 L .59289 .38657 L p F P
0 g
s
.796 .699 .758 r
.68707 .3255 m .68638 .32627 L .68779 .32699 L closepath p F P
0 g
s
.475 .646 .933 r
.69851 .6277 m .71748 .62866 L .72006 .6358 L p F P
0 g
s
.467 .651 .939 r
.71748 .62866 m .69851 .6277 L .69315 .62063 L p F P
0 g
s
.95 .614 .345 r
.59254 .65737 m .59188 .65312 L .58539 .64709 L p F P
0 g
s
.756 .701 .799 r
.64295 .36519 m .6531 .35713 L .64054 .35222 L p F P
0 g
s
.756 .701 .799 r
.64054 .35222 m .6373 .35476 L .64295 .36519 L p F P
0 g
s
.752 .695 .798 r
.61732 .37001 m .6373 .35476 L .64295 .36519 L p F P
0 g
s
.76 .746 .841 r
.5861 .59952 m .57467 .60531 L .58051 .61537 L p F P
0 g
s
.76 .746 .841 r
.58051 .61537 m .59584 .60473 L .5861 .59952 L p F P
0 g
s
.845 .723 .729 r
.58051 .61537 m .57819 .62049 L .56805 .61545 L p F P
0 g
s
.845 .723 .729 r
.56805 .61545 m .57467 .60531 L .58051 .61537 L p F P
0 g
s
0 0 .407 r
.85107 .83866 m .85334 .83507 L .85296 .82396 L p F P
0 g
s
0 0 .387 r
.85749 .81598 m .85296 .82396 L .85334 .83507 L p F P
0 g
s
.042 .022 .505 r
.85296 .82396 m .85749 .81598 L .85516 .80541 L p F P
0 g
s
.54 .149 .249 r
.46525 .16648 m .46856 .16786 L .46451 .16833 L closepath p F P
0 g
s
.073 .151 .641 r
.6124 .71516 m .61291 .71239 L p .61654 .72961 L F P
0 g
s
.073 .151 .641 r
.61654 .72961 m .61638 .72935 L .6124 .71516 L p F P
0 g
s
0 0 .045 r
.85077 .84806 m .84559 .85498 L .84077 .86748 L p F P
0 g
s
0 0 .285 r
.84559 .85498 m .85077 .84806 L .85107 .83866 L p F P
0 g
s
.589 .515 .739 r
.36514 .3067 m .36062 .29294 L .35074 .2956 L p F P
0 g
s
.59 .516 .739 r
.35992 .29085 m .36062 .29294 L .35074 .2956 L closepath p F P
0 g
s
.621 .565 .77 r
.37892 .34216 m .37946 .34198 L .37893 .3422 L closepath p F P
0 g
s
.62 .563 .769 r
.39424 .31952 m .37276 .32701 L .37892 .34216 L p F P
0 g
s
.62 .563 .769 r
.39983 .33337 m .39424 .31952 L p .37892 .34216 L F P
0 g
s
.62 .563 .769 r
.37892 .34216 m .37946 .34198 L .39983 .33337 L p F P
0 g
s
0 0 .145 r
.45479 .6684 m .45847 .664 L .45399 .67574 L p F P
0 g
s
0 0 .145 r
.45399 .67574 m .45282 .67712 L .45479 .6684 L p F P
0 g
s
.627 .584 .787 r
.39983 .33337 m .4004 .33467 L .37946 .34198 L closepath p F P
0 g
s
.627 .585 .787 r
.40659 .34869 m .4004 .33467 L .37946 .34198 L p F P
0 g
s
.666 .804 .949 r
.43447 .60515 m .45623 .59776 L p .44099 .59518 L F P
0 g
s
.666 .804 .949 r
.44099 .59518 m .43098 .60227 L .43447 .60515 L p F P
0 g
s
.793 .484 .466 r
.65033 .19711 m .6426 .19484 L .6426 .18655 L p F P
0 g
s
.778 .471 .469 r
.63378 .18432 m .6426 .18655 L .6426 .19484 L p F P
0 g
s
.807 .676 .72 r
.70314 .28661 m .69829 .29362 L p .69571 .27557 L F P
0 g
s
.807 .676 .72 r
.69571 .27557 m .69922 .27725 L .70314 .28661 L p F P
0 g
s
.792 .693 .756 r
.68772 .30685 m .68148 .31373 L .68707 .3255 L p F P
0 g
s
.791 .691 .754 r
.67484 .32094 m .68148 .31373 L .68707 .3255 L p F P
0 g
s
.791 .691 .754 r
.68707 .3255 m .68638 .32627 L .67484 .32094 L p F P
0 g
s
.151 0 .343 r
.46172 .65268 m .47047 .6449 L .46935 .65435 L p F P
0 g
s
.151 0 .343 r
.46935 .65435 m .45847 .664 L .46172 .65268 L p F P
0 g
s
.321 .46 .844 r
.80658 .69964 m .80579 .69927 L .8059 .69828 L closepath p F P
0 g
s
.372 .509 .866 r
.80579 .69927 m .8059 .69828 L .80136 .68977 L p F P
0 g
s
.778 .693 .77 r
.67129 .34114 m .68638 .32627 L .67484 .32094 L p F P
0 g
s
.807 .899 .907 r
.3041 .65259 m .30446 .6503 L p .28207 .66133 L F P
0 g
s
.793 .891 .915 r
.30446 .6503 m .30628 .65107 L .3041 .65259 L closepath p F P
0 g
s
.567 .489 .727 r
.46313 .60596 m .47372 .60166 L p .49004 .61463 L F P
0 g
s
.637 .666 .861 r
.47372 .60166 m .46313 .60596 L .46246 .60494 L closepath p F P
0 g
s
.692 .666 .82 r
.50435 .38454 m .50887 .39266 L .52598 .38388 L closepath p F P
0 g
s
.68 .66 .823 r
.50887 .39266 m .50435 .38454 L .49484 .38559 L p F P
0 g
s
.803 .537 .536 r
.65033 .19711 m .66468 .20173 L .66392 .21109 L p F P
0 g
s
.811 .545 .536 r
.67768 .21589 m .66392 .21109 L .66468 .20173 L p F P
0 g
s
.765 .699 .789 r
.6531 .35713 m .64054 .35222 L .65944 .33596 L p F P
0 g
s
.765 .699 .789 r
.66507 .34668 m .6531 .35713 L p .65944 .33596 L F P
0 g
s
.915 .617 .465 r
.58483 .63688 m .57662 .6313 L .57713 .64153 L p F P
0 g
s
.915 .617 .465 r
.57713 .64153 m .58539 .64709 L .58483 .63688 L p F P
0 g
s
.78 .892 .924 r
.30628 .65107 m .32797 .63654 L p .30625 .64341 L F P
0 g
s
.78 .892 .924 r
.30625 .64341 m .30446 .6503 L .30628 .65107 L p F P
0 g
s
.521 .526 .801 r
.66652 .88549 m .66423 .88015 L .67258 .88126 L closepath p F P
0 g
s
.545 .538 .797 r
.66652 .88549 m .67258 .88126 L p .69006 .89481 L F P
0 g
s
.82 .642 .662 r
.69228 .25882 m .70268 .2637 L p .69643 .24699 L F P
0 g
s
.816 .66 .69 r
.69228 .25882 m .69746 .27261 L .70268 .2637 L closepath p F P
0 g
s
.818 .664 .691 r
.70268 .2637 m .69746 .27261 L .69922 .27725 L p F P
0 g
s
.716 .686 .82 r
.56262 .38595 m .56491 .38997 L .56986 .38703 L closepath p F P
0 g
s
.706 .68 .822 r
.56491 .38997 m .56262 .38595 L .54966 .38484 L p F P
0 g
s
.825 .592 .585 r
.68815 .23103 m .68322 .22901 L .68065 .21701 L p F P
0 g
s
.815 .586 .591 r
.67768 .21589 m .68065 .21701 L .68322 .22901 L p F P
0 g
s
.577 .649 .885 r
.70495 .91653 m .70419 .91534 L .70706 .9151 L closepath p F P
0 g
s
.18 .256 .706 r
.84755 .75314 m .84484 .76101 L .85237 .77 L p F P
0 g
s
.232 .316 .744 r
.84484 .76101 m .84755 .75314 L .83841 .74466 L p F P
0 g
s
.771 .702 .786 r
.65949 .33598 m .66507 .34668 L .67129 .34114 L closepath p F P
0 g
s
.765 .699 .789 r
.65944 .33596 m .65949 .33598 L .66507 .34668 L p F P
0 g
s
.334 .461 .839 r
.80658 .69964 m .81999 .70607 L .81896 .71375 L p F P
0 g
s
.314 .455 .843 r
.81999 .70607 m .80658 .69964 L .8059 .69828 L p F P
0 g
s
0 0 .253 r
.85334 .83507 m .85107 .83866 L .85077 .84806 L p F P
0 g
s
.778 .693 .77 r
.65949 .33598 m .67129 .34114 L p .67484 .32094 L F P
0 g
s
.704 .676 .82 r
.53232 .3838 m .53689 .39193 L .54966 .38484 L closepath p F P
0 g
s
.693 .669 .822 r
.53689 .39193 m .53232 .3838 L .52598 .38388 L p F P
0 g
s
.639 .708 .897 r
.46246 .60494 m .45623 .59776 L p .48303 .5969 L F P
0 g
s
.639 .708 .897 r
.48303 .5969 m .47372 .60166 L .46246 .60494 L p F P
0 g
s
.602 .744 .944 r
.63087 .60313 m .61991 .60543 L .61286 .59942 L p F P
0 g
s
.115 .169 .642 r
.61649 .72976 m .61638 .72935 L .61654 .72961 L closepath p F P
0 g
s
.121 .18 .651 r
.61654 .72961 m .61649 .72976 L .62046 .74425 L p F P
0 g
s
.569 .302 .472 r
.4312 .18973 m .41304 .19402 L .4137 .18554 L p F P
0 g
s
.569 .302 .472 r
.4137 .18554 m .42891 .18193 L .4312 .18973 L p F P
0 g
s
.41 .575 .905 r
.77107 .66518 m .76664 .66428 L .76143 .65597 L p F P
0 g
s
.679 .644 .808 r
.47479 .38071 m .47837 .38761 L .49484 .38559 L p F P
0 g
s
.121 .18 .651 r
.62046 .74425 m .62253 .73862 L .61654 .72961 L p F P
0 g
s
0 .043 .591 r
.61792 .72161 m .61654 .72961 L .62253 .73862 L p F P
0 g
s
.073 .151 .641 r
.61291 .71239 m .61792 .72161 L .61654 .72961 L p F P
0 g
s
.949 .913 .54 r
.43574 .72038 m .44018 .70884 L .44018 .71405 L closepath p F P
0 g
s
.891 .92 .527 r
.43558 .72073 m .43574 .72038 L .44018 .71405 L p F P
0 g
s
.57 .347 .538 r
.41322 .20362 m .41304 .19402 L .39001 .20091 L p F P
0 g
s
.57 .347 .538 r
.39001 .20091 m .39012 .2105 L .41322 .20362 L p F P
0 g
s
.672 .965 .759 r
.81127 .90148 m .81799 .89587 L .81372 .90062 L closepath p F P
0 g
s
.682 .931 .631 r
.83266 .88085 m .81799 .89587 L .81372 .90062 L p F P
0 g
s
.752 .986 .9 r
.81372 .90062 m .81127 .90148 L p .78964 .91561 L F P
0 g
s
.664 .633 .809 r
.44155 .36819 m .44682 .37844 L .46867 .36886 L p F P
0 g
s
.992 .749 .386 r
.19903 .82281 m .19526 .81618 L .19472 .82699 L p F P
0 g
s
.992 .749 .386 r
.19472 .82699 m .1985 .83359 L .19903 .82281 L p F P
0 g
s
.733 .374 .371 r
.59936 .17714 m .59576 .16967 L .57776 .16699 L p F P
0 g
s
.727 .369 .371 r
.60859 .17867 m .59936 .17714 L .59576 .16967 L p F P
0 g
s
.314 .455 .843 r
.8059 .69828 m .80636 .69163 L p .81999 .70607 L F P
0 g
s
.352 .497 .864 r
.8059 .69828 m .80136 .68977 L .80636 .69163 L closepath p F P
0 g
s
.582 .625 .86 r
.70706 .9151 m .70419 .91534 L .69867 .90567 L p F P
0 g
s
.855 .613 .573 r
.57819 .62049 m .56805 .61545 L .56583 .62646 L p F P
0 g
s
.855 .613 .573 r
.56583 .62646 m .57662 .6313 L .57819 .62049 L p F P
0 g
s
.916 .791 .708 r
.41424 .80332 m .40956 .81261 L .41602 .81739 L p F P
0 g
s
.891 .806 .758 r
.41602 .81739 m .41308 .82187 L .40725 .81609 L p F P
0 g
s
.891 .806 .758 r
.40725 .81609 m .40956 .81261 L .41602 .81739 L p F P
0 g
s
.482 .669 .946 r
.68358 .62048 m .69315 .62063 L .68777 .6138 L p F P
0 g
s
.482 .669 .946 r
.68777 .6138 m .6795 .61368 L .68358 .62048 L p F P
0 g
s
.508 .684 .946 r
.66468 .61412 m .6795 .61368 L .68358 .62048 L p F P
0 g
s
.29 .411 .813 r
.82979 .7289 m .83135 .72116 L .81896 .71375 L p F P
0 g
s
.28 .419 .824 r
.81999 .70607 m .81896 .71375 L .83135 .72116 L p F P
0 g
s
.879 .777 .745 r
.40286 .85371 m .39986 .85836 L .39338 .85238 L p F P
0 g
s
.879 .777 .745 r
.39338 .85238 m .39597 .84834 L .40286 .85371 L p F P
0 g
s
.879 .777 .745 r
.40286 .85371 m .39597 .84834 L .40448 .8351 L p F P
0 g
s
.689 .843 .957 r
.4216 .59562 m .3998 .60501 L .40636 .60921 L p F P
0 g
s
.689 .843 .957 r
.40636 .60921 m .42808 .60001 L .4216 .59562 L p F P
0 g
s
.721 .677 .807 r
.56986 .38703 m .5871 .37606 L p .55903 .3793 L F P
0 g
s
.721 .677 .807 r
.55903 .3793 m .56262 .38595 L .56986 .38703 L p F P
0 g
s
.646 .609 .798 r
.40869 .35343 m .41279 .362 L .43448 .35339 L p F P
0 g
s
.925 .92 .79 r
.2229 .72918 m .22137 .72145 L .21168 .7348 L p F P
0 g
s
.925 .92 .79 r
.21763 .73658 m .2229 .72918 L p .21168 .7348 L F P
0 g
s
.808 .577 .589 r
.66392 .21109 m .67768 .21589 L .67518 .22597 L p F P
0 g
s
.815 .586 .591 r
.68322 .22901 m .67518 .22597 L .67768 .21589 L p F P
0 g
s
.82 .617 .629 r
.68705 .24288 m .69643 .24699 L p .68815 .23103 L F P
0 g
s
.818 .639 .661 r
.68705 .24288 m .69166 .25694 L .69643 .24699 L closepath p F P
0 g
s
.82 .642 .662 r
.69643 .24699 m .69166 .25694 L .69228 .25882 L p F P
0 g
s
.686 .773 .917 r
.6027 .60154 m .59584 .60473 L .5861 .59952 L p F P
0 g
s
.807 .676 .72 r
.69829 .29362 m .68677 .2882 L .69571 .27557 L p F P
0 g
s
.8 .683 .735 r
.68677 .2882 m .69829 .29362 L .68772 .30685 L p F P
0 g
s
.503 .691 .952 r
.6795 .61368 m .66468 .61412 L .65922 .60757 L p F P
0 g
s
.588 .474 .691 r
.37612 .26514 m .37325 .25343 L .35235 .2625 L p F P
0 g
s
.588 .474 .691 r
.35235 .2625 m .35475 .27229 L .37612 .26514 L p F P
0 g
s
.44 .624 .93 r
.72006 .6358 m .72718 .63656 L .72189 .62914 L p F P
0 g
s
.44 .624 .93 r
.72189 .62914 m .71748 .62866 L .72006 .6358 L p F P
0 g
s
.215 .315 .751 r
.84053 .73686 m .83841 .74466 L .84755 .75314 L p F P
0 g
s
.261 .365 .781 r
.83841 .74466 m .84053 .73686 L .82979 .7289 L p F P
0 g
s
.527 .512 .782 r
.67258 .88126 m .66423 .88015 L .65931 .86773 L p F P
0 g
s
.547 .756 .974 r
.2916 .91279 m .27065 .91552 L .27762 .92095 L p F P
0 g
s
.547 .756 .974 r
.27762 .92095 m .29853 .91804 L .2916 .91279 L p F P
0 g
s
.275 .62 .959 r
.26283 .91406 m .27065 .91552 L .27762 .92095 L p F P
0 g
s
.696 .963 .941 r
.78865 .91537 m .7915 .91378 L .78964 .91561 L closepath p F P
0 g
s
.752 .986 .9 r
.81127 .90148 m .7915 .91378 L .78964 .91561 L p F P
0 g
s
.248 .37 .791 r
.83135 .72116 m .82979 .7289 L .84053 .73686 L p F P
0 g
s
.818 .615 .628 r
.68322 .22901 m .68564 .23782 L .68815 .23103 L closepath p F P
0 g
s
.82 .617 .629 r
.68815 .23103 m .68564 .23782 L .68705 .24288 L p F P
0 g
s
.983 .873 .647 r
.20146 .77623 m .20207 .77471 L .20241 .7755 L closepath p F P
0 g
s
.983 .872 .647 r
.19731 .78661 m .20146 .77623 L .20241 .7755 L p F P
0 g
s
.729 .864 .944 r
.37337 .61255 m .37811 .61532 L .36923 .61993 L closepath p F P
0 g
s
.77 .465 .471 r
.61725 .18048 m .63378 .18432 L .63488 .19288 L p F P
0 g
s
.778 .471 .469 r
.6426 .19484 m .63488 .19288 L .63378 .18432 L p F P
0 g
s
.136 .502 .909 r
.24357 .90414 m .25684 .90853 L .25119 .90284 L p F P
0 g
s
.136 .502 .909 r
.25119 .90284 m .23657 .89761 L .24357 .90414 L p F P
0 g
s
0 .197 .684 r
.23489 .89634 m .23657 .89761 L .24357 .90414 L p F P
0 g
s
.622 .567 .771 r
.37144 .32377 m .37276 .32701 L .39424 .31952 L p F P
0 g
s
.965 .923 .588 r
.43516 .72873 m .43558 .72073 L .42977 .73303 L p F P
0 g
s
.965 .923 .588 r
.42977 .73303 m .4302 .74074 L .43516 .72873 L p F P
0 g
s
.366 .355 .714 r
.63458 .79388 m .63082 .79094 L .63299 .78844 L closepath p F P
0 g
s
.365 .353 .713 r
.63082 .79094 m .63299 .78844 L .62866 .77354 L p F P
0 g
s
.221 .251 .681 r
.62046 .74425 m .62253 .73862 L p .62613 .75587 L F P
0 g
s
.221 .251 .681 r
.62613 .75587 m .62245 .75135 L .62046 .74425 L p F P
0 g
s
.829 .916 .895 r
.27727 .66527 m .28207 .66133 L .28148 .6664 L closepath p F P
0 g
s
.836 .915 .889 r
.2626 .67771 m .27727 .66527 L .28148 .6664 L p F P
0 g
s
.936 .824 .71 r
.42048 .79081 m .41595 .78454 L .4094 .79717 L p F P
0 g
s
.936 .824 .71 r
.4094 .79717 m .41424 .80332 L .42048 .79081 L p F P
0 g
s
.971 .866 .676 r
.4282 .75966 m .4251 .75284 L .41982 .76504 L p F P
0 g
s
.971 .866 .676 r
.42597 .76524 m .4282 .75966 L p .41982 .76504 L F P
0 g
s
.933 .567 .294 r
.59254 .65737 m .59392 .66295 L .58694 .65707 L p F P
0 g
s
.933 .567 .294 r
.58694 .65707 m .58691 .65693 L .59254 .65737 L p F P
0 g
s
.95 .614 .345 r
.58539 .64709 m .58691 .65693 L .59254 .65737 L p F P
0 g
s
.891 .801 .753 r
.41308 .82187 m .40725 .81609 L .39849 .82939 L p F P
0 g
s
.891 .801 .753 r
.39849 .82939 m .40448 .8351 L .41308 .82187 L p F P
0 g
s
.594 .265 .383 r
.47451 .17418 m .46308 .17552 L .46451 .16833 L p F P
0 g
s
.594 .265 .383 r
.46451 .16833 m .46856 .16786 L .47451 .17418 L p F P
0 g
s
.817 .663 .692 r
.69746 .27261 m .69571 .27557 L .69922 .27725 L closepath p F P
0 g
s
.847 .786 .791 r
.39193 .86762 m .39986 .85836 L .39338 .85238 L p F P
0 g
s
.614 .545 .753 r
.36665 .31076 m .37144 .32377 L .39236 .31488 L p F P
0 g
s
.622 .567 .771 r
.39424 .31952 m .39236 .31488 L .37144 .32377 L p F P
0 g
s
.553 .612 .866 r
.70706 .9151 m .72732 .91348 L .72192 .90526 L p F P
0 g
s
.553 .612 .866 r
.72192 .90526 m .72014 .90528 L .70706 .9151 L p F P
0 g
s
.582 .625 .86 r
.69867 .90567 m .72014 .90528 L .70706 .9151 L p F P
0 g
s
.711 .673 .811 r
.55903 .3793 m .54966 .38484 L .56262 .38595 L closepath p F P
0 g
s
.74 .696 .809 r
.61362 .36892 m .61509 .37157 L .61732 .37001 L closepath p F P
0 g
s
.731 .689 .81 r
.61509 .37157 m .61362 .36892 L .60211 .36603 L p F P
0 g
s
.227 .253 .68 r
.62453 .75886 m .62245 .75135 L .62613 .75587 L closepath p F P
0 g
s
.452 .232 .488 r
.47047 .6449 m .47094 .63486 L .49086 .62589 L p F P
0 g
s
.509 .337 .584 r
.49033 .61711 m .49086 .62589 L .47094 .63486 L p F P
0 g
s
.509 .337 .584 r
.48746 .61587 m .49033 .61711 L p .47094 .63486 L F P
0 g
s
0 0 0 r
.44442 .69711 m .44884 .68774 L .44344 .69986 L p F P
0 g
s
0 0 0 r
.44344 .69986 m .44018 .70884 L .44442 .69711 L p F P
0 g
s
.775 .801 .874 r
.34158 .91416 m .3336 .91958 L .32685 .91427 L p F P
0 g
s
.695 .793 .926 r
.30541 .92325 m .32685 .91427 L .3336 .91958 L p F P
0 g
s
.597 .265 .377 r
.48952 .17258 m .47451 .17418 L .46856 .16786 L p F P
0 g
s
.597 .265 .377 r
.46856 .16786 m .49091 .16546 L .48952 .17258 L p F P
0 g
s
.8 .91 .916 r
.29915 .64852 m .30625 .64341 L .30446 .6503 L closepath p F P
0 g
s
.807 .899 .907 r
.30446 .6503 m .29915 .64852 L .28207 .66133 L p F P
0 g
s
.587 .471 .689 r
.3766 .2671 m .37612 .26514 L .35475 .27229 L p F P
0 g
s
.587 .471 .689 r
.35475 .27229 m .35568 .27614 L .3766 .2671 L p F P
0 g
s
.679 .644 .808 r
.49484 .38559 m .50284 .38166 L p .47479 .38071 L F P
0 g
s
.681 .649 .811 r
.50284 .38166 m .49484 .38559 L .50435 .38454 L closepath p F P
0 g
s
.983 .888 .649 r
.20207 .77471 m .19947 .76749 L .1945 .77949 L p F P
0 g
s
.983 .888 .649 r
.20146 .77623 m .20207 .77471 L p .1945 .77949 L F P
0 g
s
.745 .687 .796 r
.61732 .37001 m .6373 .35476 L p .62674 .3477 L F P
0 g
s
.745 .687 .796 r
.61362 .36892 m .61732 .37001 L p .62674 .3477 L F P
0 g
s
0 0 .467 r
.61223 .70489 m .61291 .71239 L .61792 .72161 L p F P
0 g
s
.809 .657 .694 r
.69746 .27261 m .69571 .27557 L p .69101 .25826 L F P
0 g
s
.809 .657 .694 r
.69101 .25826 m .69228 .25882 L .69746 .27261 L p F P
0 g
s
.925 .92 .79 r
.21168 .7348 m .21218 .73716 L .21763 .73658 L p F P
0 g
s
.929 .914 .782 r
.21218 .73716 m .21763 .73658 L .21351 .7424 L closepath p F P
0 g
s
.31 .311 .699 r
.62453 .75886 m .62613 .75587 L p .6288 .77334 L F P
0 g
s
.31 .311 .699 r
.6288 .77334 m .62852 .77307 L .62453 .75886 L p F P
0 g
s
.592 .739 .946 r
.6027 .60154 m .61286 .59942 L .60493 .59362 L p F P
0 g
s
.592 .739 .946 r
.60493 .59362 m .597 .59515 L .6027 .60154 L p F P
0 g
s
.686 .773 .917 r
.5861 .59952 m .597 .59515 L .6027 .60154 L p F P
0 g
s
.598 .5 .714 r
.38086 .28186 m .3766 .2671 L .35568 .27614 L p F P
0 g
s
.598 .5 .714 r
.35568 .27614 m .35992 .29085 L .38086 .28186 L p F P
0 g
s
.527 .512 .782 r
.65931 .86773 m .66143 .86612 L p .67258 .88126 L F P
0 g
s
.498 .496 .785 r
.65931 .86773 m .65841 .86546 L .66143 .86612 L closepath p F P
0 g
s
.003 0 .496 r
.85911 .79746 m .85516 .80541 L .85749 .81598 L p F P
0 g
s
.095 .111 .585 r
.85516 .80541 m .85911 .79746 L .85493 .78742 L p F P
0 g
s
.676 .641 .808 r
.47479 .38071 m .49678 .36999 L p .48834 .35933 L F P
0 g
s
.676 .641 .808 r
.48834 .35933 m .46867 .36886 L .47479 .38071 L p F P
0 g
s
.679 .644 .808 r
.50284 .38166 m .49678 .36999 L .47479 .38071 L p F P
0 g
s
.983 .888 .649 r
.1945 .77949 m .19521 .78144 L .20146 .77623 L p F P
0 g
s
.984 .878 .643 r
.19521 .78144 m .20146 .77623 L .19731 .78661 L closepath p F P
0 g
s
.733 .374 .371 r
.5801 .17431 m .59936 .17714 L p .57776 .16699 L F P
0 g
s
.733 .374 .371 r
.57776 .16699 m .57745 .16851 L .5801 .17431 L p F P
0 g
s
.696 .337 .364 r
.5765 .16686 m .57776 .16699 L .57745 .16851 L closepath p F P
0 g
s
.615 .547 .755 r
.36514 .3067 m .36665 .31076 L .38811 .30327 L p F P
0 g
s
.614 .545 .753 r
.39236 .31488 m .38811 .30327 L .36665 .31076 L p F P
0 g
s
.854 .789 .787 r
.38494 .86231 m .39193 .86762 L .38013 .88179 L p F P
0 g
s
.847 .786 .791 r
.39338 .85238 m .38494 .86231 L .39193 .86762 L p F P
0 g
s
.384 .538 .886 r
.77107 .66518 m .78963 .67049 L .7901 .67798 L p F P
0 g
s
.368 .546 .898 r
.77006 .65778 m .77107 .66518 L .78963 .67049 L p F P
0 g
s
.41 .575 .905 r
.76143 .65597 m .77006 .65778 L .77107 .66518 L p F P
0 g
s
.69 .336 .37 r
.55469 .16505 m .5765 .16686 L .57745 .16851 L p F P
0 g
s
.584 .422 .629 r
.39218 .22858 m .39105 .22113 L .36905 .22914 L p F P
0 g
s
.584 .422 .629 r
.36905 .22914 m .37052 .23929 L .39218 .22858 L p F P
0 g
s
.708 .666 .806 r
.54966 .38484 m .55903 .3793 L p .53093 .38119 L F P
0 g
s
.708 .666 .806 r
.53093 .38119 m .53232 .3838 L .54966 .38484 L p F P
0 g
s
0 0 0 r
.84077 .86748 m .84686 .85932 L p .83309 .88038 L F P
0 g
s
0 0 0 r
.83309 .88038 m .8333 .88002 L .84077 .86748 L p F P
0 g
s
0 0 .045 r
.85035 .85064 m .85077 .84806 L p .84077 .86748 L F P
0 g
s
0 0 .045 r
.84077 .86748 m .84686 .85932 L .85035 .85064 L p F P
0 g
s
.81 .61 .633 r
.67518 .22597 m .68322 .22901 L .68564 .23782 L p F P
0 g
s
.506 .485 .768 r
.66143 .86612 m .65841 .86546 L .65304 .85087 L p F P
0 g
s
.771 .904 .933 r
.33789 .62305 m .32096 .63369 L .32797 .63654 L p F P
0 g
s
.771 .904 .933 r
.32797 .63654 m .3335 .63303 L .33789 .62305 L p F P
0 g
s
.78 .892 .924 r
.32797 .63654 m .32096 .63369 L .30625 .64341 L p F P
0 g
s
.8 .683 .735 r
.68772 .30685 m .67596 .30154 L .68677 .2882 L p F P
0 g
s
.786 .687 .755 r
.68148 .31373 m .68772 .30685 L .67596 .30154 L p F P
0 g
s
.775 .801 .874 r
.32685 .91427 m .33456 .90899 L .34158 .91416 L p F P
0 g
s
.767 .799 .878 r
.34872 .89967 m .33456 .90899 L .34158 .91416 L p F P
0 g
s
.767 .799 .878 r
.34158 .91416 m .35539 .90514 L .34872 .89967 L p F P
0 g
s
.697 .933 .965 r
.7915 .91378 m .78865 .91537 L .7839 .9131 L p F P
0 g
s
.615 .902 .986 r
.76087 .92122 m .7839 .9131 L .78865 .91537 L p F P
0 g
s
.695 .799 .929 r
.32003 .90908 m .29853 .91804 L .30541 .92325 L p F P
0 g
s
.695 .799 .929 r
.30541 .92325 m .32685 .91427 L .32003 .90908 L p F P
0 g
s
.809 .657 .694 r
.69571 .27557 m .68365 .27028 L .69101 .25826 L p F P
0 g
s
.802 .667 .714 r
.68365 .27028 m .69571 .27557 L .68677 .2882 L p F P
0 g
s
.642 .592 .783 r
.40659 .34869 m .40869 .35343 L .43102 .34612 L p F P
0 g
s
.646 .609 .798 r
.43448 .35339 m .43102 .34612 L .40869 .35343 L p F P
0 g
s
.607 .524 .735 r
.36062 .29294 m .36514 .3067 L .38608 .29776 L p F P
0 g
s
.615 .547 .755 r
.38811 .30327 m .38608 .29776 L .36514 .3067 L p F P
0 g
s
.277 .614 .957 r
.27065 .91552 m .26283 .91406 L .25684 .90853 L p F P
0 g
s
.694 .655 .807 r
.50284 .38166 m .50435 .38454 L .52598 .38388 L p F P
0 g
s
1 .811 .49 r
.19726 .80501 m .19391 .79816 L .19188 .80936 L p F P
0 g
s
1 .811 .49 r
.19188 .80936 m .19526 .81618 L .19726 .80501 L p F P
0 g
s
.745 .687 .796 r
.62674 .3477 m .60934 .3608 L .61362 .36892 L p F P
0 g
s
.739 .685 .799 r
.60934 .3608 m .60211 .36603 L .61362 .36892 L closepath p F P
0 g
s
.572 .304 .471 r
.43721 .18834 m .4312 .18973 L .42891 .18193 L p F P
0 g
s
.572 .304 .471 r
.42891 .18193 m .4378 .17987 L .43721 .18834 L p F P
0 g
s
.71 .861 .954 r
.37811 .61532 m .3998 .60501 L p .3762 .60911 L F P
0 g
s
.71 .861 .954 r
.3762 .60911 m .37337 .61255 L .37811 .61532 L p F P
0 g
s
.608 .526 .737 r
.35992 .29085 m .36062 .29294 L .38205 .28547 L p F P
0 g
s
.607 .524 .735 r
.38608 .29776 m .38205 .28547 L .36062 .29294 L p F P
0 g
s
.608 .526 .737 r
.38205 .28547 m .38086 .28186 L .35992 .29085 L p F P
0 g
s
.669 .815 .953 r
.42808 .60001 m .44099 .59518 L .43098 .60227 L closepath p F P
0 g
s
.697 .933 .965 r
.7839 .9131 m .79972 .9053 L .7915 .91378 L p F P
0 g
s
.666 .973 .885 r
.80681 .90146 m .79972 .9053 L .7915 .91378 L p F P
0 g
s
.666 .973 .885 r
.7915 .91378 m .81127 .90148 L .80681 .90146 L p F P
0 g
s
.971 .866 .676 r
.41982 .76504 m .42029 .766 L .42597 .76524 L p F P
0 g
s
.963 .895 .711 r
.42029 .766 m .42597 .76524 L .42248 .77196 L closepath p F P
0 g
s
.303 .31 .702 r
.62866 .77354 m .62852 .77307 L .6288 .77334 L closepath p F P
0 g
s
.95 .922 .745 r
.21351 .7424 m .20579 .75514 L .20374 .74764 L p F P
0 g
s
.95 .922 .745 r
.21218 .73716 m .21351 .7424 L p .20374 .74764 L F P
0 g
s
.303 .313 .704 r
.6288 .77334 m .62866 .77354 L .63299 .78844 L p F P
0 g
s
.794 .53 .537 r
.6426 .19484 m .65033 .19711 L .64951 .20649 L p F P
0 g
s
.803 .537 .536 r
.66392 .21109 m .64951 .20649 L .65033 .19711 L p F P
0 g
s
.786 .687 .755 r
.67596 .30154 m .67584 .30166 L .68148 .31373 L p F P
0 g
s
.785 .683 .752 r
.66255 .31584 m .67584 .30166 L .68148 .31373 L p F P
0 g
s
.785 .683 .752 r
.68148 .31373 m .67484 .32094 L .66255 .31584 L p F P
0 g
s
.728 .684 .808 r
.5871 .37606 m .60211 .36603 L .58557 .36249 L p F P
0 g
s
.728 .684 .808 r
.58557 .36249 m .58126 .36533 L .5871 .37606 L p F P
0 g
s
.721 .677 .807 r
.5871 .37606 m .58126 .36533 L .55903 .3793 L p F P
0 g
s
.694 .655 .807 r
.52598 .38388 m .53093 .38119 L p .50284 .38166 L F P
0 g
s
.696 .661 .811 r
.53093 .38119 m .52598 .38388 L .53232 .3838 L closepath p F P
0 g
s
.706 .704 .846 r
.57467 .60531 m .5861 .59952 L .56962 .59754 L closepath p F P
0 g
s
.785 .635 .694 r
.57467 .60531 m .56962 .59754 L p .55383 .61163 L F P
0 g
s
.785 .635 .694 r
.55383 .61163 m .56805 .61545 L .57467 .60531 L p F P
0 g
s
.173 .24 .692 r
.63338 .76468 m .6288 .77334 L .63754 .78181 L p F P
0 g
s
.31 .311 .699 r
.62613 .75587 m .63338 .76468 L .6288 .77334 L p F P
0 g
s
.303 .313 .704 r
.63299 .78844 m .63754 .78181 L .6288 .77334 L p F P
0 g
s
.662 .618 .795 r
.44066 .36633 m .44155 .36819 L .46551 .3627 L p F P
0 g
s
.664 .633 .809 r
.46867 .36886 m .46551 .3627 L .44155 .36819 L p F P
0 g
s
.753 .886 .939 r
.34966 .62353 m .3335 .63303 L .33789 .62305 L p F P
0 g
s
.81 .61 .633 r
.68564 .23782 m .68419 .24171 L p .67518 .22597 L F P
0 g
s
.818 .616 .63 r
.68564 .23782 m .68419 .24171 L .68705 .24288 L closepath p F P
0 g
s
.754 .696 .797 r
.6349 .35026 m .6373 .35476 L .64054 .35222 L closepath p F P
0 g
s
.745 .687 .796 r
.6373 .35476 m .6349 .35026 L .62674 .3477 L p F P
0 g
s
.626 .292 .384 r
.50747 .17159 m .48952 .17258 L .49091 .16546 L p F P
0 g
s
.626 .292 .384 r
.49091 .16546 m .50246 .16482 L .50747 .17159 L p F P
0 g
s
.642 .592 .783 r
.40659 .34869 m .4283 .33992 L p .42157 .32609 L F P
0 g
s
.642 .592 .783 r
.42157 .32609 m .4004 .33467 L .40659 .34869 L p F P
0 g
s
.642 .592 .783 r
.43102 .34612 m .4283 .33992 L .40659 .34869 L p F P
0 g
s
.109 0 .288 r
.45847 .664 m .46935 .65435 L .46784 .6635 L p F P
0 g
s
.109 0 .288 r
.46784 .6635 m .45399 .67574 L .45847 .664 L p F P
0 g
s
.631 .678 .876 r
.48432 .59878 m .47372 .60166 L .48303 .5969 L closepath p F P
0 g
s
.567 .489 .727 r
.47372 .60166 m .48432 .59878 L .49004 .61463 L p F P
0 g
s
.818 .641 .663 r
.69166 .25694 m .69101 .25826 L .69228 .25882 L closepath p F P
0 g
s
.592 .78 .97 r
.73264 .92075 m .7558 .91629 L .76087 .92122 L p F P
0 g
s
.573 .734 .951 r
.7558 .91629 m .73264 .92075 L .72732 .91348 L p F P
0 g
s
.717 .282 0 r
.21123 .86652 m .20668 .8603 L .21183 .86969 L p F P
0 g
s
.717 .282 0 r
.21183 .86969 m .21644 .87586 L .21123 .86652 L p F P
0 g
s
.81 .635 .666 r
.69166 .25694 m .69101 .25826 L p .68419 .24171 L F P
0 g
s
.81 .635 .666 r
.68419 .24171 m .68705 .24288 L .69166 .25694 L p F P
0 g
s
.693 .655 .808 r
.51892 .35822 m .49678 .36999 L .50284 .38166 L p F P
0 g
s
.693 .655 .808 r
.50284 .38166 m .52494 .36978 L .51892 .35822 L p F P
0 g
s
.694 .655 .807 r
.53093 .38119 m .52494 .36978 L .50284 .38166 L p F P
0 g
s
.759 .687 .782 r
.64054 .35222 m .65944 .33596 L .64641 .33114 L p F P
0 g
s
.759 .687 .782 r
.6349 .35026 m .64054 .35222 L p .64641 .33114 L F P
0 g
s
.506 .485 .768 r
.65304 .85087 m .65411 .84999 L p .66143 .86612 L F P
0 g
s
.473 .466 .769 r
.65304 .85087 m .65252 .84948 L .65411 .84999 L closepath p F P
0 g
s
.772 .687 .769 r
.65947 .33593 m .67484 .32094 L .66255 .31584 L p F P
0 g
s
.778 .693 .77 r
.67484 .32094 m .65947 .33593 L .65949 .33598 L p F P
0 g
s
.526 .719 .961 r
.6482 .59505 m .62528 .59698 L .63087 .60313 L p F P
0 g
s
.526 .719 .961 r
.63087 .60313 m .65373 .60122 L .6482 .59505 L p F P
0 g
s
.602 .744 .944 r
.61286 .59942 m .62528 .59698 L .63087 .60313 L p F P
0 g
s
.687 .341 .384 r
.54743 .16455 m .55469 .16505 L .55855 .17235 L p F P
0 g
s
.69 .336 .37 r
.57655 .17385 m .55855 .17235 L .55469 .16505 L p F P
0 g
s
.69 .336 .37 r
.57745 .16851 m .57655 .17385 L p .55469 .16505 L F P
0 g
s
.372 .359 .715 r
.63299 .78844 m .63754 .78181 L p .64129 .79902 L F P
0 g
s
.372 .359 .715 r
.64129 .79902 m .63458 .79388 L .63299 .78844 L p F P
0 g
s
.661 .619 .796 r
.45638 .34355 m .43448 .35339 L .44066 .36633 L p F P
0 g
s
.661 .619 .796 r
.44066 .36633 m .46253 .35646 L .45638 .34355 L p F P
0 g
s
.662 .618 .795 r
.46551 .3627 m .46253 .35646 L .44066 .36633 L p F P
0 g
s
.482 .457 .754 r
.65411 .84999 m .65252 .84948 L .64744 .83468 L p F P
0 g
s
.715 .366 .386 r
.57745 .16851 m .5801 .17431 L .57655 .17385 L closepath p F P
0 g
s
0 0 .519 r
.2214 .88188 m .21644 .87586 L p .22928 .89029 L F P
0 g
s
0 0 .519 r
.22928 .89029 m .22947 .89052 L .2214 .88188 L p F P
0 g
s
.891 .798 .751 r
.40448 .8351 m .39849 .82939 L .38984 .8427 L p F P
0 g
s
.891 .798 .751 r
.38984 .8427 m .39597 .84834 L .40448 .8351 L p F P
0 g
s
.762 .46 .473 r
.60859 .17867 m .61725 .18048 L .61828 .18905 L p F P
0 g
s
.77 .465 .471 r
.63488 .19288 m .61828 .18905 L .61725 .18048 L p F P
0 g
s
0 0 .253 r
.85077 .84806 m .85157 .84679 L .85334 .83507 L p F P
0 g
s
0 0 .215 r
.85787 .82713 m .85334 .83507 L .85157 .84679 L p F P
0 g
s
0 0 .387 r
.85334 .83507 m .85787 .82713 L .85749 .81598 L p F P
0 g
s
.631 .292 .379 r
.51719 .17117 m .50747 .17159 L .50246 .16482 L p F P
0 g
s
.631 .292 .379 r
.50246 .16482 m .51852 .16413 L .51719 .17117 L p F P
0 g
s
.855 .789 .785 r
.38013 .88179 m .3775 .88498 L .37092 .8793 L p F P
0 g
s
.855 .789 .785 r
.37092 .8793 m .37321 .87649 L .38013 .88179 L p F P
0 g
s
.854 .789 .787 r
.38013 .88179 m .37321 .87649 L .38494 .86231 L p F P
0 g
s
.81 .635 .666 r
.69101 .25826 m .6784 .25312 L .68419 .24171 L p F P
0 g
s
.804 .648 .69 r
.6784 .25312 m .69101 .25826 L .68365 .27028 L p F P
0 g
s
.361 .359 .722 r
.63752 .80356 m .63458 .79388 L .64129 .79902 L closepath p F P
0 g
s
.716 .673 .807 r
.55903 .3793 m .58126 .36533 L p .5668 .35972 L F P
0 g
s
.716 .673 .807 r
.5668 .35972 m .55311 .36822 L .55903 .3793 L p F P
0 g
s
.708 .666 .806 r
.55903 .3793 m .55311 .36822 L .53093 .38119 L p F P
0 g
s
.527 .512 .782 r
.66143 .86612 m .68166 .87069 L p .67258 .88126 L F P
0 g
s
.467 .464 .771 r
.66143 .86612 m .68166 .87069 L .67587 .85714 L p F P
0 g
s
.467 .464 .771 r
.67587 .85714 m .67309 .85621 L .66143 .86612 L p F P
0 g
s
.506 .485 .768 r
.65411 .84999 m .67309 .85621 L .66143 .86612 L p F P
0 g
s
.436 .612 .923 r
.72718 .63656 m .74504 .6389 L .74716 .64611 L p F P
0 g
s
.425 .616 .93 r
.74504 .6389 m .72718 .63656 L .72189 .62914 L p F P
0 g
s
.878 .492 .025 r
.6017 .67902 m .59708 .67251 L .59392 .66295 L p F P
0 g
s
.687 .341 .384 r
.55855 .17235 m .54616 .17151 L .54743 .16455 L p F P
0 g
s
.662 .318 .38 r
.53039 .16421 m .54743 .16455 L .54616 .17151 L p F P
0 g
s
.775 .692 .772 r
.65947 .33593 m .65944 .33596 L .65949 .33598 L closepath p F P
0 g
s
.343 .5 .87 r
.80636 .69163 m .80136 .68977 L .79615 .68024 L p F P
0 g
s
.772 .687 .769 r
.66255 .31584 m .65379 .32422 L .65947 .33593 L p F P
0 g
s
.771 .684 .768 r
.64641 .33114 m .65379 .32422 L .65947 .33593 L p F P
0 g
s
.771 .684 .768 r
.65947 .33593 m .65944 .33596 L .64641 .33114 L p F P
0 g
s
.871 .502 .014 r
.20373 .85039 m .19957 .84398 L .20248 .85393 L p F P
0 g
s
.871 .502 .014 r
.20248 .85393 m .20668 .8603 L .20373 .85039 L p F P
0 g
s
.822 .796 .828 r
.36398 .89714 m .35539 .90514 L .34872 .89967 L p F P
0 g
s
.822 .796 .828 r
.34872 .89967 m .35698 .89191 L .36398 .89714 L p F P
0 g
s
.815 .795 .833 r
.37092 .8793 m .35698 .89191 L .36398 .89714 L p F P
0 g
s
.815 .795 .833 r
.36398 .89714 m .3775 .88498 L .37092 .8793 L p F P
0 g
s
.703 .661 .806 r
.53093 .38119 m .55311 .36822 L p .54586 .3577 L F P
0 g
s
.703 .661 .806 r
.54586 .3577 m .52494 .36978 L .53093 .38119 L p F P
0 g
s
.418 .396 .728 r
.63752 .80356 m .64129 .79902 L p .64494 .81621 L F P
0 g
s
.418 .396 .728 r
.64494 .81621 m .6406 .81365 L .63752 .80356 L p F P
0 g
s
.8 .569 .588 r
.64951 .20649 m .66392 .21109 L .66138 .22118 L p F P
0 g
s
.808 .577 .589 r
.67518 .22597 m .66138 .22118 L .66392 .21109 L p F P
0 g
s
.601 .328 .475 r
.46257 .18399 m .46308 .17552 L .4378 .17987 L p F P
0 g
s
.601 .328 .475 r
.4378 .17987 m .43721 .18834 L .46257 .18399 L p F P
0 g
s
.482 .457 .754 r
.64744 .83468 m .64898 .83326 L p .65411 .84999 L F P
0 g
s
.442 .433 .754 r
.64744 .83468 m .64659 .8322 L .64898 .83326 L closepath p F P
0 g
s
.657 .317 .385 r
.51852 .16413 m .53039 .16421 L .53474 .17128 L p F P
0 g
s
.662 .318 .38 r
.54616 .17151 m .53474 .17128 L .53039 .16421 L p F P
0 g
s
.453 .428 .74 r
.64898 .83326 m .64659 .8322 L .64231 .81895 L p F P
0 g
s
.657 .317 .385 r
.53474 .17128 m .51719 .17117 L .51852 .16413 L p F P
0 g
s
.453 .428 .74 r
.64231 .81895 m .64494 .81621 L p .64898 .83326 L F P
0 g
s
.406 .398 .738 r
.64231 .81895 m .6406 .81365 L .64494 .81621 L closepath p F P
0 g
s
.612 .853 .989 r
.7839 .9131 m .76087 .92122 L .7558 .91629 L p F P
0 g
s
.561 .594 .844 r
.72014 .90528 m .69867 .90567 L .69307 .89501 L p F P
0 g
s
.935 .824 .712 r
.40956 .81261 m .41424 .80332 L .4094 .79717 L p F P
0 g
s
.545 .538 .797 r
.67258 .88126 m .6874 .88332 L p .69006 .89481 L F P
0 g
s
.513 .534 .815 r
.6874 .88332 m .67258 .88126 L .68282 .87321 L closepath p F P
0 g
s
.527 .512 .782 r
.68166 .87069 m .68282 .87321 L .67258 .88126 L p F P
0 g
s
.917 .52 .208 r
.59392 .66295 m .58694 .65707 L .59023 .6666 L p F P
0 g
s
.917 .52 .208 r
.59023 .6666 m .59708 .67251 L .59392 .66295 L p F P
0 g
s
.454 .476 .792 r
.66456 .84027 m .65411 .84999 L .67309 .85621 L p F P
0 g
s
.482 .457 .754 r
.64898 .83326 m .66456 .84027 L .65411 .84999 L p F P
0 g
s
.467 .651 .939 r
.69315 .62063 m .71411 .62169 L .71748 .62866 L p F P
0 g
s
.459 .657 .946 r
.71411 .62169 m .69315 .62063 L .68777 .6138 L p F P
0 g
s
.957 .904 .726 r
.42248 .77196 m .41595 .78454 L .41284 .77778 L p F P
0 g
s
.957 .904 .726 r
.42029 .766 m .42248 .77196 L p .41284 .77778 L F P
0 g
s
.81 .61 .633 r
.68419 .24171 m .67099 .23674 L .67518 .22597 L p F P
0 g
s
.804 .627 .662 r
.67099 .23674 m .68419 .24171 L .6784 .25312 L p F P
0 g
s
.979 .917 .625 r
.4302 .74074 m .42977 .73303 L .42389 .74539 L p F P
0 g
s
.979 .917 .625 r
.42389 .74539 m .4251 .75284 L .4302 .74074 L p F P
0 g
s
.591 .398 .589 r
.41416 .21358 m .41322 .20362 L .39012 .2105 L p F P
0 g
s
.591 .398 .589 r
.41286 .21469 m .41416 .21358 L p .39012 .2105 L F P
0 g
s
.591 .398 .589 r
.39012 .2105 m .39105 .22113 L .41286 .21469 L p F P
0 g
s
.794 .53 .537 r
.64951 .20649 m .64371 .2048 L .6426 .19484 L p F P
0 g
s
.781 .52 .541 r
.63488 .19288 m .6426 .19484 L .64371 .2048 L p F P
0 g
s
.916 .583 .395 r
.58539 .64709 m .57713 .64153 L .57875 .6515 L p F P
0 g
s
.916 .583 .395 r
.58691 .65693 m .58539 .64709 L p .57875 .6515 L F P
0 g
s
.062 .094 .582 r
.85699 .78261 m .85493 .78742 L .85911 .79746 L p F P
0 g
s
.144 .193 .654 r
.85446 .77346 m .85237 .77 L p .85493 .78742 L F P
0 g
s
.144 .193 .654 r
.85493 .78742 m .85699 .78261 L .85446 .77346 L p F P
0 g
s
.803 .601 .628 r
.66138 .22118 m .67518 .22597 L .67099 .23674 L p F P
0 g
s
.505 .351 .606 r
.49033 .61711 m .48746 .61587 L .49004 .61463 L closepath p F P
0 g
s
0 0 0 r
.83266 .88085 m .83309 .88038 L .8333 .88002 L closepath p F P
0 g
s
.802 .667 .714 r
.68677 .2882 m .67454 .28299 L .68365 .27028 L p F P
0 g
s
.788 .671 .734 r
.67596 .30154 m .68677 .2882 L .67454 .28299 L p F P
0 g
s
.86 .57 .497 r
.57662 .6313 m .56583 .62646 L .56633 .6367 L p F P
0 g
s
.86 .57 .497 r
.56633 .6367 m .57713 .64153 L .57662 .6313 L p F P
0 g
s
.656 .946 .703 r
.83309 .88038 m .83266 .88085 L .81799 .89587 L p F P
0 g
s
.582 .42 .627 r
.3928 .2328 m .39218 .22858 L .37052 .23929 L p F P
0 g
s
.582 .42 .627 r
.37052 .23929 m .37073 .24076 L .3928 .2328 L p F P
0 g
s
.736 .677 .794 r
.60934 .3608 m .60211 .36603 L .58557 .36249 L p F P
0 g
s
.326 .496 .873 r
.7901 .67798 m .79615 .68024 L .79093 .67099 L p F P
0 g
s
.326 .496 .873 r
.79093 .67099 m .78963 .67049 L .7901 .67798 L p F P
0 g
s
0 .193 .689 r
.23657 .89761 m .23489 .89634 L .22947 .89052 L p F P
0 g
s
.397 .577 .911 r
.77006 .65778 m .76143 .65597 L .75621 .64791 L p F P
0 g
s
.028 .147 .654 r
.6286 .74769 m .62613 .75587 L .63338 .76468 L p F P
0 g
s
.221 .251 .681 r
.62253 .73862 m .6286 .74769 L .62613 .75587 L p F P
0 g
s
.762 .46 .473 r
.61828 .18905 m .60851 .18702 L .60859 .17867 L p F P
0 g
s
.745 .446 .475 r
.59936 .17714 m .60859 .17867 L .60851 .18702 L p F P
0 g
s
.759 .687 .782 r
.64641 .33114 m .63159 .34371 L .6349 .35026 L p F P
0 g
s
.754 .685 .785 r
.63159 .34371 m .62674 .3477 L .6349 .35026 L closepath p F P
0 g
s
.789 .558 .587 r
.56805 .61545 m .55383 .61163 L .55083 .62289 L p F P
0 g
s
.789 .558 .587 r
.55083 .62289 m .56583 .62646 L .56805 .61545 L p F P
0 g
s
.858 .933 .873 r
.25521 .68464 m .2626 .67771 L .2633 .66904 L p F P
0 g
s
.833 .922 .894 r
.27727 .66527 m .2626 .67771 L .2633 .66904 L p F P
0 g
s
.596 .368 .54 r
.42588 .20065 m .41322 .20362 L .41304 .19402 L p F P
0 g
s
.596 .368 .54 r
.41304 .19402 m .4312 .18973 L .42588 .20065 L p F P
0 g
s
.71 .986 .843 r
.81799 .89587 m .81127 .90148 L .80681 .90146 L p F P
0 g
s
.836 .893 .471 r
.44018 .70884 m .44344 .69986 L .43778 .71211 L p F P
0 g
s
.836 .893 .471 r
.43574 .72038 m .44018 .70884 L p .43778 .71211 L F P
0 g
s
.858 .933 .873 r
.2633 .66904 m .24769 .68339 L .25521 .68464 L p F P
0 g
s
.858 .925 .872 r
.25521 .68464 m .24641 .69305 L .24632 .68468 L p F P
0 g
s
.858 .925 .872 r
.24632 .68468 m .24769 .68339 L .25521 .68464 L p F P
0 g
s
.597 .457 .662 r
.39536 .24551 m .3928 .2328 L .37073 .24076 L p F P
0 g
s
.597 .457 .662 r
.37073 .24076 m .37325 .25343 L .39536 .24551 L p F P
0 g
s
.952 .652 .215 r
.1985 .83359 m .19472 .82699 L .19577 .8374 L p F P
0 g
s
.952 .652 .215 r
.19577 .8374 m .19957 .84398 L .1985 .83359 L p F P
0 g
s
.659 .717 .891 r
.597 .59515 m .5861 .59952 L .56962 .59754 L p F P
0 g
s
0 0 0 r
.84686 .85932 m .83857 .87279 L .83309 .88038 L p F P
0 g
s
.648 .893 .555 r
.82931 .88386 m .83857 .87279 L .83309 .88038 L closepath p F P
0 g
s
.656 .946 .703 r
.82931 .88386 m .83309 .88038 L p .81799 .89587 L F P
0 g
s
.878 .927 .852 r
.24641 .69305 m .24632 .68468 L .23231 .69939 L p F P
0 g
s
.878 .927 .852 r
.23284 .70747 m .24641 .69305 L p .23231 .69939 L F P
0 g
s
.593 .745 .949 r
.62528 .59698 m .61286 .59942 L .60493 .59362 L p F P
0 g
s
.71 .986 .843 r
.80681 .90146 m .82527 .88753 L .81799 .89587 L p F P
0 g
s
.656 .946 .703 r
.81799 .89587 m .82527 .88753 L .82931 .88386 L p F P
0 g
s
.649 .772 .938 r
.47192 .58459 m .44992 .59193 L .45623 .59776 L p F P
0 g
s
.649 .772 .938 r
.45623 .59776 m .47816 .59072 L .47192 .58459 L p F P
0 g
s
.666 .804 .949 r
.45623 .59776 m .44992 .59193 L .44099 .59518 L p F P
0 g
s
.639 .708 .897 r
.45623 .59776 m .47816 .59072 L .48303 .5969 L p F P
0 g
s
.996 .864 .568 r
.19731 .78661 m .19391 .79816 L .19097 .7911 L p F P
0 g
s
.996 .864 .568 r
.19521 .78144 m .19731 .78661 L p .19097 .7911 L F P
0 g
s
.392 .582 .917 r
.74716 .64611 m .75621 .64791 L .75098 .64009 L p F P
0 g
s
.392 .582 .917 r
.75098 .64009 m .74504 .6389 L .74716 .64611 L p F P
0 g
s
.741 .683 .795 r
.60934 .3608 m .62674 .3477 L .61173 .34358 L p F P
0 g
s
.741 .683 .795 r
.61173 .34358 m .60355 .34965 L .60934 .3608 L p F P
0 g
s
.736 .677 .794 r
.58557 .36249 m .60355 .34965 L .60934 .3608 L p F P
0 g
s
.413 .442 .781 r
.65777 .82385 m .64898 .83326 L .66456 .84027 L p F P
0 g
s
.453 .428 .74 r
.64494 .81621 m .65777 .82385 L .64898 .83326 L p F P
0 g
s
.83 .929 .898 r
.28387 .65224 m .2699 .66353 L .27727 .66527 L p F P
0 g
s
.83 .929 .898 r
.27727 .66527 m .28207 .66133 L .28387 .65224 L p F P
0 g
s
.833 .922 .894 r
.2633 .66904 m .2699 .66353 L .27727 .66527 L p F P
0 g
s
0 0 .077 r
.45194 .68031 m .45399 .67574 L .45282 .67712 L closepath p F P
0 g
s
0 0 .042 r
.44884 .68774 m .45194 .68031 L .45282 .67712 L p F P
0 g
s
.676 .64 .806 r
.46551 .3627 m .46867 .36886 L .48834 .35933 L closepath p F P
0 g
s
.97 .909 .697 r
.20579 .75514 m .20374 .74764 L .19733 .76006 L p F P
0 g
s
.97 .909 .697 r
.19733 .76006 m .19947 .76749 L .20579 .75514 L p F P
0 g
s
.626 .439 .609 r
.49033 .61711 m .49325 .61403 L .49004 .61463 L closepath p F P
0 g
s
.631 .552 .747 r
.51245 .60357 m .49325 .61403 L .49004 .61463 L p F P
0 g
s
.631 .552 .747 r
.50706 .59192 m .51245 .60357 L p .49004 .61463 L F P
0 g
s
.631 .552 .747 r
.49499 .59486 m .50706 .59192 L p .49004 .61463 L F P
0 g
s
.631 .552 .747 r
.49004 .61463 m .48432 .59878 L .49499 .59486 L p F P
0 g
s
.642 .592 .783 r
.39983 .33337 m .4004 .33467 L .42157 .32609 L closepath p F P
0 g
s
.666 .83 .963 r
.44352 .58716 m .4216 .59562 L .42808 .60001 L p F P
0 g
s
.666 .83 .963 r
.4484 .59074 m .44352 .58716 L p .42808 .60001 L F P
0 g
s
.666 .83 .963 r
.42808 .60001 m .44099 .59518 L .4484 .59074 L p F P
0 g
s
.739 .891 .948 r
.36457 .60833 m .34276 .62022 L .34966 .62353 L p F P
0 g
s
.739 .891 .948 r
.34966 .62353 m .37139 .61155 L .36457 .60833 L p F P
0 g
s
.753 .886 .939 r
.33789 .62305 m .34276 .62022 L .34966 .62353 L p F P
0 g
s
.805 .915 .913 r
.29915 .64852 m .28207 .66133 L .28387 .65224 L p F P
0 g
s
.774 .513 .54 r
.61828 .18905 m .63488 .19288 L .63389 .20231 L p F P
0 g
s
.781 .52 .541 r
.64371 .2048 m .63389 .20231 L .63488 .19288 L p F P
0 g
s
.637 .573 .767 r
.39424 .31952 m .39983 .33337 L .42157 .32609 L p F P
0 g
s
.739 .44 .476 r
.5801 .17431 m .59936 .17714 L .60042 .18568 L p F P
0 g
s
.745 .446 .475 r
.60851 .18702 m .60042 .18568 L .59936 .17714 L p F P
0 g
s
.891 .798 .751 r
.39338 .85238 m .39597 .84834 L .38984 .8427 L p F P
0 g
s
.128 .481 .898 r
.23657 .89761 m .25119 .90284 L .24586 .89699 L p F P
0 g
s
.128 .481 .898 r
.24586 .89699 m .22955 .89058 L .23657 .89761 L p F P
0 g
s
0 .193 .689 r
.22947 .89052 m .22955 .89058 L .23657 .89761 L p F P
0 g
s
.59 .388 .575 r
.49325 .61403 m .514 .60964 L p .49086 .62589 L F P
0 g
s
.59 .388 .575 r
.49086 .62589 m .49033 .61711 L .49325 .61403 L p F P
0 g
s
.637 .508 .689 r
.49325 .61403 m .514 .60964 L .51245 .60357 L closepath p F P
0 g
s
.878 .927 .852 r
.23231 .69939 m .23271 .70746 L .23284 .70747 L p F P
0 g
s
.884 .922 .844 r
.23271 .70746 m .23284 .70747 L .23272 .7076 L closepath p F P
0 g
s
.905 .937 .821 r
.23272 .7076 m .22137 .72145 L .22042 .71344 L p F P
0 g
s
.905 .937 .821 r
.23271 .70746 m .23272 .7076 L p .22042 .71344 L F P
0 g
s
.503 .691 .952 r
.65922 .60757 m .67452 .6071 L .6795 .61368 L p F P
0 g
s
.498 .697 .958 r
.65922 .60757 m .67452 .6071 L .66862 .60073 L p F P
0 g
s
.498 .697 .958 r
.66862 .60073 m .65373 .60122 L .65922 .60757 L p F P
0 g
s
.101 .165 .644 r
.85446 .77346 m .85237 .77 L .853 .76823 L closepath p F P
0 g
s
.18 .256 .706 r
.8484 .7542 m .84755 .75314 L p .85237 .77 L F P
0 g
s
.18 .256 .706 r
.85237 .77 m .853 .76823 L .8484 .7542 L p F P
0 g
s
.788 .671 .734 r
.67574 .30145 m .67596 .30154 L p .67454 .28299 L F P
0 g
s
.784 .682 .752 r
.67574 .30145 m .67584 .30166 L .67596 .30154 L closepath p F P
0 g
s
.778 .68 .756 r
.67584 .30166 m .66255 .31584 L p .66316 .29655 L F P
0 g
s
.778 .68 .756 r
.66316 .29655 m .67574 .30145 L .67584 .30166 L p F P
0 g
s
0 0 .065 r
.85035 .85064 m .85157 .84679 L .85077 .84806 L closepath p F P
0 g
s
.804 .648 .69 r
.68365 .27028 m .6709 .2652 L .6784 .25312 L p F P
0 g
s
.79 .653 .711 r
.67454 .28299 m .68365 .27028 L .6709 .2652 L p F P
0 g
s
.788 .671 .734 r
.67454 .28299 m .67012 .2883 L .67574 .30145 L p F P
0 g
s
.787 .67 .735 r
.67012 .2883 m .66316 .29655 L .67574 .30145 L closepath p F P
0 g
s
.903 .939 .824 r
.22505 .70792 m .23231 .69939 L .23271 .70746 L closepath p F P
0 g
s
.905 .937 .821 r
.22042 .71344 m .22505 .70792 L .23271 .70746 L p F P
0 g
s
.539 .753 .975 r
.28462 .9075 m .26365 .90988 L .27065 .91552 L p F P
0 g
s
.539 .753 .975 r
.27065 .91552 m .2916 .91279 L .28462 .9075 L p F P
0 g
s
.277 .614 .957 r
.25684 .90853 m .26365 .90988 L .27065 .91552 L p F P
0 g
s
.66 .616 .794 r
.43102 .34612 m .43448 .35339 L .45638 .34355 L p F P
0 g
s
.535 .56 .827 r
.69307 .89501 m .69006 .89481 L .69223 .89327 L closepath p F P
0 g
s
.545 .538 .797 r
.6874 .88332 m .69223 .89327 L .69006 .89481 L p F P
0 g
s
.475 .676 .953 r
.6795 .61368 m .68777 .6138 L .68237 .60719 L p F P
0 g
s
.475 .676 .953 r
.68237 .60719 m .67452 .6071 L .6795 .61368 L p F P
0 g
s
0 .018 .581 r
.62307 .73088 m .62253 .73862 L .6286 .74769 L p F P
0 g
s
0 .043 .591 r
.62253 .73862 m .62307 .73088 L .61792 .72161 L p F P
0 g
s
.935 .824 .712 r
.4094 .79717 m .40298 .80942 L .40956 .81261 L p F P
0 g
s
.907 .844 .771 r
.40956 .81261 m .40725 .81609 L .40266 .80989 L p F P
0 g
s
.907 .844 .771 r
.40266 .80989 m .40298 .80942 L .40956 .81261 L p F P
0 g
s
.421 .172 .429 r
.47047 .6449 m .49048 .63597 L p .48402 .64788 L F P
0 g
s
.421 .172 .429 r
.48402 .64788 m .46935 .65435 L .47047 .6449 L p F P
0 g
s
.452 .232 .488 r
.49086 .62589 m .49048 .63597 L .47047 .6449 L p F P
0 g
s
.664 .691 .865 r
.48432 .59878 m .49499 .59486 L .48303 .5969 L closepath p F P
0 g
s
.314 .455 .843 r
.80636 .69163 m .82039 .69849 L .81999 .70607 L p F P
0 g
s
.277 .449 .851 r
.80624 .68412 m .80636 .69163 L .82039 .69849 L p F P
0 g
s
.343 .5 .87 r
.79615 .68024 m .80624 .68412 L .80636 .69163 L p F P
0 g
s
.891 .798 .751 r
.38984 .8427 m .38681 .84738 L .39338 .85238 L p F P
0 g
s
.859 .81 .801 r
.39338 .85238 m .38494 .86231 L .37881 .85671 L p F P
0 g
s
.859 .81 .801 r
.37881 .85671 m .38681 .84738 L .39338 .85238 L p F P
0 g
s
.751 .677 .78 r
.63159 .34371 m .62674 .3477 L .61173 .34358 L p F P
0 g
s
0 0 .13 r
.45399 .67574 m .46784 .6635 L p .461 .67589 L F P
0 g
s
0 0 .13 r
.45194 .68031 m .45399 .67574 L p .461 .67589 L F P
0 g
s
.689 .649 .805 r
.49108 .35895 m .49678 .36999 L .51892 .35822 L p F P
0 g
s
.676 .641 .808 r
.49678 .36999 m .49108 .35895 L .48834 .35933 L p F P
0 g
s
.785 .635 .694 r
.56962 .59754 m .56819 .59684 L .55383 .61163 L p F P
0 g
s
.659 .717 .891 r
.59126 .58892 m .597 .59515 L p .56962 .59754 L F P
0 g
s
.659 .717 .891 r
.56962 .59754 m .56882 .59645 L .59126 .58892 L p F P
0 g
s
.743 .745 .853 r
.56819 .59684 m .56962 .59754 L .56882 .59645 L closepath p F P
0 g
s
.726 .681 .805 r
.57911 .36131 m .58126 .36533 L .58557 .36249 L closepath p F P
0 g
s
.716 .673 .807 r
.58126 .36533 m .57911 .36131 L .5668 .35972 L p F P
0 g
s
.36 .403 .77 r
.65189 .80717 m .64494 .81621 L .65777 .82385 L p F P
0 g
s
.418 .396 .728 r
.64129 .79902 m .65189 .80717 L .64494 .81621 L p F P
0 g
s
.987 .752 .363 r
.19526 .81618 m .19188 .80936 L .19131 .82019 L p F P
0 g
s
.987 .752 .363 r
.19131 .82019 m .19472 .82699 L .19526 .81618 L p F P
0 g
s
.431 .629 .937 r
.71748 .62866 m .72189 .62914 L .71658 .62196 L p F P
0 g
s
.431 .629 .937 r
.71658 .62196 m .71411 .62169 L .71748 .62866 L p F P
0 g
s
.754 .682 .781 r
.63159 .34371 m .64641 .33114 L .6325 .32659 L p F P
0 g
s
.754 .682 .781 r
.6325 .32659 m .62584 .33215 L .63159 .34371 L p F P
0 g
s
.751 .677 .78 r
.61173 .34358 m .62584 .33215 L .63159 .34371 L p F P
0 g
s
.905 .831 .762 r
.40725 .81609 m .40266 .80989 L .39351 .82334 L p F P
0 g
s
.905 .831 .762 r
.39351 .82334 m .39849 .82939 L .40725 .81609 L p F P
0 g
s
.627 .35 .478 r
.47582 .18245 m .46257 .18399 L .46308 .17552 L p F P
0 g
s
.627 .35 .478 r
.46308 .17552 m .47451 .17418 L .47582 .18245 L p F P
0 g
s
.799 .923 .919 r
.30963 .63375 m .29193 .64629 L .29915 .64852 L p F P
0 g
s
.799 .923 .919 r
.29915 .64852 m .30625 .64341 L .30963 .63375 L p F P
0 g
s
.805 .915 .913 r
.28387 .65224 m .29193 .64629 L .29915 .64852 L p F P
0 g
s
.777 .809 .878 r
.32806 .90362 m .32003 .90908 L .32685 .91427 L p F P
0 g
s
.777 .809 .878 r
.32685 .91427 m .33456 .90899 L .32806 .90362 L p F P
0 g
s
0 0 .369 r
.8615 .80805 m .85749 .81598 L .85787 .82713 L p F P
0 g
s
.003 0 .496 r
.85749 .81598 m .8615 .80805 L .85911 .79746 L p F P
0 g
s
.608 .486 .688 r
.39782 .25537 m .39536 .24551 L .37325 .25343 L p F P
0 g
s
.608 .486 .688 r
.37325 .25343 m .37612 .26514 L .39782 .25537 L p F P
0 g
s
.689 .856 .962 r
.41505 .59155 m .39317 .60103 L .3998 .60501 L p F P
0 g
s
.689 .856 .962 r
.3998 .60501 m .4216 .59562 L .41505 .59155 L p F P
0 g
s
.71 .861 .954 r
.3998 .60501 m .39317 .60103 L .3762 .60911 L p F P
0 g
s
.792 .561 .588 r
.64371 .2048 m .64951 .20649 L .64687 .21661 L p F P
0 g
s
.8 .569 .588 r
.66138 .22118 m .64687 .21661 L .64951 .20649 L p F P
0 g
s
.778 .68 .756 r
.66255 .31584 m .64944 .31098 L .66316 .29655 L p F P
0 g
s
.768 .682 .768 r
.65379 .32422 m .66255 .31584 L .64944 .31098 L p F P
0 g
s
.676 .626 .792 r
.46253 .35646 m .46551 .3627 L .48834 .35933 L p F P
0 g
s
.951 .864 .717 r
.41595 .78454 m .41284 .77778 L .40575 .7906 L p F P
0 g
s
.951 .864 .717 r
.40575 .7906 m .4094 .79717 L .41595 .78454 L p F P
0 g
s
.804 .627 .662 r
.6784 .25312 m .66509 .24819 L .67099 .23674 L p F P
0 g
s
.791 .634 .687 r
.6709 .2652 m .6784 .25312 L .66509 .24819 L p F P
0 g
s
.72 .881 .955 r
.37139 .61155 m .3762 .60911 L .37337 .61255 L closepath p F P
0 g
s
.637 .574 .768 r
.39236 .31488 m .39424 .31952 L .41596 .31057 L p F P
0 g
s
.637 .573 .767 r
.42212 .32587 m .41596 .31057 L .39424 .31952 L p F P
0 g
s
.637 .573 .767 r
.42157 .32609 m .42212 .32587 L p .39424 .31952 L F P
0 g
s
.768 .682 .768 r
.64944 .31098 m .64808 .31226 L .65379 .32422 L p F P
0 g
s
.765 .677 .765 r
.6325 .32659 m .64808 .31226 L .65379 .32422 L p F P
0 g
s
.765 .677 .765 r
.65379 .32422 m .64641 .33114 L .6325 .32659 L p F P
0 g
s
.729 .67 .792 r
.58557 .36249 m .60355 .34965 L p .59546 .33987 L F P
0 g
s
.729 .67 .792 r
.57911 .36131 m .58557 .36249 L p .59546 .33987 L F P
0 g
s
.651 .717 .896 r
.5064 .59088 m .49499 .59486 L .48303 .5969 L p F P
0 g
s
.651 .717 .896 r
.50028 .58359 m .5064 .59088 L p .48303 .5969 L F P
0 g
s
.651 .717 .896 r
.48303 .5969 m .47816 .59072 L .50028 .58359 L p F P
0 g
s
.139 .231 .698 r
.8484 .7542 m .84755 .75314 L .84778 .75233 L closepath p F P
0 g
s
.215 .315 .751 r
.84274 .73898 m .84053 .73686 L p .84755 .75314 L F P
0 g
s
.215 .315 .751 r
.84755 .75314 m .84778 .75233 L .84274 .73898 L p F P
0 g
s
.671 .559 .72 r
.56819 .59684 m .55383 .61163 L .54332 .61029 L p F P
0 g
s
.671 .559 .72 r
.55611 .59228 m .56819 .59684 L p .54332 .61029 L F P
0 g
s
.702 .75 .889 r
.56882 .59645 m .56819 .59684 L .55611 .59228 L p F P
0 g
s
.715 .67 .805 r
.5476 .35777 m .55311 .36822 L .5668 .35972 L closepath p F P
0 g
s
.703 .661 .806 r
.55311 .36822 m .5476 .35777 L .54586 .3577 L p F P
0 g
s
.701 .659 .805 r
.52494 .36978 m .54586 .3577 L .52071 .3572 L p F P
0 g
s
.701 .659 .805 r
.52071 .3572 m .51892 .35822 L .52494 .36978 L p F P
0 g
s
.658 .779 .938 r
.58547 .58289 m .56295 .58916 L .56882 .59645 L p F P
0 g
s
.658 .779 .938 r
.56882 .59645 m .59126 .58892 L .58547 .58289 L p F P
0 g
s
.702 .75 .889 r
.55611 .59228 m .56295 .58916 L .56882 .59645 L p F P
0 g
s
.561 .594 .844 r
.69307 .89501 m .71643 .89612 L p .72014 .90528 L F P
0 g
s
.512 .548 .829 r
.71087 .88619 m .71643 .89612 L .69307 .89501 L p F P
0 g
s
.512 .548 .829 r
.70207 .88506 m .71087 .88619 L p .69307 .89501 L F P
0 g
s
.512 .548 .829 r
.69307 .89501 m .69223 .89327 L .70207 .88506 L p F P
0 g
s
0 0 0 r
.85157 .84679 m .85607 .8389 L p .84916 .85603 L F P
0 g
s
0 0 0 r
.84916 .85603 m .85035 .85064 L .85157 .84679 L p F P
0 g
s
0 0 .215 r
.85157 .84679 m .85607 .8389 L .85787 .82713 L p F P
0 g
s
.28 .419 .824 r
.83183 .71324 m .81999 .70607 L p .83135 .72116 L F P
0 g
s
.243 .398 .819 r
.81999 .70607 m .83183 .71324 L .82653 .70231 L p F P
0 g
s
.243 .398 .819 r
.82653 .70231 m .82039 .69849 L .81999 .70607 L p F P
0 g
s
.58 .741 .952 r
.597 .59515 m .60493 .59362 L .59606 .58806 L p F P
0 g
s
.58 .741 .952 r
.59606 .58806 m .59126 .58892 L .597 .59515 L p F P
0 g
s
.861 .805 .793 r
.38494 .86231 m .37881 .85671 L .3669 .87098 L p F P
0 g
s
.861 .805 .793 r
.3669 .87098 m .37321 .87649 L .38494 .86231 L p F P
0 g
s
0 0 .45 r
.61668 .7143 m .61792 .72161 L .62307 .73088 L p F P
0 g
s
0 0 .467 r
.61792 .72161 m .61668 .7143 L .61223 .70489 L p F P
0 g
s
.981 .905 .652 r
.4251 .75284 m .42389 .74539 L .4179 .75784 L p F P
0 g
s
.981 .905 .652 r
.4179 .75784 m .41982 .76504 L .4251 .75284 L p F P
0 g
s
.777 .905 .93 r
.32096 .63369 m .30625 .64341 L .30963 .63375 L p F P
0 g
s
.95 .924 .746 r
.2097 .73799 m .21168 .7348 L .21218 .73716 L closepath p F P
0 g
s
.95 .922 .745 r
.20374 .74764 m .2097 .73799 L .21218 .73716 L p F P
0 g
s
.732 .435 .478 r
.57655 .17385 m .5801 .17431 L .58108 .18285 L p F P
0 g
s
.739 .44 .476 r
.60042 .18568 m .58108 .18285 L .5801 .17431 L p F P
0 g
s
.929 .934 .785 r
.22137 .72145 m .22042 .71344 L .21055 .72689 L p F P
0 g
s
.929 .934 .785 r
.21055 .72689 m .21168 .7348 L .22137 .72145 L p F P
0 g
s
.788 .588 .63 r
.65709 .23198 m .66138 .22118 L .64687 .21661 L p F P
0 g
s
.803 .601 .628 r
.67099 .23674 m .65709 .23198 L .66138 .22118 L p F P
0 g
s
.606 .439 .629 r
.39105 .22113 m .39218 .22858 L .41286 .21469 L closepath p F P
0 g
s
.77 .81 .885 r
.34871 .89967 m .33456 .90899 L .32806 .90362 L p F P
0 g
s
.79 .612 .66 r
.66509 .24819 m .67099 .23674 L .65709 .23198 L p F P
0 g
s
.631 .352 .478 r
.48909 .18103 m .47582 .18245 L .47451 .17418 L p F P
0 g
s
.631 .352 .478 r
.47451 .17418 m .48952 .17258 L .48909 .18103 L p F P
0 g
s
.631 .554 .75 r
.38811 .30327 m .39236 .31488 L .41464 .30729 L p F P
0 g
s
.637 .574 .768 r
.41596 .31057 m .41464 .30729 L .39236 .31488 L p F P
0 g
s
.657 .6 .779 r
.4283 .33992 m .43102 .34612 L .45484 .3403 L p F P
0 g
s
.66 .616 .794 r
.45638 .34355 m .45484 .3403 L .43102 .34612 L p F P
0 g
s
.091 .158 .641 r
.853 .76823 m .85479 .76224 L p .8581 .77957 L F P
0 g
s
.091 .158 .641 r
.8581 .77957 m .85446 .77346 L .853 .76823 L p F P
0 g
s
.14 .229 .695 r
.853 .76823 m .8484 .7542 L .85479 .76224 L closepath p F P
0 g
s
.325 .497 .875 r
.80624 .68412 m .79615 .68024 L .79093 .67099 L p F P
0 g
s
.514 .55 .831 r
.69223 .89327 m .6874 .88332 L .70207 .88506 L closepath p F P
0 g
s
.599 .371 .542 r
.43749 .19798 m .42588 .20065 L .4312 .18973 L p F P
0 g
s
.599 .371 .542 r
.4312 .18973 m .43721 .18834 L .43749 .19798 L p F P
0 g
s
0 0 .13 r
.461 .67589 m .45041 .68549 L .45194 .68031 L p F P
0 g
s
0 0 0 r
.45041 .68549 m .45194 .68031 L .44884 .68774 L closepath p F P
0 g
s
.694 .804 .934 r
.31314 .90402 m .2916 .91279 L .29853 .91804 L p F P
0 g
s
.694 .804 .934 r
.29853 .91804 m .32003 .90908 L .31314 .90402 L p F P
0 g
s
.176 .293 .746 r
.84274 .73898 m .84053 .73686 L .84102 .73449 L closepath p F P
0 g
s
.248 .37 .791 r
.83725 .72564 m .83135 .72116 L p .84053 .73686 L F P
0 g
s
.248 .37 .791 r
.84053 .73686 m .84102 .73449 L .83725 .72564 L p F P
0 g
s
.573 .734 .951 r
.72732 .91348 m .75063 .91037 L .7558 .91629 L p F P
0 g
s
.552 .694 .934 r
.75063 .91037 m .72732 .91348 L .72192 .90526 L p F P
0 g
s
.213 .352 .788 r
.83725 .72564 m .83135 .72116 L .83223 .71409 L closepath p F P
0 g
s
.28 .419 .824 r
.83135 .72116 m .83223 .71409 L .83183 .71324 L p F P
0 g
s
.732 .435 .478 r
.58108 .18285 m .57638 .18225 L .57655 .17385 L p F P
0 g
s
.713 .42 .479 r
.55855 .17235 m .57655 .17385 L .57638 .18225 L p F P
0 g
s
.131 .225 .696 r
.85479 .76224 m .8484 .7542 L .84778 .75233 L p F P
0 g
s
.753 .531 .595 r
.55383 .61163 m .54332 .61029 L .54473 .62205 L p F P
0 g
s
.753 .531 .595 r
.54473 .62205 m .55083 .62289 L .55383 .61163 L p F P
0 g
s
.131 .225 .696 r
.84778 .75233 m .84938 .74544 L p .85479 .76224 L F P
0 g
s
.181 .292 .743 r
.84778 .75233 m .84274 .73898 L .84938 .74544 L closepath p F P
0 g
s
.729 .67 .792 r
.59546 .33987 m .57539 .35398 L .57911 .36131 L p F P
0 g
s
.722 .667 .796 r
.57539 .35398 m .5668 .35972 L .57911 .36131 L closepath p F P
0 g
s
.607 .484 .686 r
.39877 .25925 m .39782 .25537 L .37612 .26514 L p F P
0 g
s
.607 .484 .686 r
.37612 .26514 m .3766 .2671 L .39877 .25925 L p F P
0 g
s
.792 .561 .588 r
.64687 .21661 m .64587 .21632 L .64371 .2048 L p F P
0 g
s
.781 .554 .592 r
.63389 .20231 m .64371 .2048 L .64587 .21632 L p F P
0 g
s
.098 .162 .641 r
.85699 .78261 m .85446 .77346 L .8581 .77957 L closepath p F P
0 g
s
.79 .653 .711 r
.66657 .27991 m .67454 .28299 L p .6709 .2652 L F P
0 g
s
.786 .667 .732 r
.66657 .27991 m .67012 .2883 L .67454 .28299 L closepath p F P
0 g
s
.273 .604 .953 r
.26365 .90988 m .25684 .90853 L .25119 .90284 L p F P
0 g
s
.836 .893 .471 r
.43778 .71211 m .43562 .72057 L .43574 .72038 L p F P
0 g
s
.839 .894 .472 r
.43562 .72057 m .43574 .72038 L .43558 .72073 L closepath p F P
0 g
s
.288 .353 .756 r
.64634 .79038 m .64129 .79902 L .65189 .80717 L p F P
0 g
s
.372 .359 .715 r
.63754 .78181 m .64634 .79038 L .64129 .79902 L p F P
0 g
s
.767 .506 .54 r
.60851 .18702 m .61828 .18905 L .61723 .19849 L p F P
0 g
s
.774 .513 .54 r
.63389 .20231 m .61723 .19849 L .61828 .18905 L p F P
0 g
s
.855 .909 .501 r
.43558 .72073 m .43562 .72057 L .43112 .72731 L p F P
0 g
s
.855 .909 .501 r
.43112 .72731 m .42977 .73303 L .43558 .72073 L p F P
0 g
s
.617 .512 .711 r
.40306 .27408 m .39877 .25925 L .3766 .2671 L p F P
0 g
s
.617 .512 .711 r
.3766 .2671 m .38086 .28186 L .40306 .27408 L p F P
0 g
s
0 0 .008 r
.84686 .85932 m .84916 .85603 L .85035 .85064 L closepath p F P
0 g
s
.631 .555 .751 r
.38608 .29776 m .38811 .30327 L .40983 .29416 L p F P
0 g
s
.631 .554 .75 r
.41464 .30729 m .40983 .29416 L .38811 .30327 L p F P
0 g
s
.843 .906 .497 r
.43562 .72057 m .43778 .71211 L .43186 .72448 L p F P
0 g
s
.843 .906 .497 r
.43186 .72448 m .43112 .72731 L .43562 .72057 L p F P
0 g
s
.672 .624 .792 r
.46253 .35646 m .48459 .34538 L p .46705 .33823 L F P
0 g
s
.672 .624 .792 r
.46705 .33823 m .45638 .34355 L .46253 .35646 L p F P
0 g
s
.676 .626 .792 r
.49069 .35814 m .48459 .34538 L .46253 .35646 L p F P
0 g
s
.676 .626 .792 r
.48834 .35933 m .49069 .35814 L p .46253 .35646 L F P
0 g
s
.985 .898 .638 r
.19947 .76749 m .19733 .76006 L .19232 .77209 L p F P
0 g
s
.985 .898 .638 r
.19232 .77209 m .1945 .77949 L .19947 .76749 L p F P
0 g
s
.666 .321 0 r
.61223 .70489 m .60928 .69799 L .60536 .6885 L p F P
0 g
s
.68 .317 0 r
.60928 .69799 m .61223 .70489 L .61668 .7143 L p F P
0 g
s
.368 .546 .898 r
.78573 .66233 m .77006 .65778 L p .78963 .67049 L F P
0 g
s
.344 .538 .9 r
.77006 .65778 m .78573 .66233 L .78054 .65409 L p F P
0 g
s
.344 .538 .9 r
.78054 .65409 m .76838 .65049 L .77006 .65778 L p F P
0 g
s
.397 .577 .911 r
.75621 .64791 m .76838 .65049 L .77006 .65778 L p F P
0 g
s
.663 .815 .956 r
.4484 .59074 m .44992 .59193 L .44099 .59518 L closepath p F P
0 g
s
.793 .515 .516 r
.56583 .62646 m .55083 .62289 L .55161 .63304 L p F P
0 g
s
.793 .515 .516 r
.55161 .63304 m .56633 .6367 L .56583 .62646 L p F P
0 g
s
.425 .616 .93 r
.72189 .62914 m .74221 .63182 L .74504 .6389 L p F P
0 g
s
.414 .62 .937 r
.74221 .63182 m .72189 .62914 L .71658 .62196 L p F P
0 g
s
.623 .39 .543 r
.46292 .19364 m .46257 .18399 L .43721 .18834 L p F P
0 g
s
.623 .39 .543 r
.43721 .18834 m .43749 .19798 L .46292 .19364 L p F P
0 g
s
.656 .6 .78 r
.42214 .3259 m .4283 .33992 L .45022 .3298 L p F P
0 g
s
.642 .592 .783 r
.4283 .33992 m .42214 .3259 L .42157 .32609 L p F P
0 g
s
.657 .6 .779 r
.45484 .3403 m .45022 .3298 L .4283 .33992 L p F P
0 g
s
.78 .665 .736 r
.67012 .2883 m .66316 .29655 L p .6614 .27806 L F P
0 g
s
.78 .665 .736 r
.6614 .27806 m .66657 .27991 L .67012 .2883 L p F P
0 g
s
.625 .534 .731 r
.38205 .28547 m .38608 .29776 L .40832 .29006 L p F P
0 g
s
.631 .555 .751 r
.40983 .29416 m .40832 .29006 L .38608 .29776 L p F P
0 g
s
.655 .372 .48 r
.50863 .17996 m .48909 .18103 L .48952 .17258 L p F P
0 g
s
.655 .372 .48 r
.48952 .17258 m .50747 .17159 L .50863 .17996 L p F P
0 g
s
.625 .534 .731 r
.40832 .29006 m .40376 .27618 L .38205 .28547 L p F P
0 g
s
.625 .535 .733 r
.38086 .28186 m .38205 .28547 L .40376 .27618 L p F P
0 g
s
.739 .679 .792 r
.59887 .34053 m .60355 .34965 L .61173 .34358 L closepath p F P
0 g
s
.729 .67 .792 r
.60355 .34965 m .59887 .34053 L .59546 .33987 L p F P
0 g
s
.656 .674 .855 r
.49499 .59486 m .50706 .59192 L .5064 .59088 L closepath p F P
0 g
s
.004 .054 .562 r
.8581 .77957 m .85699 .78261 L .85989 .79569 L p F P
0 g
s
.062 .094 .582 r
.85911 .79746 m .85989 .79569 L .85699 .78261 L p F P
0 g
s
.863 .804 .791 r
.37092 .8793 m .37321 .87649 L .3669 .87098 L p F P
0 g
s
.707 .415 .479 r
.54616 .17151 m .55855 .17235 L .55958 .18085 L p F P
0 g
s
.713 .42 .479 r
.57638 .18225 m .55958 .18085 L .55855 .17235 L p F P
0 g
s
.625 .535 .733 r
.40376 .27618 m .40306 .27408 L .38086 .28186 L p F P
0 g
s
.614 .415 .59 r
.41322 .20362 m .41416 .21358 L .42588 .20065 L closepath p F P
0 g
s
.52 .726 .967 r
.64264 .58907 m .61966 .591 L .62528 .59698 L p F P
0 g
s
.52 .726 .967 r
.62528 .59698 m .6482 .59505 L .64264 .58907 L p F P
0 g
s
.593 .745 .949 r
.60493 .59362 m .61966 .591 L .62528 .59698 L p F P
0 g
s
.642 .928 .973 r
.79972 .9053 m .7839 .9131 L .77902 .90965 L p F P
0 g
s
.612 .853 .989 r
.7558 .91629 m .77902 .90965 L .7839 .9131 L p F P
0 g
s
.998 .819 .473 r
.19391 .79816 m .19097 .7911 L .1889 .80234 L p F P
0 g
s
.998 .819 .473 r
.1889 .80234 m .19188 .80936 L .19391 .79816 L p F P
0 g
s
.903 .822 .758 r
.39849 .82939 m .39351 .82334 L .38451 .83679 L p F P
0 g
s
.903 .822 .758 r
.38451 .83679 m .38984 .8427 L .39849 .82939 L p F P
0 g
s
.671 .559 .72 r
.54332 .61029 m .54066 .60211 L .55611 .59228 L p F P
0 g
s
.729 .51 .595 r
.54332 .61029 m .5339 .60956 L .53033 .621 L p F P
0 g
s
.729 .51 .595 r
.53033 .621 m .54473 .62205 L .54332 .61029 L p F P
0 g
s
.731 .592 .702 r
.5339 .60956 m .54332 .61029 L .54066 .60211 L closepath p F P
0 g
s
.696 .628 .776 r
.51245 .60357 m .53321 .59113 L .50706 .59192 L closepath p F P
0 g
s
.644 .513 .688 r
.514 .60964 m .51245 .60357 L .53321 .59113 L p F P
0 g
s
.86 .46 0 r
.60536 .6885 m .60061 .68204 L .59708 .67251 L p F P
0 g
s
.587 .342 .512 r
.49048 .63597 m .49086 .62589 L .515 .62105 L p F P
0 g
s
.59 .388 .575 r
.514 .60964 m .515 .62105 L .49086 .62589 L p F P
0 g
s
.864 .544 .443 r
.57713 .64153 m .56633 .6367 L .56818 .6466 L p F P
0 g
s
.864 .544 .443 r
.56818 .6466 m .57875 .6515 L .57713 .64153 L p F P
0 g
s
.713 .654 .789 r
.54066 .60211 m .55611 .59228 L .53511 .59115 L closepath p F P
0 g
s
.644 .513 .688 r
.54066 .60211 m .5339 .60956 L .514 .60964 L p F P
0 g
s
.644 .513 .688 r
.53511 .59115 m .54066 .60211 L p .514 .60964 L F P
0 g
s
.827 .809 .834 r
.34871 .89967 m .35698 .89191 L .35062 .88645 L p F P
0 g
s
.822 .812 .841 r
.37092 .8793 m .35698 .89191 L .35062 .88645 L p F P
0 g
s
.887 .537 .379 r
.58687 .65702 m .58691 .65693 L .58694 .65707 L closepath p F P
0 g
s
.916 .583 .395 r
.57875 .6515 m .58687 .65702 L .58691 .65693 L p F P
0 g
s
.718 .89 .959 r
.38646 .59727 m .36457 .60833 L .37139 .61155 L p F P
0 g
s
.718 .89 .959 r
.38679 .59743 m .38646 .59727 L p .37139 .61155 L F P
0 g
s
.718 .89 .959 r
.37139 .61155 m .3762 .60911 L .38679 .59743 L p F P
0 g
s
.863 .804 .791 r
.3669 .87098 m .36425 .87419 L .37092 .8793 L p F P
0 g
s
.822 .812 .841 r
.35062 .88645 m .36425 .87419 L .37092 .8793 L p F P
0 g
s
.719 .659 .79 r
.5668 .35972 m .57539 .35398 L p .54716 .35689 L F P
0 g
s
.719 .659 .79 r
.54716 .35689 m .5476 .35777 L .5668 .35972 L p F P
0 g
s
.827 .809 .834 r
.35062 .88645 m .34197 .89452 L .34871 .89967 L p F P
0 g
s
.77 .81 .885 r
.32806 .90362 m .34197 .89452 L .34871 .89967 L p F P
0 g
s
.881 .499 .311 r
.58694 .65707 m .58687 .65702 L .58184 .66185 L p F P
0 g
s
.881 .499 .311 r
.58184 .66185 m .59023 .6666 L .58694 .65707 L p F P
0 g
s
.767 .912 .938 r
.33576 .61744 m .31386 .63098 L .32096 .63369 L p F P
0 g
s
.767 .912 .938 r
.34004 .61899 m .33576 .61744 L p .32096 .63369 L F P
0 g
s
.767 .912 .938 r
.32096 .63369 m .33789 .62305 L .34004 .61899 L p F P
0 g
s
.777 .905 .93 r
.30963 .63375 m .31386 .63098 L .32096 .63369 L p F P
0 g
s
.909 .55 .342 r
.58687 .65702 m .57875 .6515 L .58107 .66133 L p F P
0 g
s
.909 .55 .342 r
.58107 .66133 m .58184 .66185 L .58687 .65702 L p F P
0 g
s
.383 .579 .918 r
.76838 .65049 m .75621 .64791 L .75098 .64009 L p F P
0 g
s
.604 .436 .627 r
.41286 .21469 m .39218 .22858 L .3928 .2328 L p F P
0 g
s
.906 .496 .162 r
.59708 .67251 m .59023 .6666 L .59387 .67611 L p F P
0 g
s
.906 .496 .162 r
.59387 .67611 m .60061 .68204 L .59708 .67251 L p F P
0 g
s
.66 .376 .479 r
.51684 .17961 m .50863 .17996 L .50747 .17159 L p F P
0 g
s
.66 .376 .479 r
.50747 .17159 m .51719 .17117 L .51684 .17961 L p F P
0 g
s
.17 .29 .745 r
.84938 .74544 m .84274 .73898 L .84102 .73449 L p F P
0 g
s
.69 .269 0 r
.20668 .8603 m .20248 .85393 L .20756 .86334 L p F P
0 g
s
.69 .269 0 r
.20756 .86334 m .21183 .86969 L .20668 .8603 L p F P
0 g
s
.459 .657 .946 r
.68777 .6138 m .70995 .61489 L .71411 .62169 L p F P
0 g
s
.45 .663 .953 r
.70995 .61489 m .68777 .6138 L .68237 .60719 L p F P
0 g
s
.707 .415 .479 r
.55958 .18085 m .54591 .17993 L .54616 .17151 L p F P
0 g
s
.687 .398 .479 r
.53474 .17128 m .54616 .17151 L .54591 .17993 L p F P
0 g
s
.677 .63 .795 r
.49069 .35814 m .48834 .35933 L .49108 .35895 L closepath p F P
0 g
s
0 0 .519 r
.21644 .87586 m .22255 .88274 L .22928 .89029 L p F P
0 g
s
0 0 .529 r
.22255 .88274 m .21644 .87586 L .21183 .86969 L p F P
0 g
s
.742 .668 .778 r
.61173 .34358 m .62584 .33215 L p .61747 .32241 L F P
0 g
s
.742 .668 .778 r
.59887 .34053 m .61173 .34358 L p .61747 .32241 L F P
0 g
s
.767 .506 .54 r
.61723 .19849 m .60945 .19688 L .60851 .18702 L p F P
0 g
s
.752 .495 .544 r
.60042 .18568 m .60851 .18702 L .60945 .19688 L p F P
0 g
s
.597 .804 .979 r
.77902 .90965 m .7558 .91629 L .75063 .91037 L p F P
0 g
s
.78 .665 .736 r
.66316 .29655 m .64957 .2918 L .6614 .27806 L p F P
0 g
s
.769 .666 .749 r
.64944 .31098 m .66316 .29655 L .64957 .2918 L p F P
0 g
s
.697 .477 .586 r
.5339 .60956 m .514 .60964 L .515 .62105 L p F P
0 g
s
.644 .513 .688 r
.53321 .59113 m .53511 .59115 L p .514 .60964 L F P
0 g
s
.681 .394 .48 r
.51719 .17117 m .53474 .17128 L .53582 .17973 L p F P
0 g
s
.687 .398 .479 r
.54591 .17993 m .53582 .17973 L .53474 .17128 L p F P
0 g
s
.791 .634 .687 r
.65931 .26103 m .6709 .2652 L p .66509 .24819 L F P
0 g
s
.788 .651 .71 r
.65931 .26103 m .66434 .27414 L .6709 .2652 L closepath p F P
0 g
s
.79 .653 .711 r
.6709 .2652 m .66434 .27414 L .66657 .27991 L p F P
0 g
s
.185 .287 .736 r
.64074 .77357 m .63754 .78181 L .64634 .79038 L p F P
0 g
s
.173 .24 .692 r
.63754 .78181 m .64074 .77357 L .63338 .76468 L p F P
0 g
s
0 0 .485 r
.85989 .79569 m .85911 .79746 L .8615 .80805 L p F P
0 g
s
.697 .477 .586 r
.515 .62105 m .53033 .621 L .5339 .60956 L p F P
0 g
s
.681 .394 .48 r
.53582 .17973 m .51684 .17961 L .51719 .17117 L p F P
0 g
s
.946 .936 .752 r
.21168 .7348 m .21055 .72689 L .20225 .73989 L p F P
0 g
s
.946 .936 .752 r
.2097 .73799 m .21168 .7348 L p .20225 .73989 L F P
0 g
s
.69 .636 .79 r
.49069 .35814 m .49108 .35895 L .51838 .35719 L p F P
0 g
s
.689 .649 .805 r
.51892 .35822 m .51838 .35719 L .49108 .35895 L p F P
0 g
s
0 0 0 r
.44884 .68774 m .45041 .68549 L .44771 .69369 L p F P
0 g
s
0 0 0 r
.44771 .69369 m .44344 .69986 L .44884 .68774 L p F P
0 g
s
.97 .867 .68 r
.41935 .76611 m .41982 .76504 L .42029 .766 L closepath p F P
0 g
s
.957 .904 .726 r
.41284 .77778 m .41935 .76611 L .42029 .766 L p F P
0 g
s
.774 .546 .59 r
.61723 .19849 m .63389 .20231 L .63094 .21254 L p F P
0 g
s
.781 .554 .592 r
.64587 .21632 m .63094 .21254 L .63389 .20231 L p F P
0 g
s
.58 .745 .955 r
.61966 .591 m .60493 .59362 L .59606 .58806 L p F P
0 g
s
.938 .852 .731 r
.4094 .79717 m .40575 .7906 L .39861 .80348 L p F P
0 g
s
.938 .852 .731 r
.40298 .80942 m .4094 .79717 L p .39861 .80348 L F P
0 g
s
.686 .633 .791 r
.49069 .35814 m .51287 .34579 L p .50572 .33377 L F P
0 g
s
.686 .633 .791 r
.50572 .33377 m .48459 .34538 L .49069 .35814 L p F P
0 g
s
.69 .636 .79 r
.51838 .35719 m .51287 .34579 L .49069 .35814 L p F P
0 g
s
.17 .29 .745 r
.84102 .73449 m .84188 .72919 L p .84938 .74544 L F P
0 g
s
.22 .351 .785 r
.84102 .73449 m .83725 .72564 L .84188 .72919 L closepath p F P
0 g
s
.996 .865 .568 r
.19265 .78556 m .1945 .77949 L .19521 .78144 L closepath p F P
0 g
s
.996 .864 .568 r
.19097 .7911 m .19265 .78556 L .19521 .78144 L p F P
0 g
s
.709 .869 .957 r
.38679 .59743 m .39317 .60103 L .3762 .60911 L closepath p F P
0 g
s
.849 .49 0 r
.19957 .84398 m .19577 .8374 L .19864 .84737 L p F P
0 g
s
.849 .49 0 r
.19864 .84737 m .20248 .85393 L .19957 .84398 L p F P
0 g
s
.52 .538 .815 r
.70207 .88506 m .6874 .88332 L .68282 .87321 L p F P
0 g
s
.726 .666 .792 r
.57539 .35398 m .59546 .33987 L .57718 .33686 L p F P
0 g
s
.726 .666 .792 r
.57718 .33686 m .56948 .34219 L .57539 .35398 L p F P
0 g
s
.719 .659 .79 r
.57539 .35398 m .56948 .34219 L .54716 .35689 L p F P
0 g
s
.752 .678 .779 r
.62157 .32343 m .62584 .33215 L .6325 .32659 L closepath p F P
0 g
s
.742 .668 .778 r
.62584 .33215 m .62157 .32343 L .61747 .32241 L p F P
0 g
s
.788 .652 .713 r
.66434 .27414 m .6614 .27806 L .66657 .27991 L closepath p F P
0 g
s
.946 .936 .752 r
.20225 .73989 m .20237 .74071 L .2097 .73799 L p F P
0 g
s
.951 .927 .743 r
.20237 .74071 m .2097 .73799 L .20374 .74764 L closepath p F P
0 g
s
.604 .436 .627 r
.3928 .2328 m .41606 .22603 L p .41286 .21469 L F P
0 g
s
.618 .471 .66 r
.41868 .23879 m .41606 .22603 L .3928 .2328 L p F P
0 g
s
.618 .471 .66 r
.3928 .2328 m .39536 .24551 L .41868 .23879 L p F P
0 g
s
0 0 0 r
.84916 .85603 m .84686 .85932 L .83857 .87279 L p F P
0 g
s
.745 .489 .543 r
.58108 .18285 m .60042 .18568 L .59916 .19518 L p F P
0 g
s
.752 .495 .544 r
.60945 .19688 m .59916 .19518 L .60042 .18568 L p F P
0 g
s
.769 .666 .749 r
.64711 .31019 m .64944 .31098 L p .64957 .2918 L F P
0 g
s
.765 .678 .766 r
.64711 .31019 m .64808 .31226 L .64944 .31098 L closepath p F P
0 g
s
.756 .667 .764 r
.64808 .31226 m .64711 .31019 L .6351 .30652 L p F P
0 g
s
.756 .667 .764 r
.6325 .32659 m .64808 .31226 L p .6351 .30652 L F P
0 g
s
.756 .667 .764 r
.62157 .32343 m .6325 .32659 L p .6351 .30652 L F P
0 g
s
0 .184 .69 r
.22955 .89058 m .22947 .89052 L .22928 .89029 L closepath p F P
0 g
s
.79 .612 .66 r
.65359 .24434 m .66509 .24819 L p .65709 .23198 L F P
0 g
s
.789 .632 .686 r
.65359 .24434 m .65847 .25861 L .66509 .24819 L closepath p F P
0 g
s
.791 .634 .687 r
.66509 .24819 m .65847 .25861 L .65931 .26103 L p F P
0 g
s
.105 .477 .896 r
.22955 .89058 m .22928 .89029 L p .24084 .891 L F P
0 g
s
.105 .477 .896 r
.24084 .891 m .24586 .89699 L .22955 .89058 L p F P
0 g
s
.708 .654 .795 r
.54716 .35689 m .54586 .3577 L .5476 .35777 L closepath p F P
0 g
s
.705 .648 .79 r
.54716 .35689 m .54586 .3577 L .52071 .3572 L p F P
0 g
s
.98 .907 .659 r
.41935 .76611 m .41982 .76504 L .4179 .75784 L p F P
0 g
s
.788 .587 .63 r
.64587 .21632 m .64629 .21799 L .64687 .21661 L closepath p F P
0 g
s
.788 .588 .63 r
.64917 .22952 m .65709 .23198 L p .64687 .21661 L F P
0 g
s
.788 .588 .63 r
.64687 .21661 m .64629 .21799 L .64917 .22952 L p F P
0 g
s
.7 .656 .803 r
.51838 .35719 m .51892 .35822 L .52071 .3572 L closepath p F P
0 g
s
.105 .477 .896 r
.22928 .89029 m .22501 .88438 L .24084 .891 L p F P
0 g
s
0 .292 .783 r
.22501 .88438 m .22928 .89029 L .22255 .88274 L closepath p F P
0 g
s
.648 .811 .961 r
.4484 .59074 m .44992 .59193 L .47192 .58459 L p F P
0 g
s
.713 .654 .79 r
.54716 .35689 m .56948 .34219 L p .55682 .33457 L F P
0 g
s
.713 .654 .79 r
.55682 .33457 m .54118 .34472 L .54716 .35689 L p F P
0 g
s
.705 .648 .79 r
.52071 .3572 m .54118 .34472 L .54716 .35689 L p F P
0 g
s
.637 .573 .767 r
.42212 .32587 m .42157 .32609 L .42214 .3259 L closepath p F P
0 g
s
.778 .582 .634 r
.63094 .21254 m .64587 .21632 L .64629 .21799 L p F P
0 g
s
.612 .413 .588 r
.43859 .20871 m .43749 .19798 L .42588 .20065 L p F P
0 g
s
.612 .413 .588 r
.41422 .21429 m .43859 .20871 L p .42588 .20065 L F P
0 g
s
.612 .413 .588 r
.42588 .20065 m .41416 .21358 L .41422 .21429 L p F P
0 g
s
.789 .611 .659 r
.64917 .22952 m .65248 .24066 L .65709 .23198 L closepath p F P
0 g
s
.79 .612 .66 r
.65709 .23198 m .65248 .24066 L .65359 .24434 L p F P
0 g
s
.98 .907 .659 r
.4179 .75784 m .41259 .76866 L .41935 .76611 L p F P
0 g
s
.951 .948 .728 r
.41935 .76611 m .41284 .77778 L .4115 .77045 L p F P
0 g
s
.951 .948 .728 r
.4115 .77045 m .41259 .76866 L .41935 .76611 L p F P
0 g
s
.781 .647 .714 r
.66434 .27414 m .6614 .27806 L p .65733 .26038 L F P
0 g
s
.781 .647 .714 r
.65733 .26038 m .65931 .26103 L .66434 .27414 L p F P
0 g
s
.652 .582 .763 r
.42212 .32587 m .42214 .3259 L .44585 .31986 L p F P
0 g
s
.656 .6 .78 r
.45022 .3298 m .44585 .31986 L .42214 .3259 L p F P
0 g
s
.651 .581 .764 r
.42212 .32587 m .44406 .31541 L p .43339 .30232 L F P
0 g
s
.651 .581 .764 r
.43339 .30232 m .41596 .31057 L .42212 .32587 L p F P
0 g
s
.652 .582 .763 r
.44585 .31986 m .44406 .31541 L .42212 .32587 L p F P
0 g
s
.649 .78 .944 r
.4941 .57765 m .47192 .58459 L .47816 .59072 L p F P
0 g
s
.649 .78 .944 r
.47816 .59072 m .50028 .58359 L .4941 .57765 L p F P
0 g
s
.036 .193 .697 r
.63482 .75682 m .63338 .76468 L .64074 .77357 L p F P
0 g
s
.028 .147 .654 r
.63338 .76468 m .63482 .75682 L .6286 .74769 L p F P
0 g
s
.66 .686 .864 r
.56295 .58916 m .55611 .59228 L .53511 .59115 L p F P
0 g
s
.769 .666 .749 r
.64957 .2918 m .6423 .29927 L .64711 .31019 L p F P
0 g
s
.766 .665 .751 r
.6423 .29927 m .6351 .30652 L .64711 .31019 L closepath p F P
0 g
s
.7 .643 .79 r
.52071 .3572 m .54118 .34472 L p .53372 .33327 L F P
0 g
s
.7 .643 .79 r
.51838 .35719 m .52071 .3572 L p .53372 .33327 L F P
0 g
s
.7 .643 .79 r
.53372 .33327 m .51287 .34579 L .51838 .35719 L p F P
0 g
s
.778 .582 .634 r
.64629 .21799 m .64214 .22758 L p .63094 .21254 L F P
0 g
s
.785 .586 .631 r
.64629 .21799 m .64214 .22758 L .64917 .22952 L closepath p F P
0 g
s
.311 .499 .88 r
.79093 .67099 m .78963 .67049 L .78929 .66818 L closepath p F P
0 g
s
.368 .546 .898 r
.78963 .67049 m .78929 .66818 L .78573 .66233 L p F P
0 g
s
.672 .623 .792 r
.45484 .3403 m .45638 .34355 L .46705 .33823 L closepath p F P
0 g
s
0 0 .182 r
.86192 .81923 m .85787 .82713 L .85607 .8389 L p F P
0 g
s
0 0 .369 r
.85787 .82713 m .86192 .81923 L .8615 .80805 L p F P
0 g
s
.786 .898 .491 r
.42977 .73303 m .42389 .74539 L .42527 .7371 L p F P
0 g
s
.786 .898 .491 r
.43112 .72731 m .42977 .73303 L p .42527 .7371 L F P
0 g
s
.657 .674 .855 r
.53467 .59047 m .53321 .59113 L .50706 .59192 L p F P
0 g
s
.657 .674 .855 r
.52865 .58304 m .53467 .59047 L p .50706 .59192 L F P
0 g
s
.657 .674 .855 r
.50706 .59192 m .5064 .59088 L .52865 .58304 L p F P
0 g
s
0 0 .456 r
.86208 .7897 m .85989 .79569 L .86174 .80753 L p F P
0 g
s
.004 .054 .562 r
.85989 .79569 m .86208 .7897 L .8581 .77957 L p F P
0 g
s
0 0 .485 r
.8615 .80805 m .86174 .80753 L .85989 .79569 L p F P
0 g
s
.903 .822 .757 r
.38681 .84738 m .38984 .8427 L .38451 .83679 L p F P
0 g
s
.378 .586 .924 r
.74504 .6389 m .75098 .64009 L .74573 .63253 L p F P
0 g
s
.378 .586 .924 r
.74573 .63253 m .74221 .63182 L .74504 .6389 L p F P
0 g
s
.937 .647 .183 r
.19472 .82699 m .19131 .82019 L .19234 .83064 L p F P
0 g
s
.937 .647 .183 r
.19234 .83064 m .19577 .8374 L .19472 .82699 L p F P
0 g
s
.528 .747 .976 r
.27758 .90212 m .25661 .90402 L .26365 .90988 L p F P
0 g
s
.528 .747 .976 r
.26365 .90988 m .28462 .9075 L .27758 .90212 L p F P
0 g
s
.273 .604 .953 r
.25119 .90284 m .25661 .90402 L .26365 .90988 L p F P
0 g
s
.642 .928 .973 r
.80441 .90073 m .79972 .9053 L p .77902 .90965 L F P
0 g
s
.695 .958 .948 r
.79972 .9053 m .80441 .90073 L .80681 .90146 L closepath p F P
0 g
s
.549 .622 .877 r
.72192 .90526 m .72014 .90528 L .72133 .90427 L closepath p F P
0 g
s
.561 .594 .844 r
.71643 .89612 m .72133 .90427 L .72014 .90528 L p F P
0 g
s
.492 .703 .964 r
.65373 .60122 m .66862 .60073 L .6618 .59458 L p F P
0 g
s
.492 .703 .964 r
.6618 .59458 m .6482 .59505 L .65373 .60122 L p F P
0 g
s
.752 .892 .942 r
.34004 .61899 m .34276 .62022 L .33789 .62305 L closepath p F P
0 g
s
.398 .131 .389 r
.46935 .65435 m .48402 .64788 L .46921 .66289 L p F P
0 g
s
.398 .131 .389 r
.46921 .66289 m .46784 .6635 L .46935 .65435 L p F P
0 g
s
.781 .647 .714 r
.6614 .27806 m .64726 .27346 L .65733 .26038 L p F P
0 g
s
.77 .65 .729 r
.64957 .2918 m .6614 .27806 L .64726 .27346 L p F P
0 g
s
.646 .407 .543 r
.47285 .19249 m .46292 .19364 L .46257 .18399 L p F P
0 g
s
.646 .407 .543 r
.46257 .18399 m .47582 .18245 L .47285 .19249 L p F P
0 g
s
.751 .475 .515 r
.55083 .62289 m .54473 .62205 L .5444 .632 L p F P
0 g
s
.751 .475 .515 r
.5444 .632 m .55161 .63304 L .55083 .62289 L p F P
0 g
s
.209 .349 .787 r
.84188 .72919 m .83725 .72564 L .83223 .71409 L p F P
0 g
s
.468 .683 .959 r
.68237 .60719 m .67452 .6071 L .66862 .60073 L p F P
0 g
s
0 0 .09 r
.45041 .68549 m .461 .67589 L .45309 .68884 L p F P
0 g
s
0 0 .09 r
.45309 .68884 m .44771 .69369 L .45041 .68549 L p F P
0 g
s
0 .025 .55 r
.86038 .77188 m .8581 .77957 L .86208 .7897 L p F P
0 g
s
.091 .158 .641 r
.85479 .76224 m .86038 .77188 L .8581 .77957 L p F P
0 g
s
.742 .668 .778 r
.61747 .32241 m .59772 .33814 L .59887 .34053 L p F P
0 g
s
.737 .666 .781 r
.59772 .33814 m .59546 .33987 L .59887 .34053 L closepath p F P
0 g
s
.664 .775 .932 r
.52259 .57681 m .50028 .58359 L .5064 .59088 L p F P
0 g
s
.664 .775 .932 r
.5064 .59088 m .52865 .58304 L .52259 .57681 L p F P
0 g
s
.666 .849 .97 r
.43705 .58297 m .41505 .59155 L .4216 .59562 L p F P
0 g
s
.666 .849 .97 r
.4216 .59562 m .44352 .58716 L .43705 .58297 L p F P
0 g
s
.993 .877 .562 r
.1945 .77949 m .19232 .77209 L .1887 .78376 L p F P
0 g
s
.993 .877 .562 r
.19265 .78556 m .1945 .77949 L p .1887 .78376 L F P
0 g
s
.325 .497 .875 r
.79093 .67099 m .8055 .67671 L .80624 .68412 L p F P
0 g
s
.304 .494 .879 r
.8055 .67671 m .79093 .67099 L .78929 .66818 L p F P
0 g
s
.671 .608 .776 r
.45022 .3298 m .45484 .3403 L .46705 .33823 L p F P
0 g
s
.66 .686 .864 r
.55704 .58256 m .56295 .58916 L p .53511 .59115 L F P
0 g
s
.66 .686 .864 r
.53511 .59115 m .53467 .59047 L .55704 .58256 L p F P
0 g
s
.689 .697 .853 r
.53321 .59113 m .53511 .59115 L .53467 .59047 L closepath p F P
0 g
s
.591 .398 .588 r
.41416 .21358 m .41286 .21469 L .41422 .21429 L closepath p F P
0 g
s
.604 .436 .627 r
.41606 .22603 m .41422 .21429 L .41286 .21469 L p F P
0 g
s
.552 .694 .934 r
.72192 .90526 m .74536 .90357 L .75063 .91037 L p F P
0 g
s
.545 .62 .878 r
.74001 .89598 m .74536 .90357 L .72192 .90526 L p F P
0 g
s
.545 .62 .878 r
.73073 .89599 m .74001 .89598 L p .72192 .90526 L F P
0 g
s
.545 .62 .878 r
.72192 .90526 m .72133 .90427 L .73073 .89599 L p F P
0 g
s
.903 .822 .757 r
.38451 .83679 m .38014 .84333 L .38681 .84738 L p F P
0 g
s
.868 .837 .814 r
.38681 .84738 m .37881 .85671 L .37359 .85079 L p F P
0 g
s
.868 .837 .814 r
.37359 .85079 m .38014 .84333 L .38681 .84738 L p F P
0 g
s
.52 .538 .815 r
.68282 .87321 m .68488 .87131 L p .70207 .88506 L F P
0 g
s
.49 .523 .818 r
.68282 .87321 m .68166 .87069 L .68488 .87131 L closepath p F P
0 g
s
0 0 .57 r
.6284 .74019 m .6286 .74769 L .63482 .75682 L p F P
0 g
s
0 .018 .581 r
.6286 .74769 m .6284 .74019 L .62307 .73088 L p F P
0 g
s
.733 .659 .776 r
.59772 .33814 m .59546 .33987 L .57718 .33686 L p F P
0 g
s
.733 .891 .952 r
.34276 .62022 m .36457 .60833 L p .34502 .61208 L F P
0 g
s
.733 .891 .952 r
.34502 .61208 m .34004 .61899 L .34276 .62022 L p F P
0 g
s
.968 .93 .689 r
.20374 .74764 m .19733 .76006 L .19568 .75239 L p F P
0 g
s
.968 .93 .689 r
.20237 .74071 m .20374 .74764 L p .19568 .75239 L F P
0 g
s
.665 .783 .937 r
.5511 .57655 m .52865 .58304 L .53467 .59047 L p F P
0 g
s
.665 .783 .937 r
.53467 .59047 m .55704 .58256 L .5511 .57655 L p F P
0 g
s
.628 .455 .629 r
.44048 .22049 m .43859 .20871 L .41422 .21429 L p F P
0 g
s
.628 .455 .629 r
.41422 .21429 m .41606 .22603 L .44048 .22049 L p F P
0 g
s
.648 .823 .967 r
.44352 .58716 m .4484 .59074 L .46923 .58237 L p F P
0 g
s
.648 .811 .961 r
.47192 .58459 m .46923 .58237 L .4484 .59074 L p F P
0 g
s
.739 .483 .542 r
.57638 .18225 m .58108 .18285 L .57974 .19237 L p F P
0 g
s
.745 .489 .543 r
.59916 .19518 m .57974 .19237 L .58108 .18285 L p F P
0 g
s
.718 .446 .513 r
.54473 .62205 m .53033 .621 L .53128 .63108 L p F P
0 g
s
.718 .446 .513 r
.53128 .63108 m .5444 .632 L .54473 .62205 L p F P
0 g
s
.778 .817 .883 r
.3221 .89805 m .31314 .90402 L .32003 .90908 L p F P
0 g
s
.778 .817 .883 r
.32003 .90908 m .32806 .90362 L .3221 .89805 L p F P
0 g
s
.767 .539 .589 r
.60945 .19688 m .61723 .19849 L .61419 .20875 L p F P
0 g
s
.774 .546 .59 r
.63094 .21254 m .61419 .20875 L .61723 .19849 L p F P
0 g
s
.738 .664 .777 r
.59772 .33814 m .61747 .32241 L .6009 .31874 L p F P
0 g
s
.738 .664 .777 r
.6009 .31874 m .59184 .32583 L .59772 .33814 L p F P
0 g
s
.733 .659 .776 r
.57718 .33686 m .59184 .32583 L .59772 .33814 L p F P
0 g
s
.627 .499 .687 r
.41977 .24308 m .41868 .23879 L .39536 .24551 L p F P
0 g
s
.627 .499 .687 r
.39536 .24551 m .39782 .25537 L .41977 .24308 L p F P
0 g
s
.613 .743 .938 r
.56295 .58916 m .58547 .58289 L p .56912 .5797 L F P
0 g
s
.613 .743 .938 r
.56912 .5797 m .55704 .58256 L .56295 .58916 L p F P
0 g
s
.849 .936 .882 r
.2633 .66904 m .2644 .66238 L p .24733 .67587 L F P
0 g
s
.849 .936 .882 r
.24769 .68339 m .2633 .66904 L p .24733 .67587 L F P
0 g
s
.833 .928 .895 r
.2644 .66238 m .2699 .66353 L .2633 .66904 L closepath p F P
0 g
s
.849 .936 .882 r
.24733 .67587 m .24641 .68322 L .24769 .68339 L p F P
0 g
s
.858 .932 .873 r
.24641 .68322 m .24769 .68339 L .24632 .68468 L closepath p F P
0 g
s
.796 .973 .909 r
.80441 .90073 m .80681 .90146 L .82527 .88753 L p F P
0 g
s
.877 .95 .854 r
.24632 .68468 m .23231 .69939 L .23258 .69087 L p F P
0 g
s
.877 .95 .854 r
.24641 .68322 m .24632 .68468 L p .23258 .69087 L F P
0 g
s
.546 .623 .879 r
.72133 .90427 m .71643 .89612 L .73073 .89599 L closepath p F P
0 g
s
.788 .632 .688 r
.65847 .25861 m .65733 .26038 L .65931 .26103 L closepath p F P
0 g
s
.78 .606 .664 r
.64214 .22758 m .64917 .22952 L .65248 .24066 L p F P
0 g
s
.65 .411 .544 r
.48955 .19071 m .47285 .19249 L .47582 .18245 L p F P
0 g
s
.65 .411 .544 r
.47582 .18245 m .48909 .18103 L .48955 .19071 L p F P
0 g
s
0 0 0 r
.84705 .86041 m .84916 .85603 L p .83857 .87279 L F P
0 g
s
0 0 0 r
.83857 .87279 m .84415 .86473 L .84705 .86041 L p F P
0 g
s
.802 .982 .707 r
.83857 .87279 m .84415 .86473 L p .82781 .88454 L F P
0 g
s
.802 .982 .707 r
.82781 .88454 m .82931 .88386 L .83857 .87279 L p F P
0 g
s
.781 .628 .69 r
.65847 .25861 m .65733 .26038 L p .65092 .24354 L F P
0 g
s
.781 .628 .69 r
.65092 .24354 m .65359 .24434 L .65847 .25861 L p F P
0 g
s
.421 .635 .944 r
.71411 .62169 m .71658 .62196 L .71125 .61503 L p F P
0 g
s
.421 .635 .944 r
.71125 .61503 m .70995 .61489 L .71411 .62169 L p F P
0 g
s
.938 .852 .731 r
.39861 .80348 m .40233 .80925 L .40298 .80942 L p F P
0 g
s
.921 .877 .776 r
.40233 .80925 m .40298 .80942 L .40266 .80989 L closepath p F P
0 g
s
.82 .931 .905 r
.2699 .66353 m .28387 .65224 L p .26501 .65995 L F P
0 g
s
.82 .931 .905 r
.26501 .65995 m .2644 .66238 L .2699 .66353 L p F P
0 g
s
.498 .513 .803 r
.68488 .87131 m .68166 .87069 L .67587 .85714 L p F P
0 g
s
.651 .582 .764 r
.41464 .30729 m .41596 .31057 L .43339 .30232 L closepath p F P
0 g
s
.638 .434 .591 r
.4641 .20439 m .46292 .19364 L .43749 .19798 L p F P
0 g
s
.638 .434 .591 r
.43749 .19798 m .43859 .20871 L .4641 .20439 L p F P
0 g
s
.739 .483 .542 r
.57974 .19237 m .57717 .19204 L .57638 .18225 L p F P
0 g
s
.723 .471 .545 r
.55958 .18085 m .57638 .18225 L .57717 .19204 L p F P
0 g
s
.916 .881 .785 r
.40266 .80989 m .39351 .82334 L .38966 .81691 L p F P
0 g
s
.916 .881 .785 r
.40233 .80925 m .40266 .80989 L p .38966 .81691 L F P
0 g
s
.756 .667 .764 r
.6351 .30652 m .62005 .32014 L .62157 .32343 L p F P
0 g
s
.751 .665 .766 r
.62005 .32014 m .61747 .32241 L .62157 .32343 L closepath p F P
0 g
s
.686 .632 .79 r
.48016 .3361 m .48459 .34538 L .50572 .33377 L closepath p F P
0 g
s
.672 .624 .792 r
.48459 .34538 m .48016 .3361 L .46705 .33823 L p F P
0 g
s
0 0 .008 r
.44344 .69986 m .43778 .71211 L .44471 .70197 L p F P
0 g
s
0 0 .008 r
.44771 .69369 m .44344 .69986 L p .44471 .70197 L F P
0 g
s
.77 .65 .729 r
.6374 .28801 m .64957 .2918 L p .64726 .27346 L F P
0 g
s
.768 .663 .747 r
.6374 .28801 m .6423 .29927 L .64957 .2918 L closepath p F P
0 g
s
.277 .449 .851 r
.82039 .69849 m .82018 .69101 L .80624 .68412 L p F P
0 g
s
.268 .456 .861 r
.8055 .67671 m .80624 .68412 L .82018 .69101 L p F P
0 g
s
.781 .628 .69 r
.65733 .26038 m .64257 .25595 L .65092 .24354 L p F P
0 g
s
.777 .639 .709 r
.64257 .25595 m .65733 .26038 L .64726 .27346 L p F P
0 g
s
.569 .746 .96 r
.59126 .58892 m .59606 .58806 L .58612 .58279 L p F P
0 g
s
.569 .746 .96 r
.58612 .58279 m .58547 .58289 L .59126 .58892 L p F P
0 g
s
.868 .821 .8 r
.37881 .85671 m .37359 .85079 L .36124 .86522 L p F P
0 g
s
.868 .821 .8 r
.36124 .86522 m .3669 .87098 L .37881 .85671 L p F P
0 g
s
.78 .606 .664 r
.65248 .24066 m .65092 .24354 L p .64214 .22758 L F P
0 g
s
.787 .61 .661 r
.65248 .24066 m .65092 .24354 L .65359 .24434 L closepath p F P
0 g
s
.646 .563 .747 r
.41464 .30729 m .43339 .30232 L p .43076 .28395 L F P
0 g
s
.646 .563 .747 r
.43076 .28395 m .40983 .29416 L .41464 .30729 L p F P
0 g
s
.769 .822 .894 r
.34197 .89452 m .32806 .90362 L .3221 .89805 L p F P
0 g
s
.304 .494 .879 r
.78929 .66818 m .78843 .66314 L p .8055 .67671 L F P
0 g
s
.351 .536 .896 r
.78929 .66818 m .78573 .66233 L .78843 .66314 L closepath p F P
0 g
s
.686 .423 .519 r
.53033 .621 m .515 .62105 L .51468 .63112 L p F P
0 g
s
.587 .342 .512 r
.515 .62105 m .51468 .63112 L .49048 .63597 L p F P
0 g
s
.689 .809 .939 r
.3062 .89906 m .28462 .9075 L .2916 .91279 L p F P
0 g
s
.689 .809 .939 r
.2916 .91279 m .31314 .90402 L .3062 .89906 L p F P
0 g
s
.8 .491 .468 r
.56633 .6367 m .55161 .63304 L .55403 .64276 L p F P
0 g
s
.8 .491 .468 r
.55403 .64276 m .56818 .6466 L .56633 .6367 L p F P
0 g
s
0 0 .434 r
.62133 .72373 m .62307 .73088 L .6284 .74019 L p F P
0 g
s
0 0 .434 r
.62619 .7332 m .62133 .72373 L p .62208 .72548 L F P
0 g
s
0 0 .434 r
.6284 .74019 m .62619 .7332 L p .62208 .72548 L F P
0 g
s
0 0 .493 r
.62855 .73759 m .62619 .7332 L p .62913 .73938 L F P
0 g
s
0 0 .493 r
.63394 .74954 m .62855 .73759 L .62913 .73938 L F
.678 .284 0 r
.62619 .7332 m .62855 .73759 L .62825 .73705 L p F P
0 g
s
0 0 .493 r
.62619 .7332 m .6284 .74019 L .63394 .74954 L p F P
0 g
s
.678 .284 0 r
.62825 .73705 m .62271 .72722 L p .62619 .7332 L F P
0 g
s
.698 .306 0 r
.62133 .72373 m .62619 .7332 L p .62543 .73173 L F P
0 g
s
0 0 .45 r
.62307 .73088 m .62133 .72373 L p .61726 .7158 L F P
0 g
s
.698 .306 0 r
.61779 .71703 m .62133 .72373 L p .62543 .73173 L F P
0 g
s
.678 .284 0 r
.62271 .72722 m .62239 .72658 L .62282 .72732 L p F P
0 g
s
.678 .284 0 r
.62282 .72732 m .62619 .7332 L p .62271 .72722 L F P
0 g
s
.594 .14 0 r
.62271 .72722 m .61991 .72354 L p .62238 .72688 L F P
0 g
s
.698 .306 0 r
.62619 .7332 m .62239 .72658 L .61779 .71703 L p F P
0 g
s
0 .002 .573 r
.62855 .73759 m .62271 .72722 L p .62785 .7354 L F P
0 g
s
0 .002 .573 r
.62271 .72722 m .62888 .73569 L .63225 .74241 L p F P
0 g
s
.594 .14 0 r
.62888 .73569 m .62271 .72722 L p .62238 .72688 L F P
0 g
s
0 .002 .573 r
.63225 .74241 m .62855 .73759 L p .62785 .7354 L F P
0 g
s
0 0 .45 r
.62133 .72373 m .61668 .7143 L p .61726 .7158 L F P
0 g
s
.686 .423 .519 r
.51468 .63112 m .53128 .63108 L .53033 .621 L p F P
0 g
s
.978 .752 .337 r
.19188 .80936 m .1889 .80234 L .1883 .81321 L p F P
0 g
s
.978 .752 .337 r
.1883 .81321 m .19131 .82019 L .19188 .80936 L p F P
0 g
s
.011 .115 .626 r
.85652 .75459 m .85479 .76224 L .86038 .77188 L p F P
0 g
s
.131 .225 .696 r
.84938 .74544 m .85652 .75459 L .85479 .76224 L p F P
0 g
s
.76 .66 .751 r
.6423 .29927 m .6351 .30652 L p .63502 .28736 L F P
0 g
s
.76 .66 .751 r
.63502 .28736 m .6374 .28801 L .6423 .29927 L p F P
0 g
s
.897 .949 .83 r
.23231 .69939 m .23258 .69087 L .22023 .70511 L p F P
0 g
s
.897 .949 .83 r
.22505 .70792 m .23231 .69939 L p .22023 .70511 L F P
0 g
s
.627 .497 .684 r
.42216 .25262 m .41977 .24308 L .39782 .25537 L p F P
0 g
s
.627 .497 .684 r
.39782 .25537 m .39877 .25925 L .42216 .25262 L p F P
0 g
s
.937 .852 .733 r
.39629 .80762 m .39861 .80348 L .40233 .80925 L closepath p F P
0 g
s
.916 .881 .785 r
.38966 .81691 m .39629 .80762 L .40233 .80925 L p F P
0 g
s
.82 .931 .905 r
.28387 .65224 m .28606 .64463 L p .26501 .65995 L F P
0 g
s
.805 .921 .915 r
.28606 .64463 m .29193 .64629 L .28387 .65224 L closepath p F P
0 g
s
.671 .608 .776 r
.46705 .33823 m .47846 .33227 L p .45022 .3298 L F P
0 g
s
.672 .611 .779 r
.47846 .33227 m .46705 .33823 L .48016 .3361 L closepath p F P
0 g
s
.96 .911 .723 r
.41284 .77778 m .4115 .77045 L .40358 .78354 L p F P
0 g
s
.96 .911 .723 r
.40358 .78354 m .40575 .7906 L .41284 .77778 L p F P
0 g
s
.767 .539 .589 r
.61419 .20875 m .61136 .20817 L .60945 .19688 L p F P
0 g
s
.754 .53 .593 r
.59916 .19518 m .60945 .19688 L .61136 .20817 L p F P
0 g
s
.764 .565 .628 r
.62608 .22355 m .63094 .21254 L .61419 .20875 L p F P
0 g
s
.778 .582 .634 r
.64214 .22758 m .62608 .22355 L .63094 .21254 L p F P
0 g
s
.687 .866 .966 r
.39317 .60103 m .41505 .59155 L p .38769 .59671 L F P
0 g
s
.687 .866 .966 r
.38769 .59671 m .38679 .59743 L .39317 .60103 L p F P
0 g
s
.453 .474 .791 r
.67587 .85714 m .67309 .85621 L .6748 .8545 L closepath p F P
0 g
s
.454 .476 .792 r
.67002 .84276 m .66456 .84027 L p .67309 .85621 L F P
0 g
s
.454 .476 .792 r
.67309 .85621 m .6748 .8545 L .67002 .84276 L p F P
0 g
s
.748 .658 .762 r
.62005 .32014 m .61747 .32241 L .6009 .31874 L p F P
0 g
s
.751 .663 .763 r
.62005 .32014 m .6351 .30652 L .61975 .30239 L p F P
0 g
s
.751 .663 .763 r
.61975 .30239 m .6142 .30731 L .62005 .32014 L p F P
0 g
s
.748 .658 .762 r
.6009 .31874 m .6142 .30731 L .62005 .32014 L p F P
0 g
s
.67 .427 .544 r
.50626 .1898 m .48955 .19071 L .48909 .18103 L p F P
0 g
s
.67 .427 .544 r
.48909 .18103 m .50863 .17996 L .50626 .1898 L p F P
0 g
s
.796 .973 .909 r
.82527 .88753 m .82781 .88454 L p .80441 .90073 L F P
0 g
s
.672 .955 .718 r
.82527 .88753 m .82781 .88454 L .82931 .88386 L closepath p F P
0 g
s
.724 .664 .79 r
.56608 .33535 m .56948 .34219 L .57718 .33686 L closepath p F P
0 g
s
.713 .654 .79 r
.56948 .34219 m .56608 .33535 L .55682 .33457 L p F P
0 g
s
.76 .66 .751 r
.6351 .30652 m .61975 .30239 L .63502 .28736 L p F P
0 g
s
.669 .608 .777 r
.44585 .31986 m .45022 .3298 L .47233 .31838 L p F P
0 g
s
.671 .608 .776 r
.47846 .33227 m .47233 .31838 L .45022 .3298 L p F P
0 g
s
0 0 0 r
.84705 .86041 m .8518 .85136 L .84916 .85603 L closepath p F P
0 g
s
0 0 0 r
.85607 .8389 m .8518 .85136 L .84916 .85603 L p F P
0 g
s
.717 .465 .544 r
.54591 .17993 m .55958 .18085 L .55799 .19044 L p F P
0 g
s
.723 .471 .545 r
.57717 .19204 m .55799 .19044 L .55958 .18085 L p F P
0 g
s
.414 .62 .937 r
.71658 .62196 m .73868 .62488 L .74221 .63182 L p F P
0 g
s
.402 .625 .943 r
.73868 .62488 m .71658 .62196 L .71125 .61503 L p F P
0 g
s
.413 .441 .781 r
.67002 .84276 m .66456 .84027 L .66762 .83659 L closepath p F P
0 g
s
.413 .442 .781 r
.66413 .82766 m .65777 .82385 L p .66456 .84027 L F P
0 g
s
.413 .442 .781 r
.66456 .84027 m .66762 .83659 L .66413 .82766 L p F P
0 g
s
.872 .952 .859 r
.23999 .68324 m .24733 .67587 L .24641 .68322 L closepath p F P
0 g
s
.877 .95 .854 r
.23258 .69087 m .23999 .68324 L .24641 .68322 L p F P
0 g
s
.635 .522 .709 r
.42572 .26476 m .42216 .25262 L .39877 .25925 L p F P
0 g
s
.635 .522 .709 r
.41397 .27103 m .42572 .26476 L p .39877 .25925 L F P
0 g
s
.635 .522 .709 r
.39877 .25925 m .40306 .27408 L .41397 .27103 L p F P
0 g
s
.78 .606 .664 r
.65092 .24354 m .63553 .2393 L .64214 .22758 L p F P
0 g
s
.776 .62 .686 r
.63553 .2393 m .65092 .24354 L .64257 .25595 L p F P
0 g
s
.699 .642 .789 r
.50702 .33366 m .51287 .34579 L .53372 .33327 L closepath p F P
0 g
s
.686 .633 .791 r
.51287 .34579 m .50702 .33366 L .50572 .33377 L p F P
0 g
s
.993 .877 .562 r
.1887 .78376 m .19037 .78938 L .19265 .78556 L p F P
0 g
s
.995 .868 .563 r
.19037 .78938 m .19265 .78556 L .19097 .7911 L closepath p F P
0 g
s
.565 .297 .468 r
.49048 .63597 m .51468 .63112 L p .49599 .64417 L F P
0 g
s
.565 .297 .468 r
.49599 .64417 m .49007 .64004 L .49048 .63597 L p F P
0 g
s
.421 .172 .429 r
.49048 .63597 m .49007 .64004 L .48402 .64788 L p F P
0 g
s
.646 .564 .748 r
.40832 .29006 m .40983 .29416 L .43076 .28395 L closepath p F P
0 g
s
.774 .597 .659 r
.62608 .22355 m .64214 .22758 L .63553 .2393 L p F P
0 g
s
.264 .591 .948 r
.25661 .90402 m .25119 .90284 L .24586 .89699 L p F P
0 g
s
.869 .526 .399 r
.57875 .6515 m .56818 .6466 L .57082 .65634 L p F P
0 g
s
.869 .526 .399 r
.57082 .65634 m .58107 .66133 L .57875 .6515 L p F P
0 g
s
.68 .317 0 r
.61668 .7143 m .61342 .7075 L .60928 .69799 L p F P
0 g
s
.691 .312 0 r
.61342 .7075 m .61668 .7143 L .62133 .72373 L p F P
0 g
s
.712 .653 .789 r
.53559 .33328 m .54118 .34472 L .55682 .33457 L closepath p F P
0 g
s
.7 .643 .79 r
.54118 .34472 m .53559 .33328 L .53372 .33327 L p F P
0 g
s
.79 .923 .926 r
.29193 .64629 m .30963 .63375 L p .28684 .64267 L F P
0 g
s
.79 .923 .926 r
.28684 .64267 m .28606 .64463 L .29193 .64629 L p F P
0 g
s
.383 .579 .918 r
.75098 .64009 m .76603 .64333 L .76838 .65049 L p F P
0 g
s
.369 .581 .924 r
.76603 .64333 m .75098 .64009 L .74573 .63253 L p F P
0 g
s
.498 .513 .803 r
.67587 .85714 m .69334 .86226 L .68488 .87131 L p F P
0 g
s
.52 .538 .815 r
.68488 .87131 m .70525 .87551 L p .70207 .88506 L F P
0 g
s
.453 .489 .806 r
.68488 .87131 m .70525 .87551 L .69957 .86416 L p F P
0 g
s
.453 .489 .806 r
.69957 .86416 m .69334 .86226 L .68488 .87131 L p F P
0 g
s
.212 .389 .822 r
.82039 .69849 m .82653 .70231 L .82124 .69169 L p F P
0 g
s
.212 .389 .822 r
.82124 .69169 m .82018 .69101 L .82039 .69849 L p F P
0 g
s
.64 .543 .729 r
.40832 .29006 m .43076 .28395 L p .41397 .27103 L F P
0 g
s
.64 .543 .729 r
.41397 .27103 m .40376 .27618 L .40832 .29006 L p F P
0 g
s
.897 .949 .83 r
.22023 .70511 m .22019 .70836 L .22505 .70792 L p F P
0 g
s
.905 .942 .82 r
.22019 .70836 m .22505 .70792 L .22042 .71344 L closepath p F P
0 g
s
.209 .349 .787 r
.83223 .71409 m .83229 .71352 L p .84188 .72919 L F P
0 g
s
.258 .405 .82 r
.83223 .71409 m .83183 .71324 L .83229 .71352 L closepath p F P
0 g
s
.675 .432 .545 r
.5174 .18932 m .50626 .1898 L .50863 .17996 L p F P
0 g
s
.675 .432 .545 r
.50863 .17996 m .51684 .17961 L .5174 .18932 L p F P
0 g
s
.717 .465 .544 r
.55799 .19044 m .54658 .18968 L .54591 .17993 L p F P
0 g
s
.7 .452 .546 r
.53582 .17973 m .54591 .17993 L .54658 .18968 L p F P
0 g
s
.062 .193 .689 r
.85057 .73785 m .84938 .74544 L .85652 .75459 L p F P
0 g
s
.17 .29 .745 r
.84188 .72919 m .85057 .73785 L .84938 .74544 L p F P
0 g
s
.641 .545 .731 r
.40306 .27408 m .40376 .27618 L .41397 .27103 L closepath p F P
0 g
s
.943 .943 .612 r
.42389 .74539 m .42527 .7371 L .41821 .7499 L p F P
0 g
s
.943 .943 .612 r
.41821 .7499 m .4179 .75784 L .42389 .74539 L p F P
0 g
s
.726 .651 .775 r
.57718 .33686 m .59184 .32583 L p .58293 .31555 L F P
0 g
s
.726 .651 .775 r
.56608 .33535 m .57718 .33686 L p .58293 .31555 L F P
0 g
s
.36 .403 .77 r
.66413 .82766 m .65777 .82385 L .6609 .81912 L closepath p F P
0 g
s
.36 .403 .77 r
.65821 .81201 m .65189 .80717 L p .65777 .82385 L F P
0 g
s
.36 .403 .77 r
.65777 .82385 m .6609 .81912 L .65821 .81201 L p F P
0 g
s
.694 .446 .544 r
.51684 .17961 m .53582 .17973 L .53389 .18943 L p F P
0 g
s
.7 .452 .546 r
.54658 .18968 m .53389 .18943 L .53582 .17973 L p F P
0 g
s
.87 .821 .798 r
.36425 .87419 m .3669 .87098 L .36124 .86522 L p F P
0 g
s
.244 .404 .824 r
.83229 .71352 m .83183 .71324 L .82653 .70231 L p F P
0 g
s
.694 .446 .544 r
.53389 .18943 m .5174 .18932 L .51684 .17961 L p F P
0 g
s
0 0 .346 r
.86174 .80753 m .8615 .80805 L .86192 .81923 L p F P
0 g
s
.564 .747 .963 r
.61399 .58522 m .59606 .58806 L .58612 .58279 L p F P
0 g
s
.58 .745 .955 r
.59606 .58806 m .61399 .58522 L .61966 .591 L p F P
0 g
s
.869 .463 .257 r
.59023 .6666 m .59387 .67611 L .58496 .67077 L p F P
0 g
s
.869 .463 .257 r
.58184 .66185 m .59023 .6666 L p .58496 .67077 L F P
0 g
s
.837 .42 0 r
.60442 .69158 m .60928 .69799 L .61342 .7075 L p F P
0 g
s
.847 .439 0 r
.60928 .69799 m .60442 .69158 L .60061 .68204 L p F P
0 g
s
.74 .517 .591 r
.59571 .20559 m .59916 .19518 L .57974 .19237 L p F P
0 g
s
.754 .53 .593 r
.61136 .20817 m .59571 .20559 L .59916 .19518 L p F P
0 g
s
.513 .732 .973 r
.63704 .58329 m .61399 .58522 L .61966 .591 L p F P
0 g
s
.513 .732 .973 r
.61966 .591 m .64264 .58907 L .63704 .58329 L p F P
0 g
s
.831 .823 .841 r
.34197 .89452 m .35062 .88645 L .34491 .88076 L p F P
0 g
s
.825 .831 .853 r
.36425 .87419 m .35062 .88645 L .34491 .88076 L p F P
0 g
s
.831 .823 .841 r
.34491 .88076 m .33514 .88967 L .34197 .89452 L p F P
0 g
s
.769 .822 .894 r
.3221 .89805 m .33514 .88967 L .34197 .89452 L p F P
0 g
s
.209 .349 .787 r
.83229 .71352 m .84255 .72165 L .84188 .72919 L p F P
0 g
s
.153 .327 .786 r
.83245 .70602 m .83229 .71352 L .84255 .72165 L p F P
0 g
s
.244 .404 .824 r
.82653 .70231 m .83245 .70602 L .83229 .71352 L p F P
0 g
s
.87 .821 .798 r
.36124 .86522 m .3575 .86966 L .36425 .87419 L p F P
0 g
s
.825 .831 .853 r
.34491 .88076 m .3575 .86966 L .36425 .87419 L p F P
0 g
s
.597 .804 .979 r
.75063 .91037 m .77402 .90518 L .77902 .90965 L p F P
0 g
s
.576 .761 .966 r
.77402 .90518 m .75063 .91037 L .74536 .90357 L p F P
0 g
s
.109 .263 .742 r
.84255 .72165 m .84188 .72919 L .85057 .73785 L p F P
0 g
s
.897 .477 .125 r
.60061 .68204 m .59387 .67611 L .59777 .68563 L p F P
0 g
s
.897 .477 .125 r
.59777 .68563 m .60442 .69158 L .60061 .68204 L p F P
0 g
s
.777 .639 .709 r
.64726 .27346 m .63226 .26912 L .64257 .25595 L p F P
0 g
s
.765 .645 .729 r
.63648 .28574 m .64726 .27346 L .63226 .26912 L p F P
0 g
s
.77 .65 .729 r
.64726 .27346 m .63648 .28574 L .6374 .28801 L p F P
0 g
s
.924 .956 .787 r
.22042 .71344 m .21055 .72689 L .21 .71872 L p F P
0 g
s
.924 .956 .787 r
.22019 .70836 m .22042 .71344 L p .21 .71872 L F P
0 g
s
.45 .663 .953 r
.68237 .60719 m .70499 .60827 L .70995 .61489 L p F P
0 g
s
.442 .669 .959 r
.68237 .60719 m .70499 .60827 L .69922 .60183 L p F P
0 g
s
.442 .669 .959 r
.69922 .60183 m .67693 .60081 L .68237 .60719 L p F P
0 g
s
.468 .683 .959 r
.66862 .60073 m .67693 .60081 L .68237 .60719 L p F P
0 g
s
.468 .483 .791 r
.69334 .86226 m .67587 .85714 L .6748 .8545 L p F P
0 g
s
.326 .539 .907 r
.76838 .65049 m .78054 .65409 L .77534 .64611 L p F P
0 g
s
.326 .539 .907 r
.77534 .64611 m .76603 .64333 L .76838 .65049 L p F P
0 g
s
.912 .849 .768 r
.39351 .82334 m .38966 .81691 L .38007 .83055 L p F P
0 g
s
.912 .849 .768 r
.38007 .83055 m .38451 .83679 L .39351 .82334 L p F P
0 g
s
.686 .618 .774 r
.47846 .33227 m .48016 .3361 L .50572 .33377 L p F P
0 g
s
.746 .913 .949 r
.33576 .61744 m .34502 .61208 L .34004 .61899 L closepath p F P
0 g
s
.637 .484 .659 r
.44196 .2274 m .44048 .22049 L .41606 .22603 L p F P
0 g
s
.637 .484 .659 r
.43016 .23621 m .44196 .2274 L p .41606 .22603 L F P
0 g
s
.637 .484 .659 r
.41606 .22603 m .41868 .23879 L .43016 .23621 L p F P
0 g
s
0 0 .307 r
.86436 .80035 m .86174 .80753 L .86245 .81806 L p F P
0 g
s
0 0 .346 r
.86192 .81923 m .86245 .81806 L .86174 .80753 L p F P
0 g
s
0 0 .456 r
.86174 .80753 m .86436 .80035 L .86208 .7897 L p F P
0 g
s
0 .26 .765 r
.22255 .88274 m .22501 .88438 L .2209 .87807 L p F P
0 g
s
0 .26 .765 r
.2209 .87807 m .21557 .87416 L .22255 .88274 L p F P
0 g
s
0 0 .529 r
.21183 .86969 m .21557 .87416 L .22255 .88274 L p F P
0 g
s
0 0 0 r
.86012 .83105 m .85607 .8389 L .8518 .85136 L p F P
0 g
s
0 0 .182 r
.85607 .8389 m .86012 .83105 L .86192 .81923 L p F P
0 g
s
.642 .928 .973 r
.77902 .90965 m .80217 .89984 L .80441 .90073 L p F P
0 g
s
.634 .888 .987 r
.80217 .89984 m .77902 .90965 L .77402 .90518 L p F P
0 g
s
.468 .483 .791 r
.6748 .8545 m .6812 .84713 L p .69334 .86226 L F P
0 g
s
.429 .461 .791 r
.6748 .8545 m .67002 .84276 L .6812 .84713 L closepath p F P
0 g
s
.983 .908 .626 r
.19733 .76006 m .19568 .75239 L .19059 .76448 L p F P
0 g
s
.983 .908 .626 r
.19059 .76448 m .19232 .77209 L .19733 .76006 L p F P
0 g
s
.667 .591 .76 r
.44406 .31541 m .44585 .31986 L .47097 .31531 L p F P
0 g
s
.669 .608 .777 r
.47233 .31838 m .47097 .31531 L .44585 .31986 L p F P
0 g
s
.289 .354 .757 r
.65821 .81201 m .65189 .80717 L .65443 .80189 L closepath p F P
0 g
s
.288 .353 .756 r
.65226 .79607 m .64634 .79038 L p .65189 .80717 L F P
0 g
s
.288 .353 .756 r
.65189 .80717 m .65443 .80189 L .65226 .79607 L p F P
0 g
s
.726 .651 .775 r
.58293 .31555 m .56353 .32987 L .56608 .33535 L p F P
0 g
s
.718 .648 .778 r
.56353 .32987 m .55682 .33457 L .56608 .33535 L closepath p F P
0 g
s
.737 .662 .776 r
.58728 .31618 m .59184 .32583 L .6009 .31874 L closepath p F P
0 g
s
.726 .651 .775 r
.59184 .32583 m .58728 .31618 L .58293 .31555 L p F P
0 g
s
.767 .648 .73 r
.63648 .28574 m .63502 .28736 L .6374 .28801 L closepath p F P
0 g
s
.682 .616 .775 r
.47846 .33227 m .5007 .31947 L p .47945 .31433 L F P
0 g
s
.682 .616 .775 r
.47945 .31433 m .47233 .31838 L .47846 .33227 L p F P
0 g
s
.686 .618 .774 r
.50679 .33314 m .5007 .31947 L .47846 .33227 L p F P
0 g
s
.686 .618 .774 r
.50572 .33377 m .50679 .33314 L p .47846 .33227 L F P
0 g
s
.658 .449 .59 r
.4658 .2042 m .4641 .20439 L .46292 .19364 L p F P
0 g
s
.658 .449 .59 r
.46292 .19364 m .47285 .19249 L .4658 .2042 L p F P
0 g
s
.993 .824 .454 r
.19097 .7911 m .19037 .78938 L .18778 .79919 L p F P
0 g
s
.993 .824 .454 r
.18778 .79919 m .1889 .80234 L .19097 .7911 L p F P
0 g
s
0 0 .524 r
.21557 .87416 m .21183 .86969 L .20756 .86334 L p F P
0 g
s
.658 .255 0 r
.20248 .85393 m .19864 .84737 L p .20618 .86104 L F P
0 g
s
.658 .255 0 r
.20618 .86104 m .20756 .86334 L .20248 .85393 L p F P
0 g
s
.79 .923 .926 r
.30963 .63375 m .31123 .63005 L p .28684 .64267 L F P
0 g
s
.776 .911 .932 r
.31123 .63005 m .31386 .63098 L .30963 .63375 L closepath p F P
0 g
s
.666 .591 .761 r
.43826 .30104 m .44406 .31541 L .46619 .30351 L p F P
0 g
s
.667 .591 .76 r
.47097 .31531 m .46619 .30351 L .44406 .31541 L p F P
0 g
s
.651 .581 .764 r
.44406 .31541 m .43826 .30104 L .43339 .30232 L p F P
0 g
s
.765 .645 .729 r
.63226 .26912 m .63059 .27097 L .63648 .28574 L p F P
0 g
s
.762 .641 .726 r
.6191 .28338 m .63059 .27097 L .63648 .28574 L p F P
0 g
s
.762 .641 .726 r
.63648 .28574 m .63502 .28736 L .6191 .28338 L p F P
0 g
s
.552 .607 .862 r
.73073 .89599 m .71643 .89612 L .71087 .88619 L p F P
0 g
s
0 0 0 r
.43778 .71211 m .44471 .70197 L .43717 .71488 L p F P
0 g
s
0 0 0 r
.43717 .71488 m .43186 .72448 L .43778 .71211 L p F P
0 g
s
.715 .899 .962 r
.37965 .59427 m .35767 .60524 L .36457 .60833 L p F P
0 g
s
.715 .899 .962 r
.36457 .60833 m .38646 .59727 L .37965 .59427 L p F P
0 g
s
.733 .891 .952 r
.36457 .60833 m .35767 .60524 L .34502 .61208 L p F P
0 g
s
.776 .62 .686 r
.64257 .25595 m .62698 .25179 L .63553 .2393 L p F P
0 g
s
.765 .628 .708 r
.63226 .26912 m .64257 .25595 L .62698 .25179 L p F P
0 g
s
.765 .566 .629 r
.61136 .20817 m .61239 .21264 L .61419 .20875 L closepath p F P
0 g
s
.764 .565 .628 r
.61428 .22092 m .62608 .22355 L p .61419 .20875 L F P
0 g
s
.764 .565 .628 r
.61419 .20875 m .61239 .21264 L .61428 .22092 L p F P
0 g
s
.715 .641 .773 r
.55682 .33457 m .56353 .32987 L p .53516 .33234 L F P
0 g
s
.715 .641 .773 r
.53516 .33234 m .53559 .33328 L .55682 .33457 L p F P
0 g
s
.752 .647 .745 r
.61975 .30239 m .63502 .28736 L .6191 .28338 L p F P
0 g
s
.499 .564 .853 r
.71087 .88619 m .70207 .88506 L .70734 .87945 L closepath p F P
0 g
s
.52 .538 .815 r
.70525 .87551 m .70734 .87945 L .70207 .88506 L p F P
0 g
s
.648 .469 .628 r
.46436 .2059 m .4641 .20439 L .43859 .20871 L p F P
0 g
s
.648 .469 .628 r
.45226 .21851 m .46436 .2059 L p .43859 .20871 L F P
0 g
s
.648 .469 .628 r
.43859 .20871 m .44048 .22049 L .45226 .21851 L p F P
0 g
s
.739 .649 .76 r
.6009 .31874 m .6142 .30731 L p .60302 .29873 L F P
0 g
s
.739 .649 .76 r
.58728 .31618 m .6009 .31874 L p .60302 .29873 L F P
0 g
s
.738 .952 .946 r
.80217 .89984 m .80711 .89693 L .80441 .90073 L closepath p F P
0 g
s
.796 .973 .909 r
.82503 .88497 m .80711 .89693 L .80441 .90073 L p F P
0 g
s
.796 .973 .909 r
.82781 .88454 m .82503 .88497 L p .80441 .90073 L F P
0 g
s
.571 .293 .455 r
.4894 .64542 m .49007 .64004 L .49599 .64417 L closepath p F P
0 g
s
.404 .152 .414 r
.4894 .64542 m .49007 .64004 L .48402 .64788 L closepath p F P
0 g
s
.954 .89 .728 r
.40575 .7906 m .40358 .78354 L .3957 .79667 L p F P
0 g
s
.954 .89 .728 r
.3957 .79667 m .39861 .80348 L .40575 .7906 L p F P
0 g
s
.34 .539 .902 r
.78843 .66314 m .78573 .66233 L .78054 .65409 L p F P
0 g
s
.759 .911 .942 r
.31386 .63098 m .33576 .61744 L p .31513 .62328 L F P
0 g
s
.759 .911 .942 r
.31513 .62328 m .31123 .63005 L .31386 .63098 L p F P
0 g
s
.188 .29 .738 r
.65226 .79607 m .64634 .79038 L .64799 .78466 L closepath p F P
0 g
s
.185 .287 .736 r
.64631 .78015 m .64074 .77357 L p .64634 .79038 L F P
0 g
s
.185 .287 .736 r
.64634 .79038 m .64799 .78466 L .64631 .78015 L p F P
0 g
s
.748 .445 .47 r
.55161 .63304 m .5444 .632 L .54325 .64115 L p F P
0 g
s
.748 .445 .47 r
.54325 .64115 m .55403 .64276 L .55161 .63304 L p F P
0 g
s
.661 .454 .592 r
.49083 .20154 m .4658 .2042 L .47285 .19249 L p F P
0 g
s
.661 .454 .592 r
.47285 .19249 m .48955 .19071 L .49083 .20154 L p F P
0 g
s
.754 .559 .633 r
.59571 .20559 m .61136 .20817 L .61239 .21264 L p F P
0 g
s
.741 .519 .591 r
.57717 .19204 m .578 .19735 L .57974 .19237 L closepath p F P
0 g
s
.74 .517 .591 r
.5789 .20318 m .59571 .20559 L p .57974 .19237 L F P
0 g
s
.74 .517 .591 r
.57974 .19237 m .578 .19735 L .5789 .20318 L p F P
0 g
s
.75 .66 .762 r
.61106 .30033 m .6142 .30731 L .61975 .30239 L closepath p F P
0 g
s
.739 .649 .76 r
.6142 .30731 m .61106 .30033 L .60302 .29873 L p F P
0 g
s
.635 .522 .708 r
.42572 .26476 m .41397 .27103 L .42653 .26755 L closepath p F P
0 g
s
.64 .543 .729 r
.43178 .28343 m .42653 .26755 L .41397 .27103 L p F P
0 g
s
.64 .543 .729 r
.43076 .28395 m .43178 .28343 L p .41397 .27103 L F P
0 g
s
.848 .914 .513 r
.42886 .73053 m .43186 .72448 L .43112 .72731 L closepath p F P
0 g
s
.786 .898 .491 r
.42527 .7371 m .42886 .73053 L .43112 .72731 L p F P
0 g
s
.823 .478 0 r
.19577 .8374 m .19234 .83064 L p .19522 .84075 L F P
0 g
s
.823 .478 0 r
.19522 .84075 m .19864 .84737 L .19577 .8374 L p F P
0 g
s
.752 .647 .745 r
.61106 .30033 m .61975 .30239 L p .6191 .28338 L F P
0 g
s
.771 .996 .81 r
.82503 .88497 m .83104 .87949 L .82781 .88454 L closepath p F P
0 g
s
.802 .982 .707 r
.84415 .86473 m .83104 .87949 L .82781 .88454 L p F P
0 g
s
.646 .563 .747 r
.43339 .30232 m .43791 .3001 L p .43076 .28395 L F P
0 g
s
.648 .564 .747 r
.43791 .3001 m .43339 .30232 L .43826 .30104 L closepath p F P
0 g
s
.688 .623 .778 r
.50679 .33314 m .50572 .33377 L .50702 .33366 L closepath p F P
0 g
s
.512 .738 .976 r
.27049 .89662 m .24953 .89789 L .25661 .90402 L p F P
0 g
s
.512 .738 .976 r
.25661 .90402 m .27758 .90212 L .27049 .89662 L p F P
0 g
s
.264 .591 .948 r
.24586 .89699 m .24953 .89789 L .25661 .90402 L p F P
0 g
s
.638 .803 .962 r
.46923 .58237 m .47192 .58459 L .4941 .57765 L p F P
0 g
s
.774 .597 .659 r
.63553 .2393 m .61929 .23534 L .62608 .22355 L p F P
0 g
s
.764 .608 .686 r
.62698 .25179 m .63553 .2393 L .61929 .23534 L p F P
0 g
s
.768 .59 .657 r
.61428 .22092 m .62608 .22355 L .61929 .23534 L p F P
0 g
s
.437 .456 .782 r
.6812 .84713 m .67002 .84276 L .66762 .83659 L p F P
0 g
s
.728 .509 .595 r
.55799 .19044 m .57717 .19204 L .578 .19735 L p F P
0 g
s
.701 .629 .773 r
.50679 .33314 m .50702 .33366 L .53372 .33327 L p F P
0 g
s
.722 .649 .775 r
.56353 .32987 m .58293 .31555 L .56277 .31314 L p F P
0 g
s
.722 .649 .775 r
.56277 .31314 m .55755 .31693 L .56353 .32987 L p F P
0 g
s
.715 .641 .773 r
.56353 .32987 m .55755 .31693 L .53516 .33234 L p F P
0 g
s
.098 .462 .888 r
.22501 .88438 m .2209 .87807 L p .23784 .88706 L F P
0 g
s
.098 .462 .888 r
.23784 .88706 m .24084 .891 L .22501 .88438 L p F P
0 g
s
.696 .626 .774 r
.50679 .33314 m .52912 .31899 L p .51313 .31173 L F P
0 g
s
.696 .626 .774 r
.51313 .31173 m .5007 .31947 L .50679 .33314 L p F P
0 g
s
.701 .629 .773 r
.53516 .33234 m .52912 .31899 L .50679 .33314 L p F P
0 g
s
.701 .629 .773 r
.53372 .33327 m .53516 .33234 L p .50679 .33314 L F P
0 g
s
.946 .947 .743 r
.21055 .72689 m .21 .71872 L .20156 .7318 L p F P
0 g
s
.946 .947 .743 r
.20156 .7318 m .20225 .73989 L .21055 .72689 L p F P
0 g
s
.629 .774 .95 r
.50028 .58359 m .52259 .57681 L p .50319 .57508 L F P
0 g
s
.629 .774 .95 r
.50319 .57508 m .4941 .57765 L .50028 .58359 L p F P
0 g
s
.704 .635 .778 r
.53516 .33234 m .53372 .33327 L .53559 .33328 L closepath p F P
0 g
s
0 0 .434 r
.86435 .78204 m .86208 .7897 L .86436 .80035 L p F P
0 g
s
0 .025 .55 r
.86208 .7897 m .86435 .78204 L .86038 .77188 L p F P
0 g
s
.645 .512 .686 r
.41868 .23879 m .41977 .24308 L .43016 .23621 L closepath p F P
0 g
s
.46 .689 .965 r
.67693 .60081 m .66862 .60073 L .6618 .59458 L p F P
0 g
s
.644 .841 .976 r
.45921 .57528 m .43705 .58297 L .44352 .58716 L p F P
0 g
s
.644 .841 .976 r
.44352 .58716 m .4656 .57956 L .45921 .57528 L p F P
0 g
s
.648 .823 .967 r
.46923 .58237 m .4656 .57956 L .44352 .58716 L p F P
0 g
s
.486 .709 .969 r
.6482 .59505 m .6618 .59458 L .65406 .58866 L p F P
0 g
s
.486 .709 .969 r
.65406 .58866 m .64264 .58907 L .6482 .59505 L p F P
0 g
s
.913 .849 .767 r
.38014 .84333 m .38451 .83679 L .38007 .83055 L p F P
0 g
s
.38 .107 .37 r
.48402 .64788 m .4894 .64542 L .48783 .65444 L p F P
0 g
s
.38 .107 .37 r
.48783 .65444 m .46921 .66289 L .48402 .64788 L p F P
0 g
s
.754 .559 .633 r
.61239 .21264 m .60889 .21992 L p .59571 .20559 L F P
0 g
s
.76 .562 .63 r
.61239 .21264 m .60889 .21992 L .61428 .22092 L closepath p F P
0 g
s
.709 .637 .774 r
.53516 .33234 m .55755 .31693 L p .53987 .31173 L F P
0 g
s
.709 .637 .774 r
.53987 .31173 m .52912 .31899 L .53516 .33234 L p F P
0 g
s
.379 .098 .355 r
.46768 .66426 m .46921 .66289 L .46784 .6635 L closepath p F P
0 g
s
0 0 .13 r
.46784 .6635 m .46768 .66426 L .461 .67589 L p F P
0 g
s
.709 .407 .464 r
.5444 .632 m .53128 .63108 L .53443 .64055 L p F P
0 g
s
.709 .407 .464 r
.53443 .64055 m .54325 .64115 L .5444 .632 L p F P
0 g
s
.985 .829 .44 r
.19037 .78938 m .1887 .78376 L .18655 .79506 L p F P
0 g
s
.985 .829 .44 r
.18655 .79506 m .18778 .79919 L .19037 .78938 L p F P
0 g
s
.437 .456 .782 r
.66762 .83659 m .67152 .83137 L p .6812 .84713 L F P
0 g
s
.391 .429 .78 r
.66762 .83659 m .66413 .82766 L .67152 .83137 L closepath p F P
0 g
s
.957 .948 .696 r
.4179 .75784 m .41821 .7499 L .41107 .76277 L p F P
0 g
s
.957 .948 .696 r
.41259 .76866 m .4179 .75784 L p .41107 .76277 L F P
0 g
s
.618 .759 .947 r
.52865 .58304 m .5511 .57655 L p .53261 .57424 L F P
0 g
s
.618 .759 .947 r
.53261 .57424 m .52259 .57681 L .52865 .58304 L p F P
0 g
s
.042 .199 .702 r
.64631 .78015 m .64074 .77357 L .64128 .76713 L closepath p F P
0 g
s
.036 .193 .697 r
.64036 .76473 m .63482 .75682 L p .64074 .77357 L F P
0 g
s
.036 .193 .697 r
.64074 .77357 m .64128 .76713 L .64036 .76473 L p F P
0 g
s
.643 .509 .684 r
.43016 .23621 m .41977 .24308 L .42216 .25262 L p F P
0 g
s
.364 .589 .931 r
.74221 .63182 m .74573 .63253 L .74047 .62524 L p F P
0 g
s
.364 .589 .931 r
.74047 .62524 m .73868 .62488 L .74221 .63182 L p F P
0 g
s
.663 .572 .743 r
.43791 .3001 m .43826 .30104 L .46323 .29623 L p F P
0 g
s
.666 .591 .761 r
.46619 .30351 m .46323 .29623 L .43826 .30104 L p F P
0 g
s
.304 .494 .879 r
.78843 .66314 m .80415 .6694 L .8055 .67671 L p F P
0 g
s
.271 .49 .886 r
.78656 .65591 m .78843 .66314 L .80415 .6694 L p F P
0 g
s
.34 .539 .902 r
.78054 .65409 m .78656 .65591 L .78843 .66314 L p F P
0 g
s
.662 .573 .744 r
.43186 .28366 m .43791 .3001 L .46006 .28765 L p F P
0 g
s
.663 .572 .743 r
.46323 .29623 m .46006 .28765 L .43791 .3001 L p F P
0 g
s
.646 .563 .747 r
.43791 .3001 m .43186 .28366 L .43076 .28395 L p F P
0 g
s
.68 .467 .591 r
.50055 .20101 m .49083 .20154 L .48955 .19071 L p F P
0 g
s
.68 .467 .591 r
.48955 .19071 m .50626 .1898 L .50055 .20101 L p F P
0 g
s
.341 .048 .314 r
.46577 .67218 m .46768 .66426 L .46921 .66289 L p F P
0 g
s
.108 0 .224 r
.46577 .67218 m .46768 .66426 L .461 .67589 L closepath p F P
0 g
s
.722 .501 .59 r
.54658 .18968 m .55799 .19044 L .55391 .20106 L p F P
0 g
s
.728 .509 .595 r
.57596 .20289 m .55391 .20106 L .55799 .19044 L p F P
0 g
s
.728 .509 .595 r
.578 .19735 m .57596 .20289 L p .55799 .19044 L F P
0 g
s
.341 .048 .314 r
.46921 .66289 m .48783 .65444 L p .46577 .67218 L F P
0 g
s
.765 .628 .708 r
.62958 .26842 m .63226 .26912 L p .62698 .25179 L F P
0 g
s
.764 .643 .728 r
.62958 .26842 m .63059 .27097 L .63226 .26912 L closepath p F P
0 g
s
.593 .758 .957 r
.55704 .58256 m .56912 .5797 L .55449 .57583 L p F P
0 g
s
.593 .758 .957 r
.55449 .57583 m .5511 .57655 L .55704 .58256 L p F P
0 g
s
.217 .395 .825 r
.83245 .70602 m .82653 .70231 L .82124 .69169 L p F P
0 g
s
.776 .825 .891 r
.31677 .89225 m .3062 .89906 L .31314 .90402 L p F P
0 g
s
.776 .825 .891 r
.31314 .90402 m .3221 .89805 L .31677 .89225 L p F P
0 g
s
.739 .649 .76 r
.60302 .29873 m .58593 .31313 L .58728 .31618 L p F P
0 g
s
.733 .646 .763 r
.58593 .31313 m .58293 .31555 L .58728 .31618 L closepath p F P
0 g
s
.918 .639 .149 r
.19131 .82019 m .1883 .81321 L p .18964 .8245 L F P
0 g
s
.918 .639 .149 r
.18964 .8245 m .19234 .83064 L .19131 .82019 L p F P
0 g
s
.752 .63 .725 r
.63059 .27097 m .62958 .26842 L .61581 .26529 L p F P
0 g
s
.752 .63 .725 r
.6191 .28338 m .63059 .27097 L p .61581 .26529 L F P
0 g
s
.677 .391 .48 r
.53128 .63108 m .51468 .63112 L .51372 .6406 L p F P
0 g
s
.565 .297 .468 r
.51468 .63112 m .51372 .6406 L .49599 .64417 L p F P
0 g
s
.752 .647 .745 r
.6191 .28338 m .60832 .29378 L .61106 .30033 L p F P
0 g
s
.747 .645 .747 r
.60832 .29378 m .60302 .29873 L .61106 .30033 L closepath p F P
0 g
s
.682 .615 .775 r
.47097 .31531 m .47233 .31838 L .47945 .31433 L closepath p F P
0 g
s
.677 .391 .48 r
.51372 .6406 m .53443 .64055 L .53128 .63108 L p F P
0 g
s
.733 .512 .592 r
.578 .19735 m .57596 .20289 L .5789 .20318 L closepath p F P
0 g
s
.747 .549 .627 r
.5789 .20318 m .59571 .20559 L .59013 .21686 L p F P
0 g
s
.754 .559 .633 r
.60889 .21992 m .59013 .21686 L .59571 .20559 L p F P
0 g
s
.684 .472 .593 r
.51882 .20023 m .50055 .20101 L .50626 .1898 L p F P
0 g
s
.684 .472 .593 r
.50626 .1898 m .5174 .18932 L .51882 .20023 L p F P
0 g
s
.913 .849 .767 r
.38007 .83055 m .37337 .84017 L .38014 .84333 L p F P
0 g
s
.872 .864 .829 r
.38014 .84333 m .37359 .85079 L .36938 .84454 L p F P
0 g
s
.872 .864 .829 r
.36938 .84454 m .37337 .84017 L .38014 .84333 L p F P
0 g
s
.842 .951 .888 r
.26242 .66221 m .26501 .65995 L .2644 .66238 L closepath p F P
0 g
s
.849 .936 .882 r
.2644 .66238 m .26242 .66221 L .24733 .67587 L p F P
0 g
s
.808 .478 .431 r
.56818 .6466 m .55403 .64276 L .55732 .65229 L p F P
0 g
s
.808 .478 .431 r
.55732 .65229 m .57082 .65634 L .56818 .6466 L p F P
0 g
s
.399 .427 .773 r
.67152 .83137 m .66413 .82766 L .6609 .81912 L p F P
0 g
s
0 0 0 r
.8518 .85136 m .85576 .84358 L .86012 .83105 L p F P
0 g
s
.755 .871 .446 r
.8518 .85136 m .85576 .84358 L p .84583 .86213 L F P
0 g
s
.755 .871 .446 r
.84583 .86213 m .84705 .86041 L .8518 .85136 L p F P
0 g
s
.722 .501 .59 r
.55391 .20106 m .54813 .20068 L .54658 .18968 L p F P
0 g
s
.706 .49 .593 r
.53389 .18943 m .54658 .18968 L .54813 .20068 L p F P
0 g
s
0 .01 .582 r
.63482 .75682 m .64036 .76473 L .63444 .75035 L p F P
0 g
s
0 .01 .582 r
.63444 .75035 m .63394 .74954 L .63482 .75682 L p F P
0 g
s
0 0 .57 r
.63482 .75682 m .63394 .74954 L .6284 .74019 L p F P
0 g
s
.765 .628 .708 r
.62698 .25179 m .62463 .25469 L .62958 .26842 L p F P
0 g
s
.761 .626 .71 r
.62463 .25469 m .61581 .26529 L .62958 .26842 L closepath p F P
0 g
s
.643 .509 .684 r
.42216 .25262 m .44678 .24727 L p .43016 .23621 L F P
0 g
s
.652 .534 .707 r
.44789 .25098 m .44678 .24727 L .42216 .25262 L p F P
0 g
s
.652 .534 .707 r
.42216 .25262 m .42572 .26476 L .44789 .25098 L p F P
0 g
s
.664 .86 .974 r
.43051 .57906 m .40842 .58771 L .41505 .59155 L p F P
0 g
s
.664 .86 .974 r
.41505 .59155 m .43705 .58297 L .43051 .57906 L p F P
0 g
s
.687 .866 .966 r
.41505 .59155 m .40842 .58771 L .38769 .59671 L p F P
0 g
s
0 0 .062 r
.44492 .7016 m .45309 .68884 L .44771 .69369 L closepath p F P
0 g
s
0 0 .008 r
.44471 .70197 m .44492 .7016 L .44771 .69369 L p F P
0 g
s
.729 .639 .758 r
.58593 .31313 m .58293 .31555 L .56277 .31314 L p F P
0 g
s
.41 .641 .951 r
.70995 .61489 m .71125 .61503 L .7059 .60836 L p F P
0 g
s
.41 .641 .951 r
.7059 .60836 m .70499 .60827 L .70995 .61489 L p F P
0 g
s
.701 .484 .591 r
.5174 .18932 m .53389 .18943 L .52912 .20029 L p F P
0 g
s
.706 .49 .593 r
.54813 .20068 m .52912 .20029 L .53389 .18943 L p F P
0 g
s
.642 .544 .728 r
.43178 .28343 m .43076 .28395 L .43186 .28366 L closepath p F P
0 g
s
.768 .59 .657 r
.61929 .23534 m .6182 .2351 L .61428 .22092 L p F P
0 g
s
.757 .584 .662 r
.60889 .21992 m .61428 .22092 L .6182 .2351 L p F P
0 g
s
.701 .484 .591 r
.52912 .20029 m .51882 .20023 L .5174 .18932 L p F P
0 g
s
.735 .646 .76 r
.58593 .31313 m .60302 .29873 L .58475 .2956 L p F P
0 g
s
.735 .646 .76 r
.58475 .2956 m .57998 .29954 L .58593 .31313 L p F P
0 g
s
.729 .639 .758 r
.56277 .31314 m .57998 .29954 L .58593 .31313 L p F P
0 g
s
.679 .599 .759 r
.47097 .31531 m .47945 .31433 L p .48256 .29379 L F P
0 g
s
.679 .599 .759 r
.48256 .29379 m .46619 .30351 L .47097 .31531 L p F P
0 g
s
.967 .932 .691 r
.20147 .74134 m .20225 .73989 L .20237 .74071 L closepath p F P
0 g
s
.968 .93 .689 r
.19568 .75239 m .20147 .74134 L .20237 .74071 L p F P
0 g
s
.658 .553 .725 r
.43178 .28343 m .43186 .28366 L .4567 .27863 L p F P
0 g
s
.662 .573 .744 r
.46006 .28765 m .4567 .27863 L .43186 .28366 L p F P
0 g
s
.657 .554 .726 r
.42653 .26755 m .43178 .28343 L .45395 .27036 L p F P
0 g
s
.658 .553 .725 r
.4567 .27863 m .45395 .27036 L .43178 .28343 L p F P
0 g
s
.681 .811 .945 r
.29918 .89416 m .27758 .90212 L .28462 .9075 L p F P
0 g
s
.681 .811 .945 r
.28462 .9075 m .3062 .89906 L .29918 .89416 L p F P
0 g
s
.869 .463 .257 r
.58496 .67077 m .58131 .66216 L .58184 .66185 L p F P
0 g
s
.904 .528 .306 r
.58131 .66216 m .58107 .66133 L .58184 .66185 L closepath p F P
0 g
s
.563 .756 .968 r
.58483 .58226 m .58547 .58289 L .58612 .58279 L closepath p F P
0 g
s
.613 .743 .938 r
.58547 .58289 m .58483 .58226 L .56912 .5797 L p F P
0 g
s
.987 .881 .538 r
.19232 .77209 m .19059 .76448 L .18695 .77619 L p F P
0 g
s
.987 .881 .538 r
.18695 .77619 m .1887 .78376 L .19232 .77209 L p F P
0 g
s
.655 .498 .659 r
.44048 .22049 m .44196 .2274 L .45226 .21851 L closepath p F P
0 g
s
.639 .486 .659 r
.44196 .2274 m .43016 .23621 L .44321 .23334 L closepath p F P
0 g
s
.643 .509 .684 r
.44678 .24727 m .44321 .23334 L .43016 .23621 L p F P
0 g
s
.652 .532 .705 r
.45126 .26235 m .44789 .25098 L .42572 .26476 L p F P
0 g
s
.652 .532 .705 r
.42572 .26476 m .42653 .26755 L .45126 .26235 L p F P
0 g
s
.873 .84 .81 r
.37359 .85079 m .36938 .84454 L .35629 .85921 L p F P
0 g
s
.873 .84 .81 r
.35629 .85921 m .36124 .86522 L .37359 .85079 L p F P
0 g
s
.752 .63 .725 r
.60249 .27979 m .6191 .28338 L p .61581 .26529 L F P
0 g
s
.751 .645 .744 r
.60249 .27979 m .60832 .29378 L .6191 .28338 L closepath p F P
0 g
s
.765 .833 .904 r
.33514 .88967 m .3221 .89805 L .31677 .89225 L p F P
0 g
s
.953 .89 .73 r
.39629 .80762 m .39861 .80348 L .3957 .79667 L p F P
0 g
s
0 0 .147 r
.86245 .81806 m .86192 .81923 L .86012 .83105 L p F P
0 g
s
.533 .752 .976 r
.58612 .58279 m .60828 .57965 L p .57965 .57734 L F P
0 g
s
.533 .752 .976 r
.57965 .57734 m .58483 .58226 L .58612 .58279 L p F P
0 g
s
.564 .747 .963 r
.58612 .58279 m .60828 .57965 L .61399 .58522 L p F P
0 g
s
.764 .608 .686 r
.62327 .2509 m .62698 .25179 L p .61929 .23534 L F P
0 g
s
.764 .627 .708 r
.62327 .2509 m .62463 .25469 L .62698 .25179 L closepath p F P
0 g
s
.657 .554 .726 r
.45395 .27036 m .45126 .26235 L .42653 .26755 L p F P
0 g
s
.775 .933 .935 r
.30665 .62888 m .31513 .62328 L .31123 .63005 L closepath p F P
0 g
s
.79 .923 .926 r
.31123 .63005 m .30665 .62888 L .28684 .64267 L p F P
0 g
s
0 0 .537 r
.8621 .76426 m .86038 .77188 L .86435 .78204 L p F P
0 g
s
.011 .115 .626 r
.86038 .77188 m .8621 .76426 L .85652 .75459 L p F P
0 g
s
.402 .625 .943 r
.71125 .61503 m .73444 .61809 L .73868 .62488 L p F P
0 g
s
.39 .63 .949 r
.73444 .61809 m .71125 .61503 L .7059 .60836 L p F P
0 g
s
.666 .485 .63 r
.4641 .20439 m .46436 .2059 L .4658 .2042 L closepath p F P
0 g
s
.399 .427 .773 r
.6609 .81912 m .66332 .81522 L p .67152 .83137 L F P
0 g
s
.346 .394 .769 r
.6609 .81912 m .65821 .81201 L .66332 .81522 L closepath p F P
0 g
s
.369 .581 .924 r
.74573 .63253 m .76304 .6363 L .76603 .64333 L p F P
0 g
s
.353 .583 .93 r
.76304 .6363 m .74573 .63253 L .74047 .62524 L p F P
0 g
s
.713 .866 .454 r
.43186 .72448 m .43717 .71488 L .4295 .72787 L p F P
0 g
s
.713 .866 .454 r
.42886 .73053 m .43186 .72448 L p .4295 .72787 L F P
0 g
s
.742 .641 .748 r
.60832 .29378 m .60302 .29873 L p .60218 .27973 L F P
0 g
s
.742 .641 .748 r
.60218 .27973 m .60249 .27979 L .60832 .29378 L p F P
0 g
s
.664 .482 .628 r
.49268 .21197 m .49083 .20154 L .4658 .2042 L p F P
0 g
s
.664 .482 .628 r
.49136 .21364 m .49268 .21197 L p .4658 .2042 L F P
0 g
s
.664 .482 .628 r
.46611 .21628 m .49136 .21364 L p .4658 .2042 L F P
0 g
s
.664 .482 .628 r
.4658 .2042 m .46436 .2059 L .46611 .21628 L p F P
0 g
s
.861 .489 .341 r
.58107 .66133 m .57082 .65634 L .57401 .66599 L p F P
0 g
s
.861 .489 .341 r
.58131 .66216 m .58107 .66133 L p .57401 .66599 L F P
0 g
s
.745 .57 .657 r
.60135 .23199 m .60889 .21992 L .59013 .21686 L p F P
0 g
s
.757 .584 .662 r
.6182 .2351 m .60135 .23199 L .60889 .21992 L p F P
0 g
s
.742 .641 .748 r
.60302 .29873 m .58475 .2956 L .60218 .27973 L p F P
0 g
s
0 .226 .745 r
.21557 .87416 m .2209 .87807 L .2171 .8716 L p F P
0 g
s
0 .226 .745 r
.2171 .8716 m .20862 .86471 L .21557 .87416 L p F P
0 g
s
0 0 .524 r
.20756 .86334 m .20862 .86471 L .21557 .87416 L p F P
0 g
s
.633 .813 .969 r
.4656 .57956 m .46923 .58237 L .49261 .57643 L p F P
0 g
s
.638 .803 .962 r
.4941 .57765 m .49261 .57643 L .46923 .58237 L p F P
0 g
s
.557 .261 .42 r
.49599 .64417 m .4894 .64542 L .48783 .65444 L p F P
0 g
s
.679 .599 .759 r
.47945 .31433 m .49459 .30518 L p .48256 .29379 L F P
0 g
s
.683 .604 .761 r
.49459 .30518 m .47945 .31433 L .49755 .31241 L closepath p F P
0 g
s
.682 .616 .775 r
.5007 .31947 m .49755 .31241 L .47945 .31433 L p F P
0 g
s
.755 .622 .712 r
.62463 .25469 m .61581 .26529 L p .6099 .24815 L F P
0 g
s
.755 .622 .712 r
.6099 .24815 m .62327 .2509 L .62463 .25469 L p F P
0 g
s
.65 .472 .63 r
.46436 .2059 m .45226 .21851 L .46611 .21628 L closepath p F P
0 g
s
.742 .923 .951 r
.35069 .60244 m .32866 .61503 L .33576 .61744 L p F P
0 g
s
.742 .923 .951 r
.35232 .60297 m .35069 .60244 L p .33576 .61744 L F P
0 g
s
.742 .923 .951 r
.33576 .61744 m .34502 .61208 L .35232 .60297 L p F P
0 g
s
.759 .911 .942 r
.33576 .61744 m .32866 .61503 L .31513 .62328 L p F P
0 g
s
.695 .625 .774 r
.49755 .31241 m .5007 .31947 L .51313 .31173 L closepath p F P
0 g
s
.594 .777 .967 r
.57965 .57734 m .56912 .5797 L .58483 .58226 L closepath p F P
0 g
s
.922 .958 .79 r
.21708 .70925 m .22023 .70511 L .22019 .70836 L closepath p F P
0 g
s
.924 .956 .787 r
.21 .71872 m .21708 .70925 L .22019 .70836 L p F P
0 g
s
.96 .944 .693 r
.20225 .73989 m .20156 .7318 L .19464 .74444 L p F P
0 g
s
.96 .944 .693 r
.20147 .74134 m .20225 .73989 L p .19464 .74444 L F P
0 g
s
.763 .608 .686 r
.6182 .2351 m .61859 .23632 L .61929 .23534 L closepath p F P
0 g
s
.764 .608 .686 r
.61929 .23534 m .61859 .23632 L .62327 .2509 L p F P
0 g
s
.724 .925 .959 r
.80711 .89693 m .80217 .89984 L .79739 .89696 L p F P
0 g
s
.634 .888 .987 r
.77402 .90518 m .79739 .89696 L .80217 .89984 L p F P
0 g
s
.268 .456 .861 r
.81602 .682 m .8055 .67671 L p .82018 .69101 L F P
0 g
s
.23 .439 .858 r
.8055 .67671 m .81602 .682 L .81081 .67281 L p F P
0 g
s
.23 .439 .858 r
.81081 .67281 m .80415 .6694 L .8055 .67671 L p F P
0 g
s
.76 .606 .688 r
.61859 .23632 m .6099 .24815 L .62327 .2509 L closepath p F P
0 g
s
.754 .603 .69 r
.61859 .23632 m .6099 .24815 L p .60135 .23199 L F P
0 g
s
.754 .603 .69 r
.60135 .23199 m .6182 .2351 L .61859 .23632 L p F P
0 g
s
.836 .452 .324 r
.57771 .66777 m .58131 .66216 L .58496 .67077 L closepath p F P
0 g
s
.861 .489 .341 r
.57401 .66599 m .57771 .66777 L .58131 .66216 L p F P
0 g
s
.35 .393 .766 r
.66332 .81522 m .65821 .81201 L .65443 .80189 L p F P
0 g
s
.552 .607 .862 r
.71087 .88619 m .73459 .88768 L p .73073 .89599 L F P
0 g
s
.497 .563 .853 r
.72909 .87874 m .73459 .88768 L .71087 .88619 L p F P
0 g
s
.497 .563 .853 r
.7104 .87615 m .72909 .87874 L p .71087 .88619 L F P
0 g
s
.497 .563 .853 r
.71087 .88619 m .70734 .87945 L .7104 .87615 L p F P
0 g
s
.576 .761 .966 r
.74536 .90357 m .76892 .89982 L .77402 .90518 L p F P
0 g
s
.552 .722 .953 r
.76892 .89982 m .74536 .90357 L .74001 .89598 L p F P
0 g
s
.721 .647 .774 r
.55549 .31244 m .55755 .31693 L .56277 .31314 L closepath p F P
0 g
s
.709 .637 .774 r
.55755 .31693 m .55549 .31244 L .53987 .31173 L p F P
0 g
s
.691 .312 0 r
.62133 .72373 m .61779 .71703 L .61342 .7075 L p F P
0 g
s
.96 .944 .693 r
.19464 .74444 m .1948 .74627 L .20147 .74134 L p F P
0 g
s
.967 .934 .686 r
.1948 .74627 m .20147 .74134 L .19568 .75239 L closepath p F P
0 g
s
.953 .89 .73 r
.3957 .79667 m .38948 .807 L .39629 .80762 L p F P
0 g
s
.918 .917 .8 r
.39629 .80762 m .38966 .81691 L .38718 .81002 L p F P
0 g
s
.918 .917 .8 r
.38718 .81002 m .38948 .807 L .39629 .80762 L p F P
0 g
s
.747 .549 .627 r
.59013 .21686 m .58156 .21565 L .5789 .20318 L p F P
0 g
s
.734 .541 .631 r
.57596 .20289 m .5789 .20318 L .58156 .21565 L p F P
0 g
s
.653 .495 .657 r
.45226 .21851 m .44196 .2274 L .44321 .23334 L p F P
0 g
s
.692 .886 .969 r
.38646 .59727 m .38769 .59671 L .38679 .59743 L closepath p F P
0 g
s
.709 .636 .774 r
.52567 .31135 m .52912 .31899 L .53987 .31173 L closepath p F P
0 g
s
.696 .626 .774 r
.52912 .31899 m .52567 .31135 L .51313 .31173 L p F P
0 g
s
.957 .948 .696 r
.41107 .76277 m .41153 .76924 L .41259 .76866 L p F P
0 g
s
.943 .962 .709 r
.41153 .76924 m .41259 .76866 L .4115 .77045 L closepath p F P
0 g
s
.809 .944 .913 r
.2846 .64438 m .28684 .64267 L .28606 .64463 L closepath p F P
0 g
s
.82 .931 .905 r
.28606 .64463 m .2846 .64438 L .26501 .65995 L p F P
0 g
s
.249 .575 .941 r
.24953 .89789 m .24586 .89699 L .24084 .891 L p F P
0 g
s
.965 .75 .309 r
.1889 .80234 m .18778 .79919 L .18743 .81083 L p F P
0 g
s
.965 .75 .309 r
.18743 .81083 m .1883 .81321 L .1889 .80234 L p F P
0 g
s
.883 .474 .233 r
.59387 .67611 m .58496 .67077 L .58919 .68019 L p F P
0 g
s
.883 .474 .233 r
.58919 .68019 m .59777 .68563 L .59387 .67611 L p F P
0 g
s
.722 .528 .627 r
.5696 .21445 m .57596 .20289 L .55391 .20106 L p F P
0 g
s
.734 .541 .631 r
.58156 .21565 m .5696 .21445 L .57596 .20289 L p F P
0 g
s
.724 .925 .959 r
.79739 .89696 m .81262 .88895 L .80711 .89693 L p F P
0 g
s
.726 .983 .906 r
.82055 .88431 m .81262 .88895 L .80711 .89693 L p F P
0 g
s
.726 .983 .906 r
.80711 .89693 m .82503 .88497 L .82055 .88431 L p F P
0 g
s
0 0 .103 r
.86482 .81155 m .86245 .81806 L .86192 .82716 L p F P
0 g
s
0 0 .307 r
.86245 .81806 m .86482 .81155 L .86436 .80035 L p F P
0 g
s
0 0 .147 r
.86012 .83105 m .86192 .82716 L .86245 .81806 L p F P
0 g
s
.679 .6 .76 r
.46323 .29623 m .46619 .30351 L .48256 .29379 L closepath p F P
0 g
s
.612 .821 .419 r
.84415 .86473 m .84583 .86213 L .84705 .86041 L closepath p F P
0 g
s
.653 .495 .657 r
.46894 .22923 m .46611 .21628 L .45226 .21851 L p F P
0 g
s
.653 .495 .657 r
.44321 .23334 m .46894 .22923 L p .45226 .21851 L F P
0 g
s
.721 .633 .759 r
.56277 .31314 m .57998 .29954 L p .5644 .29321 L F P
0 g
s
.721 .633 .759 r
.55549 .31244 m .56277 .31314 L p .5644 .29321 L F P
0 g
s
.826 .403 0 r
.60846 .70113 m .61342 .7075 L .61779 .71703 L p F P
0 g
s
.837 .42 0 r
.61342 .7075 m .60846 .70113 L .60442 .69158 L p F P
0 g
s
.875 .84 .807 r
.3575 .86966 m .36124 .86522 L .35629 .85921 L p F P
0 g
s
.688 .896 .972 r
.40172 .58423 m .37965 .59427 L .38646 .59727 L p F P
0 g
s
.688 .896 .972 r
.40338 .58498 m .40172 .58423 L p .38646 .59727 L F P
0 g
s
.688 .896 .972 r
.38646 .59727 m .38769 .59671 L .40338 .58498 L p F P
0 g
s
.09 0 .198 r
.461 .67589 m .46577 .67218 L .46351 .68077 L p F P
0 g
s
.09 0 .198 r
.46351 .68077 m .45309 .68884 L .461 .67589 L p F P
0 g
s
.865 .96 .865 r
.24733 .67587 m .24921 .66668 L .23366 .68199 L p F P
0 g
s
.865 .96 .865 r
.23999 .68324 m .24733 .67587 L p .23366 .68199 L F P
0 g
s
.844 .955 .885 r
.26242 .66221 m .24733 .67587 L .24921 .66668 L p F P
0 g
s
.887 .459 .093 r
.60442 .69158 m .59777 .68563 L .6019 .69516 L p F P
0 g
s
.887 .459 .093 r
.6019 .69516 m .60846 .70113 L .60442 .69158 L p F P
0 g
s
.923 .976 .727 r
.4115 .77045 m .40358 .78354 L .40335 .77585 L p F P
0 g
s
.923 .976 .727 r
.41153 .76924 m .4115 .77045 L p .40335 .77585 L F P
0 g
s
.839 .962 .887 r
.26812 .6503 m .25478 .66175 L .26242 .66221 L p F P
0 g
s
.839 .962 .887 r
.26242 .66221 m .26501 .65995 L .26812 .6503 L p F P
0 g
s
.844 .955 .885 r
.24921 .66668 m .25478 .66175 L .26242 .66221 L p F P
0 g
s
.557 .261 .42 r
.48783 .65444 m .51071 .6501 L .49599 .64417 L p F P
0 g
s
.556 .267 .431 r
.51372 .6406 m .49599 .64417 L .51071 .6501 L p F P
0 g
s
.814 .948 .909 r
.2846 .64438 m .26501 .65995 L .26812 .6503 L p F P
0 g
s
.433 .676 .965 r
.67693 .60081 m .69922 .60183 L .69263 .59558 L p F P
0 g
s
.433 .676 .965 r
.69263 .59558 m .67147 .59467 L .67693 .60081 L p F P
0 g
s
.46 .689 .965 r
.6618 .59458 m .67147 .59467 L .67693 .60081 L p F P
0 g
s
0 .093 .62 r
.85769 .74703 m .85652 .75459 L .8621 .76426 L p F P
0 g
s
.062 .193 .689 r
.85652 .75459 m .85769 .74703 L .85057 .73785 L p F P
0 g
s
.35 .393 .766 r
.65443 .80189 m .6559 .79884 L p .66332 .81522 L F P
0 g
s
.289 .354 .757 r
.65443 .80189 m .65226 .79607 L .6559 .79884 L closepath p F P
0 g
s
.833 .838 .85 r
.33992 .8748 m .32824 .88512 L .33514 .88967 L p F P
0 g
s
.833 .838 .85 r
.33514 .88967 m .34491 .88076 L .33992 .8748 L p F P
0 g
s
.765 .833 .904 r
.31677 .89225 m .32824 .88512 L .33514 .88967 L p F P
0 g
s
.825 .849 .866 r
.3575 .86966 m .34491 .88076 L .33992 .8748 L p F P
0 g
s
.505 .738 .978 r
.63139 .57769 m .60828 .57965 L .61399 .58522 L p F P
0 g
s
.505 .738 .978 r
.61399 .58522 m .63704 .58329 L .63139 .57769 L p F P
0 g
s
.685 .874 .97 r
.40338 .58498 m .40842 .58771 L .38769 .59671 L closepath p F P
0 g
s
.755 .622 .712 r
.61581 .26529 m .59828 .26183 L .6099 .24815 L p F P
0 g
s
.747 .627 .726 r
.60239 .27952 m .61581 .26529 L .59828 .26183 L p F P
0 g
s
.752 .63 .725 r
.61581 .26529 m .60239 .27952 L .60249 .27979 L p F P
0 g
s
.713 .866 .454 r
.4295 .72787 m .42648 .73402 L .42886 .73053 L p F P
0 g
s
.772 .889 .478 r
.42648 .73402 m .42886 .73053 L .42527 .7371 L closepath p F P
0 g
s
.865 .96 .865 r
.23366 .68199 m .2334 .68341 L .23999 .68324 L p F P
0 g
s
.877 .954 .854 r
.2334 .68341 m .23999 .68324 L .23258 .69087 L closepath p F P
0 g
s
.875 .84 .807 r
.35629 .85921 m .35066 .86566 L .3575 .86966 L p F P
0 g
s
.825 .849 .866 r
.33992 .8748 m .35066 .86566 L .3575 .86966 L p F P
0 g
s
.721 .633 .759 r
.5644 .29321 m .55154 .30317 L .55549 .31244 L p F P
0 g
s
.714 .629 .762 r
.55154 .30317 m .53987 .31173 L .55549 .31244 L closepath p F P
0 g
s
.693 .609 .758 r
.49755 .31241 m .51313 .31173 L p .51545 .29148 L F P
0 g
s
.693 .609 .758 r
.51545 .29148 m .49459 .30518 L .49755 .31241 L p F P
0 g
s
.771 .988 .752 r
.84583 .86213 m .84415 .86473 L .83104 .87949 L p F P
0 g
s
.663 .523 .683 r
.47022 .23407 m .46894 .22923 L .44321 .23334 L p F P
0 g
s
.663 .523 .683 r
.45502 .24598 m .47022 .23407 L p .44321 .23334 L F P
0 g
s
.663 .523 .683 r
.44321 .23334 m .44678 .24727 L .45502 .24598 L p F P
0 g
s
.189 .387 .827 r
.82124 .69169 m .82018 .69101 L .82 .68927 L closepath p F P
0 g
s
.268 .456 .861 r
.82018 .69101 m .82 .68927 L .81602 .682 L p F P
0 g
s
.731 .901 .955 r
.35232 .60297 m .35767 .60524 L .34502 .61208 L closepath p F P
0 g
s
.286 .354 .758 r
.6559 .79884 m .65226 .79607 L .64799 .78466 L p F P
0 g
s
.322 .539 .908 r
.78656 .65591 m .78054 .65409 L .77534 .64611 L p F P
0 g
s
.893 .971 .825 r
.23258 .69087 m .22023 .70511 L .22092 .69641 L p F P
0 g
s
.893 .971 .825 r
.2334 .68341 m .23258 .69087 L p .22092 .69641 L F P
0 g
s
.686 .498 .627 r
.49083 .20154 m .49268 .21197 L .50055 .20101 L closepath p F P
0 g
s
.675 .581 .742 r
.46323 .29623 m .48256 .29379 L p .47953 .2755 L F P
0 g
s
.675 .581 .742 r
.47953 .2755 m .46006 .28765 L .46323 .29623 L p F P
0 g
s
.618 .843 .985 r
.79739 .89696 m .77402 .90518 L .76892 .89982 L p F P
0 g
s
.533 .641 .902 r
.74001 .89598 m .73073 .89599 L .73574 .88943 L closepath p F P
0 g
s
.552 .607 .862 r
.73459 .88768 m .73574 .88943 L .73073 .89599 L p F P
0 g
s
.308 .541 .913 r
.76603 .64333 m .77534 .64611 L .77013 .63843 L p F P
0 g
s
.308 .541 .913 r
.77013 .63843 m .76304 .6363 L .76603 .64333 L p F P
0 g
s
.919 .881 .781 r
.38966 .81691 m .38718 .81002 L .37671 .82395 L p F P
0 g
s
.919 .881 .781 r
.37671 .82395 m .38007 .83055 L .38966 .81691 L p F P
0 g
s
.693 .609 .758 r
.51313 .31173 m .52306 .30507 L p .51545 .29148 L F P
0 g
s
.699 .616 .761 r
.52306 .30507 m .51313 .31173 L .52567 .31135 L closepath p F P
0 g
s
.708 .621 .758 r
.53987 .31173 m .55154 .30317 L p .54174 .29167 L F P
0 g
s
.708 .621 .758 r
.52567 .31135 m .53987 .31173 L p .54174 .29167 L F P
0 g
s
.734 .644 .759 r
.57782 .29458 m .57998 .29954 L .58475 .2956 L closepath p F P
0 g
s
.721 .633 .759 r
.57998 .29954 m .57782 .29458 L .5644 .29321 L p F P
0 g
s
.746 .57 .657 r
.58156 .21565 m .58426 .22601 L .59013 .21686 L closepath p F P
0 g
s
.745 .57 .657 r
.58514 .22942 m .60135 .23199 L p .59013 .21686 L F P
0 g
s
.745 .57 .657 r
.59013 .21686 m .58426 .22601 L .58514 .22942 L p F P
0 g
s
.724 .53 .628 r
.54813 .20068 m .54968 .20849 L .55391 .20106 L closepath p F P
0 g
s
.722 .528 .627 r
.55056 .21292 m .5696 .21445 L p .55391 .20106 L F P
0 g
s
.722 .528 .627 r
.55391 .20106 m .54968 .20849 L .55056 .21292 L p F P
0 g
s
.022 .177 .686 r
.85119 .73033 m .85057 .73785 L .85769 .74703 L p F P
0 g
s
.109 .263 .742 r
.85057 .73785 m .85119 .73033 L .84255 .72165 L p F P
0 g
s
.684 .495 .626 r
.52107 .21229 m .51882 .20023 L .50055 .20101 L p F P
0 g
s
.684 .495 .626 r
.49295 .21348 m .52107 .21229 L p .50055 .20101 L F P
0 g
s
.684 .495 .626 r
.50055 .20101 m .49268 .21197 L .49295 .21348 L p F P
0 g
s
.734 .63 .743 r
.58475 .2956 m .60218 .27973 L .58325 .2768 L p F P
0 g
s
.734 .63 .743 r
.57782 .29458 m .58475 .2956 L p .58325 .2768 L F P
0 g
s
.747 .628 .728 r
.60239 .27952 m .60218 .27973 L .60249 .27979 L closepath p F P
0 g
s
.708 .621 .758 r
.54174 .29167 m .52306 .30507 L .52567 .31135 L p F P
0 g
s
.956 .948 .7 r
.4057 .77233 m .41107 .76277 L .41153 .76924 L closepath p F P
0 g
s
.923 .976 .727 r
.40335 .77585 m .4057 .77233 L .41153 .76924 L p F P
0 g
s
.747 .627 .726 r
.59828 .26183 m .5964 .26376 L .60239 .27952 L p F P
0 g
s
.743 .621 .724 r
.58325 .2768 m .5964 .26376 L .60239 .27952 L p F P
0 g
s
.743 .621 .724 r
.60239 .27952 m .60218 .27973 L .58325 .2768 L p F P
0 g
s
.754 .603 .69 r
.6099 .24815 m .59167 .24491 L .60135 .23199 L p F P
0 g
s
.745 .609 .706 r
.59828 .26183 m .6099 .24815 L .59167 .24491 L p F P
0 g
s
.217 .395 .825 r
.82124 .69169 m .83203 .69861 L .83245 .70602 L p F P
0 g
s
.186 .384 .826 r
.83203 .69861 m .82124 .69169 L .82 .68927 L p F P
0 g
s
.806 .955 .913 r
.29169 .63239 m .27712 .64328 L .2846 .64438 L p F P
0 g
s
.806 .955 .913 r
.2846 .64438 m .28684 .64267 L .29169 .63239 L p F P
0 g
s
.814 .948 .909 r
.26812 .6503 m .27712 .64328 L .2846 .64438 L p F P
0 g
s
.598 .767 .96 r
.57965 .57734 m .56912 .5797 L .55449 .57583 L p F P
0 g
s
.153 .327 .786 r
.84255 .72165 m .84264 .71418 L .83245 .70602 L p F P
0 g
s
.12 .316 .786 r
.83203 .69861 m .83245 .70602 L .84264 .71418 L p F P
0 g
s
.71 .52 .631 r
.52912 .20029 m .54813 .20068 L .54968 .20849 L p F P
0 g
s
.676 .583 .743 r
.4567 .27863 m .46006 .28765 L .47953 .2755 L closepath p F P
0 g
s
.746 .427 .443 r
.55403 .64276 m .54325 .64115 L .54164 .6499 L p F P
0 g
s
.746 .427 .443 r
.54164 .6499 m .55732 .65229 L .55403 .64276 L p F P
0 g
s
.693 .61 .758 r
.48957 .29296 m .49459 .30518 L .51545 .29148 L closepath p F P
0 g
s
.679 .599 .759 r
.49459 .30518 m .48957 .29296 L .48256 .29379 L p F P
0 g
s
.072 .25 .741 r
.84264 .71418 m .84255 .72165 L .85119 .73033 L p F P
0 g
s
.783 .937 .93 r
.30665 .62888 m .28684 .64267 L .29169 .63239 L p F P
0 g
s
.674 .511 .657 r
.47672 .22842 m .46894 .22923 L .46611 .21628 L p F P
0 g
s
.674 .511 .657 r
.46611 .21628 m .49136 .21364 L .47672 .22842 L p F P
0 g
s
.749 .592 .682 r
.58514 .22942 m .60135 .23199 L .59167 .24491 L p F P
0 g
s
.783 .996 .863 r
.83104 .87949 m .82503 .88497 L .82055 .88431 L p F P
0 g
s
.783 .996 .863 r
.82055 .88431 m .83578 .87162 L .83104 .87949 L p F P
0 g
s
.771 .988 .752 r
.84311 .86409 m .84583 .86213 L p .83104 .87949 L F P
0 g
s
.771 .988 .752 r
.83104 .87949 m .83578 .87162 L .84311 .86409 L p F P
0 g
s
.499 .565 .854 r
.70734 .87945 m .70525 .87551 L .7104 .87615 L closepath p F P
0 g
s
.705 .513 .626 r
.51882 .20023 m .52912 .20029 L .52156 .2123 L p F P
0 g
s
.71 .52 .631 r
.54708 .2128 m .52156 .2123 L .52912 .20029 L p F P
0 g
s
.71 .52 .631 r
.54968 .20849 m .54708 .2128 L p .52912 .20029 L F P
0 g
s
.286 .354 .758 r
.64799 .78466 m .64876 .78237 L p .6559 .79884 L F P
0 g
s
.216 .307 .743 r
.64799 .78466 m .64631 .78015 L .64876 .78237 L closepath p F P
0 g
s
.705 .513 .626 r
.52156 .2123 m .52107 .21229 L .51882 .20023 L p F P
0 g
s
.491 .725 .976 r
.26336 .89095 m .24242 .89143 L .24953 .89789 L p F P
0 g
s
.491 .725 .976 r
.24953 .89789 m .27049 .89662 L .26336 .89095 L p F P
0 g
s
.249 .575 .941 r
.24084 .891 m .24242 .89143 L .24953 .89789 L p F P
0 g
s
0 0 .272 r
.86664 .79272 m .86436 .80035 L .86482 .81155 L p F P
0 g
s
0 0 .434 r
.86436 .80035 m .86664 .79272 L .86435 .78204 L p F P
0 g
s
.672 .853 .449 r
.42527 .7371 m .41821 .7499 L .4216 .74097 L p F P
0 g
s
.672 .853 .449 r
.42648 .73402 m .42527 .7371 L p .4216 .74097 L F P
0 g
s
.667 .545 .707 r
.44678 .24727 m .44789 .25098 L .45502 .24598 L closepath p F P
0 g
s
0 0 .517 r
.20862 .86471 m .20756 .86334 L .20618 .86104 L closepath p F P
0 g
s
.734 .564 .661 r
.5696 .21445 m .58156 .21565 L .58426 .22601 L p F P
0 g
s
.734 .63 .743 r
.58325 .2768 m .57399 .28505 L .57782 .29458 L p F P
0 g
s
.728 .627 .745 r
.57399 .28505 m .5644 .29321 L .57782 .29458 L closepath p F P
0 g
s
.197 .303 .747 r
.64876 .78237 m .64631 .78015 L .64128 .76713 L p F P
0 g
s
.666 .543 .705 r
.45502 .24598 m .44789 .25098 L .45126 .26235 L p F P
0 g
s
.721 .632 .758 r
.54671 .29181 m .55154 .30317 L .5644 .29321 L closepath p F P
0 g
s
.708 .621 .758 r
.55154 .30317 m .54671 .29181 L .54174 .29167 L p F P
0 g
s
.671 .563 .725 r
.4567 .27863 m .47953 .2755 L p .47037 .25953 L F P
0 g
s
.671 .563 .725 r
.47037 .25953 m .45395 .27036 L .4567 .27863 L p F P
0 g
s
.637 .257 0 r
.20179 .85359 m .19864 .84737 L .19522 .84075 L closepath p F P
0 g
s
.658 .255 0 r
.19864 .84737 m .20179 .85359 L .20618 .86104 L p F P
0 g
s
.45 .695 .971 r
.67147 .59467 m .6618 .59458 L .65406 .58866 L p F P
0 g
s
.914 .968 .795 r
.22023 .70511 m .22092 .69641 L .21014 .71024 L p F P
0 g
s
.914 .968 .795 r
.21708 .70925 m .22023 .70511 L p .21014 .71024 L F P
0 g
s
.186 .384 .826 r
.82 .68927 m .81929 .68365 L p .83203 .69861 L F P
0 g
s
.248 .444 .856 r
.82 .68927 m .81602 .682 L .81929 .68365 L closepath p F P
0 g
s
.707 .621 .758 r
.51735 .29139 m .52306 .30507 L .54174 .29167 L closepath p F P
0 g
s
.693 .609 .758 r
.52306 .30507 m .51735 .29139 L .51545 .29148 L p F P
0 g
s
.672 .565 .726 r
.45126 .26235 m .45395 .27036 L .47037 .25953 L closepath p F P
0 g
s
.971 .923 .607 r
.19568 .75239 m .19059 .76448 L .18937 .75663 L p F P
0 g
s
.971 .923 .607 r
.1948 .74627 m .19568 .75239 L p .18937 .75663 L F P
0 g
s
.437 .456 .782 r
.67152 .83137 m .68595 .83885 L .6812 .84713 L p F P
0 g
s
.33 .433 .816 r
.67569 .82313 m .67152 .83137 L .68595 .83885 L p F P
0 g
s
.399 .427 .773 r
.66332 .81522 m .67569 .82313 L .67152 .83137 L p F P
0 g
s
.468 .483 .791 r
.6812 .84713 m .69383 .85227 L p .69334 .86226 L F P
0 g
s
.359 .427 .796 r
.6812 .84713 m .69383 .85227 L .68806 .83996 L p F P
0 g
s
.359 .427 .796 r
.68806 .83996 m .68595 .83885 L .6812 .84713 L p F P
0 g
s
.666 .543 .705 r
.45126 .26235 m .47037 .25953 L p .45502 .24598 L F P
0 g
s
.971 .827 .412 r
.1887 .78376 m .18695 .77619 L .18479 .78751 L p F P
0 g
s
.971 .827 .412 r
.18479 .78751 m .18655 .79506 L .1887 .78376 L p F P
0 g
s
.675 .581 .742 r
.48256 .29379 m .48847 .29002 L p .47953 .2755 L F P
0 g
s
.68 .586 .744 r
.48847 .29002 m .48256 .29379 L .48957 .29296 L closepath p F P
0 g
s
.62 .802 .969 r
.49261 .57643 m .4941 .57765 L .50319 .57508 L closepath p F P
0 g
s
0 0 0 r
.45309 .68884 m .46351 .68077 L p .44483 .70183 L F P
0 g
s
0 0 0 r
.44483 .70183 m .44492 .7016 L .45309 .68884 L p F P
0 g
s
0 0 0 r
.86192 .82716 m .86012 .83105 L .85576 .84358 L p F P
0 g
s
.256 .387 .804 r
.6666 .80711 m .66332 .81522 L .67569 .82313 L p F P
0 g
s
.35 .393 .766 r
.6559 .79884 m .6666 .80711 L .66332 .81522 L p F P
0 g
s
.953 .936 .735 r
.40358 .78354 m .40335 .77585 L .39438 .78933 L p F P
0 g
s
.953 .936 .735 r
.39438 .78933 m .3957 .79667 L .40358 .78354 L p F P
0 g
s
.619 .835 .983 r
.48154 .56848 m .45921 .57528 L .4656 .57956 L p F P
0 g
s
.619 .835 .983 r
.4656 .57956 m .48785 .57277 L .48154 .56848 L p F P
0 g
s
.633 .813 .969 r
.49261 .57643 m .48785 .57277 L .4656 .57956 L p F P
0 g
s
.479 .716 .974 r
.64264 .58907 m .65406 .58866 L .6454 .58296 L p F P
0 g
s
.479 .716 .974 r
.6454 .58296 m .63704 .58329 L .64264 .58907 L p F P
0 g
s
.729 .555 .656 r
.55056 .21292 m .5696 .21445 L .56086 .22697 L p F P
0 g
s
.734 .564 .661 r
.5822 .22908 m .56086 .22697 L .5696 .21445 L p F P
0 g
s
.734 .564 .661 r
.58426 .22601 m .5822 .22908 L p .5696 .21445 L F P
0 g
s
.914 .968 .795 r
.21014 .71024 m .21005 .71145 L .21708 .70925 L p F P
0 g
s
.924 .959 .785 r
.21005 .71145 m .21708 .70925 L .21 .71872 L closepath p F P
0 g
s
.745 .609 .706 r
.59549 .26134 m .59828 .26183 L p .59167 .24491 L F P
0 g
s
.746 .626 .726 r
.59549 .26134 m .5964 .26376 L .59828 .26183 L closepath p F P
0 g
s
.665 .526 .685 r
.47022 .23407 m .45502 .24598 L .47264 .24331 L closepath p F P
0 g
s
.666 .543 .705 r
.47626 .25527 m .47264 .24331 L .45502 .24598 L p F P
0 g
s
.666 .543 .705 r
.47037 .25953 m .47626 .25527 L p .45502 .24598 L F P
0 g
s
.702 .382 .432 r
.54325 .64115 m .53443 .64055 L .53885 .64972 L p F P
0 g
s
.702 .382 .432 r
.53885 .64972 m .54164 .6499 L .54325 .64115 L p F P
0 g
s
.943 .741 .271 r
.18778 .79919 m .18655 .79506 L .18599 .80594 L p F P
0 g
s
.943 .741 .271 r
.18599 .80594 m .18743 .81083 L .18778 .79919 L p F P
0 g
s
.505 .555 .841 r
.7104 .87615 m .70525 .87551 L .69957 .86416 L p F P
0 g
s
.733 .612 .724 r
.5964 .26376 m .59549 .26134 L .57876 .25908 L p F P
0 g
s
.733 .612 .724 r
.58325 .2768 m .5964 .26376 L p .57876 .25908 L F P
0 g
s
.708 .898 .965 r
.35767 .60524 m .37965 .59427 L p .35562 .59984 L F P
0 g
s
.708 .898 .965 r
.35562 .59984 m .35232 .60297 L .35767 .60524 L p F P
0 g
s
.61 .786 .966 r
.51925 .57382 m .52259 .57681 L .53261 .57424 L closepath p F P
0 g
s
.629 .774 .95 r
.52259 .57681 m .51925 .57382 L .50319 .57508 L p F P
0 g
s
.714 .522 .629 r
.54968 .20849 m .54708 .2128 L .55056 .21292 L closepath p F P
0 g
s
.72 .616 .741 r
.5644 .29321 m .57399 .28505 L p .56262 .27449 L F P
0 g
s
.72 .616 .741 r
.54671 .29181 m .5644 .29321 L p .56262 .27449 L F P
0 g
s
.739 .566 .659 r
.58426 .22601 m .5822 .22908 L .58514 .22942 L closepath p F P
0 g
s
0 .224 .743 r
.20862 .86471 m .20618 .86104 L p .2136 .86498 L F P
0 g
s
0 .224 .743 r
.2136 .86498 m .2171 .8716 L .20862 .86471 L p F P
0 g
s
.115 .445 .88 r
.23529 .88457 m .2209 .87807 L .2171 .8716 L p F P
0 g
s
.098 .462 .888 r
.2209 .87807 m .23529 .88457 L .23784 .88706 L p F P
0 g
s
.787 .46 0 r
.19512 .84051 m .19234 .83064 L .18964 .8245 L closepath p F P
0 g
s
.823 .478 0 r
.19234 .83064 m .19512 .84051 L .19522 .84075 L p F P
0 g
s
.431 .503 .833 r
.69957 .86416 m .69334 .86226 L .69645 .85768 L closepath p F P
0 g
s
.468 .483 .791 r
.69383 .85227 m .69645 .85768 L .69334 .86226 L p F P
0 g
s
.672 .487 .628 r
.49268 .21197 m .49136 .21364 L .49295 .21348 L closepath p F P
0 g
s
.92 .881 .78 r
.37337 .84017 m .38007 .83055 L .37671 .82395 L p F P
0 g
s
.745 .609 .706 r
.59167 .24491 m .59036 .2464 L .59549 .26134 L p F P
0 g
s
.74 .606 .708 r
.59036 .2464 m .57876 .25908 L .59549 .26134 L closepath p F P
0 g
s
.693 .594 .74 r
.48847 .29002 m .48957 .29296 L .51545 .29148 L p F P
0 g
s
.777 .95 .619 r
.84311 .86409 m .84839 .85692 L .84583 .86213 L closepath p F P
0 g
s
.755 .871 .446 r
.85576 .84358 m .84839 .85692 L .84583 .86213 L p F P
0 g
s
.129 .283 .754 r
.65812 .79092 m .6559 .79884 L .6666 .80711 L p F P
0 g
s
.286 .354 .758 r
.64876 .78237 m .65812 .79092 L .6559 .79884 L p F P
0 g
s
.35 .593 .937 r
.73868 .62488 m .74047 .62524 L .73519 .61824 L p F P
0 g
s
.35 .593 .937 r
.73519 .61824 m .73444 .61809 L .73868 .62488 L p F P
0 g
s
.734 .629 .742 r
.57 .2751 m .57399 .28505 L .58325 .2768 L closepath p F P
0 g
s
.72 .616 .741 r
.57399 .28505 m .57 .2751 L .56262 .27449 L p F P
0 g
s
.197 .303 .747 r
.64128 .76713 m .6415 .76592 L p .64876 .78237 L F P
0 g
s
.119 .249 .724 r
.64128 .76713 m .64036 .76473 L .6415 .76592 L closepath p F P
0 g
s
.672 .371 .455 r
.53443 .64055 m .51372 .6406 L .51238 .64977 L p F P
0 g
s
.556 .267 .431 r
.51071 .6501 m .51238 .64977 L .51372 .6406 L p F P
0 g
s
.677 .516 .66 r
.49593 .2266 m .47672 .22842 L .49136 .21364 L p F P
0 g
s
.677 .516 .66 r
.49136 .21364 m .49295 .21348 L .49593 .2266 L p F P
0 g
s
.749 .592 .682 r
.59167 .24491 m .58975 .24461 L .58514 .22942 L p F P
0 g
s
.738 .586 .686 r
.5822 .22908 m .58514 .22942 L .58975 .24461 L p F P
0 g
s
.35 .046 .302 r
.46351 .68077 m .46577 .67218 L .48604 .66333 L p F P
0 g
s
.341 .048 .314 r
.48783 .65444 m .48604 .66333 L .46577 .67218 L p F P
0 g
s
.672 .371 .455 r
.51238 .64977 m .53885 .64972 L .53443 .64055 L p F P
0 g
s
.817 .468 .397 r
.57082 .65634 m .55732 .65229 L .56117 .66173 L p F P
0 g
s
.817 .468 .397 r
.56117 .66173 m .57401 .66599 L .57082 .65634 L p F P
0 g
s
.691 .593 .742 r
.48285 .27507 m .48847 .29002 L .51087 .27442 L p F P
0 g
s
.693 .594 .74 r
.51697 .29039 m .51087 .27442 L .48847 .29002 L p F P
0 g
s
.693 .594 .74 r
.51545 .29148 m .51697 .29039 L p .48847 .29002 L F P
0 g
s
.675 .581 .742 r
.48847 .29002 m .48285 .27507 L .47953 .2755 L p F P
0 g
s
.733 .612 .724 r
.57 .2751 m .58325 .2768 L p .57876 .25908 L F P
0 g
s
.693 .526 .657 r
.52118 .21277 m .52107 .21229 L .49295 .21348 L p F P
0 g
s
.693 .526 .657 r
.50968 .22602 m .52118 .21277 L p .49295 .21348 L F P
0 g
s
.693 .526 .657 r
.49295 .21348 m .49593 .2266 L .50968 .22602 L p F P
0 g
s
.772 .835 .9 r
.31221 .88617 m .29918 .89416 L .3062 .89906 L p F P
0 g
s
.772 .835 .9 r
.3062 .89906 m .31677 .89225 L .31221 .88617 L p F P
0 g
s
.678 .536 .684 r
.46894 .22923 m .47022 .23407 L .47672 .22842 L closepath p F P
0 g
s
.07 .234 .726 r
.6415 .76592 m .64036 .76473 L .63444 .75035 L p F P
0 g
s
.585 .775 .97 r
.54921 .57481 m .5511 .57655 L .55449 .57583 L closepath p F P
0 g
s
.618 .759 .947 r
.5511 .57655 m .54921 .57481 L .53261 .57424 L p F P
0 g
s
.639 .853 .981 r
.45275 .57132 m .43051 .57906 L .43705 .58297 L p F P
0 g
s
.639 .853 .981 r
.43705 .58297 m .45921 .57528 L .45275 .57132 L p F P
0 g
s
.745 .609 .706 r
.58975 .24461 m .59036 .2464 L .59167 .24491 L closepath p F P
0 g
s
.77 .945 .936 r
.32147 .61279 m .29932 .62716 L .30665 .62888 L p F P
0 g
s
.77 .945 .936 r
.322 .6129 m .32147 .61279 L p .30665 .62888 L F P
0 g
s
.77 .945 .936 r
.30665 .62888 m .31513 .62328 L .322 .6129 L p F P
0 g
s
.783 .937 .93 r
.29169 .63239 m .29932 .62716 L .30665 .62888 L p F P
0 g
s
.727 .574 .682 r
.57131 .24246 m .5822 .22908 L .56086 .22697 L p F P
0 g
s
.738 .586 .686 r
.58975 .24461 m .57131 .24246 L .5822 .22908 L p F P
0 g
s
.73 .594 .704 r
.59036 .2464 m .58975 .24461 L .57131 .24246 L p F P
0 g
s
.73 .594 .704 r
.57876 .25908 m .59036 .2464 L p .57131 .24246 L F P
0 g
s
.271 .49 .886 r
.80415 .6694 m .8022 .6622 L .78656 .65591 L p F P
0 g
s
.25 .489 .89 r
.78407 .64879 m .78656 .65591 L .8022 .6622 L p F P
0 g
s
.322 .539 .908 r
.77534 .64611 m .78407 .64879 L .78656 .65591 L p F P
0 g
s
.729 .555 .656 r
.56086 .22697 m .5539 .22642 L .55056 .21292 L p F P
0 g
s
.716 .547 .66 r
.54708 .2128 m .55056 .21292 L .5539 .22642 L p F P
0 g
s
.03 .219 .724 r
.64981 .77467 m .64876 .78237 L .65812 .79092 L p F P
0 g
s
.197 .303 .747 r
.6415 .76592 m .64981 .77467 L .64876 .78237 L p F P
0 g
s
.677 .533 .682 r
.47672 .22842 m .47022 .23407 L .47264 .24331 L p F P
0 g
s
.706 .537 .658 r
.537 .22583 m .54708 .2128 L .52156 .2123 L p F P
0 g
s
.716 .547 .66 r
.5539 .22642 m .537 .22583 L .54708 .2128 L p F P
0 g
s
.399 .647 .957 r
.7059 .60836 m .70499 .60827 L .69922 .60183 L p F P
0 g
s
.72 .616 .741 r
.56262 .27449 m .5455 .28872 L .54671 .29181 L p F P
0 g
s
.712 .613 .744 r
.5455 .28872 m .54174 .29167 L .54671 .29181 L closepath p F P
0 g
s
.677 .533 .682 r
.4987 .23682 m .49593 .2266 L .47672 .22842 L p F P
0 g
s
.677 .533 .682 r
.49369 .24136 m .4987 .23682 L p .47672 .22842 L F P
0 g
s
.677 .533 .682 r
.47264 .24331 m .49369 .24136 L p .47672 .22842 L F P
0 g
s
.709 .606 .739 r
.54174 .29167 m .5455 .28872 L p .51697 .29039 L F P
0 g
s
.709 .606 .739 r
.51697 .29039 m .51735 .29139 L .54174 .29167 L p F P
0 g
s
.353 .583 .93 r
.74047 .62524 m .75939 .62938 L .76304 .6363 L p F P
0 g
s
.337 .586 .935 r
.75939 .62938 m .74047 .62524 L .73519 .61824 L p F P
0 g
s
.67 .811 .951 r
.29211 .88928 m .27049 .89662 L .27758 .90212 L p F P
0 g
s
.67 .811 .951 r
.27758 .90212 m .29918 .89416 L .29211 .88928 L p F P
0 g
s
.61 .812 .977 r
.48785 .57277 m .49261 .57643 L .50319 .57508 L p F P
0 g
s
.552 .722 .953 r
.74001 .89598 m .76373 .89369 L .76892 .89982 L p F P
0 g
s
.55 .649 .9 r
.75846 .8869 m .76373 .89369 L .74001 .89598 L p F P
0 g
s
.55 .649 .9 r
.7375 .88756 m .75846 .8869 L p .74001 .89598 L F P
0 g
s
.55 .649 .9 r
.74001 .89598 m .73574 .88943 L .7375 .88756 L p F P
0 g
s
0 0 .413 r
.86609 .77445 m .86435 .78204 L .86664 .79272 L p F P
0 g
s
0 0 .537 r
.86435 .78204 m .86609 .77445 L .8621 .76426 L p F P
0 g
s
.935 .967 .734 r
.21 .71872 m .20156 .7318 L .20145 .72344 L p F P
0 g
s
.935 .967 .734 r
.21005 .71145 m .21 .71872 L p .20145 .72344 L F P
0 g
s
.696 .599 .744 r
.51697 .29039 m .51545 .29148 L .51735 .29139 L closepath p F P
0 g
s
.707 .54 .659 r
.52107 .21229 m .52118 .21277 L .52156 .2123 L closepath p F P
0 g
s
.706 .537 .658 r
.52422 .22558 m .537 .22583 L p .52156 .2123 L F P
0 g
s
.706 .537 .658 r
.52156 .2123 m .52118 .21277 L .52422 .22558 L p F P
0 g
s
0 .224 .743 r
.20618 .86104 m .20407 .85671 L .2136 .86498 L p F P
0 g
s
0 0 .522 r
.20407 .85671 m .20618 .86104 L .20179 .85359 L closepath p F P
0 g
s
.39 .63 .949 r
.7059 .60836 m .72949 .61144 L .73444 .61809 L p F P
0 g
s
.378 .635 .955 r
.7059 .60836 m .72949 .61144 L .72382 .60495 L p F P
0 g
s
.378 .635 .955 r
.72382 .60495 m .70052 .60196 L .7059 .60836 L p F P
0 g
s
.399 .647 .957 r
.69922 .60183 m .70052 .60196 L .7059 .60836 L p F P
0 g
s
.717 .615 .742 r
.5455 .28872 m .56262 .27449 L .53963 .27304 L p F P
0 g
s
.717 .615 .742 r
.53963 .27304 m .53943 .27319 L .5455 .28872 L p F P
0 g
s
.709 .606 .739 r
.5455 .28872 m .53943 .27319 L .51697 .29039 L p F P
0 g
s
.697 .532 .66 r
.52118 .21277 m .50968 .22602 L .52422 .22558 L closepath p F P
0 g
s
.671 .563 .725 r
.47953 .2755 m .48235 .27359 L p .47037 .25953 L F P
0 g
s
.676 .568 .726 r
.48235 .27359 m .47953 .2755 L .48285 .27507 L closepath p F P
0 g
s
.702 .602 .742 r
.51697 .29039 m .53943 .27319 L p .51266 .27309 L F P
0 g
s
.702 .602 .742 r
.51266 .27309 m .51087 .27442 L .51697 .29039 L p F P
0 g
s
.671 .547 .706 r
.47626 .25527 m .47037 .25953 L .47725 .25856 L closepath p F P
0 g
s
.671 .563 .725 r
.48235 .27359 m .47725 .25856 L .47037 .25953 L p F P
0 g
s
0 .143 .682 r
.6413 .75847 m .6415 .76592 L .64981 .77467 L p F P
0 g
s
.07 .234 .726 r
.63444 .75035 m .6413 .75847 L .6415 .76592 L p F P
0 g
s
.564 .778 .979 r
.55449 .57583 m .57378 .57212 L p .5451 .57122 L F P
0 g
s
.564 .778 .979 r
.5451 .57122 m .54921 .57481 L .55449 .57583 L p F P
0 g
s
.598 .767 .96 r
.55449 .57583 m .57378 .57212 L .57965 .57734 L p F P
0 g
s
.733 .612 .724 r
.57876 .25908 m .56797 .26954 L .57 .2751 L p F P
0 g
s
.726 .609 .726 r
.56797 .26954 m .56262 .27449 L .57 .2751 L closepath p F P
0 g
s
.526 .766 .985 r
.59673 .56911 m .57378 .57212 L .57965 .57734 L p F P
0 g
s
.526 .766 .985 r
.57965 .57734 m .60253 .57428 L .59673 .56911 L p F P
0 g
s
.533 .752 .976 r
.60828 .57965 m .60253 .57428 L .57965 .57734 L p F P
0 g
s
.82 .418 .287 r
.58496 .67077 m .58919 .68019 L .57825 .67541 L p F P
0 g
s
.82 .418 .287 r
.57771 .66777 m .58496 .67077 L p .57825 .67541 L F P
0 g
s
.881 .949 .593 r
.41821 .7499 m .4216 .74097 L .41302 .75431 L p F P
0 g
s
.881 .949 .593 r
.41302 .75431 m .41107 .76277 L .41821 .7499 L p F P
0 g
s
.892 .63 .116 r
.18904 .8213 m .1883 .81321 L .18743 .81083 L closepath p F P
0 g
s
.918 .639 .149 r
.1883 .81321 m .18904 .8213 L .18964 .8245 L p F P
0 g
s
.757 .923 .944 r
.322 .6129 m .32866 .61503 L .31513 .62328 L closepath p F P
0 g
s
.69 .575 .722 r
.48235 .27359 m .48285 .27507 L .51038 .27313 L p F P
0 g
s
.691 .593 .742 r
.51087 .27442 m .51038 .27313 L .48285 .27507 L p F P
0 g
s
.92 .881 .78 r
.37671 .82395 m .3665 .83775 L .37337 .84017 L p F P
0 g
s
.871 .891 .845 r
.37337 .84017 m .36938 .84454 L .36638 .83788 L p F P
0 g
s
.871 .891 .845 r
.36638 .83788 m .3665 .83775 L .37337 .84017 L p F P
0 g
s
.687 .575 .724 r
.47725 .25856 m .48235 .27359 L .50478 .25695 L p F P
0 g
s
.69 .575 .722 r
.51038 .27313 m .50478 .25695 L .48235 .27359 L p F P
0 g
s
.72 .874 .468 r
.42187 .74055 m .4295 .72787 L .42648 .73402 L closepath p F P
0 g
s
.672 .853 .449 r
.4216 .74097 m .42187 .74055 L .42648 .73402 L p F P
0 g
s
.683 .556 .705 r
.47264 .24331 m .47626 .25527 L .49369 .24136 L closepath p F P
0 g
s
.757 .842 .915 r
.32824 .88512 m .31677 .89225 L .31221 .88617 L p F P
0 g
s
.73 .594 .704 r
.56352 .25739 m .57876 .25908 L p .57131 .24246 L F P
0 g
s
.733 .612 .724 r
.56352 .25739 m .56797 .26954 L .57876 .25908 L closepath p F P
0 g
s
.875 .861 .824 r
.36938 .84454 m .36638 .83788 L .35219 .8529 L p F P
0 g
s
.875 .861 .824 r
.35219 .8529 m .35629 .85921 L .36938 .84454 L p F P
0 g
s
0 0 0 r
.44483 .70183 m .44492 .7016 L .44471 .70197 L closepath p F P
0 g
s
0 0 .506 r
.63444 .75035 m .63394 .74954 L .63361 .74856 L closepath p F P
0 g
s
0 0 .493 r
.63394 .74954 m .63361 .74856 L .62855 .73759 L p F P
0 g
s
.661 .869 .978 r
.40842 .58771 m .43051 .57906 L p .41303 .57964 L F P
0 g
s
.661 .869 .978 r
.41303 .57964 m .40338 .58498 L .40842 .58771 L p F P
0 g
s
.456 .534 .848 r
.7104 .87615 m .72909 .87874 L .72354 .86931 L p F P
0 g
s
.456 .534 .848 r
.72354 .86931 m .71651 .86772 L .7104 .87615 L p F P
0 g
s
.505 .555 .841 r
.69957 .86416 m .71651 .86772 L .7104 .87615 L p F P
0 g
s
.682 .554 .703 r
.49369 .24136 m .47626 .25527 L .47725 .25856 L p F P
0 g
s
.722 .607 .728 r
.56797 .26954 m .56262 .27449 L p .55747 .25698 L F P
0 g
s
.722 .607 .728 r
.55747 .25698 m .56352 .25739 L .56797 .26954 L p F P
0 g
s
0 0 0 r
.44471 .70197 m .44483 .70183 L .44152 .70966 L p F P
0 g
s
0 0 0 r
.44152 .70966 m .43717 .71488 L .44471 .70197 L p F P
0 g
s
.722 .607 .728 r
.56262 .27449 m .53963 .27304 L .55747 .25698 L p F P
0 g
s
.728 .575 .683 r
.5539 .22642 m .55582 .23298 L .56086 .22697 L closepath p F P
0 g
s
.727 .574 .682 r
.5582 .24121 m .57131 .24246 L p .56086 .22697 L F P
0 g
s
.727 .574 .682 r
.56086 .22697 m .55582 .23298 L .5582 .24121 L p F P
0 g
s
.55 .244 .401 r
.48604 .66333 m .48783 .65444 L .51071 .6501 L p F P
0 g
s
.682 .554 .703 r
.47725 .25856 m .50456 .25632 L p .49369 .24136 L F P
0 g
s
.687 .575 .724 r
.50478 .25695 m .50456 .25632 L .47725 .25856 L p F P
0 g
s
0 0 .034 r
.44483 .70183 m .4611 .68931 L p .45077 .70268 L F P
0 g
s
0 0 .034 r
.45077 .70268 m .44152 .70966 L .44483 .70183 L p F P
0 g
s
0 0 0 r
.46351 .68077 m .4611 .68931 L .44483 .70183 L p F P
0 g
s
.61 .812 .977 r
.50319 .57508 m .51647 .57146 L p .48785 .57277 L F P
0 g
s
.615 .798 .97 r
.51647 .57146 m .50319 .57508 L .51925 .57382 L closepath p F P
0 g
s
.731 .595 .704 r
.5582 .24121 m .56191 .25248 L .57131 .24246 L closepath p F P
0 g
s
.73 .594 .704 r
.57131 .24246 m .56191 .25248 L .56352 .25739 L p F P
0 g
s
.939 .917 .766 r
.3957 .79667 m .39438 .78933 L .38547 .80283 L p F P
0 g
s
.939 .917 .766 r
.38948 .807 m .3957 .79667 L p .38547 .80283 L F P
0 g
s
.695 .548 .682 r
.49593 .2266 m .4987 .23682 L .50968 .22602 L closepath p F P
0 g
s
.232 .444 .861 r
.81929 .68365 m .81602 .682 L .81081 .67281 L p F P
0 g
s
.711 .559 .681 r
.55582 .23298 m .5539 .22642 L .537 .22583 L p F P
0 g
s
.598 .791 .973 r
.5451 .57122 m .53261 .57424 L .54921 .57481 L closepath p F P
0 g
s
.882 .462 .198 r
.59777 .68563 m .58919 .68019 L .59361 .68965 L p F P
0 g
s
.882 .462 .198 r
.59361 .68965 m .6019 .69516 L .59777 .68563 L p F P
0 g
s
0 .138 .68 r
.6413 .75847 m .63444 .75035 L .63361 .74856 L p F P
0 g
s
.304 .539 .913 r
.78407 .64879 m .77534 .64611 L .77013 .63843 L p F P
0 g
s
.694 .546 .681 r
.52726 .23647 m .52422 .22558 L .50968 .22602 L p F P
0 g
s
.694 .546 .681 r
.52367 .24014 m .52726 .23647 L p .50968 .22602 L F P
0 g
s
.694 .546 .681 r
.49978 .24085 m .52367 .24014 L p .50968 .22602 L F P
0 g
s
.694 .546 .681 r
.50968 .22602 m .4987 .23682 L .49978 .24085 L p F P
0 g
s
.808 .376 0 r
.61274 .7107 m .61779 .71703 L .62239 .72658 L p F P
0 g
s
.826 .403 0 r
.61779 .71703 m .61274 .7107 L .60846 .70113 L p F P
0 g
s
.711 .559 .681 r
.54894 .24075 m .55582 .23298 L p .537 .22583 L F P
0 g
s
.72 .57 .685 r
.55582 .23298 m .54894 .24075 L .5582 .24121 L closepath p F P
0 g
s
.876 .442 .061 r
.60846 .70113 m .6019 .69516 L .60626 .70472 L p F P
0 g
s
.876 .442 .061 r
.60626 .70472 m .61274 .7107 L .60846 .70113 L p F P
0 g
s
.976 .884 .516 r
.19059 .76448 m .18937 .75663 L .18567 .76839 L p F P
0 g
s
.976 .884 .516 r
.18567 .76839 m .18695 .77619 L .19059 .76448 L p F P
0 g
s
.201 .433 .861 r
.80415 .6694 m .81081 .67281 L .8056 .66396 L p F P
0 g
s
.201 .433 .861 r
.8056 .66396 m .8022 .6622 L .80415 .6694 L p F P
0 g
s
.712 .561 .682 r
.52422 .22558 m .52726 .23647 L .537 .22583 L closepath p F P
0 g
s
.711 .559 .681 r
.52826 .24006 m .54894 .24075 L p .537 .22583 L F P
0 g
s
.711 .559 .681 r
.537 .22583 m .52726 .23647 L .52826 .24006 L p F P
0 g
s
.677 .928 .971 r
.81262 .88895 m .79739 .89696 L .79249 .89312 L p F P
0 g
s
.618 .843 .985 r
.76892 .89982 m .79249 .89312 L .79739 .89696 L p F P
0 g
s
0 .138 .68 r
.63361 .74856 m .63225 .74241 L p .6413 .75847 L F P
0 g
s
0 .08 .64 r
.63361 .74856 m .62855 .73759 L .63225 .74241 L closepath p F P
0 g
s
.703 .603 .742 r
.51038 .27313 m .51087 .27442 L .51266 .27309 L closepath p F P
0 g
s
0 0 0 r
.86041 .8331 m .86192 .82716 L p .85576 .84358 L F P
0 g
s
0 0 0 r
.85576 .84358 m .85938 .83581 L .86041 .8331 L p F P
0 g
s
.738 .875 .461 r
.85938 .83581 m .85576 .84358 L .84839 .85692 L p F P
0 g
s
.597 .792 .974 r
.53261 .57424 m .5451 .57122 L p .51647 .57146 L F P
0 g
s
.597 .792 .974 r
.51647 .57146 m .51925 .57382 L .53261 .57424 L p F P
0 g
s
.724 .59 .706 r
.56191 .25248 m .55747 .25698 L .56352 .25739 L closepath p F P
0 g
s
.424 .682 .97 r
.67147 .59467 m .69263 .59558 L .68522 .58952 L p F P
0 g
s
.424 .682 .97 r
.68522 .58952 m .66597 .58875 L .67147 .59467 L p F P
0 g
s
.45 .695 .971 r
.65406 .58866 m .66597 .58875 L .67147 .59467 L p F P
0 g
s
.72 .588 .708 r
.56191 .25248 m .55747 .25698 L p .54894 .24075 L F P
0 g
s
.72 .588 .708 r
.54894 .24075 m .5582 .24121 L .56191 .25248 L p F P
0 g
s
.699 .585 .724 r
.51038 .27313 m .51266 .27309 L p .50559 .25629 L F P
0 g
s
.699 .585 .724 r
.50559 .25629 m .50478 .25695 L .51038 .27313 L p F P
0 g
s
0 0 .53 r
.86329 .75672 m .8621 .76426 L .86609 .77445 L p F P
0 g
s
0 .093 .62 r
.8621 .76426 m .86329 .75672 L .85769 .74703 L p F P
0 g
s
.232 .555 .933 r
.24242 .89143 m .24084 .891 L .23784 .88706 L closepath p F P
0 g
s
.699 .585 .724 r
.51266 .27309 m .53335 .25607 L p .50559 .25629 L F P
0 g
s
.706 .593 .727 r
.53335 .25607 m .51266 .27309 L .53937 .27303 L closepath p F P
0 g
s
.702 .602 .742 r
.53943 .27319 m .53937 .27303 L .51266 .27309 L p F P
0 g
s
.474 .528 .833 r
.71651 .86772 m .69957 .86416 L .69645 .85768 L p F P
0 g
s
.716 .614 .742 r
.53937 .27303 m .53943 .27319 L .53963 .27304 L closepath p F P
0 g
s
.683 .539 .683 r
.4987 .23682 m .49369 .24136 L .49978 .24085 L closepath p F P
0 g
s
.682 .554 .703 r
.50456 .25632 m .49978 .24085 L .49369 .24136 L p F P
0 g
s
.714 .597 .724 r
.53963 .27304 m .55747 .25698 L .53361 .25585 L p F P
0 g
s
.714 .597 .724 r
.53937 .27303 m .53963 .27304 L p .53361 .25585 L F P
0 g
s
.714 .597 .724 r
.53361 .25585 m .53335 .25607 L .53937 .27303 L p F P
0 g
s
.878 .862 .82 r
.35066 .86566 m .35629 .85921 L .35219 .8529 L p F P
0 g
s
.833 .856 .863 r
.33582 .86855 m .32127 .8808 L .32824 .88512 L p F P
0 g
s
.833 .856 .863 r
.32824 .88512 m .33992 .8748 L .33582 .86855 L p F P
0 g
s
.757 .842 .915 r
.31221 .88617 m .32127 .8808 L .32824 .88512 L p F P
0 g
s
.72 .588 .708 r
.55747 .25698 m .53361 .25585 L .54894 .24075 L p F P
0 g
s
0 0 .103 r
.86192 .82716 m .8633 .82334 L .86482 .81155 L p F P
0 g
s
0 0 .049 r
.8671 .80397 m .86482 .81155 L .8633 .82334 L p F P
0 g
s
0 0 .272 r
.86482 .81155 m .8671 .80397 L .86664 .79272 L p F P
0 g
s
0 0 .545 r
.20179 .85359 m .19522 .84075 L p .20115 .84984 L F P
0 g
s
0 0 .545 r
.20115 .84984 m .20407 .85671 L .20179 .85359 L p F P
0 g
s
.498 .743 .982 r
.60828 .57965 m .63139 .57769 L p .62509 .57234 L F P
0 g
s
.498 .743 .982 r
.62509 .57234 m .60253 .57428 L .60828 .57965 L p F P
0 g
s
.821 .866 .88 r
.35066 .86566 m .33992 .8748 L .33582 .86855 L p F P
0 g
s
.596 .801 .978 r
.79249 .89312 m .76892 .89982 L .76373 .89369 L p F P
0 g
s
.699 .568 .703 r
.50559 .25629 m .50456 .25632 L .49978 .24085 L p F P
0 g
s
.699 .568 .703 r
.49978 .24085 m .52367 .24014 L .50559 .25629 L p F P
0 g
s
0 0 0 r
.86041 .8331 m .8633 .82334 L .86192 .82716 L closepath p F P
0 g
s
.715 .581 .703 r
.52826 .24006 m .54894 .24075 L .53361 .25585 L p F P
0 g
s
.734 .921 .955 r
.32866 .61503 m .35069 .60244 L p .32277 .612 L F P
0 g
s
.734 .921 .955 r
.32277 .612 m .322 .6129 L .32866 .61503 L p F P
0 g
s
.7 .586 .725 r
.50456 .25632 m .50478 .25695 L .50559 .25629 L closepath p F P
0 g
s
.878 .862 .82 r
.35219 .8529 m .34374 .8621 L .35066 .86566 L p F P
0 g
s
.821 .866 .88 r
.33582 .86855 m .34374 .8621 L .35066 .86566 L p F P
0 g
s
.703 .574 .707 r
.53327 .25583 m .50559 .25629 L .52367 .24014 L p F P
0 g
s
.699 .585 .724 r
.53335 .25607 m .53327 .25583 L .50559 .25629 L p F P
0 g
s
.702 .554 .683 r
.52726 .23647 m .52367 .24014 L .52826 .24006 L closepath p F P
0 g
s
.955 .951 .678 r
.20156 .7318 m .20145 .72344 L .19443 .73615 L p F P
0 g
s
.955 .951 .678 r
.19443 .73615 m .19464 .74444 L .20156 .7318 L p F P
0 g
s
.431 .658 .956 r
.25618 .88505 m .26336 .89095 L .24242 .89143 L p F P
0 g
s
.431 .658 .956 r
.23674 .88469 m .25618 .88505 L p .24242 .89143 L F P
0 g
s
.431 .658 .956 r
.24242 .89143 m .23784 .88706 L .23674 .88469 L p F P
0 g
s
.916 .728 .234 r
.18655 .79506 m .18479 .78751 L .18424 .79843 L p F P
0 g
s
.916 .728 .234 r
.18424 .79843 m .18599 .80594 L .18655 .79506 L p F P
0 g
s
.703 .574 .707 r
.52367 .24014 m .52826 .24006 L .53327 .25583 L p F P
0 g
s
.824 .569 .016 r
.18743 .81083 m .18599 .80594 L .18722 .81638 L p F P
0 g
s
.824 .569 .016 r
.18904 .8213 m .18743 .81083 L p .18722 .81638 L F P
0 g
s
.709 .375 .41 r
.55732 .65229 m .56117 .66173 L .54398 .65876 L p F P
0 g
s
.709 .375 .41 r
.54164 .6499 m .55732 .65229 L p .54398 .65876 L F P
0 g
s
.715 .581 .703 r
.53361 .25585 m .53327 .25583 L .52826 .24006 L p F P
0 g
s
.715 .598 .725 r
.53327 .25583 m .53335 .25607 L .53361 .25585 L closepath p F P
0 g
s
.289 .542 .918 r
.76304 .6363 m .77013 .63843 L .76491 .63105 L p F P
0 g
s
.289 .542 .918 r
.76491 .63105 m .75939 .62938 L .76304 .6363 L p F P
0 g
s
.44 .701 .976 r
.66597 .58875 m .65406 .58866 L .6454 .58296 L p F P
0 g
s
.683 .902 .974 r
.39491 .58138 m .37276 .59136 L .37965 .59427 L p F P
0 g
s
.683 .902 .974 r
.37965 .59427 m .40172 .58423 L .39491 .58138 L p F P
0 g
s
.708 .898 .965 r
.37965 .59427 m .37276 .59136 L .35562 .59984 L p F P
0 g
s
.186 .384 .826 r
.81929 .68365 m .83103 .69129 L .83203 .69861 L p F P
0 g
s
.136 .369 .826 r
.81779 .67639 m .81929 .68365 L .83103 .69129 L p F P
0 g
s
.232 .444 .861 r
.81081 .67281 m .81779 .67639 L .81929 .68365 L p F P
0 g
s
.82 .418 .287 r
.57825 .67541 m .57568 .67038 L .57771 .66777 L p F P
0 g
s
.858 .474 .317 r
.57568 .67038 m .57401 .66599 L .57771 .66777 L closepath p F P
0 g
s
0 .076 .615 r
.85832 .73953 m .85769 .74703 L .86329 .75672 L p F P
0 g
s
.022 .177 .686 r
.85769 .74703 m .85832 .73953 L .85119 .73033 L p F P
0 g
s
.939 .917 .766 r
.38547 .80283 m .38673 .8071 L .38948 .807 L p F P
0 g
s
.921 .938 .798 r
.38673 .8071 m .38948 .807 L .38718 .81002 L closepath p F P
0 g
s
.922 .974 .708 r
.41107 .76277 m .41302 .75431 L .40444 .76769 L p F P
0 g
s
.922 .974 .708 r
.4057 .77233 m .41107 .76277 L p .40444 .76769 L F P
0 g
s
.887 .974 .83 r
.23215 .68366 m .23366 .68199 L .2334 .68341 L closepath p F P
0 g
s
.893 .971 .825 r
.22092 .69641 m .23215 .68366 L .2334 .68341 L p F P
0 g
s
.551 .651 .901 r
.73574 .88943 m .73459 .88768 L .7375 .88756 L closepath p F P
0 g
s
.474 .528 .833 r
.69645 .85768 m .6992 .85379 L p .71651 .86772 L F P
0 g
s
.439 .509 .834 r
.69645 .85768 m .69383 .85227 L .6992 .85379 L closepath p F P
0 g
s
0 0 0 r
.43717 .71488 m .44152 .70966 L .4381 .7175 L p F P
0 g
s
0 0 0 r
.4381 .7175 m .4295 .72787 L .43717 .71488 L p F P
0 g
s
.91 .947 .813 r
.38718 .81002 m .37671 .82395 L .37468 .8169 L p F P
0 g
s
.91 .947 .813 r
.38673 .8071 m .38718 .81002 L p .37468 .8169 L F P
0 g
s
.969 .926 .608 r
.19272 .74886 m .19464 .74444 L .1948 .74627 L closepath p F P
0 g
s
.971 .923 .607 r
.18937 .75663 m .19272 .74886 L .1948 .74627 L p F P
0 g
s
.12 .316 .786 r
.84264 .71418 m .84217 .70681 L .83203 .69861 L p F P
0 g
s
.085 .306 .786 r
.83103 .69129 m .83203 .69861 L .84217 .70681 L p F P
0 g
s
0 .168 .687 r
.85126 .72289 m .85119 .73033 L .85832 .73953 L p F P
0 g
s
.072 .25 .741 r
.85119 .73033 m .85126 .72289 L .84264 .71418 L p F P
0 g
s
.677 .928 .971 r
.8172 .88298 m .81262 .88895 L p .79249 .89312 L F P
0 g
s
.731 .955 .946 r
.81262 .88895 m .8172 .88298 L .82055 .88431 L closepath p F P
0 g
s
.855 .979 .861 r
.24921 .66668 m .23366 .68199 L .23599 .67261 L p F P
0 g
s
.855 .979 .861 r
.25064 .66158 m .24921 .66668 L p .23599 .67261 L F P
0 g
s
.843 .959 .885 r
.25064 .66158 m .25478 .66175 L .24921 .66668 L closepath p F P
0 g
s
.827 .963 .896 r
.25478 .66175 m .26812 .6503 L p .25237 .65698 L F P
0 g
s
.827 .963 .896 r
.25237 .65698 m .25064 .66158 L .25478 .66175 L p F P
0 g
s
.05 .251 .747 r
.84217 .70681 m .84264 .71418 L .85126 .72289 L p F P
0 g
s
.871 .987 .718 r
.84839 .85692 m .85175 .84927 L p .83967 .86513 L F P
0 g
s
.871 .987 .718 r
.83967 .86513 m .84311 .86409 L .84839 .85692 L p F P
0 g
s
.738 .875 .461 r
.84839 .85692 m .85175 .84927 L .85938 .83581 L p F P
0 g
s
.715 .921 .963 r
.35069 .60244 m .35562 .59984 L .35232 .60297 L closepath p F P
0 g
s
.556 .637 .886 r
.7375 .88756 m .73459 .88768 L .72909 .87874 L p F P
0 g
s
0 .2 .728 r
.20407 .85671 m .20115 .84984 L .2104 .8582 L p F P
0 g
s
0 .2 .728 r
.2104 .8582 m .2136 .86498 L .20407 .85671 L p F P
0 g
s
.824 .569 .016 r
.18722 .81638 m .18935 .82367 L .18904 .8213 L p F P
0 g
s
.862 .59 .058 r
.18935 .82367 m .18964 .8245 L .18904 .8213 L closepath p F P
0 g
s
.827 .963 .896 r
.26812 .6503 m .27128 .64253 L p .25237 .65698 L F P
0 g
s
.813 .952 .909 r
.27128 .64253 m .27712 .64328 L .26812 .6503 L closepath p F P
0 g
s
.473 .722 .979 r
.63704 .58329 m .6454 .58296 L .6358 .57751 L p F P
0 g
s
.473 .722 .979 r
.6358 .57751 m .63139 .57769 L .63704 .58329 L p F P
0 g
s
0 0 .545 r
.19522 .84075 m .19517 .84064 L .20115 .84984 L p F P
0 g
s
.685 .346 0 r
.19517 .84064 m .19522 .84075 L .19512 .84051 L closepath p F P
0 g
s
.882 .984 .823 r
.23215 .68366 m .23366 .68199 L .23599 .67261 L p F P
0 g
s
0 0 .273 r
.19512 .84051 m .18964 .8245 L p .19268 .83355 L F P
0 g
s
0 0 .273 r
.19268 .83355 m .19517 .84064 L .19512 .84051 L p F P
0 g
s
0 0 .51 r
.19517 .84064 m .19268 .83355 L .19854 .8428 L p F P
0 g
s
0 0 .51 r
.19854 .8428 m .20115 .84984 L .19517 .84064 L p F P
0 g
s
.812 .43 .331 r
.57401 .66599 m .56117 .66173 L .56545 .67114 L p F P
0 g
s
.812 .43 .331 r
.57568 .67038 m .57401 .66599 L p .56545 .67114 L F P
0 g
s
.55 .244 .401 r
.51071 .6501 m .51224 .65054 L p .48604 .66333 L F P
0 g
s
.546 .243 .405 r
.51224 .65054 m .51071 .6501 L .51238 .64977 L closepath p F P
0 g
s
.882 .984 .823 r
.23599 .67261 m .22409 .68546 L .23215 .68366 L p F P
0 g
s
.885 .978 .828 r
.23215 .68366 m .22092 .69641 L .22235 .68738 L p F P
0 g
s
.885 .978 .828 r
.22235 .68738 m .22409 .68546 L .23215 .68366 L p F P
0 g
s
.591 .828 .989 r
.50406 .56257 m .48154 .56848 L .48785 .57277 L p F P
0 g
s
.591 .828 .989 r
.48785 .57277 m .51029 .56686 L .50406 .56257 L p F P
0 g
s
.61 .812 .977 r
.51647 .57146 m .51029 .56686 L .48785 .57277 L p F P
0 g
s
.445 .505 .827 r
.6992 .85379 m .69383 .85227 L .68806 .83996 L p F P
0 g
s
.709 .375 .41 r
.54398 .65876 m .5409 .6531 L .54164 .6499 L p F P
0 g
s
.696 .362 .407 r
.5409 .6531 m .53885 .64972 L .54164 .6499 L closepath p F P
0 g
s
.335 .597 .943 r
.73444 .61809 m .73519 .61824 L .72989 .61152 L p F P
0 g
s
.335 .597 .943 r
.72989 .61152 m .72949 .61144 L .73444 .61809 L p F P
0 g
s
0 0 .273 r
.18964 .8245 m .18935 .82367 L .19268 .83355 L p F P
0 g
s
0 0 .237 r
.86841 .78516 m .86664 .79272 L .8671 .80397 L p F P
0 g
s
0 0 .413 r
.86664 .79272 m .86841 .78516 L .86609 .77445 L p F P
0 g
s
.57 .811 .99 r
.53296 .56189 m .51029 .56686 L .51647 .57146 L p F P
0 g
s
.57 .811 .99 r
.51647 .57146 m .53906 .56641 L .53296 .56189 L p F P
0 g
s
.597 .792 .974 r
.5451 .57122 m .53906 .56641 L .51647 .57146 L p F P
0 g
s
.828 .964 .895 r
.8172 .88298 m .82055 .88431 L .83578 .87162 L p F P
0 g
s
.629 .318 .425 r
.51238 .64977 m .53885 .64972 L p .51883 .65819 L F P
0 g
s
.629 .318 .425 r
.51883 .65819 m .51224 .65054 L .51238 .64977 L p F P
0 g
s
.629 .318 .425 r
.53885 .64972 m .5409 .6531 L p .51883 .65819 L F P
0 g
s
.764 .845 .912 r
.3087 .87974 m .29211 .88928 L .29918 .89416 L p F P
0 g
s
.764 .845 .912 r
.29918 .89416 m .31221 .88617 L .3087 .87974 L p F P
0 g
s
.794 .954 .921 r
.27712 .64328 m .29169 .63239 L p .27254 .64012 L F P
0 g
s
.794 .954 .921 r
.27254 .64012 m .27128 .64253 L .27712 .64328 L p F P
0 g
s
.773 .988 .754 r
.83578 .87162 m .83967 .86513 L .84311 .86409 L closepath p F P
0 g
s
.612 .845 .988 r
.47516 .56447 m .45275 .57132 L .45921 .57528 L p F P
0 g
s
.612 .845 .988 r
.45921 .57528 m .48154 .56848 L .47516 .56447 L p F P
0 g
s
.386 .652 .963 r
.70052 .60196 m .69922 .60183 L .69263 .59558 L p F P
0 g
s
.337 .586 .935 r
.73519 .61824 m .75511 .62259 L .75939 .62938 L p F P
0 g
s
.321 .589 .94 r
.75511 .62259 m .73519 .61824 L .72989 .61152 L p F P
0 g
s
.922 .974 .708 r
.40444 .76769 m .40373 .77354 L .4057 .77233 L p F P
0 g
s
.911 .979 .712 r
.40373 .77354 m .4057 .77233 L .40335 .77585 L closepath p F P
0 g
s
.516 .618 .892 r
.7375 .88756 m .75846 .8869 L .75311 .87955 L p F P
0 g
s
.516 .618 .892 r
.75311 .87955 m .74383 .87917 L .7375 .88756 L p F P
0 g
s
.556 .637 .886 r
.72909 .87874 m .74383 .87917 L .7375 .88756 L p F P
0 g
s
.828 .964 .895 r
.83578 .87162 m .83967 .86513 L p .8172 .88298 L F P
0 g
s
.655 .808 .957 r
.28497 .88437 m .26336 .89095 L .27049 .89662 L p F P
0 g
s
.655 .808 .957 r
.27049 .89662 m .29211 .88928 L .28497 .88437 L p F P
0 g
s
.904 .888 .806 r
.37671 .82395 m .37468 .8169 L .36328 .83117 L p F P
0 g
s
.904 .888 .806 r
.3665 .83775 m .37671 .82395 L p .36328 .83117 L F P
0 g
s
.09 .416 .864 r
.22815 .87714 m .2171 .8716 L .2136 .86498 L p F P
0 g
s
.115 .445 .88 r
.2171 .8716 m .22815 .87714 L .23529 .88457 L p F P
0 g
s
.642 .318 .408 r
.5105 .65847 m .51224 .65054 L .51883 .65819 L closepath p F P
0 g
s
.55 .244 .401 r
.51224 .65054 m .5105 .65847 L .48604 .66333 L p F P
0 g
s
.204 .437 .863 r
.81779 .67639 m .81081 .67281 L .8056 .66396 L p F P
0 g
s
.957 .933 .602 r
.19464 .74444 m .19443 .73615 L .18895 .74844 L p F P
0 g
s
.957 .933 .602 r
.19272 .74886 m .19464 .74444 L p .18895 .74844 L F P
0 g
s
.544 .793 .99 r
.56189 .5624 m .53906 .56641 L .5451 .57122 L p F P
0 g
s
.544 .793 .99 r
.5451 .57122 m .56786 .56715 L .56189 .5624 L p F P
0 g
s
.564 .778 .979 r
.57378 .57212 m .56786 .56715 L .5451 .57122 L p F P
0 g
s
.951 .821 .38 r
.18695 .77619 m .18567 .76839 L .18348 .77975 L p F P
0 g
s
.951 .821 .38 r
.18348 .77975 m .18479 .78751 L .18695 .77619 L p F P
0 g
s
.356 .044 .292 r
.46351 .68077 m .48407 .67214 L p .46535 .68756 L F P
0 g
s
.356 .044 .292 r
.46535 .68756 m .4611 .68931 L .46351 .68077 L p F P
0 g
s
.35 .046 .302 r
.48604 .66333 m .48407 .67214 L .46351 .68077 L p F P
0 g
s
0 0 .249 r
.18935 .82367 m .18722 .81638 L .19051 .82629 L p F P
0 g
s
0 0 .249 r
.19051 .82629 m .19268 .83355 L .18935 .82367 L p F P
0 g
s
.366 .64 .961 r
.70052 .60196 m .72382 .60495 L .71742 .59861 L p F P
0 g
s
.366 .64 .961 r
.71742 .59861 m .69512 .59583 L .70052 .60196 L p F P
0 g
s
.386 .652 .963 r
.69263 .59558 m .69512 .59583 L .70052 .60196 L p F P
0 g
s
.25 .489 .89 r
.8022 .6622 m .79966 .65509 L .78407 .64879 L p F P
0 g
s
.241 .497 .898 r
.78097 .64178 m .78407 .64879 L .79966 .65509 L p F P
0 g
s
.304 .539 .913 r
.77013 .63843 m .78097 .64178 L .78407 .64879 L p F P
0 g
s
.91 .977 .785 r
.22092 .69641 m .22235 .68738 L .21132 .70133 L p F P
0 g
s
.91 .977 .785 r
.21132 .70133 m .21014 .71024 L .22092 .69641 L p F P
0 g
s
.878 .988 .725 r
.40335 .77585 m .39438 .78933 L .39518 .7813 L p F P
0 g
s
.878 .988 .725 r
.40373 .77354 m .40335 .77585 L p .39518 .7813 L F P
0 g
s
.409 .643 .953 r
.23674 .88469 m .23784 .88706 L .23529 .88457 L closepath p F P
0 g
s
.709 .93 .963 r
.36578 .58876 m .34359 .60029 L .35069 .60244 L p F P
0 g
s
.709 .93 .963 r
.36754 .58928 m .36578 .58876 L p .35069 .60244 L F P
0 g
s
.709 .93 .963 r
.35069 .60244 m .35562 .59984 L .36754 .58928 L p F P
0 g
s
.734 .921 .955 r
.35069 .60244 m .34359 .60029 L .32277 .612 L p F P
0 g
s
.658 .889 .981 r
.40172 .58423 m .41303 .57964 L .40338 .58498 L closepath p F P
0 g
s
0 0 .049 r
.8633 .82334 m .86555 .8158 L .8671 .80397 L p F P
0 g
s
.754 .771 .267 r
.8633 .82334 m .86555 .8158 L p .85988 .83458 L F P
0 g
s
.754 .771 .267 r
.85988 .83458 m .86041 .8331 L .8633 .82334 L p F P
0 g
s
.599 .824 .434 r
.4295 .72787 m .4381 .7175 L p .42856 .73088 L F P
0 g
s
.599 .824 .434 r
.42187 .74055 m .4295 .72787 L p .42856 .73088 L F P
0 g
s
.848 .441 .266 r
.58919 .68019 m .57825 .67541 L .58323 .6847 L p F P
0 g
s
.848 .441 .266 r
.58323 .6847 m .59361 .68965 L .58919 .68019 L p F P
0 g
s
.634 .861 .985 r
.44622 .56757 m .42389 .57537 L .43051 .57906 L p F P
0 g
s
.634 .861 .985 r
.43051 .57906 m .45275 .57132 L .44622 .56757 L p F P
0 g
s
.661 .869 .978 r
.43051 .57906 m .42389 .57537 L .41303 .57964 L p F P
0 g
s
.33 .433 .816 r
.68225 .82739 m .67569 .82313 L p .68595 .83885 L F P
0 g
s
.255 .387 .804 r
.68225 .82739 m .67569 .82313 L .67721 .8165 L closepath p F P
0 g
s
.256 .387 .804 r
.67642 .81479 m .6666 .80711 L p .67569 .82313 L F P
0 g
s
.256 .387 .804 r
.67569 .82313 m .67721 .8165 L .67642 .81479 L p F P
0 g
s
.794 .954 .921 r
.29169 .63239 m .29509 .62626 L p .27254 .64012 L F P
0 g
s
.782 .941 .93 r
.29509 .62626 m .29932 .62716 L .29169 .63239 L closepath p F P
0 g
s
.13 .285 .755 r
.6666 .80711 m .67642 .81479 L .67058 .8024 L p F P
0 g
s
.13 .285 .755 r
.67058 .8024 m .6675 .79957 L .6666 .80711 L p F P
0 g
s
.129 .283 .754 r
.6666 .80711 m .6675 .79957 L .65812 .79092 L p F P
0 g
s
.939 .917 .767 r
.38255 .80723 m .38547 .80283 L .38673 .8071 L closepath p F P
0 g
s
.91 .947 .813 r
.37468 .8169 m .38255 .80723 L .38673 .8071 L p F P
0 g
s
.329 .432 .815 r
.68806 .83996 m .68595 .83885 L .68668 .83697 L closepath p F P
0 g
s
.33 .433 .816 r
.68595 .83885 m .68668 .83697 L .68225 .82739 L p F P
0 g
s
.284 .539 .917 r
.78097 .64178 m .77013 .63843 L .76491 .63105 L p F P
0 g
s
.932 .97 .736 r
.20886 .71214 m .21014 .71024 L .21005 .71145 L closepath p F P
0 g
s
.935 .967 .734 r
.20145 .72344 m .20886 .71214 L .21005 .71145 L p F P
0 g
s
.034 .257 .756 r
.65813 .78352 m .65812 .79092 L .6675 .79957 L p F P
0 g
s
.03 .219 .724 r
.65812 .79092 m .65813 .78352 L .64981 .77467 L p F P
0 g
s
.516 .771 .989 r
.59089 .56413 m .56786 .56715 L .57378 .57212 L p F P
0 g
s
.516 .771 .989 r
.57378 .57212 m .59673 .56911 L .59089 .56413 L p F P
0 g
s
.957 .933 .602 r
.18895 .74844 m .18909 .75348 L .19272 .74886 L p F P
0 g
s
.969 .924 .603 r
.18909 .75348 m .19272 .74886 L .18937 .75663 L closepath p F P
0 g
s
.746 .849 .927 r
.32127 .8808 m .31221 .88617 L .3087 .87974 L p F P
0 g
s
.705 .907 .967 r
.36754 .58928 m .37276 .59136 L .35562 .59984 L closepath p F P
0 g
s
.879 .449 .162 r
.6019 .69516 m .59361 .68965 L .59824 .69913 L p F P
0 g
s
.879 .449 .162 r
.59824 .69913 m .60626 .70472 L .6019 .69516 L p F P
0 g
s
0 .115 .667 r
.64882 .76745 m .64981 .77467 L .65813 .78352 L p F P
0 g
s
0 .143 .682 r
.64981 .77467 m .64882 .76745 L .6413 .75847 L p F P
0 g
s
.537 .224 .384 r
.48407 .67214 m .48604 .66333 L .5105 .65847 L p F P
0 g
s
.761 .942 .941 r
.29932 .62716 m .32147 .61279 L p .29856 .62134 L F P
0 g
s
.761 .942 .941 r
.29856 .62134 m .29509 .62626 L .29932 .62716 L p F P
0 g
s
0 0 .389 r
.86704 .76871 m .86609 .77445 L .86841 .78516 L p F P
0 g
s
0 0 .53 r
.86536 .76206 m .86329 .75672 L p .86609 .77445 L F P
0 g
s
0 0 .53 r
.86609 .77445 m .86704 .76871 L .86536 .76206 L p F P
0 g
s
.798 .412 .324 r
.57373 .67399 m .57568 .67038 L .57825 .67541 L closepath p F P
0 g
s
.812 .43 .331 r
.56545 .67114 m .57373 .67399 L .57568 .67038 L p F P
0 g
s
0 .024 .595 r
.63919 .75147 m .6413 .75847 L .64882 .76745 L p F P
0 g
s
0 .138 .68 r
.63225 .74241 m .63919 .75147 L .6413 .75847 L p F P
0 g
s
.716 .378 .404 r
.5396 .6583 m .5409 .6531 L .54398 .65876 L closepath p F P
0 g
s
.629 .318 .425 r
.5409 .6531 m .5396 .6583 L .51883 .65819 L p F P
0 g
s
.808 .376 0 r
.61692 .71958 m .61274 .7107 L p .62239 .72658 L F P
0 g
s
.86 .415 .018 r
.61274 .7107 m .60626 .70472 L .61085 .7143 L p F P
0 g
s
.86 .415 .018 r
.61692 .71958 m .61274 .7107 L p .61085 .7143 L F P
0 g
s
.793 .356 0 r
.62271 .72722 m .62239 .72658 L .61991 .72354 L closepath p F P
0 g
s
.808 .376 0 r
.62239 .72658 m .61991 .72354 L .61692 .71958 L p F P
0 g
s
.474 .528 .833 r
.6992 .85379 m .71794 .85946 L p .71651 .86772 L F P
0 g
s
.382 .475 .83 r
.6992 .85379 m .71794 .85946 L .71229 .8493 L p F P
0 g
s
.382 .475 .83 r
.71229 .8493 m .70326 .84571 L .6992 .85379 L p F P
0 g
s
.445 .505 .827 r
.68806 .83996 m .70326 .84571 L .6992 .85379 L p F P
0 g
s
.904 .888 .806 r
.36328 .83117 m .36634 .83771 L .3665 .83775 L p F P
0 g
s
.875 .908 .849 r
.36634 .83771 m .3665 .83775 L .36638 .83788 L closepath p F P
0 g
s
.867 .912 .859 r
.36638 .83788 m .35219 .8529 L .34913 .84623 L p F P
0 g
s
.867 .912 .859 r
.36634 .83771 m .36638 .83788 L p .34913 .84623 L F P
0 g
s
0 0 .497 r
.62888 .73569 m .63225 .74241 L .63919 .75147 L p F P
0 g
s
.596 .801 .978 r
.76373 .89369 m .78748 .88846 L .79249 .89312 L p F P
0 g
s
.572 .764 .969 r
.78748 .88846 m .76373 .89369 L .75846 .8869 L p F P
0 g
s
.796 .561 0 r
.18599 .80594 m .18424 .79843 L .18546 .80889 L p F P
0 g
s
.796 .561 0 r
.18546 .80889 m .18722 .81638 L .18599 .80594 L p F P
0 g
s
.903 .888 .806 r
.35953 .83591 m .36328 .83117 L .36634 .83771 L closepath p F P
0 g
s
.867 .912 .859 r
.34913 .84623 m .35953 .83591 L .36634 .83771 L p F P
0 g
s
.403 .477 .822 r
.70326 .84571 m .68806 .83996 L .68668 .83697 L p F P
0 g
s
.378 .613 .942 r
.23529 .88457 m .23674 .88469 L .23392 .87796 L p F P
0 g
s
.378 .613 .942 r
.23392 .87796 m .22815 .87714 L .23529 .88457 L p F P
0 g
s
.416 .688 .975 r
.66597 .58875 m .68522 .58952 L .67698 .58365 L p F P
0 g
s
.416 .688 .975 r
.67698 .58365 m .66044 .58305 L .66597 .58875 L p F P
0 g
s
.44 .701 .976 r
.6454 .58296 m .66044 .58305 L .66597 .58875 L p F P
0 g
s
.43 .707 .981 r
.66044 .58305 m .6454 .58296 L .6358 .57751 L p F P
0 g
s
.92 .977 .738 r
.21014 .71024 m .21132 .70133 L .20207 .71475 L p F P
0 g
s
.92 .977 .738 r
.20886 .71214 m .21014 .71024 L p .20207 .71475 L F P
0 g
s
.65 .898 .983 r
.41719 .57238 m .39491 .58138 L .40172 .58423 L p F P
0 g
s
.65 .898 .983 r
.42245 .57462 m .41719 .57238 L p .40172 .58423 L F P
0 g
s
.65 .898 .983 r
.40172 .58423 m .41303 .57964 L .42245 .57462 L p F P
0 g
s
.677 .928 .971 r
.79249 .89312 m .8159 .88235 L .8172 .88298 L p F P
0 g
s
.659 .892 .981 r
.8159 .88235 m .79249 .89312 L .78748 .88846 L p F P
0 g
s
.171 .427 .863 r
.8022 .6622 m .8056 .66396 L .8004 .65548 L p F P
0 g
s
.171 .427 .863 r
.8004 .65548 m .79966 .65509 L .8022 .6622 L p F P
0 g
s
.922 .975 .711 r
.39869 .77657 m .40444 .76769 L .40373 .77354 L closepath p F P
0 g
s
.878 .988 .725 r
.39518 .7813 m .39869 .77657 L .40373 .77354 L p F P
0 g
s
.829 .875 .878 r
.33282 .86191 m .31422 .87666 L .32127 .8808 L p F P
0 g
s
.829 .875 .878 r
.32127 .8808 m .33582 .86855 L .33282 .86191 L p F P
0 g
s
.746 .849 .927 r
.3087 .87974 m .31422 .87666 L .32127 .8808 L p F P
0 g
s
.92 .977 .738 r
.20207 .71475 m .20186 .71636 L .20886 .71214 L p F P
0 g
s
.934 .968 .731 r
.20186 .71636 m .20886 .71214 L .20145 .72344 L closepath p F P
0 g
s
.94 .954 .752 r
.39438 .78933 m .39518 .7813 L .38489 .79524 L p F P
0 g
s
.94 .954 .752 r
.38489 .79524 m .38547 .80283 L .39438 .78933 L p F P
0 g
s
0 0 .021 r
.44152 .70966 m .45077 .70268 L .43869 .71706 L p F P
0 g
s
0 0 .021 r
.43869 .71706 m .4381 .7175 L .44152 .70966 L p F P
0 g
s
.878 .887 .836 r
.34374 .8621 m .35219 .8529 L .34913 .84623 L p F P
0 g
s
.403 .477 .822 r
.68668 .83697 m .68959 .83077 L p .70326 .84571 L F P
0 g
s
.359 .451 .819 r
.68668 .83697 m .68225 .82739 L .68959 .83077 L closepath p F P
0 g
s
.458 .672 .956 r
.25618 .88505 m .23674 .88469 L .23392 .87796 L p F P
0 g
s
.489 .749 .987 r
.60253 .57428 m .62509 .57234 L .61235 .56777 L p F P
0 g
s
.489 .749 .987 r
.61235 .56777 m .59673 .56911 L .60253 .57428 L p F P
0 g
s
.763 .413 .391 r
.56117 .66173 m .54398 .65876 L .54938 .66781 L p F P
0 g
s
.763 .413 .391 r
.54938 .66781 m .56545 .67114 L .56117 .66173 L p F P
0 g
s
.528 .611 .879 r
.74383 .87917 m .72909 .87874 L .72354 .86931 L p F P
0 g
s
.812 .881 .896 r
.34374 .8621 m .33582 .86855 L .33282 .86191 L p F P
0 g
s
.845 .981 .867 r
.24699 .662 m .25237 .65698 L .25064 .66158 L closepath p F P
0 g
s
.855 .979 .861 r
.23599 .67261 m .24699 .662 L .25064 .66158 L p F P
0 g
s
.599 .824 .434 r
.42856 .73088 m .42171 .74076 L .42187 .74055 L p F P
0 g
s
.703 .874 .477 r
.42171 .74076 m .42187 .74055 L .4216 .74097 L closepath p F P
0 g
s
.713 .883 .491 r
.4216 .74097 m .42171 .74076 L .41666 .74737 L p F P
0 g
s
.713 .883 .491 r
.41666 .74737 m .41302 .75431 L .4216 .74097 L p F P
0 g
s
0 0 0 r
.85938 .83581 m .85988 .83458 L .86041 .8331 L closepath p F P
0 g
s
.269 .543 .922 r
.75939 .62938 m .76491 .63105 L .75968 .62397 L p F P
0 g
s
.269 .543 .922 r
.75968 .62397 m .75511 .62259 L .75939 .62938 L p F P
0 g
s
.878 .887 .836 r
.34913 .84623 m .33673 .85892 L .34374 .8621 L p F P
0 g
s
.812 .881 .896 r
.33282 .86191 m .33673 .85892 L .34374 .8621 L p F P
0 g
s
0 0 .5 r
.86536 .76206 m .86329 .75672 L .86348 .7547 L closepath p F P
0 g
s
0 .076 .615 r
.85901 .74077 m .85832 .73953 L p .86329 .75672 L F P
0 g
s
0 .076 .615 r
.86329 .75672 m .86348 .7547 L .85901 .74077 L p F P
0 g
s
.605 .833 .448 r
.42171 .74076 m .42856 .73088 L .41851 .74472 L p F P
0 g
s
.605 .833 .448 r
.41851 .74472 m .41666 .74737 L .42171 .74076 L p F P
0 g
s
.96 .884 .492 r
.18937 .75663 m .18909 .75348 L .18506 .76217 L p F P
0 g
s
.96 .884 .492 r
.18506 .76217 m .18567 .76839 L .18937 .75663 L p F P
0 g
s
.743 .945 .947 r
.32147 .61279 m .32277 .612 L .322 .6129 L closepath p F P
0 g
s
.433 .551 .875 r
.72354 .86931 m .71651 .86772 L .71917 .86162 L closepath p F P
0 g
s
.474 .528 .833 r
.71794 .85946 m .71917 .86162 L .71651 .86772 L p F P
0 g
s
0 0 0 r
.8689 .79643 m .8671 .80397 L .86555 .8158 L p F P
0 g
s
0 0 .237 r
.8671 .80397 m .8689 .79643 L .86841 .78516 L p F P
0 g
s
.793 .929 .558 r
.85988 .83458 m .85938 .83581 L .85175 .84927 L p F P
0 g
s
.136 .369 .826 r
.83103 .69129 m .82947 .68406 L .81779 .67639 L p F P
0 g
s
.104 .361 .826 r
.81571 .66923 m .81779 .67639 L .82947 .68406 L p F P
0 g
s
.204 .437 .863 r
.8056 .66396 m .81571 .66923 L .81779 .67639 L p F P
0 g
s
.736 .953 .946 r
.33462 .59922 m .31415 .61141 L .32147 .61279 L p F P
0 g
s
.736 .953 .946 r
.32147 .61279 m .32277 .612 L .33462 .59922 L p F P
0 g
s
.761 .942 .941 r
.32147 .61279 m .31415 .61141 L .29856 .62134 L p F P
0 g
s
.883 .711 .194 r
.18479 .78751 m .18348 .77975 L .18291 .7907 L p F P
0 g
s
.883 .711 .194 r
.18291 .7907 m .18424 .79843 L .18479 .78751 L p F P
0 g
s
.174 .43 .864 r
.81571 .66923 m .8056 .66396 L .8004 .65548 L p F P
0 g
s
.773 .948 .934 r
.8159 .88235 m .81813 .88088 L .8172 .88298 L closepath p F P
0 g
s
.828 .964 .895 r
.83887 .86516 m .81813 .88088 L .8172 .88298 L p F P
0 g
s
.828 .964 .895 r
.83967 .86513 m .83887 .86516 L p .8172 .88298 L F P
0 g
s
0 .031 .588 r
.85901 .74077 m .85832 .73953 L .85834 .73871 L closepath p F P
0 g
s
0 .168 .687 r
.85329 .72559 m .85126 .72289 L p .85832 .73953 L F P
0 g
s
0 .168 .687 r
.85832 .73953 m .85834 .73871 L .85329 .72559 L p F P
0 g
s
.726 .93 .958 r
.34359 .60029 m .32277 .612 L .33462 .59922 L p F P
0 g
s
.594 .14 0 r
.61991 .72354 m .61739 .72025 L p .62888 .73569 L F P
0 g
s
.616 .163 0 r
.61991 .72354 m .61692 .71958 L .61739 .72025 L closepath p F P
0 g
s
.93 .961 .653 r
.20145 .72344 m .19443 .73615 L .1948 .72759 L p F P
0 g
s
.93 .961 .653 r
.20186 .71636 m .20145 .72344 L p .1948 .72759 L F P
0 g
s
.678 .902 .976 r
.37276 .59136 m .39491 .58138 L p .37386 .58496 L F P
0 g
s
.678 .902 .976 r
.37386 .58496 m .36754 .58928 L .37276 .59136 L p F P
0 g
s
.359 .451 .819 r
.68959 .83077 m .68225 .82739 L .67721 .8165 L p F P
0 g
s
.775 .374 .294 r
.57825 .67541 m .58323 .6847 L .57013 .68051 L p F P
0 g
s
.775 .374 .294 r
.57373 .67399 m .57825 .67541 L p .57013 .68051 L F P
0 g
s
.085 .306 .786 r
.84217 .70681 m .84114 .69951 L .83103 .69129 L p F P
0 g
s
.067 .31 .793 r
.82947 .68406 m .83103 .69129 L .84114 .69951 L p F P
0 g
s
.94 .954 .753 r
.38255 .80723 m .38547 .80283 L .38489 .79524 L p F P
0 g
s
.656 .876 .98 r
.42245 .57462 m .42389 .57537 L .41303 .57964 L closepath p F P
0 g
s
.374 .657 .968 r
.69512 .59583 m .69263 .59558 L .68522 .58952 L p F P
0 g
s
.319 .601 .948 r
.72989 .61152 m .72949 .61144 L .72382 .60495 L p F P
0 g
s
.465 .728 .983 r
.62629 .57284 m .63139 .57769 L .6358 .57751 L closepath p F P
0 g
s
.498 .743 .982 r
.63139 .57769 m .62629 .57284 L .62509 .57234 L p F P
0 g
s
.814 .892 .472 r
.85671 .83863 m .8617 .82829 L .85988 .83458 L closepath p F P
0 g
s
.754 .771 .267 r
.86555 .8158 m .8617 .82829 L .85988 .83458 L p F P
0 g
s
.793 .929 .558 r
.85671 .83863 m .85988 .83458 L p .85175 .84927 L F P
0 g
s
0 .128 .666 r
.85329 .72559 m .85126 .72289 L .85109 .72003 L closepath p F P
0 g
s
.05 .251 .747 r
.84776 .71256 m .84217 .70681 L p .85126 .72289 L F P
0 g
s
.05 .251 .747 r
.85126 .72289 m .85109 .72003 L .84776 .71256 L p F P
0 g
s
.321 .589 .94 r
.72989 .61152 m .75017 .61593 L .75511 .62259 L p F P
0 g
s
.304 .592 .945 r
.72989 .61152 m .75017 .61593 L .74458 .6094 L p F P
0 g
s
.304 .592 .945 r
.74458 .6094 m .72457 .6051 L .72989 .61152 L p F P
0 g
s
.319 .601 .948 r
.72382 .60495 m .72457 .6051 L .72989 .61152 L p F P
0 g
s
0 0 .495 r
.86348 .7547 m .86374 .7493 L p .86724 .76694 L F P
0 g
s
0 0 .495 r
.86724 .76694 m .86536 .76206 L .86348 .7547 L p F P
0 g
s
0 .04 .592 r
.86348 .7547 m .85901 .74077 L .86374 .7493 L closepath p F P
0 g
s
0 .027 .586 r
.86374 .7493 m .85901 .74077 L .85834 .73871 L p F P
0 g
s
0 .027 .586 r
.85834 .73871 m .85822 .73217 L p .86374 .7493 L F P
0 g
s
0 .138 .669 r
.85834 .73871 m .85329 .72559 L .85822 .73217 L closepath p F P
0 g
s
0 .206 .724 r
.84217 .70681 m .84776 .71256 L .84234 .70078 L p F P
0 g
s
0 .206 .724 r
.84234 .70078 m .84114 .69951 L .84217 .70681 L p F P
0 g
s
.752 .857 .927 r
.30678 .8728 m .28497 .88437 L .29211 .88928 L p F P
0 g
s
.752 .857 .927 r
.29211 .88928 m .3087 .87974 L .30678 .8728 L p F P
0 g
s
.636 .801 .962 r
.27778 .87936 m .25618 .88505 L .26336 .89095 L p F P
0 g
s
.636 .801 .962 r
.26336 .89095 m .28497 .88437 L .27778 .87936 L p F P
0 g
s
.714 .368 .39 r
.54398 .65876 m .5396 .6583 L .53729 .66651 L p F P
0 g
s
.714 .368 .39 r
.53729 .66651 m .54938 .66781 L .54398 .65876 L p F P
0 g
s
.597 .831 .451 r
.41302 .75431 m .40444 .76769 L .40816 .75867 L p F P
0 g
s
.597 .831 .451 r
.41666 .74737 m .41302 .75431 L p .40816 .75867 L F P
0 g
s
.94 .954 .753 r
.38489 .79524 m .37552 .80804 L .38255 .80723 L p F P
0 g
s
.891 .971 .828 r
.38255 .80723 m .37468 .8169 L .37442 .80927 L p F P
0 g
s
.891 .971 .828 r
.37442 .80927 m .37552 .80804 L .38255 .80723 L p F P
0 g
s
.81 .976 .899 r
.26953 .64254 m .27254 .64012 L .27128 .64253 L closepath p F P
0 g
s
.827 .963 .896 r
.27128 .64253 m .26953 .64254 L .25237 .65698 L p F P
0 g
s
.638 .308 .396 r
.51883 .65819 m .5105 .65847 L .50842 .66706 L p F P
0 g
s
.537 .224 .384 r
.5105 .65847 m .50842 .66706 L .48407 .67214 L p F P
0 g
s
0 .19 .721 r
.20115 .84984 m .19854 .8428 L p .20803 .85246 L F P
0 g
s
0 .19 .721 r
.20803 .85246 m .2104 .8582 L .20115 .84984 L p F P
0 g
s
.653 .305 .371 r
.5396 .6583 m .51883 .65819 L .5267 .66645 L p F P
0 g
s
.653 .305 .371 r
.5267 .66645 m .53729 .66651 L .5396 .6583 L p F P
0 g
s
.558 .817 .994 r
.5268 .55759 m .50406 .56257 L .51029 .56686 L p F P
0 g
s
.558 .817 .994 r
.51029 .56686 m .53296 .56189 L .5268 .55759 L p F P
0 g
s
.582 .836 .993 r
.49776 .55853 m .47516 .56447 L .48154 .56848 L p F P
0 g
s
.582 .836 .993 r
.48154 .56848 m .50406 .56257 L .49776 .55853 L p F P
0 g
s
.638 .308 .396 r
.50842 .66706 m .5267 .66645 L .51883 .65819 L p F P
0 g
s
.772 .965 .927 r
.29188 .62597 m .29856 .62134 L .29509 .62626 L closepath p F P
0 g
s
.794 .954 .921 r
.29509 .62626 m .29188 .62597 L .27254 .64012 L p F P
0 g
s
.354 .646 .965 r
.69512 .59583 m .71742 .59861 L .71029 .59244 L p F P
0 g
s
.354 .646 .965 r
.71029 .59244 m .68969 .58995 L .69512 .59583 L p F P
0 g
s
.374 .657 .968 r
.68522 .58952 m .68969 .58995 L .69512 .59583 L p F P
0 g
s
.284 .539 .917 r
.76491 .63105 m .77726 .63488 L .78097 .64178 L p F P
0 g
s
.263 .54 .921 r
.77726 .63488 m .76491 .63105 L .75968 .62397 L p F P
0 g
s
0 0 .517 r
.19268 .83355 m .19051 .82629 L .19626 .83558 L p F P
0 g
s
0 0 .517 r
.19626 .83558 m .19854 .8428 L .19268 .83355 L p F P
0 g
s
.775 .374 .294 r
.57013 .68051 m .56996 .68025 L .57373 .67399 L p F P
0 g
s
.809 .418 .314 r
.56996 .68025 m .56545 .67114 L .57373 .67399 L closepath p F P
0 g
s
0 0 .503 r
.86704 .76871 m .86536 .76206 L .86724 .76694 L closepath p F P
0 g
s
.871 .987 .718 r
.85175 .84927 m .84023 .86375 L .83967 .86513 L p F P
0 g
s
.858 .995 .758 r
.85485 .84161 m .85175 .84927 L .84023 .86375 L p F P
0 g
s
.793 .929 .558 r
.85175 .84927 m .85485 .84161 L .85671 .83863 L p F P
0 g
s
.241 .497 .898 r
.79521 .64757 m .78097 .64178 L p .79966 .65509 L F P
0 g
s
.205 .485 .896 r
.78097 .64178 m .79521 .64757 L .79003 .64009 L p F P
0 g
s
.205 .485 .896 r
.79003 .64009 m .77726 .63488 L .78097 .64178 L p F P
0 g
s
.853 .433 .231 r
.59361 .68965 m .58323 .6847 L .58836 .69403 L p F P
0 g
s
.853 .433 .231 r
.58836 .69403 m .59824 .69913 L .59361 .68965 L p F P
0 g
s
.94 .886 .478 r
.18909 .75348 m .18895 .74844 L .18501 .76031 L p F P
0 g
s
.94 .886 .478 r
.18501 .76031 m .18506 .76217 L .18909 .75348 L p F P
0 g
s
.758 .921 .944 r
.81813 .88088 m .8159 .88235 L .81112 .87927 L p F P
0 g
s
.659 .892 .981 r
.78748 .88846 m .81112 .87927 L .8159 .88235 L p F P
0 g
s
.836 .999 .811 r
.83887 .86516 m .84023 .86375 L .83967 .86513 L closepath p F P
0 g
s
.533 .798 .994 r
.55587 .55787 m .53296 .56189 L .53906 .56641 L p F P
0 g
s
.533 .798 .994 r
.53906 .56641 m .56189 .5624 L .55587 .55787 L p F P
0 g
s
.606 .853 .991 r
.46871 .56067 m .44622 .56757 L .45275 .57132 L p F P
0 g
s
.606 .853 .991 r
.45275 .57132 m .47516 .56447 L .46871 .56067 L p F P
0 g
s
.063 .383 .846 r
.22102 .86912 m .2136 .86498 L .2104 .8582 L p F P
0 g
s
.09 .416 .864 r
.2136 .86498 m .22102 .86912 L .22815 .87714 L p F P
0 g
s
0 0 .2 r
.86913 .78094 m .86841 .78516 L .8689 .79643 L p F P
0 g
s
0 0 .389 r
.86841 .78516 m .86913 .78094 L .86704 .76871 L p F P
0 g
s
.758 .921 .944 r
.81112 .87927 m .82093 .87342 L .81813 .88088 L p F P
0 g
s
.774 .988 .894 r
.8344 .8643 m .82093 .87342 L .81813 .88088 L p F P
0 g
s
.774 .988 .894 r
.81813 .88088 m .83887 .86516 L .8344 .8643 L p F P
0 g
s
.346 .027 .274 r
.46071 .69063 m .46535 .68756 L .4611 .68931 L closepath p F P
0 g
s
0 0 .034 r
.4611 .68931 m .46071 .69063 L .45077 .70268 L p F P
0 g
s
.405 .708 .984 r
.6358 .57751 m .65487 .57758 L p .62571 .57231 L F P
0 g
s
.405 .708 .984 r
.62571 .57231 m .62629 .57284 L .6358 .57751 L p F P
0 g
s
.43 .707 .981 r
.6358 .57751 m .65487 .57758 L .66044 .58305 L p F P
0 g
s
.911 .923 .811 r
.37468 .8169 m .37442 .80927 L .36147 .82403 L p F P
0 g
s
.911 .923 .811 r
.36147 .82403 m .36328 .83117 L .37468 .8169 L p F P
0 g
s
.345 .578 .928 r
.22815 .87714 m .23392 .87796 L .23108 .87115 L p F P
0 g
s
.345 .578 .928 r
.23108 .87115 m .22102 .86912 L .22815 .87714 L p F P
0 g
s
0 .127 .665 r
.85822 .73217 m .85329 .72559 L .85109 .72003 L p F P
0 g
s
.528 .611 .879 r
.72354 .86931 m .74654 .87161 L .74383 .87917 L p F P
0 g
s
.498 .586 .874 r
.74654 .87161 m .72354 .86931 L .71917 .86162 L p F P
0 g
s
.572 .764 .969 r
.75846 .8869 m .78238 .88311 L .78748 .88846 L p F P
0 g
s
.546 .731 .961 r
.78238 .88311 m .75846 .8869 L .75311 .87955 L p F P
0 g
s
.834 .985 .871 r
.25237 .65698 m .25696 .64671 L .23924 .66284 L p F P
0 g
s
.834 .985 .871 r
.24699 .662 m .25237 .65698 L p .23924 .66284 L F P
0 g
s
.815 .978 .894 r
.26953 .64254 m .25237 .65698 L .25696 .64671 L p F P
0 g
s
0 0 .352 r
.86724 .76694 m .86704 .76871 L .86913 .78094 L p F P
0 g
s
.834 .985 .871 r
.23924 .66284 m .23917 .66301 L .24699 .662 L p F P
0 g
s
.854 .981 .86 r
.23917 .66301 m .24699 .662 L .23599 .67261 L closepath p F P
0 g
s
.749 .255 0 r
.61396 .7172 m .61692 .71958 L .61739 .72025 L closepath p F P
0 g
s
.86 .415 .018 r
.61085 .7143 m .61396 .7172 L .61692 .71958 L p F P
0 g
s
.359 .451 .819 r
.67721 .8165 m .67757 .81542 L p .68959 .83077 L F P
0 g
s
.311 .422 .813 r
.67721 .8165 m .67642 .81479 L .67757 .81542 L closepath p F P
0 g
s
.874 .434 .124 r
.60626 .70472 m .59824 .69913 L .60308 .70864 L p F P
0 g
s
.874 .434 .124 r
.60308 .70864 m .61085 .7143 L .60626 .70472 L p F P
0 g
s
0 0 .275 r
.18722 .81638 m .18546 .80889 L .18871 .81884 L p F P
0 g
s
0 0 .275 r
.18871 .81884 m .19051 .82629 L .18722 .81638 L p F P
0 g
s
.867 .986 .836 r
.23599 .67261 m .23917 .66301 L p .2251 .67782 L F P
0 g
s
.867 .986 .836 r
.22409 .68546 m .23599 .67261 L p .2251 .67782 L F P
0 g
s
.924 .811 .346 r
.18567 .76839 m .18506 .76217 L .18271 .7723 L p F P
0 g
s
.924 .811 .346 r
.18271 .7723 m .18348 .77975 L .18567 .76839 L p F P
0 g
s
.507 .777 .993 r
.56786 .56715 m .59089 .56413 L p .58359 .55955 L F P
0 g
s
.507 .777 .993 r
.58359 .55955 m .56189 .5624 L .56786 .56715 L p F P
0 g
s
.304 .422 .817 r
.67757 .81542 m .67642 .81479 L .67058 .8024 L p F P
0 g
s
.594 .14 0 r
.61739 .72025 m .62389 .72936 L .62888 .73569 L p F P
0 g
s
.732 .233 0 r
.61739 .72025 m .62389 .72936 L .61734 .72342 L p F P
0 g
s
.732 .233 0 r
.61396 .7172 m .61739 .72025 L p .61734 .72342 L F P
0 g
s
.629 .869 .987 r
.42245 .57462 m .42389 .57537 L .44622 .56757 L p F P
0 g
s
.94 .93 .572 r
.19443 .73615 m .1948 .72759 L .18924 .73994 L p F P
0 g
s
.94 .93 .572 r
.18924 .73994 m .18895 .74844 L .19443 .73615 L p F P
0 g
s
.801 .984 .894 r
.27907 .62915 m .26178 .64275 L .26953 .64254 L p F P
0 g
s
.801 .984 .894 r
.26953 .64254 m .27254 .64012 L .27907 .62915 L p F P
0 g
s
.815 .978 .894 r
.25696 .64671 m .26178 .64275 L .26953 .64254 L p F P
0 g
s
.297 0 .213 r
.45821 .69749 m .46071 .69063 L .46535 .68756 L p F P
0 g
s
.068 0 .112 r
.45821 .69749 m .46071 .69063 L .45077 .70268 L closepath p F P
0 g
s
.516 .196 .365 r
.48407 .67214 m .50842 .66706 L p .50118 .67668 L F P
0 g
s
.516 .196 .365 r
.50118 .67668 m .48329 .6753 L .48407 .67214 L p F P
0 g
s
.356 .044 .292 r
.48407 .67214 m .48329 .6753 L .46535 .68756 L p F P
0 g
s
0 .127 .665 r
.85109 .72003 m .85069 .71556 L p .85822 .73217 L F P
0 g
s
.016 .227 .735 r
.85109 .72003 m .84776 .71256 L .85069 .71556 L closepath p F P
0 g
s
.782 .967 .921 r
.29188 .62597 m .27254 .64012 L .27907 .62915 L p F P
0 g
s
.73 .853 .939 r
.31422 .87666 m .3087 .87974 L .30678 .8728 L p F P
0 g
s
.842 .991 .853 r
.84023 .86375 m .83887 .86516 L .8344 .8643 L p F P
0 g
s
.842 .991 .853 r
.8344 .8643 m .84273 .85629 L .84023 .86375 L p F P
0 g
s
.858 .995 .758 r
.84023 .86375 m .84273 .85629 L .85485 .84161 L p F P
0 g
s
0 0 0 r
.86555 .8158 m .86734 .80831 L .8689 .79643 L p F P
0 g
s
.759 .781 .284 r
.86734 .80831 m .86555 .8158 L .8617 .82829 L p F P
0 g
s
.875 .988 .721 r
.40444 .76769 m .40816 .75867 L .39775 .77267 L p F P
0 g
s
.875 .988 .721 r
.39869 .77657 m .40444 .76769 L p .39775 .77267 L F P
0 g
s
.702 .932 .964 r
.35869 .58681 m .33641 .59822 L .34359 .60029 L p F P
0 g
s
.702 .932 .964 r
.34359 .60029 m .36578 .58876 L .35869 .58681 L p F P
0 g
s
.726 .93 .958 r
.33462 .59922 m .33641 .59822 L .34359 .60029 L p F P
0 g
s
0 0 .475 r
.64222 .7541 m .63551 .74485 L p .63625 .74596 L F P
0 g
s
0 0 .475 r
.6462 .76062 m .64222 .7541 L p .63625 .74596 L F P
0 g
s
0 0 .484 r
.64729 .76095 m .64222 .7541 L .6462 .76062 L p F P
0 g
s
.626 .16 0 r
.64222 .7541 m .64729 .76095 L .64697 .76057 L p F P
0 g
s
0 0 .475 r
.63551 .74485 m .63919 .75147 L .6462 .76062 L p F P
0 g
s
.626 .16 0 r
.64697 .76057 m .64151 .75401 L p .64222 .7541 L F P
0 g
s
.636 .171 0 r
.63551 .74485 m .64222 .7541 L p .64196 .75375 L F P
0 g
s
0 0 .497 r
.63919 .75147 m .63551 .74485 L p .62911 .73604 L F P
0 g
s
.636 .171 0 r
.63041 .73857 m .63551 .74485 L p .64196 .75375 L F P
0 g
s
0 0 .497 r
.63551 .74485 m .62888 .73569 L p .62911 .73604 L F P
0 g
s
.631 .17 0 r
.62389 .72936 m .62888 .73569 L .63551 .74485 L p F P
0 g
s
.036 .259 .757 r
.67058 .8024 m .6675 .79957 L .66707 .79526 L closepath p F P
0 g
s
.034 .257 .756 r
.66474 .79051 m .65813 .78352 L p .6675 .79957 L F P
0 g
s
.034 .257 .756 r
.6675 .79957 m .66707 .79526 L .66474 .79051 L p F P
0 g
s
0 .122 .671 r
.65813 .78352 m .66474 .79051 L .6589 .77944 L p F P
0 g
s
0 .122 .671 r
.6589 .77944 m .65642 .77652 L .65813 .78352 L p F P
0 g
s
0 .115 .667 r
.65813 .78352 m .65642 .77652 L .64882 .76745 L p F P
0 g
s
.408 .695 .979 r
.66044 .58305 m .67698 .58365 L .6679 .57799 L p F P
0 g
s
.408 .695 .979 r
.6679 .57799 m .65487 .57758 L .66044 .58305 L p F P
0 g
s
.172 .37 .818 r
.67893 .80778 m .67757 .81542 L .69129 .82313 L p F P
0 g
s
.304 .422 .817 r
.67058 .8024 m .67893 .80778 L .67757 .81542 L p F P
0 g
s
.359 .451 .819 r
.67757 .81542 m .69129 .82313 L .68959 .83077 L p F P
0 g
s
.297 0 .213 r
.46535 .68756 m .48169 .68063 L p .45821 .69749 L F P
0 g
s
.331 .01 .261 r
.48169 .68063 m .48329 .6753 L .46535 .68756 L closepath p F P
0 g
s
0 .051 .614 r
.6462 .76062 m .64882 .76745 L .65642 .77652 L p F P
0 g
s
0 .024 .595 r
.64882 .76745 m .6462 .76062 L .63919 .75147 L p F P
0 g
s
.867 .986 .836 r
.2251 .67782 m .2227 .68579 L .22409 .68546 L p F P
0 g
s
.883 .98 .827 r
.2227 .68579 m .22409 .68546 L .22235 .68738 L closepath p F P
0 g
s
.639 .854 .982 r
.81112 .87927 m .78748 .88846 L .78238 .88311 L p F P
0 g
s
.468 .606 .905 r
.74383 .87917 m .75311 .87955 L .7477 .87174 L p F P
0 g
s
.468 .606 .905 r
.7477 .87174 m .74654 .87161 L .74383 .87917 L p F P
0 g
s
.888 .99 .779 r
.22235 .68738 m .21132 .70133 L .21324 .69209 L p F P
0 g
s
.888 .99 .779 r
.2227 .68579 m .22235 .68738 L p .21324 .69209 L F P
0 g
s
.912 .923 .809 r
.35953 .83591 m .36328 .83117 L .36147 .82403 L p F P
0 g
s
.764 .372 .311 r
.56545 .67114 m .54938 .66781 L .55508 .67686 L p F P
0 g
s
.764 .372 .311 r
.56996 .68025 m .56545 .67114 L p .55508 .67686 L F P
0 g
s
.821 .894 .894 r
.32963 .85598 m .3071 .87263 L .31422 .87666 L p F P
0 g
s
.821 .894 .894 r
.33158 .85679 m .32963 .85598 L p .31422 .87666 L F P
0 g
s
.821 .894 .894 r
.31422 .87666 m .33282 .86191 L .33158 .85679 L p F P
0 g
s
.73 .853 .939 r
.30678 .8728 m .3071 .87263 L .31422 .87666 L p F P
0 g
s
.145 .424 .865 r
.8004 .65548 m .79966 .65509 L .79857 .65263 L closepath p F P
0 g
s
.241 .497 .898 r
.79966 .65509 m .79857 .65263 L .79521 .64757 L p F P
0 g
s
0 0 .352 r
.86913 .78094 m .8695 .7777 L .86724 .76694 L p F P
0 g
s
0 0 .313 r
.86758 .75958 m .86724 .76694 L .8695 .7777 L p F P
0 g
s
0 0 .495 r
.86374 .7493 m .86758 .75958 L .86724 .76694 L p F P
0 g
s
.403 .477 .822 r
.68959 .83077 m .70489 .83818 L .70326 .84571 L p F P
0 g
s
.271 .448 .853 r
.69129 .82313 m .68959 .83077 L .70489 .83818 L p F P
0 g
s
.912 .923 .809 r
.36147 .82403 m .35247 .83448 L .35953 .83591 L p F P
0 g
s
.854 .93 .877 r
.35953 .83591 m .34913 .84623 L .34743 .83911 L p F P
0 g
s
.854 .93 .877 r
.34743 .83911 m .35247 .83448 L .35953 .83591 L p F P
0 g
s
.061 0 .101 r
.45077 .70268 m .45821 .69749 L .45518 .70564 L p F P
0 g
s
.061 0 .101 r
.45518 .70564 m .43869 .71706 L .45077 .70268 L p F P
0 g
s
.481 .755 .99 r
.59673 .56911 m .61235 .56777 L .59867 .56346 L p F P
0 g
s
.481 .755 .99 r
.59867 .56346 m .59089 .56413 L .59673 .56911 L p F P
0 g
s
.174 .43 .864 r
.8004 .65548 m .81307 .66216 L .81571 .66923 L p F P
0 g
s
.142 .423 .864 r
.81307 .66216 m .8004 .65548 L .79857 .65263 L p F P
0 g
s
.616 .886 .989 r
.41719 .57238 m .42245 .57462 L .44382 .56629 L p F P
0 g
s
.629 .869 .987 r
.44622 .56757 m .44382 .56629 L .42245 .57462 L p F P
0 g
s
.249 .544 .926 r
.75511 .62259 m .75968 .62397 L .75443 .61721 L p F P
0 g
s
.249 .544 .926 r
.75443 .61721 m .75017 .61593 L .75511 .62259 L p F P
0 g
s
.752 .536 0 r
.18424 .79843 m .18291 .7907 L .18411 .80119 L p F P
0 g
s
.752 .536 0 r
.18411 .80119 m .18546 .80889 L .18424 .79843 L p F P
0 g
s
.855 .879 .856 r
.34913 .84623 m .34743 .83911 L .33069 .85496 L p F P
0 g
s
.855 .879 .856 r
.33673 .85892 m .34913 .84623 L p .33069 .85496 L F P
0 g
s
.763 .973 .922 r
.30673 .61018 m .2843 .62539 L .29188 .62597 L p F P
0 g
s
.763 .973 .922 r
.30726 .6102 m .30673 .61018 L p .29188 .62597 L F P
0 g
s
.763 .973 .922 r
.29188 .62597 m .29856 .62134 L .30726 .6102 L p F P
0 g
s
.782 .967 .921 r
.27907 .62915 m .2843 .62539 L .29188 .62597 L p F P
0 g
s
.647 .899 .983 r
.4104 .56963 m .38804 .57861 L .39491 .58138 L p F P
0 g
s
.647 .899 .983 r
.39491 .58138 m .41719 .57238 L .4104 .56963 L p F P
0 g
s
.678 .902 .976 r
.39491 .58138 m .38804 .57861 L .37386 .58496 L p F P
0 g
s
0 .218 .732 r
.85069 .71556 m .84776 .71256 L .84234 .70078 L p F P
0 g
s
.875 .988 .721 r
.39775 .77267 m .39612 .77817 L .39869 .77657 L p F P
0 g
s
.874 .988 .721 r
.39612 .77817 m .39869 .77657 L .39518 .7813 L closepath p F P
0 g
s
.43 .653 .953 r
.24897 .87885 m .23392 .87796 L .23108 .87115 L p F P
0 g
s
.458 .672 .956 r
.23392 .87796 m .24897 .87885 L .25618 .88505 L p F P
0 g
s
.813 .89 .899 r
.33158 .85679 m .33673 .85892 L .33282 .86191 L closepath p F P
0 g
s
.879 .993 .782 r
.21575 .68901 m .2251 .67782 L .2227 .68579 L closepath p F P
0 g
s
.888 .99 .779 r
.21324 .69209 m .21575 .68901 L .2227 .68579 L p F P
0 g
s
.303 .445 .838 r
.70326 .84571 m .71229 .8493 L .7066 .83902 L p F P
0 g
s
.303 .445 .838 r
.7066 .83902 m .70489 .83818 L .70326 .84571 L p F P
0 g
s
.855 .879 .856 r
.33069 .85496 m .33158 .85679 L .33673 .85892 L p F P
0 g
s
.498 .586 .874 r
.71917 .86162 m .72026 .85981 L p .74654 .87161 L F P
0 g
s
.471 .573 .876 r
.71917 .86162 m .71794 .85946 L .72026 .85981 L closepath p F P
0 g
s
.36 .662 .972 r
.68969 .58995 m .68522 .58952 L .67698 .58365 L p F P
0 g
s
0 0 .002 r
.43787 .71802 m .43869 .71706 L .4381 .7175 L closepath p F P
0 g
s
.599 .824 .434 r
.4381 .7175 m .43787 .71802 L .42856 .73088 L p F P
0 g
s
.509 .17 .328 r
.48169 .68063 m .48329 .6753 L .50118 .67668 L closepath p F P
0 g
s
.755 .952 .94 r
.30726 .6102 m .31415 .61141 L .29856 .62134 L closepath p F P
0 g
s
.909 .981 .721 r
.21132 .70133 m .21324 .69209 L .20379 .70562 L p F P
0 g
s
.909 .981 .721 r
.20379 .70562 m .20207 .71475 L .21132 .70133 L p F P
0 g
s
.675 .924 .973 r
.36578 .58876 m .37386 .58496 L .36754 .58928 L closepath p F P
0 g
s
0 0 .443 r
.86358 .74197 m .86374 .7493 L .86758 .75958 L p F P
0 g
s
0 .027 .586 r
.85822 .73217 m .86358 .74197 L .86374 .7493 L p F P
0 g
s
.826 .989 .727 r
.39518 .7813 m .38489 .79524 L .38662 .78691 L p F P
0 g
s
.826 .989 .727 r
.39612 .77817 m .39518 .7813 L p .38662 .78691 L F P
0 g
s
.104 .361 .826 r
.82947 .68406 m .82736 .67692 L .81571 .66923 L p F P
0 g
s
.069 .352 .825 r
.81307 .66216 m .81571 .66923 L .82736 .67692 L p F P
0 g
s
.732 .233 0 r
.61734 .72342 m .61117 .71493 L .61396 .7172 L p F P
0 g
s
.849 .399 0 r
.61117 .71493 m .61085 .7143 L .61396 .7172 L closepath p F P
0 g
s
.225 .384 .813 r
.67893 .80778 m .67058 .8024 L .66707 .79526 L p F P
0 g
s
0 0 0 r
.43869 .71706 m .45518 .70564 L p .44501 .71785 L F P
0 g
s
0 0 0 r
.43787 .71802 m .43869 .71706 L p .44501 .71785 L F P
0 g
s
.302 .604 .951 r
.72457 .6051 m .72382 .60495 L .71742 .59861 L p F P
0 g
s
0 0 0 r
.44501 .71785 m .43421 .72502 L .43787 .71802 L p F P
0 g
s
0 0 0 r
.43421 .72502 m .43787 .71802 L .42856 .73088 L closepath p F P
0 g
s
0 0 .158 r
.8695 .7777 m .86913 .78094 L .86979 .79144 L p F P
0 g
s
0 0 .2 r
.8689 .79643 m .86979 .79144 L .86913 .78094 L p F P
0 g
s
.459 .736 .987 r
.62571 .57231 m .62509 .57234 L .62629 .57284 L closepath p F P
0 g
s
.81 .403 .279 r
.58323 .6847 m .57013 .68051 L .57609 .68959 L p F P
0 g
s
.81 .403 .279 r
.57609 .68959 m .58836 .69403 L .58323 .6847 L p F P
0 g
s
.614 .79 .966 r
.27054 .87418 m .24897 .87885 L .25618 .88505 L p F P
0 g
s
.614 .79 .966 r
.25618 .88505 m .27778 .87936 L .27054 .87418 L p F P
0 g
s
.475 .568 .87 r
.72026 .85981 m .71794 .85946 L .71229 .8493 L p F P
0 g
s
.142 .423 .864 r
.79857 .65263 m .79651 .6481 L p .81307 .66216 L F P
0 g
s
.226 .488 .895 r
.79857 .65263 m .79521 .64757 L .79651 .6481 L closepath p F P
0 g
s
.288 .596 .949 r
.72457 .6051 m .74458 .6094 L .73832 .603 L p F P
0 g
s
.288 .596 .949 r
.73832 .603 m .71923 .59896 L .72457 .6051 L p F P
0 g
s
.302 .604 .951 r
.71742 .59861 m .71923 .59896 L .72457 .6051 L p F P
0 g
s
.449 .741 .991 r
.62571 .57231 m .62509 .57234 L .61235 .56777 L p F P
0 g
s
.913 .875 .445 r
.18895 .74844 m .18924 .73994 L .18528 .75185 L p F P
0 g
s
.913 .875 .445 r
.18528 .75185 m .18501 .76031 L .18895 .74844 L p F P
0 g
s
0 0 0 r
.86979 .79144 m .8689 .79643 L .86734 .80831 L p F P
0 g
s
.924 .963 .653 r
.20024 .71794 m .20207 .71475 L .20186 .71636 L closepath p F P
0 g
s
.93 .961 .653 r
.1948 .72759 m .20024 .71794 L .20186 .71636 L p F P
0 g
s
.736 .858 .938 r
.29991 .86859 m .27778 .87936 L .28497 .88437 L p F P
0 g
s
.736 .858 .938 r
.30674 .87243 m .29991 .86859 L p .28497 .88437 L F P
0 g
s
.736 .858 .938 r
.28497 .88437 m .30678 .8728 L .30674 .87243 L p F P
0 g
s
.904 .937 .569 r
.8617 .82829 m .86342 .82086 L p .8556 .83948 L F P
0 g
s
.904 .937 .569 r
.8556 .83948 m .85671 .83863 L .8617 .82829 L p F P
0 g
s
.759 .781 .284 r
.8617 .82829 m .86342 .82086 L .86734 .80831 L p F P
0 g
s
.412 .718 .987 r
.6436 .56724 m .61999 .56742 L .62571 .57231 L p F P
0 g
s
.412 .718 .987 r
.62571 .57231 m .64926 .57231 L .6436 .56724 L p F P
0 g
s
.405 .708 .984 r
.65487 .57758 m .64926 .57231 L .62571 .57231 L p F P
0 g
s
.449 .741 .991 r
.61235 .56777 m .61999 .56742 L .62571 .57231 L p F P
0 g
s
0 0 .55 r
.85755 .72488 m .85822 .73217 L .86358 .74197 L p F P
0 g
s
0 .127 .665 r
.85069 .71556 m .85755 .72488 L .85822 .73217 L p F P
0 g
s
.067 .31 .793 r
.83703 .69029 m .82947 .68406 L p .84114 .69951 L F P
0 g
s
.001 .273 .775 r
.82947 .68406 m .83703 .69029 L .83177 .68062 L p F P
0 g
s
.001 .273 .775 r
.83177 .68062 m .82736 .67692 L .82947 .68406 L p F P
0 g
s
.263 .54 .921 r
.75968 .62397 m .77294 .62809 L .77726 .63488 L p F P
0 g
s
.242 .54 .924 r
.77294 .62809 m .75968 .62397 L .75443 .61721 L p F P
0 g
s
.313 .539 .911 r
.22102 .86912 m .23108 .87115 L .22829 .86425 L p F P
0 g
s
.313 .539 .911 r
.22829 .86425 m .21389 .86037 L .22102 .86912 L p F P
0 g
s
.063 .383 .846 r
.2104 .8582 m .21389 .86037 L .22102 .86912 L p F P
0 g
s
.675 .322 .367 r
.54938 .66781 m .55508 .67686 L .5351 .67467 L p F P
0 g
s
.675 .322 .367 r
.53729 .66651 m .54938 .66781 L p .5351 .67467 L F P
0 g
s
.843 .689 .154 r
.18348 .77975 m .18271 .7723 L .18218 .78394 L p F P
0 g
s
.843 .689 .154 r
.18218 .78394 m .18291 .7907 L .18348 .77975 L p F P
0 g
s
.498 .586 .874 r
.72026 .85981 m .74223 .86354 L p .74654 .87161 L F P
0 g
s
.424 .539 .869 r
.72026 .85981 m .74223 .86354 L .73672 .85509 L p F P
0 g
s
.424 .539 .869 r
.73672 .85509 m .72376 .85189 L .72026 .85981 L p F P
0 g
s
.475 .568 .87 r
.71229 .8493 m .72376 .85189 L .72026 .85981 L p F P
0 g
s
.546 .731 .961 r
.75311 .87955 m .7772 .87717 L .78238 .88311 L p F P
0 g
s
.517 .702 .954 r
.7772 .87717 m .75311 .87955 L .7477 .87174 L p F P
0 g
s
0 .08 .638 r
.84952 .70832 m .85069 .71556 L .85755 .72488 L p F P
0 g
s
0 .218 .732 r
.84234 .70078 m .84952 .70832 L .85069 .71556 L p F P
0 g
s
0 .191 .718 r
.84234 .70078 m .84114 .69951 L .84066 .69725 L closepath p F P
0 g
s
.067 .31 .793 r
.84114 .69951 m .84066 .69725 L .83703 .69029 L p F P
0 g
s
.342 .651 .969 r
.68969 .58995 m .71029 .59244 L .70242 .58643 L p F P
0 g
s
.342 .651 .969 r
.70242 .58643 m .68422 .58432 L .68969 .58995 L p F P
0 g
s
.36 .662 .972 r
.67698 .58365 m .68422 .58432 L .68969 .58995 L p F P
0 g
s
.61 .838 .456 r
.41479 .74978 m .41851 .74472 L .41666 .74737 L closepath p F P
0 g
s
.597 .831 .451 r
.40816 .75867 m .41479 .74978 L p .41535 .74912 L F P
0 g
s
0 0 0 r
.41616 .74829 m .41308 .7518 L p .41479 .74978 L F P
0 g
s
.662 .879 .512 r
.4113 .75383 m .41479 .74978 L .41461 .75002 L p F P
0 g
s
.662 .879 .512 r
.41461 .75002 m .40816 .75867 L .4113 .75383 L p F P
0 g
s
.539 .817 .466 r
.40762 .75807 m .4113 .75383 L p .40789 .75777 L F P
0 g
s
.539 .817 .466 r
.4033 .76307 m .40762 .75807 L p .40789 .75777 L F P
0 g
s
.539 .817 .466 r
.4113 .75383 m .40816 .75867 L p .4033 .76307 L F P
0 g
s
0 0 0 r
.41417 .75181 m .40723 .75851 L p .40762 .75807 L F P
0 g
s
.631 .887 .553 r
.40556 .76011 m .40762 .75807 L .40761 .75808 L p F P
0 g
s
.631 .887 .553 r
.40761 .75808 m .4033 .76307 L .40556 .76011 L p F P
0 g
s
.509 .823 .507 r
.40038 .76526 m .40556 .76011 L p .40028 .76537 L F P
0 g
s
.509 .823 .507 r
.39799 .76766 m .40038 .76526 L p .40028 .76537 L F P
0 g
s
.509 .823 .507 r
.40556 .76011 m .4033 .76307 L p .39799 .76766 L F P
0 g
s
0 0 0 r
.40039 .76524 m .41417 .75181 L .40556 .76011 L p F P
0 g
s
.469 .826 .558 r
.40038 .76526 m .41417 .75181 L p .41188 .75546 L F P
0 g
s
.469 .826 .558 r
.41188 .75546 m .40047 .76514 L p .40038 .76526 L F P
0 g
s
.469 .826 .558 r
.40047 .76514 m .39933 .7661 L .40038 .76526 L p F P
0 g
s
0 0 0 r
.40556 .76011 m .40038 .76526 L .40039 .76524 L p F P
0 g
s
0 0 0 r
.40723 .75851 m .40556 .76011 L .40762 .75807 L p F P
0 g
s
0 0 0 r
.4113 .75383 m .40762 .75807 L .40781 .75786 L p F P
0 g
s
0 0 0 r
.40781 .75786 m .41616 .74829 L .4113 .75383 L p F P
0 g
s
0 0 0 r
.41308 .7518 m .4113 .75383 L .41479 .74978 L p F P
0 g
s
.597 .831 .451 r
.41479 .74978 m .41666 .74737 L p .41535 .74912 L F P
0 g
s
.667 .93 .971 r
.38105 .57642 m .35869 .58681 L .36578 .58876 L p F P
0 g
s
.667 .93 .971 r
.38518 .57753 m .38105 .57642 L p .36578 .58876 L F P
0 g
s
.667 .93 .971 r
.36578 .58876 m .37386 .58496 L .38518 .57753 L p F P
0 g
s
.855 .424 .193 r
.59824 .69913 m .58836 .69403 L .59367 .70341 L p F P
0 g
s
.855 .424 .193 r
.59367 .70341 m .60308 .70864 L .59824 .69913 L p F P
0 g
s
.635 .3 .386 r
.50621 .67562 m .50842 .66706 L .5267 .66645 L p F P
0 g
s
.516 .196 .365 r
.50842 .66706 m .50621 .67562 L .50118 .67668 L p F P
0 g
s
.225 .384 .813 r
.66707 .79526 m .66718 .79228 L p .67893 .80778 L F P
0 g
s
.171 .348 .799 r
.66707 .79526 m .66474 .79051 L .66718 .79228 L closepath p F P
0 g
s
.907 .965 .809 r
.38489 .79524 m .38662 .78691 L .37468 .80141 L p F P
0 g
s
.907 .965 .809 r
.37552 .80804 m .38489 .79524 L p .37468 .80141 L F P
0 g
s
.727 .949 .951 r
.31415 .61141 m .33462 .59922 L p .30817 .60926 L F P
0 g
s
.727 .949 .951 r
.30817 .60926 m .30726 .6102 L .31415 .61141 L p F P
0 g
s
.179 .483 .898 r
.77726 .63488 m .79003 .64009 L .78484 .63295 L p F P
0 g
s
.179 .483 .898 r
.78484 .63295 m .77294 .62809 L .77726 .63488 L p F P
0 g
s
0 0 0 r
.42856 .73088 m .41851 .74472 L .42901 .73353 L p F P
0 g
s
0 0 0 r
.43421 .72502 m .42856 .73088 L p .42901 .73353 L F P
0 g
s
.906 .966 .649 r
.20207 .71475 m .20379 .70562 L .1961 .71864 L p F P
0 g
s
.906 .966 .649 r
.20024 .71794 m .20207 .71475 L p .1961 .71864 L F P
0 g
s
.55 .823 .997 r
.50406 .56257 m .5268 .55759 L p .51929 .55378 L F P
0 g
s
.55 .823 .997 r
.51929 .55378 m .49776 .55853 L .50406 .56257 L p F P
0 g
s
.675 .322 .367 r
.5351 .67467 m .53489 .67442 L .53729 .66651 L p F P
0 g
s
.649 .295 .359 r
.53489 .67442 m .5267 .66645 L .53729 .66651 L closepath p F P
0 g
s
.635 .3 .386 r
.5267 .66645 m .53489 .67442 L p .50621 .67562 L F P
0 g
s
0 .182 .716 r
.20681 .85068 m .19854 .8428 L .19626 .83558 L p F P
0 g
s
0 .19 .721 r
.19854 .8428 m .20681 .85068 L .20803 .85246 L p F P
0 g
s
.575 .842 .995 r
.47516 .56447 m .49776 .55853 L p .47978 .55775 L F P
0 g
s
.575 .842 .995 r
.47978 .55775 m .46871 .56067 L .47516 .56447 L p F P
0 g
s
0 .191 .719 r
.84952 .70832 m .84234 .70078 L .84066 .69725 L p F P
0 g
s
.867 .421 .104 r
.61117 .71493 m .61085 .7143 L .60308 .70864 L p F P
0 g
s
.737 .904 .952 r
.82093 .87342 m .81112 .87927 L .80623 .87539 L p F P
0 g
s
.639 .854 .982 r
.78238 .88311 m .80623 .87539 L .81112 .87927 L p F P
0 g
s
.525 .803 .997 r
.53296 .56189 m .55587 .55787 L p .54468 .55444 L F P
0 g
s
.525 .803 .997 r
.54468 .55444 m .5268 .55759 L .53296 .56189 L p F P
0 g
s
.885 .798 .311 r
.18506 .76217 m .18501 .76031 L .1827 .77174 L p F P
0 g
s
.885 .798 .311 r
.1827 .77174 m .18271 .7723 L .18506 .76217 L p F P
0 g
s
0 0 .525 r
.19051 .82629 m .18871 .81884 L p .19489 .83026 L F P
0 g
s
0 0 .525 r
.19489 .83026 m .19626 .83558 L .19051 .82629 L p F P
0 g
s
.875 .988 .722 r
.39159 .78095 m .39775 .77267 L .39612 .77817 L closepath p F P
0 g
s
.826 .989 .727 r
.38662 .78691 m .39159 .78095 L .39612 .77817 L p F P
0 g
s
.906 .966 .649 r
.1961 .71864 m .19533 .72279 L .20024 .71794 L p F P
0 g
s
.928 .961 .65 r
.19533 .72279 m .20024 .71794 L .1948 .72759 L closepath p F P
0 g
s
.775 .268 0 r
.61117 .71493 m .61734 .72342 L .60913 .7179 L p F P
0 g
s
.775 .268 0 r
.60913 .7179 m .60543 .71306 L .61117 .71493 L p F P
0 g
s
.867 .421 .104 r
.60308 .70864 m .60543 .71306 L .61117 .71493 L p F P
0 g
s
.036 .348 .825 r
.21389 .86037 m .2104 .8582 L .20803 .85246 L closepath p F P
0 g
s
.131 .342 .805 r
.66718 .79228 m .66474 .79051 L .6589 .77944 L p F P
0 g
s
.827 .947 .592 r
.85485 .84161 m .8556 .83948 L .85671 .83863 L closepath p F P
0 g
s
.6 .86 .993 r
.44382 .56629 m .44622 .56757 L .46871 .56067 L p F P
0 g
s
.323 0 .217 r
.45821 .69749 m .47905 .68897 L p .47349 .69842 L F P
0 g
s
.323 0 .217 r
.47349 .69842 m .45518 .70564 L .45821 .69749 L p F P
0 g
s
.297 0 .213 r
.48169 .68063 m .47905 .68897 L .45821 .69749 L p F P
0 g
s
0 0 .158 r
.86979 .79144 m .87006 .78899 L .8695 .7777 L p F P
0 g
s
0 0 .104 r
.86983 .77037 m .8695 .7777 L .87006 .78899 L p F P
0 g
s
0 0 .313 r
.8695 .7777 m .86983 .77037 L .86758 .75958 L p F P
0 g
s
.673 .908 .977 r
.38518 .57753 m .38804 .57861 L .37386 .58496 L closepath p F P
0 g
s
.631 .17 0 r
.63551 .74485 m .63041 .73857 L .62389 .72936 L p F P
0 g
s
.732 .239 0 r
.62389 .72936 m .61734 .72342 L .62396 .73261 L p F P
0 g
s
.732 .239 0 r
.62396 .73261 m .63041 .73857 L .62389 .72936 L p F P
0 g
s
0 .191 .719 r
.84066 .69725 m .83951 .69232 L p .84952 .70832 L F P
0 g
s
.04 .291 .783 r
.84066 .69725 m .83703 .69029 L .83951 .69232 L closepath p F P
0 g
s
.616 .819 .978 r
.80623 .87539 m .78238 .88311 L .7772 .87717 L p F P
0 g
s
.862 .996 .802 r
.8556 .83948 m .85485 .84161 L .84273 .85629 L p F P
0 g
s
.498 .782 .996 r
.56189 .5624 m .58359 .55955 L .56534 .55662 L p F P
0 g
s
.498 .782 .996 r
.56534 .55662 m .55587 .55787 L .56189 .5624 L p F P
0 g
s
.907 .965 .809 r
.37468 .80141 m .37456 .80818 L .37552 .80804 L p F P
0 g
s
.889 .976 .826 r
.37456 .80818 m .37552 .80804 L .37442 .80927 L closepath p F P
0 g
s
.206 .488 .898 r
.79651 .6481 m .79521 .64757 L .79003 .64009 L p F P
0 g
s
.866 .984 .842 r
.37442 .80927 m .36147 .82403 L .3614 .81631 L p F P
0 g
s
.866 .984 .842 r
.37456 .80818 m .37442 .80927 L p .3614 .81631 L F P
0 g
s
.737 .904 .952 r
.80623 .87539 m .82407 .8658 L .82093 .87342 L p F P
0 g
s
.772 .962 .928 r
.82978 .86236 m .82407 .8658 L .82093 .87342 L p F P
0 g
s
.772 .962 .928 r
.82093 .87342 m .8344 .8643 L .82978 .86236 L p F P
0 g
s
.765 .373 .312 r
.56986 .68044 m .56996 .68025 L .57013 .68051 L closepath p F P
0 g
s
.764 .372 .311 r
.55508 .67686 m .56986 .68044 L .56996 .68025 L p F P
0 g
s
.4 .701 .982 r
.65487 .57758 m .6679 .57799 L .65797 .57253 L p F P
0 g
s
.4 .701 .982 r
.65797 .57253 m .64926 .57231 L .65487 .57758 L p F P
0 g
s
.505 .161 .318 r
.47905 .68897 m .48169 .68063 L .50118 .67668 L p F P
0 g
s
.763 .364 .296 r
.57013 .68051 m .56986 .68044 L .56606 .68711 L p F P
0 g
s
.763 .364 .296 r
.56606 .68711 m .57609 .68959 L .57013 .68051 L p F P
0 g
s
0 0 0 r
.41851 .74472 m .42901 .73353 L .41616 .74829 L p F P
0 g
s
0 0 0 r
.41479 .74978 m .41851 .74472 L p .41616 .74829 L F P
0 g
s
0 0 .301 r
.18546 .80889 m .18411 .80119 L p .18754 .81241 L F P
0 g
s
0 0 .301 r
.18754 .81241 m .18871 .81884 L .18546 .80889 L p F P
0 g
s
.437 .545 .869 r
.72376 .85189 m .71229 .8493 L .7066 .83902 L p F P
0 g
s
.758 .358 .293 r
.56986 .68044 m .55508 .67686 L .56108 .68592 L p F P
0 g
s
.758 .358 .293 r
.56108 .68592 m .56606 .68711 L .56986 .68044 L p F P
0 g
s
0 .051 .614 r
.65309 .76951 m .6462 .76062 L p .65642 .77652 L F P
0 g
s
0 0 .484 r
.6462 .76062 m .65309 .76951 L .64729 .76095 L p F P
0 g
s
.142 .423 .864 r
.79651 .6481 m .80986 .65519 L .81307 .66216 L p F P
0 g
s
.101 .413 .862 r
.79276 .64121 m .79651 .6481 L .80986 .65519 L p F P
0 g
s
.206 .488 .898 r
.79003 .64009 m .79276 .64121 L .79651 .6481 L p F P
0 g
s
0 .059 .62 r
.6589 .77944 m .65642 .77652 L .65365 .77048 L closepath p F P
0 g
s
0 .051 .614 r
.65642 .77652 m .65365 .77048 L .65309 .76951 L p F P
0 g
s
.855 .879 .856 r
.32963 .85598 m .33069 .85496 L .33158 .85679 L closepath p F P
0 g
s
.435 .745 .993 r
.61999 .56742 m .61235 .56777 L .59867 .56346 L p F P
0 g
s
.228 .545 .928 r
.75443 .61721 m .75017 .61593 L .74458 .6094 L p F P
0 g
s
.729 .854 .94 r
.30674 .87243 m .3071 .87263 L .30678 .8728 L closepath p F P
0 g
s
.791 .854 .898 r
.3071 .87263 m .32963 .85598 L p .3033 .86622 L F P
0 g
s
.791 .854 .898 r
.3033 .86622 m .30674 .87243 L .3071 .87263 L p F P
0 g
s
.611 .89 .989 r
.4329 .56165 m .4104 .56963 L .41719 .57238 L p F P
0 g
s
.611 .89 .989 r
.41719 .57238 m .4396 .56444 L .4329 .56165 L p F P
0 g
s
.616 .886 .989 r
.44382 .56629 m .4396 .56444 L .41719 .57238 L p F P
0 g
s
.845 .776 .271 r
.18501 .76031 m .18528 .75185 L .18298 .76332 L p F P
0 g
s
.845 .776 .271 r
.18298 .76332 m .1827 .77174 L .18501 .76031 L p F P
0 g
s
.347 .667 .974 r
.68422 .58432 m .67698 .58365 L .6679 .57799 L p F P
0 g
s
.225 .384 .813 r
.66718 .79228 m .6784 .80056 L .67893 .80778 L p F P
0 g
s
0 .271 .775 r
.66602 .78515 m .66718 .79228 L .6784 .80056 L p F P
0 g
s
.131 .342 .805 r
.6589 .77944 m .66602 .78515 L .66718 .79228 L p F P
0 g
s
0 0 0 r
.86909 .79812 m .86979 .79144 L p .86734 .80831 L F P
0 g
s
0 0 0 r
.86734 .80831 m .8687 .80085 L .86909 .79812 L p F P
0 g
s
.81 .817 .335 r
.8687 .80085 m .86734 .80831 L .86342 .82086 L p F P
0 g
s
.791 .854 .898 r
.29991 .86859 m .3033 .86622 L .30674 .87243 L closepath p F P
0 g
s
.907 .965 .809 r
.36839 .8091 m .37468 .80141 L .37456 .80818 L closepath p F P
0 g
s
.866 .984 .842 r
.3614 .81631 m .36839 .8091 L .37456 .80818 L p F P
0 g
s
.835 .98 .878 r
.84273 .85629 m .8344 .8643 L .82978 .86236 L p F P
0 g
s
.835 .98 .878 r
.82978 .86236 m .84501 .84882 L .84273 .85629 L p F P
0 g
s
.862 .996 .802 r
.85259 .84034 m .8556 .83948 L p .84273 .85629 L F P
0 g
s
.862 .996 .802 r
.84273 .85629 m .84501 .84882 L .85259 .84034 L p F P
0 g
s
.727 .949 .951 r
.33462 .59922 m .33578 .59805 L p .30817 .60926 L F P
0 g
s
.723 .934 .958 r
.33578 .59805 m .33641 .59822 L .33462 .59922 L closepath p F P
0 g
s
.882 .925 .846 r
.36147 .82403 m .3614 .81631 L .34692 .83158 L p F P
0 g
s
.882 .925 .846 r
.35247 .83448 m .36147 .82403 L p .34692 .83158 L F P
0 g
s
.893 .923 .534 r
.1948 .72759 m .18924 .73994 L .19015 .73115 L p F P
0 g
s
.893 .923 .534 r
.19533 .72279 m .1948 .72759 L p .19015 .73115 L F P
0 g
s
.472 .76 .993 r
.58573 .55996 m .59089 .56413 L .59867 .56346 L closepath p F P
0 g
s
.507 .777 .993 r
.59089 .56413 m .58573 .55996 L .58359 .55955 L p F P
0 g
s
.172 .37 .818 r
.69129 .82313 m .69112 .81591 L .67893 .80778 L p F P
0 g
s
.094 .352 .821 r
.6784 .80056 m .67893 .80778 L .69112 .81591 L p F P
0 g
s
0 0 .269 r
.86741 .75228 m .86758 .75958 L .86983 .77037 L p F P
0 g
s
0 0 .443 r
.86758 .75958 m .86741 .75228 L .86358 .74197 L p F P
0 g
s
.698 .93 .966 r
.33578 .59805 m .33641 .59822 L .35869 .58681 L p F P
0 g
s
.845 .997 .825 r
.23903 .66306 m .23924 .66284 L .23917 .66301 L closepath p F P
0 g
s
.867 .986 .836 r
.23917 .66301 m .23903 .66306 L .2251 .67782 L p F P
0 g
s
.288 .545 .92 r
.21389 .86037 m .20803 .85246 L p .22563 .85724 L F P
0 g
s
.288 .545 .92 r
.22563 .85724 m .22829 .86425 L .21389 .86037 L p F P
0 g
s
0 0 0 r
.86909 .79812 m .87006 .78899 L .86979 .79144 L closepath p F P
0 g
s
.285 .608 .954 r
.71923 .59896 m .71742 .59861 L .71029 .59244 L p F P
0 g
s
.831 1 .811 r
.23903 .66306 m .23924 .66284 L .24439 .65234 L p F P
0 g
s
.812 .996 .86 r
.25696 .64671 m .23924 .66284 L .24439 .65234 L p F P
0 g
s
.831 1 .811 r
.24439 .65234 m .23081 .66583 L .23903 .66306 L p F P
0 g
s
.845 .998 .822 r
.23903 .66306 m .2251 .67782 L .22886 .66783 L p F P
0 g
s
.845 .998 .822 r
.22886 .66783 m .23081 .66583 L .23903 .66306 L p F P
0 g
s
.812 .996 .86 r
.25895 .64287 m .25696 .64671 L p .24439 .65234 L F P
0 g
s
.813 .98 .893 r
.25895 .64287 m .26178 .64275 L .25696 .64671 L closepath p F P
0 g
s
.894 .981 .699 r
.85259 .84034 m .85672 .83418 L .8556 .83948 L closepath p F P
0 g
s
.904 .937 .569 r
.86342 .82086 m .85672 .83418 L .8556 .83948 L p F P
0 g
s
.577 .873 .994 r
.4396 .56444 m .44382 .56629 L .4673 .5599 L p F P
0 g
s
.6 .86 .993 r
.46871 .56067 m .4673 .5599 L .44382 .56629 L p F P
0 g
s
.461 .613 .914 r
.7477 .87174 m .74654 .87161 L .74682 .87042 L closepath p F P
0 g
s
.498 .586 .874 r
.74223 .86354 m .74682 .87042 L .74654 .87161 L p F P
0 g
s
.588 .775 .969 r
.26325 .86873 m .24172 .87226 L .24897 .87885 L p F P
0 g
s
.588 .775 .969 r
.24897 .87885 m .27054 .87418 L .26325 .86873 L p F P
0 g
s
.43 .653 .953 r
.23108 .87115 m .24172 .87226 L .24897 .87885 L p F P
0 g
s
.788 .981 .903 r
.26178 .64275 m .27907 .62915 L p .26358 .63566 L F P
0 g
s
.788 .981 .903 r
.26358 .63566 m .25895 .64287 L .26178 .64275 L p F P
0 g
s
.271 .448 .853 r
.70089 .82873 m .69129 .82313 L p .70489 .83818 L F P
0 g
s
.167 .365 .815 r
.69129 .82313 m .70089 .82873 L .69516 .81864 L p F P
0 g
s
.167 .365 .815 r
.69516 .81864 m .69112 .81591 L .69129 .82313 L p F P
0 g
s
.692 .951 .955 r
.3291 .59704 m .33578 .59805 L .35198 .58505 L p F P
0 g
s
.698 .93 .966 r
.35869 .58681 m .35198 .58505 L .33578 .59805 L p F P
0 g
s
.727 .949 .951 r
.33578 .59805 m .3291 .59704 L .30817 .60926 L p F P
0 g
s
.882 .925 .846 r
.34692 .83158 m .34732 .83362 L .35247 .83448 L p F P
0 g
s
.854 .938 .877 r
.34732 .83362 m .35247 .83448 L .34743 .83911 L closepath p F P
0 g
s
.84 .943 .89 r
.34743 .83911 m .33069 .85496 L .32823 .84803 L p F P
0 g
s
.84 .943 .89 r
.34732 .83362 m .34743 .83911 L p .32823 .84803 L F P
0 g
s
.539 .817 .466 r
.40816 .75867 m .39775 .77267 L .4033 .76307 L p F P
0 g
s
.399 .631 .948 r
.24172 .87226 m .23108 .87115 L .22829 .86425 L p F P
0 g
s
.517 .702 .954 r
.7477 .87174 m .77195 .87076 L .7772 .87717 L p F P
0 g
s
.519 .643 .911 r
.76663 .86398 m .77195 .87076 L .7477 .87174 L p F P
0 g
s
.519 .643 .911 r
.75067 .86361 m .76663 .86398 L p .7477 .87174 L F P
0 g
s
.519 .643 .911 r
.7477 .87174 m .74682 .87042 L .75067 .86361 L p F P
0 g
s
.069 .352 .825 r
.82736 .67692 m .82469 .66987 L .81307 .66216 L p F P
0 g
s
.055 .36 .831 r
.80986 .65519 m .81307 .66216 L .82469 .66987 L p F P
0 g
s
0 0 .081 r
.18291 .7907 m .18218 .78394 L .18366 .79723 L p F P
0 g
s
0 0 .081 r
.18366 .79723 m .18411 .80119 L .18291 .7907 L p F P
0 g
s
.009 .283 .781 r
.83951 .69232 m .83703 .69029 L .83177 .68062 L p F P
0 g
s
.859 .897 .861 r
.32963 .85598 m .33069 .85496 L .32823 .84803 L p F P
0 g
s
.859 .897 .861 r
.32823 .84803 m .32246 .85316 L .32963 .85598 L p F P
0 g
s
.791 .854 .898 r
.32963 .85598 m .32246 .85316 L .3033 .86622 L p F P
0 g
s
.272 .599 .951 r
.71923 .59896 m .73832 .603 L .7314 .59674 L p F P
0 g
s
.272 .599 .951 r
.7314 .59674 m .71386 .59312 L .71923 .59896 L p F P
0 g
s
.285 .608 .954 r
.71029 .59244 m .71386 .59312 L .71923 .59896 L p F P
0 g
s
.819 .398 .243 r
.58836 .69403 m .57609 .68959 L .58216 .69874 L p F P
0 g
s
.819 .398 .243 r
.58216 .69874 m .59367 .70341 L .58836 .69403 L p F P
0 g
s
.865 .996 .784 r
.2251 .67782 m .22886 .66783 L .21654 .68231 L p F P
0 g
s
.865 .996 .784 r
.21575 .68901 m .2251 .67782 L p .21654 .68231 L F P
0 g
s
0 .282 .782 r
.66602 .78515 m .6589 .77944 L .65365 .77048 L p F P
0 g
s
.642 .901 .984 r
.38518 .57753 m .38804 .57861 L .4104 .56963 L p F P
0 g
s
.242 .54 .924 r
.75443 .61721 m .76802 .62141 L .77294 .62809 L p F P
0 g
s
.22 .54 .926 r
.75443 .61721 m .76802 .62141 L .76249 .61485 L p F P
0 g
s
.22 .54 .926 r
.76249 .61485 m .74917 .61077 L .75443 .61721 L p F P
0 g
s
.228 .545 .928 r
.74458 .6094 m .74917 .61077 L .75443 .61721 L p F P
0 g
s
.718 .851 .945 r
.29266 .86448 m .27054 .87418 L .27778 .87936 L p F P
0 g
s
.718 .851 .945 r
.27778 .87936 m .29991 .86859 L .29266 .86448 L p F P
0 g
s
0 0 .409 r
.86289 .73471 m .86358 .74197 L .86741 .75228 L p F P
0 g
s
0 0 .55 r
.86358 .74197 m .86289 .73471 L .85755 .72488 L p F P
0 g
s
.52 .644 .911 r
.74682 .87042 m .74223 .86354 L .75067 .86361 L closepath p F P
0 g
s
.788 .981 .903 r
.27907 .62915 m .28168 .62523 L p .26358 .63566 L F P
0 g
s
.78 .969 .92 r
.28168 .62523 m .2843 .62539 L .27907 .62915 L closepath p F P
0 g
s
.27 .447 .852 r
.7066 .83902 m .70489 .83818 L .70501 .83615 L closepath p F P
0 g
s
.271 .448 .853 r
.70489 .83818 m .70501 .83615 L .70089 .82873 L p F P
0 g
s
0 .253 .765 r
.82736 .67692 m .83177 .68062 L .82654 .67143 L p F P
0 g
s
0 .253 .765 r
.82654 .67143 m .82469 .66987 L .82736 .67692 L p F P
0 g
s
.405 .729 .99 r
.61999 .56742 m .6436 .56724 L p .63504 .56243 L F P
0 g
s
.405 .729 .99 r
.63504 .56243 m .61423 .56272 L .61999 .56742 L p F P
0 g
s
.435 .745 .993 r
.59867 .56346 m .61423 .56272 L .61999 .56742 L p F P
0 g
s
.726 .357 .352 r
.55508 .67686 m .5351 .67467 L .54268 .68323 L p F P
0 g
s
.726 .357 .352 r
.54268 .68323 m .56108 .68592 L .55508 .67686 L p F P
0 g
s
.753 .968 .93 r
.2843 .62539 m .30673 .61018 L p .28833 .61715 L F P
0 g
s
.753 .968 .93 r
.28833 .61715 m .28168 .62523 L .2843 .62539 L p F P
0 g
s
0 0 0 r
.43076 .73151 m .44501 .71785 L .43421 .72502 L closepath p F P
0 g
s
0 0 0 r
.42901 .73353 m .43076 .73151 L .43421 .72502 L p F P
0 g
s
.505 .161 .318 r
.50118 .67668 m .50585 .67694 L p .47905 .68897 L F P
0 g
s
.506 .171 .333 r
.50585 .67694 m .50118 .67668 L .50621 .67562 L closepath p F P
0 g
s
0 0 .524 r
.85635 .71767 m .85755 .72488 L .86289 .73471 L p F P
0 g
s
0 .08 .638 r
.85755 .72488 m .85635 .71767 L .84952 .70832 L p F P
0 g
s
.838 .38 .118 r
.60308 .70864 m .59367 .70341 L .59919 .71282 L p F P
0 g
s
.838 .38 .118 r
.60543 .71306 m .60308 .70864 L p .59919 .71282 L F P
0 g
s
.331 .657 .971 r
.68422 .58432 m .70242 .58643 L .69379 .5806 L p F P
0 g
s
.331 .657 .971 r
.69379 .5806 m .67873 .57894 L .68422 .58432 L p F P
0 g
s
.347 .667 .974 r
.6679 .57799 m .67873 .57894 L .68422 .58432 L p F P
0 g
s
.865 .996 .784 r
.21654 .68231 m .21382 .68993 L .21575 .68901 L p F P
0 g
s
.886 .991 .778 r
.21382 .68993 m .21575 .68901 L .21324 .69209 L closepath p F P
0 g
s
.153 .48 .898 r
.77294 .62809 m .78484 .63295 L .77964 .62615 L p F P
0 g
s
.153 .48 .898 r
.77964 .62615 m .76802 .62141 L .77294 .62809 L p F P
0 g
s
0 0 .104 r
.87006 .78899 m .87037 .7817 L .86983 .77037 L p F P
0 g
s
.809 .704 .167 r
.87006 .78899 m .87037 .7817 L p .8688 .8 L F P
0 g
s
.809 .704 .167 r
.8688 .8 m .86909 .79812 L .87006 .78899 L p F P
0 g
s
.437 .545 .869 r
.7066 .83902 m .72491 .84449 L .72376 .85189 L p F P
0 g
s
.394 .522 .868 r
.72491 .84449 m .7066 .83902 L .70501 .83615 L p F P
0 g
s
0 .155 .697 r
.8373 .68521 m .83951 .69232 L .84782 .70116 L p F P
0 g
s
.009 .283 .781 r
.83177 .68062 m .8373 .68521 L .83951 .69232 L p F P
0 g
s
0 .191 .719 r
.83951 .69232 m .84782 .70116 L .84952 .70832 L p F P
0 g
s
.411 .747 .994 r
.59867 .56346 m .61423 .56272 L p .58499 .55941 L F P
0 g
s
.411 .747 .994 r
.58499 .55941 m .58573 .55996 L .59867 .56346 L p F P
0 g
s
0 .052 .618 r
.84782 .70116 m .84952 .70832 L .85635 .71767 L p F P
0 g
s
.823 .991 .738 r
.39775 .77267 m .4033 .76307 L .39063 .77782 L p F P
0 g
s
.823 .991 .738 r
.39159 .78095 m .39775 .77267 L p .39063 .77782 L F P
0 g
s
.872 .984 .703 r
.21324 .69209 m .20379 .70562 L .20627 .69615 L p F P
0 g
s
.872 .984 .703 r
.21382 .68993 m .21324 .69209 L p .20627 .69615 L F P
0 g
s
.901 .946 .59 r
.86471 .81346 m .86342 .82086 L .85672 .83418 L p F P
0 g
s
.81 .817 .335 r
.86342 .82086 m .86471 .81346 L .8687 .80085 L p F P
0 g
s
.771 .646 .087 r
.18271 .7723 m .1827 .77174 L .18215 .78271 L p F P
0 g
s
.771 .646 .087 r
.18215 .78271 m .18218 .78394 L .18271 .7723 L p F P
0 g
s
.595 .255 .363 r
.50621 .67562 m .53481 .67465 L p .51575 .68308 L F P
0 g
s
.595 .255 .363 r
.51575 .68308 m .50585 .67694 L .50621 .67562 L p F P
0 g
s
.635 .3 .386 r
.53489 .67442 m .53481 .67465 L .50621 .67562 L p F P
0 g
s
.877 .858 .407 r
.18924 .73994 m .19015 .73115 L .18612 .74312 L p F P
0 g
s
.877 .858 .407 r
.18612 .74312 m .18528 .75185 L .18924 .73994 L p F P
0 g
s
.288 .545 .92 r
.20803 .85246 m .20775 .85119 L .22563 .85724 L p F P
0 g
s
.143 .397 .846 r
.20775 .85119 m .20803 .85246 L .20681 .85068 L closepath p F P
0 g
s
.18 .484 .899 r
.79276 .64121 m .79003 .64009 L .78484 .63295 L p F P
0 g
s
.719 .613 .045 r
.1827 .77174 m .18298 .76332 L .18246 .77431 L p F P
0 g
s
.719 .613 .045 r
.18246 .77431 m .18215 .78271 L .1827 .77174 L p F P
0 g
s
.781 .28 0 r
.61734 .72342 m .60913 .7179 L .61608 .72699 L p F P
0 g
s
.781 .28 0 r
.61608 .72699 m .62396 .73261 L .61734 .72342 L p F P
0 g
s
.793 .996 .865 r
.25384 .64394 m .26358 .63566 L .25895 .64287 L closepath p F P
0 g
s
.812 .996 .86 r
.24439 .65234 m .25384 .64394 L .25895 .64287 L p F P
0 g
s
.361 .503 .866 r
.70501 .83615 m .70089 .82873 L .7063 .83063 L closepath p F P
0 g
s
.394 .522 .868 r
.70501 .83615 m .7063 .83063 L p .72491 .84449 L F P
0 g
s
.705 .909 .967 r
.82407 .8658 m .80623 .87539 L .80124 .87085 L p F P
0 g
s
.616 .819 .978 r
.7772 .87717 m .80124 .87085 L .80623 .87539 L p F P
0 g
s
.591 .788 .974 r
.80124 .87085 m .7772 .87717 L .77195 .87076 L p F P
0 g
s
.684 .321 .352 r
.53481 .67465 m .53489 .67442 L .5351 .67467 L closepath p F P
0 g
s
.542 .829 .998 r
.49297 .55564 m .49776 .55853 L .51929 .55378 L closepath p F P
0 g
s
.575 .842 .995 r
.49776 .55853 m .49297 .55564 L .47978 .55775 L p F P
0 g
s
.823 .991 .738 r
.39063 .77782 m .38833 .78282 L .39159 .78095 L p F P
0 g
s
.837 .992 .737 r
.38833 .78282 m .39159 .78095 L .38662 .78691 L closepath p F P
0 g
s
.681 .312 .339 r
.5351 .67467 m .53481 .67465 L .53193 .68247 L p F P
0 g
s
.681 .312 .339 r
.53193 .68247 m .54268 .68323 L .5351 .67467 L p F P
0 g
s
.361 .52 .88 r
.72376 .85189 m .73672 .85509 L .73116 .8465 L p F P
0 g
s
.361 .52 .88 r
.73116 .8465 m .72491 .84449 L .72376 .85189 L p F P
0 g
s
.333 .672 .976 r
.67873 .57894 m .6679 .57799 L .65797 .57253 L p F P
0 g
s
.728 .971 .931 r
.30673 .61018 m .30817 .60926 L .30726 .6102 L closepath p F P
0 g
s
.595 .255 .363 r
.53481 .67465 m .53193 .68247 L .51575 .68308 L p F P
0 g
s
.104 .345 .814 r
.20681 .85068 m .20775 .85119 L .20647 .8437 L p F P
0 g
s
.104 .345 .814 r
.20647 .8437 m .19984 .83938 L .20681 .85068 L p F P
0 g
s
0 .182 .716 r
.19626 .83558 m .19984 .83938 L .20681 .85068 L p F P
0 g
s
.568 .848 .997 r
.4673 .5599 m .46871 .56067 L .47978 .55775 L closepath p F P
0 g
s
.516 .809 .999 r
.52089 .5537 m .5268 .55759 L .54468 .55444 L closepath p F P
0 g
s
.55 .823 .997 r
.5268 .55759 m .52089 .5537 L .51929 .55378 L p F P
0 g
s
.882 .922 .529 r
.19089 .72957 m .1961 .71864 L .19533 .72279 L closepath p F P
0 g
s
.893 .923 .534 r
.19015 .73115 m .19089 .72957 L .19533 .72279 L p F P
0 g
s
0 .143 .688 r
.19984 .83938 m .19626 .83558 L .19489 .83026 L closepath p F P
0 g
s
.602 .244 .334 r
.50353 .6838 m .50585 .67694 L .51575 .68308 L closepath p F P
0 g
s
.505 .161 .318 r
.50585 .67694 m .50353 .6838 L .47905 .68897 L p F P
0 g
s
.661 .926 .973 r
.35869 .58681 m .38105 .57642 L p .3539 .58383 L F P
0 g
s
.661 .926 .973 r
.3539 .58383 m .35198 .58505 L .35869 .58681 L p F P
0 g
s
.627 .919 .978 r
.38105 .57642 m .38518 .57753 L .40492 .56751 L p F P
0 g
s
.642 .901 .984 r
.4104 .56963 m .40492 .56751 L .38518 .57753 L p F P
0 g
s
.636 .171 0 r
.64222 .7541 m .63704 .74785 L .63041 .73857 L p F P
0 g
s
.722 .23 0 r
.63041 .73857 m .62396 .73261 L .63068 .74187 L p F P
0 g
s
.722 .23 0 r
.63068 .74187 m .63704 .74785 L .63041 .73857 L p F P
0 g
s
.778 .986 .737 r
.38662 .78691 m .37468 .80141 L .37718 .79281 L p F P
0 g
s
.778 .986 .737 r
.38833 .78282 m .38662 .78691 L p .37718 .79281 L F P
0 g
s
.715 .975 .923 r
.32168 .59602 m .29914 .60997 L .30673 .61018 L p F P
0 g
s
.715 .975 .923 r
.32197 .59602 m .32168 .59602 L p .30673 .61018 L F P
0 g
s
.715 .975 .923 r
.30673 .61018 m .30817 .60926 L .32197 .59602 L p F P
0 g
s
.753 .968 .93 r
.30673 .61018 m .29914 .60997 L .28833 .61715 L p F P
0 g
s
.205 .545 .929 r
.74917 .61077 m .74458 .6094 L .73832 .603 L p F P
0 g
s
.252 .505 .901 r
.20775 .85119 m .20647 .8437 L p .22494 .855 L F P
0 g
s
.252 .505 .901 r
.22494 .855 m .22563 .85724 L .20775 .85119 L p F P
0 g
s
.86 .984 .702 r
.20704 .69509 m .21654 .68231 L .21382 .68993 L closepath p F P
0 g
s
.872 .984 .703 r
.20627 .69615 m .20704 .69509 L .21382 .68993 L p F P
0 g
s
0 .282 .782 r
.65365 .77048 m .65343 .7698 L p .66602 .78515 L F P
0 g
s
0 .25 .762 r
.65365 .77048 m .65309 .76951 L .65343 .7698 L closepath p F P
0 g
s
.719 .956 .948 r
.32197 .59602 m .3291 .59704 L .30817 .60926 L closepath p F P
0 g
s
0 0 .527 r
.19302 .82619 m .18871 .81884 L .18754 .81241 L closepath p F P
0 g
s
0 0 .525 r
.18871 .81884 m .19302 .82619 L .19489 .83026 L p F P
0 g
s
0 0 .05 r
.86965 .7631 m .86983 .77037 L .87037 .7817 L p F P
0 g
s
0 0 .269 r
.86983 .77037 m .86965 .7631 L .86741 .75228 L p F P
0 g
s
.755 .986 .901 r
.27656 .62568 m .28833 .61715 L .28168 .62523 L closepath p F P
0 g
s
.788 .981 .903 r
.28168 .62523 m .27656 .62568 L .26358 .63566 L p F P
0 g
s
.393 .707 .985 r
.64926 .57231 m .65797 .57253 L .64713 .56731 L p F P
0 g
s
.393 .707 .985 r
.64713 .56731 m .6436 .56724 L .64926 .57231 L p F P
0 g
s
.489 .788 .998 r
.55158 .55481 m .55587 .55787 L .56534 .55662 L closepath p F P
0 g
s
.525 .803 .997 r
.55587 .55787 m .55158 .55481 L .54468 .55444 L p F P
0 g
s
.626 .16 0 r
.64151 .75401 m .63704 .74785 L .64222 .7541 L p F P
0 g
s
.732 .322 .27 r
.57609 .68959 m .58216 .69874 L .56782 .69486 L p F P
0 g
s
.732 .322 .27 r
.56606 .68711 m .57609 .68959 L p .56782 .69486 L F P
0 g
s
.573 .876 .994 r
.45557 .55471 m .4329 .56165 L .4396 .56444 L p F P
0 g
s
.573 .876 .994 r
.4396 .56444 m .46218 .55758 L .45557 .55471 L p F P
0 g
s
.577 .873 .994 r
.4673 .5599 m .46218 .55758 L .4396 .56444 L p F P
0 g
s
.101 .413 .862 r
.80986 .65519 m .8061 .6483 L .79276 .64121 L p F P
0 g
s
.07 .406 .859 r
.78844 .63442 m .79276 .64121 L .8061 .6483 L p F P
0 g
s
.18 .484 .899 r
.78484 .63295 m .78844 .63442 L .79276 .64121 L p F P
0 g
s
0 .263 .771 r
.8373 .68521 m .83177 .68062 L .82654 .67143 L p F P
0 g
s
.317 0 .206 r
.45372 .70942 m .47349 .69842 L .45518 .70564 L closepath p F P
0 g
s
0 0 0 r
.45518 .70564 m .45372 .70942 L .44501 .71785 L p F P
0 g
s
.881 .957 .616 r
.20379 .70562 m .20627 .69615 L .19842 .70926 L p F P
0 g
s
.881 .957 .616 r
.19842 .70926 m .1961 .71864 L .20379 .70562 L p F P
0 g
s
.79 .301 .045 r
.60051 .71357 m .60543 .71306 L .60913 .7179 L closepath p F P
0 g
s
.838 .38 .118 r
.59919 .71282 m .60051 .71357 L .60543 .71306 L p F P
0 g
s
0 .212 .735 r
.65343 .7698 m .65309 .76951 L .64729 .76095 L p F P
0 g
s
.522 .639 .906 r
.75067 .86361 m .74223 .86354 L .73672 .85509 L p F P
0 g
s
.267 .611 .956 r
.71386 .59312 m .71029 .59244 L .70242 .58643 L p F P
0 g
s
0 .282 .782 r
.65343 .7698 m .66333 .77836 L .66602 .78515 L p F P
0 g
s
0 .161 .693 r
.6498 .7632 m .65343 .7698 L .66333 .77836 L p F P
0 g
s
0 .212 .735 r
.64729 .76095 m .6498 .7632 L .65343 .7698 L p F P
0 g
s
.793 .871 .905 r
.30079 .85929 m .29266 .86448 L .29991 .86859 L p F P
0 g
s
.793 .871 .905 r
.29991 .86859 m .3033 .86622 L .30079 .85929 L p F P
0 g
s
.901 .946 .59 r
.85672 .83418 m .85782 .82688 L .86471 .81346 L p F P
0 g
s
.906 .984 .747 r
.85672 .83418 m .85259 .84034 L .84823 .84021 L p F P
0 g
s
.906 .984 .747 r
.84823 .84021 m .85782 .82688 L .85672 .83418 L p F P
0 g
s
.463 .773 .997 r
.58499 .55941 m .58359 .55955 L .58573 .55996 L closepath p F P
0 g
s
.482 .136 .303 r
.47905 .68897 m .50353 .6838 L p .47952 .69661 L F P
0 g
s
.482 .136 .303 r
.47952 .69661 m .47652 .69671 L .47905 .68897 L p F P
0 g
s
.323 0 .217 r
.47905 .68897 m .47652 .69671 L .47349 .69842 L p F P
0 g
s
.535 .857 .997 r
.46218 .55758 m .4673 .5599 L .47978 .55775 L p F P
0 g
s
.558 .754 .969 r
.25593 .86293 m .23447 .86521 L .24172 .87226 L p F P
0 g
s
.558 .754 .969 r
.24172 .87226 m .26325 .86873 L .25593 .86293 L p F P
0 g
s
.399 .631 .948 r
.22829 .86425 m .23447 .86521 L .24172 .87226 L p F P
0 g
s
.727 .672 .123 r
.8687 .80085 m .8688 .8 L .86909 .79812 L closepath p F P
0 g
s
.767 .9 .935 r
.32246 .85316 m .3033 .86622 L .30079 .85929 L p F P
0 g
s
.452 .777 .998 r
.58499 .55941 m .58359 .55955 L .56534 .55662 L p F P
0 g
s
.881 .98 .832 r
.37468 .80141 m .37718 .79281 L .36321 .80798 L p F P
0 g
s
.881 .98 .832 r
.36839 .8091 m .37468 .80141 L p .36321 .80798 L F P
0 g
s
.883 .925 .846 r
.34531 .83329 m .34692 .83158 L .34732 .83362 L closepath p F P
0 g
s
.84 .943 .89 r
.32823 .84803 m .34531 .83329 L .34732 .83362 L p F P
0 g
s
0 .271 .775 r
.6784 .80056 m .67638 .79368 L .66602 .78515 L p F P
0 g
s
0 .201 .728 r
.66333 .77836 m .66602 .78515 L .67638 .79368 L p F P
0 g
s
.705 .909 .967 r
.82653 .86043 m .82407 .8658 L p .80124 .87085 L F P
0 g
s
.756 .931 .945 r
.82407 .8658 m .82653 .86043 L .82978 .86236 L closepath p F P
0 g
s
0 0 .322 r
.18657 .80906 m .18411 .80119 L .18366 .79723 L closepath p F P
0 g
s
0 0 .301 r
.18411 .80119 m .18657 .80906 L .18754 .81241 L p F P
0 g
s
.354 .505 .87 r
.7063 .83063 m .70089 .82873 L .69516 .81864 L p F P
0 g
s
.417 .753 .995 r
.60255 .55386 m .57905 .55527 L .58499 .55941 L p F P
0 g
s
.417 .753 .995 r
.58499 .55941 m .60842 .5582 L .60255 .55386 L p F P
0 g
s
.411 .747 .994 r
.61423 .56272 m .60842 .5582 L .58499 .55941 L p F P
0 g
s
.452 .777 .998 r
.56534 .55662 m .57905 .55527 L .58499 .55941 L p F P
0 g
s
.863 .996 .802 r
.84501 .84882 m .85259 .84034 L .84823 .84021 L p F P
0 g
s
.87 .869 .424 r
.8688 .8 m .8687 .80085 L .86471 .81346 L p F P
0 g
s
.607 .892 .989 r
.40492 .56751 m .4104 .56963 L .4329 .56165 L p F P
0 g
s
0 0 .224 r
.86673 .74505 m .86741 .75228 L .86965 .7631 L p F P
0 g
s
0 0 .409 r
.86741 .75228 m .86673 .74505 L .86289 .73471 L p F P
0 g
s
.094 .352 .821 r
.68941 .80893 m .6784 .80056 L p .69112 .81591 L F P
0 g
s
0 .266 .772 r
.6784 .80056 m .68941 .80893 L .68367 .79976 L p F P
0 g
s
0 .266 .772 r
.68367 .79976 m .67638 .79368 L .6784 .80056 L p F P
0 g
s
.847 .937 .883 r
.82653 .86043 m .82978 .86236 L .84501 .84882 L p F P
0 g
s
.881 .98 .832 r
.36321 .80798 m .36289 .80993 L .36839 .8091 L p F P
0 g
s
.866 .985 .842 r
.36289 .80993 m .36839 .8091 L .3614 .81631 L closepath p F P
0 g
s
.055 .36 .831 r
.82132 .66279 m .80986 .65519 L p .82469 .66987 L F P
0 g
s
0 .33 .815 r
.80986 .65519 m .82132 .66279 L .81615 .65501 L p F P
0 g
s
0 .33 .815 r
.81615 .65501 m .8061 .6483 L .80986 .65519 L p F P
0 g
s
.2 .541 .927 r
.74917 .61077 m .76249 .61485 L .75634 .60841 L p F P
0 g
s
.2 .541 .927 r
.75634 .60841 m .74389 .60464 L .74917 .61077 L p F P
0 g
s
.205 .545 .929 r
.73832 .603 m .74389 .60464 L .74917 .61077 L p F P
0 g
s
.847 .937 .883 r
.84501 .84882 m .84716 .8413 L p .82653 .86043 L F P
0 g
s
.863 .996 .802 r
.84823 .84021 m .84716 .8413 L .84501 .84882 L p F P
0 g
s
.256 .603 .953 r
.71386 .59312 m .7314 .59674 L .72379 .59063 L p F P
0 g
s
.256 .603 .953 r
.72379 .59063 m .70847 .58755 L .71386 .59312 L p F P
0 g
s
.267 .611 .956 r
.70242 .58643 m .70847 .58755 L .71386 .59312 L p F P
0 g
s
.696 .844 .954 r
.28536 .8602 m .26325 .86873 L .27054 .87418 L p F P
0 g
s
.696 .844 .954 r
.27054 .87418 m .29266 .86448 L .28536 .8602 L p F P
0 g
s
.825 .389 .202 r
.59367 .70341 m .58216 .69874 L .58837 .70795 L p F P
0 g
s
.825 .389 .202 r
.58837 .70795 m .59919 .71282 L .59367 .70341 L p F P
0 g
s
.797 .746 .224 r
.18528 .75185 m .18612 .74312 L .18379 .75464 L p F P
0 g
s
.797 .746 .224 r
.18379 .75464 m .18298 .76332 L .18528 .75185 L p F P
0 g
s
.837 .991 .856 r
.3614 .81631 m .34692 .83158 L .34664 .82389 L p F P
0 g
s
.837 .991 .856 r
.36289 .80993 m .3614 .81631 L p .34664 .82389 L F P
0 g
s
.732 .322 .27 r
.56782 .69486 m .56414 .6903 L .56606 .68711 L p F P
0 g
s
.756 .35 .283 r
.56414 .6903 m .56108 .68592 L .56606 .68711 L closepath p F P
0 g
s
0 0 .176 r
.18218 .78394 m .18215 .78271 L .1836 .79316 L p F P
0 g
s
0 0 .176 r
.1836 .79316 m .18366 .79723 L .18218 .78394 L p F P
0 g
s
.535 .857 .997 r
.47978 .55775 m .49139 .55483 L p .46218 .55758 L F P
0 g
s
.545 .852 .998 r
.49139 .55483 m .47978 .55775 L .49297 .55564 L closepath p F P
0 g
s
.105 .345 .813 r
.19984 .83938 m .19489 .83026 L p .20533 .83609 L F P
0 g
s
.105 .345 .813 r
.20533 .83609 m .20647 .8437 L .19984 .83938 L p F P
0 g
s
.887 .841 .378 r
.86566 .80592 m .86904 .79359 L .8688 .8 L closepath p F P
0 g
s
.809 .704 .167 r
.87037 .7817 m .86904 .79359 L .8688 .8 L p F P
0 g
s
.87 .869 .424 r
.86566 .80592 m .8688 .8 L p .86471 .81346 L F P
0 g
s
.095 .353 .822 r
.69516 .81864 m .69112 .81591 L .68955 .80916 L closepath p F P
0 g
s
.094 .352 .821 r
.69112 .81591 m .68955 .80916 L .68941 .80893 L p F P
0 g
s
.846 .92 .882 r
.3273 .84059 m .31521 .85034 L .32246 .85316 L p F P
0 g
s
.846 .92 .882 r
.32246 .85316 m .32823 .84803 L .3273 .84059 L p F P
0 g
s
.767 .9 .935 r
.30079 .85929 m .31521 .85034 L .32246 .85316 L p F P
0 g
s
.367 .604 .94 r
.23447 .86521 m .22829 .86425 L .22563 .85724 L p F P
0 g
s
.816 .949 .908 r
.34531 .83329 m .32823 .84803 L .3273 .84059 L p F P
0 g
s
.855 .916 .516 r
.1961 .71864 m .19842 .70926 L .19235 .72186 L p F P
0 g
s
.855 .916 .516 r
.19089 .72957 m .1961 .71864 L p .19235 .72186 L F P
0 g
s
0 0 .372 r
.86169 .72753 m .86289 .73471 L .86673 .74505 L p F P
0 g
s
0 0 .524 r
.86289 .73471 m .86169 .72753 L .85635 .71767 L p F P
0 g
s
.683 .95 .956 r
.3291 .59704 m .35151 .58499 L p .32276 .59541 L F P
0 g
s
.683 .95 .956 r
.32276 .59541 m .32197 .59602 L .3291 .59704 L p F P
0 g
s
.692 .951 .955 r
.35198 .58505 m .35151 .58499 L .3291 .59704 L p F P
0 g
s
.884 .95 .846 r
.34531 .83329 m .34692 .83158 L .34664 .82389 L p F P
0 g
s
.125 .477 .897 r
.77964 .62615 m .76802 .62141 L .76249 .61485 L p F P
0 g
s
0 .239 .756 r
.82654 .67143 m .82469 .66987 L .82175 .66348 L closepath p F P
0 g
s
.055 .36 .831 r
.82469 .66987 m .82175 .66348 L .82132 .66279 L p F P
0 g
s
.884 .95 .846 r
.34664 .82389 m .33808 .83213 L .34531 .83329 L p F P
0 g
s
.816 .949 .908 r
.3273 .84059 m .33808 .83213 L .34531 .83329 L p F P
0 g
s
.712 .299 .263 r
.56108 .68592 m .54268 .68323 L .55044 .69185 L p F P
0 g
s
.712 .299 .263 r
.56414 .6903 m .56108 .68592 L p .55044 .69185 L F P
0 g
s
.432 .78 .997 r
.56534 .55662 m .57905 .55527 L p .54979 .55368 L F P
0 g
s
.432 .78 .997 r
.54979 .55368 m .55158 .55481 L .56534 .55662 L p F P
0 g
s
.823 .991 .738 r
.38439 .7851 m .39063 .77782 L .38833 .78282 L closepath p F P
0 g
s
.778 .986 .737 r
.37718 .79281 m .38439 .7851 L .38833 .78282 L p F P
0 g
s
.472 .625 .918 r
.75067 .86361 m .76663 .86398 L .76126 .85691 L p F P
0 g
s
.472 .625 .918 r
.76126 .85691 m .75237 .85615 L .75067 .86361 L p F P
0 g
s
.522 .639 .906 r
.73672 .85509 m .75237 .85615 L .75067 .86361 L p F P
0 g
s
.258 0 .124 r
.45176 .71354 m .45372 .70942 L .47349 .69842 L p F P
0 g
s
.038 0 .02 r
.45176 .71354 m .45372 .70942 L .44501 .71785 L closepath p F P
0 g
s
0 0 .209 r
.18215 .78271 m .18246 .77431 L .18392 .78478 L p F P
0 g
s
0 0 .209 r
.18392 .78478 m .1836 .79316 L .18215 .78271 L p F P
0 g
s
.319 .677 .977 r
.67319 .57379 m .65797 .57253 L .64713 .56731 L p F P
0 g
s
.333 .672 .976 r
.65797 .57253 m .67319 .57379 L .67873 .57894 L p F P
0 g
s
.767 .264 .006 r
.60913 .7179 m .61608 .72699 L .60656 .72179 L p F P
0 g
s
.767 .264 .006 r
.60051 .71357 m .60913 .7179 L p .60656 .72179 L F P
0 g
s
.398 .735 .991 r
.61423 .56272 m .63504 .56243 L .62157 .55794 L p F P
0 g
s
.398 .735 .991 r
.62157 .55794 m .60842 .5582 L .61423 .56272 L p F P
0 g
s
0 0 0 r
.44501 .71785 m .45176 .71354 L p .43014 .73249 L F P
0 g
s
0 0 0 r
.43014 .73249 m .43076 .73151 L .44501 .71785 L p F P
0 g
s
.32 .662 .973 r
.67873 .57894 m .69379 .5806 L .68437 .57495 L p F P
0 g
s
.32 .662 .973 r
.68437 .57495 m .67319 .57379 L .67873 .57894 L p F P
0 g
s
0 0 .494 r
.85463 .71053 m .85635 .71767 L .86169 .72753 L p F P
0 g
s
0 .052 .618 r
.85635 .71767 m .85463 .71053 L .84782 .70116 L p F P
0 g
s
0 0 0 r
.43014 .73249 m .43076 .73151 L .42901 .73353 L closepath p F P
0 g
s
0 .155 .697 r
.84782 .70116 m .84559 .69408 L .8373 .68521 L p F P
0 g
s
0 .132 .68 r
.83456 .67819 m .8373 .68521 L .84559 .69408 L p F P
0 g
s
0 .263 .771 r
.82654 .67143 m .83456 .67819 L .8373 .68521 L p F P
0 g
s
.153 .481 .899 r
.78844 .63442 m .78484 .63295 L .77964 .62615 L p F P
0 g
s
.62 .921 .976 r
.39654 .56534 m .37398 .5746 L .38105 .57642 L p F P
0 g
s
.62 .921 .976 r
.38105 .57642 m .40352 .56713 L .39654 .56534 L p F P
0 g
s
.661 .926 .973 r
.38105 .57642 m .37398 .5746 L .3539 .58383 L p F P
0 g
s
.627 .919 .978 r
.40492 .56751 m .40352 .56713 L .38105 .57642 L p F P
0 g
s
.591 .788 .974 r
.77195 .87076 m .79616 .86577 L .80124 .87085 L p F P
0 g
s
.567 .761 .97 r
.79616 .86577 m .77195 .87076 L .76663 .86398 L p F P
0 g
s
.394 .522 .868 r
.7063 .83063 m .72442 .83745 L .72491 .84449 L p F P
0 g
s
.264 .497 .892 r
.70641 .82335 m .7063 .83063 L .72442 .83745 L p F P
0 g
s
.354 .505 .87 r
.69516 .81864 m .70641 .82335 L .7063 .83063 L p F P
0 g
s
0 0 0 r
.42901 .73353 m .43014 .73249 L .42555 .73961 L p F P
0 g
s
0 0 0 r
.42555 .73961 m .41616 .74829 L .42901 .73353 L p F P
0 g
s
.501 .834 .999 r
.49139 .55483 m .49297 .55564 L .51929 .55378 L p F P
0 g
s
0 .022 .595 r
.84559 .69408 m .84782 .70116 L .85463 .71053 L p F P
0 g
s
.816 1 .827 r
.24439 .65234 m .24848 .64509 L p .23452 .65712 L F P
0 g
s
.816 1 .827 r
.23081 .66583 m .24439 .65234 L p .23452 .65712 L F P
0 g
s
.811 .996 .859 r
.24848 .64509 m .25384 .64394 L .24439 .65234 L closepath p F P
0 g
s
0 .125 .67 r
.19464 .8281 m .19489 .83026 L .19302 .82619 L closepath p F P
0 g
s
.105 .345 .813 r
.19489 .83026 m .19464 .8281 L .20533 .83609 L p F P
0 g
s
0 0 .05 r
.87037 .7817 m .87019 .77446 L .86965 .7631 L p F P
0 g
s
.835 .724 .197 r
.87019 .77446 m .87037 .7817 L .86904 .79359 L p F P
0 g
s
0 .242 .757 r
.83456 .67819 m .82654 .67143 L .82175 .66348 L p F P
0 g
s
.779 .996 .866 r
.25384 .64394 m .26358 .63566 L p .2512 .64118 L F P
0 g
s
.779 .996 .866 r
.2512 .64118 m .24848 .64509 L .25384 .64394 L p F P
0 g
s
.705 .909 .967 r
.80124 .87085 m .82504 .85946 L .82653 .86043 L p F P
0 g
s
.684 .88 .971 r
.82504 .85946 m .80124 .87085 L .79616 .86577 L p F P
0 g
s
0 .125 .646 r
.6498 .7632 m .64729 .76095 L .64151 .75401 L p F P
0 g
s
.481 .804 1 r
.54979 .55368 m .54468 .55444 L .55158 .55481 L closepath p F P
0 g
s
.779 .996 .866 r
.26358 .63566 m .27027 .62628 L p .2512 .64118 L F P
0 g
s
.777 .988 .894 r
.27027 .62628 m .27656 .62568 L .26358 .63566 L closepath p F P
0 g
s
.491 .621 .907 r
.75237 .85615 m .73672 .85509 L .73116 .8465 L p F P
0 g
s
.816 1 .827 r
.23452 .65712 m .22955 .66626 L .23081 .66583 L p F P
0 g
s
.844 .998 .82 r
.22955 .66626 m .23081 .66583 L .22886 .66783 L closepath p F P
0 g
s
.77 .268 0 r
.62396 .73261 m .61608 .72699 L .62309 .73617 L p F P
0 g
s
.77 .268 0 r
.62309 .73617 m .63068 .74187 L .62396 .73261 L p F P
0 g
s
0 .136 .674 r
.19302 .82619 m .18754 .81241 L p .19414 .8202 L F P
0 g
s
0 .136 .674 r
.19414 .8202 m .19464 .8281 L .19302 .82619 L p F P
0 g
s
.825 .994 .752 r
.22886 .66783 m .21654 .68231 L .22091 .67207 L p F P
0 g
s
.825 .994 .752 r
.22955 .66626 m .22886 .66783 L p .22091 .67207 L F P
0 g
s
.922 .954 .623 r
.8656 .8061 m .86471 .81346 L .85782 .82688 L p F P
0 g
s
.87 .869 .424 r
.86471 .81346 m .8656 .8061 L .86566 .80592 L p F P
0 g
s
0 0 .465 r
.18366 .79723 m .1836 .79316 L .18737 .803 L p F P
0 g
s
0 0 .465 r
.18657 .80906 m .18366 .79723 L p .18737 .803 L F P
0 g
s
0 0 0 r
.43014 .73249 m .44805 .72128 L p .43285 .73523 L F P
0 g
s
0 0 0 r
.43285 .73523 m .42555 .73961 L .43014 .73249 L p F P
0 g
s
0 0 0 r
.45176 .71354 m .44805 .72128 L .43014 .73249 L p F P
0 g
s
.182 .545 .928 r
.74389 .60464 m .73832 .603 L .7314 .59674 L p F P
0 g
s
.467 .807 .999 r
.54468 .55444 m .54979 .55368 L p .52058 .55352 L F P
0 g
s
.467 .807 .999 r
.52058 .55352 m .52089 .5537 L .54468 .55444 L p F P
0 g
s
.6 .238 .328 r
.51575 .68308 m .50353 .6838 L .5007 .69195 L p F P
0 g
s
.482 .136 .303 r
.50353 .6838 m .5007 .69195 L .47952 .69661 L p F P
0 g
s
.293 .48 .871 r
.70641 .82335 m .69516 .81864 L .68955 .80916 L p F P
0 g
s
.249 .613 .956 r
.70847 .58755 m .70242 .58643 L .69379 .5806 L p F P
0 g
s
0 0 0 r
.41616 .74829 m .42555 .73961 L p .41417 .75181 L F P
0 g
s
0 0 0 r
.40762 .75807 m .41616 .74829 L p .41417 .75181 L F P
0 g
s
.501 .834 .999 r
.51929 .55378 m .52058 .55352 L p .49139 .55483 L F P
0 g
s
.513 .828 1 r
.52058 .55352 m .51929 .55378 L .52089 .5537 L closepath p F P
0 g
s
.681 .309 .335 r
.54268 .68323 m .53193 .68247 L .52894 .69031 L p F P
0 g
s
.681 .309 .335 r
.52894 .69031 m .55044 .69185 L .54268 .68323 L p F P
0 g
s
.525 .728 .967 r
.24858 .85668 m .2272 .85757 L .23447 .86521 L p F P
0 g
s
.525 .728 .967 r
.23447 .86521 m .25593 .86293 L .24858 .85668 L p F P
0 g
s
.367 .604 .94 r
.22563 .85724 m .2272 .85757 L .23447 .86521 L p F P
0 g
s
.742 .985 .902 r
.27656 .62568 m .28833 .61715 L p .27249 .62374 L F P
0 g
s
.742 .985 .902 r
.27249 .62374 m .27027 .62628 L .27656 .62568 L p F P
0 g
s
.6 .238 .328 r
.5007 .69195 m .52789 .69035 L .51575 .68308 L p F P
0 g
s
.605 .229 .304 r
.53193 .68247 m .51575 .68308 L .52789 .69035 L p F P
0 g
s
.714 .22 0 r
.64151 .75401 m .63704 .74785 L .63068 .74187 L p F P
0 g
s
.855 .916 .516 r
.19235 .72186 m .19025 .73056 L .19089 .72957 L p F P
0 g
s
.892 .922 .532 r
.19025 .73056 m .19089 .72957 L .19015 .73115 L closepath p F P
0 g
s
.07 .406 .859 r
.8061 .6483 m .80177 .64151 L .78844 .63442 L p F P
0 g
s
.037 .399 .854 r
.78354 .62773 m .78844 .63442 L .80177 .64151 L p F P
0 g
s
.153 .481 .899 r
.77964 .62615 m .78354 .62773 L .78844 .63442 L p F P
0 g
s
.498 .835 .998 r
.50794 .54699 m .48495 .55177 L .49139 .55483 L p F P
0 g
s
.498 .835 .998 r
.49139 .55483 m .5143 .55021 L .50794 .54699 L p F P
0 g
s
.501 .834 .999 r
.52058 .55352 m .5143 .55021 L .49139 .55483 L p F P
0 g
s
.535 .857 .997 r
.49139 .55483 m .48495 .55177 L .46218 .55758 L p F P
0 g
s
0 0 .465 r
.18737 .803 m .18745 .81114 L .18657 .80906 L p F P
0 g
s
0 0 .446 r
.18745 .81114 m .18754 .81241 L .18657 .80906 L closepath p F P
0 g
s
0 .136 .674 r
.18754 .81241 m .18745 .81114 L .19414 .8202 L p F P
0 g
s
.464 .81 .998 r
.53745 .54654 m .5143 .55021 L .52058 .55352 L p F P
0 g
s
.464 .81 .998 r
.52058 .55352 m .54365 .55005 L .53745 .54654 L p F P
0 g
s
.467 .807 .999 r
.54979 .55368 m .54365 .55005 L .52058 .55352 L p F P
0 g
s
.837 .839 .37 r
.19015 .73115 m .19025 .73056 L .18666 .73967 L p F P
0 g
s
.837 .839 .37 r
.18666 .73967 m .18612 .74312 L .19015 .73115 L p F P
0 g
s
.782 .357 .241 r
.58216 .69874 m .56782 .69486 L .57509 .70375 L p F P
0 g
s
.782 .357 .241 r
.57509 .70375 m .58837 .70795 L .58216 .69874 L p F P
0 g
s
.29 .494 .883 r
.72491 .84449 m .73116 .8465 L .72557 .83791 L p F P
0 g
s
.29 .494 .883 r
.72557 .83791 m .72442 .83745 L .72491 .84449 L p F P
0 g
s
.605 .229 .304 r
.52789 .69035 m .52894 .69031 L .53193 .68247 L p F P
0 g
s
.806 .993 .752 r
.2223 .67049 m .23452 .65712 L .22955 .66626 L closepath p F P
0 g
s
.825 .994 .752 r
.22091 .67207 m .2223 .67049 L .22955 .66626 L p F P
0 g
s
.731 .322 .274 r
.56212 .69376 m .56414 .6903 L .56782 .69486 L closepath p F P
0 g
s
.712 .299 .263 r
.55044 .69185 m .56212 .69376 L .56414 .6903 L p F P
0 g
s
.381 .711 .986 r
.6403 .56442 m .6436 .56724 L .64713 .56731 L closepath p F P
0 g
s
.405 .729 .99 r
.6436 .56724 m .6403 .56442 L .63504 .56243 L p F P
0 g
s
.534 .859 .996 r
.47844 .5488 m .45557 .55471 L .46218 .55758 L p F P
0 g
s
.534 .859 .996 r
.46218 .55758 m .48495 .55177 L .47844 .5488 L p F P
0 g
s
0 0 0 r
.18298 .76332 m .18379 .75464 L .18325 .76567 L p F P
0 g
s
0 0 0 r
.18325 .76567 m .18246 .77431 L .18298 .76332 L p F P
0 g
s
.84 .983 .7 r
.21654 .68231 m .22091 .67207 L .21035 .68606 L p F P
0 g
s
.84 .983 .7 r
.20704 .69509 m .21654 .68231 L p .21035 .68606 L F P
0 g
s
.065 .299 .785 r
.19464 .8281 m .19414 .8202 L .20439 .82833 L p F P
0 g
s
.065 .299 .785 r
.20439 .82833 m .20533 .83609 L .19464 .8281 L p F P
0 g
s
.647 .944 .958 r
.35151 .58499 m .3539 .58383 L .35198 .58505 L closepath p F P
0 g
s
.799 .926 .92 r
.82504 .85946 m .82682 .8582 L .82653 .86043 L closepath p F P
0 g
s
.847 .937 .883 r
.84716 .8413 m .82682 .8582 L .82653 .86043 L p F P
0 g
s
.258 0 .124 r
.47349 .69842 m .47628 .69729 L p .45176 .71354 L F P
0 g
s
.29 0 .173 r
.47628 .69729 m .47652 .69671 L .47349 .69842 L closepath p F P
0 g
s
0 .161 .693 r
.66333 .77836 m .65934 .77186 L .6498 .7632 L p F P
0 g
s
0 .097 .618 r
.64473 .75693 m .6498 .7632 L .65934 .77186 L p F P
0 g
s
0 .125 .646 r
.64151 .75401 m .64473 .75693 L .6498 .7632 L p F P
0 g
s
0 0 .224 r
.86965 .7631 m .86898 .7559 L .86673 .74505 L p F P
0 g
s
.751 .578 .003 r
.86898 .7559 m .86965 .7631 L .87019 .77446 L p F P
0 g
s
.509 .823 .507 r
.4033 .76307 m .39063 .77782 L .39799 .76766 L p F P
0 g
s
.774 .884 .925 r
.30006 .85178 m .28536 .8602 L .29266 .86448 L p F P
0 g
s
.774 .884 .925 r
.29266 .86448 m .30079 .85929 L .30006 .85178 L p F P
0 g
s
.742 .985 .902 r
.28833 .61715 m .29479 .60988 L p .27249 .62374 L F P
0 g
s
.743 .975 .924 r
.29479 .60988 m .29914 .60997 L .28833 .61715 L closepath p F P
0 g
s
.777 .812 .332 r
.19025 .73056 m .19235 .72186 L .18806 .73396 L p F P
0 g
s
.777 .812 .332 r
.18806 .73396 m .18666 .73967 L .19025 .73056 L p F P
0 g
s
.436 .784 .997 r
.567 .54746 m .54365 .55005 L .54979 .55368 L p F P
0 g
s
.436 .784 .997 r
.54979 .55368 m .57306 .55129 L .567 .54746 L p F P
0 g
s
.432 .78 .997 r
.57905 .55527 m .57306 .55129 L .54979 .55368 L p F P
0 g
s
.466 .095 .25 r
.47628 .69729 m .47652 .69671 L .47952 .69661 L closepath p F P
0 g
s
.635 .946 .951 r
.36679 .5733 m .3442 .58408 L .35151 .58499 L p F P
0 g
s
.635 .946 .951 r
.3703 .5737 m .36679 .5733 L p .35151 .58499 L F P
0 g
s
.635 .946 .951 r
.35151 .58499 m .3539 .58383 L .3703 .5737 L p F P
0 g
s
.683 .95 .956 r
.35151 .58499 m .3442 .58408 L .32276 .59541 L p F P
0 g
s
.244 .469 .877 r
.21996 .84909 m .20647 .8437 L .20533 .83609 L p F P
0 g
s
.252 .505 .901 r
.20647 .8437 m .21996 .84909 L .22494 .855 L p F P
0 g
s
0 .085 .635 r
.18745 .81114 m .18737 .803 L .19389 .81213 L p F P
0 g
s
0 .085 .635 r
.19389 .81213 m .19414 .8202 L .18745 .81114 L p F P
0 g
s
.568 .879 .993 r
.42663 .55916 m .4329 .56165 L .45557 .55471 L p F P
0 g
s
.607 .892 .989 r
.4329 .56165 m .42663 .55916 L .40492 .56751 L p F P
0 g
s
.767 .264 .006 r
.60656 .72179 m .59969 .71363 L .60051 .71357 L p F P
0 g
s
.833 .371 .106 r
.59969 .71363 m .59919 .71282 L .60051 .71357 L closepath p F P
0 g
s
.282 0 .132 r
.45176 .71354 m .47295 .70518 L p .46783 .71378 L F P
0 g
s
.282 0 .132 r
.46783 .71378 m .44805 .72128 L .45176 .71354 L p F P
0 g
s
.258 0 .124 r
.47628 .69729 m .47295 .70518 L .45176 .71354 L p F P
0 g
s
.654 .93 .971 r
.3703 .5737 m .37398 .5746 L .3539 .58383 L closepath p F P
0 g
s
0 .201 .728 r
.67638 .79368 m .67314 .78706 L .66333 .77836 L p F P
0 g
s
0 .135 .667 r
.65934 .77186 m .66333 .77836 L .67314 .78706 L p F P
0 g
s
.461 .086 .24 r
.47295 .70518 m .47628 .69729 L .47952 .69661 L p F P
0 g
s
.58 .905 .981 r
.40352 .56713 m .40492 .56751 L .42663 .55916 L p F P
0 g
s
.925 .963 .777 r
.85782 .82688 m .85853 .81961 L p .84745 .84001 L F P
0 g
s
.925 .963 .777 r
.84745 .84001 m .84823 .84021 L .85782 .82688 L p F P
0 g
s
.922 .954 .623 r
.85782 .82688 m .85853 .81961 L .8656 .8061 L p F P
0 g
s
.741 .897 .949 r
.31521 .85034 m .30079 .85929 L .30006 .85178 L p F P
0 g
s
.672 .832 .96 r
.278 .85564 m .25593 .86293 L .26325 .86873 L p F P
0 g
s
.672 .832 .96 r
.26325 .86873 m .28536 .8602 L .278 .85564 L p F P
0 g
s
.295 .677 .974 r
.64713 .56731 m .66762 .56887 L p .63791 .56254 L F P
0 g
s
.295 .677 .974 r
.63791 .56254 m .6403 .56442 L .64713 .56731 L p F P
0 g
s
.319 .677 .977 r
.64713 .56731 m .66762 .56887 L .67319 .57379 L p F P
0 g
s
.179 .542 .927 r
.74389 .60464 m .75634 .60841 L .74956 .6021 L p F P
0 g
s
.179 .542 .927 r
.74956 .6021 m .73859 .59883 L .74389 .60464 L p F P
0 g
s
.182 .545 .928 r
.7314 .59674 m .73859 .59883 L .74389 .60464 L p F P
0 g
s
0 .317 .805 r
.8061 .6483 m .81615 .65501 L .81099 .64768 L p F P
0 g
s
0 .317 .805 r
.81099 .64768 m .80177 .64151 L .8061 .6483 L p F P
0 g
s
.776 .99 .762 r
.39063 .77782 m .39799 .76766 L .3825 .78331 L p F P
0 g
s
.776 .99 .762 r
.38439 .7851 m .39063 .77782 L p .3825 .78331 L F P
0 g
s
.707 .97 .932 r
.29914 .60997 m .32168 .59602 L p .30149 .60374 L F P
0 g
s
.707 .97 .932 r
.30149 .60374 m .29479 .60988 L .29914 .60997 L p F P
0 g
s
.461 .086 .24 r
.47952 .69661 m .49934 .69573 L p .47295 .70518 L F P
0 g
s
.47 .109 .27 r
.49934 .69573 m .47952 .69661 L .5007 .69195 L closepath p F P
0 g
s
.821 .38 .188 r
.59969 .71363 m .59919 .71282 L .58837 .70795 L p F P
0 g
s
.242 .607 .953 r
.70847 .58755 m .72379 .59063 L .71548 .58467 L p F P
0 g
s
.242 .607 .953 r
.71548 .58467 m .70305 .58226 L .70847 .58755 L p F P
0 g
s
.249 .613 .956 r
.69379 .5806 m .70305 .58226 L .70847 .58755 L p F P
0 g
s
.411 .764 .995 r
.57905 .55527 m .60255 .55386 L p .59059 .55012 L F P
0 g
s
.411 .764 .995 r
.59059 .55012 m .57306 .55129 L .57905 .55527 L p F P
0 g
s
0 0 .176 r
.86554 .73788 m .86673 .74505 L .86898 .7559 L p F P
0 g
s
0 0 .372 r
.86673 .74505 m .86554 .73788 L .86169 .72753 L p F P
0 g
s
.881 .98 .831 r
.36117 .8102 m .36321 .80798 L .36289 .80993 L closepath p F P
0 g
s
.837 .991 .856 r
.34664 .82389 m .36117 .8102 L .36289 .80993 L p F P
0 g
s
0 .199 .726 r
.67638 .79368 m .68367 .79976 L .67792 .79133 L p F P
0 g
s
0 .199 .726 r
.67792 .79133 m .67314 .78706 L .67638 .79368 L p F P
0 g
s
.84 .983 .7 r
.21035 .68606 m .20647 .69552 L .20704 .69509 L p F P
0 g
s
.871 .984 .702 r
.20647 .69552 m .20704 .69509 L .20627 .69615 L closepath p F P
0 g
s
.947 .869 .452 r
.86904 .79359 m .86883 .7864 L p .86561 .80599 L F P
0 g
s
.947 .869 .452 r
.86561 .80599 m .86566 .80592 L .86904 .79359 L p F P
0 g
s
.835 .724 .197 r
.86904 .79359 m .86883 .7864 L .87019 .77446 L p F P
0 g
s
.849 .947 .588 r
.20627 .69615 m .20647 .69552 L .20055 .70247 L p F P
0 g
s
.849 .947 .588 r
.20055 .70247 m .19842 .70926 L .20627 .69615 L p F P
0 g
s
.784 .906 .926 r
.82682 .8582 m .82504 .85946 L .82018 .85575 L p F P
0 g
s
.684 .88 .971 r
.79616 .86577 m .82018 .85575 L .82504 .85946 L p F P
0 g
s
.742 .245 .052 r
.59969 .71363 m .60656 .72179 L .59505 .71712 L p F P
0 g
s
.742 .245 .052 r
.59505 .71712 m .59391 .71592 L .59969 .71363 L p F P
0 g
s
.821 .38 .188 r
.58837 .70795 m .59391 .71592 L .59969 .71363 L p F P
0 g
s
.096 .473 .893 r
.77444 .61969 m .76249 .61485 L .75634 .60841 L p F P
0 g
s
.125 .477 .897 r
.76249 .61485 m .77444 .61969 L .77964 .62615 L p F P
0 g
s
.776 .99 .762 r
.3825 .78331 m .38009 .78727 L .38439 .7851 L p F P
0 g
s
.803 .994 .762 r
.38009 .78727 m .38439 .7851 L .37718 .79281 L closepath p F P
0 g
s
.784 .906 .926 r
.82018 .85575 m .82719 .85113 L .82682 .8582 L p F P
0 g
s
.815 .928 .908 r
.84745 .84001 m .84716 .8413 L .82682 .8582 L p F P
0 g
s
.815 .928 .908 r
.84367 .83851 m .84745 .84001 L p .82682 .8582 L F P
0 g
s
.815 .928 .908 r
.82682 .8582 m .82719 .85113 L .84367 .83851 L p F P
0 g
s
0 .242 .757 r
.82175 .66348 m .82148 .6629 L p .83456 .67819 L F P
0 g
s
.037 .347 .824 r
.82175 .66348 m .82132 .66279 L .82148 .6629 L closepath p F P
0 g
s
0 0 .444 r
.1836 .79316 m .18392 .78478 L .18764 .79467 L p F P
0 g
s
0 0 .444 r
.18764 .79467 m .18737 .803 L .1836 .79316 L p F P
0 g
s
.293 .48 .871 r
.68955 .80916 m .68954 .80899 L p .70641 .82335 L F P
0 g
s
.262 .46 .866 r
.68955 .80916 m .68941 .80893 L .68954 .80899 L closepath p F P
0 g
s
.802 .936 .572 r
.20647 .69552 m .21035 .68606 L .20179 .69945 L p F P
0 g
s
.802 .936 .572 r
.20179 .69945 m .20055 .70247 L .20647 .69552 L p F P
0 g
s
.567 .761 .97 r
.76663 .86398 m .79102 .86023 L .79616 .86577 L p F P
0 g
s
.542 .738 .966 r
.79102 .86023 m .76663 .86398 L .76126 .85691 L p F P
0 g
s
.003 .338 .819 r
.82148 .6629 m .82132 .66279 L .81615 .65501 L p F P
0 g
s
.236 .461 .873 r
.68954 .80899 m .68941 .80893 L .68367 .79976 L p F P
0 g
s
.738 .982 .758 r
.37718 .79281 m .36321 .80798 L .36615 .79922 L p F P
0 g
s
.738 .982 .758 r
.38009 .78727 m .37718 .79281 L p .36615 .79922 L F P
0 g
s
.573 .906 .978 r
.41925 .55721 m .39654 .56534 L .40352 .56713 L p F P
0 g
s
.573 .906 .978 r
.40352 .56713 m .42613 .55901 L .41925 .55721 L p F P
0 g
s
.58 .905 .981 r
.42663 .55916 m .42613 .55901 L .40352 .56713 L p F P
0 g
s
.293 .48 .871 r
.68954 .80899 m .70502 .81639 L .70641 .82335 L p F P
0 g
s
.127 .416 .862 r
.68803 .80199 m .68954 .80899 L .70502 .81639 L p F P
0 g
s
.236 .461 .873 r
.68367 .79976 m .68803 .80199 L .68954 .80899 L p F P
0 g
s
0 .242 .757 r
.82148 .6629 m .83129 .67125 L .83456 .67819 L p F P
0 g
s
0 .214 .736 r
.81769 .65603 m .82148 .6629 L .83129 .67125 L p F P
0 g
s
.003 .338 .819 r
.81615 .65501 m .81769 .65603 L .82148 .6629 L p F P
0 g
s
.491 .621 .907 r
.73116 .8465 m .75211 .84912 L .75237 .85615 L p F P
0 g
s
.456 .603 .909 r
.75211 .84912 m .73116 .8465 L .72557 .83791 L p F P
0 g
s
.862 .985 .845 r
.84716 .8413 m .84745 .84001 L .84823 .84021 L closepath p F P
0 g
s
.127 .478 .897 r
.77964 .62615 m .78354 .62773 L .77805 .62115 L p F P
0 g
s
.127 .478 .897 r
.77805 .62115 m .77444 .61969 L .77964 .62615 L p F P
0 g
s
.824 .946 .903 r
.32856 .83245 m .3079 .84742 L .31521 .85034 L p F P
0 g
s
.824 .946 .903 r
.31521 .85034 m .3273 .84059 L .32856 .83245 L p F P
0 g
s
.741 .897 .949 r
.30006 .85178 m .3079 .84742 L .31521 .85034 L p F P
0 g
s
0 0 .331 r
.85998 .72041 m .86169 .72753 L .86554 .73788 L p F P
0 g
s
0 0 .494 r
.86169 .72753 m .85998 .72041 L .85463 .71053 L p F P
0 g
s
.337 .573 .927 r
.2272 .85757 m .22563 .85724 L .22494 .855 L closepath p F P
0 g
s
.695 .276 .246 r
.56782 .69486 m .57509 .70375 L .55849 .70049 L p F P
0 g
s
.695 .276 .246 r
.56212 .69376 m .56782 .69486 L p .55849 .70049 L F P
0 g
s
.714 .22 0 r
.63575 .74874 m .64151 .75401 L p .63712 .74908 L F P
0 g
s
.714 .22 0 r
.63068 .74187 m .63575 .74874 L p .63712 .74908 L F P
0 g
s
.545 0 0 r
.63575 .74874 m .63826 .75099 L .63471 .74848 L p F P
0 g
s
.545 0 0 r
.63471 .74848 m .63034 .74539 L p .63575 .74874 L F P
0 g
s
0 .051 .536 r
.64151 .75401 m .64473 .75693 L .63826 .75099 L p F P
0 g
s
0 .051 .536 r
.63826 .75099 m .63575 .74874 L .64151 .75401 L p F P
0 g
s
.311 .668 .974 r
.67319 .57379 m .68437 .57495 L .67415 .56949 L p F P
0 g
s
.311 .668 .974 r
.67415 .56949 m .66762 .56887 L .67319 .57379 L p F P
0 g
s
.782 .28 0 r
.61608 .72699 m .60656 .72179 L .6141 .73082 L p F P
0 g
s
.782 .28 0 r
.6141 .73082 m .62309 .73617 L .61608 .72699 L p F P
0 g
s
0 .132 .68 r
.84559 .69408 m .84283 .68708 L .83456 .67819 L p F P
0 g
s
0 .107 .658 r
.83129 .67125 m .83456 .67819 L .84283 .68708 L p F P
0 g
s
.788 .95 .926 r
.33808 .83213 m .3273 .84059 L .32856 .83245 L p F P
0 g
s
.743 .713 .18 r
.18612 .74312 m .18666 .73967 L .18449 .75003 L p F P
0 g
s
.743 .713 .18 r
.18449 .75003 m .18379 .75464 L .18612 .74312 L p F P
0 g
s
.342 .704 .984 r
.63791 .56254 m .63504 .56243 L .6403 .56442 L closepath p F P
0 g
s
.232 .616 .955 r
.70305 .58226 m .69379 .5806 L .68437 .57495 L p F P
0 g
s
0 0 .46 r
.85239 .70347 m .85463 .71053 L .85998 .72041 L p F P
0 g
s
0 .022 .595 r
.85463 .71053 m .85239 .70347 L .84559 .69408 L p F P
0 g
s
.857 .997 .805 r
.36117 .8102 m .36321 .80798 L .36615 .79922 L p F P
0 g
s
.159 .545 .926 r
.73859 .59883 m .7314 .59674 L .72379 .59063 L p F P
0 g
s
.392 .74 .992 r
.60842 .5582 m .62157 .55794 L .60704 .55374 L p F P
0 g
s
.392 .74 .992 r
.60704 .55374 m .60255 .55386 L .60842 .5582 L p F P
0 g
s
.857 .997 .805 r
.36615 .79922 m .35387 .8111 L .36117 .8102 L p F P
0 g
s
.803 .992 .877 r
.36117 .8102 m .34664 .82389 L .34869 .81546 L p F P
0 g
s
.803 .992 .877 r
.34869 .81546 m .35387 .8111 L .36117 .8102 L p F P
0 g
s
0 0 .568 r
.84283 .68708 m .84559 .69408 L .85239 .70347 L p F P
0 g
s
.456 .632 .93 r
.24122 .84987 m .24858 .85668 L .2272 .85757 L p F P
0 g
s
.456 .632 .93 r
.22508 .84955 m .24122 .84987 L p .2272 .85757 L F P
0 g
s
.456 .632 .93 r
.2272 .85757 m .22494 .855 L .22508 .84955 L p F P
0 g
s
.663 .852 .972 r
.82018 .85575 m .79616 .86577 L .79102 .86023 L p F P
0 g
s
.854 .98 .861 r
.33808 .83213 m .34664 .82389 L .34869 .81546 L p F P
0 g
s
.768 .995 .801 r
.24569 .64627 m .2512 .64118 L .24848 .64509 L closepath p F P
0 g
s
.816 1 .827 r
.24848 .64509 m .24569 .64627 L .23452 .65712 L p F P
0 g
s
.885 .965 .84 r
.84367 .83851 m .84772 .83412 L .84745 .84001 L closepath p F P
0 g
s
.925 .963 .777 r
.85853 .81961 m .84772 .83412 L .84745 .84001 L p F P
0 g
s
.695 .276 .246 r
.55849 .70049 m .55821 .70021 L .56212 .69376 L p F P
0 g
s
.709 .293 .255 r
.55821 .70021 m .55044 .69185 L .56212 .69376 L closepath p F P
0 g
s
.854 .98 .861 r
.34869 .81546 m .33077 .83089 L .33808 .83213 L p F P
0 g
s
.788 .95 .926 r
.32856 .83245 m .33077 .83089 L .33808 .83213 L p F P
0 g
s
.424 .61 .926 r
.75237 .85615 m .76126 .85691 L .75584 .84966 L p F P
0 g
s
.424 .61 .926 r
.75584 .84966 m .75211 .84912 L .75237 .85615 L p F P
0 g
s
.669 .965 .928 r
.32168 .59602 m .32276 .59541 L .32197 .59602 L closepath p F P
0 g
s
.264 .497 .892 r
.71995 .82939 m .70641 .82335 L p .72442 .83745 L F P
0 g
s
.199 .438 .865 r
.70641 .82335 m .71995 .82939 L .71431 .8211 L p F P
0 g
s
.199 .438 .865 r
.71431 .8211 m .70502 .81639 L .70641 .82335 L p F P
0 g
s
.883 .753 .248 r
.86951 .76729 m .87019 .77446 L .86883 .7864 L p F P
0 g
s
.751 .578 .003 r
.87019 .77446 m .86951 .76729 L .86898 .7559 L p F P
0 g
s
.653 .965 .917 r
.33677 .58352 m .3141 .59609 L .32168 .59602 L p F P
0 g
s
.653 .965 .917 r
.33885 .58346 m .33677 .58352 L p .32168 .59602 L F P
0 g
s
.653 .965 .917 r
.32168 .59602 m .32276 .59541 L .33885 .58346 L p F P
0 g
s
.707 .97 .932 r
.32168 .59602 m .3141 .59609 L .30149 .60374 L p F P
0 g
s
.764 .259 0 r
.63575 .74874 m .63068 .74187 L .62309 .73617 L p F P
0 g
s
0 0 .238 r
.18246 .77431 m .18325 .76567 L .18469 .77618 L p F P
0 g
s
0 0 .238 r
.18469 .77618 m .18392 .78478 L .18246 .77431 L p F P
0 g
s
.761 .862 .427 r
.19842 .70926 m .19235 .72186 L .19531 .71222 L p F P
0 g
s
.761 .862 .427 r
.20055 .70247 m .19842 .70926 L p .19531 .71222 L F P
0 g
s
.674 .954 .951 r
.33885 .58346 m .3442 .58408 L .32276 .59541 L closepath p F P
0 g
s
.037 .399 .854 r
.80177 .64151 m .79689 .63482 L .78354 .62773 L p F P
0 g
s
.003 .39 .847 r
.78354 .62773 m .77805 .62115 L .79143 .62823 L p F P
0 g
s
.003 .39 .847 r
.79143 .62823 m .79689 .63482 L .78354 .62773 L p F P
0 g
s
.323 .706 .981 r
.63791 .56254 m .63504 .56243 L .62157 .55794 L p F P
0 g
s
.617 .92 .976 r
.3703 .5737 m .37398 .5746 L .39654 .56534 L p F P
0 g
s
.435 .613 .924 r
.22508 .84955 m .22494 .855 L .21996 .84909 L closepath p F P
0 g
s
.909 .888 .468 r
.8656 .8061 m .86561 .80599 L .86566 .80592 L closepath p F P
0 g
s
.936 .963 .676 r
.86561 .80599 m .8656 .8061 L .85853 .81961 L p F P
0 g
s
.955 .933 .599 r
.86155 .80761 m .86533 .79896 L .86561 .80599 L closepath p F P
0 g
s
.947 .869 .452 r
.86883 .7864 m .86533 .79896 L .86561 .80599 L p F P
0 g
s
.936 .963 .676 r
.86155 .80761 m .86561 .80599 L p .85853 .81961 L F P
0 g
s
.561 .196 .306 r
.5007 .69195 m .52789 .69035 L p .50805 .69901 L F P
0 g
s
.561 .196 .306 r
.50805 .69901 m .49934 .69573 L .5007 .69195 L p F P
0 g
s
0 .097 .618 r
.65934 .77186 m .65416 .76563 L .64473 .75693 L p F P
0 g
s
0 .039 .529 r
.64473 .75693 m .63826 .75099 L .64783 .75966 L p F P
0 g
s
0 .039 .529 r
.64783 .75966 m .65416 .76563 L .64473 .75693 L p F P
0 g
s
.639 .26 .31 r
.55044 .69185 m .55821 .70021 L p .53812 .69831 L F P
0 g
s
.639 .26 .31 r
.52894 .69031 m .55044 .69185 L p .53812 .69831 L F P
0 g
s
.766 .295 .126 r
.58837 .70795 m .57509 .70375 L .58248 .7127 L p F P
0 g
s
.766 .295 .126 r
.59391 .71592 m .58837 .70795 L p .58248 .7127 L F P
0 g
s
.729 .99 .849 r
.26867 .62672 m .27249 .62374 L .27027 .62628 L closepath p F P
0 g
s
.779 .996 .866 r
.27027 .62628 m .26867 .62672 L .2512 .64118 L p F P
0 g
s
.748 .896 .945 r
.30053 .84428 m .278 .85564 L .28536 .8602 L p F P
0 g
s
.748 .896 .945 r
.30172 .84478 m .30053 .84428 L p .28536 .8602 L F P
0 g
s
.748 .896 .945 r
.28536 .8602 m .30006 .85178 L .30172 .84478 L p F P
0 g
s
.692 .979 .891 r
.29142 .61035 m .30149 .60374 L .29479 .60988 L closepath p F P
0 g
s
.742 .985 .902 r
.29479 .60988 m .29142 .61035 L .27249 .62374 L p F P
0 g
s
.302 .691 .977 r
.63791 .56254 m .66201 .56416 L p .65072 .55936 L F P
0 g
s
.302 .691 .977 r
.65072 .55936 m .63219 .55827 L .63791 .56254 L p F P
0 g
s
.323 .706 .981 r
.62157 .55794 m .63219 .55827 L .63791 .56254 L p F P
0 g
s
.295 .677 .974 r
.66762 .56887 m .66201 .56416 L .63791 .56254 L p F P
0 g
s
.264 .496 .892 r
.72557 .83791 m .72442 .83745 L .72403 .83558 L closepath p F P
0 g
s
.264 .497 .892 r
.72442 .83745 m .72403 .83558 L .71995 .82939 L p F P
0 g
s
.495 .842 .996 r
.48495 .55177 m .50794 .54699 L p .4931 .54568 L F P
0 g
s
.495 .842 .996 r
.4931 .54568 m .47844 .5488 L .48495 .55177 L p F P
0 g
s
.461 .819 .996 r
.5143 .55021 m .53745 .54654 L p .52597 .54402 L F P
0 g
s
.461 .819 .996 r
.52597 .54402 m .50794 .54699 L .5143 .55021 L p F P
0 g
s
0 0 0 r
.18666 .73967 m .18806 .73396 L .1856 .74554 L p F P
0 g
s
0 0 0 r
.1856 .74554 m .18449 .75003 L .18666 .73967 L p F P
0 g
s
0 0 .176 r
.86898 .7559 m .8678 .74876 L .86554 .73788 L p F P
0 g
s
.809 .613 .056 r
.8678 .74876 m .86898 .7559 L .86951 .76729 L p F P
0 g
s
0 0 0 r
.42358 .74265 m .43285 .73523 L .42555 .73961 L closepath p F P
0 g
s
0 0 0 r
.42555 .73961 m .42358 .74265 L .41417 .75181 L p F P
0 g
s
.645 .814 .965 r
.27061 .85072 m .24858 .85668 L .25593 .86293 L p F P
0 g
s
.645 .814 .965 r
.25593 .86293 m .278 .85564 L .27061 .85072 L p F P
0 g
s
.151 .431 .868 r
.68803 .80199 m .68367 .79976 L .67792 .79133 L p F P
0 g
s
0 .135 .667 r
.67314 .78706 m .66883 .78066 L .65934 .77186 L p F P
0 g
s
0 .08 .599 r
.65416 .76563 m .65934 .77186 L .66883 .78066 L p F P
0 g
s
0 .303 .793 r
.80177 .64151 m .81099 .64768 L .80584 .6408 L p F P
0 g
s
0 .303 .793 r
.80584 .6408 m .79689 .63482 L .80177 .64151 L p F P
0 g
s
.561 .196 .306 r
.52789 .69035 m .52873 .69082 L p .50805 .69901 L F P
0 g
s
.601 .221 .294 r
.52873 .69082 m .52789 .69035 L .52894 .69031 L closepath p F P
0 g
s
.639 .26 .31 r
.53812 .69831 m .52873 .69082 L .52894 .69031 L p F P
0 g
s
.402 .578 .91 r
.74488 .83496 m .75038 .84232 L .72557 .83791 L p F P
0 g
s
.402 .578 .91 r
.72425 .83026 m .74488 .83496 L p .72557 .83791 L F P
0 g
s
.402 .578 .91 r
.72557 .83791 m .72403 .83558 L .72425 .83026 L p F P
0 g
s
.456 .603 .909 r
.72557 .83791 m .75038 .84232 L p .75211 .84912 L F P
0 g
s
.527 .862 .994 r
.45025 .55251 m .45557 .55471 L .47844 .5488 L p F P
0 g
s
.568 .879 .993 r
.45557 .55471 m .45025 .55251 L .42663 .55916 L p F P
0 g
s
.159 .543 .926 r
.73859 .59883 m .74956 .6021 L .74214 .59591 L p F P
0 g
s
.159 .543 .926 r
.74214 .59591 m .73326 .59332 L .73859 .59883 L p F P
0 g
s
.159 .545 .926 r
.72379 .59063 m .73326 .59332 L .73859 .59883 L p F P
0 g
s
.431 .794 .996 r
.54365 .55005 m .567 .54746 L p .55095 .54495 L F P
0 g
s
.431 .794 .996 r
.55095 .54495 m .53745 .54654 L .54365 .55005 L p F P
0 g
s
.75 .992 .801 r
.2512 .64118 m .26037 .62913 L .24192 .64571 L p F P
0 g
s
.75 .992 .801 r
.24569 .64627 m .2512 .64118 L p .24192 .64571 L F P
0 g
s
.746 .994 .848 r
.26867 .62672 m .2512 .64118 L .26037 .62913 L p F P
0 g
s
.75 .992 .801 r
.24192 .64571 m .23956 .64887 L .24569 .64627 L p F P
0 g
s
.793 .998 .801 r
.23956 .64887 m .24569 .64627 L .23452 .65712 L closepath p F P
0 g
s
.069 .283 .771 r
.19414 .8202 m .19389 .81213 L p .20432 .82687 L F P
0 g
s
.069 .283 .771 r
.20432 .82687 m .20439 .82833 L .19414 .8202 L p F P
0 g
s
.067 .469 .887 r
.76922 .61358 m .75634 .60841 L .74956 .6021 L p F P
0 g
s
.096 .473 .893 r
.75634 .60841 m .76922 .61358 L .77444 .61969 L p F P
0 g
s
.542 .738 .966 r
.76126 .85691 m .7858 .85434 L .79102 .86023 L p F P
0 g
s
.517 .718 .964 r
.7858 .85434 m .76126 .85691 L .75584 .84966 L p F P
0 g
s
.647 .253 .284 r
.52549 .6978 m .52873 .69082 L .53812 .69831 L closepath p F P
0 g
s
.561 .196 .306 r
.52873 .69082 m .52549 .6978 L .50805 .69901 L p F P
0 g
s
0 .324 .81 r
.81769 .65603 m .81615 .65501 L .81099 .64768 L p F P
0 g
s
.786 .99 .75 r
.23452 .65712 m .23956 .64887 L p .22736 .66104 L F P
0 g
s
.786 .99 .75 r
.2223 .67049 m .23452 .65712 L p .22736 .66104 L F P
0 g
s
.775 .99 .76 r
.37711 .78879 m .3825 .78331 L .38009 .78727 L closepath p F P
0 g
s
.738 .982 .758 r
.36615 .79922 m .37711 .78879 L .38009 .78727 L p F P
0 g
s
.529 .886 .98 r
.42613 .55901 m .42663 .55916 L .45025 .55251 L p F P
0 g
s
0 0 .04 r
.18379 .75464 m .18449 .75003 L .18385 .7617 L p F P
0 g
s
0 0 .04 r
.18385 .7617 m .18325 .76567 L .18379 .75464 L p F P
0 g
s
.228 .611 .953 r
.70305 .58226 m .71548 .58467 L .70645 .57888 L p F P
0 g
s
.228 .611 .953 r
.70645 .57888 m .69759 .57722 L .70305 .58226 L p F P
0 g
s
.232 .616 .955 r
.68437 .57495 m .69759 .57722 L .70305 .58226 L p F P
0 g
s
.207 .429 .856 r
.21275 .83962 m .20533 .83609 L .20439 .82833 L p F P
0 g
s
.244 .469 .877 r
.20533 .83609 m .21275 .83962 L .21996 .84909 L p F P
0 g
s
0 .134 .666 r
.67314 .78706 m .67792 .79133 L .67218 .78377 L p F P
0 g
s
0 .134 .666 r
.67218 .78377 m .66883 .78066 L .67314 .78706 L p F P
0 g
s
.721 .775 .282 r
.19235 .72186 m .19531 .71222 L .19095 .72438 L p F P
0 g
s
.721 .775 .282 r
.19095 .72438 m .18806 .73396 L .19235 .72186 L p F P
0 g
s
.916 .966 .792 r
.85885 .81236 m .85853 .81961 L .84772 .83412 L p F P
0 g
s
.936 .963 .676 r
.85853 .81961 m .85885 .81236 L .86155 .80761 L p F P
0 g
s
.704 .984 .825 r
.28354 .61155 m .26057 .62897 L .26867 .62672 L p F P
0 g
s
.704 .984 .825 r
.28404 .61138 m .28354 .61155 L p .26867 .62672 L F P
0 g
s
.704 .984 .825 r
.26867 .62672 m .27249 .62374 L .28404 .61138 L p F P
0 g
s
.746 .994 .848 r
.26037 .62913 m .26057 .62897 L .26867 .62672 L p F P
0 g
s
.77 .273 .03 r
.60656 .72179 m .59505 .71712 L .6034 .72591 L p F P
0 g
s
.77 .273 .03 r
.6034 .72591 m .6141 .73082 L .60656 .72179 L p F P
0 g
s
.214 .618 .952 r
.69759 .57722 m .68437 .57495 L .67415 .56949 L p F P
0 g
s
0 0 .331 r
.86554 .73788 m .86384 .73078 L .85998 .72041 L p F P
0 g
s
.715 .46 0 r
.86384 .73078 m .86554 .73788 L .8678 .74876 L p F P
0 g
s
.726 .987 .888 r
.28404 .61138 m .29142 .61035 L .27249 .62374 L closepath p F P
0 g
s
0 .083 .629 r
.18737 .803 m .18764 .79467 L p .194 .80654 L F P
0 g
s
0 .083 .629 r
.194 .80654 m .19389 .81213 L .18737 .803 L p F P
0 g
s
.441 .065 .228 r
.47295 .70518 m .4975 .69985 L p .47149 .71268 L F P
0 g
s
.441 .065 .228 r
.47149 .71268 m .46967 .71287 L .47295 .70518 L p F P
0 g
s
.461 .086 .24 r
.49934 .69573 m .4975 .69985 L .47295 .70518 L p F P
0 g
s
.282 0 .132 r
.47295 .70518 m .46967 .71287 L .46783 .71378 L p F P
0 g
s
.402 .578 .91 r
.72403 .83558 m .71995 .82939 L .72425 .83026 L closepath p F P
0 g
s
.398 .57 .905 r
.21996 .84909 m .22508 .84955 L .22491 .84166 L p F P
0 g
s
.398 .57 .905 r
.22491 .84166 m .21275 .83962 L .21996 .84909 L p F P
0 g
s
.524 .886 .978 r
.44211 .55022 m .41925 .55721 L .42613 .55901 L p F P
0 g
s
.524 .886 .978 r
.42613 .55901 m .44889 .55211 L .44211 .55022 L p F P
0 g
s
.529 .886 .98 r
.45025 .55251 m .44889 .55211 L .42613 .55901 L p F P
0 g
s
.768 .892 .932 r
.82719 .85113 m .82018 .85575 L .81523 .85147 L p F P
0 g
s
.663 .852 .972 r
.79102 .86023 m .81523 .85147 L .82018 .85575 L p F P
0 g
s
.742 .891 .947 r
.30172 .84478 m .3079 .84742 L .30006 .85178 L closepath p F P
0 g
s
.278 0 .124 r
.44667 .7241 m .46783 .71378 L .44805 .72128 L closepath p F P
0 g
s
0 0 0 r
.44805 .72128 m .44667 .7241 L .43285 .73523 L p F P
0 g
s
.101 .475 .895 r
.77444 .61969 m .77805 .62115 L .77197 .61468 L p F P
0 g
s
.101 .475 .895 r
.77197 .61468 m .76922 .61358 L .77444 .61969 L p F P
0 g
s
0 .214 .736 r
.83129 .67125 m .82749 .66439 L .81769 .65603 L p F P
0 g
s
0 .194 .717 r
.81336 .64924 m .81769 .65603 L .82749 .66439 L p F P
0 g
s
0 .324 .81 r
.81099 .64768 m .81336 .64924 L .81769 .65603 L p F P
0 g
s
.406 .769 .994 r
.57306 .55129 m .59059 .55012 L .57226 .54707 L p F P
0 g
s
.406 .769 .994 r
.57226 .54707 m .567 .54746 L .57306 .55129 L p F P
0 g
s
.955 .875 .47 r
.86814 .77927 m .86883 .7864 L .86533 .79896 L p F P
0 g
s
.883 .753 .248 r
.86883 .7864 m .86814 .77927 L .86951 .76729 L p F P
0 g
s
.786 .99 .75 r
.22736 .66104 m .22143 .671 L .2223 .67049 L p F P
0 g
s
.825 .994 .752 r
.22143 .671 m .2223 .67049 L .22091 .67207 L closepath p F P
0 g
s
.631 .942 .955 r
.3442 .58408 m .36679 .5733 L p .34848 .5777 L F P
0 g
s
.631 .942 .955 r
.34848 .5777 m .33885 .58346 L .3442 .58408 L p F P
0 g
s
.136 .544 .922 r
.73326 .59332 m .72379 .59063 L .71548 .58467 L p F P
0 g
s
.309 .709 .978 r
.63219 .55827 m .62157 .55794 L .60704 .55374 L p F P
0 g
s
.8 .964 .649 r
.22091 .67207 m .22143 .671 L .21466 .67706 L p F P
0 g
s
.8 .964 .649 r
.21466 .67706 m .21035 .68606 L .22091 .67207 L p F P
0 g
s
.562 .174 .264 r
.4975 .69985 m .49934 .69573 L .50805 .69901 L closepath p F P
0 g
s
.768 .892 .932 r
.81523 .85147 m .82739 .84403 L .82719 .85113 L p F P
0 g
s
.812 .949 .911 r
.83899 .83589 m .82739 .84403 L .82719 .85113 L p F P
0 g
s
.812 .949 .911 r
.82719 .85113 m .84367 .83851 L .83899 .83589 L p F P
0 g
s
.584 .929 .953 r
.36679 .5733 m .3703 .5737 L .39051 .56385 L p F P
0 g
s
.617 .92 .976 r
.39654 .56534 m .39051 .56385 L .3703 .5737 L p F P
0 g
s
.127 .416 .862 r
.70502 .81639 m .70242 .80969 L .68803 .80199 L p F P
0 g
s
.04 .38 .844 r
.68513 .79528 m .68803 .80199 L .70242 .80969 L p F P
0 g
s
.151 .431 .868 r
.67792 .79133 m .68513 .79528 L .68803 .80199 L p F P
0 g
s
0 0 .304 r
.85775 .71336 m .85998 .72041 L .86384 .73078 L p F P
0 g
s
0 0 .46 r
.85998 .72041 m .85775 .71336 L .85239 .70347 L p F P
0 g
s
.545 0 0 r
.63034 .74539 m .62999 .7451 L .63575 .74874 L p F P
0 g
s
.764 .259 0 r
.62309 .73617 m .62999 .7451 L .63575 .74874 L p F P
0 g
s
0 .107 .658 r
.84283 .68708 m .83955 .68015 L .83129 .67125 L p F P
0 g
s
0 .081 .633 r
.82749 .66439 m .83129 .67125 L .83955 .68015 L p F P
0 g
s
.643 .827 .971 r
.81523 .85147 m .79102 .86023 L .7858 .85434 L p F P
0 g
s
.744 .313 .226 r
.57509 .70375 m .55849 .70049 L .5673 .70901 L p F P
0 g
s
.744 .313 .226 r
.5673 .70901 m .58248 .7127 L .57509 .70375 L p F P
0 g
s
.782 .891 .922 r
.3079 .84742 m .32856 .83245 L p .30162 .84355 L F P
0 g
s
.782 .891 .922 r
.30162 .84355 m .30172 .84478 L .3079 .84742 L p F P
0 g
s
.746 .949 .634 r
.22143 .671 m .22736 .66104 L .2156 .67548 L p F P
0 g
s
.746 .949 .634 r
.2156 .67548 m .21466 .67706 L .22143 .671 L p F P
0 g
s
.876 .951 .855 r
.84772 .83412 m .84367 .83851 L .83899 .83589 L p F P
0 g
s
.876 .951 .855 r
.83899 .83589 m .84763 .82703 L .84772 .83412 L p F P
0 g
s
.916 .966 .792 r
.84772 .83412 m .84763 .82703 L .85885 .81236 L p F P
0 g
s
.741 .22 0 r
.62309 .73617 m .6141 .73082 L .62173 .73994 L p F P
0 g
s
.741 .22 0 r
.62999 .7451 m .62309 .73617 L p .62173 .73994 L F P
0 g
s
.302 .673 .975 r
.66762 .56887 m .67415 .56949 L .66306 .56425 L p F P
0 g
s
.302 .673 .975 r
.66306 .56425 m .66201 .56416 L .66762 .56887 L p F P
0 g
s
0 0 .422 r
.84964 .69648 m .85239 .70347 L .85775 .71336 L p F P
0 g
s
0 0 .568 r
.85239 .70347 m .84964 .69648 L .84283 .68708 L p F P
0 g
s
0 0 .536 r
.83955 .68015 m .84283 .68708 L .84964 .69648 L p F P
0 g
s
0 0 .455 r
.18392 .78478 m .18469 .77618 L p .18808 .78958 L F P
0 g
s
0 0 .455 r
.18808 .78958 m .18764 .79467 L .18392 .78478 L p F P
0 g
s
.679 .976 .891 r
.29142 .61035 m .30149 .60374 L p .28509 .61046 L F P
0 g
s
.679 .976 .891 r
.28509 .61046 m .28404 .61138 L .29142 .61035 L p F P
0 g
s
0 0 0 r
.42358 .74265 m .43285 .73523 L p .43857 .73642 L F P
0 g
s
0 0 0 r
.43857 .73642 m .42053 .74648 L .42358 .74265 L p F P
0 g
s
0 0 0 r
.42053 .74648 m .42358 .74265 L .41417 .75181 L closepath p F P
0 g
s
.469 .826 .558 r
.41417 .75181 m .42053 .74648 L p .41188 .75546 L F P
0 g
s
.381 .742 .991 r
.59981 .55194 m .60255 .55386 L .60704 .55374 L closepath p F P
0 g
s
.411 .764 .995 r
.60255 .55386 m .59981 .55194 L .59059 .55012 L p F P
0 g
s
.571 .906 .977 r
.39051 .56385 m .39654 .56534 L .41925 .55721 L p F P
0 g
s
0 .381 .837 r
.77805 .62115 m .77197 .61468 L .78541 .62174 L p F P
0 g
s
0 .381 .837 r
.78541 .62174 m .79143 .62823 L .77805 .62115 L p F P
0 g
s
.469 .648 .936 r
.24122 .84987 m .22508 .84955 L .22491 .84166 L p F P
0 g
s
0 0 0 r
.43285 .73523 m .44386 .7287 L p .43857 .73642 L F P
0 g
s
0 0 0 r
.44386 .7287 m .44667 .7241 L .43285 .73523 L closepath p F P
0 g
s
.733 .85 .413 r
.19754 .70775 m .20179 .69945 L .20055 .70247 L closepath p F P
0 g
s
.761 .862 .427 r
.19531 .71222 m .19754 .70775 L .20055 .70247 L p F P
0 g
s
.617 .904 .613 r
.39933 .7661 m .40038 .76526 L .39799 .76766 L closepath p F P
0 g
s
.709 .883 .493 r
.21035 .68606 m .20179 .69945 L .20665 .68904 L p F P
0 g
s
.709 .883 .493 r
.21466 .67706 m .21035 .68606 L p .20665 .68904 L F P
0 g
s
.502 .844 .569 r
.39799 .76766 m .3825 .78331 L .39147 .77264 L p F P
0 g
s
.502 .844 .569 r
.39933 .7661 m .39799 .76766 L p .39147 .77264 L F P
0 g
s
.408 .619 .938 r
.75584 .84966 m .75211 .84912 L .75065 .84269 L closepath p F P
0 g
s
.456 .603 .909 r
.75038 .84232 m .75065 .84269 L .75211 .84912 L p F P
0 g
s
.112 .404 .855 r
.70502 .81639 m .71431 .8211 L .70866 .81316 L p F P
0 g
s
.112 .404 .855 r
.70866 .81316 m .70242 .80969 L .70502 .81639 L p F P
0 g
s
.552 .011 0 r
.63826 .75099 m .63034 .74539 L .64028 .75396 L p F P
0 g
s
.552 .011 0 r
.64028 .75396 m .64783 .75966 L .63826 .75099 L p F P
0 g
s
.922 .774 .295 r
.86835 .76018 m .86951 .76729 L .86814 .77927 L p F P
0 g
s
.809 .613 .056 r
.86951 .76729 m .86835 .76018 L .8678 .74876 L p F P
0 g
s
.74 .258 .099 r
.59301 .71647 m .59391 .71592 L .59505 .71712 L closepath p F P
0 g
s
.766 .295 .126 r
.58248 .7127 m .59301 .71647 L .59391 .71592 L p F P
0 g
s
.204 0 .019 r
.44386 .7287 m .44667 .7241 L .46783 .71378 L p F P
0 g
s
.782 .891 .922 r
.32856 .83245 m .32916 .83056 L p .30162 .84355 L F P
0 g
s
.79 .942 .925 r
.32916 .83056 m .33077 .83089 L .32856 .83245 L closepath p F P
0 g
s
.679 .976 .891 r
.30149 .60374 m .31016 .59614 L p .28509 .61046 L F P
0 g
s
.694 .972 .923 r
.31016 .59614 m .3141 .59609 L .30149 .60374 L closepath p F P
0 g
s
.054 .396 .853 r
.68513 .79528 m .67792 .79133 L .67218 .78377 L p F P
0 g
s
.738 .988 .794 r
.3825 .78331 m .39147 .77264 L .37251 .78938 L p F P
0 g
s
.738 .988 .794 r
.37711 .78879 m .3825 .78331 L p .37251 .78938 L F P
0 g
s
.815 .939 .909 r
.33077 .83089 m .34869 .81546 L p .33014 .82413 L F P
0 g
s
.815 .939 .909 r
.33014 .82413 m .32916 .83056 L .33077 .83089 L p F P
0 g
s
.394 .582 .916 r
.72425 .83026 m .71995 .82939 L .71431 .8211 L p F P
0 g
s
.738 .988 .794 r
.37251 .78938 m .37111 .79126 L .37711 .78879 L p F P
0 g
s
.776 .995 .794 r
.37111 .79126 m .37711 .78879 L .36615 .79922 L closepath p F P
0 g
s
0 0 0 r
.18806 .73396 m .19095 .72438 L .18848 .73601 L p F P
0 g
s
0 0 0 r
.18848 .73601 m .1856 .74554 L .18806 .73396 L p F P
0 g
s
.819 .986 .881 r
.36615 .79922 m .37111 .79126 L p .35257 .80641 L F P
0 g
s
.819 .986 .881 r
.35387 .8111 m .36615 .79922 L p .35257 .80641 L F P
0 g
s
.815 .939 .909 r
.34869 .81546 m .35053 .81133 L p .33014 .82413 L F P
0 g
s
.813 .986 .884 r
.35053 .81133 m .35387 .8111 L .34869 .81546 L closepath p F P
0 g
s
0 0 .117 r
.18449 .75003 m .1856 .74554 L .18514 .75659 L p F P
0 g
s
0 0 .117 r
.18514 .75659 m .18385 .7617 L .18449 .75003 L p F P
0 g
s
.615 .791 .966 r
.26318 .84533 m .24122 .84987 L .24858 .85668 L p F P
0 g
s
.615 .791 .966 r
.24858 .85668 m .27061 .85072 L .26318 .84533 L p F P
0 g
s
.974 .925 .637 r
.86533 .79896 m .86457 .79188 L p .85878 .80773 L F P
0 g
s
.974 .925 .637 r
.85878 .80773 m .86155 .80761 L .86533 .79896 L p F P
0 g
s
.955 .875 .47 r
.86533 .79896 m .86457 .79188 L .86814 .77927 L p F P
0 g
s
.819 .986 .881 r
.35257 .80641 m .35053 .81133 L .35387 .8111 L p F P
0 g
s
.288 .709 .971 r
.60704 .55374 m .62641 .55419 L p .59664 .54999 L F P
0 g
s
.288 .709 .971 r
.59664 .54999 m .59981 .55194 L .60704 .55374 L p F P
0 g
s
.309 .709 .978 r
.60704 .55374 m .62641 .55419 L .63219 .55827 L p F P
0 g
s
.706 .21 .06 r
.59505 .71712 m .6034 .72591 L .59054 .72157 L p F P
0 g
s
.706 .21 .06 r
.59301 .71647 m .59505 .71712 L p .59054 .72157 L F P
0 g
s
.697 .274 .238 r
.55807 .70042 m .55821 .70021 L .55849 .70049 L closepath p F P
0 g
s
.639 .26 .31 r
.55821 .70021 m .55807 .70042 L .53812 .69831 L p F P
0 g
s
.467 .824 .555 r
.39307 .77124 m .41188 .75546 L .39933 .7661 L closepath p F P
0 g
s
.502 .844 .569 r
.39307 .77124 m .39933 .7661 L p .39282 .77152 L F P
0 g
s
.477 .856 .637 r
.39307 .77124 m .39993 .76548 L p .40821 .75957 L F P
0 g
s
.477 .856 .637 r
.39993 .76548 m .41188 .75546 L p .40821 .75957 L F P
0 g
s
.5 .89 .723 r
.40821 .75957 m .40882 .75913 L p .40866 .75925 L F P
0 g
s
.473 .852 .63 r
.40821 .75957 m .39242 .77165 L .3858 .77592 L p F P
0 g
s
.473 .852 .63 r
.3858 .77592 m .3857 .77599 L .38589 .77585 L p F P
0 g
s
.473 .852 .63 r
.38589 .77585 m .40821 .75957 L p .3858 .77592 L F P
0 g
s
.495 .885 .714 r
.38455 .77652 m .37828 .7795 L .39279 .77019 L p F P
0 g
s
.5 .89 .723 r
.3857 .77599 m .38908 .77352 L p .40145 .76464 L F P
0 g
s
.5 .89 .723 r
.38908 .77352 m .40821 .75957 L p .40145 .76464 L F P
0 g
s
.5 .89 .723 r
.40882 .75913 m .40171 .76447 L .40145 .76464 L p F P
0 g
s
.53 .918 .805 r
.40145 .76464 m .40164 .7645 L p .4016 .76453 L F P
0 g
s
.53 .918 .805 r
.38897 .77142 m .40145 .76464 L .4016 .76453 L F
.495 .885 .714 r
.39279 .77019 m .40145 .76464 L .38822 .77393 L p F P
0 g
s
.495 .885 .714 r
.38822 .77393 m .38455 .77652 L p .39279 .77019 L F P
0 g
s
.5 .89 .723 r
.40145 .76464 m .40821 .75957 L .40866 .75925 L F
.477 .856 .637 r
.40821 .75957 m .3933 .77097 L p .39307 .77124 L F P
0 g
s
.477 .856 .637 r
.3933 .77097 m .39242 .77165 L .39307 .77124 L p F P
0 g
s
.502 .844 .569 r
.39147 .77264 m .39307 .77124 L p .39282 .77152 L F P
0 g
s
.721 .878 .954 r
.29311 .84076 m .27061 .85072 L .278 .85564 L p F P
0 g
s
.721 .878 .954 r
.278 .85564 m .30053 .84428 L .29311 .84076 L p F P
0 g
s
.365 .523 .881 r
.21275 .83962 m .22491 .84166 L .22446 .83376 L p F P
0 g
s
.365 .523 .881 r
.22446 .83376 m .20561 .82901 L .21275 .83962 L p F P
0 g
s
.207 .429 .856 r
.20439 .82833 m .20561 .82901 L .21275 .83962 L p F P
0 g
s
.696 .269 .231 r
.55849 .70049 m .55807 .70042 L .55376 .70695 L p F P
0 g
s
.696 .269 .231 r
.55376 .70695 m .5673 .70901 L .55849 .70049 L p F P
0 g
s
.661 .228 .21 r
.55807 .70042 m .53812 .69831 L .54835 .70639 L p F P
0 g
s
.661 .228 .21 r
.54835 .70639 m .55376 .70695 L .55807 .70042 L p F P
0 g
s
.517 .718 .964 r
.75584 .84966 m .78053 .84819 L .7858 .85434 L p F P
0 g
s
.524 .679 .936 r
.7752 .84185 m .78053 .84819 L .75584 .84966 L p F P
0 g
s
.524 .679 .936 r
.75073 .84231 m .7752 .84185 L p .75584 .84966 L F P
0 g
s
.524 .679 .936 r
.75584 .84966 m .75065 .84269 L .75073 .84231 L p F P
0 g
s
.227 .633 .956 r
.67415 .56949 m .66306 .56425 L .68608 .56783 L p F P
0 g
s
.227 .633 .956 r
.6921 .57244 m .67415 .56949 L p .68608 .56783 L F P
0 g
s
.214 .618 .952 r
.67415 .56949 m .6921 .57244 L .69759 .57722 L p F P
0 g
s
0 0 .265 r
.18325 .76567 m .18385 .7617 L .1849 .77478 L p F P
0 g
s
0 0 .265 r
.1849 .77478 m .18469 .77618 L .18325 .76567 L p F P
0 g
s
0 .288 .777 r
.80584 .6408 m .79689 .63482 L .79143 .62823 L p F P
0 g
s
0 .08 .599 r
.66883 .78066 m .66356 .77447 L .65416 .76563 L p F P
0 g
s
0 .032 .526 r
.65416 .76563 m .64783 .75966 L .65733 .76847 L p F P
0 g
s
0 .032 .526 r
.65733 .76847 m .66356 .77447 L .65416 .76563 L p F P
0 g
s
.065 .48 .89 r
.74956 .6021 m .74214 .59591 L .75799 .60209 L p F P
0 g
s
.065 .48 .89 r
.76398 .60781 m .74956 .6021 L p .75799 .60209 L F P
0 g
s
.067 .469 .887 r
.74956 .6021 m .76398 .60781 L .76922 .61358 L p F P
0 g
s
.706 .21 .06 r
.59054 .72157 m .58807 .71934 L .59301 .71647 L p F P
0 g
s
.763 .289 .117 r
.58807 .71934 m .58248 .7127 L .59301 .71647 L closepath p F P
0 g
s
0 .309 .797 r
.81336 .64924 m .81099 .64768 L .80584 .6408 L p F P
0 g
s
.56 .17 .26 r
.49401 .70758 m .4975 .69985 L .50805 .69901 L p F P
0 g
s
.441 .065 .228 r
.4975 .69985 m .49401 .70758 L .47149 .71268 L p F P
0 g
s
.296 .696 .975 r
.63219 .55827 m .65072 .55936 L .63737 .55473 L p F P
0 g
s
.296 .696 .975 r
.63737 .55473 m .62641 .55419 L .63219 .55827 L p F P
0 g
s
.475 .861 .977 r
.44889 .55211 m .45025 .55251 L .47573 .54763 L p F P
0 g
s
.527 .862 .994 r
.47844 .5488 m .47573 .54763 L .45025 .55251 L p F P
0 g
s
.816 .94 .908 r
.3234 .82939 m .33014 .82413 L .32916 .83056 L closepath p F P
0 g
s
.782 .891 .922 r
.32916 .83056 m .3234 .82939 L .30162 .84355 L p F P
0 g
s
.858 .642 .106 r
.86613 .74168 m .8678 .74876 L .86835 .76018 L p F P
0 g
s
.715 .46 0 r
.8678 .74876 m .86613 .74168 L .86384 .73078 L p F P
0 g
s
.648 .961 .926 r
.3141 .59609 m .33677 .58352 L p .32189 .58776 L F P
0 g
s
.648 .961 .926 r
.32189 .58776 m .31016 .59614 L .3141 .59609 L p F P
0 g
s
.576 .928 .948 r
.38228 .56299 m .35949 .57251 L .36679 .5733 L p F P
0 g
s
.576 .928 .948 r
.36679 .5733 m .38947 .56374 L .38228 .56299 L p F P
0 g
s
.584 .929 .953 r
.39051 .56385 m .38947 .56374 L .36679 .5733 L p F P
0 g
s
.631 .942 .955 r
.36679 .5733 m .35949 .57251 L .34848 .5777 L p F P
0 g
s
.695 .832 .395 r
.20179 .69945 m .20665 .68904 L .19992 .70195 L p F P
0 g
s
.695 .832 .395 r
.19754 .70775 m .20179 .69945 L p .19992 .70195 L F P
0 g
s
.14 .544 .923 r
.73326 .59332 m .74214 .59591 L .73406 .58986 L p F P
0 g
s
.14 .544 .923 r
.73406 .58986 m .72791 .58812 L .73326 .59332 L p F P
0 g
s
.136 .544 .922 r
.71548 .58467 m .72791 .58812 L .73326 .59332 L p F P
0 g
s
.339 .553 .913 r
.72425 .83026 m .74488 .83496 L .73934 .82768 L p F P
0 g
s
.339 .553 .913 r
.73934 .82768 m .72309 .82325 L .72425 .83026 L p F P
0 g
s
.394 .582 .916 r
.71431 .8211 m .72309 .82325 L .72425 .83026 L p F P
0 g
s
.114 .543 .916 r
.72791 .58812 m .71548 .58467 L .70645 .57888 L p F P
0 g
s
.342 .741 .983 r
.59664 .54999 m .59059 .55012 L .59981 .55194 L closepath p F P
0 g
s
.56 .17 .26 r
.50805 .69901 m .52243 .70428 L p .49401 .70758 L F P
0 g
s
.559 .159 .24 r
.52243 .70428 m .50805 .69901 L .52549 .6978 L closepath p F P
0 g
s
.453 .82 .994 r
.50314 .54467 m .50794 .54699 L .52597 .54402 L closepath p F P
0 g
s
.495 .842 .996 r
.50794 .54699 m .50314 .54467 L .4931 .54568 L p F P
0 g
s
0 .079 .599 r
.66883 .78066 m .67218 .78377 L .66643 .77717 L p F P
0 g
s
0 .079 .599 r
.66643 .77717 m .66356 .77447 L .66883 .78066 L p F P
0 g
s
.487 .843 .994 r
.47573 .54763 m .47844 .5488 L .4931 .54568 L closepath p F P
0 g
s
.945 .96 .692 r
.85885 .81236 m .85878 .80773 L .86155 .80761 L closepath p F P
0 g
s
.215 .614 .952 r
.69759 .57722 m .70645 .57888 L .69667 .57326 L p F P
0 g
s
.215 .614 .952 r
.69667 .57326 m .6921 .57244 L .69759 .57722 L p F P
0 g
s
0 .194 .717 r
.82749 .66439 m .82316 .65761 L .81336 .64924 L p F P
0 g
s
0 .173 .695 r
.80849 .64255 m .81336 .64924 L .82316 .65761 L p F P
0 g
s
0 .309 .797 r
.80584 .6408 m .80849 .64255 L .81336 .64924 L p F P
0 g
s
.076 .473 .89 r
.76922 .61358 m .77197 .61468 L .7653 .60832 L p F P
0 g
s
.076 .473 .89 r
.7653 .60832 m .76398 .60781 L .76922 .61358 L p F P
0 g
s
.604 .205 .261 r
.53812 .69831 m .54835 .70639 L .52419 .70528 L p F P
0 g
s
.604 .205 .261 r
.52549 .6978 m .53812 .69831 L p .52419 .70528 L F P
0 g
s
.422 .795 .993 r
.53265 .54395 m .53745 .54654 L .55095 .54495 L closepath p F P
0 g
s
.461 .819 .996 r
.53745 .54654 m .53265 .54395 L .52597 .54402 L p F P
0 g
s
.753 .88 .937 r
.82739 .84403 m .81523 .85147 L .81019 .84671 L p F P
0 g
s
.643 .827 .971 r
.7858 .85434 m .81019 .84671 L .81523 .85147 L p F P
0 g
s
.597 .946 .917 r
.33677 .58352 m .34848 .5777 L .33885 .58346 L closepath p F P
0 g
s
.765 .257 0 r
.6141 .73082 m .6034 .72591 L .61177 .73481 L p F P
0 g
s
.765 .257 0 r
.61177 .73481 m .62173 .73994 L .6141 .73082 L p F P
0 g
s
0 0 .304 r
.86114 .72246 m .85775 .71336 L p .86378 .7306 L F P
0 g
s
0 0 .304 r
.86384 .73078 m .86364 .73017 L .86378 .7306 L F
.86364 .73017 m .86114 .72246 L .86378 .7306 L F
.86384 .73078 m .86193 .72469 L .86114 .72246 L p F P
0 g
s
.772 .494 0 r
.86613 .74168 m .86515 .73853 L .86197 .72484 L p F P
0 g
s
.772 .494 0 r
.86197 .72484 m .86193 .72469 L p .86198 .72487 L F P
0 g
s
.772 .494 0 r
.86613 .74168 m .86197 .72484 L .86198 .72487 L F
.86193 .72469 m .86384 .73078 L .86613 .74168 L p F P
0 g
s
.711 .961 .698 r
.23727 .65044 m .24192 .64571 L .23956 .64887 L closepath p F P
0 g
s
.786 .99 .75 r
.23956 .64887 m .23727 .65044 L .22736 .66104 L p F P
0 g
s
.475 .862 .976 r
.46516 .54437 m .44211 .55022 L .44889 .55211 L p F P
0 g
s
.475 .862 .976 r
.44889 .55211 m .47184 .5464 L .46516 .54437 L p F P
0 g
s
.475 .861 .977 r
.47573 .54763 m .47184 .5464 L .44889 .55211 L p F P
0 g
s
.604 .205 .261 r
.52419 .70528 m .52243 .70428 L .52549 .6978 L p F P
0 g
s
.912 .956 .808 r
.85878 .80773 m .85885 .81236 L .84763 .82703 L p F P
0 g
s
.32 .74 .976 r
.59664 .54999 m .59059 .55012 L .57226 .54707 L p F P
0 g
s
.623 .806 .97 r
.81019 .84671 m .7858 .85434 L .78053 .84819 L p F P
0 g
s
.055 .246 .742 r
.19862 .81638 m .19389 .81213 L .194 .80654 L closepath p F P
0 g
s
.069 .283 .771 r
.19389 .81213 m .19862 .81638 L .20432 .82687 L p F P
0 g
s
.204 0 .019 r
.46783 .71378 m .46954 .71311 L p .44386 .7287 L F P
0 g
s
.236 0 .067 r
.46954 .71311 m .46967 .71287 L .46783 .71378 L closepath p F P
0 g
s
.974 .879 .503 r
.86696 .77219 m .86814 .77927 L .86457 .79188 L p F P
0 g
s
.922 .774 .295 r
.86814 .77927 m .86696 .77219 L .86835 .76018 L p F P
0 g
s
.783 .891 .922 r
.30053 .84428 m .30162 .84355 L .30172 .84478 L closepath p F P
0 g
s
0 0 0 r
.41635 .75173 m .43857 .73642 L .42053 .74648 L closepath p F P
0 g
s
.469 .826 .558 r
.42053 .74648 m .41635 .75173 L .41188 .75546 L p F P
0 g
s
.179 .388 .831 r
.20561 .82901 m .20439 .82833 L .20432 .82687 L closepath p F P
0 g
s
0 .081 .633 r
.83955 .68015 m .83575 .6733 L .82749 .66439 L p F P
0 g
s
0 .055 .603 r
.82316 .65761 m .82749 .66439 L .83575 .6733 L p F P
0 g
s
.695 .832 .395 r
.19992 .70195 m .19589 .71061 L .19754 .70775 L p F P
0 g
s
.765 .865 .431 r
.19589 .71061 m .19754 .70775 L .19531 .71222 L closepath p F P
0 g
s
.412 .005 .154 r
.46954 .71311 m .46967 .71287 L .47149 .71268 L closepath p F P
0 g
s
0 0 .422 r
.85775 .71336 m .85501 .70639 L .84964 .69648 L p F P
0 g
s
.69 .362 0 r
.85775 .71336 m .86114 .72246 L .85526 .70707 L p F P
0 g
s
.69 .362 0 r
.85526 .70707 m .85501 .70639 L .85775 .71336 L p F P
0 g
s
.395 .77 .992 r
.56463 .54603 m .567 .54746 L .57226 .54707 L closepath p F P
0 g
s
.431 .794 .996 r
.567 .54746 m .56463 .54603 L .55095 .54495 L p F P
0 g
s
.04 .38 .844 r
.70242 .80969 m .69881 .80318 L .68513 .79528 L p F P
0 g
s
0 .347 .821 r
.68103 .78884 m .68513 .79528 L .69881 .80318 L p F P
0 g
s
.054 .396 .853 r
.67218 .78377 m .68103 .78884 L .68513 .79528 L p F P
0 g
s
.409 0 .148 r
.46546 .72053 m .46954 .71311 L .47149 .71268 L p F P
0 g
s
.204 0 .019 r
.46954 .71311 m .46546 .72053 L .44386 .7287 L p F P
0 g
s
0 .371 .824 r
.77197 .61468 m .7653 .60832 L .7788 .61536 L p F P
0 g
s
0 .371 .824 r
.7788 .61536 m .78541 .62174 L .77197 .61468 L p F P
0 g
s
.819 .986 .88 r
.34651 .81163 m .35257 .80641 L .35053 .81133 L closepath p F P
0 g
s
.815 .939 .909 r
.35053 .81133 m .34651 .81163 L .33014 .82413 L p F P
0 g
s
0 0 .536 r
.84964 .69648 m .84637 .68957 L .83955 .68015 L p F P
0 g
s
0 0 .499 r
.83575 .6733 m .83955 .68015 L .84637 .68957 L p F P
0 g
s
.753 .88 .937 r
.81019 .84671 m .8275 .83688 L .82739 .84403 L p F P
0 g
s
.796 .924 .922 r
.83419 .83257 m .8275 .83688 L .82739 .84403 L p F P
0 g
s
.796 .924 .922 r
.82739 .84403 m .83899 .83589 L .83419 .83257 L p F P
0 g
s
.616 .055 0 r
.62943 .74489 m .62999 .7451 L .63034 .74539 L closepath p F P
0 g
s
.741 .22 0 r
.62173 .73994 m .62943 .74489 L .62999 .7451 L p F P
0 g
s
0 0 .397 r
.84637 .68957 m .84964 .69648 L .85501 .70639 L p F P
0 g
s
0 0 .151 r
.1856 .74554 m .18848 .73601 L .18803 .74709 L p F P
0 g
s
0 0 .151 r
.18803 .74709 m .18514 .75659 L .1856 .74554 L p F P
0 g
s
.345 .532 .896 r
.20561 .82901 m .20432 .82687 L p .22448 .83151 L F P
0 g
s
.345 .532 .896 r
.22448 .83151 m .22446 .83376 L .20561 .82901 L p F P
0 g
s
.719 .236 .097 r
.58248 .7127 m .5673 .70901 L .57618 .71762 L p F P
0 g
s
.719 .236 .097 r
.58807 .71934 m .58248 .7127 L p .57618 .71762 L F P
0 g
s
0 .073 .615 r
.19187 .80102 m .18764 .79467 L .18808 .78958 L closepath p F P
0 g
s
0 .083 .629 r
.18764 .79467 m .19187 .80102 L .194 .80654 L p F P
0 g
s
.409 0 .148 r
.47149 .71268 m .49271 .7104 L p .46546 .72053 L F P
0 g
s
.427 .037 .195 r
.49271 .7104 m .47149 .71268 L .49401 .70758 L closepath p F P
0 g
s
.348 .568 .921 r
.72309 .82325 m .71431 .8211 L .70866 .81316 L p F P
0 g
s
.585 .017 0 r
.63034 .74539 m .64028 .75396 L .63138 .74859 L p F P
0 g
s
.585 .017 0 r
.62943 .74489 m .63034 .74539 L p .63138 .74859 L F P
0 g
s
.521 .887 .975 r
.41251 .55549 m .41925 .55721 L .44211 .55022 L p F P
0 g
s
.571 .906 .977 r
.41925 .55721 m .41251 .55549 L .39051 .56385 L p F P
0 g
s
0 0 .343 r
.18385 .7617 m .18514 .75659 L .18691 .76703 L p F P
0 g
s
0 0 .343 r
.18691 .76703 m .1849 .77478 L .18385 .7617 L p F P
0 g
s
.783 .903 .926 r
.30189 .83559 m .29311 .84076 L .30053 .84428 L p F P
0 g
s
.783 .903 .926 r
.30053 .84428 m .30162 .84355 L .30189 .83559 L p F P
0 g
s
0 .357 .824 r
.68103 .78884 m .67218 .78377 L .66643 .77717 L p F P
0 g
s
.286 .674 .972 r
.66105 .5634 m .66201 .56416 L .66306 .56425 L closepath p F P
0 g
s
.302 .691 .977 r
.66201 .56416 m .66105 .5634 L .65072 .55936 L p F P
0 g
s
.737 .932 .953 r
.3234 .82939 m .30162 .84355 L .30189 .83559 L p F P
0 g
s
.22 0 .027 r
.43956 .73573 m .44386 .7287 L .46546 .72053 L p F P
0 g
s
0 0 0 r
.44386 .7287 m .43956 .73573 L .43857 .73642 L p F P
0 g
s
.865 .938 .867 r
.84763 .82703 m .83899 .83589 L .83419 .83257 L p F P
0 g
s
.865 .938 .867 r
.83419 .83257 m .84714 .81997 L .84763 .82703 L p F P
0 g
s
.912 .956 .808 r
.85719 .80736 m .85878 .80773 L p .84763 .82703 L F P
0 g
s
.912 .956 .808 r
.84763 .82703 m .84714 .81997 L .85719 .80736 L p F P
0 g
s
0 0 0 r
.19531 .71222 m .19589 .71061 L .19254 .71996 L p F P
0 g
s
0 0 0 r
.19254 .71996 m .19095 .72438 L .19531 .71222 L p F P
0 g
s
.585 .017 0 r
.63138 .74859 m .62422 .74287 L .62943 .74489 L p F P
0 g
s
.736 .213 0 r
.62422 .74287 m .62173 .73994 L .62943 .74489 L closepath p F P
0 g
s
.345 .532 .896 r
.20432 .82687 m .20525 .81996 L p .22448 .83151 L F P
0 g
s
.232 .394 .819 r
.20525 .81996 m .20432 .82687 L .19862 .81638 L closepath p F P
0 g
s
.188 .629 .944 r
.66306 .56425 m .68608 .56783 L .67444 .56268 L p F P
0 g
s
.188 .629 .944 r
.66105 .5634 m .66306 .56425 L p .67444 .56268 L F P
0 g
s
.581 .942 .904 r
.35204 .57262 m .3292 .58378 L .33677 .58352 L p F P
0 g
s
.581 .942 .904 r
.35764 .57233 m .35204 .57262 L p .33677 .58352 L F P
0 g
s
.581 .942 .904 r
.33677 .58352 m .34848 .5777 L .35764 .57233 L p F P
0 g
s
.648 .961 .926 r
.33677 .58352 m .3292 .58378 L .32189 .58776 L p F P
0 g
s
.421 .833 .971 r
.47184 .5464 m .47573 .54763 L .4931 .54568 L p F P
0 g
s
.523 .906 .946 r
.38947 .56374 m .39051 .56385 L .41251 .55549 L p F P
0 g
s
.582 .762 .964 r
.25573 .83934 m .23386 .84237 L .24122 .84987 L p F P
0 g
s
.582 .762 .964 r
.24122 .84987 m .26318 .84533 L .25573 .83934 L p F P
0 g
s
.469 .648 .936 r
.22491 .84166 m .23386 .84237 L .24122 .84987 L p F P
0 g
s
.523 .679 .936 r
.75065 .84269 m .75038 .84232 L .75073 .84231 L closepath p F P
0 g
s
.689 .954 .695 r
.24192 .64571 m .25192 .63332 L .23581 .64923 L p F P
0 g
s
.689 .954 .695 r
.23727 .65044 m .24192 .64571 L p .23581 .64923 L F P
0 g
s
.699 .974 .765 r
.26037 .62913 m .24192 .64571 L .25192 .63332 L p F P
0 g
s
.3 .724 .972 r
.59664 .54999 m .62058 .55029 L p .60685 .54656 L F P
0 g
s
.3 .724 .972 r
.60685 .54656 m .59068 .54652 L .59664 .54999 L p F P
0 g
s
.288 .709 .971 r
.62641 .55419 m .62058 .55029 L .59664 .54999 L p F P
0 g
s
.32 .74 .976 r
.57226 .54707 m .59068 .54652 L .59664 .54999 L p F P
0 g
s
.026 .369 .838 r
.70242 .80969 m .70866 .81316 L .70299 .80566 L p F P
0 g
s
.026 .369 .838 r
.70299 .80566 m .69881 .80318 L .70242 .80969 L p F P
0 g
s
.699 .974 .765 r
.26048 .62899 m .26037 .62913 L p .25192 .63332 L F P
0 g
s
.745 .993 .847 r
.26048 .62899 m .26057 .62897 L .26037 .62913 L closepath p F P
0 g
s
.304 .74 .967 r
.57226 .54707 m .59068 .54652 L p .56089 .54416 L F P
0 g
s
.304 .74 .967 r
.56089 .54416 m .56463 .54603 L .57226 .54707 L p F P
0 g
s
.699 .983 .847 r
.26057 .62897 m .28354 .61155 L p .2736 .61559 L F P
0 g
s
.699 .983 .847 r
.2736 .61559 m .26048 .62899 L .26057 .62897 L p F P
0 g
s
.523 .68 .937 r
.75073 .84231 m .75038 .84232 L .74488 .83496 L p F P
0 g
s
.188 .629 .944 r
.67444 .56268 m .65636 .56005 L .66105 .5634 L p F P
0 g
s
.215 .646 .953 r
.65636 .56005 m .65072 .55936 L .66105 .5634 L closepath p F P
0 g
s
.689 .954 .695 r
.23581 .64923 m .23198 .65402 L .23727 .65044 L p F P
0 g
s
.749 .973 .709 r
.23198 .65402 m .23727 .65044 L .22736 .66104 L closepath p F P
0 g
s
.657 .959 .758 r
.25219 .63309 m .2736 .61559 L .26048 .62899 L closepath p F P
0 g
s
.699 .974 .765 r
.25192 .63332 m .25219 .63309 L .26048 .62899 L p F P
0 g
s
.611 .956 .87 r
.30638 .59683 m .32189 .58776 L .31016 .59614 L closepath p F P
0 g
s
.679 .976 .891 r
.31016 .59614 m .30638 .59683 L .28509 .61046 L p F P
0 g
s
.49 .66 .937 r
.75073 .84231 m .7752 .84185 L .76983 .8354 L p F P
0 g
s
.49 .66 .937 r
.76983 .8354 m .75107 .83498 L .75073 .84231 L p F P
0 g
s
.523 .68 .937 r
.74488 .83496 m .75107 .83498 L .75073 .84231 L p F P
0 g
s
.952 .788 .336 r
.86669 .75312 m .86835 .76018 L .86696 .77219 L p F P
0 g
s
.858 .642 .106 r
.86835 .76018 m .86669 .75312 L .86613 .74168 L p F P
0 g
s
.014 .46 .871 r
.74214 .59591 m .73406 .58986 L .75003 .596 L p F P
0 g
s
.014 .46 .871 r
.75003 .596 m .75799 .60209 L .74214 .59591 L p F P
0 g
s
0 0 0 r
.19589 .71061 m .19992 .70195 L .1952 .71427 L p F P
0 g
s
0 0 0 r
.1952 .71427 m .19254 .71996 L .19589 .71061 L p F P
0 g
s
0 0 .448 r
.18575 .7793 m .18469 .77618 L .1849 .77478 L closepath p F P
0 g
s
0 0 .455 r
.18469 .77618 m .18575 .7793 L .18808 .78958 L p F P
0 g
s
.541 .008 0 r
.64783 .75966 m .64028 .75396 L .65013 .76268 L p F P
0 g
s
.541 .008 0 r
.65013 .76268 m .65733 .76847 L .64783 .75966 L p F P
0 g
s
0 .272 .757 r
.80069 .63439 m .79143 .62823 L .78541 .62174 L p F P
0 g
s
0 .288 .777 r
.79143 .62823 m .80069 .63439 L .80584 .6408 L p F P
0 g
s
.694 .86 .961 r
.28565 .83679 m .26318 .84533 L .27061 .85072 L p F P
0 g
s
.694 .86 .961 r
.27061 .85072 m .29311 .84076 L .28565 .83679 L p F P
0 g
s
.433 .62 .93 r
.23386 .84237 m .22491 .84166 L .22446 .83376 L p F P
0 g
s
.661 .901 .566 r
.22736 .66104 m .2156 .67548 L .223 .66408 L p F P
0 g
s
.661 .901 .566 r
.23198 .65402 m .22736 .66104 L p .223 .66408 L F P
0 g
s
.124 .559 .921 r
.70645 .57888 m .69667 .57326 L .7158 .57823 L p F P
0 g
s
.124 .559 .921 r
.72254 .5832 m .70645 .57888 L p .7158 .57823 L F P
0 g
s
.114 .543 .916 r
.70645 .57888 m .72254 .5832 L .72791 .58812 L p F P
0 g
s
.362 .774 .98 r
.56089 .54416 m .55095 .54495 L .56463 .54603 L closepath p F P
0 g
s
0 .295 .782 r
.80584 .6408 m .80849 .64255 L .80306 .63595 L p F P
0 g
s
0 .295 .782 r
.80306 .63595 m .80069 .63439 L .80584 .6408 L p F P
0 g
s
.517 .905 .942 r
.4052 .5547 m .38228 .56299 L .38947 .56374 L p F P
0 g
s
.517 .905 .942 r
.38947 .56374 m .41228 .55546 L .4052 .5547 L p F P
0 g
s
.523 .906 .946 r
.41251 .55549 m .41228 .55546 L .38947 .56374 L p F P
0 g
s
.641 .964 .817 r
.28354 .61155 m .28509 .61046 L .28404 .61138 L closepath p F P
0 g
s
.421 .833 .971 r
.4931 .54568 m .50152 .54407 L p .47184 .5464 L F P
0 g
s
.437 .834 .98 r
.50152 .54407 m .4931 .54568 L .50314 .54467 L closepath p F P
0 g
s
.671 .865 .476 r
.2133 .67886 m .2156 .67548 L .21466 .67706 L closepath p F P
0 g
s
.709 .883 .493 r
.20665 .68904 m .2133 .67886 L .21466 .67706 L p F P
0 g
s
.974 .925 .637 r
.86457 .79188 m .85847 .80523 L .85878 .80773 L p F P
0 g
s
.973 .927 .659 r
.86334 .78486 m .86457 .79188 L .85847 .80523 L p F P
0 g
s
.974 .879 .503 r
.86457 .79188 m .86334 .78486 L .86696 .77219 L p F P
0 g
s
.802 .974 .905 r
.33406 .81505 m .31597 .8275 L .3234 .82939 L p F P
0 g
s
.802 .974 .905 r
.3234 .82939 m .33014 .82413 L .33406 .81505 L p F P
0 g
s
.737 .932 .953 r
.30189 .83559 m .31597 .8275 L .3234 .82939 L p F P
0 g
s
.233 .394 .819 r
.19862 .81638 m .194 .80654 L p .20645 .81139 L F P
0 g
s
.233 .394 .819 r
.20645 .81139 m .20525 .81996 L .19862 .81638 L p F P
0 g
s
.743 .239 .023 r
.6034 .72591 m .59054 .72157 L .59999 .73015 L p F P
0 g
s
.743 .239 .023 r
.59999 .73015 m .61177 .73481 L .6034 .72591 L p F P
0 g
s
.335 .77 .968 r
.55095 .54495 m .56089 .54416 L p .53119 .54332 L F P
0 g
s
.335 .77 .968 r
.53119 .54332 m .53265 .54395 L .55095 .54495 L p F P
0 g
s
.612 .949 .789 r
.29848 .59852 m .27543 .61424 L .28354 .61155 L p F P
0 g
s
.612 .949 .789 r
.29993 .59797 m .29848 .59852 L p .28354 .61155 L F P
0 g
s
.612 .949 .789 r
.28354 .61155 m .28509 .61046 L .29993 .59797 L p F P
0 g
s
.699 .983 .847 r
.28354 .61155 m .27543 .61424 L .2736 .61559 L p F P
0 g
s
.621 .943 .95 r
.35764 .57233 m .35949 .57251 L .34848 .5777 L closepath p F P
0 g
s
.95 .949 .729 r
.85719 .80736 m .85847 .80523 L .85878 .80773 L closepath p F P
0 g
s
.745 .978 .919 r
.34651 .81163 m .33014 .82413 L .33406 .81505 L p F P
0 g
s
.737 .987 .79 r
.36976 .79183 m .37251 .78938 L .37111 .79126 L closepath p F P
0 g
s
.819 .986 .881 r
.37111 .79126 m .36976 .79183 L .35257 .80641 L p F P
0 g
s
.66 .972 .875 r
.29993 .59797 m .30638 .59683 L .28509 .61046 L closepath p F P
0 g
s
0 .004 .541 r
.1849 .77478 m .18691 .76703 L .19123 .77679 L p F P
0 g
s
0 .004 .541 r
.18575 .7793 m .1849 .77478 L p .19123 .77679 L F P
0 g
s
.655 .22 .202 r
.5673 .70901 m .57618 .71762 L .55897 .71447 L p F P
0 g
s
.655 .22 .202 r
.55376 .70695 m .5673 .70901 L p .55897 .71447 L F P
0 g
s
.375 .802 .97 r
.50152 .54407 m .50314 .54467 L .52597 .54402 L p F P
0 g
s
.9 .665 .155 r
.86515 .73853 m .86613 .74168 L .86669 .75312 L p F P
0 g
s
0 .031 .526 r
.66643 .77717 m .66356 .77447 L .65733 .76847 L p F P
0 g
s
.122 .545 .919 r
.72791 .58812 m .73406 .58986 L .72531 .58396 L p F P
0 g
s
.122 .545 .919 r
.72531 .58396 m .72254 .5832 L .72791 .58812 L p F P
0 g
s
.375 .802 .97 r
.52597 .54402 m .53119 .54332 L p .50152 .54407 L F P
0 g
s
.397 .804 .981 r
.53119 .54332 m .52597 .54402 L .53265 .54395 L closepath p F P
0 g
s
0 .004 .541 r
.19123 .77679 m .18885 .78596 L .18575 .7793 L p F P
0 g
s
0 0 .536 r
.18885 .78596 m .18808 .78958 L .18575 .7793 L closepath p F P
0 g
s
.639 .851 .464 r
.2156 .67548 m .223 .66408 L .21326 .67796 L p F P
0 g
s
.639 .851 .464 r
.2133 .67886 m .2156 .67548 L p .21326 .67796 L F P
0 g
s
.291 .702 .973 r
.62641 .55419 m .63737 .55473 L .623 .55038 L p F P
0 g
s
.291 .702 .973 r
.623 .55038 m .62058 .55029 L .62641 .55419 L p F P
0 g
s
0 .173 .695 r
.82316 .65761 m .8183 .65092 L .80849 .64255 L p F P
0 g
s
0 .152 .668 r
.80849 .64255 m .80306 .63595 L .81289 .64432 L p F P
0 g
s
0 .152 .668 r
.81289 .64432 m .8183 .65092 L .80849 .64255 L p F P
0 g
s
.8 .515 0 r
.86162 .72376 m .86193 .72469 L .86515 .73853 L p F P
0 g
s
0 0 .269 r
.86193 .72469 m .86114 .72246 L .86162 .72376 L closepath p F P
0 g
s
.285 .539 .917 r
.72309 .82325 m .73934 .82768 L .73378 .82057 L p F P
0 g
s
.285 .539 .917 r
.73378 .82057 m .72064 .81651 L .72309 .82325 L p F P
0 g
s
.348 .568 .921 r
.70866 .81316 m .72064 .81651 L .72309 .82325 L p F P
0 g
s
.68 .35 0 r
.86162 .72376 m .86114 .72246 L .85526 .70707 L p F P
0 g
s
0 0 0 r
.19095 .72438 m .19254 .71996 L .19048 .73046 L p F P
0 g
s
0 0 0 r
.19048 .73046 m .18848 .73601 L .19095 .72438 L p F P
0 g
s
.769 .997 .836 r
.35915 .79648 m .33908 .81166 L .34651 .81163 L p F P
0 g
s
.769 .997 .836 r
.34651 .81163 m .35257 .80641 L .35915 .79648 L p F P
0 g
s
.745 .978 .919 r
.33406 .81505 m .33908 .81166 L .34651 .81163 L p F P
0 g
s
.233 .394 .819 r
.194 .80654 m .19449 .80372 L .20645 .81139 L p F P
0 g
s
.074 .215 .707 r
.19449 .80372 m .194 .80654 L .19187 .80102 L closepath p F P
0 g
s
.046 .466 .882 r
.76059 .60429 m .76398 .60781 L .7653 .60832 L closepath p F P
0 g
s
.065 .48 .89 r
.75799 .60209 m .76059 .60429 L .76398 .60781 L p F P
0 g
s
.686 .979 .83 r
.36976 .79183 m .35257 .80641 L .35915 .79648 L p F P
0 g
s
.623 .806 .97 r
.78053 .84819 m .80508 .84158 L .81019 .84671 L p F P
0 g
s
.605 .789 .969 r
.80508 .84158 m .78053 .84819 L .7752 .84185 L p F P
0 g
s
.639 .851 .464 r
.21326 .67796 m .20914 .68434 L .2133 .67886 L p F P
0 g
s
.716 .888 .499 r
.20914 .68434 m .2133 .67886 L .20665 .68904 L closepath p F P
0 g
s
.739 .869 .941 r
.8275 .83688 m .81019 .84671 L .80508 .84158 L p F P
0 g
s
.521 .129 .238 r
.49401 .70758 m .52188 .70525 L p .50661 .71337 L F P
0 g
s
.521 .129 .238 r
.50661 .71337 m .49271 .7104 L .49401 .70758 L p F P
0 g
s
.56 .17 .26 r
.52243 .70428 m .52188 .70525 L .49401 .70758 L p F P
0 g
s
.091 .22 .705 r
.19187 .80102 m .18808 .78958 L p .19639 .79483 L F P
0 g
s
.091 .22 .705 r
.19639 .79483 m .19449 .80372 L .19187 .80102 L p F P
0 g
s
.194 .612 .946 r
.68707 .56831 m .6921 .57244 L .69667 .57326 L closepath p F P
0 g
s
.227 .633 .956 r
.68608 .56783 m .68707 .56831 L .6921 .57244 L p F P
0 g
s
.186 .641 .941 r
.65636 .56005 m .65072 .55936 L .63737 .55473 L p F P
0 g
s
.091 .22 .705 r
.18808 .78958 m .18885 .78596 L .19639 .79483 L p F P
0 g
s
.8 .515 0 r
.86515 .73853 m .86385 .7347 L .86162 .72376 L p F P
0 g
s
.846 .544 .009 r
.85877 .71684 m .86162 .72376 L .86385 .7347 L p F P
0 g
s
.68 .35 0 r
.85526 .70707 m .85877 .71684 L .86162 .72376 L p F P
0 g
s
0 0 .361 r
.18514 .75659 m .18803 .74709 L .18978 .75758 L p F P
0 g
s
0 0 .361 r
.18978 .75758 m .18691 .76703 L .18514 .75659 L p F P
0 g
s
.706 .218 .084 r
.58642 .72049 m .58807 .71934 L .59054 .72157 L closepath p F P
0 g
s
.719 .236 .097 r
.57618 .71762 m .58642 .72049 L .58807 .71934 L p F P
0 g
s
.298 .556 .925 r
.72064 .81651 m .70866 .81316 L .70299 .80566 L p F P
0 g
s
.639 .938 .696 r
.38264 .77834 m .36235 .79409 L .36976 .79183 L p F P
0 g
s
.639 .938 .696 r
.36976 .79183 m .37251 .78938 L .38264 .77834 L p F P
0 g
s
.686 .979 .83 r
.35915 .79648 m .36235 .79409 L .36976 .79183 L p F P
0 g
s
.513 .874 .645 r
.39147 .77264 m .37251 .78938 L .38264 .77834 L p F P
0 g
s
0 .362 .807 r
.7653 .60832 m .7788 .61536 L .7716 .60909 L p F P
0 g
s
0 .362 .807 r
.76059 .60429 m .7653 .60832 L p .7716 .60909 L F P
0 g
s
.762 .251 0 r
.62422 .74287 m .62173 .73994 L .61177 .73481 L p F P
0 g
s
0 .055 .603 r
.83575 .6733 m .83142 .66653 L .82316 .65761 L p F P
0 g
s
0 .028 .569 r
.8183 .65092 m .82316 .65761 L .83142 .66653 L p F P
0 g
s
.655 .22 .202 r
.55897 .71447 m .55216 .70933 L .55376 .70695 L p F P
0 g
s
.659 .224 .205 r
.55216 .70933 m .54835 .70639 L .55376 .70695 L closepath p F P
0 g
s
.387 .807 .973 r
.51845 .53828 m .49502 .54181 L .50152 .54407 L p F P
0 g
s
.387 .807 .973 r
.50152 .54407 m .52486 .54076 L .51845 .53828 L p F P
0 g
s
.375 .802 .97 r
.53119 .54332 m .52486 .54076 L .50152 .54407 L p F P
0 g
s
.421 .833 .971 r
.50152 .54407 m .49502 .54181 L .47184 .5464 L p F P
0 g
s
.513 .874 .645 r
.39242 .77165 m .39147 .77264 L p .38264 .77834 L F P
0 g
s
.617 .927 .683 r
.39242 .77165 m .39307 .77124 L .39147 .77264 L closepath p F P
0 g
s
.574 .927 .95 r
.35764 .57233 m .35949 .57251 L .38228 .56299 L p F P
0 g
s
0 .347 .821 r
.69881 .80318 m .69433 .79685 L .68103 .78884 L p F P
0 g
s
0 .321 .797 r
.67584 .78262 m .68103 .78884 L .69433 .79685 L p F P
0 g
s
0 .357 .824 r
.66643 .77717 m .67584 .78262 L .68103 .78884 L p F P
0 g
s
.608 .189 .222 r
.52188 .70525 m .52243 .70428 L .52419 .70528 L closepath p F P
0 g
s
.427 .839 .97 r
.47184 .5464 m .49502 .54181 L p .48596 .54012 L F P
0 g
s
.427 .839 .97 r
.48596 .54012 m .46516 .54437 L .47184 .5464 L p F P
0 g
s
.947 .939 .75 r
.85847 .80523 m .85719 .80736 L .85262 .80544 L p F P
0 g
s
.947 .939 .75 r
.85262 .80544 m .85711 .79828 L .85847 .80523 L p F P
0 g
s
.973 .927 .659 r
.85847 .80523 m .85711 .79828 L .86334 .78486 L p F P
0 g
s
.61 .157 .151 r
.54835 .70639 m .52419 .70528 L .53725 .71261 L p F P
0 g
s
.61 .157 .151 r
.55216 .70933 m .54835 .70639 L p .53725 .71261 L F P
0 g
s
.745 .396 0 r
.85526 .70707 m .85501 .70639 L .85469 .7057 L closepath p F P
0 g
s
0 0 .397 r
.85501 .70639 m .84981 .69601 L .84659 .69001 L F
.85501 .70639 m .85469 .7057 L .84981 .69601 L p F P
0 g
s
0 0 .499 r
.84637 .68957 m .84257 .68273 L .83575 .6733 L p F P
0 g
s
0 0 .365 r
.85469 .7057 m .84981 .69601 L .85169 .69951 L closepath p F P
0 g
s
.637 .244 0 r
.84981 .69601 m .84448 .68634 L p .85158 .69932 L F P
0 g
s
.637 .244 0 r
.85169 .69951 m .84981 .69601 L p .85158 .69932 L F P
0 g
s
0 0 .397 r
.84981 .69601 m .84637 .68957 L p .84659 .69001 L F P
0 g
s
.346 .781 .967 r
.53119 .54332 m .55472 .54123 L p .54708 .53856 L F P
0 g
s
.346 .781 .967 r
.54708 .53856 m .52486 .54076 L .53119 .54332 L p F P
0 g
s
.335 .77 .968 r
.56089 .54416 m .55472 .54123 L .53119 .54332 L p F P
0 g
s
.986 .879 .531 r
.8653 .76517 m .86696 .77219 L .86334 .78486 L p F P
0 g
s
.952 .788 .336 r
.86696 .77219 m .8653 .76517 L .86669 .75312 L p F P
0 g
s
0 .325 .785 r
.66643 .77717 m .67584 .78262 L .66957 .77664 L p F P
0 g
s
0 .325 .785 r
.66957 .77664 m .66069 .77158 L .66643 .77717 L p F P
0 g
s
0 .307 .744 r
.66219 .7709 m .65751 .76836 L p .66069 .77158 L F P
0 g
s
0 .031 .526 r
.65733 .76847 m .66069 .77158 L p .66246 .77337 L F P
0 g
s
.542 .009 0 r
.66069 .77158 m .65733 .76847 L .65013 .76268 L p F P
0 g
s
.542 .009 0 r
.65493 .76696 m .66069 .77158 L p .65721 .76865 L F P
0 g
s
.542 .009 0 r
.65013 .76268 m .65493 .76696 L p .65721 .76865 L F P
0 g
s
.585 .033 0 r
.65493 .76696 m .65013 .76268 L .64182 .75714 L p F P
0 g
s
.585 .033 0 r
.64916 .76324 m .65493 .76696 L p .65172 .76455 L F P
0 g
s
.585 .033 0 r
.64182 .75714 m .64916 .76324 L p .65172 .76455 L F P
0 g
s
.607 .043 0 r
.64916 .76324 m .64182 .75714 L .63222 .75191 L p F P
0 g
s
.607 .043 0 r
.63222 .75191 m .64335 .76029 L .64916 .76324 L p F P
0 g
s
0 .31 .678 r
.64916 .76324 m .65356 .76545 L .64689 .76207 L p F P
0 g
s
0 .31 .678 r
.64689 .76207 m .64348 .76035 L p .64916 .76324 L F P
0 g
s
0 .301 .706 r
.65356 .76545 m .6515 .76442 L p .65493 .76696 L F P
0 g
s
0 .301 .706 r
.6515 .76442 m .64916 .76324 L .65493 .76696 L p F P
0 g
s
0 .307 .744 r
.65751 .76836 m .65493 .76696 L .66069 .77158 L p F P
0 g
s
0 .031 .526 r
.66069 .77158 m .66643 .77717 L p .66246 .77337 L F P
0 g
s
0 0 .457 r
.83142 .66653 m .83575 .6733 L .84257 .68273 L p F P
0 g
s
.477 .856 .637 r
.41188 .75546 m .41502 .75304 L p .40821 .75957 L F P
0 g
s
0 0 0 r
.41502 .75304 m .41635 .75173 L .41188 .75546 L closepath p F P
0 g
s
.911 .958 .807 r
.84714 .81997 m .85719 .80736 L .85262 .80544 L p F P
0 g
s
.644 .252 0 r
.84637 .68957 m .84981 .69601 L .84448 .68634 L p F P
0 g
s
.644 .252 0 r
.84448 .68634 m .84257 .68273 L .84637 .68957 L p F P
0 g
s
.747 .397 0 r
.85877 .71684 m .85526 .70707 L .85469 .7057 L p F P
0 g
s
.601 .952 .87 r
.30638 .59683 m .32189 .58776 L p .30457 .59475 L F P
0 g
s
.601 .952 .87 r
.30457 .59475 m .29993 .59797 L .30638 .59683 L p F P
0 g
s
0 0 0 r
.41502 .75304 m .41635 .75173 L .43857 .73642 L p F P
0 g
s
.548 .728 .958 r
.24828 .83263 m .22651 .83405 L .23386 .84237 L p F P
0 g
s
.548 .728 .958 r
.23386 .84237 m .25573 .83934 L .24828 .83263 L p F P
0 g
s
.433 .62 .93 r
.22446 .83376 m .22651 .83405 L .23386 .84237 L p F P
0 g
s
.513 .874 .645 r
.38264 .77834 m .3857 .77599 L .39242 .77165 L p F P
0 g
s
.747 .397 0 r
.85469 .7057 m .85169 .69951 L p .85877 .71684 L F P
0 g
s
.914 .671 .173 r
.86385 .7347 m .86515 .73853 L .86525 .74846 L p F P
0 g
s
.9 .665 .155 r
.86669 .75312 m .86525 .74846 L .86515 .73853 L p F P
0 g
s
0 0 0 r
.20665 .68904 m .20914 .68434 L .20477 .69272 L p F P
0 g
s
0 0 0 r
.20477 .69272 m .19992 .70195 L .20665 .68904 L p F P
0 g
s
.496 .671 .942 r
.75107 .83498 m .74488 .83496 L .73934 .82768 L p F P
0 g
s
.47 .863 .972 r
.43625 .54864 m .44211 .55022 L .46516 .54437 L p F P
0 g
s
.521 .887 .975 r
.44211 .55022 m .43625 .54864 L .41251 .55549 L p F P
0 g
s
.607 .186 .218 r
.52419 .70528 m .52188 .70525 L .51777 .71234 L p F P
0 g
s
.607 .186 .218 r
.51777 .71234 m .53725 .71261 L .52419 .70528 L p F P
0 g
s
.521 .129 .238 r
.52188 .70525 m .51777 .71234 L .50661 .71337 L p F P
0 g
s
0 .453 .859 r
.73406 .58986 m .72531 .58396 L .74141 .59004 L p F P
0 g
s
0 .453 .859 r
.74141 .59004 m .75003 .596 L .73406 .58986 L p F P
0 g
s
.318 .753 .968 r
.56089 .54416 m .58465 .54319 L p .56934 .54049 L F P
0 g
s
.318 .753 .968 r
.56934 .54049 m .55472 .54123 L .56089 .54416 L p F P
0 g
s
.304 .74 .967 r
.59068 .54652 m .58465 .54319 L .56089 .54416 L p F P
0 g
s
.667 .165 .044 r
.59054 .72157 m .59999 .73015 L .58585 .72613 L p F P
0 g
s
.667 .165 .044 r
.58642 .72049 m .59054 .72157 L p .58585 .72613 L F P
0 g
s
.749 .918 .948 r
.30567 .82654 m .28565 .83679 L .29311 .84076 L p F P
0 g
s
.749 .918 .948 r
.29311 .84076 m .30189 .83559 L .30567 .82654 L p F P
0 g
s
.739 .869 .941 r
.80508 .84158 m .8276 .82966 L .8275 .83688 L p F P
0 g
s
.779 .901 .928 r
.82929 .82865 m .8276 .82966 L .8275 .83688 L p F P
0 g
s
.779 .901 .928 r
.8275 .83688 m .83419 .83257 L .82929 .82865 L p F P
0 g
s
.073 .545 .899 r
.69667 .57326 m .7158 .57823 L .70547 .5727 L p F P
0 g
s
.073 .545 .899 r
.68707 .56831 m .69667 .57326 L p .70547 .5727 L F P
0 g
s
.2 .351 .792 r
.19449 .80372 m .19639 .79483 L p .20743 .80578 L F P
0 g
s
.2 .351 .792 r
.20743 .80578 m .20645 .81139 L .19449 .80372 L p F P
0 g
s
.587 .013 0 r
.62422 .74287 m .63138 .74859 L .62089 .74361 L p F P
0 g
s
.587 .013 0 r
.62089 .74361 m .61841 .74184 L .62422 .74287 L p F P
0 g
s
.762 .251 0 r
.61177 .73481 m .61841 .74184 L .62422 .74287 L p F P
0 g
s
.855 .925 .875 r
.84714 .81997 m .83419 .83257 L .82929 .82865 L p F P
0 g
s
.855 .925 .875 r
.82929 .82865 m .84626 .81294 L .84714 .81997 L p F P
0 g
s
.911 .958 .807 r
.85262 .80544 m .84626 .81294 L .84714 .81997 L p F P
0 g
s
.325 .487 .866 r
.21921 .82455 m .20525 .81996 L .20645 .81139 L p F P
0 g
s
.345 .532 .896 r
.20525 .81996 m .21921 .82455 L .22448 .83151 L p F P
0 g
s
.18 .633 .94 r
.65636 .56005 m .67444 .56268 L .66194 .55774 L p F P
0 g
s
.18 .633 .94 r
.66194 .55774 m .65068 .55623 L .65636 .56005 L p F P
0 g
s
.186 .641 .941 r
.63737 .55473 m .65068 .55623 L .65636 .56005 L p F P
0 g
s
.582 .029 0 r
.64028 .75396 m .63138 .74859 L .64182 .75714 L p F P
0 g
s
.582 .029 0 r
.64182 .75714 m .65013 .76268 L .64028 .75396 L p F P
0 g
s
.513 .092 .179 r
.49006 .71498 m .49271 .7104 L .50661 .71337 L closepath p F P
0 g
s
.409 0 .148 r
.49271 .7104 m .49006 .71498 L .46546 .72053 L p F P
0 g
s
0 .337 .814 r
.69881 .80318 m .70299 .80566 L .6973 .79869 L p F P
0 g
s
0 .337 .814 r
.6973 .79869 m .69433 .79685 L .69881 .80318 L p F P
0 g
s
.518 .915 .898 r
.35204 .57262 m .35764 .57233 L .37822 .56259 L p F P
0 g
s
.574 .927 .95 r
.38228 .56299 m .37822 .56259 L .35764 .57233 L p F P
0 g
s
0 .256 .734 r
.79553 .62844 m .78541 .62174 L .7788 .61536 L p F P
0 g
s
0 .272 .757 r
.78541 .62174 m .79553 .62844 L .80069 .63439 L p F P
0 g
s
.401 0 .143 r
.46274 .72547 m .46546 .72053 L .49006 .71498 L p F P
0 g
s
.22 0 .027 r
.46546 .72053 m .46274 .72547 L .43956 .73573 L p F P
0 g
s
.667 .165 .044 r
.58585 .72613 m .58216 .72335 L .58642 .72049 L p F P
0 g
s
.717 .231 .091 r
.58216 .72335 m .57618 .71762 L .58642 .72049 L closepath p F P
0 g
s
.457 .876 .936 r
.41228 .55546 m .41251 .55549 L .43625 .54864 L p F P
0 g
s
.665 .837 .966 r
.27815 .83226 m .25573 .83934 L .26318 .84533 L p F P
0 g
s
.665 .837 .966 r
.26318 .84533 m .28565 .83679 L .27815 .83226 L p F P
0 g
s
0 .282 .765 r
.80069 .63439 m .80306 .63595 L .79708 .62945 L p F P
0 g
s
0 .282 .765 r
.79708 .62945 m .79553 .62844 L .80069 .63439 L p F P
0 g
s
.705 .916 .967 r
.31597 .8275 m .30189 .83559 L .30567 .82654 L p F P
0 g
s
.975 .799 .38 r
.86525 .74846 m .86669 .75312 L .8653 .76517 L p F P
0 g
s
.456 .875 .934 r
.42827 .54767 m .4052 .5547 L .41228 .55546 L p F P
0 g
s
.456 .875 .934 r
.41228 .55546 m .43525 .54851 L .42827 .54767 L p F P
0 g
s
.457 .876 .936 r
.43625 .54864 m .43525 .54851 L .41228 .55546 L p F P
0 g
s
0 0 0 r
.40906 .75896 m .41502 .75304 L .43411 .74265 L p F P
0 g
s
0 0 0 r
.43938 .73597 m .43411 .74265 L .41502 .75304 L p F P
0 g
s
0 0 0 r
.43857 .73642 m .43938 .73597 L p .41502 .75304 L F P
0 g
s
.477 .856 .637 r
.41502 .75304 m .40906 .75896 L .40821 .75957 L p F P
0 g
s
.614 .878 .547 r
.22845 .65757 m .23581 .64923 L .23198 .65402 L closepath p F P
0 g
s
.661 .901 .566 r
.223 .66408 m .22845 .65757 L .23198 .65402 L p F P
0 g
s
.064 .181 .676 r
.18885 .78596 m .19123 .77679 L p .19845 .78626 L F P
0 g
s
.064 .181 .676 r
.19845 .78626 m .19639 .79483 L .18885 .78596 L p F P
0 g
s
0 0 .038 r
.19254 .71996 m .1952 .71427 L .19258 .72599 L p F P
0 g
s
0 0 .038 r
.19258 .72599 m .19048 .73046 L .19254 .71996 L p F P
0 g
s
0 0 0 r
.43938 .73597 m .43956 .73573 L .43857 .73642 L closepath p F P
0 g
s
.658 .212 .181 r
.54916 .71333 m .55216 .70933 L .55897 .71447 L closepath p F P
0 g
s
.61 .157 .151 r
.53725 .71261 m .54916 .71333 L .55216 .70933 L p F P
0 g
s
.136 0 0 r
.43938 .73597 m .43956 .73573 L .46274 .72547 L p F P
0 g
s
0 .362 .807 r
.7716 .60909 m .75874 .60248 L .76059 .60429 L p F P
0 g
s
0 .364 .809 r
.75874 .60248 m .75799 .60209 L .76059 .60429 L closepath p F P
0 g
s
.601 .952 .87 r
.32189 .58776 m .32752 .58384 L p .30457 .59475 L F P
0 g
s
.635 .959 .917 r
.32752 .58384 m .3292 .58378 L .32189 .58776 L closepath p F P
0 g
s
.169 .642 .931 r
.65068 .55623 m .63737 .55473 L .623 .55038 L p F P
0 g
s
.298 .728 .97 r
.59068 .54652 m .60685 .54656 L .58929 .54316 L p F P
0 g
s
.298 .728 .97 r
.58929 .54316 m .58465 .54319 L .59068 .54652 L p F P
0 g
s
0 0 .183 r
.18848 .73601 m .19048 .73046 L .18979 .74218 L p F P
0 g
s
0 0 .183 r
.18979 .74218 m .18803 .74709 L .18848 .73601 L p F P
0 g
s
.457 .656 .946 r
.75107 .83498 m .76983 .8354 L .76441 .8289 L p F P
0 g
s
.457 .656 .946 r
.76441 .8289 m .74958 .82806 L .75107 .83498 L p F P
0 g
s
.496 .671 .942 r
.73934 .82768 m .74958 .82806 L .75107 .83498 L p F P
0 g
s
.142 0 0 r
.43411 .74265 m .43938 .73597 L .46109 .72779 L p F P
0 g
s
.136 0 0 r
.46274 .72547 m .46109 .72779 L .43938 .73597 L p F P
0 g
s
.974 .918 .674 r
.86163 .77789 m .86334 .78486 L .85711 .79828 L p F P
0 g
s
.986 .879 .531 r
.86334 .78486 m .86163 .77789 L .8653 .76517 L p F P
0 g
s
0 .129 .637 r
.80306 .63595 m .79708 .62945 L .80694 .63781 L p F P
0 g
s
0 .129 .637 r
.80694 .63781 m .81289 .64432 L .80306 .63595 L p F P
0 g
s
0 0 0 r
.19992 .70195 m .1952 .71427 L .20077 .70362 L p F P
0 g
s
0 0 0 r
.20477 .69272 m .19992 .70195 L p .20077 .70362 L F P
0 g
s
.692 .15 0 r
.61177 .73481 m .59999 .73015 L .60946 .73885 L p F P
0 g
s
.692 .15 0 r
.61841 .74184 m .61177 .73481 L p .60946 .73885 L F P
0 g
s
.586 .942 .914 r
.32752 .58384 m .3292 .58378 L .35204 .57262 L p F P
0 g
s
.914 .671 .173 r
.86525 .74846 m .86446 .74616 L .86385 .7347 L p F P
0 g
s
.942 .686 .218 r
.86099 .7278 m .86385 .7347 L .86446 .74616 L p F P
0 g
s
.846 .544 .009 r
.86385 .7347 m .86099 .7278 L .85877 .71684 L p F P
0 g
s
.402 .585 .916 r
.22651 .83405 m .22446 .83376 L .22448 .83151 L closepath p F P
0 g
s
.605 .789 .969 r
.7752 .84185 m .79991 .83614 L .80508 .84158 L p F P
0 g
s
.588 .775 .968 r
.79991 .83614 m .7752 .84185 L .76983 .8354 L p F P
0 g
s
.298 .556 .925 r
.70299 .80566 m .71713 .80998 L .72064 .81651 L p F P
0 g
s
.245 .544 .926 r
.71713 .80998 m .70299 .80566 L .6973 .79869 L p F P
0 g
s
.764 .971 .924 r
.3316 .81106 m .30848 .82513 L .31597 .8275 L p F P
0 g
s
.764 .971 .924 r
.33632 .81142 m .3316 .81106 L p .31597 .8275 L F P
0 g
s
.764 .971 .924 r
.31597 .8275 m .33406 .81505 L .33632 .81142 L p F P
0 g
s
.705 .916 .967 r
.30567 .82654 m .30848 .82513 L .31597 .8275 L p F P
0 g
s
.097 .54 .91 r
.71883 .58003 m .72254 .5832 L .72531 .58396 L closepath p F P
0 g
s
.124 .559 .921 r
.7158 .57823 m .71883 .58003 L .72254 .5832 L p F P
0 g
s
0 .347 .785 r
.75874 .60248 m .75799 .60209 L .75003 .596 L p F P
0 g
s
.667 .167 .05 r
.57618 .71762 m .55897 .71447 L .56974 .72264 L p F P
0 g
s
.667 .167 .05 r
.58216 .72335 m .57618 .71762 L p .56974 .72264 L F P
0 g
s
0 .002 .534 r
.18691 .76703 m .18978 .75758 L p .19335 .76977 L F P
0 g
s
0 .002 .534 r
.19335 .76977 m .19123 .77679 L .18691 .76703 L p F P
0 g
s
.723 .867 .949 r
.8276 .82966 m .80508 .84158 L .79991 .83614 L p F P
0 g
s
.234 .526 .917 r
.72064 .81651 m .73378 .82057 L .7282 .81369 L p F P
0 g
s
.234 .526 .917 r
.7282 .81369 m .71713 .80998 L .72064 .81651 L p F P
0 g
s
0 0 0 r
.20914 .68434 m .21326 .67796 L .20578 .69116 L p F P
0 g
s
0 0 0 r
.20578 .69116 m .20477 .69272 L .20914 .68434 L p F P
0 g
s
0 .354 .791 r
.75874 .60248 m .7716 .60909 L .76379 .60294 L p F P
0 g
s
0 .354 .791 r
.76379 .60294 m .75349 .59774 L .75874 .60248 L p F P
0 g
s
0 .347 .785 r
.75003 .596 m .75349 .59774 L .75874 .60248 L p F P
0 g
s
.516 .904 .942 r
.37822 .56259 m .38228 .56299 L .4052 .5547 L p F P
0 g
s
.48 .623 .913 r
.24084 .82506 m .24828 .83263 L .22651 .83405 L p F P
0 g
s
.48 .623 .913 r
.22657 .82503 m .24084 .82506 L p .22651 .83405 L F P
0 g
s
.48 .623 .913 r
.22651 .83405 m .22448 .83151 L .22657 .82503 L p F P
0 g
s
.073 .545 .899 r
.70547 .5727 m .68657 .56794 L .68707 .56831 L p F P
0 g
s
.093 .56 .908 r
.68657 .56794 m .68608 .56783 L .68707 .56831 L closepath p F P
0 g
s
0 .028 .569 r
.83142 .66653 m .82657 .65985 L .8183 .65092 L p F P
0 g
s
0 .001 .53 r
.8183 .65092 m .81289 .64432 L .82118 .65326 L p F P
0 g
s
0 .001 .53 r
.82118 .65326 m .82657 .65985 L .8183 .65092 L p F P
0 g
s
.276 .7 .968 r
.61908 .54934 m .62058 .55029 L .623 .55038 L closepath p F P
0 g
s
.3 .724 .972 r
.62058 .55029 m .61908 .54934 L .60685 .54656 L p F P
0 g
s
.883 .567 .06 r
.85543 .70998 m .85877 .71684 L .86099 .7278 L p F P
0 g
s
.747 .397 0 r
.85169 .69951 m .85543 .70998 L .85877 .71684 L p F P
0 g
s
.061 .55 .891 r
.68657 .56794 m .68608 .56783 L .67444 .56268 L p F P
0 g
s
0 .321 .797 r
.69433 .79685 m .68902 .79067 L .67584 .78262 L p F P
0 g
s
0 .299 .768 r
.67584 .78262 m .66957 .77664 L .68291 .78465 L p F P
0 g
s
0 .299 .768 r
.68291 .78465 m .68902 .79067 L .67584 .78262 L p F P
0 g
s
.059 .546 .89 r
.68657 .56794 m .70547 .5727 L .69439 .56735 L p F P
0 g
s
.059 .546 .89 r
.69439 .56735 m .68102 .56414 L .68657 .56794 L p F P
0 g
s
.061 .55 .891 r
.67444 .56268 m .68102 .56414 L .68657 .56794 L p F P
0 g
s
.469 .665 .948 r
.74958 .82806 m .73934 .82768 L .73378 .82057 L p F P
0 g
s
0 .449 .841 r
.72531 .58396 m .74141 .59004 L .73213 .58423 L p F P
0 g
s
0 .449 .841 r
.71883 .58003 m .72531 .58396 L p .73213 .58423 L F P
0 g
s
0 .307 .744 r
.66069 .77158 m .66957 .77664 L .66219 .7709 L p F P
0 g
s
0 0 .457 r
.84257 .68273 m .83825 .67598 L .83142 .66653 L p F P
0 g
s
.575 .131 0 r
.82657 .65985 m .83142 .66653 L .83825 .67598 L p F P
0 g
s
.521 .917 .839 r
.32147 .58511 m .32752 .58384 L .3467 .57288 L p F P
0 g
s
.586 .942 .914 r
.35204 .57262 m .3467 .57288 L .32752 .58384 L p F P
0 g
s
.601 .952 .87 r
.32752 .58384 m .32147 .58511 L .30457 .59475 L p F P
0 g
s
.803 .433 0 r
.84785 .6927 m .85169 .69951 L .85543 .70998 L p F P
0 g
s
.637 .244 0 r
.84448 .68634 m .84785 .6927 L .85169 .69951 L p F P
0 g
s
.644 .925 .648 r
.25192 .63332 m .25207 .63315 L .2449 .63859 L p F P
0 g
s
.644 .925 .648 r
.2449 .63859 m .23581 .64923 L .25192 .63332 L p F P
0 g
s
.702 .975 .769 r
.25207 .63315 m .25219 .63309 L .25192 .63332 L closepath p F P
0 g
s
.64 .954 .757 r
.25219 .63309 m .2736 .61559 L p .26621 .61938 L F P
0 g
s
.64 .954 .757 r
.26621 .61938 m .25207 .63315 L .25219 .63309 L p F P
0 g
s
.562 .886 .619 r
.25207 .63315 m .26621 .61938 L .24724 .63631 L p F P
0 g
s
.562 .886 .619 r
.24724 .63631 m .2449 .63859 L .25207 .63315 L p F P
0 g
s
.762 .967 .928 r
.33632 .81142 m .33908 .81166 L .33406 .81505 L closepath p F P
0 g
s
.698 .287 0 r
.84257 .68273 m .84448 .68634 L .83923 .67784 L p F P
0 g
s
.698 .287 0 r
.83923 .67784 m .83825 .67598 L .84257 .68273 L p F P
0 g
s
.169 .652 .925 r
.623 .55038 m .64494 .5526 L p .63378 .54873 L F P
0 g
s
.169 .652 .925 r
.61908 .54934 m .623 .55038 L p .63378 .54873 L F P
0 g
s
.169 .642 .931 r
.623 .55038 m .64494 .5526 L .65068 .55623 L p F P
0 g
s
.461 .602 .905 r
.22657 .82503 m .22448 .83151 L .21921 .82455 L closepath p F P
0 g
s
.941 .927 .764 r
.85711 .79828 m .85262 .80544 L .84791 .80266 L p F P
0 g
s
.941 .927 .764 r
.84791 .80266 m .85528 .79138 L .85711 .79828 L p F P
0 g
s
.974 .918 .674 r
.85711 .79828 m .85528 .79138 L .86163 .77789 L p F P
0 g
s
.993 .874 .554 r
.86314 .75821 m .8653 .76517 L .86163 .77789 L p F P
0 g
s
.975 .799 .38 r
.86405 .75069 m .86525 .74846 L p .8653 .76517 L F P
0 g
s
.975 .799 .38 r
.8653 .76517 m .86314 .75821 L .86405 .75069 L p F P
0 g
s
.6 .034 0 r
.63138 .74859 m .62089 .74361 L .63222 .75191 L p F P
0 g
s
.6 .034 0 r
.63222 .75191 m .64182 .75714 L .63138 .74859 L p F P
0 g
s
.588 .867 .542 r
.23581 .64923 m .2449 .63859 L p .23298 .65171 L F P
0 g
s
.588 .867 .542 r
.22845 .65757 m .23581 .64923 L p .23298 .65171 L F P
0 g
s
.975 .78 .358 r
.86405 .75069 m .86446 .74616 L .86525 .74846 L closepath p F P
0 g
s
.76 .967 .929 r
.33908 .81166 m .35915 .79648 L p .34028 .8052 L F P
0 g
s
.76 .967 .929 r
.34028 .8052 m .33632 .81142 L .33908 .81166 L p F P
0 g
s
.475 .053 .158 r
.49006 .71498 m .50661 .71337 L p .48698 .7221 L F P
0 g
s
.475 .053 .158 r
.48698 .7221 m .48599 .722 L .49006 .71498 L p F P
0 g
s
.401 0 .143 r
.49006 .71498 m .48599 .722 L .46274 .72547 L p F P
0 g
s
.64 .954 .757 r
.2736 .61559 m .27477 .61445 L p .26621 .61938 L F P
0 g
s
.674 .975 .825 r
.27477 .61445 m .27543 .61424 L .2736 .61559 L closepath p F P
0 g
s
.169 .652 .925 r
.63378 .54873 m .61471 .54703 L .61908 .54934 L p F P
0 g
s
.205 .676 .938 r
.61471 .54703 m .60685 .54656 L .61908 .54934 L closepath p F P
0 g
s
.628 .959 .818 r
.27477 .61445 m .27543 .61424 L .29848 .59852 L p F P
0 g
s
0 .268 .734 r
.7788 .61536 m .7716 .60909 L .78339 .61676 L p F P
0 g
s
0 .268 .734 r
.79038 .62294 m .7788 .61536 L p .78339 .61676 L F P
0 g
s
0 .256 .734 r
.7788 .61536 m .79038 .62294 L .79553 .62844 L p F P
0 g
s
.588 .867 .542 r
.23298 .65171 m .22561 .66039 L .22845 .65757 L p F P
0 g
s
.669 .907 .574 r
.22561 .66039 m .22845 .65757 L .223 .66408 L closepath p F P
0 g
s
.345 0 .038 r
.46109 .72779 m .46274 .72547 L .48599 .722 L p F P
0 g
s
.378 .809 .964 r
.48887 .53976 m .49502 .54181 L .51845 .53828 L p F P
0 g
s
.427 .839 .97 r
.49502 .54181 m .48887 .53976 L .48596 .54012 L p F P
0 g
s
.613 .159 .15 r
.55897 .71447 m .56974 .72264 L .55043 .72004 L p F P
0 g
s
.613 .159 .15 r
.54916 .71333 m .55897 .71447 L p .55043 .72004 L F P
0 g
s
.717 .902 .961 r
.30096 .82213 m .27815 .83226 L .28565 .83679 L p F P
0 g
s
.717 .902 .961 r
.3069 .82449 m .30096 .82213 L p .28565 .83679 L F P
0 g
s
.717 .902 .961 r
.28565 .83679 m .30567 .82654 L .3069 .82449 L p F P
0 g
s
.902 .939 .825 r
.84626 .81294 m .85262 .80544 L .84791 .80266 L p F P
0 g
s
0 0 .076 r
.1952 .71427 m .20077 .70362 L .19813 .7154 L p F P
0 g
s
0 0 .076 r
.19813 .7154 m .19258 .72599 L .1952 .71427 L p F P
0 g
s
.347 .785 .965 r
.52486 .54076 m .54708 .53856 L .52035 .53807 L p F P
0 g
s
.347 .785 .965 r
.52035 .53807 m .51845 .53828 L .52486 .54076 L p F P
0 g
s
.39 .84 .923 r
.43525 .54851 m .43625 .54864 L .4617 .54336 L p F P
0 g
s
.47 .863 .972 r
.46516 .54437 m .4617 .54336 L .43625 .54864 L p F P
0 g
s
0 .311 .789 r
.69433 .79685 m .6973 .79869 L .69161 .79229 L p F P
0 g
s
0 .311 .789 r
.69161 .79229 m .68902 .79067 L .69433 .79685 L p F P
0 g
s
.421 .838 .966 r
.4617 .54336 m .46516 .54437 L .48596 .54012 L closepath p F P
0 g
s
0 0 .376 r
.18803 .74709 m .18979 .74218 L .19064 .7552 L p F P
0 g
s
0 0 .376 r
.19064 .7552 m .18978 .75758 L .18803 .74709 L p F P
0 g
s
.635 .808 .966 r
.27064 .82705 m .24828 .83263 L .25573 .83934 L p F P
0 g
s
.635 .808 .966 r
.25573 .83934 m .27815 .83226 L .27064 .82705 L p F P
0 g
s
0 0 .25 r
.19048 .73046 m .19258 .72599 L .19222 .73708 L p F P
0 g
s
0 0 .25 r
.19222 .73708 m .18979 .74218 L .19048 .73046 L p F P
0 g
s
.534 .915 .772 r
.29848 .59852 m .30457 .59475 L .29993 .59797 L closepath p F P
0 g
s
.542 .902 .699 r
.26706 .6187 m .27477 .61445 L .29105 .60127 L p F P
0 g
s
.628 .959 .818 r
.29848 .59852 m .29105 .60127 L .27477 .61445 L p F P
0 g
s
.64 .954 .757 r
.27477 .61445 m .26706 .6187 L .26621 .61938 L p F P
0 g
s
0 0 0 r
.223 .66408 m .22561 .66039 L .22037 .66788 L p F P
0 g
s
0 0 0 r
.22037 .66788 m .21326 .67796 L .223 .66408 L p F P
0 g
s
.723 .867 .949 r
.82752 .82709 m .8276 .82966 L p .79991 .83614 L F P
0 g
s
.762 .882 .932 r
.8276 .82966 m .82752 .82709 L .82929 .82865 L closepath p F P
0 g
s
.76 .967 .929 r
.35915 .79648 m .36086 .79436 L p .34028 .8052 L F P
0 g
s
.736 .99 .874 r
.36086 .79436 m .36235 .79409 L .35915 .79648 L closepath p F P
0 g
s
.708 .19 0 r
.59999 .73015 m .58585 .72613 L .59671 .73441 L p F P
0 g
s
.708 .19 0 r
.59671 .73441 m .60946 .73885 L .59999 .73015 L p F P
0 g
s
.85 .891 .867 r
.84626 .81294 m .84497 .80595 L p .82752 .82709 L F P
0 g
s
.85 .891 .867 r
.82752 .82709 m .82929 .82865 L .84626 .81294 L p F P
0 g
s
.902 .939 .825 r
.84791 .80266 m .84497 .80595 L .84626 .81294 L p F P
0 g
s
.694 .281 0 r
.84785 .6927 m .84448 .68634 L .83923 .67784 L p F P
0 g
s
0 .269 .746 r
.79553 .62844 m .79708 .62945 L .79054 .62305 L p F P
0 g
s
0 .269 .746 r
.79054 .62305 m .79038 .62294 L .79553 .62844 L p F P
0 g
s
.693 .981 .876 r
.36235 .79409 m .38264 .77834 L p .3698 .78525 L F P
0 g
s
.693 .981 .876 r
.3698 .78525 m .36086 .79436 L .36235 .79409 L p F P
0 g
s
.475 .053 .158 r
.50661 .71337 m .51601 .71535 L p .48698 .7221 L F P
0 g
s
.509 .082 .165 r
.51601 .71535 m .50661 .71337 L .51777 .71234 L closepath p F P
0 g
s
.613 .159 .15 r
.55043 .72004 m .54599 .7175 L .54916 .71333 L p F P
0 g
s
.609 .155 .148 r
.54599 .7175 m .53725 .71261 L .54916 .71333 L closepath p F P
0 g
s
.517 .915 .898 r
.3467 .57288 m .35204 .57262 L .37497 .56278 L p F P
0 g
s
.518 .915 .898 r
.37822 .56259 m .37497 .56278 L .35204 .57262 L p F P
0 g
s
.307 .752 .963 r
.54894 .53863 m .55472 .54123 L .56934 .54049 L closepath p F P
0 g
s
.346 .781 .967 r
.55472 .54123 m .54894 .53863 L .54708 .53856 L p F P
0 g
s
.174 .637 .935 r
.65068 .55623 m .66194 .55774 L .64853 .55304 L p F P
0 g
s
.174 .637 .935 r
.64853 .55304 m .64494 .5526 L .65068 .55623 L p F P
0 g
s
.991 .782 .399 r
.86446 .74616 m .86157 .73929 L p .86123 .75331 L F P
0 g
s
.991 .782 .399 r
.86123 .75331 m .86405 .75069 L .86446 .74616 L p F P
0 g
s
.942 .686 .218 r
.86446 .74616 m .86157 .73929 L .86099 .7278 L p F P
0 g
s
.397 .843 .926 r
.45153 .54187 m .42827 .54767 L .43525 .54851 L p F P
0 g
s
.397 .843 .926 r
.43525 .54851 m .4584 .54287 L .45153 .54187 L p F P
0 g
s
.39 .84 .923 r
.4617 .54336 m .4584 .54287 L .43525 .54851 L p F P
0 g
s
.562 .136 .192 r
.53725 .71261 m .54599 .7175 L p .52557 .71905 L F P
0 g
s
.562 .136 .192 r
.51777 .71234 m .53725 .71261 L p .52557 .71905 L F P
0 g
s
0 .449 .841 r
.73213 .58423 m .71714 .57871 L .71883 .58003 L p F P
0 g
s
0 .458 .847 r
.71714 .57871 m .7158 .57823 L .71883 .58003 L closepath p F P
0 g
s
.667 .167 .049 r
.57999 .72486 m .58216 .72335 L .58585 .72613 L closepath p F P
0 g
s
.667 .167 .05 r
.56974 .72264 m .57999 .72486 L .58216 .72335 L p F P
0 g
s
.427 .554 .88 r
.21921 .82455 m .22657 .82503 L .22876 .81617 L p F P
0 g
s
.427 .554 .88 r
.22876 .81617 m .21199 .81367 L .21921 .82455 L p F P
0 g
s
.325 .487 .866 r
.20645 .81139 m .21199 .81367 L .21921 .82455 L p F P
0 g
s
.562 .136 .192 r
.52557 .71905 m .51601 .71535 L .51777 .71234 L p F P
0 g
s
0 .106 .603 r
.79708 .62945 m .79054 .62305 L .80044 .6314 L p F P
0 g
s
0 .106 .603 r
.80044 .6314 m .80694 .63781 L .79708 .62945 L p F P
0 g
s
.172 .666 .917 r
.61471 .54703 m .60685 .54656 L .58929 .54316 L p F P
0 g
s
.614 .047 0 r
.61609 .74179 m .61841 .74184 L .62089 .74361 L closepath p F P
0 g
s
.692 .15 0 r
.60946 .73885 m .61609 .74179 L .61841 .74184 L p F P
0 g
s
.245 .544 .926 r
.6973 .79869 m .71272 .80363 L .71713 .80998 L p F P
0 g
s
.191 .533 .924 r
.71272 .80363 m .6973 .79869 L .69161 .79229 L p F P
0 g
s
0 .337 .764 r
.75349 .59774 m .75003 .596 L .74141 .59004 L p F P
0 g
s
.693 .981 .876 r
.38264 .77834 m .38455 .77652 L p .3698 .78525 L F P
0 g
s
.625 .948 .757 r
.38455 .77652 m .3857 .77599 L .38264 .77834 L closepath p F P
0 g
s
.428 .651 .952 r
.74958 .82806 m .76441 .8289 L .75896 .82242 L p F P
0 g
s
.428 .651 .952 r
.75896 .82242 m .74683 .82139 L .74958 .82806 L p F P
0 g
s
.469 .665 .948 r
.73378 .82057 m .74683 .82139 L .74958 .82806 L p F P
0 g
s
.761 .968 .928 r
.3316 .81106 m .34028 .8052 L .33632 .81142 L closepath p F P
0 g
s
.588 .775 .968 r
.76983 .8354 m .79468 .83047 L .79991 .83614 L p F P
0 g
s
.574 .763 .968 r
.79468 .83047 m .76983 .8354 L .76441 .8289 L p F P
0 g
s
.194 .323 .768 r
.20491 .8009 m .19639 .79483 L .19845 .78626 L closepath p F P
0 g
s
.2 .351 .792 r
.19639 .79483 m .20491 .8009 L .20743 .80578 L p F P
0 g
s
.292 .446 .843 r
.21199 .81367 m .20645 .81139 L .20743 .80578 L closepath p F P
0 g
s
.041 .548 .877 r
.68102 .56414 m .67444 .56268 L .66194 .55774 L p F P
0 g
s
.524 .911 .773 r
.29848 .59852 m .30457 .59475 L p .2933 .59975 L F P
0 g
s
.524 .911 .773 r
.2933 .59975 m .29105 .60127 L .29848 .59852 L p F P
0 g
s
.44 .877 .875 r
.37497 .56278 m .37822 .56259 L .40046 .55421 L p F P
0 g
s
.516 .904 .942 r
.4052 .5547 m .40046 .55421 L .37822 .56259 L p F P
0 g
s
.5 .89 .723 r
.40145 .76464 m .38455 .77652 L .3857 .77599 L p F P
0 g
s
.973 .907 .686 r
.85943 .77098 m .86163 .77789 L .85528 .79138 L p F P
0 g
s
.993 .874 .554 r
.86163 .77789 m .85943 .77098 L .86314 .75821 L p F P
0 g
s
.692 .981 .872 r
.35489 .79548 m .3698 .78525 L .36086 .79436 L closepath p F P
0 g
s
.76 .967 .929 r
.36086 .79436 m .35489 .79548 L .34028 .8052 L p F P
0 g
s
.284 .726 .963 r
.58242 .54203 m .58465 .54319 L .58929 .54316 L closepath p F P
0 g
s
.318 .753 .968 r
.58465 .54319 m .58242 .54203 L .56934 .54049 L p F P
0 g
s
.989 .8 .412 r
.86314 .75821 m .86123 .75331 L .86405 .75069 L closepath p F P
0 g
s
.962 .695 .258 r
.85763 .72097 m .86099 .7278 L .86157 .73929 L p F P
0 g
s
.883 .567 .06 r
.86099 .7278 m .85763 .72097 L .85543 .70998 L p F P
0 g
s
.346 0 .04 r
.45619 .73469 m .46109 .72779 L .48582 .72223 L p F P
0 g
s
.345 0 .038 r
.48599 .722 m .48582 .72223 L .46109 .72779 L p F P
0 g
s
.142 0 0 r
.46109 .72779 m .45619 .73469 L .43411 .74265 L p F P
0 g
s
0 0 0 r
.21326 .67796 m .20578 .69116 L .21395 .6795 L p F P
0 g
s
0 0 0 r
.22037 .66788 m .21326 .67796 L p .21395 .6795 L F P
0 g
s
.812 .884 .897 r
.8243 .82418 m .82616 .82276 L .82752 .82709 L closepath p F P
0 g
s
.85 .891 .867 r
.84497 .80595 m .82616 .82276 L .82752 .82709 L p F P
0 g
s
.723 .867 .949 r
.79991 .83614 m .8243 .82418 L .82752 .82709 L p F P
0 g
s
0 .443 .823 r
.71714 .57871 m .7158 .57823 L .70547 .5727 L p F P
0 g
s
.524 .911 .773 r
.30457 .59475 m .31769 .58588 L p .2933 .59975 L F P
0 g
s
.583 .945 .854 r
.31769 .58588 m .32147 .58511 L .30457 .59475 L closepath p F P
0 g
s
.709 .851 .95 r
.8243 .82418 m .79991 .83614 L .79468 .83047 L p F P
0 g
s
0 0 .488 r
.81289 .64432 m .80694 .63781 L .81524 .64675 L p F P
0 g
s
0 0 .488 r
.81524 .64675 m .82118 .65326 L .81289 .64432 L p F P
0 g
s
.454 .875 .932 r
.40046 .55421 m .4052 .5547 L .42827 .54767 L p F P
0 g
s
.57 0 0 r
.62089 .74361 m .63222 .75191 L .62104 .74706 L p F P
0 g
s
.57 0 0 r
.61609 .74179 m .62089 .74361 L p .62104 .74706 L F P
0 g
s
.081 .175 .663 r
.19809 .78523 m .19123 .77679 L .19335 .76977 L closepath p F P
0 g
s
.064 .181 .676 r
.19123 .77679 m .19809 .78523 L .19845 .78626 L p F P
0 g
s
.188 .515 .915 r
.71713 .80998 m .7282 .81369 L .72259 .8071 L p F P
0 g
s
.188 .515 .915 r
.72259 .8071 m .71272 .80363 L .71713 .80998 L p F P
0 g
s
.442 .661 .954 r
.74683 .82139 m .73378 .82057 L .7282 .81369 L p F P
0 g
s
.713 .897 .962 r
.3069 .82449 m .30848 .82513 L .30567 .82654 L closepath p F P
0 g
s
0 .28 .737 r
.66957 .77664 m .66219 .7709 L .67597 .77879 L p F P
0 g
s
0 .28 .737 r
.67597 .77879 m .68291 .78465 L .66957 .77664 L p F P
0 g
s
0 0 0 r
.22561 .66039 m .23298 .65171 L .22188 .6661 L p F P
0 g
s
0 0 0 r
.22188 .6661 m .22037 .66788 L .22561 .66039 L p F P
0 g
s
0 .447 .828 r
.71714 .57871 m .73213 .58423 L .72215 .57857 L p F P
0 g
s
0 .447 .828 r
.72215 .57857 m .71172 .57486 L .71714 .57871 L p F P
0 g
s
0 .443 .823 r
.70547 .5727 m .71172 .57486 L .71714 .57871 L p F P
0 g
s
.693 .981 .876 r
.38455 .77652 m .37828 .7795 L .3698 .78525 L p F P
0 g
s
.911 .583 .107 r
.85157 .7032 m .85543 .70998 L .85763 .72097 L p F P
0 g
s
.803 .433 0 r
.85543 .70998 m .85157 .7032 L .84785 .6927 L p F P
0 g
s
.731 .899 .954 r
.30848 .82513 m .3316 .81106 L p .31001 .81723 L F P
0 g
s
.731 .899 .954 r
.31001 .81723 m .3069 .82449 L .30848 .82513 L p F P
0 g
s
0 .347 .774 r
.75349 .59774 m .76379 .60294 L .75537 .59692 L p F P
0 g
s
0 .347 .774 r
.75537 .59692 m .74822 .59339 L .75349 .59774 L p F P
0 g
s
0 .337 .764 r
.74141 .59004 m .74822 .59339 L .75349 .59774 L p F P
0 g
s
0 0 0 r
.40882 .75913 m .40906 .75896 L .40821 .75957 L closepath p F P
0 g
s
0 0 0 r
.40882 .75913 m .40906 .75896 L .43239 .74485 L p F P
0 g
s
0 0 0 r
.43411 .74265 m .43239 .74485 L .40906 .75896 L p F P
0 g
s
.575 .131 0 r
.83825 .67598 m .8334 .6693 L .82657 .65985 L p F P
0 g
s
.623 .16 0 r
.82657 .65985 m .82118 .65326 L .82801 .66272 L p F P
0 g
s
.623 .16 0 r
.82801 .66272 m .8334 .6693 L .82657 .65985 L p F P
0 g
s
.621 .109 .008 r
.58585 .72613 m .59671 .73441 L .58137 .73068 L p F P
0 g
s
.621 .109 .008 r
.57999 .72486 m .58585 .72613 L p .58137 .73068 L F P
0 g
s
.162 0 0 r
.43239 .74485 m .43411 .74265 L .45619 .73469 L p F P
0 g
s
.325 .802 .909 r
.4584 .54287 m .4617 .54336 L .48596 .54012 L p F P
0 g
s
0 0 .272 r
.19258 .72599 m .19813 .7154 L .19778 .72653 L p F P
0 g
s
0 0 .272 r
.19778 .72653 m .19222 .73708 L .19258 .72599 L p F P
0 g
s
0 0 0 r
.20311 .6977 m .20578 .69116 L .20477 .69272 L closepath p F P
0 g
s
0 0 0 r
.20077 .70362 m .20311 .6977 L .20477 .69272 L p F P
0 g
s
.838 .456 0 r
.8435 .68597 m .84785 .6927 L .85157 .7032 L p F P
0 g
s
.694 .281 0 r
.83923 .67784 m .8435 .68597 L .84785 .6927 L p F P
0 g
s
0 0 0 r
.40171 .76447 m .40882 .75913 L .42819 .74888 L p F P
0 g
s
0 0 0 r
.43239 .74485 m .42819 .74888 L .40882 .75913 L p F P
0 g
s
.176 .677 .911 r
.58929 .54316 m .60878 .54409 L p .60033 .54123 L F P
0 g
s
.176 .677 .911 r
.58242 .54203 m .58929 .54316 L p .60033 .54123 L F P
0 g
s
.172 .666 .917 r
.58929 .54316 m .60878 .54409 L .61471 .54703 L p F P
0 g
s
.744 .316 0 r
.83825 .67598 m .83923 .67784 L .83406 .67057 L p F P
0 g
s
.744 .316 0 r
.83406 .67057 m .8334 .6693 L .83825 .67598 L p F P
0 g
s
0 .301 .706 r
.65493 .76696 m .66219 .7709 L .65356 .76545 L p F P
0 g
s
0 0 .431 r
.18979 .74218 m .19222 .73708 L .19438 .74748 L p F P
0 g
s
0 0 .431 r
.19438 .74748 m .19064 .7552 L .18979 .74218 L p F P
0 g
s
0 .223 .681 r
.7716 .60909 m .76379 .60294 L .77564 .61059 L p F P
0 g
s
0 .223 .681 r
.77564 .61059 m .78339 .61676 L .7716 .60909 L p F P
0 g
s
.486 .637 .922 r
.24084 .82506 m .22657 .82503 L .22876 .81617 L p F P
0 g
s
.57 0 0 r
.62104 .74706 m .61257 .74169 L .61609 .74179 L p F P
0 g
s
.69 .147 0 r
.61257 .74169 m .60946 .73885 L .61609 .74179 L closepath p F P
0 g
s
.167 .657 .921 r
.61471 .54703 m .63378 .54873 L .61774 .54478 L p F P
0 g
s
.167 .657 .921 r
.61774 .54478 m .60878 .54409 L .61471 .54703 L p F P
0 g
s
.995 .867 .576 r
.86123 .75331 m .86314 .75821 L .85943 .77098 L p F P
0 g
s
.558 .107 .137 r
.51325 .71915 m .51601 .71535 L .52557 .71905 L closepath p F P
0 g
s
.475 .053 .158 r
.51601 .71535 m .51325 .71915 L .48698 .7221 L p F P
0 g
s
.049 .548 .883 r
.68102 .56414 m .69439 .56735 L .6825 .56219 L p F P
0 g
s
.049 .548 .883 r
.6825 .56219 m .67543 .56058 L .68102 .56414 L p F P
0 g
s
.041 .548 .877 r
.66194 .55774 m .67543 .56058 L .68102 .56414 L p F P
0 g
s
.935 .903 .768 r
.85528 .79138 m .85297 .78454 L p .84328 .79928 L F P
0 g
s
.935 .903 .768 r
.84328 .79928 m .84791 .80266 L .85528 .79138 L p F P
0 g
s
.973 .907 .686 r
.85528 .79138 m .85297 .78454 L .85943 .77098 L p F P
0 g
s
.621 .109 .008 r
.58137 .73068 m .57616 .72749 L .57999 .72486 L p F P
0 g
s
.666 .165 .047 r
.57616 .72749 m .56974 .72264 L .57999 .72486 L closepath p F P
0 g
s
.176 .677 .911 r
.60033 .54123 m .57857 .54048 L .58242 .54203 L p F P
0 g
s
.22 .707 .927 r
.57857 .54048 m .56934 .54049 L .58242 .54203 L closepath p F P
0 g
s
.417 .563 .892 r
.21199 .81367 m .20743 .80578 L p .2299 .81187 L F P
0 g
s
.417 .563 .892 r
.2299 .81187 m .22876 .81617 L .21199 .81367 L p F P
0 g
s
.732 .9 .954 r
.30096 .82213 m .31001 .81723 L .3069 .82449 L closepath p F P
0 g
s
.741 .313 0 r
.8435 .68597 m .83923 .67784 L .83406 .67057 L p F P
0 g
s
.604 .774 .962 r
.26311 .82105 m .24084 .82506 L .24828 .83263 L p F P
0 g
s
.604 .774 .962 r
.24828 .83263 m .27064 .82705 L .26311 .82105 L p F P
0 g
s
.521 .918 .842 r
.31769 .58588 m .32147 .58511 L .34446 .5734 L p F P
0 g
s
.521 .917 .839 r
.3467 .57288 m .34446 .5734 L .32147 .58511 L p F P
0 g
s
0 0 0 r
.20578 .69116 m .21395 .6795 L .20869 .6921 L p F P
0 g
s
0 0 0 r
.20311 .6977 m .20578 .69116 L p .20869 .6921 L F P
0 g
s
0 .002 .525 r
.19193 .76277 m .18978 .75758 L .19064 .7552 L closepath p F P
0 g
s
0 .002 .534 r
.18978 .75758 m .19193 .76277 L .19335 .76977 L p F P
0 g
s
0 .287 .759 r
.69161 .79229 m .68902 .79067 L .68291 .78465 L p F P
0 g
s
.068 .572 .888 r
.66194 .55774 m .64853 .55304 L .66976 .55724 L p F P
0 g
s
.068 .572 .888 r
.67543 .56058 m .66194 .55774 L p .66976 .55724 L F P
0 g
s
.439 .877 .877 r
.37497 .56278 m .398 .55435 L p .36811 .56298 L F P
0 g
s
.439 .877 .877 r
.36811 .56298 m .36755 .56319 L .37497 .56278 L p F P
0 g
s
.517 .915 .898 r
.37497 .56278 m .36755 .56319 L .3467 .57288 L p F P
0 g
s
.44 .877 .875 r
.40046 .55421 m .398 .55435 L .37497 .56278 L p F P
0 g
s
.69 .873 .967 r
.29342 .81842 m .27064 .82705 L .27815 .83226 L p F P
0 g
s
.69 .873 .967 r
.27815 .83226 m .30096 .82213 L .29342 .81842 L p F P
0 g
s
.18 .691 .898 r
.56934 .54049 m .57857 .54048 L p .54848 .53848 L F P
0 g
s
.18 .691 .898 r
.54848 .53848 m .54894 .53863 L .56934 .54049 L p F P
0 g
s
0 .326 .74 r
.74822 .59339 m .74141 .59004 L .73213 .58423 L p F P
0 g
s
.613 .143 .114 r
.54421 .7195 m .54599 .7175 L .55043 .72004 L closepath p F P
0 g
s
.562 .136 .192 r
.54599 .7175 m .54421 .7195 L .52557 .71905 L p F P
0 g
s
.325 .802 .909 r
.48596 .54012 m .48844 .53967 L p .4584 .54287 L F P
0 g
s
.344 .809 .925 r
.48844 .53967 m .48596 .54012 L .48887 .53976 L closepath p F P
0 g
s
.803 .873 .899 r
.82616 .82276 m .8243 .82418 L .81923 .81928 L p F P
0 g
s
.709 .851 .95 r
.79468 .83047 m .81923 .81928 L .8243 .82418 L p F P
0 g
s
0 .25 .72 r
.78995 .62253 m .79038 .62294 L .79054 .62305 L closepath p F P
0 g
s
0 .268 .734 r
.78339 .61676 m .78995 .62253 L .79038 .62294 L p F P
0 g
s
.89 .921 .837 r
.84497 .80595 m .84328 .79928 L .84791 .80266 L closepath p F P
0 g
s
.72 .983 .902 r
.34738 .79596 m .32407 .80973 L .3316 .81106 L p F P
0 g
s
.72 .983 .902 r
.34849 .79587 m .34738 .79596 L p .3316 .81106 L F P
0 g
s
.72 .983 .902 r
.3316 .81106 m .34028 .8052 L .34849 .79587 L p F P
0 g
s
.731 .899 .954 r
.3316 .81106 m .32407 .80973 L .31001 .81723 L p F P
0 g
s
.803 .873 .899 r
.81923 .81928 m .82358 .8161 L .82616 .82276 L p F P
0 g
s
.838 .887 .876 r
.84328 .79928 m .84497 .80595 L .82616 .82276 L p F P
0 g
s
.838 .887 .876 r
.84309 .79913 m .84328 .79928 L p .82616 .82276 L F P
0 g
s
.838 .887 .876 r
.82616 .82276 m .82358 .8161 L .84309 .79913 L p F P
0 g
s
0 .088 .567 r
.79054 .62305 m .80044 .6314 L .79338 .62509 L p F P
0 g
s
0 .088 .567 r
.78995 .62253 m .79054 .62305 L p .79338 .62509 L F P
0 g
s
.268 .763 .901 r
.48844 .53967 m .48887 .53976 L .51789 .53807 L p F P
0 g
s
.378 .809 .964 r
.51845 .53828 m .51789 .53807 L .48887 .53976 L p F P
0 g
s
.05 0 0 r
.42819 .74888 m .43239 .74485 L .45573 .73534 L p F P
0 g
s
.162 0 0 r
.45619 .73469 m .45573 .73534 L .43239 .74485 L p F P
0 g
s
.427 .868 .802 r
.34446 .5734 m .3467 .57288 L .36755 .56319 L p F P
0 g
s
.991 .782 .399 r
.86157 .73929 m .86039 .75135 L .86123 .75331 L p F P
0 g
s
.996 .784 .428 r
.8582 .7325 m .86157 .73929 L .86039 .75135 L p F P
0 g
s
.962 .695 .258 r
.86157 .73929 m .8582 .7325 L .85763 .72097 L p F P
0 g
s
.608 .088 0 r
.56974 .72264 m .55043 .72004 L .56356 .72762 L p F P
0 g
s
.608 .088 0 r
.57616 .72749 m .56974 .72264 L p .56356 .72762 L F P
0 g
s
.453 0 .075 r
.48582 .72223 m .48599 .722 L .48698 .7221 L closepath p F P
0 g
s
.417 .563 .892 r
.20743 .80578 m .20868 .80241 L p .2299 .81187 L F P
0 g
s
.327 .44 .823 r
.20868 .80241 m .20743 .80578 L .20491 .8009 L closepath p F P
0 g
s
0 .437 .803 r
.71172 .57486 m .70547 .5727 L .69439 .56735 L p F P
0 g
s
.574 .763 .968 r
.76441 .8289 m .78939 .82462 L .79468 .83047 L p F P
0 g
s
.562 .755 .968 r
.78939 .82462 m .76441 .8289 L .75896 .82242 L p F P
0 g
s
.191 .533 .924 r
.69161 .79229 m .70746 .79744 L .71272 .80363 L p F P
0 g
s
.147 .529 .92 r
.69161 .79229 m .70746 .79744 L .70138 .7914 L p F P
0 g
s
.147 .529 .92 r
.70138 .7914 m .6859 .78648 L .69161 .79229 L p F P
0 g
s
0 .287 .759 r
.68291 .78465 m .6859 .78648 L .69161 .79229 L p F P
0 g
s
0 .088 .567 r
.79338 .62509 m .78526 .61832 L .78995 .62253 L p F P
0 g
s
.459 0 0 r
.78526 .61832 m .79338 .62509 L .79279 .62461 L p F P
0 g
s
0 .085 .564 r
.78352 .61687 m .78995 .62253 L .78526 .61832 L p F P
0 g
s
.459 0 0 r
.79279 .62461 m .78574 .61888 L p .78526 .61832 L F P
0 g
s
0 .085 .564 r
.78526 .61832 m .78339 .61676 L .78352 .61687 L p F P
0 g
s
0 0 0 r
.20869 .6921 m .20158 .70223 L .20311 .6977 L p F P
0 g
s
0 0 0 r
.20158 .70223 m .20311 .6977 L .20077 .70362 L closepath p F P
0 g
s
.453 0 .075 r
.48081 .72889 m .48582 .72223 L .48698 .7221 L p F P
0 g
s
.346 0 .04 r
.48582 .72223 m .48081 .72889 L .45619 .73469 L p F P
0 g
s
.283 .773 .902 r
.48844 .53967 m .51197 .53669 L p .50426 .53538 L F P
0 g
s
.283 .773 .902 r
.50426 .53538 m .48177 .53847 L .48844 .53967 L p F P
0 g
s
.268 .763 .901 r
.51789 .53807 m .51197 .53669 L .48844 .53967 L p F P
0 g
s
.325 .802 .909 r
.48844 .53967 m .48177 .53847 L .4584 .54287 L p F P
0 g
s
.707 .188 0 r
.61257 .74169 m .60946 .73885 L .59671 .73441 L p F P
0 g
s
.453 0 .075 r
.48698 .7221 m .50948 .72435 L p .48081 .72889 L F P
0 g
s
.452 0 .075 r
.50948 .72435 m .48698 .7221 L .51325 .71915 L closepath p F P
0 g
s
.338 .783 .959 r
.51789 .53807 m .51845 .53828 L .52035 .53807 L closepath p F P
0 g
s
.721 .981 .908 r
.34849 .79587 m .35489 .79548 L .34028 .8052 L closepath p F P
0 g
s
.083 .11 .59 r
.19064 .7552 m .19438 .74748 L .19943 .75709 L p F P
0 g
s
.083 .11 .59 r
.19193 .76277 m .19064 .7552 L p .19943 .75709 L F P
0 g
s
0 0 0 r
.24342 .64023 m .24724 .63631 L .2449 .63859 L closepath p F P
0 g
s
0 0 0 r
.24656 .63802 m .23945 .64463 L p .24342 .64023 L F P
0 g
s
.588 .867 .542 r
.24342 .64023 m .23298 .65171 L p .24458 .63894 L F P
0 g
s
.532 .823 .484 r
.23886 .64518 m .24342 .64023 L .23298 .65171 L closepath p F P
0 g
s
0 0 0 r
.23945 .64463 m .23886 .64518 L .24342 .64023 L p F P
0 g
s
.588 .867 .542 r
.2449 .63859 m .24342 .64023 L p .24458 .63894 L F P
0 g
s
.252 .738 .924 r
.54848 .53848 m .54708 .53856 L .54894 .53863 L closepath p F P
0 g
s
.221 .726 .899 r
.54848 .53848 m .54708 .53856 L .52035 .53807 L p F P
0 g
s
.155 .632 .925 r
.64251 .55117 m .64494 .5526 L .64853 .55304 L closepath p F P
0 g
s
.169 .652 .925 r
.64494 .5526 m .64251 .55117 L .63378 .54873 L p F P
0 g
s
.33 .439 .821 r
.20491 .8009 m .19845 .78626 L p .21245 .79288 L F P
0 g
s
.33 .439 .821 r
.21245 .79288 m .20868 .80241 L .20491 .8009 L p F P
0 g
s
.402 .647 .957 r
.74683 .82139 m .75896 .82242 L .75346 .81599 L p F P
0 g
s
.402 .647 .957 r
.75346 .81599 m .74312 .81491 L .74683 .82139 L p F P
0 g
s
.442 .661 .954 r
.7282 .81369 m .74312 .81491 L .74683 .82139 L p F P
0 g
s
.338 .81 .911 r
.4584 .54287 m .48177 .53847 L p .46287 .53966 L F P
0 g
s
.338 .81 .911 r
.46287 .53966 m .45153 .54187 L .4584 .54287 L p F P
0 g
s
.236 .739 .899 r
.52035 .53807 m .54217 .53659 L p .53424 .53491 L F P
0 g
s
.236 .739 .899 r
.51789 .53807 m .52035 .53807 L p .53424 .53491 L F P
0 g
s
.221 .726 .899 r
.52035 .53807 m .54217 .53659 L .54848 .53848 L p F P
0 g
s
.236 .739 .899 r
.53424 .53491 m .51197 .53669 L .51789 .53807 L p F P
0 g
s
.2 .708 .9 r
.54848 .53848 m .57243 .53815 L p .55898 .53615 L F P
0 g
s
.2 .708 .9 r
.55898 .53615 m .54217 .53659 L .54848 .53848 L p F P
0 g
s
.18 .691 .898 r
.57857 .54048 m .57243 .53815 L .54848 .53848 L p F P
0 g
s
.554 .052 0 r
.80694 .63781 m .80044 .6314 L .80876 .64034 L p F P
0 g
s
.554 .052 0 r
.80876 .64034 m .81524 .64675 L .80694 .63781 L p F P
0 g
s
.97 .895 .695 r
.85671 .76414 m .85943 .77098 L .85297 .78454 L p F P
0 g
s
.995 .867 .576 r
.85996 .75318 m .86123 .75331 L p .85943 .77098 L F P
0 g
s
.995 .867 .576 r
.85943 .77098 m .85671 .76414 L .85996 .75318 L p F P
0 g
s
.415 .659 .96 r
.74312 .81491 m .7282 .81369 L .72259 .8071 L p F P
0 g
s
.974 .699 .294 r
.85376 .71422 m .85763 .72097 L .8582 .7325 L p F P
0 g
s
.911 .583 .107 r
.85763 .72097 m .85376 .71422 L .85157 .7032 L p F P
0 g
s
.698 .837 .949 r
.81923 .81928 m .79468 .83047 L .78939 .82462 L p F P
0 g
s
0 .273 .711 r
.66219 .7709 m .65356 .76545 L .66811 .77312 L p F P
0 g
s
0 .273 .711 r
.66811 .77312 m .67597 .77879 L .66219 .7709 L p F P
0 g
s
.359 .832 .85 r
.398 .55435 m .40046 .55421 L .42433 .54721 L p F P
0 g
s
.454 .875 .932 r
.42827 .54767 m .42433 .54721 L .40046 .55421 L p F P
0 g
s
.083 .11 .59 r
.19943 .75709 m .19447 .76726 L .19193 .76277 L p F P
0 g
s
.062 .101 .59 r
.19447 .76726 m .19335 .76977 L .19193 .76277 L closepath p F P
0 g
s
0 0 .44 r
.19222 .73708 m .19778 .72653 L p .1996 .7376 L F P
0 g
s
0 0 .44 r
.1996 .7376 m .19438 .74748 L .19222 .73708 L p F P
0 g
s
0 0 .108 r
.20077 .70362 m .20158 .70223 L .1996 .71285 L p F P
0 g
s
0 0 .108 r
.1996 .71285 m .19813 .7154 L .20077 .70362 L p F P
0 g
s
.15 .509 .912 r
.71272 .80363 m .72259 .8071 L .71695 .80081 L p F P
0 g
s
.15 .509 .912 r
.71695 .80081 m .70746 .79744 L .71272 .80363 L p F P
0 g
s
.68 .973 .912 r
.35489 .79548 m .3698 .78525 L p .35041 .7941 L F P
0 g
s
.68 .973 .912 r
.35041 .7941 m .34849 .79587 L .35489 .79548 L p F P
0 g
s
.563 .086 .08 r
.55043 .72004 m .56356 .72762 L .54217 .72557 L p F P
0 g
s
.563 .086 .08 r
.54421 .7195 m .55043 .72004 L p .54217 .72557 L F P
0 g
s
.999 .844 .53 r
.85996 .75318 m .86039 .75135 L .86123 .75331 L closepath p F P
0 g
s
.665 .187 0 r
.82118 .65326 m .81524 .64675 L .82208 .65622 L p F P
0 g
s
.665 .187 0 r
.82208 .65622 m .82801 .66272 L .82118 .65326 L p F P
0 g
s
.392 .842 .919 r
.42433 .54721 m .42827 .54767 L .45153 .54187 L p F P
0 g
s
.931 .594 .15 r
.84722 .69649 m .85157 .7032 L .85376 .71422 L p F P
0 g
s
.838 .456 0 r
.85157 .7032 m .84722 .69649 L .8435 .68597 L p F P
0 g
s
.018 .553 .849 r
.64853 .55304 m .66976 .55724 L .65574 .55265 L p F P
0 g
s
.018 .553 .849 r
.64251 .55117 m .64853 .55304 L p .65574 .55265 L F P
0 g
s
.22 .29 .724 r
.19335 .76977 m .19447 .76726 L .20315 .77584 L p F P
0 g
s
.22 .29 .724 r
.19809 .78523 m .19335 .76977 L p .20315 .77584 L F P
0 g
s
.518 .853 .575 r
.24724 .63631 m .26621 .61938 L p .26057 .62397 L F P
0 g
s
.518 .853 .575 r
.25991 .6245 m .25985 .62456 L p .26057 .62397 L F P
0 g
s
.518 .853 .575 r
.25985 .62456 m .24724 .63631 L p .26057 .62397 L F P
0 g
s
.607 .934 .724 r
.26676 .61887 m .26706 .6187 L .26621 .61938 L closepath p F P
0 g
s
.548 .906 .706 r
.26676 .61887 m .26706 .6187 L .29037 .60168 L p F P
0 g
s
.542 .902 .699 r
.29105 .60127 m .29037 .60168 L .26706 .6187 L p F P
0 g
s
.548 .906 .706 r
.29037 .60168 m .28337 .60587 L .26676 .61887 L p F P
0 g
s
0 0 0 r
.26676 .61887 m .28337 .60587 L p .26361 .62162 L F P
0 g
s
0 0 0 r
.24724 .63631 m .25991 .6245 L p .24656 .63802 L F P
0 g
s
0 0 0 r
.24342 .64023 m .24724 .63631 L p .24656 .63802 L F P
0 g
s
0 .204 .648 r
.76379 .60294 m .75537 .59692 L .76729 .60453 L p F P
0 g
s
0 .204 .648 r
.76729 .60453 m .77564 .61059 L .76379 .60294 L p F P
0 g
s
.53 0 0 r
.61257 .74169 m .62104 .74706 L .60784 .74274 L p F P
0 g
s
.53 0 0 r
.60784 .74274 m .60667 .74212 L .61257 .74169 L p F P
0 g
s
.707 .188 0 r
.59671 .73441 m .60667 .74212 L .61257 .74169 L p F P
0 g
s
.207 .289 .728 r
.19867 .78572 m .19845 .78626 L .19809 .78523 L closepath p F P
0 g
s
.33 .439 .821 r
.19845 .78626 m .19867 .78572 L .21245 .79288 L p F P
0 g
s
.426 .867 .805 r
.34446 .5734 m .36753 .56319 L p .34147 .57305 L F P
0 g
s
.426 .867 .805 r
.34147 .57305 m .33717 .57502 L .34446 .5734 L p F P
0 g
s
.427 .868 .802 r
.36755 .56319 m .36753 .56319 L .34446 .5734 L p F P
0 g
s
.521 .918 .842 r
.34446 .5734 m .33717 .57502 L .31769 .58588 L p F P
0 g
s
.22 .29 .724 r
.20315 .77584 m .19867 .78572 L .19809 .78523 L p F P
0 g
s
.563 .086 .08 r
.54217 .72557 m .53971 .72454 L .54421 .7195 L p F P
0 g
s
.552 .073 .072 r
.53971 .72454 m .52557 .71905 L .54421 .7195 L closepath p F P
0 g
s
.518 .853 .575 r
.26621 .61938 m .26676 .61887 L .25991 .6245 L p F P
0 g
s
.78 .339 0 r
.83406 .67057 m .8334 .6693 L .82801 .66272 L p F P
0 g
s
.866 .473 0 r
.83863 .67931 m .8435 .68597 L .84722 .69649 L p F P
0 g
s
.741 .313 0 r
.83406 .67057 m .83863 .67931 L .8435 .68597 L p F P
0 g
s
.418 .849 .718 r
.31354 .58758 m .31769 .58588 L .33717 .57502 L p F P
0 g
s
.524 .911 .773 r
.31769 .58588 m .31354 .58758 L .2933 .59975 L p F P
0 g
s
.178 .682 .907 r
.57857 .54048 m .60033 .54123 L .58077 .53834 L p F P
0 g
s
.178 .682 .907 r
.58077 .53834 m .57243 .53815 L .57857 .54048 L p F P
0 g
s
.511 .057 .11 r
.51325 .71915 m .52557 .71905 L p .51401 .72549 L F P
0 g
s
.511 .057 .11 r
.51401 .72549 m .50948 .72435 L .51325 .71915 L p F P
0 g
s
.511 .057 .11 r
.52557 .71905 m .53971 .72454 L p .51401 .72549 L F P
0 g
s
.391 .509 .858 r
.22607 .80656 m .20868 .80241 L .21245 .79288 L p F P
0 g
s
.417 .563 .892 r
.20868 .80241 m .22607 .80656 L .2299 .81187 L p F P
0 g
s
.293 .389 .79 r
.19867 .78572 m .20315 .77584 L p .21477 .78734 L F P
0 g
s
.293 .389 .79 r
.21477 .78734 m .21245 .79288 L .19867 .78572 L p F P
0 g
s
0 0 0 r
.26361 .62162 m .25991 .6245 L .26676 .61887 L p F P
0 g
s
0 0 .168 r
.20158 .70223 m .20869 .6921 L .20587 .70399 L p F P
0 g
s
0 0 .168 r
.20587 .70399 m .1996 .71285 L .20158 .70223 L p F P
0 g
s
.571 .734 .952 r
.2556 .81412 m .23342 .81648 L .24084 .82506 L p F P
0 g
s
.571 .734 .952 r
.24084 .82506 m .26311 .82105 L .2556 .81412 L p F P
0 g
s
.486 .637 .922 r
.22876 .81617 m .23342 .81648 L .24084 .82506 L p F P
0 g
s
0 .446 .815 r
.71172 .57486 m .72215 .57857 L .71146 .57307 L p F P
0 g
s
0 .446 .815 r
.71146 .57307 m .70627 .5713 L .71172 .57486 L p F P
0 g
s
0 .437 .803 r
.69439 .56735 m .70627 .5713 L .71172 .57486 L p F P
0 g
s
0 .341 .756 r
.74822 .59339 m .75537 .59692 L .74629 .59102 L p F P
0 g
s
0 .341 .756 r
.74629 .59102 m .74293 .58941 L .74822 .59339 L p F P
0 g
s
0 .326 .74 r
.73213 .58423 m .74293 .58941 L .74822 .59339 L p F P
0 g
s
.718 .932 .96 r
.31651 .80761 m .29342 .81842 L .30096 .82213 L p F P
0 g
s
.718 .932 .96 r
.31733 .80783 m .31651 .80761 L p .30096 .82213 L F P
0 g
s
.718 .932 .96 r
.30096 .82213 m .31001 .81723 L .31733 .80783 L p F P
0 g
s
.496 0 0 r
.63222 .75191 m .62104 .74706 L .63341 .75519 L p F P
0 g
s
.496 0 0 r
.64335 .76029 m .63222 .75191 L p .63341 .75519 L F P
0 g
s
.778 .337 0 r
.83406 .67057 m .83863 .67931 L .83326 .67274 L p F P
0 g
s
.778 .337 0 r
.83326 .67274 m .82899 .66458 L .83406 .67057 L p F P
0 g
s
.78 .339 0 r
.82801 .66272 m .82899 .66458 L .83406 .67057 L p F P
0 g
s
.68 .973 .912 r
.3698 .78525 m .37531 .78037 L p .35041 .7941 L F P
0 g
s
.635 .963 .826 r
.37531 .78037 m .37828 .7795 L .3698 .78525 L closepath p F P
0 g
s
0 0 0 r
.23298 .65171 m .22188 .6661 L .23361 .65309 L p F P
0 g
s
0 0 0 r
.23886 .64518 m .23298 .65171 L p .23361 .65309 L F P
0 g
s
.421 .826 .624 r
.29037 .60168 m .2933 .59975 L .29105 .60127 L closepath p F P
0 g
s
0 .31 .678 r
.64348 .76035 m .64335 .76029 L .64916 .76324 L p F P
0 g
s
.018 .553 .849 r
.65574 .55265 m .63917 .54959 L .64251 .55117 L p F P
0 g
s
.049 .577 .865 r
.63917 .54959 m .63378 .54873 L .64251 .55117 L closepath p F P
0 g
s
.332 0 .032 r
.45573 .73534 m .45619 .73469 L .48081 .72889 L p F P
0 g
s
0 0 0 r
.21889 .67099 m .22188 .6661 L .22037 .66788 L closepath p F P
0 g
s
0 0 0 r
.21395 .6795 m .21889 .67099 L .22037 .66788 L p F P
0 g
s
.998 .837 .554 r
.86039 .75135 m .85996 .75318 L .85537 .75126 L p F P
0 g
s
.998 .837 .554 r
.85537 .75126 m .85699 .74459 L .86039 .75135 L p F P
0 g
s
.996 .784 .428 r
.86039 .75135 m .85699 .74459 L .8582 .7325 L p F P
0 g
s
0 .266 .726 r
.6859 .78648 m .68291 .78465 L .67597 .77879 L p F P
0 g
s
0 .35 .749 r
.73213 .58423 m .72215 .57857 L .73653 .58528 L p F P
0 g
s
0 .35 .749 r
.74293 .58941 m .73213 .58423 L p .73653 .58528 L F P
0 g
s
.935 .903 .768 r
.85297 .78454 m .84318 .79902 L .84328 .79928 L p F P
0 g
s
.927 .897 .778 r
.85016 .77776 m .85297 .78454 L .84318 .79902 L p F P
0 g
s
.97 .895 .695 r
.85297 .78454 m .85016 .77776 L .85671 .76414 L p F P
0 g
s
.59 .022 0 r
.59671 .73441 m .58137 .73068 L .594 .73856 L p F P
0 g
s
.59 .022 0 r
.60667 .74212 m .59671 .73441 L p .594 .73856 L F P
0 g
s
.62 .103 0 r
.57341 .72926 m .57616 .72749 L .58137 .73068 L closepath p F P
0 g
s
.608 .088 0 r
.56356 .72762 m .57341 .72926 L .57616 .72749 L p F P
0 g
s
0 .464 .815 r
.69439 .56735 m .6825 .56219 L .69997 .56776 L p F P
0 g
s
0 .464 .815 r
.70627 .5713 m .69439 .56735 L p .69997 .56776 L F P
0 g
s
.53 .918 .805 r
.37828 .7795 m .40145 .76464 L p .38897 .77142 L F P
0 g
s
.53 .918 .805 r
.38897 .77142 m .37531 .78037 L .37828 .7795 L p F P
0 g
s
.364 .835 .853 r
.398 .55435 m .42119 .54735 L p .41341 .54784 L F P
0 g
s
.364 .835 .853 r
.41341 .54784 m .39069 .55475 L .398 .55435 L p F P
0 g
s
.359 .832 .85 r
.42433 .54721 m .42119 .54735 L .398 .55435 L p F P
0 g
s
.439 .877 .877 r
.398 .55435 m .39069 .55475 L .36811 .56298 L p F P
0 g
s
.994 .857 .588 r
.85671 .76414 m .85996 .75318 L .85537 .75126 L p F P
0 g
s
.662 .842 .969 r
.28585 .8139 m .26311 .82105 L .27064 .82705 L p F P
0 g
s
.662 .842 .969 r
.27064 .82705 m .29342 .81842 L .28585 .8139 L p F P
0 g
s
.191 .247 .692 r
.19447 .76726 m .19943 .75709 L p .20673 .76836 L F P
0 g
s
.191 .247 .692 r
.20673 .76836 m .20315 .77584 L .19447 .76726 L p F P
0 g
s
.412 .823 .628 r
.29037 .60168 m .2933 .59975 L p .28814 .60274 L F P
0 g
s
.412 .823 .628 r
.28814 .60274 m .28337 .60587 L .29037 .60168 L p F P
0 g
s
.261 0 0 r
.45044 .74095 m .45573 .73534 L .47918 .73108 L p F P
0 g
s
.332 0 .032 r
.48081 .72889 m .47918 .73108 L .45573 .73534 L p F P
0 g
s
.05 0 0 r
.45573 .73534 m .45044 .74095 L .42819 .74888 L p F P
0 g
s
.716 .928 .962 r
.31733 .80783 m .32407 .80973 L .31001 .81723 L closepath p F P
0 g
s
.476 0 0 r
.78526 .61832 m .78339 .61676 L .77564 .61059 L p F P
0 g
s
.026 .54 .867 r
.66982 .55727 m .67543 .56058 L .6825 .56219 L closepath p F P
0 g
s
.068 .572 .888 r
.66976 .55724 m .66982 .55727 L .67543 .56058 L p F P
0 g
s
.412 .823 .628 r
.2933 .59975 m .30913 .58933 L p .28814 .60274 L F P
0 g
s
.501 .897 .752 r
.30913 .58933 m .31354 .58758 L .2933 .59975 L closepath p F P
0 g
s
.151 .651 .91 r
.60398 .54186 m .60878 .54409 L .61774 .54478 L closepath p F P
0 g
s
.176 .677 .911 r
.60878 .54409 m .60398 .54186 L .60033 .54123 L p F P
0 g
s
0 0 0 r
.22188 .6661 m .23361 .65309 L .22496 .66679 L p F P
0 g
s
0 0 0 r
.21889 .67099 m .22188 .6661 L p .22496 .66679 L F P
0 g
s
.562 .755 .968 r
.75896 .82242 m .78405 .81864 L .78939 .82462 L p F P
0 g
s
.553 .749 .968 r
.78405 .81864 m .75896 .82242 L .75346 .81599 L p F P
0 g
s
.796 .864 .9 r
.82358 .8161 m .81923 .81928 L .81409 .81406 L p F P
0 g
s
.698 .837 .949 r
.78939 .82462 m .81409 .81406 L .81923 .81928 L p F P
0 g
s
.011 .558 .832 r
.63917 .54959 m .63378 .54873 L .61774 .54478 L p F P
0 g
s
.455 .602 .908 r
.23342 .81648 m .22876 .81617 L .2299 .81187 L closepath p F P
0 g
s
.119 .534 .916 r
.6859 .78648 m .70138 .7914 L .69444 .78554 L p F P
0 g
s
.119 .534 .916 r
.69444 .78554 m .68017 .78127 L .6859 .78648 L p F P
0 g
s
0 .266 .726 r
.67597 .77879 m .68017 .78127 L .6859 .78648 L p F P
0 g
s
.796 .864 .9 r
.81409 .81406 m .82055 .80947 L .82358 .8161 L p F P
0 g
s
.84 .898 .88 r
.83814 .79477 m .82055 .80947 L .82358 .8161 L p F P
0 g
s
.84 .898 .88 r
.82358 .8161 m .84309 .79913 L .83814 .79477 L p F P
0 g
s
.998 .778 .451 r
.85432 .72577 m .8582 .7325 L .85699 .74459 L p F P
0 g
s
.974 .699 .294 r
.8582 .7325 m .85432 .72577 L .85376 .71422 L p F P
0 g
s
.903 .907 .816 r
.84309 .79913 m .84318 .79902 L .84328 .79928 L closepath p F P
0 g
s
.459 0 0 r
.78574 .61888 m .78013 .61429 L .78526 .61832 L p F P
0 g
s
.476 0 0 r
.77564 .61059 m .78013 .61429 L .78526 .61832 L p F P
0 g
s
.074 0 0 r
.42516 .75184 m .42819 .74888 L .45044 .74095 L p F P
0 g
s
0 0 0 r
.42819 .74888 m .42516 .75184 L .40171 .76447 L p F P
0 g
s
.895 .893 .82 r
.84318 .79902 m .84309 .79913 L .83814 .79477 L p F P
0 g
s
.895 .893 .82 r
.83814 .79477 m .84018 .79234 L .84318 .79902 L p F P
0 g
s
.927 .897 .778 r
.84318 .79902 m .84018 .79234 L .85016 .77776 L p F P
0 g
s
0 0 .291 r
.19813 .7154 m .1996 .71285 L .19889 .72461 L p F P
0 g
s
0 0 .291 r
.19889 .72461 m .19778 .72653 L .19813 .7154 L p F P
0 g
s
0 .28 .69 r
.65356 .76545 m .64348 .76035 L .65919 .76769 L p F P
0 g
s
0 .28 .69 r
.65919 .76769 m .66811 .77312 L .65356 .76545 L p F P
0 g
s
0 0 0 r
.22496 .66679 m .21624 .67647 L .21889 .67099 L p F P
0 g
s
0 0 0 r
.21624 .67647 m .21889 .67099 L .21395 .6795 L closepath p F P
0 g
s
.593 .077 0 r
.80044 .6314 m .79338 .62509 L .80173 .63402 L p F P
0 g
s
.593 .077 0 r
.80173 .63402 m .80876 .64034 L .80044 .6314 L p F P
0 g
s
.415 .659 .96 r
.72259 .8071 m .7386 .80858 L .74312 .81491 L p F P
0 g
s
.392 .66 .966 r
.7386 .80858 m .72259 .8071 L .71695 .80081 L p F P
0 g
s
.381 .646 .961 r
.74312 .81491 m .75346 .81599 L .74794 .80966 L p F P
0 g
s
.381 .646 .961 r
.74794 .80966 m .7386 .80858 L .74312 .81491 L p F P
0 g
s
.28 .783 .824 r
.42119 .54735 m .42433 .54721 L .4498 .54164 L p F P
0 g
s
.392 .842 .919 r
.45153 .54187 m .4498 .54164 L .42433 .54721 L p F P
0 g
s
.689 .825 .948 r
.81409 .81406 m .78939 .82462 L .78405 .81864 L p F P
0 g
s
.466 .865 .687 r
.40164 .7645 m .40171 .76447 L .40145 .76464 L closepath p F P
0 g
s
.354 .798 .644 r
.40164 .7645 m .40171 .76447 L .42516 .75184 L p F P
0 g
s
.711 .927 .963 r
.32407 .80973 m .34738 .79596 L p .31828 .80667 L F P
0 g
s
.711 .927 .963 r
.31828 .80667 m .31733 .80783 L .32407 .80973 L p F P
0 g
s
.53 .918 .805 r
.39432 .76838 m .38897 .77142 L p .39167 .76995 L F P
0 g
s
.53 .918 .805 r
.40164 .7645 m .39432 .76838 L p .39167 .76995 L F P
0 g
s
0 0 0 r
.39432 .76838 m .40164 .7645 L .42137 .75445 L p F P
0 g
s
0 0 0 r
.41788 .75693 m .39432 .76838 L p .41496 .75776 L F P
0 g
s
0 0 0 r
.42137 .75445 m .41788 .75693 L p .41496 .75776 L F P
0 g
s
0 0 0 r
.41788 .75693 m .44152 .74836 L p .42152 .7559 L F P
0 g
s
.43 .865 .768 r
.39432 .76838 m .41788 .75693 L p .39625 .76725 L F P
0 g
s
.43 .865 .768 r
.41788 .75693 m .41325 .75902 L .39303 .76878 L p F P
0 g
s
0 0 0 r
.41325 .75902 m .41788 .75693 L p .42152 .7559 L F P
0 g
s
.43 .865 .768 r
.39303 .76878 m .39432 .76838 L p .39625 .76725 L F P
0 g
s
.354 .798 .644 r
.42516 .75184 m .42137 .75445 L .40164 .7645 L p F P
0 g
s
.981 .698 .325 r
.8494 .70753 m .85376 .71422 L .85432 .72577 L p F P
0 g
s
.931 .594 .15 r
.85376 .71422 m .8494 .70753 L .84722 .69649 L p F P
0 g
s
0 .186 .613 r
.75537 .59692 m .74629 .59102 L .75832 .5986 L p F P
0 g
s
0 .186 .613 r
.75832 .5986 m .76729 .60453 L .75537 .59692 L p F P
0 g
s
.089 .1 .576 r
.19438 .74748 m .1996 .7376 L .20209 .7521 L p F P
0 g
s
.089 .1 .576 r
.20209 .7521 m .19943 .75709 L .19438 .74748 L p F P
0 g
s
.569 .041 0 r
.58137 .73068 m .594 .73856 L .57766 .73506 L p F P
0 g
s
.569 .041 0 r
.57341 .72926 m .58137 .73068 L p .57766 .73506 L F P
0 g
s
.964 .881 .701 r
.85348 .75737 m .85671 .76414 L .85016 .77776 L p F P
0 g
s
.994 .857 .588 r
.85537 .75126 m .85348 .75737 L .85671 .76414 L p F P
0 g
s
.33 .809 .759 r
.36753 .56319 m .36811 .56298 L .36755 .56319 L closepath p F P
0 g
s
.318 .8 .746 r
.38321 .55642 m .35992 .56501 L .36753 .56319 L p F P
0 g
s
.318 .8 .746 r
.39001 .55478 m .38321 .55642 L p .36753 .56319 L F P
0 g
s
.318 .8 .746 r
.36753 .56319 m .36811 .56298 L .39001 .55478 L p F P
0 g
s
.426 .867 .805 r
.36753 .56319 m .35992 .56501 L .34147 .57305 L p F P
0 g
s
.114 .504 .907 r
.71695 .80081 m .70746 .79744 L .70138 .7914 L p F P
0 g
s
.701 .211 0 r
.81524 .64675 m .80876 .64034 L .81561 .64981 L p F P
0 g
s
.701 .211 0 r
.81561 .64981 m .82208 .65622 L .81524 .64675 L p F P
0 g
s
.436 .875 .873 r
.39001 .55478 m .39069 .55475 L .36811 .56298 L closepath p F P
0 g
s
.551 0 0 r
.62104 .74706 m .60784 .74274 L .62183 .7504 L p F P
0 g
s
.551 0 0 r
.62183 .7504 m .63341 .75519 L .62104 .74706 L p F P
0 g
s
.507 .627 .904 r
.24811 .8061 m .2556 .81412 L .23342 .81648 L p F P
0 g
s
.507 .627 .904 r
.23285 .80665 m .24811 .8061 L p .23342 .81648 L F P
0 g
s
.507 .627 .904 r
.23342 .81648 m .2299 .81187 L .23285 .80665 L p F P
0 g
s
.524 .914 .796 r
.37081 .78178 m .38897 .77142 L .37531 .78037 L closepath p F P
0 g
s
.68 .973 .912 r
.37531 .78037 m .37081 .78178 L .35041 .7941 L p F P
0 g
s
.426 .855 .727 r
.30913 .58933 m .31354 .58758 L .33672 .57522 L p F P
0 g
s
.418 .849 .718 r
.33717 .57502 m .33672 .57522 L .31354 .58758 L p F P
0 g
s
.944 .6 .188 r
.84235 .68985 m .84722 .69649 L .8494 .70753 L p F P
0 g
s
.866 .473 0 r
.84722 .69649 m .84235 .68985 L .83863 .67931 L p F P
0 g
s
.016 .557 .842 r
.63917 .54959 m .65574 .55265 L .64078 .54832 L p F P
0 g
s
.016 .557 .842 r
.64078 .54832 m .63335 .54705 L .63917 .54959 L p F P
0 g
s
.011 .558 .832 r
.61774 .54478 m .63335 .54705 L .63917 .54959 L p F P
0 g
s
0 0 .012 r
.21395 .6795 m .21624 .67647 L .21322 .68611 L p F P
0 g
s
0 0 .012 r
.21322 .68611 m .20869 .6921 L .21395 .6795 L p F P
0 g
s
.807 .358 0 r
.82899 .66458 m .82801 .66272 L .82208 .65622 L p F P
0 g
s
0 .429 .757 r
.6825 .56219 m .69997 .56776 L .68749 .56271 L p F P
0 g
s
0 .429 .757 r
.66982 .55727 m .6825 .56219 L p .68749 .56271 L F P
0 g
s
0 0 .341 r
.1996 .71285 m .20587 .70399 L .20566 .71513 L p F P
0 g
s
0 0 .341 r
.20566 .71513 m .19889 .72461 L .1996 .71285 L p F P
0 g
s
.231 .736 .894 r
.50566 .53528 m .51197 .53669 L .53424 .53491 L closepath p F P
0 g
s
.283 .773 .902 r
.51197 .53669 m .50566 .53528 L .50426 .53538 L p F P
0 g
s
.886 .486 .044 r
.83863 .67931 m .83326 .67274 L .83697 .68329 L p F P
0 g
s
.886 .486 .044 r
.83697 .68329 m .84235 .68985 L .83863 .67931 L p F P
0 g
s
.279 .771 .899 r
.4769 .53762 m .48177 .53847 L .50426 .53538 L closepath p F P
0 g
s
.338 .81 .911 r
.48177 .53847 m .4769 .53762 L .46287 .53966 L p F P
0 g
s
0 .311 .696 r
.72215 .57857 m .71146 .57307 L .72598 .57972 L p F P
0 g
s
0 .311 .696 r
.72598 .57972 m .73653 .58528 L .72215 .57857 L p F P
0 g
s
.569 .041 0 r
.57766 .73506 m .57007 .7314 L .57341 .72926 L p F P
0 g
s
.608 .088 0 r
.57007 .7314 m .56356 .72762 L .57341 .72926 L closepath p F P
0 g
s
.01 .566 .817 r
.61774 .54478 m .63335 .54705 L p .62459 .54433 L F P
0 g
s
.01 .566 .817 r
.60398 .54186 m .61774 .54478 L p .62459 .54433 L F P
0 g
s
0 0 0 r
.23403 .65256 m .24656 .63802 L .23886 .64518 L closepath p F P
0 g
s
0 0 0 r
.23361 .65309 m .23403 .65256 L .23886 .64518 L p F P
0 g
s
.446 0 .073 r
.47918 .73108 m .48081 .72889 L .50827 .72564 L p F P
0 g
s
.453 0 .075 r
.50948 .72435 m .50827 .72564 L .48081 .72889 L p F P
0 g
s
.679 .973 .908 r
.34738 .79596 m .35041 .7941 L .34849 .79587 L closepath p F P
0 g
s
.192 .704 .893 r
.53624 .53491 m .54217 .53659 L .55898 .53615 L closepath p F P
0 g
s
.236 .739 .899 r
.54217 .53659 m .53624 .53491 L .53424 .53491 L p F P
0 g
s
.334 .808 .907 r
.4498 .54164 m .45153 .54187 L .46287 .53966 L closepath p F P
0 g
s
0 .256 .695 r
.68017 .78127 m .67597 .77879 L .66811 .77312 L p F P
0 g
s
.803 .353 0 r
.82899 .66458 m .83326 .67274 L .82736 .66624 L p F P
0 g
s
.803 .353 0 r
.82736 .66624 m .82399 .65984 L .82899 .66458 L p F P
0 g
s
.807 .358 0 r
.82208 .65622 m .82399 .65984 L .82899 .66458 L p F P
0 g
s
.491 .607 .895 r
.23285 .80665 m .2299 .81187 L .22607 .80656 L closepath p F P
0 g
s
.496 .01 .032 r
.50827 .72564 m .50948 .72435 L .51401 .72549 L closepath p F P
0 g
s
.505 0 0 r
.78013 .61429 m .77564 .61059 L .76729 .60453 L p F P
0 g
s
.693 .898 .97 r
.30892 .80455 m .28585 .8139 L .29342 .81842 L p F P
0 g
s
.693 .898 .97 r
.29342 .81842 m .31651 .80761 L .30892 .80455 L p F P
0 g
s
.994 .827 .571 r
.85699 .74459 m .85537 .75126 L .85059 .7479 L p F P
0 g
s
.994 .827 .571 r
.85059 .7479 m .85308 .73789 L .85699 .74459 L p F P
0 g
s
.998 .778 .451 r
.85699 .74459 m .85308 .73789 L .85432 .72577 L p F P
0 g
s
.537 0 0 r
.56356 .72762 m .54217 .72557 L .55825 .7324 L p F P
0 g
s
.537 0 0 r
.57007 .7314 m .56356 .72762 L p .55825 .7324 L F P
0 g
s
0 .324 .729 r
.73887 .58664 m .74293 .58941 L .74629 .59102 L closepath p F P
0 g
s
0 .35 .749 r
.73653 .58528 m .73887 .58664 L .74293 .58941 L p F P
0 g
s
.634 .805 .965 r
.27827 .80847 m .2556 .81412 L .26311 .82105 L p F P
0 g
s
.634 .805 .965 r
.26311 .82105 m .28585 .8139 L .27827 .80847 L p F P
0 g
s
.921 .884 .78 r
.84683 .77105 m .85016 .77776 L .84018 .79234 L p F P
0 g
s
.964 .881 .701 r
.85016 .77776 m .84683 .77105 L .85348 .75737 L p F P
0 g
s
.642 .967 .878 r
.3633 .78283 m .33983 .79541 L .34738 .79596 L p F P
0 g
s
.642 .967 .878 r
.36407 .78271 m .3633 .78283 L p .34738 .79596 L F P
0 g
s
.642 .967 .878 r
.34738 .79596 m .35041 .7941 L .36407 .78271 L p F P
0 g
s
.711 .927 .963 r
.34738 .79596 m .33983 .79541 L .31828 .80667 L p F P
0 g
s
0 .433 .793 r
.70149 .56844 m .70627 .5713 L .71146 .57307 L closepath p F P
0 g
s
0 .464 .815 r
.69997 .56776 m .70149 .56844 L .70627 .5713 L p F P
0 g
s
.165 .677 .897 r
.56889 .5369 m .57243 .53815 L .58077 .53834 L closepath p F P
0 g
s
.2 .708 .9 r
.57243 .53815 m .56889 .5369 L .55898 .53615 L p F P
0 g
s
.556 .057 .024 r
.5388 .72536 m .53971 .72454 L .54217 .72557 L closepath p F P
0 g
s
.511 .057 .11 r
.53971 .72454 m .5388 .72536 L .51401 .72549 L p F P
0 g
s
.645 .967 .884 r
.36407 .78271 m .37081 .78178 L .35041 .7941 L closepath p F P
0 g
s
0 0 0 r
.42137 .75445 m .42516 .75184 L .44866 .74286 L p F P
0 g
s
.074 0 0 r
.45044 .74095 m .44866 .74286 L .42516 .75184 L p F P
0 g
s
.31 0 0 r
.64322 .76023 m .64335 .76029 L .64348 .76035 L closepath p F P
0 g
s
.496 0 0 r
.63341 .75519 m .64322 .76023 L .64335 .76029 L p F P
0 g
s
0 0 .071 r
.21624 .67647 m .22496 .66679 L .21905 .67967 L p F P
0 g
s
0 0 .071 r
.21905 .67967 m .21322 .68611 L .21624 .67647 L p F P
0 g
s
0 .32 .657 r
.64348 .76035 m .65919 .76769 L .64899 .76255 L p F P
0 g
s
0 .32 .657 r
.64322 .76023 m .64348 .76035 L p .64899 .76255 L F P
0 g
s
.286 .787 .828 r
.41401 .54766 m .42119 .54735 L .44456 .54178 L p F P
0 g
s
.364 .835 .853 r
.42119 .54735 m .41401 .54766 L .41341 .54784 L p F P
0 g
s
.28 .783 .824 r
.4498 .54164 m .44456 .54178 L .42119 .54735 L p F P
0 g
s
.538 0 0 r
.60586 .74221 m .60667 .74212 L .60784 .74274 L closepath p F P
0 g
s
.59 .022 0 r
.594 .73856 m .60586 .74221 L .60667 .74212 L p F P
0 g
s
.553 .749 .968 r
.75346 .81599 m .77866 .81256 L .78405 .81864 L p F P
0 g
s
.547 .746 .969 r
.77866 .81256 m .75346 .81599 L .74794 .80966 L p F P
0 g
s
0 .32 .657 r
.64899 .76255 m .63751 .75792 L .64322 .76023 L p F P
0 g
s
.494 0 0 r
.63751 .75792 m .63341 .75519 L .64322 .76023 L closepath p F P
0 g
s
0 0 .444 r
.1994 .7346 m .19778 .72653 L .19889 .72461 L closepath p F P
0 g
s
0 0 .44 r
.19778 .72653 m .1994 .7346 L .1996 .7376 L p F P
0 g
s
.01 .566 .817 r
.62459 .54433 m .6028 .54147 L .60398 .54186 L p F P
0 g
s
.052 .598 .838 r
.6028 .54147 m .60033 .54123 L .60398 .54186 L closepath p F P
0 g
s
.207 .734 .801 r
.44456 .54178 m .4498 .54164 L .46287 .53966 L p F P
0 g
s
.305 .775 .656 r
.33672 .57522 m .34147 .57305 L .33717 .57502 L closepath p F P
0 g
s
.789 .855 .9 r
.82055 .80947 m .81409 .81406 L .80888 .80855 L p F P
0 g
s
.689 .825 .948 r
.78405 .81864 m .80888 .80855 L .81409 .81406 L p F P
0 g
s
.481 0 0 r
.60784 .74274 m .62183 .7504 L .60821 .74613 L p F P
0 g
s
.481 0 0 r
.60586 .74221 m .60784 .74274 L p .60821 .74613 L F P
0 g
s
.015 .578 .802 r
.6028 .54147 m .60033 .54123 L .58077 .53834 L p F P
0 g
s
.625 .099 0 r
.79338 .62509 m .78574 .61888 L .79413 .6278 L p F P
0 g
s
.625 .099 0 r
.79413 .6278 m .80173 .63402 L .79338 .62509 L p F P
0 g
s
.996 .77 .47 r
.84994 .71911 m .85432 .72577 L .85308 .73789 L p F P
0 g
s
.981 .698 .325 r
.85432 .72577 m .84994 .71911 L .8494 .70753 L p F P
0 g
s
.361 .469 .835 r
.21883 .79492 m .21245 .79288 L .21477 .78734 L closepath p F P
0 g
s
.391 .509 .858 r
.21245 .79288 m .21883 .79492 L .22607 .80656 L p F P
0 g
s
.103 .546 .913 r
.68017 .78127 m .69444 .78554 L .68655 .77987 L p F P
0 g
s
.103 .546 .913 r
.68655 .77987 m .67441 .77658 L .68017 .78127 L p F P
0 g
s
0 .256 .695 r
.66811 .77312 m .67441 .77658 L .68017 .78127 L p F P
0 g
s
0 0 .195 r
.20869 .6921 m .21322 .68611 L .21131 .69681 L p F P
0 g
s
0 0 .195 r
.21131 .69681 m .20587 .70399 L .20869 .6921 L p F P
0 g
s
.461 .558 .868 r
.22607 .80656 m .23285 .80665 L .23789 .79674 L p F P
0 g
s
.461 .558 .868 r
.23789 .79674 m .21883 .79492 L .22607 .80656 L p F P
0 g
s
.445 0 .002 r
.50827 .72564 m .51401 .72549 L p .5037 .7316 L F P
0 g
s
.445 0 .002 r
.5037 .7316 m .50284 .73148 L .50827 .72564 L p F P
0 g
s
.446 0 .073 r
.50827 .72564 m .50284 .73148 L .47918 .73108 L p F P
0 g
s
.373 0 0 r
.47516 .73508 m .47918 .73108 L .50284 .73148 L p F P
0 g
s
.261 0 0 r
.47918 .73108 m .47516 .73508 L .45044 .74095 L p F P
0 g
s
.988 .846 .609 r
.85348 .75737 m .85537 .75126 L .85059 .7479 L p F P
0 g
s
.501 0 0 r
.54217 .72557 m .55825 .7324 L .53497 .73084 L p F P
0 g
s
.501 0 0 r
.5388 .72536 m .54217 .72557 L p .53497 .73084 L F P
0 g
s
.789 .855 .9 r
.80888 .80855 m .81706 .80291 L .82055 .80947 L p F P
0 g
s
.829 .882 .881 r
.83311 .7899 m .81706 .80291 L .82055 .80947 L p F P
0 g
s
.829 .882 .881 r
.82055 .80947 m .83814 .79477 L .83311 .7899 L p F P
0 g
s
.445 0 .002 r
.51401 .72549 m .53332 .73036 L p .5037 .7316 L F P
0 g
s
.483 0 0 r
.53332 .73036 m .51401 .72549 L .5388 .72536 L closepath p F P
0 g
s
.307 .778 .664 r
.33672 .57522 m .34147 .57305 L p .32985 .57811 L F P
0 g
s
.307 .778 .664 r
.32985 .57811 m .32886 .57856 L .33672 .57522 L p F P
0 g
s
.426 .855 .727 r
.33672 .57522 m .32886 .57856 L .30913 .58933 L p F P
0 g
s
.283 .359 .765 r
.21177 .78096 m .20315 .77584 L .20673 .76836 L closepath p F P
0 g
s
.293 .389 .79 r
.20315 .77584 m .21177 .78096 L .21477 .78734 L p F P
0 g
s
.481 0 0 r
.60821 .74613 m .60069 .74281 L .60586 .74221 L p F P
0 g
s
.59 .022 0 r
.60069 .74281 m .594 .73856 L .60586 .74221 L closepath p F P
0 g
s
.4 0 0 r
.74629 .59102 m .75832 .5986 L .74871 .59281 L p F P
0 g
s
.4 0 0 r
.73887 .58664 m .74629 .59102 L p .74871 .59281 L F P
0 g
s
.501 0 0 r
.53497 .73084 m .53332 .73036 L .5388 .72536 L p F P
0 g
s
0 0 0 r
.25829 .62642 m .26361 .62162 L .25991 .6245 L closepath p F P
0 g
s
0 0 0 r
.25991 .6245 m .25829 .62642 L .24656 .63802 L p F P
0 g
s
0 .429 .757 r
.68749 .56271 m .66979 .55726 L .66982 .55727 L p F P
0 g
s
0 .449 .772 r
.66979 .55726 m .66976 .55724 L .66982 .55727 L closepath p F P
0 g
s
0 .427 .734 r
.66979 .55726 m .66976 .55724 L .65574 .55265 L p F P
0 g
s
.392 .66 .966 r
.71695 .80081 m .73335 .80237 L .7386 .80858 L p F P
0 g
s
.376 .666 .971 r
.71695 .80081 m .73335 .80237 L .72739 .79629 L p F P
0 g
s
.376 .666 .971 r
.72739 .79629 m .71129 .79485 L .71695 .80081 L p F P
0 g
s
.114 .504 .907 r
.70138 .7914 m .71129 .79485 L .71695 .80081 L p F P
0 g
s
0 .431 .744 r
.66979 .55726 m .68749 .56271 L .67419 .55786 L p F P
0 g
s
0 .431 .744 r
.67419 .55786 m .66414 .55494 L .66979 .55726 L p F P
0 g
s
0 .427 .734 r
.65574 .55265 m .66414 .55494 L .66979 .55726 L p F P
0 g
s
.888 .881 .822 r
.84018 .79234 m .83814 .79477 L .83311 .7899 L p F P
0 g
s
.888 .881 .822 r
.83311 .7899 m .83669 .78571 L .84018 .79234 L p F P
0 g
s
.921 .884 .78 r
.84018 .79234 m .83669 .78571 L .84683 .77105 L p F P
0 g
s
.683 .816 .946 r
.80888 .80855 m .78405 .81864 L .77866 .81256 L p F P
0 g
s
.013 .572 .811 r
.6028 .54147 m .62459 .54433 L .60673 .54083 L p F P
0 g
s
.013 .572 .811 r
.60673 .54083 m .59677 .53968 L .6028 .54147 L p F P
0 g
s
.015 .578 .802 r
.58077 .53834 m .59677 .53968 L .6028 .54147 L p F P
0 g
s
.095 .037 .494 r
.19889 .72461 m .20566 .71513 L .20833 .72545 L p F P
0 g
s
.095 .037 .494 r
.1994 .7346 m .19889 .72461 L p .20833 .72545 L F P
0 g
s
.366 .647 .964 r
.7386 .80858 m .74794 .80966 L .74237 .80344 L p F P
0 g
s
.366 .647 .964 r
.74237 .80344 m .73335 .80237 L .7386 .80858 L p F P
0 g
s
.207 .734 .801 r
.46287 .53966 m .47501 .5376 L p .44456 .54178 L F P
0 g
s
.224 .745 .821 r
.47501 .5376 m .46287 .53966 L .4769 .53762 L closepath p F P
0 g
s
.484 0 0 r
.78013 .61429 m .78574 .61888 L .77752 .61279 L p F P
0 g
s
.484 0 0 r
.77752 .61279 m .775 .61076 L .78013 .61429 L p F P
0 g
s
.505 0 0 r
.76729 .60453 m .775 .61076 L .78013 .61429 L p F P
0 g
s
.73 .232 0 r
.80876 .64034 m .80173 .63402 L .80858 .6435 L p F P
0 g
s
.73 .232 0 r
.80858 .6435 m .81561 .64981 L .80876 .64034 L p F P
0 g
s
0 .295 .652 r
.71146 .57307 m .72598 .57972 L .71472 .57433 L p F P
0 g
s
0 .295 .652 r
.70149 .56844 m .71146 .57307 L p .71472 .57433 L F P
0 g
s
.982 .695 .351 r
.84452 .70092 m .8494 .70753 L .84994 .71911 L p F P
0 g
s
.944 .6 .188 r
.8494 .70753 m .84452 .70092 L .84235 .68985 L p F P
0 g
s
.307 .778 .664 r
.34147 .57305 m .35827 .56539 L p .32985 .57811 L F P
0 g
s
.418 .862 .798 r
.35827 .56539 m .35992 .56501 L .34147 .57305 L closepath p F P
0 g
s
.082 .501 .9 r
.71129 .79485 m .70138 .7914 L .69444 .78554 L p F P
0 g
s
.255 0 0 r
.44866 .74286 m .45044 .74095 L .47516 .73508 L p F P
0 g
s
.364 .835 .853 r
.39001 .55478 m .39069 .55475 L .41341 .54784 L closepath p F P
0 g
s
.559 .935 .875 r
.37081 .78178 m .38897 .77142 L p .36667 .7811 L F P
0 g
s
.559 .935 .875 r
.36667 .7811 m .36407 .78271 L .37081 .78178 L p F P
0 g
s
0 0 0 r
.30539 .59175 m .30913 .58933 L .32886 .57856 L p F P
0 g
s
0 0 0 r
.30539 .59175 m .32876 .57863 L p .30278 .59343 L F P
0 g
s
.412 .823 .628 r
.30539 .59175 m .28814 .60274 L p .308 .59006 L F P
0 g
s
.389 .805 .606 r
.30171 .59404 m .30539 .59175 L .28814 .60274 L closepath p F P
0 g
s
0 0 0 r
.30171 .59404 m .30539 .59175 L p .30278 .59343 L F P
0 g
s
.412 .823 .628 r
.30913 .58933 m .30539 .59175 L p .308 .59006 L F P
0 g
s
.712 .929 .963 r
.31651 .80761 m .31828 .80667 L .31733 .80783 L closepath p F P
0 g
s
.958 .866 .705 r
.8497 .75067 m .85348 .75737 L .84683 .77105 L p F P
0 g
s
.988 .846 .609 r
.85059 .7479 m .8497 .75067 L .85348 .75737 L p F P
0 g
s
0 0 0 r
.28196 .60713 m .28814 .60274 L .28337 .60587 L closepath p F P
0 g
s
0 0 0 r
.28337 .60587 m .28196 .60713 L .26361 .62162 L p F P
0 g
s
.826 .371 0 r
.82399 .65984 m .82208 .65622 L .81561 .64981 L p F P
0 g
s
.95 .603 .222 r
.84235 .68985 m .83697 .68329 L .83913 .69438 L p F P
0 g
s
.95 .603 .222 r
.83913 .69438 m .84452 .70092 L .84235 .68985 L p F P
0 g
s
.194 .231 .672 r
.20505 .76309 m .19943 .75709 L .20209 .7521 L closepath p F P
0 g
s
.191 .247 .692 r
.19943 .75709 m .20505 .76309 L .20673 .76836 L p F P
0 g
s
.025 .589 .792 r
.58077 .53834 m .59677 .53968 L p .58737 .53779 L F P
0 g
s
.025 .589 .792 r
.56889 .5369 m .58077 .53834 L p .58737 .53779 L F P
0 g
s
.899 .495 .085 r
.83326 .67274 m .82736 .66624 L .83107 .67681 L p F P
0 g
s
.899 .495 .085 r
.83107 .67681 m .83697 .68329 L .83326 .67274 L p F P
0 g
s
.563 .025 0 r
.56642 .73341 m .57007 .7314 L .57766 .73506 L closepath p F P
0 g
s
.537 0 0 r
.55825 .7324 m .56642 .73341 L .57007 .7314 L p F P
0 g
s
.239 .749 .722 r
.38321 .55642 m .39001 .55478 L .41341 .54784 L p F P
0 g
s
.7 .941 .961 r
.32933 .79518 m .30892 .80455 L .31651 .80761 L p F P
0 g
s
.7 .941 .961 r
.31651 .80761 m .31828 .80667 L .32933 .79518 L p F P
0 g
s
.136 .683 .782 r
.47501 .5376 m .4769 .53762 L .50426 .53538 L p F P
0 g
s
0 .256 .667 r
.67441 .77658 m .66811 .77312 L .65919 .76769 L p F P
0 g
s
0 0 0 r
.25829 .62642 m .26361 .62162 L p .26617 .62218 L F P
0 g
s
0 0 0 r
.26617 .62218 m .25412 .63126 L .25829 .62642 L p F P
0 g
s
0 0 0 r
.25412 .63126 m .25829 .62642 L .24656 .63802 L closepath p F P
0 g
s
0 0 0 r
.26361 .62162 m .27678 .61164 L p .26617 .62218 L F P
0 g
s
0 0 0 r
.27678 .61164 m .28196 .60713 L .26361 .62162 L closepath p F P
0 g
s
.648 .932 .97 r
.33983 .79541 m .31828 .80667 L .32933 .79518 L p F P
0 g
s
.51 .637 .911 r
.24811 .8061 m .23285 .80665 L .23789 .79674 L p F P
0 g
s
.491 0 0 r
.76729 .60453 m .75832 .5986 L .76865 .60682 L p F P
0 g
s
.491 0 0 r
.775 .61076 m .76729 .60453 L p .76865 .60682 L F P
0 g
s
0 0 0 r
.24656 .63802 m .25412 .63126 L p .23385 .65284 L F P
0 g
s
0 0 0 r
.23385 .65284 m .23403 .65256 L .24656 .63802 L p F P
0 g
s
.025 .589 .792 r
.58737 .53779 m .56623 .53635 L .56889 .5369 L p F P
0 g
s
.075 .629 .818 r
.56623 .53635 m .55898 .53615 L .56889 .5369 L closepath p F P
0 g
s
.456 .564 .876 r
.21883 .79492 m .21477 .78734 L p .23909 .79457 L F P
0 g
s
.456 .564 .876 r
.23909 .79457 m .23789 .79674 L .21883 .79492 L p F P
0 g
s
.518 0 0 r
.594 .73856 m .57766 .73506 L .59247 .74243 L p F P
0 g
s
.518 0 0 r
.60069 .74281 m .594 .73856 L p .59247 .74243 L F P
0 g
s
.095 .037 .494 r
.20833 .72545 m .20005 .73694 L .1994 .7346 L p F P
0 g
s
.071 .023 .49 r
.20005 .73694 m .1996 .7376 L .1994 .7346 L closepath p F P
0 g
s
.56 0 0 r
.63751 .75792 m .63341 .75519 L .62183 .7504 L p F P
0 g
s
.605 .764 .955 r
.27071 .80199 m .24811 .8061 L .2556 .81412 L p F P
0 g
s
.605 .764 .955 r
.2556 .81412 m .27827 .80847 L .27071 .80199 L p F P
0 g
s
.031 .599 .771 r
.55898 .53615 m .56623 .53635 L p .53579 .53485 L F P
0 g
s
.031 .599 .771 r
.53579 .53485 m .53624 .53491 L .55898 .53615 L p F P
0 g
s
.4 0 0 r
.74871 .59281 m .73762 .58595 L .73887 .58664 L p F P
0 g
s
.396 0 0 r
.73762 .58595 m .73653 .58528 L .73887 .58664 L closepath p F P
0 g
s
0 0 0 r
.28196 .60713 m .28814 .60274 L p .28934 .60365 L F P
0 g
s
0 0 0 r
.28934 .60365 m .27678 .61164 L .28196 .60713 L p F P
0 g
s
.821 .364 0 r
.82399 .65984 m .82736 .66624 L .82093 .65983 L p F P
0 g
s
.821 .364 0 r
.82093 .65983 m .81905 .65631 L .82399 .65984 L p F P
0 g
s
.826 .371 0 r
.81561 .64981 m .81905 .65631 L .82399 .65984 L p F P
0 g
s
0 .421 .709 r
.66414 .55494 m .65574 .55265 L .64078 .54832 L p F P
0 g
s
0 .548 .826 r
.629 .54531 m .63335 .54705 L .64078 .54832 L closepath p F P
0 g
s
.01 .566 .817 r
.63335 .54705 m .629 .54531 L .62459 .54433 L p F P
0 g
s
.987 .816 .584 r
.85308 .73789 m .85059 .7479 L .84563 .74323 L p F P
0 g
s
.987 .816 .584 r
.84563 .74323 m .84868 .73127 L .85308 .73789 L p F P
0 g
s
.996 .77 .47 r
.85308 .73789 m .84868 .73127 L .84994 .71911 L p F P
0 g
s
.152 0 0 r
.44382 .74656 m .44866 .74286 L .47227 .73801 L p F P
0 g
s
.255 0 0 r
.47516 .73508 m .47227 .73801 L .44866 .74286 L p F P
0 g
s
0 0 0 r
.44866 .74286 m .44382 .74656 L .42137 .75445 L p F P
0 g
s
.559 .935 .875 r
.38897 .77142 m .39303 .76878 L p .36667 .7811 L F P
0 g
s
.52 .912 .795 r
.39303 .76878 m .39432 .76838 L .38897 .77142 L closepath p F P
0 g
s
0 0 .355 r
.20587 .70399 m .21131 .69681 L .21061 .70863 L p F P
0 g
s
0 0 .355 r
.21061 .70863 m .20566 .71513 L .20587 .70399 L p F P
0 g
s
0 0 0 r
.41788 .75693 m .42137 .75445 L .44382 .74656 L p F P
0 g
s
.18 .164 .602 r
.1996 .7376 m .20005 .73694 L .20606 .74628 L p F P
0 g
s
.18 .164 .602 r
.20606 .74628 m .20209 .7521 L .1996 .7376 L p F P
0 g
s
.669 .863 .973 r
.30132 .80053 m .27827 .80847 L .28585 .8139 L p F P
0 g
s
.669 .863 .973 r
.28585 .8139 m .30892 .80455 L .30132 .80053 L p F P
0 g
s
.136 .683 .782 r
.50426 .53538 m .50541 .53527 L p .47501 .5376 L F P
0 g
s
.163 .701 .813 r
.50541 .53527 m .50426 .53538 L .50566 .53528 L closepath p F P
0 g
s
0 0 0 r
.28814 .60274 m .30171 .59404 L p .28934 .60365 L F P
0 g
s
.077 .637 .772 r
.50541 .53527 m .50566 .53528 L .53424 .53491 L p F P
0 g
s
0 0 0 r
.23385 .65284 m .23403 .65256 L .23361 .65309 L closepath p F P
0 g
s
.958 .866 .705 r
.84683 .77105 m .84298 .76441 L .8497 .75067 L p F P
0 g
s
.915 .871 .78 r
.84298 .76441 m .84683 .77105 L .83669 .78571 L p F P
0 g
s
0 0 0 r
.23361 .65309 m .23385 .65284 L .22992 .66157 L p F P
0 g
s
0 0 0 r
.22992 .66157 m .22496 .66679 L .23361 .65309 L p F P
0 g
s
.547 .746 .969 r
.74794 .80966 m .77323 .80642 L .77866 .81256 L p F P
0 g
s
.545 .745 .969 r
.77323 .80642 m .74794 .80966 L .74237 .80344 L p F P
0 g
s
.113 .662 .812 r
.53579 .53485 m .53424 .53491 L .53624 .53491 L closepath p F P
0 g
s
.077 .637 .772 r
.53424 .53491 m .53579 .53485 L p .50541 .53527 L F P
0 g
s
0 0 0 r
.23385 .65284 m .24932 .63905 L p .23999 .65263 L F P
0 g
s
0 0 0 r
.23999 .65263 m .22992 .66157 L .23385 .65284 L p F P
0 g
s
0 0 0 r
.25412 .63126 m .24932 .63905 L .23385 .65284 L p F P
0 g
s
.105 .659 .782 r
.50541 .53527 m .52933 .53415 L p .51209 .53414 L F P
0 g
s
.105 .659 .782 r
.51209 .53414 m .49875 .53494 L .50541 .53527 L p F P
0 g
s
.077 .637 .772 r
.53579 .53485 m .52933 .53415 L .50541 .53527 L p F P
0 g
s
.136 .683 .782 r
.50541 .53527 m .49875 .53494 L .47501 .5376 L p F P
0 g
s
0 .295 .652 r
.71472 .57433 m .70078 .56811 L .70149 .56844 L p F P
0 g
s
0 .308 .661 r
.70078 .56811 m .69997 .56776 L .70149 .56844 L closepath p F P
0 g
s
.432 0 0 r
.73762 .58595 m .73653 .58528 L .72598 .57972 L p F P
0 g
s
.193 .169 .601 r
.20005 .73694 m .20833 .72545 L p .21348 .73601 L F P
0 g
s
.193 .169 .601 r
.21348 .73601 m .20606 .74628 L .20005 .73694 L p F P
0 g
s
.651 .118 0 r
.78574 .61888 m .77752 .61279 L .78595 .6217 L p F P
0 g
s
.651 .118 0 r
.78595 .6217 m .79413 .6278 L .78574 .61888 L p F P
0 g
s
.456 .564 .876 r
.21477 .78734 m .21755 .78283 L p .23909 .79457 L F P
0 g
s
.381 .453 .81 r
.21755 .78283 m .21477 .78734 L .21177 .78096 L closepath p F P
0 g
s
.162 .702 .793 r
.47501 .5376 m .49875 .53494 L p .47577 .53662 L F P
0 g
s
.162 .702 .793 r
.47577 .53662 m .46815 .53756 L .47501 .5376 L p F P
0 g
s
.207 .734 .801 r
.47501 .5376 m .46815 .53756 L .44456 .54178 L p F P
0 g
s
0 0 .245 r
.21322 .68611 m .21905 .67967 L .21598 .69169 L p F P
0 g
s
0 0 .245 r
.21598 .69169 m .21131 .69681 L .21322 .68611 L p F P
0 g
s
.337 .814 .769 r
.35827 .56539 m .35992 .56501 L .38321 .55642 L p F P
0 g
s
.061 .624 .781 r
.53579 .53485 m .55995 .53518 L p .54093 .53414 L F P
0 g
s
.061 .624 .781 r
.54093 .53414 m .52933 .53415 L .53579 .53485 L p F P
0 g
s
.031 .599 .771 r
.56623 .53635 m .55995 .53518 L .53579 .53485 L p F P
0 g
s
.307 0 0 r
.70078 .56811 m .69997 .56776 L .68749 .56271 L p F P
0 g
s
.413 0 0 r
.73762 .58595 m .74871 .59281 L .73843 .58715 L p F P
0 g
s
.413 0 0 r
.73843 .58715 m .73232 .5835 L .73762 .58595 L p F P
0 g
s
.432 0 0 r
.72598 .57972 m .73232 .5835 L .73762 .58595 L p F P
0 g
s
.784 .847 .899 r
.81706 .80291 m .80888 .80855 L .80362 .80281 L p F P
0 g
s
.683 .816 .946 r
.77866 .81256 m .80362 .80281 L .80888 .80855 L p F P
0 g
s
.991 .76 .486 r
.84504 .71253 m .84994 .71911 L .84868 .73127 L p F P
0 g
s
.982 .695 .351 r
.84994 .71911 m .84504 .71253 L .84452 .70092 L p F P
0 g
s
.291 0 0 r
.70078 .56811 m .71472 .57433 L .7027 .56911 L p F P
0 g
s
.291 0 0 r
.7027 .56911 m .69529 .56594 L .70078 .56811 L p F P
0 g
s
.307 0 0 r
.68749 .56271 m .69529 .56594 L .70078 .56811 L p F P
0 g
s
.382 .452 .808 r
.21177 .78096 m .20673 .76836 L p .22426 .77218 L F P
0 g
s
.382 .452 .808 r
.22426 .77218 m .21755 .78283 L .21177 .78096 L p F P
0 g
s
.218 .742 .807 r
.43956 .5419 m .44456 .54178 L .46815 .53756 L p F P
0 g
s
.286 .787 .828 r
.44456 .54178 m .43956 .5419 L .41401 .54766 L p F P
0 g
s
.371 .677 .976 r
.71129 .79485 m .72739 .79629 L .72068 .79035 L p F P
0 g
s
.371 .677 .976 r
.72068 .79035 m .7056 .78921 L .71129 .79485 L p F P
0 g
s
.082 .501 .9 r
.69444 .78554 m .7056 .78921 L .71129 .79485 L p F P
0 g
s
.224 0 0 r
.63751 .75792 m .64899 .76255 L .63716 .75782 L p F P
0 g
s
.224 0 0 r
.63716 .75782 m .63162 .75597 L .63751 .75792 L p F P
0 g
s
.56 0 0 r
.62183 .7504 m .63162 .75597 L .63751 .75792 L p F P
0 g
s
.784 .847 .899 r
.80362 .80281 m .81306 .79641 L .81706 .80291 L p F P
0 g
s
.821 .867 .881 r
.82799 .78458 m .81306 .79641 L .81706 .80291 L p F P
0 g
s
.821 .867 .881 r
.81706 .80291 m .83311 .7899 L .82799 .78458 L p F P
0 g
s
.105 .566 .913 r
.67441 .77658 m .68655 .77987 L .67756 .77444 L p F P
0 g
s
.105 .566 .913 r
.67756 .77444 m .66862 .77237 L .67441 .77658 L p F P
0 g
s
0 .256 .667 r
.65919 .76769 m .66862 .77237 L .67441 .77658 L p F P
0 g
s
.654 .959 .934 r
.35576 .78262 m .33225 .79386 L .33983 .79541 L p F P
0 g
s
.654 .959 .934 r
.33983 .79541 m .3633 .78283 L .35576 .78262 L p F P
0 g
s
.648 .932 .97 r
.32933 .79518 m .33225 .79386 L .33983 .79541 L p F P
0 g
s
.752 .251 0 r
.80173 .63402 m .79413 .6278 L .80098 .63729 L p F P
0 g
s
.752 .251 0 r
.80098 .63729 m .80858 .6435 L .80173 .63402 L p F P
0 g
s
.295 .32 .717 r
.20209 .7521 m .20606 .74628 L .2161 .75451 L p F P
0 g
s
.295 .32 .717 r
.20505 .76309 m .20209 .7521 L p .2161 .75451 L F P
0 g
s
.68 .809 .944 r
.80362 .80281 m .77866 .81256 L .77323 .80642 L p F P
0 g
s
.881 .87 .822 r
.83669 .78571 m .83311 .7899 L .82799 .78458 L p F P
0 g
s
.881 .87 .822 r
.82799 .78458 m .8327 .77915 L .83669 .78571 L p F P
0 g
s
.915 .871 .78 r
.83669 .78571 m .8327 .77915 L .84298 .76441 L p F P
0 g
s
.376 0 0 r
.47227 .73801 m .47516 .73508 L .50262 .73165 L p F P
0 g
s
.373 0 0 r
.50284 .73148 m .50262 .73165 L .47516 .73508 L p F P
0 g
s
.506 0 0 r
.57766 .73506 m .59247 .74243 L .57545 .73906 L p F P
0 g
s
.506 0 0 r
.56642 .73341 m .57766 .73506 L p .57545 .73906 L F P
0 g
s
.387 .838 .744 r
.38688 .77079 m .39303 .76878 L .41325 .75902 L p F P
0 g
s
.559 .935 .875 r
.39303 .76878 m .38688 .77079 L .36667 .7811 L p F P
0 g
s
0 0 0 r
.32886 .57856 m .32876 .57863 L .30539 .59175 L p F P
0 g
s
.06 .505 .894 r
.7056 .78921 m .69444 .78554 L .68655 .77987 L p F P
0 g
s
.033 .597 .791 r
.56623 .53635 m .58737 .53779 L .56563 .53549 L p F P
0 g
s
.033 .597 .791 r
.56563 .53549 m .55995 .53518 L .56623 .53635 L p F P
0 g
s
.354 .651 .967 r
.74237 .80344 m .73335 .80237 L .72739 .79629 L p F P
0 g
s
.98 .689 .374 r
.84452 .70092 m .83913 .69438 L .83964 .70601 L p F P
0 g
s
.98 .689 .374 r
.83964 .70601 m .84504 .71252 L .84452 .70092 L p F P
0 g
s
.98 .832 .624 r
.8497 .75067 m .85059 .7479 L .84563 .74323 L p F P
0 g
s
.295 .32 .717 r
.2161 .75451 m .20854 .76557 L .20505 .76309 L p F P
0 g
s
.288 .32 .721 r
.20854 .76557 m .20673 .76836 L .20505 .76309 L closepath p F P
0 g
s
.382 .452 .808 r
.20673 .76836 m .20854 .76557 L .22426 .77218 L p F P
0 g
s
0 0 .101 r
.22496 .66679 m .22992 .66157 L .22702 .67131 L p F P
0 g
s
0 0 .101 r
.22702 .67131 m .21905 .67967 L .22496 .66679 L p F P
0 g
s
.825 .36 0 r
.81561 .64981 m .80858 .6435 L .81396 .65351 L p F P
0 g
s
.825 .36 0 r
.81905 .65631 m .81561 .64981 L p .81396 .65351 L F P
0 g
s
.307 .778 .664 r
.35212 .56812 m .32985 .57811 L p .35661 .56613 L F P
0 g
s
.307 .778 .664 r
.35827 .56539 m .35212 .56812 L p .35661 .56613 L F P
0 g
s
.303 .774 .661 r
.35018 .56896 m .35212 .56812 L .32985 .57811 L closepath p F P
0 g
s
0 0 0 r
.35212 .56812 m .37557 .55938 L p .35064 .56878 L F P
0 g
s
0 0 0 r
.35018 .56896 m .35212 .56812 L p .35064 .56878 L F P
0 g
s
.337 .814 .769 r
.38321 .55642 m .38091 .55695 L .35827 .56539 L p F P
0 g
s
0 0 0 r
.35212 .56812 m .35827 .56539 L .38091 .55695 L p F P
0 g
s
0 .427 .688 r
.64078 .54832 m .65843 .55282 L p .64443 .54901 L F P
0 g
s
0 .427 .688 r
.629 .54531 m .64078 .54832 L p .64443 .54901 L F P
0 g
s
0 .421 .709 r
.64078 .54832 m .65843 .55282 L .66414 .55494 L p F P
0 g
s
.953 .602 .252 r
.83697 .68329 m .83107 .67681 L .83322 .68792 L p F P
0 g
s
.953 .602 .252 r
.83322 .68792 m .83913 .69438 L .83697 .68329 L p F P
0 g
s
0 .265 .64 r
.66862 .77237 m .65919 .76769 L .64899 .76255 L p F P
0 g
s
.482 0 0 r
.59609 .74335 m .60069 .74281 L .60821 .74613 L closepath p F P
0 g
s
.518 0 0 r
.59247 .74243 m .59609 .74335 L .60069 .74281 L p F P
0 g
s
.907 .501 .121 r
.82736 .66624 m .82093 .65983 L .82464 .67042 L p F P
0 g
s
.907 .501 .121 r
.82464 .67042 m .83107 .67681 L .82736 .66624 L p F P
0 g
s
.951 .851 .708 r
.84536 .74406 m .8497 .75067 L .84298 .76441 L p F P
0 g
s
.98 .832 .624 r
.84563 .74323 m .84536 .74406 L .8497 .75067 L p F P
0 g
s
.547 0 0 r
.75832 .5986 m .74871 .59281 L .7591 .601 L p F P
0 g
s
.547 0 0 r
.7591 .601 m .76865 .60682 L .75832 .5986 L p F P
0 g
s
.239 .749 .722 r
.41341 .54784 m .41399 .54767 L p .38321 .55642 L F P
0 g
s
.238 .748 .721 r
.41399 .54767 m .41341 .54784 L .41401 .54766 L closepath p F P
0 g
s
.383 0 0 r
.62183 .7504 m .60821 .74613 L .62391 .75343 L p F P
0 g
s
.383 0 0 r
.63162 .75597 m .62183 .7504 L p .62391 .75343 L F P
0 g
s
0 0 0 r
.41399 .54767 m .41401 .54766 L .43956 .5419 L p F P
0 g
s
0 0 0 r
.41399 .54767 m .43432 .54307 L p .42539 .54502 L F P
0 g
s
0 0 0 r
.42539 .54502 m .43432 .54307 L .43309 .54333 L F
.43747 .54236 m .41399 .54767 L p .43925 .54197 L F P
0 g
s
0 0 0 r
.43956 .5419 m .43747 .54236 L p .43925 .54197 L F P
0 g
s
0 0 0 r
.43432 .54307 m .43747 .54236 L p .43309 .54333 L F P
0 g
s
.218 .742 .807 r
.46815 .53756 m .46663 .53755 L .43956 .5419 L p F P
0 g
s
0 0 0 r
.43747 .54236 m .46118 .5386 L p .43181 .54361 L F P
0 g
s
0 0 0 r
.43747 .54236 m .43067 .5438 L .42539 .54502 L p F P
0 g
s
0 0 0 r
.43067 .5438 m .43747 .54236 L p .43181 .54361 L F P
0 g
s
0 0 0 r
.46118 .5386 m .45778 .53923 L .43114 .54373 L p F P
0 g
s
0 0 0 r
.43114 .54373 m .43067 .5438 L p .43117 .54372 L F P
0 g
s
0 0 0 r
.43117 .54372 m .46118 .5386 L .43114 .54373 L F
.239 .749 .722 r
.40665 .54939 m .38321 .55642 L p .41262 .54806 L F P
0 g
s
.239 .749 .722 r
.41399 .54767 m .40665 .54939 L p .41262 .54806 L F P
0 g
s
0 0 0 r
.42539 .54502 m .40665 .54939 L .41399 .54767 L p F P
0 g
s
.166 .698 .696 r
.40665 .54939 m .42539 .54502 L .40531 .54968 L p F P
0 g
s
.166 .698 .696 r
.40531 .54968 m .40505 .54974 L .40665 .54939 L p F P
0 g
s
.506 0 0 r
.57545 .73906 m .56388 .73483 L .56642 .73341 L p F P
0 g
s
.539 0 0 r
.56388 .73483 m .55825 .7324 L .56642 .73341 L closepath p F P
0 g
s
0 .436 .736 r
.66414 .55494 m .67419 .55786 L .65999 .55324 L p F P
0 g
s
0 .436 .736 r
.65999 .55324 m .65843 .55282 L .66414 .55494 L p F P
0 g
s
.514 0 0 r
.77147 .60869 m .775 .61076 L .77752 .61279 L closepath p F P
0 g
s
.491 0 0 r
.76865 .60682 m .77147 .60869 L .775 .61076 L p F P
0 g
s
.575 .718 .94 r
.26317 .79432 m .24066 .79682 L .24811 .8061 L p F P
0 g
s
.575 .718 .94 r
.24811 .8061 m .27071 .80199 L .26317 .79432 L p F P
0 g
s
.51 .637 .911 r
.23789 .79674 m .24066 .79682 L .24811 .8061 L p F P
0 g
s
0 0 0 r
.25412 .63126 m .26617 .62218 L .25032 .6383 L p F P
0 g
s
0 0 0 r
.25032 .6383 m .24932 .63905 L .25412 .63126 L p F P
0 g
s
.45 0 0 r
.55825 .7324 m .53497 .73084 L .55471 .73672 L p F P
0 g
s
.45 0 0 r
.56388 .73483 m .55825 .7324 L p .55471 .73672 L F P
0 g
s
0 .564 .798 r
.59205 .53839 m .59677 .53968 L .60673 .54083 L closepath p F P
0 g
s
.025 .589 .792 r
.59677 .53968 m .59205 .53839 L .58737 .53779 L p F P
0 g
s
.428 .511 .842 r
.23332 .78577 m .21755 .78283 L .22426 .77218 L p F P
0 g
s
.456 .564 .876 r
.21755 .78283 m .23332 .78577 L .23909 .79457 L p F P
0 g
s
.109 .038 .487 r
.20566 .71513 m .21061 .70863 L .21126 .72164 L p F P
0 g
s
.109 .038 .487 r
.21126 .72164 m .20833 .72545 L .20566 .71513 L p F P
0 g
s
.41 0 0 r
.50262 .73165 m .50284 .73148 L .5037 .7316 L closepath p F P
0 g
s
0 0 0 r
.44382 .74656 m .44152 .74836 L .41788 .75693 L p F P
0 g
s
.553 .933 .868 r
.3633 .78283 m .36667 .7811 L .36407 .78271 L closepath p F P
0 g
s
.447 0 0 r
.73232 .5835 m .72598 .57972 L .71472 .57433 L p F P
0 g
s
.679 .91 .975 r
.32465 .79118 m .30132 .80053 L .30892 .80455 L p F P
0 g
s
.679 .91 .975 r
.33119 .79348 m .32465 .79118 L p .30892 .80455 L F P
0 g
s
.679 .91 .975 r
.30892 .80455 m .32933 .79518 L .33119 .79348 L p F P
0 g
s
.32 0 0 r
.69529 .56594 m .68749 .56271 L .67419 .55786 L p F P
0 g
s
.482 0 0 r
.53276 .73075 m .53332 .73036 L .53497 .73084 L closepath p F P
0 g
s
.445 0 .002 r
.53332 .73036 m .53276 .73075 L .5037 .7316 L p F P
0 g
s
.36 .409 .777 r
.20854 .76557 m .2161 .75451 L p .22522 .77078 L F P
0 g
s
.36 .409 .777 r
.22522 .77078 m .22426 .77218 L .20854 .76557 L p F P
0 g
s
.357 0 0 r
.50262 .73165 m .5037 .7316 L p .49637 .73689 L F P
0 g
s
.357 0 0 r
.49637 .73689 m .4961 .73688 L .50262 .73165 L p F P
0 g
s
.376 0 0 r
.50262 .73165 m .4961 .73688 L .47227 .73801 L p F P
0 g
s
.357 0 0 r
.5037 .7316 m .52683 .73493 L p .49637 .73689 L F P
0 g
s
.396 0 0 r
.52683 .73493 m .5037 .7316 L .53276 .73075 L closepath p F P
0 g
s
0 .427 .688 r
.64443 .54901 m .62747 .54494 L .629 .54531 L p F P
0 g
s
0 .456 .71 r
.62747 .54494 m .62459 .54433 L .629 .54531 L closepath p F P
0 g
s
.98 .803 .592 r
.84868 .73127 m .84563 .74323 L .84051 .73735 L p F P
0 g
s
.98 .803 .592 r
.84051 .73735 m .84376 .72471 L .84868 .73127 L p F P
0 g
s
.991 .76 .486 r
.84868 .73127 m .84376 .72471 L .84504 .71253 L p F P
0 g
s
.673 .132 0 r
.77752 .61279 m .78595 .6217 L .77718 .6157 L p F P
0 g
s
.673 .132 0 r
.77147 .60869 m .77752 .61279 L p .77718 .6157 L F P
0 g
s
.561 .936 .875 r
.37941 .77177 m .35576 .78262 L .3633 .78283 L p F P
0 g
s
.561 .936 .875 r
.38227 .77136 m .37941 .77177 L p .3633 .78283 L F P
0 g
s
.561 .936 .875 r
.3633 .78283 m .36667 .7811 L .38227 .77136 L p F P
0 g
s
0 0 0 r
.32876 .57863 m .32985 .57811 L .32886 .57856 L closepath p F P
0 g
s
.645 .823 .969 r
.29372 .79544 m .27071 .80199 L .27827 .80847 L p F P
0 g
s
.645 .823 .969 r
.27827 .80847 m .30132 .80053 L .29372 .79544 L p F P
0 g
s
.421 0 0 r
.53497 .73084 m .55471 .73672 L .53 .73551 L p F P
0 g
s
.421 0 0 r
.53276 .73075 m .53497 .73084 L p .53 .73551 L F P
0 g
s
.545 .745 .969 r
.74237 .80344 m .76775 .80024 L .77323 .80642 L p F P
0 g
s
.544 .745 .969 r
.76222 .79402 m .73677 .79735 L .74237 .80344 L p F P
0 g
s
.544 .745 .969 r
.74237 .80344 m .76775 .80024 L .76222 .79402 L p F P
0 g
s
.354 .651 .967 r
.72739 .79629 m .73677 .79735 L .74237 .80344 L p F P
0 g
s
.421 0 0 r
.53 .73551 m .52683 .73493 L .53276 .73075 L p F P
0 g
s
0 0 0 r
.32876 .57863 m .32985 .57811 L p .33311 .57823 L F P
0 g
s
0 0 0 r
.33311 .57823 m .32167 .58335 L .32876 .57863 L p F P
0 g
s
0 0 0 r
.32876 .57863 m .32167 .58335 L .30171 .59404 L p F P
0 g
s
.092 0 .393 r
.21131 .69681 m .21598 .69169 L .21594 .70283 L p F P
0 g
s
.092 0 .393 r
.21594 .70283 m .21061 .70863 L .21131 .69681 L p F P
0 g
s
.909 .858 .779 r
.83858 .75785 m .84298 .76441 L .8327 .77915 L p F P
0 g
s
.951 .851 .708 r
.84298 .76441 m .83858 .75785 L .84536 .74406 L p F P
0 g
s
.169 0 0 r
.62747 .54494 m .62459 .54433 L .60673 .54083 L p F P
0 g
s
0 0 0 r
.32985 .57811 m .35018 .56896 L p .33311 .57823 L F P
0 g
s
.008 0 .263 r
.21905 .67967 m .22702 .67131 L .22518 .68209 L p F P
0 g
s
.008 0 .263 r
.22518 .68209 m .21598 .69169 L .21905 .67967 L p F P
0 g
s
.564 .937 .879 r
.38227 .77136 m .38688 .77079 L .36667 .7811 L closepath p F P
0 g
s
0 0 0 r
.27313 .61616 m .28934 .60365 L .27678 .61164 L closepath p F P
0 g
s
0 0 0 r
.27678 .61164 m .27313 .61616 L .26617 .62218 L p F P
0 g
s
.835 .376 0 r
.81467 .65415 m .81905 .65631 L .82093 .65983 L closepath p F P
0 g
s
.825 .36 0 r
.81396 .65351 m .81467 .65415 L .81905 .65631 L p F P
0 g
s
.248 .756 .731 r
.38091 .55695 m .38321 .55642 L .40665 .54939 L p F P
0 g
s
.266 0 0 r
.46864 .7406 m .47227 .73801 L .4961 .73688 L p F P
0 g
s
.152 0 0 r
.47227 .73801 m .46864 .7406 L .44382 .74656 L p F P
0 g
s
.151 0 0 r
.44152 .74836 m .44382 .74656 L .46864 .7406 L p F P
0 g
s
.781 .84 .897 r
.81306 .79641 m .80362 .80281 L .79829 .79684 L p F P
0 g
s
.68 .809 .944 r
.77323 .80642 m .79829 .79684 L .80362 .80281 L p F P
0 g
s
0 0 0 r
.29692 .59848 m .30171 .59404 L .32167 .58335 L p F P
0 g
s
0 0 0 r
.30171 .59404 m .29692 .59848 L .28934 .60365 L p F P
0 g
s
.985 .75 .499 r
.84504 .71252 m .83964 .70601 L .83833 .71823 L p F P
0 g
s
.985 .75 .499 r
.83833 .71823 m .84376 .72471 L .84504 .71252 L p F P
0 g
s
.769 .266 0 r
.79413 .6278 m .78595 .6217 L .79282 .63118 L p F P
0 g
s
.769 .266 0 r
.79282 .63118 m .80098 .63729 L .79413 .6278 L p F P
0 g
s
.283 .291 .691 r
.20606 .74628 m .21348 .73601 L .21782 .75215 L p F P
0 g
s
.283 .291 .691 r
.21782 .75215 m .2161 .75451 L .20606 .74628 L p F P
0 g
s
0 0 .152 r
.22992 .66157 m .23999 .65263 L .23318 .66587 L p F P
0 g
s
0 0 .152 r
.23318 .66587 m .22702 .67131 L .22992 .66157 L p F P
0 g
s
.419 0 0 r
.60821 .74613 m .62391 .75343 L .61033 .74909 L p F P
0 g
s
.419 0 0 r
.59609 .74335 m .60821 .74613 L p .61033 .74909 L F P
0 g
s
.047 .516 .889 r
.69988 .78386 m .68655 .77987 L .67756 .77444 L p F P
0 g
s
.06 .505 .894 r
.68655 .77987 m .69988 .78386 L .7056 .78921 L p F P
0 g
s
.483 .598 .892 r
.24066 .79682 m .23789 .79674 L .23909 .79457 L closepath p F P
0 g
s
.159 0 0 r
.62747 .54494 m .64443 .54901 L .62779 .54508 L p F P
0 g
s
.159 0 0 r
.62779 .54508 m .62156 .5437 L .62747 .54494 L p F P
0 g
s
.169 0 0 r
.60673 .54083 m .62156 .5437 L .62747 .54494 L p F P
0 g
s
.491 0 0 r
.55875 .73708 m .56388 .73483 L .57545 .73906 L closepath p F P
0 g
s
.45 0 0 r
.55471 .73672 m .55875 .73708 L .56388 .73483 L p F P
0 g
s
.373 .692 .981 r
.7056 .78921 m .72068 .79035 L .71314 .78457 L p F P
0 g
s
.373 .692 .981 r
.71314 .78457 m .69988 .78386 L .7056 .78921 L p F P
0 g
s
.679 .803 .942 r
.79829 .79684 m .77323 .80642 L .76775 .80024 L p F P
0 g
s
0 .41 .784 r
.64899 .76255 m .63716 .75782 L .65574 .76448 L p F P
0 g
s
0 .41 .784 r
.66279 .76852 m .64899 .76255 L p .65574 .76448 L F P
0 g
s
0 .265 .64 r
.64899 .76255 m .66279 .76852 L .66862 .77237 L p F P
0 g
s
.781 .84 .897 r
.79829 .79684 m .80852 .78998 L .81306 .79641 L p F P
0 g
s
.813 .853 .879 r
.82279 .77884 m .80852 .78998 L .81306 .79641 L p F P
0 g
s
.813 .853 .879 r
.81306 .79641 m .82799 .78458 L .82279 .77884 L p F P
0 g
s
.346 .656 .97 r
.73677 .79735 m .72739 .79629 L .72068 .79035 L p F P
0 g
s
.571 .002 0 r
.74871 .59281 m .73843 .58715 L .7489 .59531 L p F P
0 g
s
.571 .002 0 r
.7489 .59531 m .7591 .601 L .74871 .59281 L p F P
0 g
s
0 0 0 r
.43747 .54236 m .43956 .5419 L .46663 .53755 L p F P
0 g
s
.876 .858 .82 r
.8327 .77915 m .82799 .78458 L .82279 .77884 L p F P
0 g
s
.876 .858 .82 r
.82279 .77884 m .8282 .77266 L .8327 .77915 L p F P
0 g
s
.909 .858 .779 r
.8327 .77915 m .8282 .77266 L .83858 .75785 L p F P
0 g
s
.976 .682 .394 r
.83913 .69438 m .83322 .68792 L .83371 .69958 L p F P
0 g
s
.976 .682 .394 r
.83371 .69958 m .83964 .70601 L .83913 .69438 L p F P
0 g
s
.845 .384 .013 r
.80858 .6435 m .80098 .63729 L .80635 .64731 L p F P
0 g
s
.845 .384 .013 r
.80635 .64731 m .81396 .65351 L .80858 .6435 L p F P
0 g
s
.125 .595 .919 r
.66862 .77237 m .67756 .77444 L .6672 .76934 L p F P
0 g
s
.125 .595 .919 r
.6672 .76934 m .66279 .76852 L .66862 .77237 L p F P
0 g
s
.951 .6 .279 r
.83107 .67681 m .82464 .67042 L .82678 .68154 L p F P
0 g
s
.951 .6 .279 r
.82678 .68154 m .83322 .68792 L .83107 .67681 L p F P
0 g
s
.909 .503 .158 r
.82093 .65983 m .82464 .67042 L .81768 .66411 L p F P
0 g
s
.909 .503 .158 r
.81467 .65415 m .82093 .65983 L p .81768 .66411 L F P
0 g
s
.519 .615 .888 r
.25568 .78528 m .26317 .79432 L .24066 .79682 L p F P
0 g
s
.519 .615 .888 r
.24624 .78573 m .25568 .78528 L p .24066 .79682 L F P
0 g
s
.519 .615 .888 r
.24066 .79682 m .23909 .79457 L .24624 .78573 L p F P
0 g
s
.419 0 0 r
.73232 .5835 m .73843 .58715 L .72746 .58165 L p F P
0 g
s
.419 0 0 r
.72746 .58165 m .72699 .58138 L .73232 .5835 L p F P
0 g
s
.447 0 0 r
.71472 .57433 m .72699 .58138 L .73232 .5835 L p F P
0 g
s
.276 0 0 r
.67419 .55786 m .65999 .55324 L .67594 .55936 L p F P
0 g
s
.276 0 0 r
.68975 .56402 m .67419 .55786 L p .67594 .55936 L F P
0 g
s
.32 0 0 r
.67419 .55786 m .68975 .56402 L .69529 .56594 L p F P
0 g
s
.673 .132 0 r
.77718 .6157 m .76988 .6081 L .77147 .60869 L p F P
0 g
s
.673 .133 0 r
.76988 .6081 m .76865 .60682 L .77147 .60869 L closepath p F P
0 g
s
.161 0 0 r
.60673 .54083 m .62156 .5437 L p .60963 .5416 L F P
0 g
s
.161 0 0 r
.59205 .53839 m .60673 .54083 L p .60963 .5416 L F P
0 g
s
.971 .817 .633 r
.84536 .74406 m .84563 .74323 L .84051 .73735 L p F P
0 g
s
.678 .907 .975 r
.33119 .79348 m .33225 .79386 L .32933 .79518 L closepath p F P
0 g
s
.102 .657 .779 r
.49529 .53479 m .49875 .53494 L .51209 .53414 L closepath p F P
0 g
s
.162 .702 .793 r
.49875 .53494 m .49529 .53479 L .47577 .53662 L p F P
0 g
s
.943 .836 .709 r
.84045 .73753 m .84536 .74406 L .83858 .75785 L p F P
0 g
s
.971 .817 .633 r
.84051 .73735 m .84045 .73753 L .84536 .74406 L p F P
0 g
s
.414 0 0 r
.71472 .57433 m .7027 .56911 L .71559 .57637 L p F P
0 g
s
.414 0 0 r
.72699 .58138 m .71472 .57433 L p .71559 .57637 L F P
0 g
s
.292 0 0 r
.69529 .56594 m .7027 .56911 L .68989 .56408 L p F P
0 g
s
.292 0 0 r
.68989 .56408 m .68975 .56402 L .69529 .56594 L p F P
0 g
s
.245 0 0 r
.62734 .75474 m .63162 .75597 L .63716 .75782 L closepath p F P
0 g
s
.383 0 0 r
.62391 .75343 m .62734 .75474 L p .63135 .75589 L F P
0 g
s
0 .405 .686 r
.64455 .7595 m .62569 .75427 L p .62734 .75474 L F P
0 g
s
.387 0 0 r
.62567 .75427 m .62391 .75343 L .62726 .75471 L p F P
0 g
s
.387 0 0 r
.62726 .75471 m .62734 .75474 L .62567 .75427 L p F P
0 g
s
.443 0 0 r
.62567 .75427 m .62391 .75343 L .61033 .74909 L p F P
0 g
s
.443 0 0 r
.61033 .74909 m .61965 .75259 L .62567 .75427 L p F P
0 g
s
0 .483 .743 r
.63155 .75497 m .61978 .75262 L p .62567 .75427 L F P
0 g
s
0 .483 .743 r
.61978 .75262 m .61965 .75259 L .62567 .75427 L p F P
0 g
s
0 .405 .686 r
.62569 .75427 m .62567 .75427 L .62734 .75474 L p F P
0 g
s
.383 0 0 r
.62734 .75474 m .63162 .75597 L p .63135 .75589 L F P
0 g
s
.056 .62 .775 r
.52562 .53377 m .52933 .53415 L .54093 .53414 L closepath p F P
0 g
s
.105 .659 .782 r
.52933 .53415 m .52562 .53377 L .51209 .53414 L p F P
0 g
s
.16 .7 .791 r
.46663 .53755 m .46815 .53756 L .47577 .53662 L closepath p F P
0 g
s
.504 .593 .877 r
.24624 .78573 m .23909 .79457 L .23332 .78577 L closepath p F P
0 g
s
.656 .903 .981 r
.33225 .79386 m .35576 .78262 L p .34758 .78146 L F P
0 g
s
.656 .903 .981 r
.34758 .78146 m .33119 .79348 L .33225 .79386 L p F P
0 g
s
.248 .756 .731 r
.40665 .54939 m .40505 .54974 L .38091 .55695 L p F P
0 g
s
0 0 0 r
.37557 .55938 m .38091 .55695 L .40505 .54974 L p F P
0 g
s
0 0 0 r
.38091 .55695 m .37557 .55938 L .35212 .56812 L p F P
0 g
s
.419 0 0 r
.61033 .74909 m .59464 .74353 L .59609 .74335 L p F P
0 g
s
.522 0 0 r
.59464 .74353 m .59247 .74243 L .59609 .74335 L closepath p F P
0 g
s
.387 .838 .744 r
.41055 .7603 m .38688 .77079 L p .4076 .76154 L F P
0 g
s
.387 .838 .744 r
.41325 .75902 m .41055 .7603 L p .4076 .76154 L F P
0 g
s
0 0 0 r
.44152 .74836 m .43596 .75119 L .41325 .75902 L p F P
0 g
s
0 0 0 r
.41055 .7603 m .41325 .75902 L .43596 .75119 L p F P
0 g
s
0 0 0 r
.43432 .75205 m .41055 .7603 L p .43204 .75259 L F P
0 g
s
0 0 0 r
.43596 .75119 m .43432 .75205 L p .43204 .75259 L F P
0 g
s
.018 0 0 r
.45824 .74634 m .43432 .75205 L p .45512 .74659 L F P
0 g
s
.018 0 0 r
.46084 .74509 m .45824 .74634 L p .45512 .74659 L F P
0 g
s
0 0 0 r
.45824 .74634 m .48237 .74292 L p .4645 .74584 L F P
0 g
s
0 0 0 r
.45131 .748 m .45824 .74634 L .4645 .74584 L F
.131 0 0 r
.48237 .74292 m .45824 .74634 L p .47494 .74337 L F P
0 g
s
.131 0 0 r
.48808 .74103 m .48237 .74292 L p .47494 .74337 L F P
0 g
s
0 0 0 r
.48237 .74292 m .50326 .74135 L .48834 .74255 L p F P
0 g
s
0 0 0 r
.48237 .74292 m .47806 .74338 L .45133 .74799 L p F P
0 g
s
0 0 0 r
.45131 .748 m .48237 .74292 L .45133 .74799 L F
.48834 .74255 m .47806 .74338 L .48237 .74292 L p F P
0 g
s
0 0 0 r
.45824 .74634 m .45115 .74802 L .45024 .74825 L p F P
0 g
s
0 0 0 r
.45115 .74802 m .45824 .74634 L p .45131 .748 L F P
0 g
s
0 0 0 r
.45133 .74799 m .45115 .74802 L p .45131 .748 L F P
0 g
s
0 0 0 r
.43432 .75205 m .4431 .74996 L p .45024 .74825 L F P
0 g
s
0 0 0 r
.4431 .74996 m .45824 .74634 L p .4508 .74812 L F P
0 g
s
0 0 0 r
.45024 .74825 m .4431 .74996 L .4508 .74812 L F
.45024 .74825 m .44639 .74922 L p .43432 .75205 L F P
0 g
s
.287 .782 .744 r
.41055 .7603 m .43432 .75205 L p .41661 .75774 L F P
0 g
s
.287 .782 .744 r
.42707 .75407 m .40405 .76177 L p .42008 .75663 L F P
0 g
s
.287 .782 .744 r
.43432 .75205 m .42707 .75407 L p .42008 .75663 L F P
0 g
s
0 0 0 r
.44639 .74922 m .42707 .75407 L .43432 .75205 L p F P
0 g
s
.309 .801 .84 r
.42707 .75407 m .45024 .74825 L .42877 .75344 L p F P
0 g
s
.309 .801 .84 r
.42877 .75344 m .42602 .75411 L .42707 .75407 L p F P
0 g
s
.287 .782 .744 r
.40405 .76177 m .41055 .7603 L .41661 .75774 L F
.495 .906 .866 r
.38227 .77136 m .38688 .77079 L .41055 .7603 L p F P
0 g
s
.016 0 0 r
.43596 .75119 m .44152 .74836 L .46529 .74305 L p F P
0 g
s
.151 0 0 r
.46864 .7406 m .46529 .74305 L .44152 .74836 L p F P
0 g
s
.693 .153 0 r
.76988 .6081 m .76865 .60682 L .7591 .601 L p F P
0 g
s
.116 0 .401 r
.21598 .69169 m .22518 .68209 L .22451 .69395 L p F P
0 g
s
.116 0 .401 r
.22451 .69395 m .21594 .70283 L .21598 .69169 L p F P
0 g
s
.192 .1 .514 r
.21061 .70863 m .21594 .70283 L .21927 .713 L p F P
0 g
s
.192 .1 .514 r
.21927 .713 m .21126 .72164 L .21061 .70863 L p F P
0 g
s
.656 .905 .981 r
.32465 .79118 m .34758 .78146 L .33119 .79348 L closepath p F P
0 g
s
.204 .166 .591 r
.21292 .73287 m .20833 .72545 L .21126 .72164 L closepath p F P
0 g
s
.193 .169 .601 r
.20833 .72545 m .21292 .73287 L .21348 .73601 L p F P
0 g
s
.554 0 0 r
.59464 .74353 m .59247 .74243 L .57545 .73906 L p F P
0 g
s
.023 .591 .78 r
.55778 .53482 m .55995 .53518 L .56563 .53549 L closepath p F P
0 g
s
.061 .624 .781 r
.55995 .53518 m .55778 .53482 L .54093 .53414 L p F P
0 g
s
.161 0 0 r
.60963 .5416 m .59067 .53825 L .59205 .53839 L p F P
0 g
s
.119 0 0 r
.59067 .53825 m .58737 .53779 L .59205 .53839 L closepath p F P
0 g
s
0 0 0 r
.46663 .53755 m .46118 .5386 L .43747 .54236 L p F P
0 g
s
.972 .789 .599 r
.84051 .73735 m .84376 .72471 L .83833 .71823 L p F P
0 g
s
.155 0 0 r
.59067 .53825 m .58737 .53779 L .56563 .53549 L p F P
0 g
s
.678 .134 0 r
.76988 .6081 m .77718 .6157 L .7678 .60982 L p F P
0 g
s
.678 .134 0 r
.7678 .60982 m .7648 .60679 L .76988 .6081 L p F P
0 g
s
.693 .153 0 r
.7591 .601 m .7648 .60679 L .76988 .6081 L p F P
0 g
s
.621 .779 .957 r
.28613 .78917 m .26317 .79432 L .27071 .80199 L p F P
0 g
s
.621 .779 .957 r
.27071 .80199 m .29372 .79544 L .28613 .78917 L p F P
0 g
s
0 0 0 r
.46663 .53755 m .47577 .53662 L p .47877 .5369 L F P
0 g
s
0 0 0 r
.47877 .5369 m .46118 .5386 L .46663 .53755 L p F P
0 g
s
.663 .871 .977 r
.31705 .78735 m .29372 .79544 L .30132 .80053 L p F P
0 g
s
.663 .871 .977 r
.30132 .80053 m .32465 .79118 L .31705 .78735 L p F P
0 g
s
.546 .747 .969 r
.75664 .78774 m .73114 .79137 L .73677 .79735 L p F P
0 g
s
.546 .747 .969 r
.73677 .79735 m .76222 .79402 L .75664 .78774 L p F P
0 g
s
.346 .656 .97 r
.72068 .79035 m .73114 .79137 L .73677 .79735 L p F P
0 g
s
0 .422 .713 r
.65746 .5525 m .65843 .55282 L .65999 .55324 L closepath p F P
0 g
s
0 .427 .688 r
.65843 .55282 m .65746 .5525 L .64443 .54901 L p F P
0 g
s
0 0 0 r
.26617 .62218 m .27119 .6185 L .26659 .6264 L p F P
0 g
s
0 0 0 r
.26659 .6264 m .25032 .6383 L .26617 .62218 L p F P
0 g
s
0 0 0 r
.27119 .6185 m .27313 .61616 L .26617 .62218 L closepath p F P
0 g
s
0 0 .058 r
.24885 .64017 m .25032 .6383 L .24932 .63905 L closepath p F P
0 g
s
0 0 0 r
.24932 .63905 m .24885 .64017 L .23999 .65263 L p F P
0 g
s
.323 0 0 r
.59464 .74353 m .61033 .74909 L .59409 .74546 L p F P
0 g
s
.323 0 0 r
.59409 .74546 m .58851 .74404 L .59464 .74353 L p F P
0 g
s
.554 0 0 r
.57545 .73906 m .58851 .74404 L .59464 .74353 L p F P
0 g
s
0 0 0 r
.27119 .6185 m .27313 .61616 L .28934 .60365 L p F P
0 g
s
.903 .846 .777 r
.83363 .75137 m .83858 .75785 L .8282 .77266 L p F P
0 g
s
.943 .836 .709 r
.83858 .75785 m .83363 .75137 L .84045 .73753 L p F P
0 g
s
0 .405 .686 r
.63716 .75782 m .65574 .76448 L .64455 .7595 L p F P
0 g
s
0 .405 .686 r
.62734 .75474 m .63716 .75782 L p .64455 .7595 L F P
0 g
s
.78 .278 0 r
.78595 .6217 m .77718 .6157 L .78407 .62518 L p F P
0 g
s
.78 .278 0 r
.78407 .62518 m .79282 .63118 L .78595 .6217 L p F P
0 g
s
0 0 0 r
.47577 .53662 m .492 .53528 L p .47877 .5369 L F P
0 g
s
0 0 0 r
.492 .53528 m .47577 .53662 L .49529 .53479 L closepath p F P
0 g
s
.274 0 0 r
.46529 .74305 m .46864 .7406 L .49604 .73691 L p F P
0 g
s
.266 0 0 r
.4961 .73688 m .49604 .73691 L .46864 .7406 L p F P
0 g
s
.043 .533 .883 r
.69412 .77875 m .67756 .77444 L .6672 .76934 L p F P
0 g
s
.047 .516 .889 r
.67756 .77444 m .69412 .77875 L .69988 .78386 L p F P
0 g
s
.503 .595 .878 r
.23332 .78577 m .22612 .77268 L p .2514 .77921 L F P
0 g
s
.503 .595 .878 r
.2514 .77921 m .24624 .78573 L .23332 .78577 L p F P
0 g
s
.428 .511 .842 r
.22426 .77218 m .22612 .77268 L .23332 .78577 L p F P
0 g
s
.011 0 .059 r
.25032 .6383 m .26659 .6264 L p .26179 .63609 L F P
0 g
s
.011 0 .059 r
.24885 .64017 m .25032 .6383 L p .26179 .63609 L F P
0 g
s
.328 0 0 r
.65999 .55324 m .67594 .55936 L .6611 .55487 L p F P
0 g
s
.328 0 0 r
.65746 .5525 m .65999 .55324 L p .6611 .55487 L F P
0 g
s
.588 .017 0 r
.73843 .58715 m .72746 .58165 L .73804 .58977 L p F P
0 g
s
.588 .017 0 r
.73804 .58977 m .7489 .59531 L .73843 .58715 L p F P
0 g
s
.011 0 .059 r
.26179 .63609 m .24554 .64788 L .24885 .64017 L p F P
0 g
s
0 0 .007 r
.24554 .64788 m .24885 .64017 L .23999 .65263 L closepath p F P
0 g
s
.977 .738 .51 r
.83964 .70601 m .83371 .69958 L .83239 .71183 L p F P
0 g
s
.977 .738 .51 r
.83239 .71183 m .83833 .71823 L .83964 .70601 L p F P
0 g
s
.15 0 0 r
.59067 .53825 m .60963 .5416 L .5898 .53862 L p F P
0 g
s
.15 0 0 r
.5898 .53862 m .58451 .53779 L .59067 .53825 L p F P
0 g
s
.155 0 0 r
.56563 .53549 m .58451 .53779 L .59067 .53825 L p F P
0 g
s
.779 .833 .894 r
.80852 .78998 m .79829 .79684 L .7929 .79067 L p F P
0 g
s
.679 .803 .942 r
.76775 .80024 m .7929 .79067 L .79829 .79684 L p F P
0 g
s
0 0 0 r
.28934 .60365 m .29533 .59991 L p .27119 .6185 L F P
0 g
s
0 0 0 r
.29533 .59991 m .29692 .59848 L .28934 .60365 L closepath p F P
0 g
s
.132 0 0 r
.56563 .53549 m .58451 .53779 L p .56769 .53636 L F P
0 g
s
.132 0 0 r
.55778 .53482 m .56563 .53549 L p .56769 .53636 L F P
0 g
s
.328 0 0 r
.6611 .55487 m .6527 .55182 L .65746 .5525 L p F P
0 g
s
.307 0 0 r
.6527 .55182 m .64443 .54901 L .65746 .5525 L closepath p F P
0 g
s
.851 .392 .052 r
.80098 .63729 m .79282 .63118 L .79817 .64121 L p F P
0 g
s
.851 .392 .052 r
.79817 .64121 m .80635 .64731 L .80098 .63729 L p F P
0 g
s
.104 0 .303 r
.22702 .67131 m .23318 .66587 L .22974 .67808 L p F P
0 g
s
.104 0 .303 r
.22974 .67808 m .22518 .68209 L .22702 .67131 L p F P
0 g
s
.345 .666 .974 r
.73114 .79137 m .72068 .79035 L .71314 .78457 L p F P
0 g
s
.47 0 0 r
.7027 .56911 m .68989 .56408 L .70296 .57127 L p F P
0 g
s
.47 0 0 r
.70296 .57127 m .71559 .57637 L .7027 .56911 L p F P
0 g
s
.909 .503 .158 r
.81768 .66411 m .8142 .65421 L .81467 .65415 L p F P
0 g
s
.909 .502 .158 r
.8142 .65421 m .81396 .65351 L .81467 .65415 L closepath p F P
0 g
s
.679 .798 .938 r
.78745 .7843 m .76222 .79402 L .76775 .80024 L p F P
0 g
s
.679 .798 .938 r
.76775 .80024 m .7929 .79067 L .78745 .7843 L p F P
0 g
s
0 0 0 r
.3441 .57314 m .35018 .56896 L .37299 .5605 L p F P
0 g
s
0 0 0 r
.37557 .55938 m .37299 .5605 L .35018 .56896 L p F P
0 g
s
0 0 0 r
.35018 .56896 m .3441 .57314 L .33311 .57823 L p F P
0 g
s
.132 0 0 r
.56769 .53636 m .55361 .53489 L .55778 .53482 L p F P
0 g
s
.081 0 0 r
.55361 .53489 m .54093 .53414 L .55778 .53482 L closepath p F P
0 g
s
.427 0 0 r
.57545 .73906 m .58851 .74404 L p .57581 .74238 L F P
0 g
s
.427 0 0 r
.55875 .73708 m .57545 .73906 L p .57581 .74238 L F P
0 g
s
.049 0 0 r
.49529 .53479 m .51209 .53414 L p .51451 .53471 L F P
0 g
s
.049 0 0 r
.51451 .53471 m .492 .53528 L .49529 .53479 L p F P
0 g
s
.969 .673 .411 r
.83322 .68792 m .82678 .68154 L .82726 .69323 L p F P
0 g
s
.969 .673 .411 r
.82726 .69323 m .83371 .69958 L .83322 .68792 L p F P
0 g
s
.385 .709 .986 r
.69988 .78386 m .71314 .78457 L .70458 .779 L p F P
0 g
s
.385 .709 .986 r
.70458 .779 m .69412 .77875 L .69988 .78386 L p F P
0 g
s
.779 .833 .894 r
.7929 .79067 m .80343 .78363 L .80852 .78998 L p F P
0 g
s
.808 .841 .875 r
.81751 .77268 m .80343 .78363 L .80852 .78998 L p F P
0 g
s
.808 .841 .875 r
.80852 .78998 m .82279 .77884 L .81751 .77268 L p F P
0 g
s
0 0 0 r
.29533 .59991 m .29692 .59848 L .32053 .58447 L p F P
0 g
s
0 0 0 r
.32167 .58335 m .32053 .58447 L .29692 .59848 L p F P
0 g
s
.597 .94 .94 r
.3719 .77133 m .3482 .78121 L .35576 .78262 L p F P
0 g
s
.597 .94 .94 r
.35576 .78262 m .37941 .77177 L .3719 .77133 L p F P
0 g
s
.656 .903 .981 r
.35576 .78262 m .3482 .78121 L .34758 .78146 L p F P
0 g
s
.288 .238 .626 r
.21126 .72164 m .21927 .713 L .22647 .72206 L p F P
0 g
s
.288 .238 .626 r
.21292 .73287 m .21126 .72164 L p .22647 .72206 L F P
0 g
s
.909 .503 .189 r
.8142 .65421 m .81396 .65351 L .80635 .64731 L p F P
0 g
s
.871 .847 .817 r
.8282 .77266 m .82279 .77884 L .81751 .77268 L p F P
0 g
s
.871 .847 .817 r
.81751 .77268 m .82317 .76624 L .8282 .77266 L p F P
0 g
s
.903 .846 .777 r
.8282 .77266 m .82317 .76624 L .83363 .75137 L p F P
0 g
s
.947 .595 .302 r
.82464 .67042 m .81768 .66411 L .81981 .67525 L p F P
0 g
s
.947 .595 .302 r
.81981 .67525 m .82678 .68154 L .82464 .67042 L p F P
0 g
s
.049 0 0 r
.51209 .53414 m .52279 .53404 L p .51451 .53471 L F P
0 g
s
.038 0 0 r
.52279 .53404 m .51209 .53414 L .52562 .53377 L closepath p F P
0 g
s
.098 0 0 r
.54093 .53414 m .55361 .53489 L p .54307 .53489 L F P
0 g
s
.098 0 0 r
.52562 .53377 m .54093 .53414 L p .54307 .53489 L F P
0 g
s
.906 .496 .178 r
.8142 .65421 m .81768 .66411 L .81017 .65789 L p F P
0 g
s
.906 .496 .178 r
.81017 .65789 m .80969 .65657 L .8142 .65421 L p F P
0 g
s
.909 .503 .189 r
.80635 .64731 m .80969 .65657 L .8142 .65421 L p F P
0 g
s
.098 0 0 r
.54307 .53489 m .52279 .53404 L .52562 .53377 L p F P
0 g
s
.404 .47 .814 r
.22612 .77268 m .22426 .77218 L .22522 .77078 L closepath p F P
0 g
s
.287 .782 .744 r
.40405 .76177 m .40321 .76206 L .41055 .7603 L p F P
0 g
s
.495 .906 .866 r
.41055 .7603 m .40321 .76206 L .38227 .77136 L p F P
0 g
s
.024 0 .174 r
.23999 .65263 m .24554 .64788 L .24276 .65771 L p F P
0 g
s
.024 0 .174 r
.24276 .65771 m .23318 .66587 L .23999 .65263 L p F P
0 g
s
.004 0 0 r
.27119 .6185 m .28994 .60685 L p .27671 .62015 L F P
0 g
s
.004 0 0 r
.27671 .62015 m .26659 .6264 L .27119 .6185 L p F P
0 g
s
0 0 0 r
.29533 .59991 m .28994 .60685 L .27119 .6185 L p F P
0 g
s
.972 .789 .599 r
.83833 .71823 m .83523 .73027 L .84051 .73735 L p F P
0 g
s
.962 .801 .637 r
.84051 .73735 m .84045 .73753 L .83496 .7311 L p F P
0 g
s
.962 .801 .637 r
.83496 .7311 m .83523 .73027 L .84051 .73735 L p F P
0 g
s
.935 .821 .709 r
.84045 .73753 m .83496 .7311 L .8281 .74498 L p F P
0 g
s
.935 .821 .709 r
.8281 .74498 m .83363 .75137 L .84045 .73753 L p F P
0 g
s
.341 .37 .746 r
.21921 .75613 m .2161 .75451 L .21782 .75215 L closepath p F P
0 g
s
.36 .409 .777 r
.2161 .75451 m .21921 .75613 L .22522 .77078 L p F P
0 g
s
.1 .588 .906 r
.65853 .76591 m .66279 .76852 L .6672 .76934 L closepath p F P
0 g
s
0 .41 .784 r
.65574 .76448 m .65853 .76591 L .66279 .76852 L p F P
0 g
s
.672 .123 0 r
.7591 .601 m .7489 .59531 L .75772 .60409 L p F P
0 g
s
.672 .123 0 r
.7648 .60679 m .7591 .601 L p .75772 .60409 L F P
0 g
s
.444 .88 .845 r
.37941 .77177 m .38227 .77136 L .40321 .76206 L p F P
0 g
s
0 0 0 r
.40505 .54974 m .42539 .54502 L p .42177 .54744 L F P
0 g
s
0 0 0 r
.42177 .54744 m .39914 .55241 L .40505 .54974 L p F P
0 g
s
0 0 0 r
.40505 .54974 m .39914 .55241 L .37557 .55938 L p F P
0 g
s
.381 0 0 r
.52581 .73542 m .52683 .73493 L .53 .73551 L closepath p F P
0 g
s
.357 0 0 r
.52683 .73493 m .52581 .73542 L .49637 .73689 L p F P
0 g
s
.427 0 0 r
.57581 .74238 m .55759 .7376 L .55875 .73708 L p F P
0 g
s
.455 0 0 r
.55759 .7376 m .55471 .73672 L .55875 .73708 L closepath p F P
0 g
s
.294 0 0 r
.49604 .73691 m .4961 .73688 L .49637 .73689 L closepath p F P
0 g
s
.447 .494 .815 r
.24102 .76147 m .24828 .7745 L .22612 .77268 L p F P
0 g
s
.447 .494 .815 r
.23427 .7604 m .24102 .76147 L p .22612 .77268 L F P
0 g
s
.447 .494 .815 r
.22612 .77268 m .22522 .77078 L .23427 .7604 L p F P
0 g
s
.503 .595 .878 r
.22612 .77268 m .24828 .7745 L .2514 .77921 L p F P
0 g
s
.208 .109 .515 r
.21594 .70283 m .22451 .69395 L .22512 .70698 L p F P
0 g
s
.208 .109 .515 r
.22512 .70698 m .21927 .713 L .21594 .70283 L p F P
0 g
s
.238 0 0 r
.49604 .73691 m .49637 .73689 L p .49477 .74056 L F P
0 g
s
.238 0 0 r
.49477 .74056 m .48928 .74066 L .49604 .73691 L p F P
0 g
s
.274 0 0 r
.49604 .73691 m .48928 .74066 L .46529 .74305 L p F P
0 g
s
.238 0 0 r
.49637 .73689 m .52024 .73824 L p .49477 .74056 L F P
0 g
s
.284 0 0 r
.52024 .73824 m .49637 .73689 L .52581 .73542 L closepath p F P
0 g
s
0 0 0 r
.32053 .58447 m .33311 .57823 L .32167 .58335 L closepath p F P
0 g
s
.487 0 0 r
.55759 .7376 m .55471 .73672 L .53 .73551 L p F P
0 g
s
.414 .445 .784 r
.23427 .7604 m .22522 .77078 L .21921 .75613 L closepath p F P
0 g
s
.291 0 0 r
.64443 .54901 m .62779 .54508 L .64523 .55066 L p F P
0 g
s
.291 0 0 r
.6527 .55182 m .64443 .54901 L p .64523 .55066 L F P
0 g
s
.288 .238 .626 r
.22647 .72206 m .21459 .73476 L .21292 .73287 L p F P
0 g
s
.278 .236 .63 r
.21459 .73476 m .21348 .73601 L .21292 .73287 L closepath p F P
0 g
s
.172 0 0 r
.61836 .54312 m .62156 .5437 L .62779 .54508 L closepath p F P
0 g
s
.161 0 0 r
.62156 .5437 m .61836 .54312 L .60963 .5416 L p F P
0 g
s
0 0 0 r
.29533 .59991 m .31549 .58928 L p .30066 .60123 L F P
0 g
s
0 0 0 r
.30066 .60123 m .28994 .60685 L .29533 .59991 L p F P
0 g
s
0 0 0 r
.32053 .58447 m .31549 .58928 L .29533 .59991 L p F P
0 g
s
.344 .33 .7 r
.21348 .73601 m .21459 .73476 L .22663 .74241 L p F P
0 g
s
.344 .33 .7 r
.22663 .74241 m .21782 .75215 L .21348 .73601 L p F P
0 g
s
.595 .731 .939 r
.27857 .78158 m .25568 .78528 L .26317 .79432 L p F P
0 g
s
.595 .731 .939 r
.26317 .79432 m .28613 .78917 L .27857 .78158 L p F P
0 g
s
.656 .905 .981 r
.34061 .77848 m .31705 .78735 L .32465 .79118 L p F P
0 g
s
.656 .905 .981 r
.34802 .78114 m .34061 .77848 L p .32465 .79118 L F P
0 g
s
.656 .905 .981 r
.32465 .79118 m .34758 .78146 L .34802 .78114 L p F P
0 g
s
.442 0 0 r
.72658 .58124 m .72699 .58138 L .72746 .58165 L closepath p F P
0 g
s
.414 0 0 r
.71559 .57637 m .72658 .58124 L .72699 .58138 L p F P
0 g
s
.315 0 0 r
.53 .73551 m .55121 .73957 L p .52906 .73907 L F P
0 g
s
.315 0 0 r
.52581 .73542 m .53 .73551 L p .52906 .73907 L F P
0 g
s
.487 0 0 r
.53 .73551 m .55121 .73957 L .55759 .7376 L p F P
0 g
s
0 0 0 r
.37299 .5605 m .37557 .55938 L .39914 .55241 L p F P
0 g
s
.315 0 0 r
.52906 .73907 m .52024 .73824 L .52581 .73542 L p F P
0 g
s
.963 .776 .603 r
.83523 .73027 m .83833 .71823 L .83239 .71183 L p F P
0 g
s
0 .483 .743 r
.62567 .75427 m .64455 .7595 L .63155 .75497 L p F P
0 g
s
.591 .017 0 r
.72746 .58165 m .73804 .58977 L .72648 .58437 L p F P
0 g
s
.591 .017 0 r
.72658 .58124 m .72746 .58165 L p .72648 .58437 L F P
0 g
s
.417 .443 .78 r
.21921 .75613 m .21782 .75215 L p .23838 .75587 L F P
0 g
s
.417 .443 .78 r
.23838 .75587 m .23427 .7604 L .21921 .75613 L p F P
0 g
s
.1 .587 .905 r
.6672 .76934 m .68832 .77381 L p .65692 .76493 L F P
0 g
s
.1 .587 .905 r
.65692 .76493 m .65853 .76591 L .6672 .76934 L p F P
0 g
s
.043 .533 .883 r
.6672 .76934 m .68832 .77381 L .69412 .77875 L p F P
0 g
s
.787 .287 0 r
.77718 .6157 m .7678 .60982 L .77473 .61929 L p F P
0 g
s
.787 .287 0 r
.77473 .61929 m .78407 .62518 L .77718 .6157 L p F P
0 g
s
.311 0 0 r
.55759 .7376 m .57581 .74238 L .55459 .74011 L p F P
0 g
s
.311 0 0 r
.55459 .74011 m .55121 .73957 L .55759 .7376 L p F P
0 g
s
.417 .443 .78 r
.21782 .75215 m .22663 .74241 L p .23838 .75587 L F P
0 g
s
.126 0 0 r
.46084 .74509 m .46529 .74305 L .48928 .74066 L p F P
0 g
s
.016 0 0 r
.46529 .74305 m .46084 .74509 L .43596 .75119 L p F P
0 g
s
0 0 0 r
.31549 .58928 m .32053 .58447 L .33311 .57823 L p F P
0 g
s
.591 .017 0 r
.72648 .58437 m .72169 .58083 L .72658 .58124 L p F P
0 g
s
.588 .013 0 r
.72169 .58083 m .71559 .57637 L .72658 .58124 L closepath p F P
0 g
s
.313 0 0 r
.68966 .56399 m .68975 .56402 L .68989 .56408 L closepath p F P
0 g
s
.276 0 0 r
.67594 .55936 m .68966 .56399 L .68975 .56402 L p F P
0 g
s
.472 0 0 r
.68989 .56408 m .70296 .57127 L .68953 .56636 L p F P
0 g
s
.472 0 0 r
.68966 .56399 m .68989 .56408 L p .68953 .56636 L F P
0 g
s
.35 .329 .695 r
.21459 .73476 m .22647 .72206 L p .23136 .7374 L F P
0 g
s
.35 .329 .695 r
.23136 .7374 m .22663 .74241 L .21459 .73476 L p F P
0 g
s
.553 .749 .968 r
.75102 .7814 m .72546 .78549 L .73114 .79137 L p F P
0 g
s
.553 .749 .968 r
.73114 .79137 m .75664 .78774 L .75102 .7814 L p F P
0 g
s
.345 .666 .974 r
.71314 .78457 m .72546 .78549 L .73114 .79137 L p F P
0 g
s
.472 0 0 r
.68953 .56636 m .68422 .56358 L .68966 .56399 L p F P
0 g
s
.461 0 0 r
.68422 .56358 m .67594 .55936 L .68966 .56399 L closepath p F P
0 g
s
.521 .62 .891 r
.25568 .78528 m .24624 .78573 L .2514 .77921 L closepath p F P
0 g
s
.645 .828 .971 r
.30944 .7823 m .28613 .78917 L .29372 .79544 L p F P
0 g
s
.645 .828 .971 r
.29372 .79544 m .31705 .78735 L .30944 .7823 L p F P
0 g
s
.898 .833 .774 r
.83363 .75137 m .8281 .74498 L .81761 .7599 L p F P
0 g
s
.898 .833 .774 r
.81761 .7599 m .82317 .76624 L .83363 .75137 L p F P
0 g
s
.127 0 .315 r
.23318 .66587 m .24276 .65771 L .241 .66855 L p F P
0 g
s
.127 0 .315 r
.241 .66855 m .22974 .67808 L .23318 .66587 L p F P
0 g
s
.018 0 0 r
.43432 .75205 m .43596 .75119 L .46084 .74509 L p F P
0 g
s
.047 0 0 r
.48639 .53611 m .492 .53528 L .51451 .53471 L closepath p F P
0 g
s
0 0 0 r
.492 .53528 m .48639 .53611 L .47877 .5369 L p F P
0 g
s
.967 .726 .519 r
.83371 .69958 m .82726 .69323 L .82592 .70551 L p F P
0 g
s
.967 .726 .519 r
.82592 .70551 m .83239 .71183 L .83371 .69958 L p F P
0 g
s
.854 .398 .087 r
.79282 .63118 m .78407 .62518 L .78942 .63522 L p F P
0 g
s
.854 .398 .087 r
.78942 .63522 m .79817 .64121 L .79282 .63118 L p F P
0 g
s
.099 0 0 r
.51658 .53463 m .52279 .53404 L .54307 .53489 L closepath p F P
0 g
s
.049 0 0 r
.52279 .53404 m .51658 .53463 L .51451 .53471 L p F P
0 g
s
.505 .908 .901 r
.39576 .76227 m .3719 .77133 L .37941 .77177 L p F P
0 g
s
.505 .908 .901 r
.37941 .77177 m .40317 .76206 L .39576 .76227 L p F P
0 g
s
.444 .88 .845 r
.40321 .76206 m .40317 .76206 L .37941 .77177 L p F P
0 g
s
.777 .826 .891 r
.79777 .77737 m .78745 .7843 L .7929 .79067 L p F P
0 g
s
.777 .826 .891 r
.7929 .79067 m .80343 .78363 L .79777 .77737 L p F P
0 g
s
.198 .041 .43 r
.22518 .68209 m .22974 .67808 L .22995 .6892 L p F P
0 g
s
.198 .041 .43 r
.22995 .6892 m .22451 .69395 L .22518 .68209 L p F P
0 g
s
.35 .681 .979 r
.72546 .78549 m .71314 .78457 L .70458 .779 L p F P
0 g
s
.119 0 .216 r
.24554 .64788 m .26179 .63609 L .25362 .64986 L p F P
0 g
s
.119 0 .216 r
.25362 .64986 m .24276 .65771 L .24554 .64788 L p F P
0 g
s
0 0 0 r
.45778 .53923 m .46118 .5386 L .47877 .5369 L closepath p F P
0 g
s
.332 0 0 r
.62779 .54508 m .64523 .55066 L .62783 .54689 L p F P
0 g
s
.332 0 0 r
.61836 .54312 m .62779 .54508 L p .62783 .54689 L F P
0 g
s
0 0 0 r
.42539 .54502 m .43026 .54399 L p .42177 .54744 L F P
0 g
s
0 0 0 r
.43026 .54399 m .42539 .54502 L .43067 .5438 L closepath p F P
0 g
s
.96 .664 .425 r
.82678 .68154 m .81981 .67525 L .82028 .68696 L p F P
0 g
s
.96 .664 .425 r
.82028 .68696 m .82726 .69323 L .82678 .68154 L p F P
0 g
s
.899 .487 .193 r
.80635 .64731 m .79817 .64121 L .80198 .6518 L p F P
0 g
s
.899 .487 .193 r
.80969 .65657 m .80635 .64731 L p .80198 .6518 L F P
0 g
s
.681 .794 .934 r
.78195 .77772 m .75664 .78774 L .76222 .79402 L p F P
0 g
s
.681 .794 .934 r
.76222 .79402 m .78745 .7843 L .78195 .77772 L p F P
0 g
s
.941 .59 .322 r
.81768 .66411 m .81017 .65789 L .8123 .66905 L p F P
0 g
s
.941 .59 .322 r
.8123 .66905 m .81981 .67525 L .81768 .66411 L p F P
0 g
s
.136 0 0 r
.54847 .53503 m .55361 .53489 L .56769 .53636 L closepath p F P
0 g
s
.098 0 0 r
.55361 .53489 m .54847 .53503 L .54307 .53489 L p F P
0 g
s
.805 .83 .87 r
.81751 .77268 m .80343 .78363 L .79777 .77737 L p F P
0 g
s
.689 .146 0 r
.7617 .60631 m .7648 .60679 L .7678 .60982 L closepath p F P
0 g
s
.672 .123 0 r
.75772 .60409 m .7617 .60631 L .7648 .60679 L p F P
0 g
s
0 0 0 r
.33311 .57823 m .34316 .57376 L p .31549 .58928 L F P
0 g
s
0 0 0 r
.34316 .57376 m .3441 .57314 L .33311 .57823 L closepath p F P
0 g
s
.7 .159 0 r
.7489 .59531 m .73804 .58977 L .7469 .59853 L p F P
0 g
s
.7 .159 0 r
.7469 .59853 m .75772 .60409 L .7489 .59531 L p F P
0 g
s
.867 .836 .814 r
.81751 .77268 m .82317 .76624 L .81761 .7599 L p F P
0 g
s
.408 0 0 r
.61965 .75259 m .61033 .74909 L .59409 .74546 L p F P
0 g
s
.081 0 0 r
.43026 .54399 m .43067 .5438 L .45778 .53923 L p F P
0 g
s
.406 .73 .99 r
.69412 .77875 m .70458 .779 L .69468 .77374 L p F P
0 g
s
.406 .73 .99 r
.69468 .77374 m .68832 .77381 L .69412 .77875 L p F P
0 g
s
0 .409 .783 r
.65692 .76493 m .65574 .76448 L .65853 .76591 L closepath p F P
0 g
s
.339 0 0 r
.64782 .55128 m .6527 .55182 L .6611 .55487 L closepath p F P
0 g
s
.291 0 0 r
.64523 .55066 m .64782 .55128 L .6527 .55182 L p F P
0 g
s
.038 0 0 r
.36771 .56422 m .37299 .5605 L .39727 .55322 L p F P
0 g
s
0 0 0 r
.39914 .55241 m .39727 .55322 L .37299 .5605 L p F P
0 g
s
0 0 0 r
.37299 .5605 m .36771 .56422 L .3441 .57314 L p F P
0 g
s
.867 .836 .814 r
.81761 .7599 m .81215 .76612 L .81751 .77268 L p F P
0 g
s
.805 .83 .87 r
.79777 .77737 m .81215 .76612 L .81751 .77268 L p F P
0 g
s
.963 .776 .603 r
.83239 .71183 m .8298 .72195 L .83523 .73027 L p F P
0 g
s
.952 .785 .638 r
.83523 .73027 m .83496 .7311 L .82889 .72476 L p F P
0 g
s
.952 .785 .638 r
.82889 .72476 m .8298 .72195 L .83523 .73027 L p F P
0 g
s
.332 0 0 r
.62783 .54689 m .61559 .5432 L .61836 .54312 L p F P
0 g
s
.303 0 0 r
.61559 .5432 m .60963 .5416 L .61836 .54312 L closepath p F P
0 g
s
.298 0 0 r
.58569 .74408 m .58851 .74404 L .59409 .74546 L closepath p F P
0 g
s
.427 0 0 r
.58851 .74404 m .58569 .74408 L .57581 .74238 L p F P
0 g
s
.067 0 0 r
.42298 .54715 m .43026 .54399 L .45408 .54079 L p F P
0 g
s
.081 0 0 r
.45778 .53923 m .45408 .54079 L .43026 .54399 L p F P
0 g
s
0 0 0 r
.43026 .54399 m .42298 .54715 L .42177 .54744 L p F P
0 g
s
.927 .806 .708 r
.83496 .7311 m .82889 .72476 L .82201 .73868 L p F P
0 g
s
.927 .806 .708 r
.82201 .73868 m .8281 .74498 L .83496 .7311 L p F P
0 g
s
.446 0 0 r
.67594 .55936 m .6611 .55487 L .67511 .56171 L p F P
0 g
s
.446 0 0 r
.68422 .56358 m .67594 .55936 L p .67511 .56171 L F P
0 g
s
.545 .631 .888 r
.27106 .77247 m .27857 .78158 L .25568 .78528 L p F P
0 g
s
.545 .631 .888 r
.25688 .7739 m .27106 .77247 L p .25568 .78528 L F P
0 g
s
.545 .631 .888 r
.25568 .78528 m .2514 .77921 L .25688 .7739 L p F P
0 g
s
.575 0 0 r
.71559 .57637 m .70296 .57127 L .71411 .57918 L p F P
0 g
s
.575 0 0 r
.72169 .58083 m .71559 .57637 L p .71411 .57918 L F P
0 g
s
0 .379 .733 r
.65692 .76493 m .65574 .76448 L .64455 .7595 L p F P
0 g
s
.286 .222 .608 r
.21927 .713 m .22512 .70698 L .22721 .72131 L p F P
0 g
s
.286 .222 .608 r
.22721 .72131 m .22647 .72206 L .21927 .713 L p F P
0 g
s
.656 .903 .981 r
.34802 .78114 m .3482 .78121 L .34758 .78146 L closepath p F P
0 g
s
.158 0 0 r
.58227 .53766 m .58451 .53779 L .5898 .53862 L closepath p F P
0 g
s
.132 0 0 r
.58451 .53779 m .58227 .53766 L .56769 .53636 L p F P
0 g
s
.283 0 0 r
.60963 .5416 m .5898 .53862 L .60933 .54344 L p F P
0 g
s
.283 0 0 r
.61559 .5432 m .60963 .5416 L p .60933 .54344 L F P
0 g
s
.652 .903 .982 r
.34802 .78114 m .3482 .78121 L .3719 .77133 L p F P
0 g
s
.632 .9 .985 r
.34061 .77848 m .34802 .78114 L .36684 .77009 L p F P
0 g
s
.652 .903 .982 r
.3719 .77133 m .36684 .77009 L .34802 .78114 L p F P
0 g
s
.786 .287 0 r
.7678 .60982 m .77473 .61929 L .76477 .61353 L p F P
0 g
s
.786 .287 0 r
.7617 .60631 m .7678 .60982 L p .76477 .61353 L F P
0 g
s
.187 .653 .938 r
.65692 .76493 m .68246 .76898 L p .67269 .76366 L F P
0 g
s
.187 .653 .938 r
.67269 .76366 m .65099 .76144 L .65692 .76493 L p F P
0 g
s
.1 .587 .905 r
.68832 .77381 m .68246 .76898 L .65692 .76493 L p F P
0 g
s
0 .379 .733 r
.64455 .7595 m .65099 .76144 L .65692 .76493 L p F P
0 g
s
0 0 0 r
.34316 .57376 m .3441 .57314 L .36771 .56422 L p F P
0 g
s
.214 .053 .434 r
.22974 .67808 m .241 .66855 L .24036 .68045 L p F P
0 g
s
.214 .053 .434 r
.24036 .68045 m .22995 .6892 L .22974 .67808 L p F P
0 g
s
.114 0 .116 r
.26339 .63416 m .27671 .62015 L .26659 .6264 L closepath p F P
0 g
s
.011 0 .059 r
.26659 .6264 m .26339 .63416 L .26179 .63609 L p F P
0 g
s
.954 .762 .604 r
.8298 .72195 m .83239 .71183 L .82592 .70551 L p F P
0 g
s
.408 0 0 r
.59409 .74546 m .61356 .75082 L .61965 .75259 L p F P
0 g
s
.179 0 0 r
.60003 .74733 m .58141 .74427 L p .60099 .74766 L F P
0 g
s
.223 0 0 r
.59616 .74603 m .61356 .75082 L p .60003 .74733 L F P
0 g
s
.223 0 0 r
.61356 .75082 m .6122 .75036 L .60003 .74733 L p F P
0 g
s
0 .506 .778 r
.60739 .74877 m .60003 .74733 L .6122 .75036 L closepath p F P
0 g
s
.179 0 0 r
.60739 .74877 m .60003 .74733 L p .60099 .74766 L F P
0 g
s
.223 0 0 r
.59409 .74546 m .59616 .74603 L p .60003 .74733 L F P
0 g
s
.223 0 0 r
.58569 .74408 m .59409 .74546 L p .60003 .74733 L F P
0 g
s
.277 .16 .534 r
.22451 .69395 m .22995 .6892 L .23419 .69914 L p F P
0 g
s
.277 .16 .534 r
.23419 .69914 m .22512 .70698 L .22451 .69395 L p F P
0 g
s
.072 0 0 r
.33714 .57971 m .34316 .57376 L .36613 .56529 L p F P
0 g
s
0 0 0 r
.36771 .56422 m .36613 .56529 L .34316 .57376 L p F P
0 g
s
0 0 0 r
.34316 .57376 m .33714 .57971 L .31549 .58928 L p F P
0 g
s
.853 .401 .118 r
.78407 .62518 m .77473 .61929 L .78008 .62934 L p F P
0 g
s
.853 .401 .118 r
.78008 .62934 m .78942 .63522 L .78407 .62518 L p F P
0 g
s
.563 .752 .966 r
.74534 .77497 m .71974 .77967 L .72546 .78549 L p F P
0 g
s
.563 .752 .966 r
.72546 .78549 m .75102 .7814 L .74534 .77497 L p F P
0 g
s
.35 .681 .979 r
.70458 .779 m .71974 .77967 L .72546 .78549 L p F P
0 g
s
.131 0 0 r
.45824 .74634 m .46084 .74509 L .48808 .74103 L p F P
0 g
s
.126 0 0 r
.48928 .74066 m .48808 .74103 L .46084 .74509 L p F P
0 g
s
0 0 0 r
.39727 .55322 m .39914 .55241 L .42177 .54744 L closepath p F P
0 g
s
.649 .865 .981 r
.33302 .77445 m .30944 .7823 L .31705 .78735 L p F P
0 g
s
.649 .865 .981 r
.31705 .78735 m .34061 .77848 L .33302 .77445 L p F P
0 g
s
.625 .781 .956 r
.30185 .77591 m .27857 .78158 L .28613 .78917 L p F P
0 g
s
.625 .781 .956 r
.28613 .78917 m .30944 .7823 L .30185 .77591 L p F P
0 g
s
.131 0 0 r
.45778 .53923 m .47877 .5369 L p .47511 .53942 L F P
0 g
s
.131 0 0 r
.47511 .53942 m .45408 .54079 L .45778 .53923 L p F P
0 g
s
.892 .821 .771 r
.8281 .74498 m .82201 .73868 L .81152 .75364 L p F P
0 g
s
.892 .821 .771 r
.81152 .75364 m .81761 .7599 L .8281 .74498 L p F P
0 g
s
.534 .612 .877 r
.25688 .7739 m .2514 .77921 L .24828 .7745 L closepath p F P
0 g
s
.273 .771 .728 r
.40317 .76206 m .40405 .76177 L .40321 .76206 L closepath p F P
0 g
s
.416 .864 .876 r
.41976 .75448 m .39576 .76227 L .40317 .76206 L p F P
0 g
s
.416 .864 .876 r
.42602 .75411 m .41976 .75448 L p .40317 .76206 L F P
0 g
s
.416 .864 .876 r
.40317 .76206 m .40405 .76177 L .42602 .75411 L p F P
0 g
s
.362 .7 .984 r
.71974 .77967 m .70458 .779 L .69468 .77374 L p F P
0 g
s
.958 .714 .526 r
.82726 .69323 m .82028 .68696 L .81892 .69926 L p F P
0 g
s
.958 .714 .526 r
.81892 .69926 m .82592 .70551 L .82726 .69323 L p F P
0 g
s
.412 .862 .873 r
.42602 .75411 m .42707 .75407 L .40405 .76177 L closepath p F P
0 g
s
.904 .497 .2 r
.80911 .65708 m .80969 .65657 L .81017 .65789 L closepath p F P
0 g
s
.899 .487 .193 r
.80198 .6518 m .80911 .65708 L .80969 .65657 L p F P
0 g
s
.31 0 0 r
.5898 .53862 m .60933 .54344 L .58862 .54066 L p F P
0 g
s
.31 0 0 r
.58227 .53766 m .5898 .53862 L p .58862 .54066 L F P
0 g
s
.707 .17 0 r
.73804 .58977 m .72648 .58437 L .73541 .59311 L p F P
0 g
s
.707 .17 0 r
.73541 .59311 m .7469 .59853 L .73804 .58977 L p F P
0 g
s
.898 .494 .233 r
.79817 .64121 m .78942 .63522 L .7932 .64583 L p F P
0 g
s
.898 .494 .233 r
.7932 .64583 m .80198 .6518 L .79817 .64121 L p F P
0 g
s
.114 0 .02 r
.2879 .61055 m .30066 .60123 L .28994 .60685 L closepath p F P
0 g
s
.004 0 0 r
.28994 .60685 m .2879 .61055 L .27671 .62015 L p F P
0 g
s
.777 .82 .887 r
.79154 .7712 m .78195 .77772 L .78745 .7843 L p F P
0 g
s
.777 .82 .887 r
.78745 .7843 m .79777 .77737 L .79154 .7712 L p F P
0 g
s
.223 0 0 r
.60003 .74733 m .58229 .74417 L .58569 .74408 L p F P
0 g
s
.321 0 0 r
.58229 .74417 m .57581 .74238 L .58569 .74408 L closepath p F P
0 g
s
.951 .654 .437 r
.81981 .67525 m .8123 .66905 L .81275 .68078 L p F P
0 g
s
.951 .654 .437 r
.81275 .68078 m .82028 .68696 L .81981 .67525 L p F P
0 g
s
.099 0 0 r
.31189 .59411 m .31549 .58928 L .33714 .57971 L p F P
0 g
s
0 0 0 r
.31549 .58928 m .31189 .59411 L .30066 .60123 L p F P
0 g
s
.338 0 0 r
.60966 .54349 m .61559 .5432 L .62783 .54689 L closepath p F P
0 g
s
.283 0 0 r
.60933 .54344 m .60966 .54349 L .61559 .5432 L p F P
0 g
s
.933 .583 .339 r
.81017 .65789 m .80911 .65708 L .80788 .66569 L p F P
0 g
s
.933 .583 .339 r
.80788 .66569 m .8123 .66905 L .81017 .65789 L p F P
0 g
s
.006 .567 .807 r
.61965 .75259 m .63155 .75497 L .61599 .75112 L p F P
0 g
s
.006 .567 .807 r
.61599 .75112 m .61356 .75082 L .61965 .75259 L p F P
0 g
s
.485 0 0 r
.6611 .55487 m .67511 .56171 L .65955 .55737 L p F P
0 g
s
.485 0 0 r
.64782 .55128 m .6611 .55487 L p .65955 .55737 L F P
0 g
s
.786 .287 0 r
.76477 .61353 m .75977 .60683 L .7617 .60631 L p F P
0 g
s
.786 .287 0 r
.75977 .60683 m .75772 .60409 L .7617 .60631 L closepath p F P
0 g
s
.31 0 0 r
.58862 .54066 m .57829 .53832 L .58227 .53766 L p F P
0 g
s
.273 0 0 r
.57829 .53832 m .56769 .53636 L .58227 .53766 L closepath p F P
0 g
s
.208 0 .347 r
.24276 .65771 m .25362 .64986 L .24967 .66232 L p F P
0 g
s
.208 0 .347 r
.24967 .66232 m .241 .66855 L .24276 .65771 L p F P
0 g
s
.685 .79 .929 r
.77638 .77092 m .75102 .7814 L .75664 .78774 L p F P
0 g
s
.685 .79 .929 r
.75664 .78774 m .78195 .77772 L .77638 .77092 L p F P
0 g
s
.452 .496 .814 r
.24102 .76147 m .23427 .7604 L .23838 .75587 L closepath p F P
0 g
s
.25 0 0 r
.51758 .73902 m .52024 .73824 L .52906 .73907 L closepath p F P
0 g
s
.238 0 0 r
.52024 .73824 m .51758 .73902 L .49477 .74056 L p F P
0 g
s
.534 .609 .874 r
.24828 .7745 m .24102 .76147 L p .26607 .76528 L F P
0 g
s
.534 .609 .874 r
.26607 .76528 m .25688 .7739 L .24828 .7745 L p F P
0 g
s
.804 .819 .863 r
.81215 .76612 m .79777 .77737 L .79154 .7712 L p F P
0 g
s
.604 .035 0 r
.70296 .57127 m .68953 .56636 L .7008 .57422 L p F P
0 g
s
.604 .035 0 r
.7008 .57422 m .71411 .57918 L .70296 .57127 L p F P
0 g
s
.131 0 0 r
.47877 .5369 m .48515 .5366 L p .47511 .53942 L F P
0 g
s
.132 0 0 r
.48515 .5366 m .47877 .5369 L .48639 .53611 L closepath p F P
0 g
s
.929 .577 .34 r
.80911 .65708 m .80198 .6518 L .80416 .66296 L p F P
0 g
s
.929 .577 .34 r
.80416 .66296 m .80788 .66569 L .80911 .65708 L p F P
0 g
s
.6 .028 0 r
.718 .58075 m .72169 .58083 L .72648 .58437 L closepath p F P
0 g
s
.575 0 0 r
.71411 .57918 m .718 .58075 L .72169 .58083 L p F P
0 g
s
.143 0 0 r
.48808 .74103 m .48928 .74066 L .49477 .74056 L closepath p F P
0 g
s
.954 .762 .604 r
.82592 .70551 m .82422 .7123 L .8298 .72195 L p F P
0 g
s
.943 .768 .635 r
.8298 .72195 m .82889 .72476 L .82223 .71851 L p F P
0 g
s
.943 .768 .635 r
.82223 .71851 m .82422 .7123 L .8298 .72195 L p F P
0 g
s
.863 .825 .81 r
.81215 .76612 m .81761 .7599 L .81152 .75364 L p F P
0 g
s
.287 0 0 r
.56769 .53636 m .57829 .53832 L p .56605 .53846 L F P
0 g
s
.287 0 0 r
.54847 .53503 m .56769 .53636 L p .56605 .53846 L F P
0 g
s
.399 .404 .749 r
.23402 .74516 m .22663 .74241 L .23136 .7374 L closepath p F P
0 g
s
.417 .443 .78 r
.22663 .74241 m .23402 .74516 L .23838 .75587 L p F P
0 g
s
.401 0 0 r
.58229 .74417 m .57581 .74238 L .55459 .74011 L p F P
0 g
s
0 .422 .737 r
.65099 .76144 m .64455 .7595 L .63155 .75497 L p F P
0 g
s
.216 0 0 r
.48515 .5366 m .48639 .53611 L .51451 .53471 L p F P
0 g
s
.863 .825 .81 r
.81152 .75364 m .80672 .75915 L .81215 .76612 L p F P
0 g
s
.804 .819 .863 r
.79154 .7712 m .80672 .75915 L .81215 .76612 L p F P
0 g
s
.116 0 0 r
.39727 .55322 m .42177 .54744 L p .40253 .55508 L F P
0 g
s
.116 0 0 r
.40253 .55508 m .39143 .55734 L .39727 .55322 L p F P
0 g
s
.038 0 0 r
.39727 .55322 m .39143 .55734 L .36771 .56422 L p F P
0 g
s
.481 0 0 r
.68079 .56346 m .68422 .56358 L .68953 .56636 L closepath p F P
0 g
s
.446 0 0 r
.67511 .56171 m .68079 .56346 L .68422 .56358 L p F P
0 g
s
.918 .792 .706 r
.82889 .72476 m .82223 .71851 L .81535 .73247 L p F P
0 g
s
.918 .792 .706 r
.81535 .73247 m .82201 .73868 L .82889 .72476 L p F P
0 g
s
.436 .751 .994 r
.68832 .77381 m .69468 .77374 L .68283 .76896 L p F P
0 g
s
.436 .751 .994 r
.68283 .76896 m .68246 .76898 L .68832 .77381 L p F P
0 g
s
.258 0 0 r
.54991 .73977 m .55121 .73957 L .55459 .74011 L closepath p F P
0 g
s
.315 0 0 r
.55121 .73957 m .54991 .73977 L .52906 .73907 L p F P
0 g
s
.775 .273 .002 r
.75772 .60409 m .7469 .59853 L .75415 .6079 L p F P
0 g
s
.775 .273 .002 r
.75977 .60683 m .75772 .60409 L p .75415 .6079 L F P
0 g
s
.593 .912 .978 r
.36684 .77009 m .3719 .77133 L .39576 .76227 L p F P
0 g
s
.344 .263 .619 r
.22721 .72131 m .22512 .70698 L .23419 .69914 L p F P
0 g
s
.287 0 0 r
.56605 .53846 m .54718 .53536 L .54847 .53503 L p F P
0 g
s
.241 0 0 r
.54718 .53536 m .54307 .53489 L .54847 .53503 L closepath p F P
0 g
s
.27 0 0 r
.54307 .53489 m .54718 .53536 L p .51616 .53477 L F P
0 g
s
.27 0 0 r
.51616 .53477 m .51658 .53463 L .54307 .53489 L p F P
0 g
s
.088 0 0 r
.48808 .74103 m .49477 .74056 L p .50326 .74135 L F P
0 g
s
.088 0 0 r
.50326 .74135 m .48237 .74292 L .48808 .74103 L p F P
0 g
s
.216 0 0 r
.51451 .53471 m .51616 .53477 L p .48515 .5366 L F P
0 g
s
.193 0 0 r
.51616 .53477 m .51451 .53471 L .51658 .53463 L closepath p F P
0 g
s
.289 .165 .533 r
.22995 .6892 m .24036 .68045 L .24096 .6935 L p F P
0 g
s
.289 .165 .533 r
.24096 .6935 m .23419 .69914 L .22995 .6892 L p F P
0 g
s
.088 0 0 r
.49477 .74056 m .51355 .74029 L p .50326 .74135 L F P
0 g
s
.145 0 0 r
.51355 .74029 m .49477 .74056 L .51758 .73902 L closepath p F P
0 g
s
.101 0 .103 r
.27671 .62015 m .28549 .61482 L p .26292 .63529 L F P
0 g
s
.101 0 .103 r
.26292 .63529 m .26339 .63416 L .27671 .62015 L p F P
0 g
s
.019 0 0 r
.28549 .61482 m .2879 .61055 L .27671 .62015 L closepath p F P
0 g
s
.485 0 0 r
.65955 .55737 m .64692 .55141 L .64782 .55128 L p F P
0 g
s
.467 0 0 r
.64692 .55141 m .64523 .55066 L .64782 .55128 L closepath p F P
0 g
s
.228 0 0 r
.51616 .53477 m .54067 .53706 L p .51136 .53714 L F P
0 g
s
.228 0 0 r
.51136 .53714 m .50942 .537 L .51616 .53477 L p F P
0 g
s
.216 0 0 r
.51616 .53477 m .50942 .537 L .48515 .5366 L p F P
0 g
s
.27 0 0 r
.54718 .53536 m .54067 .53706 L .51616 .53477 L p F P
0 g
s
.1 0 .004 r
.28549 .61482 m .2879 .61055 L .30066 .60123 L p F P
0 g
s
.193 0 0 r
.47874 .53901 m .48515 .5366 L .50942 .537 L p F P
0 g
s
.131 0 0 r
.48515 .5366 m .47874 .53901 L .47511 .53942 L p F P
0 g
s
.024 0 0 r
.36613 .56529 m .36771 .56422 L .39143 .55734 L p F P
0 g
s
.181 0 0 r
.55944 .74094 m .57599 .74378 L p .56027 .74189 L F P
0 g
s
.181 0 0 r
.57599 .74378 m .57363 .74338 L .56027 .74189 L p F P
0 g
s
0 .552 .751 r
.56959 .74273 m .56027 .74189 L .57363 .74338 L closepath p F P
0 g
s
.124 0 0 r
.56027 .74189 m .56959 .74273 L p .56051 .74217 L F P
0 g
s
.124 0 0 r
.53816 .74078 m .56027 .74189 L .56051 .74217 L F
.181 0 0 r
.55459 .74011 m .55944 .74094 L p .56027 .74189 L F P
0 g
s
.181 0 0 r
.54991 .73977 m .55459 .74011 L p .56027 .74189 L F P
0 g
s
.401 0 0 r
.55459 .74011 m .57599 .74378 L .58229 .74417 L p F P
0 g
s
.945 .747 .604 r
.82422 .7123 m .82592 .70551 L .81892 .69926 L p F P
0 g
s
.485 0 0 r
.64692 .55141 m .64523 .55066 L .62783 .54689 L p F P
0 g
s
.181 0 0 r
.56027 .74189 m .54473 .74065 L .54991 .73977 L p F P
0 g
s
.203 0 0 r
.54473 .74065 m .52906 .73907 L .54991 .73977 L closepath p F P
0 g
s
.849 .402 .145 r
.77473 .61929 m .76477 .61353 L .77014 .62357 L p F P
0 g
s
.849 .402 .145 r
.77014 .62357 m .78008 .62934 L .77473 .61929 L p F P
0 g
s
.485 .514 .813 r
.25637 .74811 m .26364 .76152 L .24102 .76147 L p F P
0 g
s
.485 .514 .813 r
.24766 .74746 m .25637 .74811 L p .24102 .76147 L F P
0 g
s
.485 .514 .813 r
.24102 .76147 m .23838 .75587 L .24766 .74746 L p F P
0 g
s
.534 .609 .874 r
.24102 .76147 m .26364 .76152 L .26607 .76528 L p F P
0 g
s
.027 0 .067 r
.26292 .63529 m .26339 .63416 L .26179 .63609 L closepath p F P
0 g
s
.787 .292 .017 r
.75537 .60852 m .75977 .60683 L .76477 .61353 L closepath p F P
0 g
s
.775 .273 .002 r
.75415 .6079 m .75537 .60852 L .75977 .60683 L p F P
0 g
s
.546 .63 .886 r
.27106 .77247 m .25688 .7739 L .26607 .76528 L closepath p F P
0 g
s
.138 0 .231 r
.26179 .63609 m .26292 .63529 L .26026 .64519 L p F P
0 g
s
.138 0 .231 r
.26026 .64519 m .25362 .64986 L .26179 .63609 L p F P
0 g
s
.378 .723 .989 r
.71397 .77386 m .69468 .77374 L .68283 .76896 L p F P
0 g
s
.362 .7 .984 r
.69468 .77374 m .71397 .77386 L .71974 .77967 L p F P
0 g
s
.704 .173 0 r
.72648 .58437 m .73541 .59311 L .72323 .58785 L p F P
0 g
s
.704 .173 0 r
.718 .58075 m .72648 .58437 L p .72323 .58785 L F P
0 g
s
.34 .302 .67 r
.22755 .72286 m .22647 .72206 L .22721 .72131 L closepath p F P
0 g
s
.35 .329 .695 r
.22647 .72206 m .22755 .72286 L .23136 .7374 L p F P
0 g
s
.267 0 0 r
.54718 .53536 m .56605 .53846 L .54089 .53709 L p F P
0 g
s
.267 0 0 r
.54089 .53709 m .54067 .53706 L .54718 .53536 L p F P
0 g
s
.605 .73 .933 r
.29429 .76805 m .27106 .77247 L .27857 .78158 L p F P
0 g
s
.605 .73 .933 r
.27857 .78158 m .30185 .77591 L .29429 .76805 L p F P
0 g
s
.181 0 0 r
.52906 .73907 m .54473 .74065 L p .53495 .7407 L F P
0 g
s
.181 0 0 r
.51758 .73902 m .52906 .73907 L p .53495 .7407 L F P
0 g
s
.181 0 0 r
.53495 .7407 m .51355 .74029 L .51758 .73902 L p F P
0 g
s
.125 0 0 r
.45014 .5424 m .45408 .54079 L .47511 .53942 L closepath p F P
0 g
s
.067 0 0 r
.45408 .54079 m .45014 .5424 L .42298 .54715 L p F P
0 g
s
.1 0 .004 r
.30066 .60123 m .31025 .59626 L p .28549 .61482 L F P
0 g
s
0 0 0 r
.31025 .59626 m .31189 .59411 L .30066 .60123 L closepath p F P
0 g
s
.633 .887 .987 r
.35683 .76628 m .33302 .77445 L .34061 .77848 L p F P
0 g
s
.633 .887 .987 r
.34061 .77848 m .36437 .76952 L .35683 .76628 L p F P
0 g
s
.632 .9 .985 r
.36684 .77009 m .36437 .76952 L .34061 .77848 L p F P
0 g
s
.078 0 0 r
.58229 .74417 m .58884 .74534 L p .58141 .74427 L F P
0 g
s
.078 0 0 r
.58141 .74427 m .57599 .74378 L .57684 .74383 L p F P
0 g
s
.078 0 0 r
.57684 .74383 m .58229 .74417 L p .58141 .74427 L F P
0 g
s
0 .547 .747 r
.58141 .74427 m .60114 .74631 L p .59172 .74524 L F P
0 g
s
0 .547 .747 r
.57526 .74338 m .58141 .74427 L .59172 .74524 L F
.56959 .74273 m .58141 .74427 L .57526 .74338 L F
.078 0 0 r
.58884 .74534 m .60003 .74733 L .58141 .74427 L p F P
0 g
s
.254 .698 .959 r
.65099 .76144 m .67269 .76366 L .66132 .75864 L p F P
0 g
s
.254 .698 .959 r
.66132 .75864 m .64499 .75795 L .65099 .76144 L p F P
0 g
s
0 .422 .737 r
.63155 .75497 m .64499 .75795 L .65099 .76144 L p F P
0 g
s
.471 0 0 r
.64692 .55141 m .65955 .55737 L .64306 .55328 L p F P
0 g
s
.471 0 0 r
.64306 .55328 m .64111 .55242 L .64692 .55141 L p F P
0 g
s
.485 0 0 r
.62783 .54689 m .64111 .55242 L .64692 .55141 L p F P
0 g
s
.886 .809 .767 r
.82201 .73868 m .81535 .73247 L .80489 .74745 L p F P
0 g
s
.886 .809 .767 r
.80489 .74745 m .81152 .75364 L .82201 .73868 L p F P
0 g
s
.459 .471 .783 r
.24766 .74746 m .23838 .75587 L .23402 .74516 L closepath p F P
0 g
s
.951 .702 .526 r
.82028 .68696 m .81892 .69926 L .81677 .69751 L p F P
0 g
s
.951 .702 .526 r
.81275 .68078 m .82028 .68696 L p .81677 .69751 L F P
0 g
s
.218 0 .264 r
.26026 .64519 m .26292 .63529 L .28198 .62378 L p F P
0 g
s
.101 0 .103 r
.28549 .61482 m .28198 .62378 L .26292 .63529 L p F P
0 g
s
.604 .04 0 r
.68953 .56636 m .7008 .57422 L .6867 .56945 L p F P
0 g
s
.604 .04 0 r
.68079 .56346 m .68953 .56636 L p .6867 .56945 L F P
0 g
s
.891 .492 .256 r
.78942 .63522 m .78008 .62934 L .78384 .63996 L p F P
0 g
s
.891 .492 .256 r
.78384 .63996 m .7932 .64583 L .78942 .63522 L p F P
0 g
s
.404 .36 .696 r
.22721 .72131 m .24296 .70782 L .24696 .72388 L p F P
0 g
s
.404 .36 .696 r
.22755 .72286 m .22721 .72131 L p .24696 .72388 L F P
0 g
s
.344 .263 .619 r
.24292 .70761 m .24296 .70782 L .22721 .72131 L p F P
0 g
s
.344 .263 .619 r
.23419 .69914 m .24292 .70761 L p .22721 .72131 L F P
0 g
s
.578 .756 .963 r
.73961 .76839 m .71397 .77386 L .71974 .77967 L p F P
0 g
s
.578 .756 .963 r
.71974 .77967 m .74534 .77497 L .73961 .76839 L p F P
0 g
s
.404 .36 .696 r
.24696 .72388 m .24088 .72901 L .22755 .72286 L p F P
0 g
s
.399 .363 .702 r
.24088 .72901 m .23136 .7374 L .22755 .72286 L closepath p F P
0 g
s
.941 .644 .447 r
.8123 .66905 m .80788 .66569 L .81008 .67876 L p F P
0 g
s
.941 .644 .447 r
.81008 .67876 m .81275 .68078 L .8123 .66905 L p F P
0 g
s
.638 .818 .969 r
.32544 .76906 m .30185 .77591 L .30944 .7823 L p F P
0 g
s
.638 .818 .969 r
.30944 .7823 m .33302 .77445 L .32544 .76906 L p F P
0 g
s
.92 .57 .358 r
.80198 .6518 m .7932 .64583 L .79533 .65701 L p F P
0 g
s
.92 .57 .358 r
.79533 .65701 m .80416 .66296 L .80198 .6518 L p F P
0 g
s
0 .464 .732 r
.64499 .75795 m .63155 .75497 L .61599 .75112 L p F P
0 g
s
.777 .814 .882 r
.78475 .76511 m .77638 .77092 L .78195 .77772 L p F P
0 g
s
.777 .814 .882 r
.78195 .77772 m .79154 .7712 L .78475 .76511 L p F P
0 g
s
.945 .747 .604 r
.81892 .69926 m .81846 .70114 L .82422 .7123 L p F P
0 g
s
.933 .75 .631 r
.82422 .7123 m .82223 .71851 L .815 .71236 L p F P
0 g
s
.933 .75 .631 r
.815 .71236 m .81846 .70114 L .82422 .7123 L p F P
0 g
s
.161 0 0 r
.36025 .57123 m .36613 .56529 L .39053 .55795 L p F P
0 g
s
.024 0 0 r
.39143 .55734 m .39053 .55795 L .36613 .56529 L p F P
0 g
s
.072 0 0 r
.36613 .56529 m .36025 .57123 L .33714 .57971 L p F P
0 g
s
.462 .466 .777 r
.23402 .74516 m .23136 .7374 L p .25369 .74224 L F P
0 g
s
.462 .466 .777 r
.25369 .74224 m .24766 .74746 L .23402 .74516 L p F P
0 g
s
.284 .107 .456 r
.241 .66855 m .24967 .66232 L .25024 .6734 L p F P
0 g
s
.284 .107 .456 r
.25024 .6734 m .24036 .68045 L .241 .66855 L p F P
0 g
s
.462 .466 .777 r
.23136 .7374 m .24088 .72901 L p .25369 .74224 L F P
0 g
s
.087 0 0 r
.31025 .59626 m .31189 .59411 L .33573 .58171 L p F P
0 g
s
.099 0 0 r
.33714 .57971 m .33573 .58171 L .31189 .59411 L p F P
0 g
s
.116 0 0 r
.42177 .54744 m .42288 .54722 L p .40253 .55508 L F P
0 g
s
.128 0 0 r
.42288 .54722 m .42177 .54744 L .42298 .54715 L closepath p F P
0 g
s
.295 .793 .826 r
.41976 .75448 m .42602 .75411 L .45024 .74825 L p F P
0 g
s
.212 0 0 r
.42288 .54722 m .42298 .54715 L .45014 .5424 L p F P
0 g
s
.691 .785 .923 r
.77076 .76386 m .74534 .77497 L .75102 .7814 L p F P
0 g
s
.691 .785 .923 r
.75102 .7814 m .77638 .77092 L .77076 .76386 L p F P
0 g
s
.313 0 0 r
.57413 .53905 m .57829 .53832 L .58862 .54066 L closepath p F P
0 g
s
.287 0 0 r
.57829 .53832 m .57413 .53905 L .56605 .53846 L p F P
0 g
s
.804 .808 .854 r
.80672 .75915 m .79154 .7712 L .78475 .76511 L p F P
0 g
s
.198 0 0 r
.41635 .5518 m .42288 .54722 L .44683 .5447 L p F P
0 g
s
.212 0 0 r
.45014 .5424 m .44683 .5447 L .42288 .54722 L p F P
0 g
s
.116 0 0 r
.42288 .54722 m .41635 .5518 L .40253 .55508 L p F P
0 g
s
.472 0 0 r
.62783 .54689 m .64111 .55242 L p .62495 .54967 L F P
0 g
s
.472 0 0 r
.60966 .54349 m .62783 .54689 L p .62495 .54967 L F P
0 g
s
.78 .288 .045 r
.7469 .59853 m .73541 .59311 L .74266 .60247 L p F P
0 g
s
.78 .288 .045 r
.74266 .60247 m .75415 .6079 L .7469 .59853 L p F P
0 g
s
.859 .815 .805 r
.80672 .75915 m .81152 .75364 L .80489 .74745 L p F P
0 g
s
.223 .003 .354 r
.25362 .64986 m .26026 .64519 L .25858 .65609 L p F P
0 g
s
.223 .003 .354 r
.25858 .65609 m .24967 .66232 L .25362 .64986 L p F P
0 g
s
.704 .173 0 r
.72323 .58785 m .71639 .58132 L .718 .58075 L p F P
0 g
s
.701 .168 0 r
.71639 .58132 m .71411 .57918 L .718 .58075 L closepath p F P
0 g
s
.604 .04 0 r
.6867 .56945 m .67866 .56403 L .68079 .56346 L p F P
0 g
s
.595 .03 0 r
.67866 .56403 m .67511 .56171 L .68079 .56346 L closepath p F P
0 g
s
.859 .815 .805 r
.80489 .74745 m .80121 .75174 L .80672 .75915 L p F P
0 g
s
.804 .808 .854 r
.78475 .76511 m .80121 .75174 L .80672 .75915 L p F P
0 g
s
.91 .779 .703 r
.82223 .71851 m .815 .71236 L .80812 .72635 L p F P
0 g
s
.91 .779 .703 r
.80812 .72635 m .81535 .73247 L .82223 .71851 L p F P
0 g
s
.213 0 .17 r
.28198 .62378 m .28549 .61482 L .30595 .60428 L p F P
0 g
s
.1 0 .004 r
.31025 .59626 m .30595 .60428 L .28549 .61482 L p F P
0 g
s
.566 .905 .976 r
.36437 .76952 m .36684 .77009 L .38838 .76105 L p F P
0 g
s
.593 .912 .978 r
.39576 .76227 m .38838 .76105 L .36684 .77009 L p F P
0 g
s
.499 .889 .957 r
.39576 .76227 m .41976 .75448 L p .39064 .7603 L F P
0 g
s
.499 .889 .957 r
.39064 .7603 m .38838 .76105 L .39576 .76227 L p F P
0 g
s
.195 0 0 r
.33573 .58171 m .33714 .57971 L .36025 .57123 L p F P
0 g
s
.033 .582 .832 r
.6122 .75036 m .61356 .75082 L .61599 .75112 L closepath p F P
0 g
s
.936 .64 .455 r
.80788 .66569 m .80416 .66296 L .80453 .67473 L p F P
0 g
s
.936 .64 .455 r
.80453 .67473 m .81008 .67876 L .80788 .66569 L p F P
0 g
s
.686 .152 0 r
.71411 .57918 m .7008 .57422 L .71026 .58276 L p F P
0 g
s
.686 .152 0 r
.71639 .58132 m .71411 .57918 L p .71026 .58276 L F P
0 g
s
.434 .752 .994 r
.68217 .76874 m .68246 .76898 L .68283 .76896 L closepath p F P
0 g
s
.187 .653 .938 r
.68246 .76898 m .68217 .76874 L .67269 .76366 L p F P
0 g
s
.435 .752 .994 r
.68283 .76896 m .70814 .768 L p .67656 .76414 L F P
0 g
s
.435 .752 .994 r
.67656 .76414 m .68217 .76874 L .68283 .76896 L p F P
0 g
s
.378 .723 .989 r
.68283 .76896 m .70814 .768 L .71397 .77386 L p F P
0 g
s
.205 0 .068 r
.30595 .60428 m .31025 .59626 L .33206 .58673 L p F P
0 g
s
.087 0 0 r
.33573 .58171 m .33206 .58673 L .31025 .59626 L p F P
0 g
s
.839 .397 .176 r
.76477 .61353 m .77014 .62357 L .75957 .61793 L p F P
0 g
s
.839 .397 .176 r
.75537 .60852 m .76477 .61353 L p .75957 .61793 L F P
0 g
s
.578 .011 0 r
.67511 .56171 m .65955 .55737 L .67169 .56492 L p F P
0 g
s
.578 .011 0 r
.67866 .56403 m .67511 .56171 L p .67169 .56492 L F P
0 g
s
.26 .651 .965 r
.67656 .76414 m .67269 .76366 L .68217 .76874 L closepath p F P
0 g
s
.098 .632 .863 r
.61599 .75112 m .63893 .75435 L p .63158 .75041 L F P
0 g
s
.098 .632 .863 r
.6122 .75036 m .61599 .75112 L p .63158 .75041 L F P
0 g
s
0 .464 .732 r
.61599 .75112 m .63893 .75435 L .64499 .75795 L p F P
0 g
s
.937 .733 .602 r
.81846 .70114 m .81892 .69926 L .81677 .69751 L closepath p F P
0 g
s
.563 .637 .883 r
.28679 .75852 m .29429 .76805 L .27106 .77247 L p F P
0 g
s
.563 .637 .883 r
.27216 .76054 m .28679 .75852 L p .27106 .77247 L F P
0 g
s
.563 .637 .883 r
.27106 .77247 m .26607 .76528 L .27216 .76054 L p F P
0 g
s
.351 .263 .615 r
.24292 .70761 m .23419 .69914 L .24096 .6935 L closepath p F P
0 g
s
.472 0 0 r
.62495 .54967 m .60956 .54352 L .60966 .54349 L p F P
0 g
s
.448 0 0 r
.60956 .54352 m .60933 .54344 L .60966 .54349 L closepath p F P
0 g
s
.463 0 0 r
.60956 .54352 m .60933 .54344 L .58862 .54066 L p F P
0 g
s
.455 0 0 r
.60956 .54352 m .62495 .54967 L .60564 .5464 L p F P
0 g
s
.455 0 0 r
.60564 .5464 m .6035 .54561 L .60956 .54352 L p F P
0 g
s
.463 0 0 r
.58862 .54066 m .6035 .54561 L .60956 .54352 L p F P
0 g
s
.925 .739 .632 r
.81846 .70114 m .81677 .69751 L p .8072 .7063 L F P
0 g
s
.925 .739 .632 r
.8072 .7063 m .815 .71236 L .81846 .70114 L p F P
0 g
s
.098 .632 .863 r
.63158 .75041 m .60739 .74877 L .6122 .75036 L p F P
0 g
s
.883 .488 .276 r
.78008 .62934 m .77014 .62357 L .77388 .6342 L p F P
0 g
s
.883 .488 .276 r
.77388 .6342 m .78384 .63996 L .78008 .62934 L p F P
0 g
s
.601 .894 .989 r
.38084 .75829 m .35683 .76628 L .36437 .76952 L p F P
0 g
s
.601 .894 .989 r
.36437 .76952 m .38831 .76103 L .38084 .75829 L p F P
0 g
s
.566 .905 .976 r
.38838 .76105 m .38831 .76103 L .36437 .76952 L p F P
0 g
s
.089 0 0 r
.50748 .741 m .51355 .74029 L .53495 .7407 L closepath p F P
0 g
s
.088 0 0 r
.51355 .74029 m .50748 .741 L .50326 .74135 L p F P
0 g
s
.937 .687 .533 r
.81227 .68543 m .81275 .68078 L .81008 .67876 L closepath p F P
0 g
s
.951 .702 .526 r
.81677 .69751 m .81227 .68543 L .81275 .68078 L p F P
0 g
s
.706 .178 0 r
.71167 .58328 m .71639 .58132 L .72323 .58785 L closepath p F P
0 g
s
.686 .152 0 r
.71026 .58276 m .71167 .58328 L .71639 .58132 L p F P
0 g
s
.257 0 0 r
.45014 .5424 m .47511 .53942 L p .46464 .54422 L F P
0 g
s
.257 0 0 r
.46464 .54422 m .44683 .5447 L .45014 .5424 L p F P
0 g
s
.106 0 0 r
.39053 .55795 m .39143 .55734 L .40253 .55508 L closepath p F P
0 g
s
.881 .798 .763 r
.81535 .73247 m .80812 .72635 L .79773 .74135 L p F P
0 g
s
.881 .798 .763 r
.79773 .74135 m .80489 .74745 L .81535 .73247 L p F P
0 g
s
.184 0 0 r
.33206 .58673 m .33573 .58171 L .35955 .57225 L p F P
0 g
s
.195 0 0 r
.36025 .57123 m .35955 .57225 L .33573 .58171 L p F P
0 g
s
.346 .209 .547 r
.24036 .68045 m .25024 .6734 L .25579 .68299 L p F P
0 g
s
.346 .209 .547 r
.25579 .68299 m .24096 .6935 L .24036 .68045 L p F P
0 g
s
.91 .564 .373 r
.7932 .64583 m .78384 .63996 L .78593 .65116 L p F P
0 g
s
.91 .564 .373 r
.78593 .65116 m .79533 .65701 L .7932 .64583 L p F P
0 g
s
.925 .63 .464 r
.80416 .66296 m .79533 .65701 L .79565 .66881 L p F P
0 g
s
.925 .63 .464 r
.79565 .66881 m .80453 .67473 L .80416 .66296 L p F P
0 g
s
.925 .739 .632 r
.81677 .69751 m .81121 .69316 L .8072 .7063 L p F P
0 g
s
.941 .702 .548 r
.81121 .69316 m .81677 .69751 L .81227 .68543 L closepath p F P
0 g
s
.607 .046 0 r
.67388 .56553 m .67866 .56403 L .6867 .56945 L closepath p F P
0 g
s
.578 .011 0 r
.67169 .56492 m .67388 .56553 L .67866 .56403 L p F P
0 g
s
.292 .059 .379 r
.25858 .65609 m .26026 .64519 L .27939 .63372 L p F P
0 g
s
.218 0 .264 r
.28198 .62378 m .27939 .63372 L .26026 .64519 L p F P
0 g
s
.109 0 0 r
.53913 .74075 m .54473 .74065 L .56027 .74189 L closepath p F P
0 g
s
.181 0 0 r
.54473 .74065 m .53913 .74075 L .53495 .7407 L p F P
0 g
s
.595 .759 .957 r
.73382 .76163 m .70814 .768 L .71397 .77386 L p F P
0 g
s
.595 .759 .957 r
.71397 .77386 m .73961 .76839 L .73382 .76163 L p F P
0 g
s
.294 .114 .458 r
.24967 .66232 m .25858 .65609 L .25798 .66803 L p F P
0 g
s
.294 .114 .458 r
.25798 .66803 m .25024 .6734 L .24967 .66232 L p F P
0 g
s
.778 .293 .074 r
.73541 .59311 m .72323 .58785 L .73051 .59719 L p F P
0 g
s
.778 .293 .074 r
.73051 .59719 m .74266 .60247 L .73541 .59311 L p F P
0 g
s
.624 .768 .949 r
.31787 .76217 m .29429 .76805 L .30185 .77591 L p F P
0 g
s
.624 .768 .949 r
.30185 .77591 m .32544 .76906 L .31787 .76217 L p F P
0 g
s
.779 .808 .876 r
.77743 .7591 m .77076 .76386 L .77638 .77092 L p F P
0 g
s
.779 .808 .876 r
.77638 .77092 m .78475 .76511 L .77743 .7591 L p F P
0 g
s
.635 .844 .98 r
.34928 .76162 m .32544 .76906 L .33302 .77445 L p F P
0 g
s
.635 .844 .98 r
.33302 .77445 m .35683 .76628 L .34928 .76162 L p F P
0 g
s
.439 0 0 r
.58862 .54066 m .6035 .54561 L p .58414 .5438 L F P
0 g
s
.439 0 0 r
.57413 .53905 m .58862 .54066 L p .58414 .5438 L F P
0 g
s
.238 0 0 r
.38478 .56385 m .39053 .55795 L .40253 .55508 L p F P
0 g
s
.161 0 0 r
.39053 .55795 m .38478 .56385 L .36025 .57123 L p F P
0 g
s
0 0 0 r
.45112 .74803 m .45024 .74825 L .45115 .74802 L closepath p F P
0 g
s
.295 .793 .826 r
.45024 .74825 m .45112 .74803 L p .41976 .75448 L F P
0 g
s
.329 .741 .979 r
.64499 .75795 m .66132 .75864 L .64779 .75417 L p F P
0 g
s
.329 .741 .979 r
.64779 .75417 m .63893 .75435 L .64499 .75795 L p F P
0 g
s
.93 .689 .553 r
.81227 .68543 m .81008 .67876 L p .80286 .68716 L F P
0 g
s
.93 .689 .553 r
.80286 .68716 m .81121 .69316 L .81227 .68543 L p F P
0 g
s
0 0 0 r
.45112 .74803 m .45115 .74802 L .47806 .74338 L p F P
0 g
s
.93 .689 .553 r
.81008 .67876 m .80453 .67473 L .80286 .68716 L p F P
0 g
s
.286 .782 .876 r
.46835 .74311 m .44394 .74815 L .45112 .74803 L p F P
0 g
s
.286 .782 .876 r
.45112 .74803 m .47539 .74373 L .46835 .74311 L p F P
0 g
s
0 0 0 r
.47806 .74338 m .47539 .74373 L p .46613 .74544 L F P
0 g
s
0 0 0 r
.47539 .74373 m .47806 .74338 L .50326 .74135 L p F P
0 g
s
.307 .781 .928 r
.47539 .74373 m .49993 .74062 L .49661 .7398 L p F P
0 g
s
.307 .781 .928 r
.49661 .7398 m .493 .73891 L p .47539 .74373 L F P
0 g
s
0 0 0 r
.47539 .74373 m .45112 .74803 L p .46613 .74544 L F P
0 g
s
.295 .793 .826 r
.45112 .74803 m .44394 .74815 L .41976 .75448 L p F P
0 g
s
.553 .619 .872 r
.27216 .76054 m .26607 .76528 L .26364 .76152 L closepath p F P
0 g
s
.594 .039 0 r
.65955 .55737 m .64306 .55328 L .65535 .56075 L p F P
0 g
s
.594 .039 0 r
.65535 .56075 m .67169 .56492 L .65955 .55737 L p F P
0 g
s
.805 .797 .845 r
.80121 .75174 m .78475 .76511 L .77743 .7591 L p F P
0 g
s
.699 .781 .914 r
.76506 .75651 m .73961 .76839 L .74534 .77497 L p F P
0 g
s
.699 .781 .914 r
.74534 .77497 m .77076 .76386 L .76506 .75651 L p F P
0 g
s
.487 .51 .807 r
.25637 .74811 m .24766 .74746 L .25369 .74224 L closepath p F P
0 g
s
.856 .805 .799 r
.80121 .75174 m .80489 .74745 L .79773 .74135 L p F P
0 g
s
.695 .171 0 r
.7008 .57422 m .6867 .56945 L .69622 .57796 L p F P
0 g
s
.695 .171 0 r
.69622 .57796 m .71026 .58276 L .7008 .57422 L p F P
0 g
s
.257 0 0 r
.47511 .53942 m .47817 .5394 L p .46464 .54422 L F P
0 g
s
.264 0 0 r
.47817 .5394 m .47511 .53942 L .47874 .53901 L closepath p F P
0 g
s
.839 .397 .176 r
.75957 .61793 m .75484 .60917 L .75537 .60852 L p F P
0 g
s
.838 .395 .175 r
.75484 .60917 m .75415 .6079 L .75537 .60852 L closepath p F P
0 g
s
.856 .805 .799 r
.79773 .74135 m .79562 .74386 L .80121 .75174 L p F P
0 g
s
.805 .797 .845 r
.77743 .7591 m .79562 .74386 L .80121 .75174 L p F P
0 g
s
.903 .766 .7 r
.815 .71236 m .8072 .7063 L .80034 .72031 L p F P
0 g
s
.903 .766 .7 r
.80034 .72031 m .80812 .72635 L .815 .71236 L p F P
0 g
s
.439 0 0 r
.58414 .5438 m .57201 .54003 L .57413 .53905 L p F P
0 g
s
.408 0 0 r
.57201 .54003 m .56605 .53846 L .57413 .53905 L closepath p F P
0 g
s
.336 0 0 r
.47817 .5394 m .47874 .53901 L .50887 .53718 L p F P
0 g
s
.193 0 0 r
.50942 .537 m .50887 .53718 L .47874 .53901 L p F P
0 g
s
0 .557 .758 r
.57363 .74338 m .57599 .74378 L .58141 .74427 L closepath p F P
0 g
s
.554 .61 .864 r
.26364 .76152 m .25637 .74811 L p .28294 .75269 L F P
0 g
s
.554 .61 .864 r
.28294 .75269 m .27216 .76054 L .26364 .76152 L p F P
0 g
s
.826 .382 .18 r
.75415 .6079 m .74266 .60247 L .74828 .61244 L p F P
0 g
s
.826 .382 .18 r
.75484 .60917 m .75415 .6079 L p .74828 .61244 L F P
0 g
s
.387 0 0 r
.56605 .53846 m .54089 .53709 L .56066 .54182 L p F P
0 g
s
.387 0 0 r
.57201 .54003 m .56605 .53846 L p .56066 .54182 L F P
0 g
s
.443 .424 .744 r
.24936 .73118 m .24088 .72901 L .24696 .72388 L closepath p F P
0 g
s
.462 .466 .777 r
.24088 .72901 m .24936 .73118 L .25369 .74224 L p F P
0 g
s
.224 .648 .956 r
.67656 .76414 m .67269 .76366 L .66132 .75864 L p F P
0 g
s
.227 0 0 r
.50887 .53718 m .50942 .537 L .51136 .53714 L closepath p F P
0 g
s
.316 0 0 r
.47222 .54331 m .47817 .5394 L .50257 .54105 L p F P
0 g
s
.336 0 0 r
.50887 .53718 m .50257 .54105 L .47817 .5394 L p F P
0 g
s
.257 0 0 r
.47817 .5394 m .47222 .54331 L .46464 .54422 L p F P
0 g
s
.438 .863 .94 r
.41976 .75448 m .44394 .74815 L p .43435 .74746 L F P
0 g
s
.438 .863 .94 r
.43435 .74746 m .41242 .75341 L .41976 .75448 L p F P
0 g
s
.499 .889 .957 r
.41976 .75448 m .41242 .75341 L .39064 .7603 L p F P
0 g
s
.238 0 0 r
.40253 .55508 m .41531 .5529 L p .38478 .56385 L F P
0 g
s
.243 0 0 r
.41531 .5529 m .40253 .55508 L .41635 .5518 L closepath p F P
0 g
s
.836 .397 .187 r
.75141 .61391 m .75484 .60917 L .75957 .61793 L closepath p F P
0 g
s
.826 .382 .18 r
.74828 .61244 m .75141 .61391 L .75484 .60917 L p F P
0 g
s
.409 .314 .636 r
.24096 .6935 m .25579 .68299 L p .26061 .69549 L F P
0 g
s
.409 .314 .636 r
.24292 .70761 m .24096 .6935 L p .26061 .69549 L F P
0 g
s
.476 0 0 r
.64011 .55262 m .64111 .55242 L .64306 .55328 L closepath p F P
0 g
s
.472 0 0 r
.64111 .55242 m .64011 .55262 L .62495 .54967 L p F P
0 g
s
.268 0 0 r
.5406 .53708 m .54067 .53706 L .54089 .53709 L closepath p F P
0 g
s
.228 0 0 r
.54067 .53706 m .5406 .53708 L .51136 .53714 L p F P
0 g
s
.35 0 0 r
.50887 .53718 m .51136 .53714 L p .50347 .54116 L F P
0 g
s
.35 0 0 r
.50347 .54116 m .50257 .54105 L .50887 .53718 L p F P
0 g
s
.35 0 0 r
.51136 .53714 m .53407 .54068 L p .50347 .54116 L F P
0 g
s
.351 0 0 r
.53407 .54068 m .51136 .53714 L .5406 .53708 L closepath p F P
0 g
s
.39 0 0 r
.54089 .53709 m .56066 .54182 L .53436 .54074 L p F P
0 g
s
.39 0 0 r
.5406 .53708 m .54089 .53709 L p .53436 .54074 L F P
0 g
s
.39 0 0 r
.53436 .54074 m .53407 .54068 L .5406 .53708 L p F P
0 g
s
.916 .725 .63 r
.81121 .69316 m .80286 .68716 L .79883 .70034 L p F P
0 g
s
.916 .725 .63 r
.79883 .70034 m .8072 .7063 L .81121 .69316 L p F P
0 g
s
.291 .005 .294 r
.28198 .62378 m .30254 .61326 L p .2892 .62872 L F P
0 g
s
.291 .005 .294 r
.2892 .62872 m .27939 .63372 L .28198 .62378 L p F P
0 g
s
.213 0 .17 r
.30595 .60428 m .30254 .61326 L .28198 .62378 L p F P
0 g
s
.875 .484 .293 r
.77014 .62357 m .75957 .61793 L .76332 .62856 L p F P
0 g
s
.875 .484 .293 r
.76332 .62856 m .77388 .6342 L .77014 .62357 L p F P
0 g
s
.273 0 .011 r
.35955 .57225 m .36025 .57123 L .38478 .56385 L p F P
0 g
s
.498 .738 .98 r
.69633 .75587 m .67059 .7592 L .67656 .76414 L p F P
0 g
s
.498 .738 .98 r
.67656 .76414 m .70227 .76203 L .69633 .75587 L p F P
0 g
s
.435 .752 .994 r
.70814 .768 m .70227 .76203 L .67656 .76414 L p F P
0 g
s
.224 .648 .956 r
.66132 .75864 m .67059 .7592 L .67656 .76414 L p F P
0 g
s
0 .547 .747 r
.56959 .74273 m .57363 .74338 L .58141 .74427 L p F P
0 g
s
.179 0 0 r
.58141 .74427 m .60114 .74631 L .60739 .74877 L p F P
0 g
s
.579 .029 0 r
.64306 .55328 m .65535 .56075 L .63807 .55684 L p F P
0 g
s
.579 .029 0 r
.64011 .55262 m .64306 .55328 L p .63807 .55684 L F P
0 g
s
.92 .676 .554 r
.80453 .67473 m .79565 .66881 L .79395 .68127 L p F P
0 g
s
.92 .676 .554 r
.79395 .68127 m .80286 .68716 L .80453 .67473 L p F P
0 g
s
.251 0 0 r
.44357 .54689 m .44683 .5447 L .46464 .54422 L closepath p F P
0 g
s
.198 0 0 r
.44683 .5447 m .44357 .54689 L .41635 .5518 L p F P
0 g
s
.9 .557 .386 r
.78384 .63996 m .77388 .6342 L .77594 .64542 L p F P
0 g
s
.9 .557 .386 r
.77594 .64542 m .78593 .65116 L .78384 .63996 L p F P
0 g
s
.767 .291 .109 r
.72323 .58785 m .73051 .59719 L .71765 .59207 L p F P
0 g
s
.767 .291 .109 r
.71167 .58328 m .72323 .58785 L p .71765 .59207 L F P
0 g
s
.915 .62 .472 r
.79533 .65701 m .78593 .65116 L .78621 .66298 L p F P
0 g
s
.915 .62 .472 r
.78621 .66298 m .79565 .66881 L .79533 .65701 L p F P
0 g
s
.876 .786 .758 r
.80812 .72635 m .80034 .72031 L .79004 .73533 L p F P
0 g
s
.876 .786 .758 r
.79004 .73533 m .79773 .74135 L .80812 .72635 L p F P
0 g
s
.492 .888 .952 r
.38831 .76103 m .39064 .7603 L .38838 .76105 L closepath p F P
0 g
s
.224 .711 .927 r
.60739 .74877 m .63158 .75041 L .61676 .74621 L p F P
0 g
s
.224 .711 .927 r
.61676 .74621 m .60114 .74631 L .60739 .74877 L p F P
0 g
s
.567 .884 .991 r
.40503 .7508 m .38084 .75829 L .38831 .76103 L p F P
0 g
s
.567 .884 .991 r
.41148 .75307 m .40503 .7508 L p .38831 .76103 L F P
0 g
s
.567 .884 .991 r
.38831 .76103 m .39064 .7603 L .41148 .75307 L p F P
0 g
s
.579 .029 0 r
.63807 .55684 m .63529 .55525 L .64011 .55262 L p F P
0 g
s
.566 .013 0 r
.63529 .55525 m .62495 .54967 L .64011 .55262 L closepath p F P
0 g
s
.265 0 0 r
.35531 .57825 m .35955 .57225 L .38343 .56584 L p F P
0 g
s
.273 0 .011 r
.38478 .56385 m .38343 .56584 L .35955 .57225 L p F P
0 g
s
.184 0 0 r
.35955 .57225 m .35531 .57825 L .33206 .58673 L p F P
0 g
s
.288 0 .204 r
.30595 .60428 m .32788 .59475 L p .30382 .61271 L F P
0 g
s
.288 0 .204 r
.30382 .61271 m .30254 .61326 L .30595 .60428 L p F P
0 g
s
.205 0 .068 r
.33206 .58673 m .32788 .59475 L .30595 .60428 L p F P
0 g
s
.563 .629 .875 r
.28679 .75852 m .27216 .76054 L .28294 .75269 L closepath p F P
0 g
s
.513 .524 .805 r
.27215 .73261 m .27939 .7469 L .25637 .74811 L p F P
0 g
s
.513 .524 .805 r
.2669 .73256 m .27215 .73261 L p .25637 .74811 L F P
0 g
s
.513 .524 .805 r
.25637 .74811 m .25369 .74224 L .2669 .73256 L p F P
0 g
s
.554 .61 .864 r
.25637 .74811 m .27939 .7469 L .28294 .75269 L p F P
0 g
s
.687 .174 .012 r
.6867 .56945 m .69622 .57796 L .6814 .57335 L p F P
0 g
s
.687 .174 .012 r
.67388 .56553 m .6867 .56945 L p .6814 .57335 L F P
0 g
s
.28 0 .107 r
.32788 .59475 m .33206 .58673 L .35531 .57825 L p F P
0 g
s
.439 0 0 r
.56733 .5422 m .57201 .54003 L .58414 .5438 L closepath p F P
0 g
s
.387 0 0 r
.56066 .54182 m .56733 .5422 L .57201 .54003 L p F P
0 g
s
.353 .161 .475 r
.25798 .66803 m .25858 .65609 L .27779 .64465 L p F P
0 g
s
.292 .059 .379 r
.27939 .63372 m .27779 .64465 L .25858 .65609 L p F P
0 g
s
.566 .885 .99 r
.41148 .75307 m .41242 .75341 L .39064 .7603 L closepath p F P
0 g
s
.354 .211 .545 r
.25024 .6734 m .25798 .66803 L .25856 .68109 L p F P
0 g
s
.354 .211 .545 r
.25856 .68109 m .25579 .68299 L .25024 .6734 L p F P
0 g
s
.315 0 0 r
.41531 .5529 m .41635 .5518 L .44357 .54689 L p F P
0 g
s
.609 .716 .921 r
.31034 .75365 m .28679 .75852 L .29429 .76805 L p F P
0 g
s
.609 .716 .921 r
.29429 .76805 m .31787 .76217 L .31034 .75365 L p F P
0 g
s
.409 .314 .636 r
.26061 .69549 m .24309 .70772 L .24292 .70761 L p F P
0 g
s
.404 .316 .642 r
.24309 .70772 m .24296 .70782 L .24292 .70761 L closepath p F P
0 g
s
.443 .385 .698 r
.24296 .70782 m .24309 .70772 L .26144 .71349 L p F P
0 g
s
.443 .385 .698 r
.26144 .71349 m .24696 .72388 L .24296 .70782 L p F P
0 g
s
.447 .381 .69 r
.24309 .70772 m .26061 .69549 L .26441 .71145 L p F P
0 g
s
.447 .381 .69 r
.26441 .71145 m .26144 .71349 L .24309 .70772 L p F P
0 g
s
.782 .803 .87 r
.76959 .75317 m .76506 .75651 L .77076 .76386 L p F P
0 g
s
.782 .803 .87 r
.77076 .76386 m .77743 .7591 L .76959 .75317 L p F P
0 g
s
.492 .483 .776 r
.2669 .73256 m .25369 .74224 L .24936 .73118 L closepath p F P
0 g
s
.615 .761 .949 r
.72797 .75461 m .70227 .76203 L .70814 .768 L p F P
0 g
s
.615 .761 .949 r
.70814 .768 m .73382 .76163 L .72797 .75461 L p F P
0 g
s
.62 .856 .988 r
.37335 .75406 m .34928 .76162 L .35683 .76628 L p F P
0 g
s
.62 .856 .988 r
.35683 .76628 m .38084 .75829 L .37335 .75406 L p F P
0 g
s
.124 0 0 r
.53816 .74078 m .53913 .74075 L .56027 .74189 L p F P
0 g
s
.806 .785 .833 r
.79562 .74386 m .77743 .7591 L .76959 .75317 L p F P
0 g
s
.821 .386 .206 r
.74266 .60247 m .73051 .59719 L .7361 .60716 L p F P
0 g
s
.821 .386 .206 r
.7361 .60716 m .74828 .61244 L .74266 .60247 L p F P
0 g
s
.631 .795 .961 r
.34173 .75544 m .31787 .76217 L .32544 .76906 L p F P
0 g
s
.631 .795 .961 r
.32544 .76906 m .34928 .76162 L .34173 .75544 L p F P
0 g
s
0 0 0 r
.50326 .74135 m .50678 .7411 L p .47539 .74373 L F P
0 g
s
0 0 0 r
.50678 .7411 m .50326 .74135 L .50748 .741 L closepath p F P
0 g
s
.854 .794 .792 r
.79562 .74386 m .79773 .74135 L .79004 .73533 L p F P
0 g
s
.494 .476 .766 r
.24936 .73118 m .24696 .72388 L p .27092 .72975 L F P
0 g
s
.494 .476 .766 r
.27092 .72975 m .2669 .73256 L .24936 .73118 L p F P
0 g
s
.494 .476 .766 r
.24696 .72388 m .26144 .71349 L p .27092 .72975 L F P
0 g
s
.268 .69 .967 r
.67059 .7592 m .66132 .75864 L .64779 .75417 L p F P
0 g
s
.854 .794 .792 r
.79004 .73533 m .78995 .73544 L .79562 .74386 L p F P
0 g
s
.806 .785 .833 r
.76959 .75317 m .78995 .73544 L .79562 .74386 L p F P
0 g
s
.895 .753 .697 r
.8072 .7063 m .79883 .70034 L .79201 .71437 L p F P
0 g
s
.895 .753 .697 r
.79201 .71437 m .80034 .72031 L .8072 .7063 L p F P
0 g
s
.709 .776 .904 r
.75931 .74881 m .73382 .76163 L .73961 .76839 L p F P
0 g
s
.709 .776 .904 r
.73961 .76839 m .76506 .75651 L .75931 .74881 L p F P
0 g
s
.105 0 0 r
.50678 .7411 m .50748 .741 L .53495 .7407 L p F P
0 g
s
.548 0 0 r
.62495 .54967 m .60564 .5464 L .61912 .55342 L p F P
0 g
s
.548 0 0 r
.63529 .55525 m .62495 .54967 L p .61912 .55342 L F P
0 g
s
.302 0 0 r
.4107 .55762 m .41531 .5529 L .43938 .55121 L p F P
0 g
s
.238 0 0 r
.41531 .5529 m .4107 .55762 L .38478 .56385 L p F P
0 g
s
.315 0 0 r
.44357 .54689 m .43938 .55121 L .41531 .5529 L p F P
0 g
s
.051 0 0 r
.53816 .74078 m .53495 .7407 L .53913 .74075 L closepath p F P
0 g
s
.105 0 0 r
.53495 .7407 m .53816 .74078 L p .50678 .7411 L F P
0 g
s
.342 .741 .983 r
.6338 .75113 m .63893 .75435 L .64779 .75417 L closepath p F P
0 g
s
.098 .632 .863 r
.63893 .75435 m .6338 .75113 L .63158 .75041 L p F P
0 g
s
.229 .727 .91 r
.52476 .73794 m .49993 .74062 L .50678 .7411 L p F P
0 g
s
.229 .727 .91 r
.50678 .7411 m .5315 .73988 L .52476 .73794 L p F P
0 g
s
.105 0 0 r
.53816 .74078 m .5315 .73988 L .50678 .7411 L p F P
0 g
s
0 0 0 r
.50678 .7411 m .49993 .74062 L .47539 .74373 L p F P
0 g
s
.767 .291 .109 r
.71765 .59207 m .71113 .58384 L .71167 .58328 L p F P
0 g
s
.764 .286 .107 r
.71113 .58384 m .71026 .58276 L .71167 .58328 L closepath p F P
0 g
s
.858 .471 .309 r
.75957 .61793 m .76332 .62856 L .75212 .62305 L p F P
0 g
s
.858 .471 .309 r
.75141 .61391 m .75957 .61793 L p .75212 .62305 L F P
0 g
s
.687 .174 .012 r
.6814 .57335 m .67311 .56612 L .67388 .56553 L p F P
0 g
s
.68 .165 .006 r
.67311 .56612 m .67169 .56492 L .67388 .56553 L closepath p F P
0 g
s
.307 .781 .928 r
.493 .73891 m .46835 .74311 L .47539 .74373 L p F P
0 g
s
.75 .271 .106 r
.71026 .58276 m .69622 .57796 L .70395 .58715 L p F P
0 g
s
.75 .271 .106 r
.71113 .58384 m .71026 .58276 L p .70395 .58715 L F P
0 g
s
.456 0 0 r
.60257 .54594 m .6035 .54561 L .60564 .5464 L closepath p F P
0 g
s
.439 0 0 r
.6035 .54561 m .60257 .54594 L .58414 .5438 L p F P
0 g
s
.907 .713 .629 r
.80286 .68716 m .79395 .68127 L .78991 .69447 L p F P
0 g
s
.907 .713 .629 r
.78991 .69447 m .79883 .70034 L .80286 .68716 L p F P
0 g
s
.16 .695 .839 r
.53816 .74078 m .56311 .74094 L p .55463 .73843 L F P
0 g
s
.16 .695 .839 r
.55463 .73843 m .5315 .73988 L .53816 .74078 L p F P
0 g
s
.124 0 0 r
.56959 .74273 m .56311 .74094 L .53816 .74078 L p F P
0 g
s
.664 .147 0 r
.67169 .56492 m .65535 .56075 L .6656 .56899 L p F P
0 g
s
.664 .147 0 r
.67311 .56612 m .67169 .56492 L p .6656 .56899 L F P
0 g
s
.89 .549 .397 r
.77388 .6342 m .76332 .62856 L .76536 .6398 L p F P
0 g
s
.89 .549 .397 r
.76536 .6398 m .77594 .64542 L .77388 .6342 L p F P
0 g
s
.765 .292 .118 r
.70715 .58824 m .71113 .58384 L .71765 .59207 L closepath p F P
0 g
s
.75 .271 .106 r
.70395 .58715 m .70715 .58824 L .71113 .58384 L p F P
0 g
s
.354 0 0 r
.44357 .54689 m .46464 .54422 L p .44714 .55137 L F P
0 g
s
.354 0 0 r
.44714 .55137 m .43938 .55121 L .44357 .54689 L p F P
0 g
s
.909 .665 .557 r
.79565 .66881 m .78621 .66298 L .78447 .67547 L p F P
0 g
s
.909 .665 .557 r
.78447 .67547 m .79395 .68127 L .79565 .66881 L p F P
0 g
s
.379 .828 .935 r
.43679 .74683 m .44394 .74815 L .46835 .74311 L p F P
0 g
s
.438 .863 .94 r
.44394 .74815 m .43679 .74683 L .43435 .74746 L p F P
0 g
s
.904 .611 .479 r
.78593 .65116 m .77594 .64542 L .77618 .65727 L p F P
0 g
s
.904 .611 .479 r
.77618 .65727 m .78621 .66298 L .78593 .65116 L p F P
0 g
s
.353 .109 .399 r
.27939 .63372 m .2892 .62872 L .28288 .64207 L p F P
0 g
s
.353 .109 .399 r
.28288 .64207 m .27779 .64465 L .27939 .63372 L p F P
0 g
s
.338 0 .042 r
.38343 .56584 m .38478 .56385 L .4107 .55762 L p F P
0 g
s
.551 .013 0 r
.60564 .5464 m .61912 .55342 L .5989 .55037 L p F P
0 g
s
.551 .013 0 r
.60257 .54594 m .60564 .5464 L p .5989 .55037 L F P
0 g
s
.687 .176 .019 r
.66858 .56975 m .67311 .56612 L .6814 .57335 L closepath p F P
0 g
s
.664 .147 0 r
.6656 .56899 m .66858 .56975 L .67311 .56612 L p F P
0 g
s
.403 .248 .555 r
.25856 .68109 m .25798 .66803 L .27725 .65663 L p F P
0 g
s
.353 .161 .475 r
.27779 .64465 m .27725 .65663 L .25798 .66803 L p F P
0 g
s
.877 .779 .749 r
.80034 .72031 m .79004 .73533 L .78973 .7351 L p F P
0 g
s
.877 .779 .749 r
.79201 .71437 m .80034 .72031 L p .78973 .7351 L F P
0 g
s
.551 .013 0 r
.5989 .55037 m .59739 .54964 L .60257 .54594 L p F P
0 g
s
.532 0 0 r
.59739 .54964 m .58414 .5438 L .60257 .54594 L closepath p F P
0 g
s
.221 .725 .903 r
.56959 .74273 m .59481 .74336 L p .57845 .74016 L F P
0 g
s
.221 .725 .903 r
.57845 .74016 m .56311 .74094 L .56959 .74273 L p F P
0 g
s
0 .547 .747 r
.60114 .74631 m .59481 .74336 L .56959 .74273 L p F P
0 g
s
.576 .634 .872 r
.30288 .74327 m .31034 .75365 L .28679 .75852 L p F P
0 g
s
.576 .634 .872 r
.29608 .74441 m .30288 .74327 L p .28679 .75852 L F P
0 g
s
.576 .634 .872 r
.28679 .75852 m .28294 .75269 L .29608 .74441 L p F P
0 g
s
.535 .747 .974 r
.69032 .74942 m .66456 .75408 L .67059 .7592 L p F P
0 g
s
.535 .747 .974 r
.67059 .7592 m .69633 .75587 L .69032 .74942 L p F P
0 g
s
.268 .69 .967 r
.64779 .75417 m .66456 .75408 L .67059 .7592 L p F P
0 g
s
.339 .74 .983 r
.64779 .75417 m .66456 .75408 L p .63281 .75051 L F P
0 g
s
.339 .74 .983 r
.63281 .75051 m .6338 .75113 L .64779 .75417 L p F P
0 g
s
.814 .385 .226 r
.73051 .59719 m .71765 .59207 L .72325 .60203 L p F P
0 g
s
.814 .385 .226 r
.72325 .60203 m .7361 .60716 L .73051 .59719 L p F P
0 g
s
.526 .869 .991 r
.41148 .75307 m .41242 .75341 L .43435 .74746 L closepath p F P
0 g
s
.354 0 0 r
.46464 .54422 m .47104 .54452 L p .44714 .55137 L F P
0 g
s
.366 0 0 r
.47104 .54452 m .46464 .54422 L .47222 .54331 L closepath p F P
0 g
s
.785 .797 .862 r
.76125 .74731 m .75931 .74881 L .76506 .75651 L p F P
0 g
s
.785 .797 .862 r
.76506 .75651 m .76959 .75317 L .76125 .74731 L p F P
0 g
s
.858 .471 .309 r
.75212 .62305 m .75029 .61798 L .75141 .61391 L p F P
0 g
s
.857 .469 .309 r
.75029 .61798 m .74828 .61244 L .75141 .61391 L closepath p F P
0 g
s
.53 .004 0 r
.58414 .5438 m .59739 .54964 L p .57629 .54806 L F P
0 g
s
.53 .004 0 r
.56733 .5422 m .58414 .5438 L p .57629 .54806 L F P
0 g
s
.81 .794 .838 r
.76125 .74731 m .76959 .75317 L .78995 .73544 L p F P
0 g
s
.521 .87 .989 r
.40503 .7508 m .41148 .75307 L .43435 .74746 L p F P
0 g
s
.329 0 .027 r
.37995 .57084 m .38343 .56584 L .40745 .56242 L p F P
0 g
s
.338 0 .042 r
.4107 .55762 m .40745 .56242 L .38343 .56584 L p F P
0 g
s
.265 0 0 r
.38343 .56584 m .37995 .57084 L .35531 .57825 L p F P
0 g
s
.358 .067 .327 r
.30238 .61392 m .30382 .61271 L .30254 .61326 L closepath p F P
0 g
s
.291 .005 .294 r
.30254 .61326 m .30238 .61392 L .2892 .62872 L p F P
0 g
s
.399 .288 .611 r
.25911 .68551 m .25579 .68299 L .25856 .68109 L closepath p F P
0 g
s
.409 .314 .636 r
.25579 .68299 m .25911 .68551 L .26061 .69549 L p F P
0 g
s
.345 0 .139 r
.35124 .58627 m .35531 .57825 L .37995 .57084 L p F P
0 g
s
.28 0 .107 r
.35531 .57825 m .35124 .58627 L .32788 .59475 L p F P
0 g
s
.412 0 0 r
.47222 .54331 m .50232 .54119 L p .49007 .54702 L F P
0 g
s
.412 0 0 r
.49007 .54702 m .47104 .54452 L .47222 .54331 L p F P
0 g
s
.316 0 0 r
.50257 .54105 m .50232 .54119 L .47222 .54331 L p F P
0 g
s
.852 .783 .784 r
.78995 .73544 m .79004 .73533 L .78973 .7351 L closepath p F P
0 g
s
.667 .162 .036 r
.65535 .56075 m .63807 .55684 L .64843 .56502 L p F P
0 g
s
.667 .162 .036 r
.64843 .56502 m .6656 .56899 L .65535 .56075 L p F P
0 g
s
.81 .794 .838 r
.78995 .73544 m .78973 .7351 L p .76125 .74731 L F P
0 g
s
.888 .741 .693 r
.79883 .70034 m .78991 .69447 L .78312 .70852 L p F P
0 g
s
.888 .741 .693 r
.78312 .70852 m .79201 .71437 L .79883 .70034 L p F P
0 g
s
.6 .855 .992 r
.39763 .7467 m .37335 .75406 L .38084 .75829 L p F P
0 g
s
.6 .855 .992 r
.38084 .75829 m .40503 .7508 L .39763 .7467 L p F P
0 g
s
.568 .615 .86 r
.29608 .74441 m .28294 .75269 L .27939 .7469 L closepath p F P
0 g
s
.344 .772 .972 r
.60114 .74631 m .61676 .74621 L .59792 .74311 L p F P
0 g
s
.344 .772 .972 r
.59792 .74311 m .59481 .74336 L .60114 .74631 L p F P
0 g
s
.635 .761 .938 r
.72206 .74727 m .69633 .75587 L .70227 .76203 L p F P
0 g
s
.635 .761 .938 r
.70227 .76203 m .72797 .75461 L .72206 .74727 L p F P
0 g
s
.877 .779 .749 r
.78973 .7351 m .78417 .72615 L .79201 .71437 L p F P
0 g
s
.81 .794 .838 r
.78973 .7351 m .78105 .7296 L .76125 .74731 L p F P
0 g
s
.835 .773 .793 r
.78105 .7296 m .78973 .7351 L .78417 .72615 L closepath p F P
0 g
s
.748 .279 .135 r
.69622 .57796 m .6814 .57335 L .68915 .58252 L p F P
0 g
s
.748 .279 .135 r
.68915 .58252 m .70395 .58715 L .69622 .57796 L p F P
0 g
s
.622 .743 .933 r
.33422 .74763 m .31034 .75365 L .31787 .76217 L p F P
0 g
s
.622 .743 .933 r
.31787 .76217 m .34173 .75544 L .33422 .74763 L p F P
0 g
s
.354 .061 .322 r
.30008 .62325 m .30238 .61392 L .30382 .61271 L p F P
0 g
s
.299 .014 .301 r
.30008 .62325 m .30238 .61392 L .2892 .62872 L closepath p F P
0 g
s
.354 .061 .322 r
.30382 .61271 m .3246 .60378 L p .30008 .62325 L F P
0 g
s
.292 0 .208 r
.3246 .60378 m .32671 .59803 L .30382 .61271 L closepath p F P
0 g
s
.288 0 .204 r
.32788 .59475 m .32671 .59803 L .30382 .61271 L p F P
0 g
s
.845 .457 .313 r
.74828 .61244 m .7361 .60716 L .73998 .61776 L p F P
0 g
s
.845 .457 .313 r
.75029 .61798 m .74828 .61244 L p .73998 .61776 L F P
0 g
s
.628 .809 .97 r
.36585 .74831 m .34173 .75544 L .34928 .76162 L p F P
0 g
s
.628 .809 .97 r
.34928 .76162 m .37335 .75406 L .36585 .74831 L p F P
0 g
s
.719 .769 .892 r
.75169 .74173 m .72797 .75461 L .73382 .76163 L p F P
0 g
s
.719 .769 .892 r
.75556 .7436 m .75169 .74173 L p .73382 .76163 L F P
0 g
s
.719 .769 .892 r
.73382 .76163 m .75931 .74881 L .75556 .7436 L p F P
0 g
s
.357 .015 .242 r
.32671 .59803 m .32788 .59475 L .35124 .58627 L p F P
0 g
s
.53 .004 0 r
.57629 .54806 m .56565 .54362 L .56733 .5422 L p F P
0 g
s
.505 0 0 r
.56565 .54362 m .56066 .54182 L .56733 .5422 L closepath p F P
0 g
s
.486 0 0 r
.56066 .54182 m .53436 .54074 L .55145 .54645 L p F P
0 g
s
.486 0 0 r
.56565 .54362 m .56066 .54182 L p .55145 .54645 L F P
0 g
s
.347 0 0 r
.50232 .54119 m .50257 .54105 L .50347 .54116 L closepath p F P
0 g
s
.58 .032 0 r
.63395 .556 m .63529 .55525 L .63807 .55684 L closepath p F P
0 g
s
.548 0 0 r
.61912 .55342 m .63395 .556 L .63529 .55525 L p F P
0 g
s
.898 .701 .628 r
.79395 .68127 m .78447 .67547 L .78042 .6887 L p F P
0 g
s
.898 .701 .628 r
.78042 .6887 m .78991 .69447 L .79395 .68127 L p F P
0 g
s
.223 .669 .952 r
.63281 .75051 m .63158 .75041 L .6338 .75113 L closepath p F P
0 g
s
.359 .116 .402 r
.2892 .62872 m .30008 .62325 L .29857 .63423 L p F P
0 g
s
.359 .116 .402 r
.29857 .63423 m .28288 .64207 L .2892 .62872 L p F P
0 g
s
.448 .331 .627 r
.25856 .68109 m .27789 .66976 L .27989 .68416 L p F P
0 g
s
.448 .331 .627 r
.25911 .68551 m .25856 .68109 L p .27989 .68416 L F P
0 g
s
.403 .248 .555 r
.27725 .65663 m .27789 .66976 L .25856 .68109 L p F P
0 g
s
.458 0 0 r
.50347 .54116 m .50232 .54119 L .49683 .54654 L p F P
0 g
s
.412 0 0 r
.50232 .54119 m .49683 .54654 L .49007 .54702 L p F P
0 g
s
.879 .541 .406 r
.76332 .62856 m .75212 .62305 L .75415 .63429 L p F P
0 g
s
.879 .541 .406 r
.75415 .63429 m .76536 .6398 L .76332 .62856 L p F P
0 g
s
.458 0 0 r
.49683 .54654 m .52338 .54588 L .50347 .54116 L p F P
0 g
s
.45 0 0 r
.53398 .54073 m .50347 .54116 L .52338 .54588 L p F P
0 g
s
.35 0 0 r
.53407 .54068 m .53398 .54073 L .50347 .54116 L p F P
0 g
s
.568 .602 .847 r
.27939 .7469 m .27215 .73261 L p .3016 .74118 L F P
0 g
s
.568 .602 .847 r
.3016 .74118 m .29608 .74441 L .27939 .7469 L p F P
0 g
s
.389 0 0 r
.53398 .54073 m .53407 .54068 L .53436 .54074 L closepath p F P
0 g
s
.498 0 0 r
.53436 .54074 m .53398 .54073 L .52847 .5458 L p F P
0 g
s
.498 0 0 r
.52847 .5458 m .55145 .54645 L .53436 .54074 L p F P
0 g
s
.45 0 0 r
.52338 .54588 m .52847 .5458 L .53398 .54073 L p F P
0 g
s
.409 0 0 r
.4667 .54887 m .47104 .54452 L .49007 .54702 L closepath p F P
0 g
s
.354 0 0 r
.47104 .54452 m .4667 .54887 L .44714 .55137 L p F P
0 g
s
.195 .663 .938 r
.63281 .75051 m .63158 .75041 L .61676 .74621 L p F P
0 g
s
.899 .654 .559 r
.78621 .66298 m .77618 .65727 L .77442 .66978 L p F P
0 g
s
.899 .654 .559 r
.77442 .66978 m .78447 .67547 L .78621 .66298 L p F P
0 g
s
.893 .601 .485 r
.77594 .64542 m .76536 .6398 L .76557 .65166 L p F P
0 g
s
.893 .601 .485 r
.76557 .65166 m .77618 .65727 L .77594 .64542 L p F P
0 g
s
.513 .513 .794 r
.27215 .73261 m .2669 .73256 L .27092 .72975 L closepath p F P
0 g
s
.384 0 .057 r
.4107 .55762 m .438 .55259 L p .41878 .56213 L F P
0 g
s
.384 0 .057 r
.41878 .56213 m .40745 .56242 L .4107 .55762 L p F P
0 g
s
.302 0 0 r
.43938 .55121 m .438 .55259 L .4107 .55762 L p F P
0 g
s
.448 .331 .627 r
.27989 .68416 m .2697 .69006 L .25911 .68551 L p F P
0 g
s
.445 .334 .634 r
.2697 .69006 m .26061 .69549 L .25911 .68551 L closepath p F P
0 g
s
.473 .743 .987 r
.65229 .74286 m .6266 .74627 L .63281 .75051 L p F P
0 g
s
.473 .743 .987 r
.63281 .75051 m .65846 .74867 L .65229 .74286 L p F P
0 g
s
.339 .74 .983 r
.66456 .75408 m .65846 .74867 L .63281 .75051 L p F P
0 g
s
.195 .663 .938 r
.61676 .74621 m .6266 .74627 L .63281 .75051 L p F P
0 g
s
.404 .201 .487 r
.27779 .64465 m .28288 .64207 L .28485 .65281 L p F P
0 g
s
.404 .201 .487 r
.28485 .65281 m .27725 .65663 L .27779 .64465 L p F P
0 g
s
.796 .374 .246 r
.71765 .59207 m .72325 .60203 L .70969 .59706 L p F P
0 g
s
.796 .374 .246 r
.70715 .58824 m .71765 .59207 L p .70969 .59706 L F P
0 g
s
.866 .76 .743 r
.78417 .72615 m .79201 .71437 L .78312 .70852 L p F P
0 g
s
.647 .148 .049 r
.63807 .55684 m .64843 .56502 L .6303 .56131 L p F P
0 g
s
.647 .148 .049 r
.63395 .556 m .63807 .55684 L p .6303 .56131 L F P
0 g
s
.352 .008 .234 r
.3246 .60378 m .32671 .59803 L .35085 .58742 L p F P
0 g
s
.357 .015 .242 r
.35124 .58627 m .35085 .58742 L .32671 .59803 L p F P
0 g
s
.855 .469 .315 r
.74932 .62177 m .75029 .61798 L .75212 .62305 L closepath p F P
0 g
s
.845 .457 .313 r
.73998 .61776 m .74932 .62177 L .75029 .61798 L p F P
0 g
s
.647 .148 .049 r
.6303 .56131 m .62946 .56069 L .63395 .556 L p F P
0 g
s
.636 .135 .042 r
.62946 .56069 m .61912 .55342 L .63395 .556 L closepath p F P
0 g
s
.475 .434 .732 r
.26522 .71409 m .26144 .71349 L .26441 .71145 L closepath p F P
0 g
s
.494 .476 .766 r
.26144 .71349 m .26522 .71409 L .27092 .72975 L p F P
0 g
s
.732 .274 .162 r
.6814 .57335 m .68915 .58252 L .67354 .57809 L p F P
0 g
s
.732 .274 .162 r
.66858 .56975 m .6814 .57335 L p .67354 .57809 L F P
0 g
s
.529 .003 0 r
.56173 .54688 m .56565 .54362 L .57629 .54806 L closepath p F P
0 g
s
.486 0 0 r
.55145 .54645 m .56173 .54688 L .56565 .54362 L p F P
0 g
s
.349 0 0 r
.438 .55259 m .43938 .55121 L .44714 .55137 L closepath p F P
0 g
s
.481 .403 .692 r
.26441 .71145 m .26061 .69549 L .2697 .69006 L p F P
0 g
s
.352 .808 .94 r
.49993 .74062 m .52476 .73794 L p .49365 .73881 L F P
0 g
s
.352 .808 .94 r
.49365 .73881 m .493 .73891 L .49993 .74062 L p F P
0 g
s
.383 .818 .959 r
.46356 .74173 m .46835 .74311 L .493 .73891 L p F P
0 g
s
.379 .828 .935 r
.46835 .74311 m .46356 .74173 L .43679 .74683 L p F P
0 g
s
.537 .527 .792 r
.29004 .71844 m .29554 .73038 L .27215 .73261 L p F P
0 g
s
.537 .527 .792 r
.27215 .73261 m .27092 .72975 L .29004 .71844 L p F P
0 g
s
.568 .602 .847 r
.27215 .73261 m .29554 .73038 L .3016 .74118 L p F P
0 g
s
.328 .789 .941 r
.5315 .73988 m .55463 .73843 L .52788 .73753 L p F P
0 g
s
.328 .789 .941 r
.52788 .73753 m .52476 .73794 L .5315 .73988 L p F P
0 g
s
.521 .87 .989 r
.43435 .74746 m .43671 .74682 L p .40503 .7508 L F P
0 g
s
.444 .865 .945 r
.43671 .74682 m .43435 .74746 L .43679 .74683 L closepath p F P
0 g
s
.789 .79 .853 r
.75931 .74881 m .76125 .74731 L .75556 .7436 L closepath p F P
0 g
s
.571 .753 .963 r
.68425 .74259 m .65846 .74867 L .66456 .75408 L p F P
0 g
s
.571 .753 .963 r
.66456 .75408 m .69032 .74942 L .68425 .74259 L p F P
0 g
s
.866 .76 .743 r
.78312 .70852 m .77829 .71604 L .78417 .72615 L p F P
0 g
s
.834 .758 .779 r
.78417 .72615 m .78105 .7296 L .7715 .72397 L p F P
0 g
s
.834 .758 .779 r
.7715 .72397 m .77829 .71604 L .78417 .72615 L p F P
0 g
s
.837 .458 .332 r
.7361 .60716 m .72325 .60203 L .7271 .61264 L p F P
0 g
s
.837 .458 .332 r
.7271 .61264 m .73998 .61776 L .7361 .60716 L p F P
0 g
s
.818 .793 .828 r
.78105 .7296 m .76125 .74731 L .75556 .7436 L p F P
0 g
s
.515 .485 .762 r
.28839 .71431 m .29004 .71844 L .27092 .72975 L p F P
0 g
s
.515 .485 .762 r
.27092 .72975 m .26522 .71409 L .28839 .71431 L p F P
0 g
s
.409 .204 .487 r
.28288 .64207 m .29857 .63423 L .29809 .64625 L p F P
0 g
s
.409 .204 .487 r
.29809 .64625 m .28485 .65281 L .28288 .64207 L p F P
0 g
s
.818 .793 .828 r
.7715 .72397 m .78105 .7296 L p .75556 .7436 L F P
0 g
s
.881 .73 .689 r
.78991 .69447 m .78042 .6887 L .77369 .70275 L p F P
0 g
s
.881 .73 .689 r
.77369 .70275 m .78312 .70852 L .78991 .69447 L p F P
0 g
s
.39 .836 .933 r
.43671 .74682 m .43679 .74683 L .46356 .74173 L p F P
0 g
s
.611 .691 .9 r
.32674 .73799 m .30288 .74327 L .31034 .75365 L p F P
0 g
s
.611 .691 .9 r
.31034 .75365 m .33422 .74763 L .32674 .73799 L p F P
0 g
s
.519 .847 .998 r
.45407 .73764 m .42944 .74396 L .43671 .74682 L p F P
0 g
s
.519 .847 .998 r
.43671 .74682 m .46124 .74109 L .45407 .73764 L p F P
0 g
s
.39 .836 .933 r
.46356 .74173 m .46124 .74109 L .43671 .74682 L p F P
0 g
s
.521 .87 .989 r
.43671 .74682 m .42944 .74396 L .40503 .7508 L p F P
0 g
s
.481 .403 .692 r
.28167 .69233 m .28368 .70017 L .26441 .71145 L p F P
0 g
s
.481 .403 .692 r
.2697 .69006 m .28167 .69233 L p .26441 .71145 L F P
0 g
s
.506 .454 .732 r
.26522 .71409 m .26441 .71145 L .28368 .70017 L p F P
0 g
s
.506 .454 .732 r
.28368 .70017 m .28839 .71431 L .26522 .71409 L p F P
0 g
s
.621 .117 .032 r
.61912 .55342 m .5989 .55037 L .61025 .55817 L p F P
0 g
s
.621 .117 .032 r
.62946 .56069 m .61912 .55342 L p .61025 .55817 L F P
0 g
s
.284 .747 .949 r
.55726 .7386 m .56311 .74094 L .57845 .74016 L closepath p F P
0 g
s
.16 .695 .839 r
.56311 .74094 m .55726 .7386 L .55463 .73843 L p F P
0 g
s
.25 .713 .948 r
.6266 .74627 m .61676 .74621 L .59792 .74311 L p F P
0 g
s
.403 .004 .166 r
.376 .57885 m .37995 .57084 L .40596 .56454 L p F P
0 g
s
.345 0 .139 r
.37995 .57084 m .376 .57885 L .35124 .58627 L p F P
0 g
s
.329 0 .027 r
.40745 .56242 m .40596 .56454 L .37995 .57084 L p F P
0 g
s
.796 .374 .246 r
.70969 .59706 m .70604 .59073 L .70715 .58824 L p F P
0 g
s
.793 .371 .244 r
.70604 .59073 m .70395 .58715 L .70715 .58824 L closepath p F P
0 g
s
.411 .158 .418 r
.29857 .63423 m .30008 .62325 L .32224 .6138 L p F P
0 g
s
.354 .061 .322 r
.3246 .60378 m .32224 .6138 L .30008 .62325 L p F P
0 g
s
.868 .532 .413 r
.75212 .62305 m .74932 .62177 L .74899 .63195 L p F P
0 g
s
.868 .532 .413 r
.74899 .63195 m .75415 .63429 L .75212 .62305 L p F P
0 g
s
.656 .758 .925 r
.71607 .73951 m .69032 .74942 L .69633 .75587 L p F P
0 g
s
.656 .758 .925 r
.69633 .75587 m .72206 .74727 L .71607 .73951 L p F P
0 g
s
.584 .844 .994 r
.42213 .73962 m .39763 .7467 L .40503 .7508 L p F P
0 g
s
.584 .844 .994 r
.40503 .7508 m .42944 .74396 L .42213 .73962 L p F P
0 g
s
.889 .689 .627 r
.78447 .67547 m .77442 .66978 L .77037 .68302 L p F P
0 g
s
.889 .689 .627 r
.77037 .68302 m .78042 .6887 L .78447 .67547 L p F P
0 g
s
.731 .775 .888 r
.74043 .73655 m .72206 .74727 L .72797 .75461 L p F P
0 g
s
.731 .775 .888 r
.72797 .75461 m .75169 .74173 L .74043 .73655 L p F P
0 g
s
.439 0 .077 r
.43336 .55943 m .438 .55259 L .44714 .55137 L p F P
0 g
s
.384 0 .057 r
.438 .55259 m .43336 .55943 L .41878 .56213 L p F P
0 g
s
.732 .274 .162 r
.67354 .57809 m .6676 .57123 L .66858 .56975 L p F P
0 g
s
.726 .267 .159 r
.6676 .57123 m .6656 .56899 L .66858 .56975 L closepath p F P
0 g
s
.628 .759 .941 r
.35837 .7409 m .33422 .74763 L .34173 .75544 L p F P
0 g
s
.628 .759 .941 r
.34173 .75544 m .36585 .74831 L .35837 .7409 L p F P
0 g
s
.883 .592 .489 r
.76536 .6398 m .75415 .63429 L .75435 .64617 L p F P
0 g
s
.883 .592 .489 r
.75435 .64617 m .76557 .65166 L .76536 .6398 L p F P
0 g
s
.781 .357 .244 r
.70395 .58715 m .68915 .58252 L .69506 .59237 L p F P
0 g
s
.781 .357 .244 r
.70604 .59073 m .70395 .58715 L p .69506 .59237 L F P
0 g
s
.62 .812 .974 r
.39021 .74104 m .36585 .74831 L .37335 .75406 L p F P
0 g
s
.62 .812 .974 r
.37335 .75406 m .39763 .7467 L .39021 .74104 L p F P
0 g
s
.89 .643 .56 r
.77618 .65727 m .76557 .65166 L .76379 .66419 L p F P
0 g
s
.89 .643 .56 r
.76379 .66419 m .77442 .66978 L .77618 .65727 L p F P
0 g
s
.859 .523 .415 r
.74932 .62177 m .73998 .61776 L .74205 .629 L p F P
0 g
s
.859 .523 .415 r
.74205 .629 m .74899 .63195 L .74932 .62177 L p F P
0 g
s
.551 .013 0 r
.59677 .55009 m .59739 .54964 L .5989 .55037 L closepath p F P
0 g
s
.53 .004 0 r
.59739 .54964 m .59677 .55009 L .57629 .54806 L p F P
0 g
s
.713 .251 .154 r
.6656 .56899 m .64843 .56502 L .65676 .57397 L p F P
0 g
s
.713 .251 .154 r
.6676 .57123 m .6656 .56899 L p .65676 .57397 L F P
0 g
s
.439 0 .077 r
.44714 .55137 m .46372 .55329 L p .43336 .55943 L F P
0 g
s
.438 0 .068 r
.46372 .55329 m .44714 .55137 L .4667 .54887 L closepath p F P
0 g
s
.575 .619 .859 r
.30288 .74327 m .29608 .74441 L .3016 .74118 L closepath p F P
0 g
s
.447 .282 .563 r
.27725 .65663 m .28485 .65281 L .29601 .6607 L p F P
0 g
s
.447 .282 .563 r
.29601 .6607 m .27789 .66976 L .27725 .65663 L p F P
0 g
s
.384 .775 .988 r
.59346 .74259 m .59481 .74336 L .59792 .74311 L closepath p F P
0 g
s
.221 .725 .903 r
.59481 .74336 m .59346 .74259 L .57845 .74016 L p F P
0 g
s
.413 .068 .267 r
.35085 .58742 m .35124 .58627 L .376 .57885 L p F P
0 g
s
.412 .112 .343 r
.32224 .6138 m .3246 .60378 L .34808 .59531 L p F P
0 g
s
.352 .008 .234 r
.35085 .58742 m .34808 .59531 L .3246 .60378 L p F P
0 g
s
.863 .748 .734 r
.77829 .71604 m .78312 .70852 L .77369 .70275 L p F P
0 g
s
.818 .793 .828 r
.75556 .7436 m .75347 .74065 L .7715 .72397 L p F P
0 g
s
.748 .775 .875 r
.75169 .74173 m .75556 .7436 L .75347 .74065 L closepath p F P
0 g
s
.63 .145 .084 r
.5989 .55037 m .59677 .55009 L .59213 .55576 L p F P
0 g
s
.63 .145 .084 r
.59213 .55576 m .61025 .55817 L .5989 .55037 L p F P
0 g
s
.379 0 .045 r
.40596 .56454 m .40745 .56242 L .41878 .56213 L closepath p F P
0 g
s
.599 .11 .064 r
.59677 .55009 m .57629 .54806 L .58884 .55544 L p F P
0 g
s
.599 .11 .064 r
.58884 .55544 m .59213 .55576 L .59677 .55009 L p F P
0 g
s
.41 .062 .26 r
.34808 .59531 m .35085 .58742 L .37491 .58213 L p F P
0 g
s
.413 .068 .267 r
.376 .57885 m .37491 .58213 L .35085 .58742 L p F P
0 g
s
.379 .773 .987 r
.59792 .74311 m .62032 .74156 L p .5884 .73974 L F P
0 g
s
.379 .773 .987 r
.5884 .73974 m .59346 .74259 L .59792 .74311 L p F P
0 g
s
.25 .713 .948 r
.59792 .74311 m .62032 .74156 L .6266 .74627 L p F P
0 g
s
.479 .391 .678 r
.28167 .69233 m .2697 .69006 L .27989 .68416 L closepath p F P
0 g
s
.827 .452 .344 r
.72325 .60203 m .70969 .59706 L .71353 .60767 L p F P
0 g
s
.827 .452 .344 r
.71353 .60767 m .7271 .61264 L .72325 .60203 L p F P
0 g
s
.732 .274 .165 r
.66465 .57579 m .6676 .57123 L .67354 .57809 L closepath p F P
0 g
s
.713 .251 .154 r
.65676 .57397 m .66465 .57579 L .6676 .57123 L p F P
0 g
s
.341 .752 .98 r
.5884 .73974 m .57845 .74016 L .59346 .74259 L closepath p F P
0 g
s
.794 .374 .249 r
.70413 .59519 m .70604 .59073 L .70969 .59706 L closepath p F P
0 g
s
.781 .357 .244 r
.69506 .59237 m .70413 .59519 L .70604 .59073 L p F P
0 g
s
.863 .748 .734 r
.77369 .70275 m .7723 .70501 L .77829 .71604 L p F P
0 g
s
.833 .742 .764 r
.77829 .71604 m .7715 .72397 L .76145 .71841 L p F P
0 g
s
.833 .742 .764 r
.76145 .71841 m .7723 .70501 L .77829 .71604 L p F P
0 g
s
.476 .02 .089 r
.4667 .54887 m .49007 .54702 L p .47083 .55483 L F P
0 g
s
.476 .02 .089 r
.47083 .55483 m .46372 .55329 L .4667 .54887 L p F P
0 g
s
.529 .754 .979 r
.64604 .73655 m .62032 .74156 L .6266 .74627 L p F P
0 g
s
.529 .754 .979 r
.6266 .74627 m .65229 .74286 L .64604 .73655 L p F P
0 g
s
.59 .626 .855 r
.32227 .731 m .32674 .73799 L .30288 .74327 L p F P
0 g
s
.59 .626 .855 r
.30288 .74327 m .3016 .74118 L .32227 .731 L p F P
0 g
s
.757 .766 .86 r
.75347 .74065 m .75169 .74173 L .74043 .73655 L p F P
0 g
s
.373 .815 .953 r
.46124 .74109 m .46356 .74173 L .49284 .73884 L p F P
0 g
s
.383 .818 .959 r
.493 .73891 m .49284 .73884 L .46356 .74173 L p F P
0 g
s
.807 .767 .816 r
.75347 .74065 m .7715 .72397 L .76145 .71841 L p F P
0 g
s
.589 .113 .093 r
.57629 .54806 m .58884 .55544 L .56497 .55346 L p F P
0 g
s
.589 .113 .093 r
.56173 .54688 m .57629 .54806 L p .56497 .55346 L F P
0 g
s
.807 .767 .816 r
.76145 .71841 m .74755 .73189 L .75347 .74065 L p F P
0 g
s
.757 .766 .86 r
.74043 .73655 m .74755 .73189 L .75347 .74065 L p F P
0 g
s
.882 .723 .681 r
.78042 .6887 m .77369 .70275 L .77014 .70075 L p F P
0 g
s
.882 .723 .681 r
.77037 .68302 m .78042 .6887 L p .77014 .70075 L F P
0 g
s
.578 .603 .841 r
.31935 .72611 m .32227 .731 L .3016 .74118 L p F P
0 g
s
.578 .603 .841 r
.3016 .74118 m .29554 .73038 L .31935 .72611 L p F P
0 g
s
.71 .26 .181 r
.64843 .56502 m .6303 .56131 L .6387 .57022 L p F P
0 g
s
.71 .26 .181 r
.6387 .57022 m .65676 .57397 L .64843 .56502 L p F P
0 g
s
.849 .517 .424 r
.73998 .61776 m .7271 .61264 L .72911 .62389 L p F P
0 g
s
.849 .517 .424 r
.72911 .62389 m .74205 .629 L .73998 .61776 L p F P
0 g
s
.775 .362 .266 r
.68915 .58252 m .67354 .57809 L .67946 .58792 L p F P
0 g
s
.775 .362 .266 r
.67946 .58792 m .69506 .59237 L .68915 .58252 L p F P
0 g
s
.45 .281 .56 r
.28485 .65281 m .29809 .64625 L .29872 .65937 L p F P
0 g
s
.45 .281 .56 r
.29872 .65937 m .29601 .6607 L .28485 .65281 L p F P
0 g
s
.476 .02 .089 r
.49007 .54702 m .49557 .54841 L p .47083 .55483 L F P
0 g
s
.489 .028 .085 r
.49557 .54841 m .49007 .54702 L .49683 .54654 L closepath p F P
0 g
s
.452 .051 .187 r
.40213 .57253 m .40596 .56454 L .41878 .56213 L p F P
0 g
s
.403 .004 .166 r
.40596 .56454 m .40213 .57253 L .376 .57885 L p F P
0 g
s
.589 .113 .093 r
.56497 .55346 m .55922 .55026 L .56173 .54688 L p F P
0 g
s
.568 .09 .081 r
.55922 .55026 m .55145 .54645 L .56173 .54688 L closepath p F P
0 g
s
.606 .754 .949 r
.6781 .73528 m .65229 .74286 L .65846 .74867 L p F P
0 g
s
.606 .754 .949 r
.65846 .74867 m .68425 .74259 L .6781 .73528 L p F P
0 g
s
.887 .685 .624 r
.77442 .66978 m .77037 .68302 L .75991 .67754 L p F P
0 g
s
.887 .685 .624 r
.76379 .66419 m .77442 .66978 L p .75991 .67754 L F P
0 g
s
.521 .061 .102 r
.49683 .54654 m .52338 .54588 L p .5077 .55257 L F P
0 g
s
.521 .061 .102 r
.5077 .55257 m .49557 .54841 L .49683 .54654 L p F P
0 g
s
.483 .354 .628 r
.27989 .68416 m .27789 .66976 L .29601 .6607 L p F P
0 g
s
.274 .742 .944 r
.57845 .74016 m .5884 .73974 L p .55655 .73832 L F P
0 g
s
.274 .742 .944 r
.55655 .73832 m .55726 .7386 L .57845 .74016 L p F P
0 g
s
.558 .092 .103 r
.55145 .54645 m .55922 .55026 L p .53827 .55239 L F P
0 g
s
.558 .092 .103 r
.52847 .5458 m .55145 .54645 L p .53827 .55239 L F P
0 g
s
.872 .582 .493 r
.75415 .63429 m .74899 .63195 L .75042 .64439 L p F P
0 g
s
.872 .582 .493 r
.75042 .64439 m .75435 .64617 L .75415 .63429 L p F P
0 g
s
.453 .239 .497 r
.29809 .64625 m .29857 .63423 L .32082 .62481 L p F P
0 g
s
.411 .158 .418 r
.32224 .6138 m .32082 .62481 L .29857 .63423 L p F P
0 g
s
.886 .638 .558 r
.76557 .65166 m .76379 .66419 L .75386 .65935 L p F P
0 g
s
.886 .638 .558 r
.75435 .64617 m .76557 .65166 L p .75386 .65935 L F P
0 g
s
.521 .061 .102 r
.52338 .54588 m .52737 .54739 L p .5077 .55257 L F P
0 g
s
.532 .064 .089 r
.52737 .54739 m .52338 .54588 L .52847 .5458 L closepath p F P
0 g
s
.558 .092 .103 r
.53827 .55239 m .52737 .54739 L .52847 .5458 L p F P
0 g
s
.741 .773 .879 r
.7291 .73135 m .71607 .73951 L .72206 .74727 L p F P
0 g
s
.741 .773 .879 r
.72206 .74727 m .74043 .73655 L .7291 .73135 L p F P
0 g
s
.622 .708 .907 r
.35092 .73167 m .32674 .73799 L .33422 .74763 L p F P
0 g
s
.622 .708 .907 r
.33422 .74763 m .35837 .7409 L .35092 .73167 L p F P
0 g
s
.676 .753 .909 r
.71 .73123 m .68425 .74259 L .69032 .74942 L p F P
0 g
s
.676 .753 .909 r
.69032 .74942 m .71607 .73951 L .71 .73123 L p F P
0 g
s
.439 .82 .99 r
.49284 .73884 m .493 .73891 L .49365 .73881 L closepath p F P
0 g
s
.432 .819 .988 r
.48601 .73587 m .49284 .73884 L .49365 .73881 L p F P
0 g
s
.373 .815 .953 r
.49284 .73884 m .48601 .73587 L .46124 .74109 L p F P
0 g
s
.53 .824 .999 r
.47896 .7315 m .45407 .73764 L .46124 .74109 L p F P
0 g
s
.53 .824 .999 r
.46124 .74109 m .48601 .73587 L .47896 .7315 L p F P
0 g
s
.432 .819 .988 r
.49365 .73881 m .51795 .73484 L p .48601 .73587 L F P
0 g
s
.435 .819 .989 r
.51795 .73484 m .49365 .73881 L .52381 .7375 L closepath p F P
0 g
s
.352 .808 .94 r
.52476 .73794 m .52381 .7375 L .49365 .73881 L p F P
0 g
s
.405 .802 .986 r
.52381 .7375 m .52476 .73794 L .52788 .73753 L closepath p F P
0 g
s
.285 .749 .947 r
.55655 .73832 m .55463 .73843 L .55726 .7386 L closepath p F P
0 g
s
.245 .736 .919 r
.55655 .73832 m .55463 .73843 L .52788 .73753 L p F P
0 g
s
.452 .051 .187 r
.41878 .56213 m .43164 .56311 L p .40213 .57253 L F P
0 g
s
.454 .052 .186 r
.43164 .56311 m .41878 .56213 L .43336 .55943 L closepath p F P
0 g
s
.578 .825 .992 r
.44687 .73274 m .42213 .73962 L .42944 .74396 L p F P
0 g
s
.578 .825 .992 r
.42944 .74396 m .45407 .73764 L .44687 .73274 L p F P
0 g
s
.647 .148 .05 r
.62908 .56109 m .62946 .56069 L .6303 .56131 L closepath p F P
0 g
s
.621 .117 .032 r
.61025 .55817 m .62908 .56109 L .62946 .56069 L p F P
0 g
s
.817 .446 .353 r
.70969 .59706 m .70413 .59519 L .70248 .60394 L p F P
0 g
s
.817 .446 .353 r
.70248 .60394 m .71353 .60767 L .70969 .59706 L p F P
0 g
s
.565 .556 .803 r
.31211 .71134 m .31935 .72611 L .29554 .73038 L p F P
0 g
s
.565 .556 .803 r
.301 .7129 m .31211 .71134 L p .29554 .73038 L F P
0 g
s
.565 .556 .803 r
.29554 .73038 m .29004 .71844 L .301 .7129 L p F P
0 g
s
.86 .735 .724 r
.7723 .70501 m .77369 .70275 L .77014 .70075 L closepath p F P
0 g
s
.628 .764 .944 r
.38279 .73373 m .35837 .7409 L .36585 .74831 L p F P
0 g
s
.628 .764 .944 r
.36585 .74831 m .39021 .74104 L .38279 .73373 L p F P
0 g
s
.613 .805 .973 r
.4148 .73374 m .39021 .74104 L .39763 .7467 L p F P
0 g
s
.613 .805 .973 r
.39763 .7467 m .42213 .73962 L .4148 .73374 L p F P
0 g
s
.862 .573 .498 r
.74899 .63195 m .74205 .629 L .74214 .64092 L p F P
0 g
s
.862 .573 .498 r
.74214 .64092 m .75042 .64439 L .74899 .63195 L p F P
0 g
s
.481 .773 .996 r
.57533 .73019 m .5499 .73474 L .55655 .73832 L p F P
0 g
s
.481 .773 .996 r
.55655 .73832 m .5819 .73539 L .57533 .73019 L p F P
0 g
s
.274 .742 .944 r
.5884 .73974 m .5819 .73539 L .55655 .73832 L p F P
0 g
s
.245 .736 .919 r
.52788 .73753 m .5499 .73474 L .55655 .73832 L p F P
0 g
s
.702 .258 .194 r
.6303 .56131 m .62908 .56109 L .62542 .56776 L p F P
0 g
s
.702 .258 .194 r
.62542 .56776 m .6387 .57022 L .6303 .56131 L p F P
0 g
s
.833 .743 .765 r
.7723 .70501 m .77014 .70075 L p .75091 .71294 L F P
0 g
s
.833 .743 .765 r
.75091 .71294 m .76145 .71841 L .7723 .70501 L p F P
0 g
s
.457 .106 .282 r
.376 .57885 m .40213 .57253 L p .39762 .58189 L F P
0 g
s
.457 .106 .282 r
.39762 .58189 m .37491 .58213 L .376 .57885 L p F P
0 g
s
.398 .801 .983 r
.52788 .73753 m .5499 .73474 L p .51795 .73484 L F P
0 g
s
.398 .801 .983 r
.51795 .73484 m .52381 .7375 L .52788 .73753 L p F P
0 g
s
.68 .233 .182 r
.62908 .56109 m .61025 .55817 L .61935 .56683 L p F P
0 g
s
.68 .233 .182 r
.61935 .56683 m .62542 .56776 L .62908 .56109 L p F P
0 g
s
.52 .057 .094 r
.49231 .55311 m .49557 .54841 L .5077 .55257 L closepath p F P
0 g
s
.476 .02 .089 r
.49557 .54841 m .49231 .55311 L .47083 .55483 L p F P
0 g
s
.456 .197 .431 r
.32082 .62481 m .32224 .6138 L .34582 .60534 L p F P
0 g
s
.412 .112 .343 r
.34808 .59531 m .34582 .60534 L .32224 .6138 L p F P
0 g
s
.518 .428 .693 r
.27989 .68416 m .30079 .67385 L .30449 .68984 L p F P
0 g
s
.518 .428 .693 r
.28167 .69233 m .27989 .68416 L p .30449 .68984 L F P
0 g
s
.483 .354 .628 r
.29898 .66145 m .30079 .67385 L .27989 .68416 L p F P
0 g
s
.483 .354 .628 r
.29601 .6607 m .29898 .66145 L p .27989 .68416 L F P
0 g
s
.558 .089 .097 r
.52397 .55216 m .52737 .54739 L .53827 .55239 L closepath p F P
0 g
s
.521 .061 .102 r
.52737 .54739 m .52397 .55216 L .5077 .55257 L p F P
0 g
s
.755 .346 .276 r
.67354 .57809 m .67946 .58792 L .66305 .58368 L p F P
0 g
s
.755 .346 .276 r
.66465 .57579 m .67354 .57809 L p .66305 .58368 L F P
0 g
s
.765 .755 .843 r
.74755 .73189 m .74043 .73655 L .7291 .73135 L p F P
0 g
s
.458 .153 .359 r
.34582 .60534 m .34808 .59531 L .37294 .58788 L p F P
0 g
s
.41 .062 .26 r
.37491 .58213 m .37294 .58788 L .34808 .59531 L p F P
0 g
s
.805 .432 .351 r
.70413 .59519 m .69506 .59237 L .6991 .6029 L p F P
0 g
s
.805 .432 .351 r
.6991 .6029 m .70248 .60394 L .70413 .59519 L p F P
0 g
s
.521 .763 .985 r
.60752 .73024 m .5819 .73539 L .5884 .73974 L p F P
0 g
s
.521 .763 .985 r
.5884 .73974 m .61396 .73625 L .60752 .73024 L p F P
0 g
s
.379 .773 .987 r
.62032 .74156 m .61396 .73625 L .5884 .73974 L p F P
0 g
s
.839 .51 .431 r
.7271 .61264 m .71353 .60767 L .71551 .61893 L p F P
0 g
s
.839 .51 .431 r
.71551 .61893 m .72911 .62389 L .7271 .61264 L p F P
0 g
s
.552 .522 .776 r
.301 .7129 m .29004 .71844 L .28839 .71431 L closepath p F P
0 g
s
.518 .428 .693 r
.30449 .68984 m .29918 .69241 L .28167 .69233 L p F P
0 g
s
.518 .436 .702 r
.29918 .69241 m .28368 .70017 L .28167 .69233 L closepath p F P
0 g
s
.81 .758 .805 r
.74755 .73189 m .76145 .71841 L .75091 .71294 L p F P
0 g
s
.833 .743 .765 r
.77014 .70075 m .76316 .69724 L .75091 .71294 L p F P
0 g
s
.882 .723 .681 r
.77014 .70075 m .76615 .69218 L .77037 .68302 L p F P
0 g
s
.852 .716 .711 r
.76316 .69724 m .77014 .70075 L .76615 .69218 L closepath p F P
0 g
s
.867 .703 .676 r
.76615 .69218 m .77037 .68302 L .75991 .67754 L closepath p F P
0 g
s
.492 .088 .203 r
.43336 .55943 m .46213 .55558 L p .44287 .56551 L F P
0 g
s
.492 .088 .203 r
.44287 .56551 m .43164 .56311 L .43336 .55943 L p F P
0 g
s
.439 0 .077 r
.46372 .55329 m .46213 .55558 L .43336 .55943 L p F P
0 g
s
.475 .015 .08 r
.46213 .55558 m .46372 .55329 L .47083 .55483 L closepath p F P
0 g
s
.81 .758 .805 r
.75091 .71294 m .74155 .72248 L .74755 .73189 L p F P
0 g
s
.765 .755 .843 r
.7291 .73135 m .74155 .72248 L .74755 .73189 L p F P
0 g
s
.551 .51 .762 r
.28839 .71431 m .28368 .70017 L p .31079 .70815 L F P
0 g
s
.551 .51 .762 r
.31079 .70815 m .301 .7129 L .28839 .71431 L p F P
0 g
s
.551 .51 .762 r
.28368 .70017 m .29918 .69241 L p .31079 .70815 L F P
0 g
s
.853 .566 .502 r
.74205 .629 m .72911 .62389 L .72913 .63584 L p F P
0 g
s
.853 .566 .502 r
.72913 .63584 m .74214 .64092 L .74205 .629 L p F P
0 g
s
.871 .666 .622 r
.75982 .67727 m .76379 .66419 L .75386 .65935 L closepath p F P
0 g
s
.887 .685 .624 r
.75991 .67754 m .75982 .67727 L .76379 .66419 L p F P
0 g
s
.667 .233 .209 r
.61025 .55817 m .61935 .56683 L .59823 .56397 L p F P
0 g
s
.667 .233 .209 r
.59213 .55576 m .61025 .55817 L p .59823 .56397 L F P
0 g
s
.755 .346 .276 r
.66305 .58368 m .66226 .58244 L .66465 .57579 L p F P
0 g
s
.75 .34 .274 r
.66226 .58244 m .65676 .57397 L .66465 .57579 L closepath p F P
0 g
s
.589 .111 .089 r
.55719 .55294 m .55922 .55026 L .56497 .55346 L closepath p F P
0 g
s
.558 .092 .103 r
.55922 .55026 m .55719 .55294 L .53827 .55239 L p F P
0 g
s
.455 .102 .276 r
.37294 .58788 m .37491 .58213 L .39762 .58189 L closepath p F P
0 g
s
.487 .31 .565 r
.29872 .65937 m .29809 .64625 L .32042 .63686 L p F P
0 g
s
.453 .239 .497 r
.32082 .62481 m .32042 .63686 L .29809 .64625 L p F P
0 g
s
.576 .756 .963 r
.63972 .72961 m .61396 .73625 L .62032 .74156 L p F P
0 g
s
.576 .756 .963 r
.62032 .74156 m .64604 .73655 L .63972 .72961 L p F P
0 g
s
.87 .621 .56 r
.753 .65584 m .75435 .64617 L .75042 .64439 L closepath p F P
0 g
s
.886 .638 .558 r
.75386 .65935 m .753 .65584 L .75435 .64617 L p F P
0 g
s
.796 .428 .361 r
.69506 .59237 m .67946 .58792 L .68345 .59846 L p F P
0 g
s
.796 .428 .361 r
.68345 .59846 m .6991 .6029 L .69506 .59237 L p F P
0 g
s
.606 .647 .864 r
.34436 .7217 m .35092 .73167 L .32674 .73799 L p F P
0 g
s
.606 .647 .864 r
.32674 .73799 m .32227 .731 L .34436 .7217 L p F P
0 g
s
.846 .707 .709 r
.76615 .69218 m .75991 .67754 L p .75181 .6919 L F P
0 g
s
.846 .707 .709 r
.75181 .6919 m .76316 .69724 L .76615 .69218 L p F P
0 g
s
.738 .328 .27 r
.65676 .57397 m .6387 .57022 L .64501 .5799 L p F P
0 g
s
.738 .328 .27 r
.66226 .58244 m .65676 .57397 L p .64501 .5799 L F P
0 g
s
.636 .749 .93 r
.67187 .72737 m .64604 .73655 L .65229 .74286 L p F P
0 g
s
.636 .749 .93 r
.65229 .74286 m .6781 .73528 L .67187 .72737 L p F P
0 g
s
.751 .77 .868 r
.71758 .72613 m .71 .73123 L .71607 .73951 L p F P
0 g
s
.751 .77 .868 r
.71607 .73951 m .7291 .73135 L .71758 .72613 L p F P
0 g
s
.858 .618 .574 r
.75042 .64439 m .74214 .64092 L .74001 .65357 L p F P
0 g
s
.858 .618 .574 r
.753 .65584 m .75042 .64439 L p .74001 .65357 L F P
0 g
s
.667 .233 .209 r
.59823 .56397 m .59126 .55751 L .59213 .55576 L p F P
0 g
s
.654 .219 .203 r
.59126 .55751 m .58884 .55544 L .59213 .55576 L closepath p F P
0 g
s
.832 .734 .755 r
.76316 .69724 m .75181 .6919 L .7399 .70753 L p F P
0 g
s
.832 .734 .755 r
.7399 .70753 m .75091 .71294 L .76316 .69724 L p F P
0 g
s
.535 .126 .211 r
.47083 .55483 m .46213 .55558 L .45847 .56342 L p F P
0 g
s
.492 .088 .203 r
.46213 .55558 m .45847 .56342 L .44287 .56551 L p F P
0 g
s
.694 .744 .89 r
.70386 .72234 m .6781 .73528 L .68425 .74259 L p F P
0 g
s
.694 .744 .89 r
.68425 .74259 m .71 .73123 L .70386 .72234 L p F P
0 g
s
.642 .204 .195 r
.58884 .55544 m .56497 .55346 L .57509 .56172 L p F P
0 g
s
.642 .204 .195 r
.59126 .55751 m .58884 .55544 L p .57509 .56172 L F P
0 g
s
.491 .084 .195 r
.42961 .56735 m .43164 .56311 L .44287 .56551 L closepath p F P
0 g
s
.452 .051 .187 r
.43164 .56311 m .42961 .56735 L .40213 .57253 L p F P
0 g
s
.5 .142 .291 r
.39916 .58152 m .40213 .57253 L .42961 .56735 L p F P
0 g
s
.457 .106 .282 r
.40213 .57253 m .39916 .58152 L .39762 .58189 L p F P
0 g
s
.535 .126 .211 r
.45847 .56342 m .48691 .56095 L .47083 .55483 L p F P
0 g
s
.535 .119 .199 r
.49231 .55311 m .47083 .55483 L .48691 .56095 L p F P
0 g
s
.829 .502 .436 r
.71353 .60767 m .70248 .60394 L .70218 .61445 L p F P
0 g
s
.829 .502 .436 r
.70218 .61445 m .71551 .61893 L .71353 .60767 L p F P
0 g
s
.628 .714 .908 r
.37538 .72459 m .35092 .73167 L .35837 .7409 L p F P
0 g
s
.628 .714 .908 r
.35837 .7409 m .38279 .73373 L .37538 .72459 L p F P
0 g
s
.48 .342 .615 r
.29898 .66145 m .29601 .6607 L .29872 .65937 L closepath p F P
0 g
s
.771 .741 .825 r
.74155 .72248 m .7291 .73135 L .71758 .72613 L p F P
0 g
s
.492 .27 .505 r
.32042 .63686 m .32082 .62481 L .34449 .61638 L p F P
0 g
s
.456 .197 .431 r
.34582 .60534 m .34449 .61638 L .32082 .62481 L p F P
0 g
s
.601 .629 .851 r
.34353 .72035 m .34436 .7217 L .32227 .731 L p F P
0 g
s
.601 .629 .851 r
.32227 .731 m .31935 .72611 L .34353 .72035 L p F P
0 g
s
.858 .618 .574 r
.74001 .65357 m .75248 .65874 L .753 .65584 L p F P
0 g
s
.867 .628 .574 r
.75248 .65874 m .75386 .65935 L .753 .65584 L closepath p F P
0 g
s
.846 .707 .709 r
.75991 .67754 m .75974 .67746 L .75181 .6919 L p F P
0 g
s
.864 .677 .648 r
.75974 .67746 m .75991 .67754 L .75982 .67727 L closepath p F P
0 g
s
.855 .666 .646 r
.75982 .67727 m .75386 .65935 L p .74779 .67221 L F P
0 g
s
.855 .666 .646 r
.74779 .67221 m .75974 .67746 L .75982 .67727 L p F P
0 g
s
.628 .759 .941 r
.40745 .7262 m .38279 .73373 L .39021 .74104 L p F P
0 g
s
.628 .759 .941 r
.39021 .74104 m .4148 .73374 L .40745 .7262 L p F P
0 g
s
.812 .749 .793 r
.74155 .72248 m .75091 .71294 L .7399 .70753 L p F P
0 g
s
.64 .213 .216 r
.56497 .55346 m .55719 .55294 L .55364 .56028 L p F P
0 g
s
.64 .213 .216 r
.55364 .56028 m .57509 .56172 L .56497 .55346 L p F P
0 g
s
.561 .535 .783 r
.31211 .71134 m .301 .7129 L .31079 .70815 L closepath p F P
0 g
s
.845 .694 .695 r
.75974 .67746 m .74779 .67221 L .73997 .68665 L p F P
0 g
s
.845 .694 .695 r
.73997 .68665 m .75181 .6919 L .75974 .67746 L p F P
0 g
s
.585 .801 .982 r
.47186 .72574 m .44687 .73274 L .45407 .73764 L p F P
0 g
s
.585 .801 .982 r
.45407 .73764 m .47896 .7315 L .47186 .72574 L p F P
0 g
s
.558 .798 .989 r
.50411 .72504 m .47896 .7315 L .48601 .73587 L p F P
0 g
s
.558 .798 .989 r
.48601 .73587 m .51106 .73057 L .50411 .72504 L p F P
0 g
s
.432 .819 .988 r
.51795 .73484 m .51106 .73057 L .48601 .73587 L p F P
0 g
s
.612 .789 .966 r
.43963 .72631 m .4148 .73374 L .42213 .73962 L p F P
0 g
s
.612 .789 .966 r
.42213 .73962 m .44687 .73274 L .43963 .72631 L p F P
0 g
s
.667 .232 .207 r
.58857 .56283 m .59126 .55751 L .59823 .56397 L closepath p F P
0 g
s
.642 .204 .195 r
.57509 .56172 m .58857 .56283 L .59126 .55751 L p F P
0 g
s
.573 .158 .216 r
.4887 .56081 m .49231 .55311 L .5077 .55257 L p F P
0 g
s
.535 .119 .199 r
.48691 .56095 m .4887 .56081 L .49231 .55311 L p F P
0 g
s
.513 .365 .618 r
.29898 .66145 m .29872 .65937 L .32113 .65004 L p F P
0 g
s
.487 .31 .565 r
.32042 .63686 m .32113 .65004 L .29872 .65937 L p F P
0 g
s
.544 .787 .988 r
.53638 .72449 m .51106 .73057 L .51795 .73484 L p F P
0 g
s
.544 .787 .988 r
.51795 .73484 m .54318 .73016 L .53638 .72449 L p F P
0 g
s
.398 .801 .983 r
.5499 .73474 m .54318 .73016 L .51795 .73484 L p F P
0 g
s
.855 .666 .646 r
.75386 .65935 m .75248 .65874 L .74779 .67221 L p F P
0 g
s
.812 .749 .793 r
.7399 .70753 m .73546 .7123 L .74155 .72248 L p F P
0 g
s
.771 .741 .825 r
.71758 .72613 m .73546 .7123 L .74155 .72248 L p F P
0 g
s
.843 .558 .505 r
.72911 .62389 m .71551 .61893 L .7155 .63089 L p F P
0 g
s
.843 .558 .505 r
.7155 .63089 m .72913 .63584 L .72911 .62389 L p F P
0 g
s
.61 .181 .202 r
.55719 .55294 m .53827 .55239 L .54972 .56017 L p F P
0 g
s
.61 .181 .202 r
.54972 .56017 m .55364 .56028 L .55719 .55294 L p F P
0 g
s
.573 .158 .216 r
.5077 .55257 m .52053 .55943 L p .4887 .56081 L F P
0 g
s
.574 .152 .203 r
.52053 .55943 m .5077 .55257 L .52397 .55216 L closepath p F P
0 g
s
.513 .365 .618 r
.32113 .65004 m .32265 .66135 L .29898 .66145 L p F P
0 g
s
.517 .379 .633 r
.30079 .67385 m .29898 .66145 L .32265 .66135 L p F P
0 g
s
.723 .326 .296 r
.6387 .57022 m .64501 .5799 L .62603 .57637 L p F P
0 g
s
.723 .326 .296 r
.62542 .56776 m .6387 .57022 L p .62603 .57637 L F P
0 g
s
.787 .424 .369 r
.67946 .58792 m .66305 .58368 L .66704 .59421 L p F P
0 g
s
.787 .424 .369 r
.66704 .59421 m .68345 .59846 L .67946 .58792 L p F P
0 g
s
.5 .189 .371 r
.37079 .59792 m .37294 .58788 L .39762 .58189 L p F P
0 g
s
.458 .153 .359 r
.37294 .58788 m .37079 .59792 L .34582 .60534 L p F P
0 g
s
.596 .174 .213 r
.53827 .55239 m .54972 .56017 L .52095 .5597 L p F P
0 g
s
.596 .174 .213 r
.52397 .55216 m .53827 .55239 L p .52095 .5597 L F P
0 g
s
.851 .652 .633 r
.75248 .65874 m .74001 .65357 L .73531 .66706 L p F P
0 g
s
.851 .652 .633 r
.73531 .66706 m .74779 .67221 L .75248 .65874 L p F P
0 g
s
.85 .607 .57 r
.74214 .64092 m .72913 .63584 L .72696 .64852 L p F P
0 g
s
.85 .607 .57 r
.72696 .64852 m .74001 .65357 L .74214 .64092 L p F P
0 g
s
.55 .773 .981 r
.56868 .72405 m .54318 .73016 L .5499 .73474 L p F P
0 g
s
.55 .773 .981 r
.5499 .73474 m .57533 .73019 L .56868 .72405 L p F P
0 g
s
.596 .174 .213 r
.52095 .5597 m .52053 .55943 L .52397 .55216 L p F P
0 g
s
.497 .23 .441 r
.34449 .61638 m .34582 .60534 L .37079 .59792 L p F P
0 g
s
.598 .597 .821 r
.33626 .70613 m .31211 .71134 L .31935 .72611 L p F P
0 g
s
.598 .597 .821 r
.31935 .72611 m .34353 .72035 L .33626 .70613 L p F P
0 g
s
.576 .761 .966 r
.601 .72339 m .57533 .73019 L .5819 .73539 L p F P
0 g
s
.576 .761 .966 r
.5819 .73539 m .60752 .73024 L .601 .72339 L p F P
0 g
s
.816 .49 .437 r
.70248 .60394 m .6991 .6029 L .70117 .61414 L p F P
0 g
s
.816 .49 .437 r
.70117 .61414 m .70218 .61445 L .70248 .60394 L p F P
0 g
s
.534 .465 .725 r
.30515 .69205 m .29918 .69241 L .30449 .68984 L closepath p F P
0 g
s
.551 .51 .762 r
.29918 .69241 m .30515 .69205 L .31079 .70815 L p F P
0 g
s
.723 .326 .296 r
.62603 .57637 m .62374 .57299 L .62542 .56776 L p F P
0 g
s
.715 .317 .294 r
.62374 .57299 m .61935 .56683 L .62542 .56776 L closepath p F P
0 g
s
.839 .734 .748 r
.75181 .6919 m .7399 .70753 L .73035 .70315 L p F P
0 g
s
.839 .734 .748 r
.73997 .68665 m .75181 .6919 L p .73035 .70315 L F P
0 g
s
.807 .484 .442 r
.6991 .6029 m .68345 .59846 L .68543 .60972 L p F P
0 g
s
.807 .484 .442 r
.68543 .60972 m .70117 .61414 L .6991 .6029 L p F P
0 g
s
.538 .177 .303 r
.42676 .57633 m .42961 .56735 L .44287 .56551 L p F P
0 g
s
.5 .142 .291 r
.42961 .56735 m .42676 .57633 L .39916 .58152 L p F P
0 g
s
.542 .439 .686 r
.30449 .68984 m .30079 .67385 L .32316 .6645 L p F P
0 g
s
.517 .379 .633 r
.32265 .66135 m .32316 .6645 L .30079 .67385 L p F P
0 g
s
.616 .75 .941 r
.63332 .72191 m .60752 .73024 L .61396 .73625 L p F P
0 g
s
.616 .75 .941 r
.61396 .73625 m .63972 .72961 L .63332 .72191 L p F P
0 g
s
.76 .765 .856 r
.7058 .72094 m .70386 .72234 L .71 .73123 L p F P
0 g
s
.76 .765 .856 r
.71 .73123 m .71758 .72613 L .7058 .72094 L p F P
0 g
s
.755 .346 .276 r
.66192 .58341 m .66226 .58244 L .66305 .58368 L closepath p F P
0 g
s
.738 .328 .27 r
.64501 .5799 m .66192 .58341 L .66226 .58244 L p F P
0 g
s
.704 .305 .289 r
.61935 .56683 m .59823 .56397 L .60508 .57343 L p F P
0 g
s
.704 .305 .289 r
.62374 .57299 m .61935 .56683 L p .60508 .57343 L F P
0 g
s
.581 .546 .781 r
.33322 .69898 m .33626 .70613 L .31211 .71134 L p F P
0 g
s
.581 .546 .781 r
.31211 .71134 m .31079 .70815 L .33322 .69898 L p F P
0 g
s
.778 .757 .834 r
.7058 .72094 m .71758 .72613 L .73546 .7123 L p F P
0 g
s
.662 .741 .908 r
.66557 .71873 m .63972 .72961 L .64604 .73655 L p F P
0 g
s
.662 .741 .908 r
.64604 .73655 m .67187 .72737 L .66557 .71873 L p F P
0 g
s
.566 .509 .751 r
.3292 .68792 m .33322 .69898 L .31079 .70815 L p F P
0 g
s
.566 .509 .751 r
.31079 .70815 m .30515 .69205 L .3292 .68792 L p F P
0 g
s
.621 .662 .868 r
.36812 .71356 m .37538 .72459 L .35092 .73167 L p F P
0 g
s
.621 .662 .868 r
.35092 .73167 m .34436 .7217 L .36812 .71356 L p F P
0 g
s
.71 .735 .871 r
.69137 .71644 m .67187 .72737 L .6781 .73528 L p F P
0 g
s
.71 .735 .871 r
.70193 .71936 m .69137 .71644 L p .6781 .73528 L F P
0 g
s
.71 .735 .871 r
.6781 .73528 m .70386 .72234 L .70193 .71936 L p F P
0 g
s
.777 .418 .375 r
.66305 .58368 m .66192 .58341 L .66043 .59265 L p F P
0 g
s
.777 .418 .375 r
.66043 .59265 m .66704 .59421 L .66305 .58368 L p F P
0 g
s
.522 .336 .57 r
.32113 .65004 m .32042 .63686 L .34417 .62847 L p F P
0 g
s
.492 .27 .505 r
.34449 .61638 m .34417 .62847 L .32042 .63686 L p F P
0 g
s
.762 .402 .373 r
.66192 .58341 m .64501 .5799 L .64923 .59034 L p F P
0 g
s
.762 .402 .373 r
.64923 .59034 m .66043 .59265 L .66192 .58341 L p F P
0 g
s
.834 .549 .507 r
.71551 .61893 m .70218 .61445 L .70335 .62681 L p F P
0 g
s
.834 .549 .507 r
.70335 .62681 m .7155 .63089 L .71551 .61893 L p F P
0 g
s
.84 .685 .69 r
.74779 .67221 m .73531 .66706 L .72761 .68148 L p F P
0 g
s
.84 .685 .69 r
.72761 .68148 m .73997 .68665 L .74779 .67221 L p F P
0 g
s
.538 .177 .303 r
.44287 .56551 m .45605 .57119 L p .42676 .57633 L F P
0 g
s
.539 .175 .297 r
.45605 .57119 m .44287 .56551 L .45847 .56342 L closepath p F P
0 g
s
.559 .481 .723 r
.30515 .69205 m .30449 .68984 L .32695 .68061 L p F P
0 g
s
.542 .439 .686 r
.32316 .6645 m .32695 .68061 L .30449 .68984 L p F P
0 g
s
.559 .481 .723 r
.32695 .68061 m .3292 .68792 L .30515 .69205 L p F P
0 g
s
.814 .738 .781 r
.73546 .7123 m .7399 .70753 L .73035 .70315 L closepath p F P
0 g
s
.778 .757 .834 r
.73546 .7123 m .73035 .70315 L p .7058 .72094 L F P
0 g
s
.842 .598 .57 r
.72913 .63584 m .7155 .63089 L .7133 .64359 L p F P
0 g
s
.842 .598 .57 r
.7133 .64359 m .72696 .64852 L .72913 .63584 L p F P
0 g
s
.844 .643 .631 r
.74001 .65357 m .72696 .64852 L .72228 .66201 L p F P
0 g
s
.844 .643 .631 r
.72228 .66201 m .73531 .66706 L .74001 .65357 L p F P
0 g
s
.5 .189 .371 r
.39762 .58189 m .39903 .58218 L p .37079 .59792 L F P
0 g
s
.502 .193 .374 r
.39903 .58218 m .39762 .58189 L .39916 .58152 L closepath p F P
0 g
s
.633 .712 .904 r
.40011 .71683 m .37538 .72459 L .38279 .73373 L p F P
0 g
s
.633 .712 .904 r
.38279 .73373 m .40745 .7262 L .40011 .71683 L p F P
0 g
s
.7 .312 .309 r
.59823 .56397 m .58857 .56283 L .58601 .57119 L p F P
0 g
s
.7 .312 .309 r
.58601 .57119 m .60508 .57343 L .59823 .56397 L p F P
0 g
s
.535 .222 .383 r
.39916 .58152 m .42676 .57633 L p .41154 .5888 L F P
0 g
s
.535 .222 .383 r
.41154 .5888 m .39903 .58218 L .39916 .58152 L p F P
0 g
s
.566 .201 .307 r
.45847 .56342 m .48691 .56095 L p .45762 .57214 L F P
0 g
s
.566 .201 .307 r
.45762 .57214 m .45605 .57119 L .45847 .56342 L p F P
0 g
s
.536 .221 .381 r
.3971 .59156 m .39903 .58218 L .41154 .5888 L closepath p F P
0 g
s
.5 .189 .371 r
.39903 .58218 m .3971 .59156 L .37079 .59792 L p F P
0 g
s
.631 .746 .931 r
.43237 .71822 m .40745 .7262 L .4148 .73374 L p F P
0 g
s
.631 .746 .931 r
.4148 .73374 m .43963 .72631 L .43237 .71822 L p F P
0 g
s
.527 .298 .511 r
.34417 .62847 m .34449 .61638 L .36955 .60897 L p F P
0 g
s
.497 .23 .441 r
.37079 .59792 m .36955 .60897 L .34449 .61638 L p F P
0 g
s
.799 .478 .447 r
.68345 .59846 m .66704 .59421 L .66898 .60547 L p F P
0 g
s
.799 .478 .447 r
.66898 .60547 m .68543 .60972 L .68345 .59846 L p F P
0 g
s
.677 .288 .301 r
.58857 .56283 m .57509 .56172 L .58267 .57091 L p F P
0 g
s
.677 .288 .301 r
.58267 .57091 m .58601 .57119 L .58857 .56283 L p F P
0 g
s
.619 .766 .95 r
.46471 .71847 m .43963 .72631 L .44687 .73274 L p F P
0 g
s
.619 .766 .95 r
.44687 .73274 m .47186 .72574 L .46471 .71847 L p F P
0 g
s
.605 .773 .961 r
.4971 .71815 m .47186 .72574 L .47896 .7315 L p F P
0 g
s
.605 .773 .961 r
.47896 .7315 m .50411 .72504 L .4971 .71815 L p F P
0 g
s
.532 .261 .449 r
.36955 .60897 m .37079 .59792 L .3971 .59156 L p F P
0 g
s
.755 .4 .381 r
.64501 .5799 m .62603 .57637 L .63023 .5868 L p F P
0 g
s
.755 .4 .381 r
.63023 .5868 m .64923 .59034 L .64501 .5799 L p F P
0 g
s
.824 .709 .738 r
.72927 .7011 m .73997 .68665 L .72761 .68148 L p F P
0 g
s
.839 .734 .748 r
.73035 .70315 m .72927 .7011 L .73997 .68665 L p F P
0 g
s
.596 .769 .963 r
.52951 .71759 m .50411 .72504 L .51106 .73057 L p F P
0 g
s
.596 .769 .963 r
.51106 .73057 m .53638 .72449 L .52951 .71759 L p F P
0 g
s
.663 .283 .315 r
.57509 .56172 m .58267 .57091 L .55764 .56921 L p F P
0 g
s
.663 .283 .315 r
.55364 .56028 m .57509 .56172 L p .55764 .56921 L F P
0 g
s
.724 .326 .295 r
.62283 .57583 m .62374 .57299 L .62603 .57637 L closepath p F P
0 g
s
.704 .305 .289 r
.60508 .57343 m .62283 .57583 L .62374 .57299 L p F P
0 g
s
.619 .646 .855 r
.36802 .7134 m .36812 .71356 L .34436 .7217 L p F P
0 g
s
.619 .646 .855 r
.34436 .7217 m .34353 .72035 L .36802 .7134 L p F P
0 g
s
.6 .76 .955 r
.56195 .71682 m .53638 .72449 L .54318 .73016 L p F P
0 g
s
.6 .76 .955 r
.54318 .73016 m .56868 .72405 L .56195 .71682 L p F P
0 g
s
.821 .538 .511 r
.70218 .61445 m .70117 .61414 L .70106 .62613 L p F P
0 g
s
.821 .538 .511 r
.70106 .62613 m .70335 .62681 L .70218 .61445 L p F P
0 g
s
.566 .201 .307 r
.48691 .56095 m .48837 .56194 L p .45762 .57214 L F P
0 g
s
.58 .214 .311 r
.48837 .56194 m .48691 .56095 L .4887 .56081 L closepath p F P
0 g
s
.545 .392 .625 r
.32265 .66135 m .32113 .65004 L .34495 .64169 L p F P
0 g
s
.522 .336 .57 r
.34417 .62847 m .34495 .64169 L .32113 .65004 L p F P
0 g
s
.602 .235 .318 r
.4887 .56081 m .5204 .5597 L p .49706 .56917 L F P
0 g
s
.602 .235 .318 r
.49706 .56917 m .48837 .56194 L .4887 .56081 L p F P
0 g
s
.573 .158 .216 r
.52053 .55943 m .5204 .5597 L .4887 .56081 L p F P
0 g
s
.614 .608 .822 r
.36076 .6993 m .33626 .70613 L .34353 .72035 L p F P
0 g
s
.614 .608 .822 r
.34353 .72035 m .36802 .7134 L .36076 .6993 L p F P
0 g
s
.767 .754 .842 r
.70386 .72234 m .7058 .72094 L .70193 .71936 L closepath p F P
0 g
s
.812 .531 .512 r
.70117 .61414 m .68543 .60972 L .68524 .62174 L p F P
0 g
s
.812 .531 .512 r
.68524 .62174 m .70106 .62613 L .70117 .61414 L p F P
0 g
s
.778 .757 .834 r
.73035 .70315 m .72809 .7023 L .7058 .72094 L p F P
0 g
s
.797 .721 .78 r
.72809 .7023 m .73035 .70315 L .72927 .7011 L closepath p F P
0 g
s
.797 .756 .815 r
.72809 .7023 m .7058 .72094 L .70193 .71936 L p F P
0 g
s
.618 .749 .94 r
.5944 .71557 m .56868 .72405 L .57533 .73019 L p F P
0 g
s
.618 .749 .94 r
.57533 .73019 m .601 .72339 L .5944 .71557 L p F P
0 g
s
.663 .283 .315 r
.55764 .56921 m .55272 .56339 L .55364 .56028 L p F P
0 g
s
.648 .268 .311 r
.55272 .56339 m .54972 .56017 L .55364 .56028 L closepath p F P
0 g
s
.639 .257 .305 r
.54972 .56017 m .52095 .5597 L .52949 .5685 L p F P
0 g
s
.639 .257 .305 r
.55272 .56339 m .54972 .56017 L p .52949 .5685 L F P
0 g
s
.596 .172 .208 r
.5204 .5597 m .52053 .55943 L .52095 .5597 L closepath p F P
0 g
s
.844 .683 .683 r
.73531 .66706 m .72761 .68148 L .7183 .67785 L p F P
0 g
s
.844 .683 .683 r
.72228 .66201 m .73531 .66706 L p .7183 .67785 L F P
0 g
s
.636 .261 .317 r
.52095 .5597 m .5204 .5597 L .5178 .56844 L p F P
0 g
s
.636 .261 .317 r
.5178 .56844 m .52949 .5685 L .52095 .5597 L p F P
0 g
s
.602 .235 .318 r
.5204 .5597 m .5178 .56844 L .49706 .56917 L p F P
0 g
s
.604 .234 .314 r
.48603 .56966 m .48837 .56194 L .49706 .56917 L closepath p F P
0 g
s
.566 .201 .307 r
.48837 .56194 m .48603 .56966 L .45762 .57214 L p F P
0 g
s
.824 .709 .738 r
.72761 .68148 m .72294 .68819 L .72927 .7011 L p F P
0 g
s
.799 .706 .762 r
.72927 .7011 m .72809 .7023 L .71448 .69752 L p F P
0 g
s
.799 .706 .762 r
.71448 .69752 m .72294 .68819 L .72927 .7011 L p F P
0 g
s
.797 .756 .815 r
.71448 .69752 m .72809 .7023 L p .70193 .71936 L F P
0 g
s
.833 .589 .569 r
.7155 .63089 m .70335 .62681 L .70613 .64119 L p F P
0 g
s
.833 .589 .569 r
.70613 .64119 m .7133 .64359 L .7155 .63089 L p F P
0 g
s
.647 .738 .915 r
.62683 .71331 m .601 .72339 L .60752 .73024 L p F P
0 g
s
.647 .738 .915 r
.60752 .73024 m .63332 .72191 L .62683 .71331 L p F P
0 g
s
.846 .641 .626 r
.72696 .64852 m .72228 .66201 L .71083 .65788 L p F P
0 g
s
.846 .641 .626 r
.7133 .64359 m .72696 .64852 L p .71083 .65788 L F P
0 g
s
.728 .75 .869 r
.67639 .71204 m .66557 .71873 L .67187 .72737 L p F P
0 g
s
.728 .75 .869 r
.67187 .72737 m .69137 .71644 L .67639 .71204 L p F P
0 g
s
.683 .728 .884 r
.65918 .70921 m .63332 .72191 L .63972 .72961 L p F P
0 g
s
.683 .728 .884 r
.63972 .72961 m .66557 .71873 L .65918 .70921 L p F P
0 g
s
.797 .756 .815 r
.70193 .71936 m .69763 .71254 L .71448 .69752 L p F P
0 g
s
.74 .738 .85 r
.69137 .71644 m .70193 .71936 L .69763 .71254 L closepath p F P
0 g
s
.746 .394 .386 r
.62603 .57637 m .62283 .57583 L .62134 .58532 L p F P
0 g
s
.746 .394 .386 r
.62134 .58532 m .63023 .5868 L .62603 .57637 L p F P
0 g
s
.789 .471 .45 r
.66704 .59421 m .66043 .59265 L .66011 .60338 L p F P
0 g
s
.789 .471 .45 r
.66011 .60338 m .66898 .60547 L .66704 .59421 L p F P
0 g
s
.571 .251 .387 r
.42479 .58633 m .42676 .57633 L .45569 .57232 L p F P
0 g
s
.538 .177 .303 r
.45605 .57119 m .45569 .57232 L .42676 .57633 L p F P
0 g
s
.535 .222 .383 r
.42676 .57633 m .42479 .58633 L .41154 .5888 L p F P
0 g
s
.545 .392 .625 r
.34495 .64169 m .34697 .65596 L .32265 .66135 L p F P
0 g
s
.551 .408 .64 r
.32316 .6645 m .32265 .66135 L .34697 .65596 L p F P
0 g
s
.728 .377 .384 r
.62283 .57583 m .60508 .57343 L .60959 .58374 L p F P
0 g
s
.728 .377 .384 r
.60959 .58374 m .62134 .58532 L .62283 .57583 L p F P
0 g
s
.635 .67 .867 r
.39363 .70672 m .40011 .71683 L .37538 .72459 L p F P
0 g
s
.635 .67 .867 r
.37538 .72459 m .36812 .71356 L .39363 .70672 L p F P
0 g
s
.569 .457 .687 r
.32695 .68061 m .32316 .6645 L .34701 .65617 L p F P
0 g
s
.551 .408 .64 r
.34697 .65596 m .34701 .65617 L .32316 .6645 L p F P
0 g
s
.602 .563 .783 r
.35713 .69082 m .36076 .6993 L .33626 .70613 L p F P
0 g
s
.602 .563 .783 r
.33626 .70613 m .33322 .69898 L .35713 .69082 L p F P
0 g
s
.552 .359 .572 r
.34495 .64169 m .34417 .62847 L .36931 .62109 L p F P
0 g
s
.527 .298 .511 r
.36955 .60897 m .36931 .62109 L .34417 .62847 L p F P
0 g
s
.775 .458 .451 r
.66043 .59265 m .64923 .59034 L .65124 .60158 L p F P
0 g
s
.775 .458 .451 r
.65124 .60158 m .66011 .60338 L .66043 .59265 L p F P
0 g
s
.664 .283 .313 r
.55108 .56886 m .55272 .56339 L .55764 .56921 L closepath p F P
0 g
s
.639 .257 .305 r
.52949 .5685 m .55108 .56886 L .55272 .56339 L p F P
0 g
s
.823 .696 .724 r
.72294 .68819 m .72761 .68148 L .7183 .67785 L closepath p F P
0 g
s
.804 .525 .515 r
.68543 .60972 m .66898 .60547 L .66874 .6175 L p F P
0 g
s
.804 .525 .515 r
.66874 .6175 m .68524 .62174 L .68543 .60972 L p F P
0 g
s
.592 .531 .755 r
.35366 .68137 m .35713 .69082 L .33322 .69898 L p F P
0 g
s
.592 .531 .755 r
.33322 .69898 m .3292 .68792 L .35366 .68137 L p F P
0 g
s
.639 .702 .892 r
.4251 .70829 m .40011 .71683 L .40745 .7262 L p F P
0 g
s
.639 .702 .892 r
.40745 .7262 m .43237 .71822 L .4251 .70829 L p F P
0 g
s
.564 .287 .454 r
.41154 .5888 m .3971 .59156 L .39597 .60262 L p F P
0 g
s
.532 .261 .449 r
.3971 .59156 m .39597 .60262 L .36955 .60897 L p F P
0 g
s
.567 .199 .303 r
.45569 .57232 m .45605 .57119 L .45762 .57214 L closepath p F P
0 g
s
.711 .367 .392 r
.60508 .57343 m .60959 .58374 L .5874 .58113 L p F P
0 g
s
.711 .367 .392 r
.58601 .57119 m .60508 .57343 L p .5874 .58113 L F P
0 g
s
.749 .723 .828 r
.69763 .71254 m .69137 .71644 L .67639 .71204 L p F P
0 g
s
.584 .5 .726 r
.3292 .68792 m .32695 .68061 L .35087 .67237 L p F P
0 g
s
.569 .457 .687 r
.34701 .65617 m .35087 .67237 L .32695 .68061 L p F P
0 g
s
.559 .323 .515 r
.36931 .62109 m .36955 .60897 L .39597 .60262 L p F P
0 g
s
.584 .5 .726 r
.35087 .67237 m .35366 .68137 L .3292 .68792 L p F P
0 g
s
.82 .579 .575 r
.70335 .62681 m .70106 .62613 L .69851 .63894 L p F P
0 g
s
.82 .579 .575 r
.69851 .63894 m .70613 .64119 L .70335 .62681 L p F P
0 g
s
.799 .705 .761 r
.72294 .68819 m .7183 .67785 L p .70062 .69276 L F P
0 g
s
.799 .705 .761 r
.70062 .69276 m .71448 .69752 L .72294 .68819 L p F P
0 g
s
.638 .727 .913 r
.45754 .70952 m .43237 .71822 L .43963 .72631 L p F P
0 g
s
.638 .727 .913 r
.43963 .72631 m .46471 .71847 L .45754 .70952 L p F P
0 g
s
.828 .661 .676 r
.71646 .67327 m .72228 .66201 L .71083 .65788 L closepath p F P
0 g
s
.844 .683 .683 r
.7183 .67785 m .71646 .67327 L .72228 .66201 L p F P
0 g
s
.782 .723 .797 r
.70062 .69276 m .6913 .70169 L .69763 .71254 L p F P
0 g
s
.782 .723 .797 r
.69763 .71254 m .71448 .69752 L .70062 .69276 L p F P
0 g
s
.749 .723 .828 r
.67639 .71204 m .6913 .70169 L .69763 .71254 L p F P
0 g
s
.813 .572 .575 r
.70106 .62613 m .68524 .62174 L .68263 .63457 L p F P
0 g
s
.813 .572 .575 r
.68263 .63457 m .69851 .63894 L .70106 .62613 L p F P
0 g
s
.767 .453 .455 r
.64923 .59034 m .63023 .5868 L .63218 .59804 L p F P
0 g
s
.767 .453 .455 r
.63218 .59804 m .65124 .60158 L .64923 .59034 L p F P
0 g
s
.6 .276 .393 r
.45762 .57214 m .45569 .57232 L .45383 .58231 L p F P
0 g
s
.571 .251 .387 r
.45569 .57232 m .45383 .58231 L .42479 .58633 L p F P
0 g
s
.6 .276 .393 r
.45383 .58231 m .46518 .58125 L .45762 .57214 L p F P
0 g
s
.604 .277 .39 r
.48603 .56966 m .45762 .57214 L .46518 .58125 L p F P
0 g
s
.633 .74 .925 r
.49004 .70974 m .46471 .71847 L .47186 .72574 L p F P
0 g
s
.633 .74 .925 r
.47186 .72574 m .4971 .71815 L .49004 .70974 L p F P
0 g
s
.829 .621 .622 r
.70971 .65418 m .7133 .64359 L .70613 .64119 L closepath p F P
0 g
s
.846 .641 .626 r
.71083 .65788 m .70971 .65418 L .7133 .64359 L p F P
0 g
s
.63 .743 .929 r
.52259 .70932 m .4971 .71815 L .50411 .72504 L p F P
0 g
s
.63 .743 .929 r
.50411 .72504 m .52951 .71759 L .52259 .70932 L p F P
0 g
s
.711 .367 .392 r
.5874 .58113 m .58521 .57623 L .58601 .57119 L p F P
0 g
s
.702 .357 .39 r
.58521 .57623 m .58267 .57091 L .58601 .57119 L closepath p F P
0 g
s
.634 .739 .923 r
.55516 .70834 m .52951 .71759 L .53638 .72449 L p F P
0 g
s
.634 .739 .923 r
.53638 .72449 m .56195 .71682 L .55516 .70834 L p F P
0 g
s
.693 .348 .387 r
.58267 .57091 m .55764 .56921 L .56254 .57935 L p F P
0 g
s
.693 .348 .387 r
.58521 .57623 m .58267 .57091 L p .56254 .57935 L F P
0 g
s
.564 .287 .454 r
.39597 .60262 m .41684 .59866 L .41154 .5888 L p F P
0 g
s
.567 .288 .453 r
.42479 .58633 m .41154 .5888 L .41684 .59866 L p F P
0 g
s
.813 .671 .706 r
.71432 .67653 m .7183 .67785 L .71646 .67327 L closepath p F P
0 g
s
.799 .705 .761 r
.7183 .67785 m .71432 .67653 L .70062 .69276 L p F P
0 g
s
.634 .656 .854 r
.3928 .70535 m .39363 .70672 L .36812 .71356 L p F P
0 g
s
.634 .656 .854 r
.36812 .71356 m .36802 .7134 L .3928 .70535 L p F P
0 g
s
.648 .731 .909 r
.58773 .70661 m .56195 .71682 L .56868 .72405 L p F P
0 g
s
.648 .731 .909 r
.56868 .72405 m .5944 .71557 L .58773 .70661 L p F P
0 g
s
.741 .745 .856 r
.66166 .70753 m .65918 .70921 L .66557 .71873 L p F P
0 g
s
.741 .745 .856 r
.66557 .71873 m .67639 .71204 L .66166 .70753 L p F P
0 g
s
.626 .61 .815 r
.38557 .69096 m .36076 .6993 L .36802 .7134 L p F P
0 g
s
.626 .61 .815 r
.36802 .7134 m .3928 .70535 L .38557 .69096 L p F P
0 g
s
.573 .413 .627 r
.34697 .65596 m .34495 .64169 L .37018 .63435 L p F P
0 g
s
.552 .359 .572 r
.36931 .62109 m .37018 .63435 L .34495 .64169 L p F P
0 g
s
.631 .302 .396 r
.49706 .56917 m .48603 .56966 L .48427 .57959 L p F P
0 g
s
.604 .277 .39 r
.46518 .58125 m .48427 .57959 L .48603 .56966 L p F P
0 g
s
.671 .721 .887 r
.62027 .70364 m .5944 .71557 L .601 .72339 L p F P
0 g
s
.671 .721 .887 r
.601 .72339 m .62683 .71331 L .62027 .70364 L p F P
0 g
s
.796 .517 .515 r
.66898 .60547 m .66011 .60338 L .66105 .61569 L p F P
0 g
s
.796 .517 .515 r
.66105 .61569 m .66874 .6175 L .66898 .60547 L p F P
0 g
s
.808 .664 .703 r
.71646 .67327 m .71083 .65788 L p .69958 .67195 L F P
0 g
s
.808 .664 .703 r
.69958 .67195 m .71432 .67653 L .71646 .67327 L p F P
0 g
s
.814 .62 .641 r
.70613 .64119 m .69851 .63894 L .69313 .65266 L p F P
0 g
s
.814 .62 .641 r
.70971 .65418 m .70613 .64119 L p .69313 .65266 L F P
0 g
s
.7 .715 .86 r
.64382 .70386 m .62683 .71331 L .63332 .72191 L p F P
0 g
s
.7 .715 .86 r
.65739 .70632 m .64382 .70386 L p .63332 .72191 L F P
0 g
s
.7 .715 .86 r
.63332 .72191 m .65918 .70921 L .65739 .70632 L p F P
0 g
s
.688 .349 .396 r
.55764 .56921 m .55108 .56886 L .54949 .57864 L p F P
0 g
s
.688 .349 .396 r
.54949 .57864 m .56254 .57935 L .55764 .56921 L p F P
0 g
s
.631 .302 .396 r
.48427 .57959 m .50338 .57875 L .49706 .56917 L p F P
0 g
s
.635 .303 .392 r
.5178 .56844 m .49706 .56917 L .50338 .57875 L p F P
0 g
s
.801 .695 .747 r
.71432 .67653 m .69958 .67195 L .68641 .68805 L p F P
0 g
s
.801 .695 .747 r
.68641 .68805 m .70062 .69276 L .71432 .67653 L p F P
0 g
s
.759 .447 .458 r
.63023 .5868 m .62134 .58532 L .62094 .59617 L p F P
0 g
s
.759 .447 .458 r
.62094 .59617 m .63218 .59804 L .63023 .5868 L p F P
0 g
s
.666 .328 .392 r
.55108 .56886 m .52949 .5685 L .53498 .5784 L p F P
0 g
s
.666 .328 .392 r
.53498 .5784 m .54949 .57864 L .55108 .56886 L p F P
0 g
s
.755 .704 .804 r
.6913 .70169 m .67639 .71204 L .66166 .70753 L p F P
0 g
s
.66 .326 .397 r
.52949 .5685 m .5178 .56844 L .51612 .57831 L p F P
0 g
s
.66 .326 .397 r
.51612 .57831 m .53498 .5784 L .52949 .5685 L p F P
0 g
s
.635 .303 .392 r
.50338 .57875 m .51612 .57831 L .5178 .56844 L p F P
0 g
s
.596 .313 .458 r
.42374 .59739 m .42479 .58633 L .45383 .58231 L p F P
0 g
s
.567 .288 .453 r
.41684 .59866 m .42374 .59739 L .42479 .58633 L p F P
0 g
s
.814 .62 .641 r
.69313 .65266 m .70847 .65714 L .70971 .65418 L p F P
0 g
s
.82 .629 .644 r
.70847 .65714 m .71083 .65788 L .70971 .65418 L closepath p F P
0 g
s
.808 .664 .703 r
.71083 .65788 m .70847 .65714 L .69958 .67195 L p F P
0 g
s
.806 .565 .574 r
.68524 .62174 m .66874 .6175 L .66612 .63034 L p F P
0 g
s
.806 .565 .574 r
.66612 .63034 m .68263 .63457 L .68524 .62174 L p F P
0 g
s
.781 .505 .518 r
.66011 .60338 m .65124 .60158 L .65085 .61364 L p F P
0 g
s
.781 .505 .518 r
.65085 .61364 m .66105 .61569 L .66011 .60338 L p F P
0 g
s
.646 .672 .861 r
.42072 .7011 m .4251 .70829 L .40011 .71683 L p F P
0 g
s
.646 .672 .861 r
.40011 .71683 m .39363 .70672 L .42072 .7011 L p F P
0 g
s
.808 .652 .688 r
.70847 .65714 m .69313 .65266 L .68442 .66744 L p F P
0 g
s
.808 .652 .688 r
.68442 .66744 m .69958 .67195 L .70847 .65714 L p F P
0 g
s
.742 .432 .458 r
.62134 .58532 m .60959 .58374 L .61163 .59493 L p F P
0 g
s
.742 .432 .458 r
.61163 .59493 m .62094 .59617 L .62134 .58532 L p F P
0 g
s
.58 .379 .574 r
.37018 .63435 m .36931 .62109 L .39583 .61476 L p F P
0 g
s
.559 .323 .515 r
.39597 .60262 m .39583 .61476 L .36931 .62109 L p F P
0 g
s
.81 .609 .631 r
.69851 .63894 m .68263 .63457 L .67728 .64829 L p F P
0 g
s
.81 .609 .631 r
.67728 .64829 m .69313 .65266 L .69851 .63894 L p F P
0 g
s
.787 .714 .783 r
.6913 .70169 m .70062 .69276 L .68641 .68805 L p F P
0 g
s
.787 .714 .783 r
.68641 .68805 m .68487 .68963 L .6913 .70169 L p F P
0 g
s
.755 .704 .804 r
.66166 .70753 m .68487 .68963 L .6913 .70169 L p F P
0 g
s
.713 .367 .39 r
.58447 .58083 m .58521 .57623 L .5874 .58113 L closepath p F P
0 g
s
.693 .348 .387 r
.56254 .57935 m .58447 .58083 L .58521 .57623 L p F P
0 g
s
.587 .346 .518 r
.41684 .59866 m .39597 .60262 L .39583 .61476 L p F P
0 g
s
.573 .413 .627 r
.37018 .63435 m .3718 .64574 L .34697 .65596 L p F P
0 g
s
.579 .429 .642 r
.34701 .65617 m .34697 .65596 L .3718 .64574 L p F P
0 g
s
.593 .473 .685 r
.35087 .67237 m .34701 .65617 L .37233 .64891 L p F P
0 g
s
.579 .429 .642 r
.3718 .64574 m .37233 .64891 L .34701 .65617 L p F P
0 g
s
.62 .575 .782 r
.38253 .68373 m .38557 .69096 L .36076 .6993 L p F P
0 g
s
.62 .575 .782 r
.36076 .6993 m .35713 .69082 L .38253 .68373 L p F P
0 g
s
.647 .686 .873 r
.45035 .69869 m .4251 .70829 L .43237 .71822 L p F P
0 g
s
.647 .686 .873 r
.43237 .71822 m .45754 .70952 L .45035 .69869 L p F P
0 g
s
.735 .428 .461 r
.60959 .58374 m .5874 .58113 L .58938 .59232 L p F P
0 g
s
.735 .428 .461 r
.58938 .59232 m .61163 .59493 L .60959 .58374 L p F P
0 g
s
.774 .499 .519 r
.65124 .60158 m .63218 .59804 L .63172 .61012 L p F P
0 g
s
.774 .499 .519 r
.63172 .61012 m .65085 .61364 L .65124 .60158 L p F P
0 g
s
.614 .546 .754 r
.37849 .67255 m .38253 .68373 L .35713 .69082 L p F P
0 g
s
.614 .546 .754 r
.35713 .69082 m .35366 .68137 L .37849 .67255 L p F P
0 g
s
.649 .704 .887 r
.48295 .69963 m .45754 .70952 L .46471 .71847 L p F P
0 g
s
.649 .704 .887 r
.46471 .71847 m .49004 .70974 L .48295 .69963 L p F P
0 g
s
.605 .515 .725 r
.35366 .68137 m .35087 .67237 L .37622 .66517 L p F P
0 g
s
.593 .473 .685 r
.37233 .64891 m .37622 .66517 L .35087 .67237 L p F P
0 g
s
.605 .515 .725 r
.37622 .66517 m .37849 .67255 L .35366 .68137 L p F P
0 g
s
.623 .336 .462 r
.46518 .58125 m .45383 .58231 L .45291 .59337 L p F P
0 g
s
.596 .313 .458 r
.45383 .58231 m .45291 .59337 L .42374 .59739 L p F P
0 g
s
.811 .692 .733 r
.69958 .67195 m .68641 .68805 L .68368 .68722 L p F P
0 g
s
.811 .692 .733 r
.68442 .66744 m .69958 .67195 L p .68368 .68722 L F P
0 g
s
.651 .712 .892 r
.51561 .6995 m .49004 .70974 L .4971 .71815 L p F P
0 g
s
.651 .712 .892 r
.4971 .71815 m .52259 .70932 L .51561 .6995 L p F P
0 g
s
.749 .733 .837 r
.65918 .70921 m .66166 .70753 L .65739 .70632 L closepath p F P
0 g
s
.779 .733 .811 r
.68487 .68963 m .66166 .70753 L .65739 .70632 L p F P
0 g
s
.798 .556 .572 r
.66874 .6175 m .66105 .61569 L .66339 .62969 L p F P
0 g
s
.798 .556 .572 r
.66339 .62969 m .66612 .63034 L .66874 .6175 L p F P
0 g
s
.657 .712 .888 r
.5483 .69845 m .52259 .70932 L .52951 .71759 L p F P
0 g
s
.657 .712 .888 r
.52951 .71759 m .55516 .70834 L .5483 .69845 L p F P
0 g
s
.623 .336 .462 r
.45291 .59337 m .46817 .59195 L .46518 .58125 L p F P
0 g
s
.626 .339 .461 r
.48427 .57959 m .46518 .58125 L .46817 .59195 L p F P
0 g
s
.728 .423 .462 r
.5874 .58113 m .58447 .58083 L .58398 .59177 L p F P
0 g
s
.728 .423 .462 r
.58398 .59177 m .58938 .59232 L .5874 .58113 L p F P
0 g
s
.71 .407 .462 r
.58447 .58083 m .56254 .57935 L .56463 .59048 L p F P
0 g
s
.71 .407 .462 r
.56463 .59048 m .58398 .59177 L .58447 .58083 L p F P
0 g
s
.669 .708 .876 r
.58098 .69633 m .55516 .70834 L .56195 .71682 L p F P
0 g
s
.669 .708 .876 r
.56195 .71682 m .58773 .70661 L .58098 .69633 L p F P
0 g
s
.648 .659 .847 r
.41786 .69609 m .42072 .7011 L .39363 .70672 L p F P
0 g
s
.648 .659 .847 r
.39363 .70672 m .3928 .70535 L .41786 .69609 L p F P
0 g
s
.721 .732 .86 r
.62583 .7002 m .62027 .70364 L .62683 .71331 L p F P
0 g
s
.721 .732 .86 r
.62683 .71331 m .64382 .70386 L .62583 .7002 L p F P
0 g
s
.815 .652 .681 r
.69313 .65266 m .68442 .66744 L .67379 .66447 L p F P
0 g
s
.815 .652 .681 r
.67728 .64829 m .69313 .65266 L p .67379 .66447 L F P
0 g
s
.587 .346 .518 r
.39583 .61476 m .41341 .61145 L .41684 .59866 L p F P
0 g
s
.59 .349 .519 r
.42374 .59739 m .41684 .59866 L .41341 .61145 L p F P
0 g
s
.813 .607 .624 r
.68263 .63457 m .67728 .64829 L .66747 .64578 L p F P
0 g
s
.813 .607 .624 r
.66612 .63034 m .68263 .63457 L p .66747 .64578 L F P
0 g
s
.689 .704 .859 r
.60559 .69716 m .58773 .70661 L .5944 .71557 L p F P
0 g
s
.689 .704 .859 r
.6171 .69847 m .60559 .69716 L p .5944 .71557 L F P
0 g
s
.689 .704 .859 r
.5944 .71557 m .62027 .70364 L .6171 .69847 L p F P
0 g
s
.596 .428 .625 r
.3718 .64574 m .37018 .63435 L .39676 .62805 L p F P
0 g
s
.58 .379 .574 r
.39583 .61476 m .39676 .62805 L .37018 .63435 L p F P
0 g
s
.779 .733 .811 r
.68368 .68722 m .68487 .68963 L p .65739 .70632 L F P
0 g
s
.779 .733 .811 r
.66994 .68395 m .68368 .68722 L p .65739 .70632 L F P
0 g
s
.779 .733 .811 r
.65739 .70632 m .65269 .69844 L .66994 .68395 L p F P
0 g
s
.729 .716 .838 r
.64382 .70386 m .65739 .70632 L .65269 .69844 L closepath p F P
0 g
s
.636 .606 .802 r
.41068 .68096 m .38557 .69096 L .3928 .70535 L p F P
0 g
s
.636 .606 .802 r
.3928 .70535 m .41786 .69609 L .41068 .68096 L p F P
0 g
s
.767 .493 .52 r
.63218 .59804 m .62094 .59617 L .62171 .60845 L p F P
0 g
s
.767 .493 .52 r
.62171 .60845 m .63172 .61012 L .63218 .59804 L p F P
0 g
s
.788 .699 .767 r
.68487 .68963 m .68641 .68805 L .68368 .68722 L closepath p F P
0 g
s
.783 .546 .577 r
.66105 .61569 m .65085 .61364 L .64779 .62661 L p F P
0 g
s
.783 .546 .577 r
.64779 .62661 m .66339 .62969 L .66105 .61569 L p F P
0 g
s
.651 .359 .464 r
.50338 .57875 m .48427 .57959 L .48344 .59064 L p F P
0 g
s
.626 .339 .461 r
.46817 .59195 m .48344 .59064 L .48427 .57959 L p F P
0 g
s
.616 .369 .521 r
.42371 .60956 m .42374 .59739 L .45291 .59337 L p F P
0 g
s
.59 .349 .519 r
.41341 .61145 m .42371 .60956 L .42374 .59739 L p F P
0 g
s
.704 .403 .464 r
.56254 .57935 m .54949 .57864 L .54888 .58963 L p F P
0 g
s
.704 .403 .464 r
.54888 .58963 m .56463 .59048 L .56254 .57935 L p F P
0 g
s
.811 .692 .733 r
.68368 .68722 m .67831 .67544 L .68442 .66744 L p F P
0 g
s
.775 .678 .757 r
.66994 .68395 m .68368 .68722 L .67831 .67544 L closepath p F P
0 g
s
.651 .359 .464 r
.48344 .59064 m .50594 .58965 L .50338 .57875 L p F P
0 g
s
.656 .362 .463 r
.51612 .57831 m .50338 .57875 L .50594 .58965 L p F P
0 g
s
.605 .398 .574 r
.41341 .61145 m .39583 .61476 L .39676 .62805 L p F P
0 g
s
.683 .385 .463 r
.54949 .57864 m .53498 .5784 L .53726 .58944 L p F P
0 g
s
.683 .385 .463 r
.53726 .58944 m .54888 .58963 L .54949 .57864 L p F P
0 g
s
.678 .382 .465 r
.53498 .5784 m .51612 .57831 L .5154 .58933 L p F P
0 g
s
.678 .382 .465 r
.5154 .58933 m .53726 .58944 L .53498 .5784 L p F P
0 g
s
.656 .362 .463 r
.50594 .58965 m .5154 .58933 L .51612 .57831 L p F P
0 g
s
.751 .48 .522 r
.62094 .59617 m .61163 .59493 L .611 .60705 L p F P
0 g
s
.751 .48 .522 r
.611 .60705 m .62171 .60845 L .62094 .59617 L p F P
0 g
s
.655 .668 .85 r
.44911 .69651 m .45035 .69869 L .4251 .70829 L p F P
0 g
s
.655 .668 .85 r
.4251 .70829 m .42072 .7011 L .44911 .69651 L p F P
0 g
s
.737 .696 .812 r
.65269 .69844 m .64382 .70386 L .62583 .7002 L p F P
0 g
s
.777 .54 .577 r
.65085 .61364 m .63172 .61012 L .62863 .62309 L p F P
0 g
s
.777 .54 .577 r
.62863 .62309 m .64779 .62661 L .65085 .61364 L p F P
0 g
s
.596 .428 .625 r
.39676 .62805 m .39706 .63015 L .3718 .64574 L p F P
0 g
s
.606 .446 .639 r
.37233 .64891 m .3718 .64574 L .39706 .63015 L p F P
0 g
s
.795 .666 .721 r
.67831 .67544 m .68442 .66744 L .67379 .66447 L closepath p F P
0 g
s
.744 .474 .522 r
.61163 .59493 m .58938 .59232 L .58869 .60445 L p F P
0 g
s
.744 .474 .522 r
.58869 .60445 m .611 .60705 L .61163 .59493 L p F P
0 g
s
.615 .487 .683 r
.37622 .66517 m .37233 .64891 L .39907 .64275 L p F P
0 g
s
.606 .446 .639 r
.39706 .63015 m .39907 .64275 L .37233 .64891 L p F P
0 g
s
.635 .581 .776 r
.40936 .67771 m .41068 .68096 L .38557 .69096 L p F P
0 g
s
.635 .581 .776 r
.38557 .69096 m .38253 .68373 L .40936 .67771 L p F P
0 g
s
.762 .697 .79 r
.65299 .67994 m .64611 .68623 L .65269 .69844 L p F P
0 g
s
.762 .697 .79 r
.65269 .69844 m .66994 .68395 L .65299 .67994 L p F P
0 g
s
.737 .696 .812 r
.62583 .7002 m .64611 .68623 L .65269 .69844 L p F P
0 g
s
.796 .587 .618 r
.66455 .63459 m .66612 .63034 L .66339 .62969 L closepath p F P
0 g
s
.813 .607 .624 r
.66747 .64578 m .66455 .63459 L .66612 .63034 L p F P
0 g
s
.658 .67 .85 r
.45766 .69552 m .45035 .69869 L .45754 .70952 L p F P
0 g
s
.658 .67 .85 r
.47927 .69347 m .45766 .69552 L p .45754 .70952 L F P
0 g
s
.658 .67 .85 r
.45754 .70952 m .48295 .69963 L .47927 .69347 L p F P
0 g
s
.798 .629 .672 r
.67158 .65836 m .67728 .64829 L .66747 .64578 L closepath p F P
0 g
s
.815 .652 .681 r
.67379 .66447 m .67158 .65836 L .67728 .64829 L p F P
0 g
s
.774 .677 .756 r
.67831 .67544 m .67379 .66447 L p .65299 .67994 L F P
0 g
s
.774 .677 .756 r
.65299 .67994 m .66994 .68395 L .67831 .67544 L p F P
0 g
s
.782 .586 .635 r
.66339 .62969 m .64779 .62661 L .64167 .64058 L p F P
0 g
s
.782 .586 .635 r
.66455 .63459 m .66339 .62969 L p .64167 .64058 L F P
0 g
s
.635 .555 .747 r
.40364 .66127 m .40936 .67771 L .38253 .68373 L p F P
0 g
s
.635 .555 .747 r
.38253 .68373 m .37849 .67255 L .40364 .66127 L p F P
0 g
s
.605 .398 .574 r
.39676 .62805 m .40034 .62738 L .41341 .61145 L p F P
0 g
s
.608 .403 .577 r
.42371 .60956 m .41341 .61145 L .40034 .62738 L p F P
0 g
s
.639 .388 .522 r
.46817 .59195 m .45291 .59337 L .45298 .60556 L p F P
0 g
s
.616 .369 .521 r
.45291 .59337 m .45298 .60556 L .42371 .60956 L p F P
0 g
s
.664 .681 .856 r
.49908 .6923 m .48295 .69963 L .49004 .70974 L p F P
0 g
s
.664 .681 .856 r
.5109 .69179 m .49908 .6923 L p .49004 .70974 L F P
0 g
s
.664 .681 .856 r
.49004 .70974 m .51561 .6995 L .5109 .69179 L p F P
0 g
s
.624 .524 .721 r
.37849 .67255 m .37622 .66517 L .40296 .65902 L p F P
0 g
s
.615 .487 .683 r
.39907 .64275 m .40296 .65902 L .37622 .66517 L p F P
0 g
s
.782 .586 .635 r
.64167 .64058 m .6602 .64424 L .66455 .63459 L p F P
0 g
s
.787 .592 .637 r
.6602 .64424 m .66747 .64578 L .66455 .63459 L closepath p F P
0 g
s
.624 .524 .721 r
.40296 .65902 m .40364 .66127 L .37849 .67255 L p F P
0 g
s
.664 .657 .833 r
.44318 .68529 m .44911 .69651 L .42072 .7011 L p F P
0 g
s
.664 .657 .833 r
.42072 .7011 m .41786 .69609 L .44318 .68529 L p F P
0 g
s
.732 .72 .84 r
.62027 .70364 m .62583 .7002 L .6171 .69847 L closepath p F P
0 g
s
.672 .686 .854 r
.53157 .69178 m .51561 .6995 L .52259 .70932 L p F P
0 g
s
.672 .686 .854 r
.54431 .69186 m .53157 .69178 L p .52259 .70932 L F P
0 g
s
.672 .686 .854 r
.52259 .70932 m .5483 .69845 L .54431 .69186 L p F P
0 g
s
.737 .468 .522 r
.58938 .59232 m .58398 .59177 L .58457 .60403 L p F P
0 g
s
.737 .468 .522 r
.58457 .60403 m .58869 .60445 L .58938 .59232 L p F P
0 g
s
.774 .677 .756 r
.67379 .66447 m .66816 .6632 L .65299 .67994 L p F P
0 g
s
.784 .638 .7 r
.66816 .6632 m .67379 .66447 L .67158 .65836 L closepath p F P
0 g
s
.77 .532 .575 r
.63172 .61012 m .62171 .60845 L .62376 .62229 L p F P
0 g
s
.77 .532 .575 r
.62376 .62229 m .62863 .62309 L .63172 .61012 L p F P
0 g
s
.685 .687 .847 r
.55913 .69274 m .5483 .69845 L .55516 .70834 L p F P
0 g
s
.685 .687 .847 r
.57953 .69386 m .55913 .69274 L p .55516 .70834 L F P
0 g
s
.685 .687 .847 r
.55516 .70834 m .58098 .69633 L .57953 .69386 L p F P
0 g
s
.71 .719 .856 r
.58423 .69441 m .58098 .69633 L .58773 .70661 L p F P
0 g
s
.71 .719 .856 r
.58773 .70661 m .60559 .69716 L .58423 .69441 L p F P
0 g
s
.639 .388 .522 r
.45298 .60556 m .46623 .60433 L .46817 .59195 L p F P
0 g
s
.644 .392 .523 r
.48344 .59064 m .46817 .59195 L .46623 .60433 L p F P
0 g
s
.617 .439 .619 r
.39706 .63015 m .40034 .62738 L .39676 .62805 L closepath p F P
0 g
s
.761 .72 .814 r
.64611 .68623 m .62583 .7002 L .6171 .69847 L p F P
0 g
s
.72 .455 .524 r
.58398 .59177 m .56463 .59048 L .56371 .60265 L p F P
0 g
s
.72 .455 .524 r
.56371 .60265 m .58457 .60403 L .58398 .59177 L p F P
0 g
s
.781 .633 .697 r
.67158 .65836 m .66747 .64578 L p .65027 .6594 L F P
0 g
s
.781 .633 .697 r
.65027 .6594 m .66816 .6632 L .67158 .65836 L p F P
0 g
s
.781 .633 .697 r
.66747 .64578 m .6602 .64424 L .65027 .6594 L p F P
0 g
s
.631 .42 .577 r
.4248 .62294 m .42371 .60956 L .45298 .60556 L p F P
0 g
s
.608 .403 .577 r
.40034 .62738 m .4248 .62294 L .42371 .60956 L p F P
0 g
s
.628 .457 .631 r
.39907 .64275 m .39706 .63015 L .40034 .62738 L p F P
0 g
s
.628 .457 .631 r
.40034 .62738 m .4248 .62294 L p .39907 .64275 L F P
0 g
s
.647 .599 .786 r
.42249 .67541 m .41068 .68096 L .41786 .69609 L p F P
0 g
s
.647 .599 .786 r
.43771 .67294 m .42249 .67541 L p .41786 .69609 L F P
0 g
s
.647 .599 .786 r
.41786 .69609 m .44318 .68529 L .43771 .67294 L p F P
0 g
s
.789 .677 .74 r
.66816 .6632 m .65299 .67994 L .64184 .67742 L p F P
0 g
s
.789 .677 .74 r
.65027 .6594 m .66816 .6632 L p .64184 .67742 L F P
0 g
s
.665 .41 .524 r
.50594 .58965 m .48344 .59064 L .48364 .60285 L p F P
0 g
s
.644 .392 .523 r
.46623 .60433 m .48364 .60285 L .48344 .59064 L p F P
0 g
s
.715 .45 .524 r
.56463 .59048 m .54888 .58963 L .54934 .60188 L p F P
0 g
s
.715 .45 .524 r
.54934 .60188 m .56371 .60265 L .56463 .59048 L p F P
0 g
s
.788 .586 .627 r
.64779 .62661 m .64167 .64058 L .62738 .63795 L p F P
0 g
s
.788 .586 .627 r
.62863 .62309 m .64779 .62661 L p .62738 .63795 L F P
0 g
s
.755 .521 .579 r
.62171 .60845 m .611 .60705 L .6074 .62018 L p F P
0 g
s
.755 .521 .579 r
.6074 .62018 m .62376 .62229 L .62171 .60845 L p F P
0 g
s
.792 .634 .686 r
.6602 .64424 m .65027 .6594 L .633 .65589 L p F P
0 g
s
.792 .634 .686 r
.64167 .64058 m .6602 .64424 L p .633 .65589 L F P
0 g
s
.761 .72 .814 r
.64184 .67742 m .64611 .68623 L p .6171 .69847 L F P
0 g
s
.761 .72 .814 r
.63476 .67626 m .64184 .67742 L p .6171 .69847 L F P
0 g
s
.761 .72 .814 r
.6171 .69847 m .61362 .69255 L .63476 .67626 L p F P
0 g
s
.716 .704 .837 r
.60559 .69716 m .6171 .69847 L .61362 .69255 L closepath p F P
0 g
s
.665 .41 .524 r
.48364 .60285 m .50445 .60195 L .50594 .58965 L p F P
0 g
s
.67 .414 .525 r
.5154 .58933 m .50594 .58965 L .50445 .60195 L p F P
0 g
s
.696 .435 .525 r
.54888 .58963 m .53726 .58944 L .53608 .60167 L p F P
0 g
s
.696 .435 .525 r
.53608 .60167 m .54934 .60188 L .54888 .58963 L p F P
0 g
s
.766 .685 .773 r
.64611 .68623 m .65299 .67994 L .64184 .67742 L closepath p F P
0 g
s
.691 .43 .524 r
.53726 .58944 m .5154 .58933 L .51573 .60156 L p F P
0 g
s
.691 .43 .524 r
.51573 .60156 m .53608 .60167 L .53726 .58944 L p F P
0 g
s
.67 .414 .525 r
.50445 .60195 m .51573 .60156 L .5154 .58933 L p F P
0 g
s
.759 .525 .578 r
.611 .60705 m .6074 .62018 L .58639 .61773 L p F P
0 g
s
.759 .525 .578 r
.58869 .60445 m .611 .60705 L p .58639 .61773 L F P
0 g
s
.667 .66 .834 r
.45035 .69869 m .45766 .69552 L .44911 .69651 L closepath p F P
0 g
s
.723 .68 .808 r
.61362 .69255 m .60559 .69716 L .58423 .69441 L p F P
0 g
s
.635 .502 .684 r
.42717 .63767 m .39907 .64275 L .40296 .65902 L p F P
0 g
s
.628 .457 .631 r
.4248 .62294 m .42717 .63767 L .39907 .64275 L p F P
0 g
s
.681 .651 .813 r
.47584 .68737 m .45766 .69552 L .44911 .69651 L p F P
0 g
s
.681 .651 .813 r
.46873 .67238 m .47584 .68737 L p .44911 .69651 L F P
0 g
s
.681 .651 .813 r
.44911 .69651 m .44318 .68529 L .46873 .67238 L p F P
0 g
s
.65 .583 .766 r
.41068 .68096 m .42249 .67541 L .40936 .67771 L closepath p F P
0 g
s
.652 .435 .576 r
.46623 .60433 m .45298 .60556 L .45415 .61896 L p F P
0 g
s
.631 .42 .577 r
.45298 .60556 m .45415 .61896 L .4248 .62294 L p F P
0 g
s
.678 .679 .843 r
.48295 .69963 m .49908 .6923 L .47927 .69347 L closepath p F P
0 g
s
.743 .68 .789 r
.61466 .6731 m .60688 .67967 L .61362 .69255 L p F P
0 g
s
.743 .68 .789 r
.61362 .69255 m .63476 .67626 L .61466 .6731 L p F P
0 g
s
.723 .68 .808 r
.58423 .69441 m .60688 .67967 L .61362 .69255 L p F P
0 g
s
.654 .56 .736 r
.43606 .66867 m .42249 .67541 L .40936 .67771 L p F P
0 g
s
.654 .56 .736 r
.43123 .6541 m .43606 .66867 L p .40936 .67771 L F P
0 g
s
.654 .56 .736 r
.41002 .65774 m .43123 .6541 L p .40936 .67771 L F P
0 g
s
.654 .56 .736 r
.40936 .67771 m .40364 .66127 L .41002 .65774 L p F P
0 g
s
.772 .649 .726 r
.63943 .67202 m .65027 .6594 L .633 .65589 L closepath p F P
0 g
s
.789 .677 .74 r
.64184 .67742 m .63943 .67202 L .65027 .6594 L p F P
0 g
s
.77 .565 .621 r
.62555 .63042 m .62863 .62309 L .62376 .62229 L closepath p F P
0 g
s
.788 .586 .627 r
.62738 .63795 m .62555 .63042 L .62863 .62309 L p F P
0 g
s
.754 .662 .76 r
.63476 .67626 m .64184 .67742 L .63943 .67202 L closepath p F P
0 g
s
.672 .662 .832 r
.45766 .69552 m .47927 .69347 L .47584 .68737 L closepath p F P
0 g
s
.643 .467 .63 r
.45415 .61896 m .4248 .62294 L .42717 .63767 L p F P
0 g
s
.64 .53 .712 r
.40364 .66127 m .41002 .65774 L .40296 .65902 L closepath p F P
0 g
s
.635 .502 .684 r
.4291 .64605 m .42717 .63767 L p .40296 .65902 L F P
0 g
s
.635 .502 .684 r
.40296 .65902 m .41002 .65774 L .4291 .64605 L p F P
0 g
s
.689 .691 .846 r
.51561 .6995 m .53157 .69178 L .5109 .69179 L closepath p F P
0 g
s
.743 .508 .574 r
.58594 .61456 m .58869 .60445 L .58457 .60403 L closepath p F P
0 g
s
.759 .525 .578 r
.58639 .61773 m .58594 .61456 L .58869 .60445 L p F P
0 g
s
.652 .435 .576 r
.45415 .61896 m .45887 .61852 L .46623 .60433 L p F P
0 g
s
.657 .441 .579 r
.48364 .60285 m .46623 .60433 L .45887 .61852 L p F P
0 g
s
.774 .609 .675 r
.63261 .65477 m .64167 .64058 L .62738 .63795 L closepath p F P
0 g
s
.792 .634 .686 r
.633 .65589 m .63261 .65477 L .64167 .64058 L p F P
0 g
s
.719 .701 .832 r
.58098 .69633 m .58423 .69441 L .57953 .69386 L closepath p F P
0 g
s
.756 .564 .636 r
.62376 .62229 m .6074 .62018 L .60041 .63441 L p F P
0 g
s
.756 .564 .636 r
.62555 .63042 m .62376 .62229 L p .60041 .63441 L F P
0 g
s
.703 .698 .843 r
.5483 .69845 m .55913 .69274 L .54431 .69186 L closepath p F P
0 g
s
.727 .5 .583 r
.58457 .60403 m .56371 .60265 L .55946 .61595 L p F P
0 g
s
.727 .5 .583 r
.58594 .61456 m .58457 .60403 L p .55946 .61595 L F P
0 g
s
.746 .699 .807 r
.60688 .67967 m .58423 .69441 L .57953 .69386 L p F P
0 g
s
.752 .659 .759 r
.61466 .6731 m .63476 .67626 L .63943 .67202 L p F P
0 g
s
.752 .659 .759 r
.63943 .67202 m .633 .65589 L p .61466 .6731 L F P
0 g
s
.64 .513 .692 r
.41002 .65774 m .43123 .6541 L .4291 .64605 L closepath p F P
0 g
s
.746 .699 .807 r
.603 .67134 m .60688 .67967 L p .57953 .69386 L F P
0 g
s
.746 .699 .807 r
.593 .67037 m .603 .67134 L p .57953 .69386 L F P
0 g
s
.746 .699 .807 r
.57953 .69386 m .57416 .6842 L .593 .67037 L p F P
0 g
s
.708 .684 .825 r
.55913 .69274 m .57953 .69386 L .57416 .6842 L closepath p F P
0 g
s
.676 .455 .577 r
.50445 .60195 m .48364 .60285 L .48496 .61633 L p F P
0 g
s
.657 .441 .579 r
.45887 .61852 m .48496 .61633 L .48364 .60285 L p F P
0 g
s
.653 .578 .758 r
.42249 .67541 m .43771 .67294 L .43606 .66867 L closepath p F P
0 g
s
.696 .672 .823 r
.50859 .68778 m .49908 .6923 L .47927 .69347 L p F P
0 g
s
.696 .672 .823 r
.50154 .67353 m .50859 .68778 L p .47927 .69347 L F P
0 g
s
.696 .672 .823 r
.47927 .69347 m .47584 .68737 L .50154 .67353 L p F P
0 g
s
.756 .564 .636 r
.60041 .63441 m .62207 .6372 L .62555 .63042 L p F P
0 g
s
.761 .57 .639 r
.62207 .6372 m .62738 .63795 L .62555 .63042 L closepath p F P
0 g
s
.722 .492 .577 r
.56371 .60265 m .54934 .60188 L .55097 .61549 L p F P
0 g
s
.722 .492 .577 r
.55097 .61549 m .55946 .61595 L .56371 .60265 L p F P
0 g
s
.668 .609 .78 r
.46751 .66939 m .46873 .67238 L .44318 .68529 L p F P
0 g
s
.668 .609 .78 r
.44318 .68529 m .43771 .67294 L .46751 .66939 L p F P
0 g
s
.751 .553 .628 r
.6074 .62018 m .58639 .61773 L .58973 .63317 L p F P
0 g
s
.751 .553 .628 r
.58973 .63317 m .60041 .63441 L .6074 .62018 L p F P
0 g
s
.728 .696 .819 r
.57416 .6842 m .55913 .69274 L .54431 .69186 L p F P
0 g
s
.676 .455 .577 r
.48496 .61633 m .49845 .61574 L .50445 .60195 L p F P
0 g
s
.681 .46 .58 r
.51573 .60156 m .50445 .60195 L .49845 .61574 L p F P
0 g
s
.705 .479 .579 r
.54934 .60188 m .53608 .60167 L .53108 .61518 L p F P
0 g
s
.705 .479 .579 r
.53108 .61518 m .55097 .61549 L .54934 .60188 L p F P
0 g
s
.699 .474 .578 r
.53608 .60167 m .51573 .60156 L .5172 .61511 L p F P
0 g
s
.699 .474 .578 r
.5172 .61511 m .53108 .61518 L .53608 .60167 L p F P
0 g
s
.757 .612 .698 r
.62738 .63795 m .62207 .6372 L .61082 .65278 L p F P
0 g
s
.757 .612 .698 r
.63261 .65477 m .62738 .63795 L p .61082 .65278 L F P
0 g
s
.681 .46 .58 r
.49845 .61574 m .5172 .61511 L .51573 .60156 L p F P
0 g
s
.683 .676 .837 r
.49908 .6923 m .5109 .69179 L .50859 .68778 L closepath p F P
0 g
s
.761 .619 .702 r
.63186 .65572 m .633 .65589 L .63261 .65477 L closepath p F P
0 g
s
.752 .659 .759 r
.633 .65589 m .63186 .65572 L .61466 .6731 L p F P
0 g
s
.757 .612 .698 r
.61082 .65278 m .63186 .65572 L .63261 .65477 L p F P
0 g
s
.651 .503 .67 r
.4291 .64605 m .44254 .63559 L .42717 .63767 L closepath p F P
0 g
s
.643 .467 .63 r
.45486 .62351 m .45415 .61896 L p .42717 .63767 L F P
0 g
s
.643 .467 .63 r
.42717 .63767 m .44254 .63559 L .45486 .62351 L p F P
0 g
s
.769 .656 .738 r
.63186 .65572 m .61466 .6731 L .603 .67134 L p F P
0 g
s
.769 .656 .738 r
.61082 .65278 m .63186 .65572 L p .603 .67134 L F P
0 g
s
.728 .696 .819 r
.56727 .66996 m .57416 .6842 L p .54431 .69186 L F P
0 g
s
.728 .696 .819 r
.54431 .69186 m .54138 .68676 L .56727 .66996 L p F P
0 g
s
.694 .682 .834 r
.53157 .69178 m .54431 .69186 L .54138 .68676 L closepath p F P
0 g
s
.711 .687 .825 r
.54138 .68676 m .53157 .69178 L .5109 .69179 L p F P
0 g
s
.711 .687 .825 r
.53441 .67273 m .54138 .68676 L p .5109 .69179 L F P
0 g
s
.711 .687 .825 r
.5109 .69179 m .50859 .68778 L .53441 .67273 L p F P
0 g
s
.768 .61 .682 r
.62207 .6372 m .61082 .65278 L .59491 .65068 L p F P
0 g
s
.768 .61 .682 r
.60041 .63441 m .62207 .6372 L p .59491 .65068 L F P
0 g
s
.661 .474 .62 r
.45486 .62351 m .45887 .61852 L .45415 .61896 L closepath p F P
0 g
s
.747 .665 .77 r
.60688 .67967 m .61466 .6731 L .603 .67134 L closepath p F P
0 g
s
.727 .5 .583 r
.55946 .61595 m .58493 .61761 L .58594 .61456 L p F P
0 g
s
.733 .507 .584 r
.58493 .61761 m .58639 .61773 L .58594 .61456 L closepath p F P
0 g
s
.673 .608 .775 r
.47459 .66886 m .46873 .67238 L .47584 .68737 L p F P
0 g
s
.673 .608 .775 r
.49889 .66731 m .47459 .66886 L p .47584 .68737 L F P
0 g
s
.673 .608 .775 r
.47584 .68737 m .50154 .67353 L .49889 .66731 L p F P
0 g
s
.675 .493 .631 r
.45887 .61852 m .48496 .61633 L p .45668 .6338 L F P
0 g
s
.675 .493 .631 r
.45668 .6338 m .45486 .62351 L .45887 .61852 L p F P
0 g
s
.676 .59 .752 r
.46168 .65307 m .46751 .66939 L .43771 .67294 L p F P
0 g
s
.676 .59 .752 r
.43771 .67294 m .43606 .66867 L .46168 .65307 L p F P
0 g
s
.665 .528 .687 r
.43123 .6541 m .4291 .64605 L .44254 .63559 L p F P
0 g
s
.662 .557 .726 r
.46084 .65033 m .46168 .65307 L .43606 .66867 L p F P
0 g
s
.662 .557 .726 r
.43606 .66867 m .43123 .6541 L .46084 .65033 L p F P
0 g
s
.648 .475 .635 r
.44254 .63559 m .45668 .6338 L .45486 .62351 L closepath p F P
0 g
s
.665 .528 .687 r
.45668 .6338 m .46084 .65033 L .43123 .6541 L p F P
0 g
s
.665 .528 .687 r
.44254 .63559 m .45668 .6338 L p .43123 .6541 L F P
0 g
s
.735 .543 .632 r
.58639 .61773 m .58493 .61761 L .57682 .63218 L p F P
0 g
s
.735 .543 .632 r
.57682 .63218 m .58973 .63317 L .58639 .61773 L p F P
0 g
s
.742 .549 .633 r
.58493 .61761 m .57682 .63218 L .55399 .63066 L p F P
0 g
s
.742 .549 .633 r
.55946 .61595 m .58493 .61761 L p .55399 .63066 L F P
0 g
s
.685 .619 .776 r
.51151 .66701 m .50154 .67353 L .50859 .68778 L p F P
0 g
s
.685 .619 .776 r
.5318 .66674 m .51151 .66701 L p .50859 .68778 L F P
0 g
s
.685 .619 .776 r
.50859 .68778 m .53441 .67273 L .5318 .66674 L p F P
0 g
s
.729 .661 .782 r
.5695 .66816 m .56727 .66996 L .57416 .6842 L p F P
0 g
s
.729 .661 .782 r
.57416 .6842 m .593 .67037 L .5695 .66816 L p F P
0 g
s
.7 .627 .772 r
.54231 .66704 m .53441 .67273 L .54138 .68676 L p F P
0 g
s
.7 .627 .772 r
.56638 .66791 m .54231 .66704 L p .54138 .68676 L F P
0 g
s
.7 .627 .772 r
.54138 .68676 m .56727 .66996 L .56638 .66791 L p F P
0 g
s
.769 .656 .738 r
.603 .67134 m .60005 .66436 L .61082 .65278 L p F P
0 g
s
.736 .641 .754 r
.593 .67037 m .603 .67134 L .60005 .66436 L closepath p F P
0 g
s
.751 .627 .722 r
.60005 .66436 m .61082 .65278 L .59491 .65068 L closepath p F P
0 g
s
.684 .496 .626 r
.48752 .63098 m .49845 .61574 L .48496 .61633 L closepath p F P
0 g
s
.675 .493 .631 r
.48496 .61633 m .48752 .63098 L p .45668 .6338 L F P
0 g
s
.75 .585 .67 r
.5931 .64499 m .60041 .63441 L .58973 .63317 L closepath p F P
0 g
s
.768 .61 .682 r
.59491 .65068 m .5931 .64499 L .60041 .63441 L p F P
0 g
s
.725 .528 .624 r
.55327 .62734 m .55946 .61595 L .55097 .61549 L closepath p F P
0 g
s
.742 .549 .633 r
.55399 .63066 m .55327 .62734 L .55946 .61595 L p F P
0 g
s
.735 .639 .753 r
.5695 .66816 m .593 .67037 L .60005 .66436 L p F P
0 g
s
.699 .517 .637 r
.49845 .61574 m .5172 .61511 L p .48756 .6312 L F P
0 g
s
.699 .517 .637 r
.48756 .6312 m .48752 .63098 L .49845 .61574 L p F P
0 g
s
.673 .526 .677 r
.48731 .63122 m .45668 .6338 L .46084 .65033 L p F P
0 g
s
.675 .493 .631 r
.48752 .63098 m .48731 .63122 L .45668 .6338 L p F P
0 g
s
.735 .639 .753 r
.60005 .66436 m .59491 .65068 L p .5695 .66816 L F P
0 g
s
.711 .526 .637 r
.55097 .61549 m .53108 .61518 L .52173 .63012 L p F P
0 g
s
.711 .526 .637 r
.55327 .62734 m .55097 .61549 L p .52173 .63012 L F P
0 g
s
.705 .513 .626 r
.53108 .61518 m .5172 .61511 L .51999 .63011 L p F P
0 g
s
.705 .513 .626 r
.51999 .63011 m .52173 .63012 L .53108 .61518 L p F P
0 g
s
.681 .604 .762 r
.46873 .67238 m .47459 .66886 L .46751 .66939 L closepath p F P
0 g
s
.699 .517 .637 r
.5172 .61511 m .51999 .63011 L .48756 .6312 L p F P
0 g
s
.736 .589 .692 r
.58973 .63317 m .57682 .63218 L .56413 .64821 L p F P
0 g
s
.736 .589 .692 r
.5931 .64499 m .58973 .63317 L p .56413 .64821 L F P
0 g
s
.692 .585 .731 r
.4945 .65565 m .47459 .66886 L .46751 .66939 L p F P
0 g
s
.692 .585 .731 r
.49199 .64799 m .4945 .65565 L p .46751 .66939 L F P
0 g
s
.692 .585 .731 r
.46597 .6499 m .49199 .64799 L p .46751 .66939 L F P
0 g
s
.692 .585 .731 r
.46751 .66939 m .46168 .65307 L .46597 .6499 L p F P
0 g
s
.736 .589 .692 r
.56413 .64821 m .58872 .65013 L .5931 .64499 L p F P
0 g
s
.739 .594 .695 r
.58872 .65013 m .59491 .65068 L .5931 .64499 L closepath p F P
0 g
s
.735 .639 .753 r
.59491 .65068 m .58872 .65013 L .5695 .66816 L p F P
0 g
s
.685 .591 .745 r
.47459 .66886 m .49889 .66731 L .4945 .65565 L closepath p F P
0 g
s
.732 .574 .677 r
.57682 .63218 m .55399 .63066 L .55886 .64786 L p F P
0 g
s
.732 .574 .677 r
.55886 .64786 m .56413 .64821 L .57682 .63218 L p F P
0 g
s
.676 .555 .71 r
.46168 .65307 m .46597 .6499 L .46084 .65033 L closepath p F P
0 g
s
.673 .526 .677 r
.46084 .65033 m .46597 .6499 L .48731 .63122 L p F P
0 g
s
.748 .629 .727 r
.58872 .65013 m .5695 .66816 L .56638 .66791 L p F P
0 g
s
.748 .629 .727 r
.56413 .64821 m .58872 .65013 L p .56638 .66791 L F P
0 g
s
.697 .62 .767 r
.50154 .67353 m .51151 .66701 L .49889 .66731 L closepath p F P
0 g
s
.73 .641 .76 r
.56727 .66996 m .5695 .66816 L .56638 .66791 L closepath p F P
0 g
s
.678 .534 .682 r
.48756 .6312 m .48731 .63122 L .46597 .6499 L p F P
0 g
s
.678 .534 .682 r
.46597 .6499 m .49199 .64799 L .48756 .6312 L p F P
0 g
s
.748 .629 .727 r
.56638 .66791 m .56031 .65213 L .56413 .64821 L p F P
0 g
s
.718 .614 .74 r
.54231 .66704 m .56638 .66791 L .56031 .65213 L closepath p F P
0 g
s
.713 .632 .766 r
.53441 .67273 m .54231 .66704 L .5318 .66674 L closepath p F P
0 g
s
.672 .499 .642 r
.48731 .63122 m .48756 .6312 L .48752 .63098 L closepath p F P
0 g
s
.711 .526 .637 r
.52173 .63012 m .55111 .63059 L .55327 .62734 L p F P
0 g
s
.715 .532 .64 r
.55111 .63059 m .55399 .63066 L .55327 .62734 L closepath p F P
0 g
s
.693 .544 .68 r
.51999 .63011 m .48756 .6312 L .49199 .64799 L p F P
0 g
s
.712 .605 .736 r
.5274 .65532 m .51151 .66701 L .49889 .66731 L p F P
0 g
s
.712 .605 .736 r
.52463 .64709 m .5274 .65532 L p .49889 .66731 L F P
0 g
s
.712 .605 .736 r
.5044 .64757 m .52463 .64709 L p .49889 .66731 L F P
0 g
s
.712 .605 .736 r
.49889 .66731 m .4945 .65565 L .5044 .64757 L p F P
0 g
s
.717 .565 .682 r
.55399 .63066 m .55111 .63059 L .53625 .64728 L p F P
0 g
s
.717 .565 .682 r
.53625 .64728 m .55886 .64786 L .55399 .63066 L p F P
0 g
s
.724 .567 .676 r
.55111 .63059 m .53625 .64728 L .52463 .64709 L p F P
0 g
s
.724 .567 .676 r
.52173 .63012 m .55111 .63059 L p .52463 .64709 L F P
0 g
s
.73 .619 .734 r
.56031 .65213 m .54231 .66704 L .5318 .66674 L p F P
0 g
s
.702 .605 .745 r
.51151 .66701 m .5318 .66674 L .5274 .65532 L closepath p F P
0 g
s
.73 .619 .734 r
.55886 .64786 m .56031 .65213 L p .5318 .66674 L F P
0 g
s
.73 .619 .734 r
.53625 .64728 m .55886 .64786 L p .5318 .66674 L F P
0 g
s
.73 .619 .734 r
.5318 .66674 m .5274 .65532 L .53625 .64728 L p F P
0 g
s
.708 .542 .662 r
.52039 .63174 m .52173 .63012 L .51999 .63011 L closepath p F P
0 g
s
.724 .567 .676 r
.52463 .64709 m .52039 .63174 L .52173 .63012 L p F P
0 g
s
.693 .544 .68 r
.52039 .63174 m .51999 .63011 L p .49199 .64799 L F P
0 g
s
.731 .6 .711 r
.56031 .65213 m .56413 .64821 L .55886 .64786 L closepath p F P
0 g
s
.693 .544 .68 r
.49199 .64799 m .5044 .64757 L .52039 .63174 L p F P
0 g
s
.698 .551 .684 r
.5044 .64757 m .52463 .64709 L .52039 .63174 L closepath p F P
0 g
s
.695 .574 .715 r
.4945 .65565 m .5044 .64757 L .49199 .64799 L closepath p F P
0 g
s
.713 .589 .715 r
.5274 .65532 m .53625 .64728 L .52463 .64709 L closepath p F P
0 g
s
.25 Mabswid
.67239 0 m
.92713 .41504 L
s
.92713 .41504 m
1 .94835 L
s
1 .94835 m
.70635 .58561 L
s
.70635 .58561 m
.67239 0 L
s
.08846 .24552 m
0 .80386 L
s
0 .80386 m
.70635 .58561 L
s
.70635 .58561 m
.67239 0 L
s
.67239 0 m
.08846 .24552 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0123094 0.97619 0.504685 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0652563 1.12575 0 1.12575 [
[ 0 0 0 0 ]
[ 1 1.10172 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07962 .26911 m
0 .9318 L
s
0 .9318 m
.24143 1.10172 L
s
.24143 1.10172 m
.27883 .47227 L
s
.27883 .47227 m
.07962 .26911 L
s
.76523 0 m
.91897 .25049 L
s
.91897 .25049 m
1 .91594 L
s
1 .91594 m
.8234 .6978 L
s
.8234 .6978 m
.76523 0 L
s
.07962 .26911 m
0 .9318 L
s
0 .9318 m
.8234 .6978 L
s
.8234 .6978 m
.76523 0 L
s
.76523 0 m
.07962 .26911 L
s
.27883 .47227 m
.91897 .25049 L
s
.91897 .25049 m
1 .91594 L
s
1 .91594 m
.24143 1.10172 L
s
.24143 1.10172 m
.27883 .47227 L
s
0 0 m
1 0 L
1 1.10172 L
0 1.10172 L
closepath
clip
newpath
.5 Mabswid
.7 .558 .69 r
.4351 .4172 m .41739 .41767 L .42106 .43102 L closepath p F P
0 g
s
.711 .564 .686 r
.41988 .43243 m .42106 .43102 L .41739 .41767 L p F P
0 g
s
.711 .564 .686 r
.39408 .43198 m .41988 .43243 L p .41739 .41767 L F P
0 g
s
.711 .564 .686 r
.41739 .41767 m .40719 .41748 L .39408 .43198 L p F P
0 g
s
.701 .592 .731 r
.41739 .41767 m .4351 .4172 L p .43992 .39971 L F P
0 g
s
.701 .592 .731 r
.41494 .41043 m .41739 .41767 L p .43992 .39971 L F P
0 g
s
.711 .585 .713 r
.41494 .41043 m .40719 .41748 L .41739 .41767 L closepath p F P
0 g
s
.714 .601 .729 r
.40719 .41748 m .41494 .41043 L .41104 .40028 L p F P
0 g
s
.714 .601 .729 r
.38734 .41691 m .40719 .41748 L p .41104 .40028 L F P
0 g
s
.714 .568 .689 r
.39155 .4319 m .39408 .43198 L .40719 .41748 L p F P
0 g
s
.714 .568 .689 r
.40719 .41748 m .38734 .41691 L .39155 .4319 L p F P
0 g
s
.701 .592 .731 r
.43992 .39971 m .42884 .40001 L .41494 .41043 L p F P
0 g
s
.703 .597 .734 r
.42884 .40001 m .41104 .40028 L .41494 .41043 L closepath p F P
0 g
s
.697 .553 .687 r
.44598 .41679 m .4351 .4172 L .42106 .43102 L p F P
0 g
s
.698 .575 .713 r
.44377 .41006 m .4351 .4172 L .44598 .41679 L closepath p F P
0 g
s
.701 .592 .731 r
.4351 .4172 m .44377 .41006 L .43992 .39971 L p F P
0 g
s
.725 .575 .685 r
.37137 .43044 m .39155 .4319 L .38734 .41691 L p F P
0 g
s
.725 .575 .685 r
.38734 .41691 m .3827 .41657 L .37137 .43044 L p F P
0 g
s
.714 .601 .729 r
.38606 .41315 m .38734 .41691 L p .41104 .40028 L F P
0 g
s
.724 .593 .71 r
.38606 .41315 m .3827 .41657 L .38734 .41691 L closepath p F P
0 g
s
.686 .546 .689 r
.46884 .41491 m .44598 .41679 L .44986 .43139 L p F P
0 g
s
.697 .553 .687 r
.42141 .43244 m .44986 .43139 L .44598 .41679 L p F P
0 g
s
.697 .553 .687 r
.42106 .43102 m .42141 .43244 L p .44598 .41679 L F P
0 g
s
.688 .581 .729 r
.44598 .41679 m .46884 .41491 L p .46751 .39763 L F P
0 g
s
.688 .581 .729 r
.44377 .41006 m .44598 .41679 L p .46751 .39763 L F P
0 g
s
.714 .601 .729 r
.41104 .40028 m .4018 .39998 L .38606 .41315 L p F P
0 g
s
.715 .604 .731 r
.4018 .39998 m .38061 .39912 L .38606 .41315 L closepath p F P
0 g
s
.726 .608 .725 r
.3827 .41657 m .38606 .41315 L .38061 .39912 L p F P
0 g
s
.688 .581 .729 r
.46751 .39763 m .46126 .39817 L .44377 .41006 L p F P
0 g
s
.692 .587 .734 r
.46126 .39817 m .43992 .39971 L .44377 .41006 L closepath p F P
0 g
s
.708 .552 .675 r
.42106 .43102 m .41988 .43243 L .42141 .43244 L closepath p F P
0 g
s
.726 .608 .725 r
.36095 .41468 m .3827 .41657 L p .38061 .39912 L F P
0 g
s
.728 .586 .697 r
.35993 .42949 m .37137 .43044 L .3827 .41657 L p F P
0 g
s
.728 .586 .697 r
.35703 .41915 m .35993 .42949 L p .3827 .41657 L F P
0 g
s
.728 .586 .697 r
.3827 .41657 m .36095 .41468 L .35703 .41915 L p F P
0 g
s
.694 .522 .65 r
.44989 .43157 m .44986 .43139 L .42141 .43244 L p F P
0 g
s
.694 .522 .65 r
.44027 .44477 m .44989 .43157 L p .42141 .43244 L F P
0 g
s
.694 .522 .65 r
.42141 .43244 m .42376 .44537 L .44027 .44477 L p F P
0 g
s
.707 .531 .648 r
.41155 .4453 m .42376 .44537 L .42141 .43244 L p F P
0 g
s
.707 .531 .648 r
.42141 .43244 m .41988 .43243 L .41155 .4453 L p F P
0 g
s
.71 .54 .656 r
.39401 .44501 m .41155 .4453 L .41988 .43243 L p F P
0 g
s
.71 .54 .656 r
.39214 .43477 m .39401 .44501 L p .41988 .43243 L F P
0 g
s
.71 .54 .656 r
.41988 .43243 m .39408 .43198 L .39214 .43477 L p F P
0 g
s
.703 .612 .753 r
.40871 .39489 m .41104 .40028 L .42884 .40001 L p F P
0 g
s
.712 .617 .749 r
.40871 .39489 m .4018 .39998 L .41104 .40028 L closepath p F P
0 g
s
.701 .608 .75 r
.43757 .39413 m .42884 .40001 L .43992 .39971 L closepath p F P
0 g
s
.703 .612 .753 r
.42884 .40001 m .43757 .39413 L p .40871 .39489 L F P
0 g
s
.713 .618 .749 r
.4018 .39998 m .40871 .39489 L p .3798 .39727 L F P
0 g
s
.713 .618 .749 r
.3798 .39727 m .38061 .39912 L .4018 .39998 L p F P
0 g
s
.714 .544 .659 r
.39408 .43198 m .39155 .4319 L .39214 .43477 L closepath p F P
0 g
s
.726 .549 .651 r
.38651 .44457 m .39214 .43477 L .39155 .4319 L p F P
0 g
s
.726 .549 .651 r
.36392 .44299 m .38651 .44457 L p .39155 .4319 L F P
0 g
s
.726 .549 .651 r
.39155 .4319 m .37137 .43044 L .36392 .44299 L p F P
0 g
s
.692 .604 .753 r
.43757 .39413 m .43992 .39971 L .46126 .39817 L p F P
0 g
s
.686 .546 .689 r
.44986 .43139 m .45008 .43137 L .46884 .41491 L p F P
0 g
s
.682 .52 .66 r
.45008 .43137 m .44986 .43139 L .44989 .43157 L closepath p F P
0 g
s
.682 .54 .685 r
.45008 .43137 m .47706 .42887 L .47336 .41449 L p F P
0 g
s
.682 .54 .685 r
.47336 .41449 m .46884 .41491 L .45008 .43137 L p F P
0 g
s
.679 .515 .657 r
.47706 .42887 m .45008 .43137 L .44989 .43157 L p F P
0 g
s
.722 .542 .647 r
.39214 .43477 m .38651 .44457 L .39401 .44501 L closepath p F P
0 g
s
.679 .515 .657 r
.44989 .43157 m .45215 .44421 L p .47706 .42887 L F P
0 g
s
.691 .518 .648 r
.44989 .43157 m .44027 .44477 L .45215 .44421 L closepath p F P
0 g
s
.703 .612 .753 r
.43757 .39413 m .4313 .38107 L .40871 .39489 L p F P
0 g
s
.701 .65 .796 r
.40871 .39489 m .4313 .38107 L .42922 .3773 L p F P
0 g
s
.701 .65 .796 r
.40238 .38203 m .40871 .39489 L p .42922 .3773 L F P
0 g
s
.713 .618 .749 r
.40871 .39489 m .40238 .38203 L .3798 .39727 L p F P
0 g
s
.723 .623 .745 r
.3798 .39727 m .37785 .39887 L .38061 .39912 L closepath p F P
0 g
s
.726 .608 .725 r
.38061 .39912 m .37785 .39887 L .36095 .41468 L p F P
0 g
s
.685 .562 .709 r
.47261 .41208 m .46884 .41491 L .47336 .41449 L closepath p F P
0 g
s
.688 .581 .729 r
.46884 .41491 m .47261 .41208 L .46751 .39763 L p F P
0 g
s
.723 .636 .761 r
.37785 .39887 m .3798 .39727 L .37343 .38423 L p F P
0 g
s
.723 .636 .761 r
.37343 .38423 m .35697 .39665 L .37785 .39887 L p F P
0 g
s
.727 .622 .74 r
.35544 .41415 m .36095 .41468 L .37785 .39887 L p F P
0 g
s
.727 .622 .74 r
.35079 .40196 m .35544 .41415 L p .37785 .39887 L F P
0 g
s
.727 .622 .74 r
.37785 .39887 m .35697 .39665 L .35079 .40196 L p F P
0 g
s
.711 .655 .792 r
.3798 .39727 m .40238 .38203 L .39969 .37723 L p F P
0 g
s
.711 .655 .792 r
.37343 .38423 m .3798 .39727 L p .39969 .37723 L F P
0 g
s
.692 .604 .753 r
.46643 .39495 m .46022 .38128 L .43757 .39413 L p F P
0 g
s
.692 .604 .753 r
.46126 .39817 m .46643 .39495 L p .43757 .39413 L F P
0 g
s
.691 .642 .795 r
.43757 .39413 m .46022 .38128 L .4572 .37557 L p F P
0 g
s
.691 .642 .795 r
.4313 .38107 m .43757 .39413 L p .4572 .37557 L F P
0 g
s
.73 .59 .699 r
.36095 .41468 m .35544 .41415 L .35703 .41915 L closepath p F P
0 g
s
.674 .555 .712 r
.49959 .41077 m .49534 .39788 L .47261 .41208 L p F P
0 g
s
.674 .555 .712 r
.47261 .41208 m .47336 .41449 L .49959 .41077 L p F P
0 g
s
.68 .574 .73 r
.46751 .39763 m .47261 .41208 L .49534 .39788 L p F P
0 g
s
.671 .533 .688 r
.5015 .41781 m .49959 .41077 L .47336 .41449 L p F P
0 g
s
.671 .533 .688 r
.48958 .42714 m .5015 .41781 L p .47336 .41449 L F P
0 g
s
.671 .533 .688 r
.47336 .41449 m .47706 .42887 L .48958 .42714 L p F P
0 g
s
.729 .553 .653 r
.36262 .44288 m .36392 .44299 L .37137 .43044 L p F P
0 g
s
.729 .553 .653 r
.37137 .43044 m .35993 .42949 L .36262 .44288 L p F P
0 g
s
.689 .596 .747 r
.46643 .39495 m .46126 .39817 L .46751 .39763 L closepath p F P
0 g
s
.739 .613 .718 r
.35079 .40196 m .34121 .41207 L .35544 .41415 L closepath p F P
0 g
s
.743 .593 .689 r
.3504 .42828 m .35703 .41915 L .35544 .41415 L p F P
0 g
s
.743 .593 .689 r
.33096 .42557 m .3504 .42828 L p .35544 .41415 L F P
0 g
s
.743 .593 .689 r
.35544 .41415 m .34121 .41207 L .33096 .42557 L p F P
0 g
s
.739 .583 .681 r
.35703 .41915 m .3504 .42828 L .35993 .42949 L closepath p F P
0 g
s
.68 .592 .75 r
.46643 .39495 m .46751 .39763 L .49389 .39406 L p F P
0 g
s
.68 .574 .73 r
.49534 .39788 m .49389 .39406 L .46751 .39763 L p F P
0 g
s
.741 .561 .65 r
.34379 .44053 m .36262 .44288 L .35993 .42949 L p F P
0 g
s
.741 .561 .65 r
.35993 .42949 m .3504 .42828 L .34379 .44053 L p F P
0 g
s
.69 .491 .613 r
.44027 .44477 m .42376 .44537 L .42494 .45704 L p F P
0 g
s
.703 .501 .612 r
.40693 .45694 m .42494 .45704 L .42376 .44537 L p F P
0 g
s
.703 .501 .612 r
.42376 .44537 m .41155 .4453 L .40693 .45694 L p F P
0 g
s
.68 .592 .75 r
.49389 .39406 m .48916 .38284 L .46643 .39495 L p F P
0 g
s
.682 .629 .789 r
.46643 .39495 m .48916 .38284 L .48403 .3724 L p F P
0 g
s
.682 .629 .789 r
.46022 .38128 m .46643 .39495 L p .48403 .3724 L F P
0 g
s
.707 .505 .614 r
.39519 .45674 m .40693 .45694 L .41155 .4453 L p F P
0 g
s
.707 .505 .614 r
.41155 .4453 m .39401 .44501 L .39519 .45674 L p F P
0 g
s
.72 .515 .612 r
.38242 .45601 m .39519 .45674 L .39401 .44501 L p F P
0 g
s
.72 .515 .612 r
.39401 .44501 m .38651 .44457 L .38242 .45601 L p F P
0 g
s
.728 .623 .741 r
.35697 .39665 m .34806 .39566 L .35079 .40196 L closepath p F P
0 g
s
.741 .624 .729 r
.34121 .41207 m .35079 .40196 L .34806 .39566 L p F P
0 g
s
.665 .503 .655 r
.48958 .42714 m .47706 .42887 L .47873 .43777 L closepath p F P
0 g
s
.679 .515 .657 r
.47521 .44212 m .47873 .43777 L .47706 .42887 L p F P
0 g
s
.679 .515 .657 r
.45215 .44421 m .47521 .44212 L p .47706 .42887 L F P
0 g
s
.686 .487 .612 r
.45215 .44421 m .44027 .44477 L .43491 .45667 L p F P
0 g
s
.69 .491 .613 r
.42494 .45704 m .43491 .45667 L .44027 .44477 L p F P
0 g
s
.722 .655 .782 r
.35697 .39665 m .37343 .38423 L .36836 .37516 L p F P
0 g
s
.722 .655 .782 r
.34806 .39566 m .35697 .39665 L p .36836 .37516 L F P
0 g
s
.724 .522 .616 r
.36381 .45471 m .38242 .45601 L .38651 .44457 L p F P
0 g
s
.724 .522 .616 r
.36292 .44561 m .36381 .45471 L p .38651 .44457 L F P
0 g
s
.724 .522 .616 r
.38651 .44457 m .36392 .44299 L .36292 .44561 L p F P
0 g
s
.744 .568 .657 r
.32904 .4385 m .34379 .44053 L .3504 .42828 L p F P
0 g
s
.744 .568 .657 r
.32764 .43142 m .32904 .4385 L p .3504 .42828 L F P
0 g
s
.744 .568 .657 r
.3504 .42828 m .33096 .42557 L .32764 .43142 L p F P
0 g
s
.672 .476 .613 r
.47521 .44212 m .45215 .44421 L .45333 .45582 L p F P
0 g
s
.686 .487 .612 r
.43491 .45667 m .45333 .45582 L .45215 .44421 L p F P
0 g
s
.741 .624 .729 r
.32225 .40916 m .34121 .41207 L p .34806 .39566 L F P
0 g
s
.743 .603 .701 r
.32616 .42484 m .33096 .42557 L .34121 .41207 L p F P
0 g
s
.743 .603 .701 r
.32157 .40999 m .32616 .42484 L p .34121 .41207 L F P
0 g
s
.743 .603 .701 r
.34121 .41207 m .32225 .40916 L .32157 .40999 L p F P
0 g
s
.722 .655 .782 r
.3444 .38805 m .34806 .39566 L p .36836 .37516 L F P
0 g
s
.736 .64 .752 r
.3444 .38805 m .33756 .39389 L .34806 .39566 L closepath p F P
0 g
s
.741 .624 .729 r
.34806 .39566 m .33756 .39389 L .32225 .40916 L p F P
0 g
s
.701 .65 .796 r
.42922 .3773 m .41095 .37731 L .40238 .38203 L p F P
0 g
s
.701 .652 .798 r
.41095 .37731 m .39969 .37723 L .40238 .38203 L closepath p F P
0 g
s
.667 .524 .68 r
.5015 .41781 m .48958 .42714 L .50327 .42511 L closepath p F P
0 g
s
.661 .497 .651 r
.50327 .42511 m .48958 .42714 L .47873 .43777 L p F P
0 g
s
.711 .655 .792 r
.39969 .37723 m .38652 .37632 L .37343 .38423 L p F P
0 g
s
.71 .653 .791 r
.38652 .37632 m .36836 .37516 L .37343 .38423 L closepath p F P
0 g
s
.691 .642 .795 r
.4572 .37557 m .43967 .37678 L .4313 .38107 L p F P
0 g
s
.694 .648 .8 r
.43967 .37678 m .42922 .3773 L .4313 .38107 L closepath p F P
0 g
s
.728 .526 .618 r
.36392 .44299 m .36262 .44288 L .36292 .44561 L closepath p F P
0 g
s
.741 .534 .614 r
.36012 .45431 m .36292 .44561 L .36262 .44288 L p F P
0 g
s
.741 .534 .614 r
.34002 .45183 m .36012 .45431 L p .36262 .44288 L F P
0 g
s
.741 .534 .614 r
.36262 .44288 m .34379 .44053 L .34002 .45183 L p F P
0 g
s
.659 .531 .697 r
.51857 .40714 m .49959 .41077 L .5015 .41781 L closepath p F P
0 g
s
.665 .568 .736 r
.49959 .41077 m .51857 .40714 L p .5193 .38921 L F P
0 g
s
.665 .568 .736 r
.49534 .39788 m .49959 .41077 L p .5193 .38921 L F P
0 g
s
.661 .497 .651 r
.47873 .43777 m .47939 .4417 L p .50327 .42511 L F P
0 g
s
.674 .501 .644 r
.47873 .43777 m .47521 .44212 L .47939 .4417 L closepath p F P
0 g
s
.669 .578 .744 r
.5075 .39155 m .49389 .39406 L .49534 .39788 L closepath p F P
0 g
s
.665 .568 .736 r
.5193 .38921 m .5075 .39155 L .49534 .39788 L p F P
0 g
s
.656 .524 .691 r
.5015 .41781 m .50327 .42511 L p .52493 .40587 L F P
0 g
s
.656 .524 .691 r
.52493 .40587 m .51857 .40714 L .5015 .41781 L p F P
0 g
s
.672 .596 .762 r
.48916 .38284 m .49389 .39406 L .5075 .39155 L p F P
0 g
s
.668 .472 .611 r
.47939 .4417 m .47521 .44212 L .46878 .45442 L p F P
0 g
s
.672 .476 .613 r
.45333 .45582 m .46878 .45442 L .47521 .44212 L p F P
0 g
s
.734 .65 .766 r
.33756 .39389 m .3444 .38805 L .33791 .37602 L p F P
0 g
s
.734 .65 .766 r
.33791 .37602 m .31935 .39068 L .33756 .39389 L p F P
0 g
s
.739 .635 .744 r
.32122 .40899 m .32225 .40916 L .33756 .39389 L p F P
0 g
s
.739 .635 .744 r
.31521 .39444 m .32122 .40899 L p .33756 .39389 L F P
0 g
s
.739 .635 .744 r
.33756 .39389 m .31935 .39068 L .31521 .39444 L p F P
0 g
s
.682 .629 .789 r
.48403 .3724 m .4764 .37343 L .46022 .38128 L p F P
0 g
s
.686 .638 .797 r
.4764 .37343 m .4572 .37557 L .46022 .38128 L closepath p F P
0 g
s
.736 .527 .611 r
.36292 .44561 m .36012 .45431 L .36381 .45471 L closepath p F P
0 g
s
.722 .655 .782 r
.36836 .37516 m .36414 .37459 L .3444 .38805 L p F P
0 g
s
.72 .65 .779 r
.36414 .37459 m .3444 .38805 L .33791 .37602 L p F P
0 g
s
.661 .497 .651 r
.47939 .4417 m .50557 .43787 L .50327 .42511 L p F P
0 g
s
.653 .461 .612 r
.50682 .44944 m .50557 .43787 L .47939 .4417 L p F P
0 g
s
.653 .461 .612 r
.47939 .4417 m .48058 .45325 L .50682 .44944 L p F P
0 g
s
.668 .472 .611 r
.46878 .45442 m .48058 .45325 L .47939 .4417 L p F P
0 g
s
.747 .573 .658 r
.33096 .42557 m .32616 .42484 L .32764 .43142 L closepath p F P
0 g
s
.699 .659 .807 r
.42497 .36996 m .41095 .37731 L .42922 .3773 L closepath p F P
0 g
s
.7 .66 .808 r
.41095 .37731 m .42497 .36996 L p .39599 .37095 L F P
0 g
s
.7 .66 .808 r
.39599 .37095 m .39969 .37723 L .41095 .37731 L p F P
0 g
s
.692 .656 .809 r
.42497 .36996 m .42922 .3773 L .43967 .37678 L p F P
0 g
s
.708 .663 .804 r
.39599 .37095 m .38652 .37632 L .39969 .37723 L closepath p F P
0 g
s
.746 .607 .704 r
.32225 .40916 m .32122 .40899 L .32157 .40999 L closepath p F P
0 g
s
.656 .524 .691 r
.50327 .42511 m .52854 .42013 L .52493 .40587 L p F P
0 g
s
.647 .486 .652 r
.53058 .43108 m .52854 .42013 L .50327 .42511 L p F P
0 g
s
.647 .486 .652 r
.52764 .43356 m .53058 .43108 L p .50327 .42511 L F P
0 g
s
.647 .486 .652 r
.50327 .42511 m .50557 .43787 L .52764 .43356 L p F P
0 g
s
.756 .601 .685 r
.32157 .40999 m .31313 .42226 L .32616 .42484 L closepath p F P
0 g
s
.76 .609 .691 r
.31313 .42226 m .32157 .40999 L .32122 .40899 L p F P
0 g
s
.754 .628 .721 r
.31521 .39444 m .30539 .40548 L .32122 .40899 L closepath p F P
0 g
s
.76 .609 .691 r
.29609 .41865 m .31313 .42226 L p .32122 .40899 L F P
0 g
s
.76 .609 .691 r
.32122 .40899 m .30539 .40548 L .29609 .41865 L p F P
0 g
s
.691 .65 .805 r
.45395 .36972 m .43967 .37678 L .4572 .37557 L closepath p F P
0 g
s
.692 .656 .809 r
.43967 .37678 m .45395 .36972 L p .42497 .36996 L F P
0 g
s
.683 .456 .572 r
.43491 .45667 m .42494 .45704 L .42507 .46759 L p F P
0 g
s
.698 .469 .572 r
.40561 .46749 m .42507 .46759 L .42494 .45704 L p F P
0 g
s
.698 .469 .572 r
.42494 .45704 m .40693 .45694 L .40561 .46749 L p F P
0 g
s
.759 .579 .652 r
.32461 .43772 m .32764 .43142 L .32616 .42484 L p F P
0 g
s
.759 .579 .652 r
.30707 .43432 m .32461 .43772 L p .32616 .42484 L F P
0 g
s
.759 .579 .652 r
.32616 .42484 m .31313 .42226 L .30707 .43432 L p F P
0 g
s
.702 .472 .572 r
.39526 .46731 m .40561 .46749 L .40693 .45694 L p F P
0 g
s
.702 .472 .572 r
.40693 .45694 m .39519 .45674 L .39526 .46731 L p F P
0 g
s
.716 .484 .572 r
.38118 .46651 m .39526 .46731 L .39519 .45674 L p F P
0 g
s
.716 .484 .572 r
.39519 .45674 m .38242 .45601 L .38118 .46651 L p F P
0 g
s
.679 .453 .571 r
.45333 .45582 m .43491 .45667 L .43349 .46729 L p F P
0 g
s
.683 .456 .572 r
.42507 .46759 m .43349 .46729 L .43491 .45667 L p F P
0 g
s
.708 .661 .801 r
.38652 .37632 m .39599 .37095 L p .36698 .37281 L F P
0 g
s
.708 .661 .801 r
.36698 .37281 m .36836 .37516 L .38652 .37632 L p F P
0 g
s
.745 .538 .615 r
.33032 .4505 m .34002 .45183 L .34379 .44053 L p F P
0 g
s
.745 .538 .615 r
.34379 .44053 m .32904 .4385 L .33032 .4505 L p F P
0 g
s
.672 .596 .762 r
.51816 .38627 m .512 .37233 L .48916 .38284 L p F P
0 g
s
.672 .596 .762 r
.5075 .39155 m .51816 .38627 L p .48916 .38284 L F P
0 g
s
.677 .624 .788 r
.48403 .3724 m .48916 .38284 L .512 .37233 L p F P
0 g
s
.721 .488 .572 r
.36382 .4653 m .38118 .46651 L .38242 .45601 L p F P
0 g
s
.721 .488 .572 r
.38242 .45601 m .36381 .45471 L .36382 .4653 L p F P
0 g
s
.755 .57 .646 r
.32764 .43142 m .32461 .43772 L .32904 .4385 L closepath p F P
0 g
s
.685 .648 .807 r
.45395 .36972 m .4572 .37557 L .4764 .37343 L p F P
0 g
s
.668 .582 .75 r
.51816 .38627 m .5075 .39155 L .5193 .38921 L closepath p F P
0 g
s
.663 .44 .571 r
.46878 .45442 m .45333 .45582 L .45353 .46636 L p F P
0 g
s
.679 .453 .571 r
.43349 .46729 m .45353 .46636 L .45333 .45582 L p F P
0 g
s
.718 .665 .796 r
.36698 .37281 m .36414 .37459 L .36836 .37516 L closepath p F P
0 g
s
.66 .544 .712 r
.52433 .40388 m .51857 .40714 L .52493 .40587 L closepath p F P
0 g
s
.665 .568 .736 r
.51857 .40714 m .52433 .40388 L .5193 .38921 L p F P
0 g
s
.74 .637 .745 r
.31935 .39068 m .31289 .38949 L .31521 .39444 L closepath p F P
0 g
s
.756 .639 .731 r
.30539 .40548 m .31521 .39444 L .31289 .38949 L p F P
0 g
s
.734 .669 .787 r
.31935 .39068 m .33791 .37602 L .33448 .37035 L p F P
0 g
s
.734 .669 .787 r
.31289 .38949 m .31935 .39068 L p .33448 .37035 L F P
0 g
s
.714 .678 .813 r
.36414 .37459 m .36698 .37281 L .36044 .36278 L p F P
0 g
s
.714 .678 .813 r
.36044 .36278 m .34489 .37173 L .36414 .37459 L p F P
0 g
s
.72 .65 .779 r
.33791 .37602 m .34489 .37173 L .36414 .37459 L p F P
0 g
s
.734 .499 .572 r
.35894 .46478 m .36382 .4653 L .36381 .45471 L p F P
0 g
s
.734 .499 .572 r
.36381 .45471 m .36012 .45431 L .35894 .46478 L p F P
0 g
s
.7 .66 .808 r
.42497 .36996 m .41857 .36029 L .39599 .37095 L p F P
0 g
s
.687 .705 .861 r
.41857 .36029 m .39599 .37095 L .38952 .36123 L p F P
0 g
s
.708 .661 .801 r
.39599 .37095 m .38952 .36123 L .36698 .37281 L p F P
0 g
s
.756 .547 .613 r
.32117 .4489 m .33032 .4505 L .32904 .4385 L p F P
0 g
s
.756 .547 .613 r
.32904 .4385 m .32461 .43772 L .32117 .4489 L p F P
0 g
s
.696 .704 .854 r
.38952 .36123 m .36698 .37281 L .36044 .36278 L p F P
0 g
s
.763 .585 .657 r
.29265 .4313 m .30707 .43432 L .31313 .42226 L p F P
0 g
s
.763 .585 .657 r
.29174 .42699 m .29265 .4313 L p .31313 .42226 L F P
0 g
s
.763 .585 .657 r
.31313 .42226 m .29609 .41865 L .29174 .42699 L p F P
0 g
s
.659 .437 .57 r
.48058 .45325 m .46878 .45442 L .46717 .46513 L p F P
0 g
s
.663 .44 .571 r
.45353 .46636 m .46717 .46513 L .46878 .45442 L p F P
0 g
s
.739 .504 .573 r
.33877 .46231 m .35894 .46478 L .36012 .45431 L p F P
0 g
s
.739 .504 .573 r
.36012 .45431 m .34002 .45183 L .33877 .46231 L p F P
0 g
s
.692 .656 .809 r
.45395 .36972 m .44764 .3598 L .42497 .36996 L p F P
0 g
s
.682 .701 .861 r
.44764 .3598 m .42497 .36996 L .41857 .36029 L p F P
0 g
s
.648 .536 .714 r
.54933 .39966 m .54729 .39309 L .52433 .40388 L p F P
0 g
s
.648 .536 .714 r
.52433 .40388 m .52493 .40587 L .54933 .39966 L p F P
0 g
s
.655 .557 .732 r
.5193 .38921 m .52433 .40388 L .54729 .39309 L p F P
0 g
s
.642 .512 .69 r
.55301 .414 m .54933 .39966 L .52493 .40587 L p F P
0 g
s
.642 .512 .69 r
.52493 .40587 m .52854 .42013 L .55301 .414 L p F P
0 g
s
.636 .449 .613 r
.52764 .43356 m .50557 .43787 L .50682 .44944 L p F P
0 g
s
.682 .637 .798 r
.48296 .37035 m .4764 .37343 L .48403 .3724 L closepath p F P
0 g
s
.685 .648 .807 r
.4764 .37343 m .48296 .37035 L p .45395 .36972 L F P
0 g
s
.734 .669 .787 r
.30871 .38132 m .31289 .38949 L p .33448 .37035 L F P
0 g
s
.749 .653 .754 r
.30871 .38132 m .30259 .38692 L .31289 .38949 L closepath p F P
0 g
s
.756 .639 .731 r
.28884 .40166 m .30539 .40548 L p .31289 .38949 L F P
0 g
s
.756 .639 .731 r
.31289 .38949 m .30259 .38692 L .28884 .40166 L p F P
0 g
s
.761 .553 .615 r
.30355 .44552 m .32117 .4489 L .32461 .43772 L p F P
0 g
s
.761 .553 .615 r
.32461 .43772 m .30707 .43432 L .30355 .44552 L p F P
0 g
s
.76 .617 .701 r
.28935 .41712 m .29609 .41865 L .30539 .40548 L p F P
0 g
s
.76 .617 .701 r
.28564 .40588 m .28935 .41712 L p .30539 .40548 L F P
0 g
s
.76 .617 .701 r
.30539 .40548 m .28884 .40166 L .28564 .40588 L p F P
0 g
s
.657 .577 .753 r
.51816 .38627 m .5193 .38921 L .54374 .38301 L p F P
0 g
s
.655 .557 .732 r
.54729 .39309 m .54374 .38301 L .5193 .38921 L p F P
0 g
s
.717 .667 .8 r
.34489 .37173 m .33448 .37035 L .33791 .37602 L closepath p F P
0 g
s
.685 .648 .807 r
.48296 .37035 m .47672 .35983 L .45395 .36972 L p F P
0 g
s
.679 .689 .852 r
.47672 .35983 m .45395 .36972 L .44764 .3598 L p F P
0 g
s
.642 .423 .57 r
.50714 .45999 m .50682 .44944 L .48058 .45325 L p F P
0 g
s
.642 .423 .57 r
.48058 .45325 m .48083 .46379 L .50714 .45999 L p F P
0 g
s
.659 .437 .57 r
.46717 .46513 m .48083 .46379 L .48058 .45325 L p F P
0 g
s
.662 .607 .782 r
.54113 .37641 m .51816 .38627 L .512 .37233 L p F P
0 g
s
.657 .577 .753 r
.54374 .38301 m .54113 .37641 L .51816 .38627 L p F P
0 g
s
.675 .634 .8 r
.48296 .37035 m .48403 .3724 L .50956 .36759 L p F P
0 g
s
.677 .624 .788 r
.512 .37233 m .50956 .36759 L .48403 .3724 L p F P
0 g
s
.632 .477 .655 r
.55356 .41677 m .55301 .414 L .52854 .42013 L p F P
0 g
s
.632 .477 .655 r
.52854 .42013 m .53058 .43108 L .55356 .41677 L p F P
0 g
s
.714 .673 .809 r
.34489 .37173 m .36044 .36278 L p .33133 .36534 L F P
0 g
s
.714 .673 .809 r
.33133 .36534 m .33448 .37035 L .34489 .37173 L p F P
0 g
s
.675 .634 .8 r
.50956 .36759 m .50582 .36069 L .48296 .37035 L p F P
0 g
s
.675 .671 .837 r
.50582 .36069 m .48296 .37035 L .47672 .35983 L p F P
0 g
s
.744 .508 .573 r
.33028 .46114 m .33877 .46231 L .34002 .45183 L p F P
0 g
s
.744 .508 .573 r
.34002 .45183 m .33032 .4505 L .33028 .46114 L p F P
0 g
s
.673 .416 .524 r
.43349 .46729 m .42507 .46759 L .42425 .47715 L p F P
0 g
s
.69 .431 .526 r
.40733 .47706 m .42425 .47715 L .42507 .46759 L p F P
0 g
s
.69 .431 .526 r
.42507 .46759 m .40561 .46749 L .40733 .47706 L p F P
0 g
s
.695 .434 .525 r
.39431 .47684 m .40733 .47706 L .40561 .46749 L p F P
0 g
s
.695 .434 .525 r
.40561 .46749 m .39526 .46731 L .39431 .47684 L p F P
0 g
s
.747 .661 .766 r
.30259 .38692 m .30871 .38132 L .3021 .36972 L p F P
0 g
s
.747 .661 .766 r
.3021 .36972 m .28677 .38278 L .30259 .38692 L p F P
0 g
s
.755 .648 .742 r
.28359 .40037 m .28884 .40166 L .30259 .38692 L p F P
0 g
s
.755 .648 .742 r
.27922 .39034 m .28359 .40037 L p .30259 .38692 L F P
0 g
s
.755 .648 .742 r
.30259 .38692 m .28677 .38278 L .27922 .39034 L p F P
0 g
s
.734 .669 .787 r
.33448 .37035 m .32647 .36854 L .30871 .38132 L p F P
0 g
s
.73 .661 .781 r
.32647 .36854 m .30871 .38132 L .3021 .36972 L p F P
0 g
s
.71 .448 .527 r
.38255 .47618 m .39431 .47684 L .39526 .46731 L p F P
0 g
s
.71 .448 .527 r
.39526 .46731 m .38118 .46651 L .38255 .47618 L p F P
0 g
s
.673 .416 .524 r
.42425 .47715 m .43566 .47674 L .43349 .46729 L p F P
0 g
s
.669 .414 .525 r
.45353 .46636 m .43349 .46729 L .43566 .47674 L p F P
0 g
s
.728 .678 .801 r
.33133 .36534 m .32647 .36854 L .33448 .37035 L closepath p F P
0 g
s
.766 .589 .659 r
.29609 .41865 m .28935 .41712 L .29174 .42699 L closepath p F P
0 g
s
.756 .518 .572 r
.31995 .45936 m .33028 .46114 L .33032 .4505 L p F P
0 g
s
.756 .518 .572 r
.33032 .4505 m .32117 .4489 L .31995 .45936 L p F P
0 g
s
.766 .557 .616 r
.29407 .44354 m .30355 .44552 L .30707 .43432 L p F P
0 g
s
.766 .557 .616 r
.30707 .43432 m .29265 .4313 L .29407 .44354 L p F P
0 g
s
.715 .452 .525 r
.36273 .47479 m .38255 .47618 L .38118 .46651 L p F P
0 g
s
.715 .452 .525 r
.38118 .46651 m .36382 .4653 L .36273 .47479 L p F P
0 g
s
.651 .398 .523 r
.46717 .46513 m .45353 .46636 L .45281 .47595 L p F P
0 g
s
.669 .414 .525 r
.43566 .47674 m .45281 .47595 L .45353 .46636 L p F P
0 g
s
.763 .621 .703 r
.28884 .40166 m .28359 .40037 L .28564 .40588 L closepath p F P
0 g
s
.662 .607 .782 r
.512 .37233 m .53499 .36295 L .54113 .37641 L p F P
0 g
s
.669 .63 .801 r
.50956 .36759 m .512 .37233 L .53499 .36295 L p F P
0 g
s
.643 .477 .644 r
.53058 .43108 m .52764 .43356 L .53089 .43291 L closepath p F P
0 g
s
.634 .446 .611 r
.53089 .43291 m .52764 .43356 L .51614 .44763 L p F P
0 g
s
.636 .449 .613 r
.50682 .44944 m .51614 .44763 L .52764 .43356 L p F P
0 g
s
.627 .466 .645 r
.55533 .42672 m .55356 .41677 L .53058 .43108 L p F P
0 g
s
.627 .466 .645 r
.53058 .43108 m .53089 .43291 L .55533 .42672 L p F P
0 g
s
.623 .408 .569 r
.51614 .44763 m .50682 .44944 L .50714 .45999 L p F P
0 g
s
.773 .615 .684 r
.28564 .40588 m .28013 .41462 L .28935 .41712 L closepath p F P
0 g
s
.778 .596 .653 r
.2901 .43068 m .29174 .42699 L .28935 .41712 L p F P
0 g
s
.778 .596 .653 r
.27453 .42651 m .2901 .43068 L p .28935 .41712 L F P
0 g
s
.778 .596 .653 r
.28935 .41712 m .28013 .41462 L .27453 .42651 L p F P
0 g
s
.777 .625 .692 r
.28013 .41462 m .28564 .40588 L .28359 .40037 L p F P
0 g
s
.73 .465 .527 r
.36007 .47451 m .36273 .47479 L .36382 .4653 L p F P
0 g
s
.73 .465 .527 r
.36382 .4653 m .35894 .46478 L .36007 .47451 L p F P
0 g
s
.722 .687 .815 r
.32647 .36854 m .33133 .36534 L .32466 .35571 L p F P
0 g
s
.722 .687 .815 r
.32466 .35571 m .30984 .36467 L .32647 .36854 L p F P
0 g
s
.73 .661 .781 r
.3021 .36972 m .30984 .36467 L .32647 .36854 L p F P
0 g
s
.616 .433 .611 r
.55664 .43827 m .55533 .42672 L .53089 .43291 L p F P
0 g
s
.616 .433 .611 r
.53089 .43291 m .53214 .44443 L .55664 .43827 L p F P
0 g
s
.634 .446 .611 r
.51614 .44763 m .53214 .44443 L .53089 .43291 L p F P
0 g
s
.648 .396 .524 r
.48083 .46379 m .46717 .46513 L .46998 .4744 L p F P
0 g
s
.651 .398 .523 r
.45281 .47595 m .46998 .4744 L .46717 .46513 L p F P
0 g
s
.696 .704 .854 r
.36044 .36278 m .38298 .35255 L .38952 .36123 L p F P
0 g
s
.683 .724 .88 r
.38298 .35255 m .36044 .36278 L .35383 .35372 L p F P
0 g
s
.714 .673 .809 r
.36044 .36278 m .35383 .35372 L .33133 .36534 L p F P
0 g
s
.687 .705 .861 r
.38952 .36123 m .41212 .35176 L .41857 .36029 L p F P
0 g
s
.675 .729 .89 r
.41212 .35176 m .38952 .36123 L .38298 .35255 L p F P
0 g
s
.762 .524 .573 r
.30228 .45598 m .31995 .45936 L .32117 .4489 L p F P
0 g
s
.762 .524 .573 r
.32117 .4489 m .30355 .44552 L .30228 .45598 L p F P
0 g
s
.777 .625 .692 r
.26507 .41023 m .28013 .41462 L p .28359 .40037 L F P
0 g
s
.777 .625 .692 r
.28359 .40037 m .27353 .39736 L .26507 .41023 L p F P
0 g
s
.77 .64 .719 r
.27922 .39034 m .27353 .39736 L .28359 .40037 L closepath p F P
0 g
s
.735 .469 .526 r
.33982 .47206 m .36007 .47451 L .35894 .46478 L p F P
0 g
s
.735 .469 .526 r
.35894 .46478 m .33877 .46231 L .33982 .47206 L p F P
0 g
s
.682 .701 .861 r
.41857 .36029 m .44127 .35116 L .44764 .3598 L p F P
0 g
s
.672 .728 .892 r
.44127 .35116 m .41857 .36029 L .41212 .35176 L p F P
0 g
s
.698 .716 .863 r
.35383 .35372 m .33133 .36534 L .32466 .35571 L p F P
0 g
s
.67 .64 .811 r
.50582 .36069 m .50956 .36759 L .53429 .36163 L p F P
0 g
s
.669 .63 .801 r
.53499 .36295 m .53429 .36163 L .50956 .36759 L p F P
0 g
s
.636 .533 .72 r
.57296 .39229 m .57042 .3842 L .54729 .39309 L p F P
0 g
s
.636 .533 .72 r
.54729 .39309 m .54933 .39966 L .57296 .39229 L p F P
0 g
s
.643 .554 .74 r
.54374 .38301 m .54729 .39309 L .57042 .3842 L p F P
0 g
s
.773 .586 .646 r
.29174 .42699 m .2901 .43068 L .29265 .4313 L closepath p F P
0 g
s
.627 .504 .693 r
.57668 .40668 m .57296 .39229 L .54933 .39966 L p F P
0 g
s
.627 .504 .693 r
.54933 .39966 m .55301 .414 L .57668 .40668 L p F P
0 g
s
.679 .689 .852 r
.44764 .3598 m .47044 .35074 L .47672 .35983 L p F P
0 g
s
.673 .719 .884 r
.47044 .35074 m .44764 .3598 L .44127 .35116 L p F P
0 g
s
.628 .379 .522 r
.50661 .46961 m .50714 .45999 L .48083 .46379 L p F P
0 g
s
.628 .379 .522 r
.48083 .46379 m .48022 .47341 L .50661 .46961 L p F P
0 g
s
.648 .396 .524 r
.46998 .4744 m .48022 .47341 L .48083 .46379 L p F P
0 g
s
.621 .406 .569 r
.53214 .44443 m .51614 .44763 L .51342 .45877 L p F P
0 g
s
.623 .408 .569 r
.50714 .45999 m .51342 .45877 L .51614 .44763 L p F P
0 g
s
.648 .575 .76 r
.54113 .37641 m .54374 .38301 L .56737 .3756 L p F P
0 g
s
.643 .554 .74 r
.57042 .3842 m .56737 .3756 L .54374 .38301 L p F P
0 g
s
.776 .565 .613 r
.28685 .44178 m .29407 .44354 L .29265 .4313 L p F P
0 g
s
.776 .565 .613 r
.29265 .4313 m .2901 .43068 L .28685 .44178 L p F P
0 g
s
.748 .677 .783 r
.28677 .38278 m .3021 .36972 L .29726 .36205 L p F P
0 g
s
.748 .677 .783 r
.27385 .37938 m .28677 .38278 L p .29726 .36205 L F P
0 g
s
.755 .648 .743 r
.28677 .38278 m .27385 .37938 L .27922 .39034 L closepath p F P
0 g
s
.771 .652 .73 r
.27353 .39736 m .27922 .39034 L .27385 .37938 L p F P
0 g
s
.782 .602 .656 r
.25936 .42216 m .27453 .42651 L .28013 .41462 L p F P
0 g
s
.782 .602 .656 r
.28013 .41462 m .26507 .41023 L .25936 .42216 L p F P
0 g
s
.675 .671 .837 r
.47672 .35983 m .49962 .35078 L .50582 .36069 L p F P
0 g
s
.674 .702 .869 r
.49962 .35078 m .47672 .35983 L .47044 .35074 L p F P
0 g
s
.782 .572 .615 r
.2712 .43763 m .28685 .44178 L .2901 .43068 L p F P
0 g
s
.782 .572 .615 r
.2901 .43068 m .27453 .42651 L .2712 .43763 L p F P
0 g
s
.726 .675 .8 r
.30984 .36467 m .29726 .36205 L .3021 .36972 L closepath p F P
0 g
s
.648 .575 .76 r
.56737 .3756 m .56426 .36777 L .54113 .37641 L p F P
0 g
s
.655 .605 .787 r
.56426 .36777 m .54113 .37641 L .53499 .36295 L p F P
0 g
s
.616 .47 .661 r
.57671 .40686 m .57668 .40668 L .55301 .414 L p F P
0 g
s
.616 .47 .661 r
.55301 .414 m .55356 .41677 L .57671 .40686 L p F P
0 g
s
.741 .473 .525 r
.32902 .47057 m .33982 .47206 L .33877 .46231 L p F P
0 g
s
.741 .473 .525 r
.33877 .46231 m .33028 .46114 L .32902 .47057 L p F P
0 g
s
.779 .631 .696 r
.25031 .40569 m .26507 .41023 L .27353 .39736 L p F P
0 g
s
.779 .631 .696 r
.27353 .39736 m .259 .39273 L .25031 .40569 L p F P
0 g
s
.771 .652 .73 r
.259 .39273 m .27353 .39736 L p .27385 .37938 L F P
0 g
s
.612 .459 .65 r
.57901 .4194 m .57671 .40686 L .55356 .41677 L p F P
0 g
s
.612 .459 .65 r
.55356 .41677 m .55533 .42672 L .57901 .4194 L p F P
0 g
s
.767 .528 .573 r
.29398 .45425 m .30228 .45598 L .30355 .44552 L p F P
0 g
s
.767 .528 .573 r
.30355 .44552 m .29407 .44354 L .29398 .45425 L p F P
0 g
s
.722 .68 .809 r
.30984 .36467 m .32466 .35571 L p .29539 .35921 L F P
0 g
s
.722 .68 .809 r
.29539 .35921 m .29726 .36205 L .30984 .36467 L p F P
0 g
s
.67 .64 .811 r
.53429 .36163 m .52885 .35177 L .50582 .36069 L p F P
0 g
s
.671 .677 .847 r
.52885 .35177 m .50582 .36069 L .49962 .35078 L p F P
0 g
s
.754 .485 .526 r
.32079 .46916 m .32902 .47057 L .33028 .46114 L p F P
0 g
s
.754 .485 .526 r
.33028 .46114 m .31995 .45936 L .32079 .46916 L p F P
0 g
s
.66 .369 .468 r
.43566 .47674 m .42425 .47715 L .42251 .48579 L p F P
0 g
s
.679 .388 .473 r
.41193 .48573 m .42251 .48579 L .42425 .47715 L p F P
0 g
s
.679 .388 .473 r
.42425 .47715 m .40733 .47706 L .41193 .48573 L p F P
0 g
s
.684 .389 .469 r
.39239 .4854 m .41193 .48573 L .40733 .47706 L p F P
0 g
s
.684 .389 .469 r
.40733 .47706 m .39431 .47684 L .39239 .4854 L p F P
0 g
s
.701 .407 .473 r
.38643 .48507 m .39239 .4854 L .39431 .47684 L p F P
0 g
s
.701 .407 .473 r
.39431 .47684 m .38255 .47618 L .38643 .48507 L p F P
0 g
s
.601 .39 .568 r
.55709 .44883 m .55664 .43827 L .53214 .44443 L p F P
0 g
s
.601 .39 .568 r
.53214 .44443 m .53252 .45498 L .55709 .44883 L p F P
0 g
s
.621 .406 .569 r
.51342 .45877 m .53252 .45498 L .53214 .44443 L p F P
0 g
s
.656 .368 .471 r
.45281 .47595 m .43566 .47674 L .44125 .48511 L p F P
0 g
s
.66 .369 .468 r
.42251 .48579 m .44125 .48511 L .43566 .47674 L p F P
0 g
s
.748 .677 .783 r
.27263 .3771 m .27385 .37938 L p .29726 .36205 L F P
0 g
s
.764 .662 .75 r
.27263 .3771 m .27123 .37851 L .27385 .37938 L closepath p F P
0 g
s
.771 .652 .73 r
.27385 .37938 m .27123 .37851 L .259 .39273 L p F P
0 g
s
.706 .406 .467 r
.36363 .48348 m .38643 .48507 L .38255 .47618 L p F P
0 g
s
.706 .406 .467 r
.3617 .47879 m .36363 .48348 L p .38255 .47618 L F P
0 g
s
.706 .406 .467 r
.38255 .47618 m .36273 .47479 L .3617 .47879 L p F P
0 g
s
.606 .361 .519 r
.51342 .45877 m .50714 .45999 L .50661 .46961 L p F P
0 g
s
.635 .348 .466 r
.46998 .4744 m .45281 .47595 L .45124 .48465 L p F P
0 g
s
.656 .368 .471 r
.44125 .48511 m .45124 .48465 L .45281 .47595 L p F P
0 g
s
.778 .538 .572 r
.2856 .45223 m .29398 .45425 L .29407 .44354 L p F P
0 g
s
.778 .538 .572 r
.29407 .44354 m .28685 .44178 L .2856 .45223 L p F P
0 g
s
.748 .677 .783 r
.29726 .36205 m .2932 .36077 L .27263 .3771 L p F P
0 g
s
.742 .666 .776 r
.2932 .36077 m .27263 .3771 L .26591 .36552 L p F P
0 g
s
.764 .672 .761 r
.27123 .37851 m .27263 .3771 L .26591 .36552 L p F P
0 g
s
.764 .672 .761 r
.26591 .36552 m .25745 .37356 L .27123 .37851 L p F P
0 g
s
.774 .659 .737 r
.24469 .38798 m .259 .39273 L .27123 .37851 L p F P
0 g
s
.774 .659 .737 r
.27123 .37851 m .25745 .37356 L .24469 .38798 L p F P
0 g
s
.76 .49 .525 r
.30305 .46579 m .32079 .46916 L .31995 .45936 L p F P
0 g
s
.76 .49 .525 r
.31995 .45936 m .30228 .45598 L .30305 .46579 L p F P
0 g
s
.655 .605 .787 r
.53499 .36295 m .55814 .35443 L .56426 .36777 L p F P
0 g
s
.662 .633 .81 r
.53429 .36163 m .53499 .36295 L .55814 .35443 L p F P
0 g
s
.74 .686 .799 r
.29539 .35921 m .2932 .36077 L .29726 .36205 L closepath p F P
0 g
s
.597 .42 .612 r
.58038 .43097 m .57901 .4194 L .55533 .42672 L p F P
0 g
s
.597 .42 .612 r
.55533 .42672 m .55664 .43827 L .58038 .43097 L p F P
0 g
s
.683 .724 .88 r
.35383 .35372 m .37637 .34477 L .38298 .35255 L p F P
0 g
s
.665 .742 .907 r
.37637 .34477 m .35383 .35372 L .34715 .34547 L p F P
0 g
s
.698 .716 .863 r
.32466 .35571 m .34715 .34547 L .35383 .35372 L p F P
0 g
s
.787 .577 .616 r
.25598 .4333 m .2712 .43763 L .27453 .42651 L p F P
0 g
s
.787 .577 .616 r
.27453 .42651 m .25936 .42216 L .25598 .4333 L p F P
0 g
s
.605 .36 .52 r
.53252 .45498 m .51342 .45877 L .51876 .46726 L p F P
0 g
s
.606 .361 .519 r
.50661 .46961 m .51876 .46726 L .51342 .45877 L p F P
0 g
s
.785 .61 .663 r
.25199 .41991 m .25936 .42216 L .26507 .41023 L p F P
0 g
s
.785 .61 .663 r
.249 .40827 m .25199 .41991 L p .26507 .41023 L F P
0 g
s
.785 .61 .663 r
.26507 .41023 m .25031 .40569 L .249 .40827 L p F P
0 g
s
.683 .731 .887 r
.34715 .34547 m .32466 .35571 L .31791 .34684 L p F P
0 g
s
.722 .68 .809 r
.32466 .35571 m .31791 .34684 L .29539 .35921 L p F P
0 g
s
.663 .643 .819 r
.52885 .35177 m .53429 .36163 L .55805 .35427 L p F P
0 g
s
.662 .633 .81 r
.55814 .35443 m .55805 .35427 L .53429 .36163 L p F P
0 g
s
.675 .729 .89 r
.38298 .35255 m .40559 .34425 L .41212 .35176 L p F P
0 g
s
.655 .751 .92 r
.40559 .34425 m .38298 .35255 L .37637 .34477 L p F P
0 g
s
.722 .422 .471 r
.36273 .47479 m .3617 .47879 L .36007 .47451 L closepath p F P
0 g
s
.72 .422 .472 r
.34303 .48112 m .33982 .47206 L .36007 .47451 L p F P
0 g
s
.72 .422 .472 r
.36058 .48322 m .34303 .48112 L p .36007 .47451 L F P
0 g
s
.72 .422 .472 r
.36007 .47451 m .3617 .47879 L .36058 .48322 L p F P
0 g
s
.632 .348 .469 r
.48022 .47341 m .46998 .4744 L .47703 .48234 L p F P
0 g
s
.635 .348 .466 r
.45124 .48465 m .47703 .48234 L .46998 .4744 L p F P
0 g
s
.672 .728 .892 r
.41212 .35176 m .43484 .34364 L .44127 .35116 L p F P
0 g
s
.655 .755 .923 r
.43484 .34364 m .41212 .35176 L .40559 .34425 L p F P
0 g
s
.784 .544 .573 r
.2699 .44809 m .2856 .45223 L .28685 .44178 L p F P
0 g
s
.784 .544 .573 r
.28685 .44178 m .2712 .43763 L .2699 .44809 L p F P
0 g
s
.735 .695 .812 r
.2932 .36077 m .29539 .35921 L .2886 .3496 L p F P
0 g
s
.735 .695 .812 r
.2886 .3496 m .27908 .35591 L .2932 .36077 L p F P
0 g
s
.742 .666 .776 r
.26591 .36552 m .27908 .35591 L .2932 .36077 L p F P
0 g
s
.707 .72 .859 r
.31791 .34684 m .29539 .35921 L .2886 .3496 L p F P
0 g
s
.673 .719 .884 r
.44127 .35116 m .46411 .34291 L .47044 .35074 L p F P
0 g
s
.661 .75 .916 r
.46411 .34291 m .44127 .35116 L .43484 .34364 L p F P
0 g
s
.779 .639 .706 r
.24802 .40494 m .25031 .40569 L .259 .39273 L p F P
0 g
s
.779 .639 .706 r
.24262 .39085 m .24802 .40494 L p .259 .39273 L F P
0 g
s
.779 .639 .706 r
.259 .39273 m .24469 .38798 L .24262 .39085 L p F P
0 g
s
.61 .328 .464 r
.50528 .47838 m .50661 .46961 L .48022 .47341 L p F P
0 g
s
.61 .328 .464 r
.48022 .47341 m .47879 .48216 L .50528 .47838 L p F P
0 g
s
.632 .348 .469 r
.47703 .48234 m .47879 .48216 L .48022 .47341 L p F P
0 g
s
.623 .526 .724 r
.59582 .38371 m .59376 .37709 L .57042 .3842 L p F P
0 g
s
.623 .526 .724 r
.57042 .3842 m .57296 .39229 L .59582 .38371 L p F P
0 g
s
.629 .548 .744 r
.56737 .3756 m .57042 .3842 L .59376 .37709 L p F P
0 g
s
.612 .494 .695 r
.59956 .39814 m .59582 .38371 L .57296 .39229 L p F P
0 g
s
.612 .494 .695 r
.57296 .39229 m .57668 .40668 L .59956 .39814 L p F P
0 g
s
.674 .702 .869 r
.47044 .35074 m .49339 .34228 L .49962 .35078 L p F P
0 g
s
.668 .736 .901 r
.49339 .34228 m .47044 .35074 L .46411 .34291 L p F P
0 g
s
.637 .571 .764 r
.56426 .36777 m .56737 .3756 L .5902 .36694 L p F P
0 g
s
.629 .548 .744 r
.59376 .37709 m .5902 .36694 L .56737 .3756 L p F P
0 g
s
.766 .495 .523 r
.2925 .46359 m .30305 .46579 L .30228 .45598 L p F P
0 g
s
.766 .495 .523 r
.30228 .45598 m .29398 .45425 L .2925 .46359 L p F P
0 g
s
.734 .431 .468 r
.32659 .47886 m .34303 .48112 L .33982 .47206 L p F P
0 g
s
.734 .431 .468 r
.33982 .47206 m .32902 .47057 L .32659 .47886 L p F P
0 g
s
.671 .677 .847 r
.49962 .35078 m .52269 .3422 L .52885 .35177 L p F P
0 g
s
.671 .711 .878 r
.52269 .3422 m .49962 .35078 L .49339 .34228 L p F P
0 g
s
.646 .599 .787 r
.58758 .36027 m .56426 .36777 L .55814 .35443 L p F P
0 g
s
.637 .571 .764 r
.5902 .36694 m .58758 .36027 L .56426 .36777 L p F P
0 g
s
.598 .46 .664 r
.60013 .40093 m .59956 .39814 L .57668 .40668 L p F P
0 g
s
.598 .46 .664 r
.57668 .40668 m .57671 .40686 L .60013 .40093 L p F P
0 g
s
.594 .448 .652 r
.60197 .41093 m .60013 .40093 L .57671 .40686 L p F P
0 g
s
.594 .448 .652 r
.57671 .40686 m .57901 .4194 L .60197 .41093 L p F P
0 g
s
.582 .341 .517 r
.55673 .45849 m .55709 .44883 L .53252 .45498 L p F P
0 g
s
.582 .341 .517 r
.53252 .45498 m .53209 .46463 L .55673 .45849 L p F P
0 g
s
.605 .36 .52 r
.51876 .46726 m .53209 .46463 L .53252 .45498 L p F P
0 g
s
.712 .414 .47 r
.3617 .47879 m .36363 .48348 L .36058 .48322 L closepath p F P
0 g
s
.739 .679 .792 r
.27908 .35591 m .26591 .36552 L .2591 .35483 L p F P
0 g
s
.761 .679 .771 r
.25745 .37356 m .26591 .36552 L .2591 .35483 L p F P
0 g
s
.761 .679 .771 r
.2591 .35483 m .24384 .3685 L .25745 .37356 L p F P
0 g
s
.772 .666 .746 r
.24079 .38661 m .24469 .38798 L .25745 .37356 L p F P
0 g
s
.772 .666 .746 r
.23599 .37686 m .24079 .38661 L p .25745 .37356 L F P
0 g
s
.772 .666 .746 r
.25745 .37356 m .24384 .3685 L .23599 .37686 L p F P
0 g
s
.792 .582 .618 r
.25377 .43262 m .25598 .4333 L .25936 .42216 L p F P
0 g
s
.792 .582 .618 r
.25936 .42216 m .25199 .41991 L .25377 .43262 L p F P
0 g
s
.579 .374 .567 r
.58089 .44155 m .58038 .43097 L .55664 .43827 L p F P
0 g
s
.579 .374 .567 r
.55664 .43827 m .55709 .44883 L .58089 .44155 L p F P
0 g
s
.748 .446 .472 r
.3236 .47835 m .32659 .47886 L .32902 .47057 L p F P
0 g
s
.748 .446 .472 r
.32902 .47057 m .32079 .46916 L .3236 .47835 L p F P
0 g
s
.789 .616 .665 r
.25031 .40569 m .24802 .40494 L .249 .40827 L closepath p F P
0 g
s
.663 .643 .819 r
.55805 .35427 m .55203 .34336 L .52885 .35177 L p F P
0 g
s
.668 .679 .851 r
.55203 .34336 m .52885 .35177 L .52269 .3422 L p F P
0 g
s
.777 .506 .525 r
.28622 .46208 m .2925 .46359 L .29398 .45425 L p F P
0 g
s
.777 .506 .525 r
.29398 .45425 m .2856 .45223 L .28622 .46208 L p F P
0 g
s
.79 .549 .572 r
.25466 .44376 m .2699 .44809 L .2712 .43763 L p F P
0 g
s
.79 .549 .572 r
.2712 .43763 m .25598 .4333 L .25466 .44376 L p F P
0 g
s
.793 .638 .688 r
.24262 .39085 m .2367 .4007 L .24802 .40494 L closepath p F P
0 g
s
.802 .62 .656 r
.24497 .41749 m .249 .40827 L .24802 .40494 L p F P
0 g
s
.802 .62 .656 r
.2314 .41248 m .24497 .41749 L p .24802 .40494 L F P
0 g
s
.802 .62 .656 r
.24802 .40494 m .2367 .4007 L .2314 .41248 L p F P
0 g
s
.796 .611 .651 r
.249 .40827 m .24497 .41749 L .25199 .41991 L closepath p F P
0 g
s
.584 .306 .46 r
.51876 .46726 m .50661 .46961 L .50528 .47838 L p F P
0 g
s
.64 .312 .4 r
.44125 .48511 m .42251 .48579 L .41987 .49353 L p F P
0 g
s
.663 .335 .408 r
.41937 .49352 m .41987 .49353 L .42251 .48579 L p F P
0 g
s
.663 .335 .408 r
.42251 .48579 m .41193 .48573 L .41937 .49352 L p F P
0 g
s
.666 .332 .398 r
.39308 .49309 m .41937 .49352 L .41193 .48573 L p F P
0 g
s
.666 .332 .398 r
.39054 .49022 m .39308 .49309 L p .41193 .48573 L F P
0 g
s
.666 .332 .398 r
.41193 .48573 m .39239 .4854 L .39054 .49022 L p F P
0 g
s
.728 .698 .822 r
.27908 .35591 m .2886 .3496 L .28173 .34059 L p F P
0 g
s
.728 .698 .822 r
.28173 .34059 m .26461 .35114 L .27908 .35591 L p F P
0 g
s
.739 .679 .792 r
.2591 .35483 m .26461 .35114 L .27908 .35591 L p F P
0 g
s
.686 .353 .406 r
.39239 .4854 m .39054 .49022 L .38643 .48507 L closepath p F P
0 g
s
.755 .451 .469 r
.30576 .475 m .3236 .47835 L .32079 .46916 L p F P
0 g
s
.755 .451 .469 r
.32079 .46916 m .30305 .46579 L .30576 .475 L p F P
0 g
s
.782 .644 .709 r
.24469 .38798 m .24079 .38661 L .24262 .39085 L closepath p F P
0 g
s
.637 .313 .405 r
.45124 .48465 m .44911 .49148 L .44125 .48511 L closepath p F P
0 g
s
.64 .312 .4 r
.4488 .49249 m .44911 .49148 L .44125 .48511 L p F P
0 g
s
.64 .312 .4 r
.41987 .49353 m .4488 .49249 L p .44125 .48511 L F P
0 g
s
.685 .353 .408 r
.36978 .49164 m .36363 .48348 L .38643 .48507 L p F P
0 g
s
.685 .353 .408 r
.38949 .49298 m .36978 .49164 L p .38643 .48507 L F P
0 g
s
.685 .353 .408 r
.38643 .48507 m .39054 .49022 L .38949 .49298 L p F P
0 g
s
.683 .731 .887 r
.31791 .34684 m .34039 .33791 L .34715 .34547 L p F P
0 g
s
.664 .744 .909 r
.34039 .33791 m .31791 .34684 L .31109 .3386 L p F P
0 g
s
.707 .72 .859 r
.2886 .3496 m .31109 .3386 L .31791 .34684 L p F P
0 g
s
.802 .59 .615 r
.24181 .42855 m .25377 .43262 L .25199 .41991 L p F P
0 g
s
.802 .59 .615 r
.25199 .41991 m .24497 .41749 L .24181 .42855 L p F P
0 g
s
.798 .647 .695 r
.2367 .4007 m .24262 .39085 L .24079 .38661 L p F P
0 g
s
.784 .512 .524 r
.27044 .45796 m .28622 .46208 L .2856 .45223 L p F P
0 g
s
.784 .512 .524 r
.2856 .45223 m .2699 .44809 L .27044 .45796 L p F P
0 g
s
.665 .742 .907 r
.34715 .34547 m .36968 .33778 L .37637 .34477 L p F P
0 g
s
.64 .758 .934 r
.36968 .33778 m .34715 .34547 L .34039 .33791 L p F P
0 g
s
.612 .288 .396 r
.47703 .48234 m .45124 .48465 L .44911 .49148 L p F P
0 g
s
.577 .405 .612 r
.60339 .42253 m .60197 .41093 L .57901 .4194 L p F P
0 g
s
.577 .405 .612 r
.57901 .4194 m .58038 .43097 L .60339 .42253 L p F P
0 g
s
.646 .599 .787 r
.55814 .35443 m .58148 .34669 L .58758 .36027 L p F P
0 g
s
.653 .631 .815 r
.55805 .35427 m .55814 .35443 L .58148 .34669 L p F P
0 g
s
.693 .73 .879 r
.31109 .3386 m .2886 .3496 L .28173 .34059 L p F P
0 g
s
.655 .751 .92 r
.37637 .34477 m .399 .33764 L .40559 .34425 L p F P
0 g
s
.627 .771 .949 r
.399 .33764 m .37637 .34477 L .36968 .33778 L p F P
0 g
s
.656 .642 .824 r
.55203 .34336 m .55805 .35427 L .58079 .34536 L p F P
0 g
s
.653 .631 .815 r
.58148 .34669 m .58079 .34536 L .55805 .35427 L p F P
0 g
s
.789 .66 .721 r
.23599 .37686 m .23147 .3828 L .24079 .38661 L closepath p F P
0 g
s
.798 .647 .695 r
.2236 .39548 m .2367 .4007 L p .24079 .38661 L F P
0 g
s
.798 .647 .695 r
.24079 .38661 m .23147 .3828 L .2236 .39548 L p F P
0 g
s
.583 .306 .462 r
.53209 .46463 m .53096 .47286 L .51876 .46726 L closepath p F P
0 g
s
.584 .306 .46 r
.53088 .47345 m .53096 .47286 L .51876 .46726 L p F P
0 g
s
.584 .306 .46 r
.50528 .47838 m .53088 .47345 L p .51876 .46726 L F P
0 g
s
.698 .359 .399 r
.35734 .4906 m .36978 .49164 L .36363 .48348 L p F P
0 g
s
.698 .359 .399 r
.36363 .48348 m .36058 .48322 L .35734 .4906 L p F P
0 g
s
.655 .755 .923 r
.40559 .34425 m .42835 .33714 L .43484 .34364 L p F P
0 g
s
.627 .78 .954 r
.42835 .33714 m .40559 .34425 L .399 .33764 L p F P
0 g
s
.716 .379 .407 r
.34838 .48953 m .35734 .4906 L .36058 .48322 L p F P
0 g
s
.716 .379 .407 r
.36058 .48322 m .34303 .48112 L .34838 .48953 L p F P
0 g
s
.661 .75 .916 r
.43484 .34364 m .45772 .33621 L .46411 .34291 L p F P
0 g
s
.639 .781 .949 r
.45772 .33621 m .43484 .34364 L .42835 .33714 L p F P
0 g
s
.808 .597 .616 r
.22818 .42357 m .24181 .42855 L .24497 .41749 L p F P
0 g
s
.808 .597 .616 r
.24497 .41749 m .2314 .41248 L .22818 .42357 L p F P
0 g
s
.668 .736 .901 r
.46411 .34291 m .48711 .33502 L .49339 .34228 L p F P
0 g
s
.655 .77 .934 r
.48711 .33502 m .46411 .34291 L .45772 .33621 L p F P
0 g
s
.608 .284 .395 r
.47879 .48216 m .4785 .48315 L .47703 .48234 L closepath p F P
0 g
s
.612 .288 .396 r
.47651 .49005 m .4785 .48315 L .47703 .48234 L p F P
0 g
s
.612 .288 .396 r
.45044 .49235 m .47651 .49005 L p .47703 .48234 L F P
0 g
s
.612 .288 .396 r
.44911 .49148 m .45044 .49235 L p .47703 .48234 L F P
0 g
s
.762 .693 .785 r
.24384 .3685 m .2591 .35483 L .25436 .34794 L p F P
0 g
s
.762 .693 .785 r
.23031 .36337 m .24384 .3685 L p .25436 .34794 L F P
0 g
s
.772 .667 .747 r
.22921 .36445 m .23031 .36337 L .24384 .3685 L p F P
0 g
s
.772 .667 .747 r
.24384 .3685 m .23599 .37686 L .22921 .36445 L p F P
0 g
s
.587 .263 .388 r
.50317 .48634 m .50528 .47838 L .47879 .48216 L p F P
0 g
s
.587 .263 .388 r
.49089 .48808 m .50317 .48634 L p .47879 .48216 L F P
0 g
s
.587 .263 .388 r
.47879 .48216 m .4785 .48315 L .49089 .48808 L p F P
0 g
s
.762 .454 .465 r
.2897 .47164 m .30576 .475 L .30305 .46579 L p F P
0 g
s
.762 .454 .465 r
.30305 .46579 m .2925 .46359 L .2897 .47164 L p F P
0 g
s
.796 .555 .572 r
.25367 .44346 m .25466 .44376 L .25598 .4333 L p F P
0 g
s
.796 .555 .572 r
.25598 .4333 m .25377 .43262 L .25367 .44346 L p F P
0 g
s
.734 .69 .808 r
.26461 .35114 m .25436 .34794 L .2591 .35483 L closepath p F P
0 g
s
.806 .626 .658 r
.21821 .4073 m .2314 .41248 L .2367 .4007 L p F P
0 g
s
.806 .626 .658 r
.2367 .4007 m .2236 .39548 L .21821 .4073 L p F P
0 g
s
.671 .711 .878 r
.49339 .34228 m .5165 .33403 L .52269 .3422 L p F P
0 g
s
.668 .747 .91 r
.5165 .33403 m .49339 .34228 L .48711 .33502 L p F P
0 g
s
.789 .669 .731 r
.23147 .3828 m .23599 .37686 L .22921 .36445 L p F P
0 g
s
.806 .564 .572 r
.24048 .43901 m .25367 .44346 L .25377 .43262 L p F P
0 g
s
.806 .564 .572 r
.25377 .43262 m .24181 .42855 L .24048 .43901 L p F P
0 g
s
.608 .517 .725 r
.61796 .37392 m .61734 .3719 L .59376 .37709 L p F P
0 g
s
.608 .517 .725 r
.59376 .37709 m .59582 .38371 L .61796 .37392 L p F P
0 g
s
.613 .538 .746 r
.5902 .36694 m .59376 .37709 L .61734 .3719 L p F P
0 g
s
.556 .321 .514 r
.58061 .45123 m .58089 .44155 L .55709 .44883 L p F P
0 g
s
.556 .321 .514 r
.55709 .44883 m .55673 .45849 L .58061 .45123 L p F P
0 g
s
.595 .484 .697 r
.6217 .38836 m .61796 .37392 L .59582 .38371 L p F P
0 g
s
.595 .484 .697 r
.59582 .38371 m .59956 .39814 L .6217 .38836 L p F P
0 g
s
.73 .694 .816 r
.26461 .35114 m .28173 .34059 L p .2522 .34489 L F P
0 g
s
.73 .694 .816 r
.2522 .34489 m .25436 .34794 L .26461 .35114 L p F P
0 g
s
.721 .375 .392 r
.32865 .48684 m .34838 .48953 L .34303 .48112 L p F P
0 g
s
.721 .375 .392 r
.32531 .48134 m .32865 .48684 L p .34303 .48112 L F P
0 g
s
.721 .375 .392 r
.34303 .48112 m .32659 .47886 L .32531 .48134 L p F P
0 g
s
.587 .265 .392 r
.4785 .48315 m .49089 .48808 L .47651 .49005 L closepath p F P
0 g
s
.559 .285 .456 r
.55562 .46733 m .55673 .45849 L .53209 .46463 L p F P
0 g
s
.559 .285 .456 r
.53233 .47309 m .55562 .46733 L p .53209 .46463 L F P
0 g
s
.559 .285 .456 r
.53209 .46463 m .53096 .47286 L .53233 .47309 L p F P
0 g
s
.668 .679 .851 r
.52269 .3422 m .54592 .33387 L .55203 .34336 L p F P
0 g
s
.671 .715 .881 r
.54592 .33387 m .52269 .3422 L .5165 .33403 L p F P
0 g
s
.625 .563 .765 r
.58758 .36027 m .5902 .36694 L .61227 .357 L p F P
0 g
s
.613 .538 .746 r
.61734 .3719 m .61227 .357 L .5902 .36694 L p F P
0 g
s
.791 .517 .522 r
.25519 .45363 m .27044 .45796 L .2699 .44809 L p F P
0 g
s
.791 .517 .522 r
.2699 .44809 m .25466 .44376 L .25519 .45363 L p F P
0 g
s
.789 .669 .731 r
.22921 .36445 m .2189 .37733 L .23147 .3828 L p F P
0 g
s
.801 .653 .699 r
.21084 .39008 m .2236 .39548 L .23147 .3828 L p F P
0 g
s
.801 .653 .699 r
.23147 .3828 m .2189 .37733 L .21084 .39008 L p F P
0 g
s
.673 .341 .404 r
.39054 .49022 m .39308 .49309 L .38949 .49298 L closepath p F P
0 g
s
.773 .467 .469 r
.28862 .47138 m .2897 .47164 L .2925 .46359 L p F P
0 g
s
.773 .467 .469 r
.2925 .46359 m .28622 .46208 L .28862 .47138 L p F P
0 g
s
.556 .356 .565 r
.60397 .43312 m .60339 .42253 L .58038 .43097 L p F P
0 g
s
.556 .356 .565 r
.58038 .43097 m .58089 .44155 L .60397 .43312 L p F P
0 g
s
.625 .563 .765 r
.61227 .357 m .61113 .35401 L .58758 .36027 L p F P
0 g
s
.635 .586 .782 r
.61113 .35401 m .58758 .36027 L .58148 .34669 L p F P
0 g
s
.577 .444 .664 r
.62389 .39943 m .6217 .38836 L .59956 .39814 L p F P
0 g
s
.577 .444 .664 r
.59956 .39814 m .60013 .40093 L .62389 .39943 L p F P
0 g
s
.656 .642 .824 r
.58079 .34536 m .5754 .33539 L .55203 .34336 L p F P
0 g
s
.664 .674 .85 r
.5754 .33539 m .55203 .34336 L .54592 .33387 L p F P
0 g
s
.736 .394 .4 r
.32659 .47886 m .32531 .48134 L .3236 .47835 L closepath p F P
0 g
s
.575 .434 .652 r
.62423 .40128 m .62389 .39943 L .60013 .40093 L p F P
0 g
s
.575 .434 .652 r
.60013 .40093 m .60197 .41093 L .62423 .40128 L p F P
0 g
s
.556 .239 .387 r
.52888 .48142 m .53088 .47345 L .50528 .47838 L p F P
0 g
s
.556 .239 .387 r
.50528 .47838 m .50317 .48634 L .52888 .48142 L p F P
0 g
s
.781 .473 .466 r
.27274 .46728 m .28862 .47138 L .28622 .46208 L p F P
0 g
s
.781 .473 .466 r
.28622 .46208 m .27044 .45796 L .27274 .46728 L p F P
0 g
s
.736 .393 .401 r
.31036 .48362 m .30576 .475 L .3236 .47835 L p F P
0 g
s
.736 .393 .401 r
.32294 .48596 m .31036 .48362 L p .3236 .47835 L F P
0 g
s
.736 .393 .401 r
.3236 .47835 m .32531 .48134 L .32294 .48596 L p F P
0 g
s
.752 .7 .802 r
.2522 .34489 m .25047 .34621 L .25436 .34794 L closepath p F P
0 g
s
.762 .693 .785 r
.25436 .34794 m .25047 .34621 L .23031 .36337 L p F P
0 g
s
.664 .744 .909 r
.31109 .3386 m .33355 .33094 L .34039 .33791 L p F P
0 g
s
.639 .753 .931 r
.33355 .33094 m .31109 .3386 L .30419 .33087 L p F P
0 g
s
.693 .73 .879 r
.28173 .34059 m .30419 .33087 L .31109 .3386 L p F P
0 g
s
.677 .739 .897 r
.30419 .33087 m .28173 .34059 L .27478 .33208 L p F P
0 g
s
.73 .694 .816 r
.28173 .34059 m .27478 .33208 L .2522 .34489 L p F P
0 g
s
.814 .603 .618 r
.21494 .4184 m .22818 .42357 L .2314 .41248 L p F P
0 g
s
.814 .603 .618 r
.2314 .41248 m .21821 .4073 L .21494 .4184 L p F P
0 g
s
.64 .758 .934 r
.34039 .33791 m .36292 .33148 L .36968 .33778 L p F P
0 g
s
.606 .769 .958 r
.36292 .33148 m .34039 .33791 L .33355 .33094 L p F P
0 g
s
.813 .571 .572 r
.2268 .43404 m .24048 .43901 L .24181 .42855 L p F P
0 g
s
.813 .571 .572 r
.24181 .42855 m .22818 .42357 L .2268 .43404 L p F P
0 g
s
.759 .701 .797 r
.22803 .36245 m .23031 .36337 L .25047 .34621 L p F P
0 g
s
.771 .677 .759 r
.23031 .36337 m .22803 .36245 L .22921 .36445 L closepath p F P
0 g
s
.793 .679 .738 r
.2189 .37733 m .22921 .36445 L .22803 .36245 L p F P
0 g
s
.619 .296 .402 r
.44911 .49148 m .45044 .49235 L .4488 .49249 L closepath p F P
0 g
s
.617 .24 .306 r
.44546 .4994 m .4488 .49249 L .41987 .49353 L p F P
0 g
s
.617 .24 .306 r
.43126 .49991 m .44546 .4994 L p .41987 .49353 L F P
0 g
s
.617 .24 .306 r
.41987 .49353 m .41974 .49376 L .43126 .49991 L p F P
0 g
s
.635 .26 .316 r
.41987 .49353 m .41974 .49376 L .41937 .49352 L closepath p F P
0 g
s
.634 .262 .32 r
.40305 .50008 m .39308 .49309 L .41937 .49352 L p F P
0 g
s
.634 .262 .32 r
.41626 .50029 m .40305 .50008 L p .41937 .49352 L F P
0 g
s
.634 .262 .32 r
.41937 .49352 m .41974 .49376 L .41626 .50029 L p F P
0 g
s
.811 .633 .661 r
.20537 .40194 m .21821 .4073 L .2236 .39548 L p F P
0 g
s
.811 .633 .661 r
.2236 .39548 m .21084 .39008 L .20537 .40194 L p F P
0 g
s
.617 .242 .31 r
.41974 .49376 m .43126 .49991 L .41626 .50029 L closepath p F P
0 g
s
.647 .268 .312 r
.38556 .49956 m .40305 .50008 L .39308 .49309 L p F P
0 g
s
.647 .268 .312 r
.39308 .49309 m .38949 .49298 L .38556 .49956 L p F P
0 g
s
.671 .296 .326 r
.37833 .49907 m .38556 .49956 L .38949 .49298 L p F P
0 g
s
.671 .296 .326 r
.38949 .49298 m .36978 .49164 L .37833 .49907 L p F P
0 g
s
.627 .771 .949 r
.36968 .33778 m .39233 .33184 L .399 .33764 L p F P
0 g
s
.584 .786 .975 r
.39233 .33184 m .36968 .33778 L .36292 .33148 L p F P
0 g
s
.748 .706 .812 r
.25047 .34621 m .2522 .34489 L .24521 .33559 L p F P
0 g
s
.748 .706 .812 r
.24521 .33559 m .23844 .34044 L .25047 .34621 L p F P
0 g
s
.759 .701 .797 r
.22231 .35336 m .22803 .36245 L p .25047 .34621 L F P
0 g
s
.759 .701 .797 r
.25047 .34621 m .23844 .34044 L .22231 .35336 L p F P
0 g
s
.782 .688 .76 r
.22231 .35336 m .21815 .35768 L .22803 .36245 L closepath p F P
0 g
s
.793 .679 .738 r
.20662 .3717 m .2189 .37733 L p .22803 .36245 L F P
0 g
s
.793 .679 .738 r
.22803 .36245 m .21815 .35768 L .20662 .3717 L p F P
0 g
s
.798 .522 .52 r
.25186 .45261 m .25519 .45363 L .25466 .44376 L p F P
0 g
s
.798 .522 .52 r
.25466 .44376 m .25367 .44346 L .25186 .45261 L p F P
0 g
s
.714 .727 .86 r
.27478 .33208 m .2522 .34489 L .24521 .33559 L p F P
0 g
s
.635 .586 .782 r
.58148 .34669 m .60502 .33982 L .61113 .35401 L p F P
0 g
s
.642 .624 .816 r
.58079 .34536 m .58148 .34669 L .60502 .33982 L p F P
0 g
s
.584 .215 .307 r
.45044 .49235 m .4488 .49249 L .44546 .4994 L p F P
0 g
s
.555 .389 .612 r
.6257 .4129 m .62423 .40128 L .60197 .41093 L p F P
0 g
s
.555 .389 .612 r
.60197 .41093 m .60339 .42253 L .6257 .4129 L p F P
0 g
s
.584 .215 .307 r
.44546 .4994 m .46533 .4978 L .45044 .49235 L p F P
0 g
s
.584 .22 .317 r
.47651 .49005 m .45044 .49235 L .46533 .4978 L p F P
0 g
s
.808 .532 .522 r
.24084 .44893 m .25186 .45261 L .25367 .44346 L p F P
0 g
s
.808 .532 .522 r
.25367 .44346 m .24048 .43901 L .24084 .44893 L p F P
0 g
s
.627 .78 .954 r
.399 .33764 m .42179 .33159 L .42835 .33714 L p F P
0 g
s
.582 .801 .983 r
.42179 .33159 m .399 .33764 L .39233 .33184 L p F P
0 g
s
.648 .636 .824 r
.5754 .33539 m .58079 .34536 L .60262 .33498 L p F P
0 g
s
.642 .624 .816 r
.60502 .33982 m .60262 .33498 L .58079 .34536 L p F P
0 g
s
.729 .386 .398 r
.32531 .48134 m .32865 .48684 L .32294 .48596 L closepath p F P
0 g
s
.674 .289 .309 r
.35609 .49722 m .37833 .49907 L .36978 .49164 L p F P
0 g
s
.674 .289 .309 r
.35408 .49534 m .35609 .49722 L p .36978 .49164 L F P
0 g
s
.674 .289 .309 r
.36978 .49164 m .35734 .4906 L .35408 .49534 L p F P
0 g
s
.639 .781 .949 r
.42835 .33714 m .45128 .33057 L .45772 .33621 L p F P
0 g
s
.603 .807 .978 r
.45128 .33057 m .42835 .33714 L .42179 .33159 L p F P
0 g
s
.804 .659 .703 r
.19839 .38453 m .21084 .39008 L .2189 .37733 L p F P
0 g
s
.804 .659 .703 r
.2189 .37733 m .20662 .3717 L .19839 .38453 L p F P
0 g
s
.75 .398 .385 r
.29308 .48004 m .31036 .48362 L .30576 .475 L p F P
0 g
s
.75 .398 .385 r
.28916 .47248 m .29308 .48004 L p .30576 .475 L F P
0 g
s
.75 .398 .385 r
.30576 .475 m .2897 .47164 L .28916 .47248 L p F P
0 g
s
.528 .259 .45 r
.57958 .46007 m .58061 .45123 L .55673 .45849 L p F P
0 g
s
.528 .259 .45 r
.55673 .45849 m .55562 .46733 L .57958 .46007 L p F P
0 g
s
.655 .77 .934 r
.45772 .33621 m .48078 .32893 L .48711 .33502 L p F P
0 g
s
.632 .804 .965 r
.48078 .32893 m .45772 .33621 L .45128 .33057 L p F P
0 g
s
.668 .747 .91 r
.48711 .33502 m .51028 .32712 L .5165 .33403 L p F P
0 g
s
.658 .785 .942 r
.51028 .32712 m .48711 .33502 L .48078 .32893 L p F P
0 g
s
.696 .315 .323 r
.35734 .4906 m .35408 .49534 L .34838 .48953 L closepath p F P
0 g
s
.789 .478 .462 r
.25744 .46295 m .27274 .46728 L .27044 .45796 L p F P
0 g
s
.789 .478 .462 r
.27044 .45796 m .25519 .45363 L .25744 .46295 L p F P
0 g
s
.529 .299 .51 r
.60376 .44281 m .60397 .43312 L .58089 .44155 L p F P
0 g
s
.529 .299 .51 r
.58089 .44155 m .58061 .45123 L .60376 .44281 L p F P
0 g
s
.671 .715 .881 r
.5165 .33403 m .53979 .32577 L .54592 .33387 L p F P
0 g
s
.671 .753 .912 r
.53979 .32577 m .5165 .33403 L .51028 .32712 L p F P
0 g
s
.559 .287 .459 r
.53096 .47286 m .53233 .47309 L .53088 .47345 L closepath p F P
0 g
s
.551 .186 .302 r
.49089 .48808 m .47651 .49005 L .4734 .49709 L p F P
0 g
s
.584 .22 .317 r
.46533 .4978 m .4734 .49709 L .47651 .49005 L p F P
0 g
s
.524 .21 .378 r
.53233 .47309 m .53088 .47345 L .52888 .48142 L p F P
0 g
s
.695 .315 .324 r
.33594 .49464 m .32865 .48684 L .34838 .48953 L p F P
0 g
s
.695 .315 .324 r
.35301 .49692 m .33594 .49464 L p .34838 .48953 L F P
0 g
s
.695 .315 .324 r
.34838 .48953 m .35408 .49534 L .35301 .49692 L p F P
0 g
s
.664 .674 .85 r
.54592 .33387 m .56933 .32571 L .5754 .33539 L p F P
0 g
s
.671 .711 .878 r
.56933 .32571 m .54592 .33387 L .53979 .32577 L p F P
0 g
s
.523 .211 .379 r
.55562 .46733 m .55442 .47241 L .53233 .47309 L closepath p F P
0 g
s
.524 .21 .378 r
.55375 .47533 m .55442 .47241 L .53233 .47309 L p F P
0 g
s
.524 .21 .378 r
.52888 .48142 m .55375 .47533 L p .53233 .47309 L F P
0 g
s
.819 .611 .622 r
.20637 .41482 m .21494 .4184 L .21821 .4073 L p F P
0 g
s
.819 .611 .622 r
.20459 .40448 m .20637 .41482 L p .21821 .4073 L F P
0 g
s
.819 .611 .622 r
.21821 .4073 m .20537 .40194 L .20459 .40448 L p F P
0 g
s
.82 .577 .572 r
.21354 .42888 m .2268 .43404 L .22818 .42357 L p F P
0 g
s
.82 .577 .572 r
.22818 .42357 m .21494 .4184 L .21354 .42888 L p F P
0 g
s
.754 .691 .791 r
.23844 .34044 m .22231 .35336 L .2153 .34301 L p F P
0 g
s
.781 .695 .769 r
.21815 .35768 m .22231 .35336 L .2153 .34301 L p F P
0 g
s
.781 .695 .769 r
.2153 .34301 m .20654 .35174 L .21815 .35768 L p F P
0 g
s
.795 .685 .743 r
.19464 .36591 m .20662 .3717 L .21815 .35768 L p F P
0 g
s
.795 .685 .743 r
.21815 .35768 m .20654 .35174 L .19464 .36591 L p F P
0 g
s
.592 .503 .723 r
.61734 .3719 m .62333 .37115 L .61796 .37392 L closepath p F P
0 g
s
.594 .522 .744 r
.61227 .357 m .61734 .3719 L .62333 .37115 L p F P
0 g
s
.58 .477 .701 r
.64314 .37733 m .6217 .38836 L .61796 .37392 L p F P
0 g
s
.58 .477 .701 r
.64127 .36989 m .64314 .37733 L p .61796 .37392 L F P
0 g
s
.58 .477 .701 r
.61796 .37392 m .62333 .37115 L .64127 .36989 L p F P
0 g
s
.549 .186 .305 r
.50317 .48634 m .50158 .49013 L .49089 .48808 L closepath p F P
0 g
s
.551 .186 .302 r
.50023 .49345 m .50158 .49013 L .49089 .48808 L p F P
0 g
s
.551 .186 .302 r
.4734 .49709 m .50023 .49345 L p .49089 .48808 L F P
0 g
s
.813 .642 .67 r
.20393 .4013 m .20537 .40194 L .21084 .39008 L p F P
0 g
s
.813 .642 .67 r
.19831 .38469 m .20393 .4013 L p .21084 .39008 L F P
0 g
s
.813 .642 .67 r
.21084 .39008 m .19839 .38453 L .19831 .38469 L p F P
0 g
s
.816 .539 .52 r
.22711 .44397 m .24084 .44893 L .24048 .43901 L p F P
0 g
s
.816 .539 .52 r
.24048 .43901 m .2268 .43404 L .22711 .44397 L p F P
0 g
s
.763 .414 .393 r
.2897 .47164 m .28916 .47248 L .28862 .47138 L closepath p F P
0 g
s
.53 .337 .563 r
.62634 .42352 m .6257 .4129 L .60339 .42253 L p F P
0 g
s
.53 .337 .563 r
.60339 .42253 m .60397 .43312 L .62634 .42352 L p F P
0 g
s
.764 .414 .392 r
.27677 .47608 m .27274 .46728 L .28862 .47138 L p F P
0 g
s
.764 .414 .392 r
.28545 .47829 m .27677 .47608 L p .28862 .47138 L F P
0 g
s
.764 .414 .392 r
.28862 .47138 m .28916 .47248 L .28545 .47829 L p F P
0 g
s
.677 .739 .897 r
.27478 .33208 m .29722 .32356 L .30419 .33087 L p F P
0 g
s
.658 .744 .914 r
.29722 .32356 m .27478 .33208 L .26776 .32396 L p F P
0 g
s
.714 .727 .86 r
.24521 .33559 m .26776 .32396 L .27478 .33208 L p F P
0 g
s
.648 .636 .824 r
.60262 .33498 m .59895 .32794 L .5754 .33539 L p F P
0 g
s
.659 .664 .843 r
.59895 .32794 m .5754 .33539 L .56933 .32571 L p F P
0 g
s
.612 .552 .763 r
.61113 .35401 m .6222 .35178 L .61227 .357 L closepath p F P
0 g
s
.594 .522 .744 r
.63494 .34953 m .6222 .35178 L .61227 .357 L p F P
0 g
s
.594 .522 .744 r
.63927 .3627 m .63494 .34953 L p .61227 .357 L F P
0 g
s
.594 .522 .744 r
.62333 .37115 m .63927 .3627 L p .61227 .357 L F P
0 g
s
.639 .753 .931 r
.30419 .33087 m .32664 .32446 L .33355 .33094 L p F P
0 g
s
.609 .759 .95 r
.32664 .32446 m .30419 .33087 L .29722 .32356 L p F P
0 g
s
.743 .71 .821 r
.23844 .34044 m .24521 .33559 L .23815 .32669 L p F P
0 g
s
.743 .71 .821 r
.23815 .32669 m .22651 .33459 L .23844 .34044 L p F P
0 g
s
.754 .691 .791 r
.2153 .34301 m .22651 .33459 L .23844 .34044 L p F P
0 g
s
.622 .57 .775 r
.6222 .35178 m .61113 .35401 L .60502 .33982 L p F P
0 g
s
.708 .317 .306 r
.31806 .49188 m .33594 .49464 L .32865 .48684 L p F P
0 g
s
.708 .317 .306 r
.32865 .48684 m .32294 .48596 L .31806 .49188 L p F P
0 g
s
.76 .409 .39 r
.28916 .47248 m .29308 .48004 L .28545 .47829 L closepath p F P
0 g
s
.703 .733 .874 r
.26776 .32396 m .24521 .33559 L .23815 .32669 L p F P
0 g
s
.606 .769 .958 r
.33355 .33094 m .35608 .32578 L .36292 .33148 L p F P
0 g
s
.557 .777 .981 r
.35608 .32578 m .33355 .33094 L .32664 .32446 L p F P
0 g
s
.551 .424 .66 r
.64572 .3903 m .64314 .37733 L .6217 .38836 L p F P
0 g
s
.551 .424 .66 r
.62699 .39989 m .64572 .3903 L p .6217 .38836 L F P
0 g
s
.551 .424 .66 r
.6217 .38836 m .62389 .39943 L .62699 .39989 L p F P
0 g
s
.518 .156 .291 r
.5261 .48858 m .52888 .48142 L .50317 .48634 L p F P
0 g
s
.518 .156 .291 r
.51396 .49089 m .5261 .48858 L p .50317 .48634 L F P
0 g
s
.518 .156 .291 r
.50317 .48634 m .50158 .49013 L .51396 .49089 L p F P
0 g
s
.796 .482 .457 r
.24842 .46019 m .25744 .46295 L .25519 .45363 L p F P
0 g
s
.796 .482 .457 r
.25519 .45363 m .25186 .45261 L .24842 .46019 L p F P
0 g
s
.805 .668 .712 r
.19821 .38444 m .19839 .38453 L .20662 .3717 L p F P
0 g
s
.805 .668 .712 r
.19156 .37043 m .19821 .38444 L p .20662 .3717 L F P
0 g
s
.805 .668 .712 r
.20662 .3717 m .19464 .36591 L .19156 .37043 L p F P
0 g
s
.727 .341 .319 r
.31689 .49167 m .31806 .49188 L .32294 .48596 L p F P
0 g
s
.727 .341 .319 r
.32294 .48596 m .31036 .48362 L .31689 .49167 L p F P
0 g
s
.581 .483 .708 r
.62333 .37115 m .63927 .3627 L .64127 .36989 L closepath p F P
0 g
s
.806 .494 .462 r
.24283 .45834 m .24842 .46019 L .25186 .45261 L p F P
0 g
s
.806 .494 .462 r
.25186 .45261 m .24084 .44893 L .24283 .45834 L p F P
0 g
s
.584 .786 .975 r
.36292 .33148 m .38558 .32679 L .39233 .33184 L p F P
0 g
s
.512 .793 .996 r
.38558 .32679 m .36292 .33148 L .35608 .32578 L p F P
0 g
s
.622 .57 .775 r
.63349 .34561 m .6222 .35178 L p .60502 .33982 L F P
0 g
s
.622 .57 .775 r
.60502 .33982 m .62879 .3341 L .63349 .34561 L p F P
0 g
s
.628 .61 .813 r
.60262 .33498 m .60502 .33982 L .62879 .3341 L p F P
0 g
s
.496 .232 .443 r
.6028 .45165 m .60376 .44281 L .58061 .45123 L p F P
0 g
s
.496 .232 .443 r
.58061 .45123 m .57958 .46007 L .6028 .45165 L p F P
0 g
s
.572 .146 .194 r
.43126 .49991 m .41626 .50029 L .41279 .50464 L p F P
0 g
s
.606 .185 .217 r
.41626 .50029 m .41279 .50464 L .40305 .50008 L closepath p F P
0 g
s
.582 .801 .983 r
.41608 .32759 m .42179 .33159 L p .39233 .33184 L F P
0 g
s
.582 .801 .983 r
.39233 .33184 m .41229 .32756 L .41608 .32759 L p F P
0 g
s
.508 .805 .999 r
.41229 .32756 m .39233 .33184 L .38558 .32679 L p F P
0 g
s
.827 .583 .571 r
.20631 .42587 m .21354 .42888 L .21494 .4184 L p F P
0 g
s
.827 .583 .571 r
.21494 .4184 m .20637 .41482 L .20631 .42587 L p F P
0 g
s
.825 .618 .623 r
.20537 .40194 m .20393 .4013 L .20459 .40448 L closepath p F P
0 g
s
.604 .17 .191 r
.41165 .5061 m .41279 .50464 L .40305 .50008 L p F P
0 g
s
.604 .17 .191 r
.39016 .5055 m .41165 .5061 L p .40305 .50008 L F P
0 g
s
.604 .17 .191 r
.38333 .50199 m .39016 .5055 L p .40305 .50008 L F P
0 g
s
.604 .17 .191 r
.40305 .50008 m .38556 .49956 L .38333 .50199 L p F P
0 g
s
.489 .18 .368 r
.57803 .46706 m .57958 .46007 L .55562 .46733 L p F P
0 g
s
.489 .18 .368 r
.55562 .46733 m .55442 .47241 L .57803 .46706 L p F P
0 g
s
.781 .43 .391 r
.26137 .47177 m .27677 .47608 L .27274 .46728 L p F P
0 g
s
.781 .43 .391 r
.27274 .46728 m .25744 .46295 L .26137 .47177 L p F P
0 g
s
.735 .344 .312 r
.29942 .48812 m .31689 .49167 L .31036 .48362 L p F P
0 g
s
.735 .344 .312 r
.31036 .48362 m .29308 .48004 L .29942 .48812 L p F P
0 g
s
.553 .416 .648 r
.62389 .39943 m .62699 .39989 L .62423 .40128 L closepath p F P
0 g
s
.574 .156 .213 r
.44546 .4994 m .44238 .50368 L .43126 .49991 L closepath p F P
0 g
s
.572 .146 .194 r
.44118 .50541 m .44238 .50368 L .43126 .49991 L p F P
0 g
s
.572 .146 .194 r
.4164 .50603 m .44118 .50541 L p .43126 .49991 L F P
0 g
s
.572 .146 .194 r
.41279 .50464 m .4164 .50603 L p .43126 .49991 L F P
0 g
s
.634 .207 .213 r
.38556 .49956 m .38333 .50199 L .37833 .49907 L closepath p F P
0 g
s
.824 .546 .518 r
.21382 .43881 m .22711 .44397 L .2268 .43404 L p F P
0 g
s
.824 .546 .518 r
.2268 .43404 m .21354 .42888 L .21382 .43881 L p F P
0 g
s
.751 .7 .803 r
.22651 .33459 m .2153 .34301 L .20821 .33318 L p F P
0 g
s
.78 .701 .776 r
.20654 .35174 m .2153 .34301 L .20821 .33318 L p F P
0 g
s
.825 .643 .656 r
.19831 .38469 m .19339 .39621 L .20393 .4013 L closepath p F P
0 g
s
.834 .623 .616 r
.20225 .41298 m .20459 .40448 L .20393 .4013 L p F P
0 g
s
.834 .623 .616 r
.19027 .40726 m .20225 .41298 L p .20393 .4013 L F P
0 g
s
.834 .623 .616 r
.20393 .4013 m .19339 .39621 L .19027 .40726 L p F P
0 g
s
.603 .807 .978 r
.44491 .32605 m .45128 .33057 L p .42179 .33159 L F P
0 g
s
.603 .807 .978 r
.42179 .33159 m .44417 .32609 L .44491 .32605 L p F P
0 g
s
.603 .807 .978 r
.42179 .33159 m .44417 .32609 L .41608 .32759 L closepath p F P
0 g
s
.532 .372 .61 r
.63936 .40606 m .6257 .4129 L .62423 .40128 L p F P
0 g
s
.532 .372 .61 r
.62423 .40128 m .62699 .39989 L .63936 .40606 L p F P
0 g
s
.536 .114 .189 r
.46533 .4978 m .44546 .4994 L .44238 .50368 L p F P
0 g
s
.684 .303 .318 r
.35408 .49534 m .35609 .49722 L .35301 .49692 L closepath p F P
0 g
s
.671 .753 .912 r
.51028 .32712 m .53363 .31894 L .53979 .32577 L p F P
0 g
s
.667 .792 .942 r
.53363 .31894 m .51028 .32712 L .50402 .32139 L p F P
0 g
s
.658 .785 .942 r
.48078 .32893 m .50402 .32139 L .51028 .32712 L p F P
0 g
s
.632 .804 .965 r
.45128 .33057 m .4744 .32395 L .48078 .32893 L p F P
0 g
s
.62 .814 .975 r
.4723 .32272 m .4744 .32395 L .45128 .33057 L p F P
0 g
s
.62 .814 .975 r
.45128 .33057 m .44491 .32605 L .4723 .32272 L p F P
0 g
s
.637 .823 .972 r
.50402 .32139 m .48078 .32893 L .4744 .32395 L p F P
0 g
s
.818 .649 .672 r
.19839 .38453 m .19821 .38444 L .19831 .38469 L closepath p F P
0 g
s
.605 .543 .758 r
.6222 .35178 m .63349 .34561 L .63494 .34953 L closepath p F P
0 g
s
.634 .208 .217 r
.36682 .50398 m .35609 .49722 L .37833 .49907 L p F P
0 g
s
.634 .208 .217 r
.38053 .50509 m .36682 .50398 L p .37833 .49907 L F P
0 g
s
.634 .208 .217 r
.37833 .49907 m .38333 .50199 L .38053 .50509 L p F P
0 g
s
.78 .701 .776 r
.20821 .33318 m .1952 .34564 L .20654 .35174 L p F P
0 g
s
.795 .691 .75 r
.18713 .36207 m .19464 .36591 L .20654 .35174 L p F P
0 g
s
.795 .691 .75 r
.18465 .35784 m .18713 .36207 L p .20654 .35174 L F P
0 g
s
.795 .691 .75 r
.20654 .35174 m .1952 .34564 L .18465 .35784 L p F P
0 g
s
.671 .711 .878 r
.53979 .32577 m .56325 .31742 L .56933 .32571 L p F P
0 g
s
.676 .75 .907 r
.56325 .31742 m .53979 .32577 L .53363 .31894 L p F P
0 g
s
.831 .651 .659 r
.19339 .39621 m .19831 .38469 L .19821 .38444 L p F P
0 g
s
.82 .666 .692 r
.19156 .37043 m .18693 .37856 L .19821 .38444 L closepath p F P
0 g
s
.831 .651 .659 r
.18186 .39027 m .19339 .39621 L p .19821 .38444 L F P
0 g
s
.831 .651 .659 r
.19821 .38444 m .18693 .37856 L .18186 .39027 L p F P
0 g
s
.828 .614 .614 r
.20459 .40448 m .20225 .41298 L .20637 .41482 L closepath p F P
0 g
s
.639 .626 .821 r
.59895 .32794 m .60262 .33498 L .62377 .32335 L p F P
0 g
s
.628 .61 .813 r
.62879 .3341 m .62377 .32335 L .60262 .33498 L p F P
0 g
s
.5 .275 .505 r
.62619 .43321 m .62634 .42352 L .60397 .43312 L p F P
0 g
s
.5 .275 .505 r
.60397 .43312 m .60376 .44281 L .62619 .43321 L p F P
0 g
s
.737 .713 .828 r
.22651 .33459 m .23815 .32669 L .23102 .3181 L p F P
0 g
s
.737 .713 .828 r
.23102 .3181 m .21461 .32867 L .22651 .33459 L p F P
0 g
s
.751 .7 .803 r
.20821 .33318 m .21461 .32867 L .22651 .33459 L p F P
0 g
s
.53 .374 .613 r
.6473 .40202 m .63936 .40606 L .62699 .39989 L p F P
0 g
s
.53 .374 .613 r
.62699 .39989 m .64572 .3903 L .6473 .40202 L p F P
0 g
s
.659 .664 .843 r
.56933 .32571 m .59291 .3178 L .59895 .32794 L p F P
0 g
s
.669 .701 .87 r
.59291 .3178 m .56933 .32571 L .56325 .31742 L p F P
0 g
s
.815 .501 .459 r
.22902 .4534 m .24283 .45834 L .24084 .44893 L p F P
0 g
s
.815 .501 .459 r
.24084 .44893 m .22711 .44397 L .22902 .4534 L p F P
0 g
s
.535 .119 .198 r
.4734 .49709 m .47201 .49916 L .46533 .4978 L closepath p F P
0 g
s
.536 .114 .189 r
.46938 .50322 m .47201 .49916 L .46533 .4978 L p F P
0 g
s
.536 .114 .189 r
.4475 .50495 m .46938 .50322 L p .46533 .4978 L F P
0 g
s
.536 .114 .189 r
.44238 .50368 m .4475 .50495 L p .46533 .4978 L F P
0 g
s
.479 .123 .283 r
.55109 .48251 m .55375 .47533 L .52888 .48142 L p F P
0 g
s
.479 .123 .283 r
.52888 .48142 m .5261 .48858 L .55109 .48251 L p F P
0 g
s
.52 .161 .298 r
.50158 .49013 m .51396 .49089 L .50023 .49345 L closepath p F P
0 g
s
.645 .207 .195 r
.34745 .50206 m .36682 .50398 L .35609 .49722 L p F P
0 g
s
.645 .207 .195 r
.35609 .49722 m .35301 .49692 L .34745 .50206 L p F P
0 g
s
.658 .744 .914 r
.26776 .32396 m .29018 .31657 L .29722 .32356 L p F P
0 g
s
.636 .747 .928 r
.29018 .31657 m .26776 .32396 L .26067 .31613 L p F P
0 g
s
.703 .733 .874 r
.23815 .32669 m .26067 .31613 L .26776 .32396 L p F P
0 g
s
.502 .084 .179 r
.49644 .49969 m .50023 .49345 L .4734 .49709 L p F P
0 g
s
.502 .084 .179 r
.4878 .50084 m .49644 .49969 L p .4734 .49709 L F P
0 g
s
.502 .084 .179 r
.4734 .49709 m .47201 .49916 L .4878 .50084 L p F P
0 g
s
.809 .673 .714 r
.19464 .36591 m .18713 .36207 L .19156 .37043 L closepath p F P
0 g
s
.672 .241 .217 r
.34542 .50179 m .34745 .50206 L .35301 .49692 L p F P
0 g
s
.672 .241 .217 r
.35301 .49692 m .33594 .49464 L .34542 .50179 L p F P
0 g
s
.834 .59 .57 r
.20086 .42346 m .20631 .42587 L .20637 .41482 L p F P
0 g
s
.834 .59 .57 r
.20637 .41482 m .20225 .41298 L .20086 .42346 L p F P
0 g
s
.69 .736 .886 r
.26067 .31613 m .23815 .32669 L .23102 .3181 L p F P
0 g
s
.609 .759 .95 r
.29722 .32356 m .31965 .31838 L .32664 .32446 L p F P
0 g
s
.572 .759 .966 r
.31965 .31838 m .29722 .32356 L .29018 .31657 L p F P
0 g
s
.74 .339 .292 r
.28266 .4843 m .29942 .48812 L .29308 .48004 L p F P
0 g
s
.74 .339 .292 r
.28117 .48226 m .28266 .4843 L p .29308 .48004 L F P
0 g
s
.74 .339 .292 r
.29308 .48004 m .28545 .47829 L .28117 .48226 L p F P
0 g
s
.824 .675 .699 r
.18693 .37856 m .19156 .37043 L .18713 .36207 L p F P
0 g
s
.639 .626 .821 r
.62377 .32335 m .62272 .32124 L .59895 .32794 L p F P
0 g
s
.65 .647 .833 r
.62272 .32124 m .59895 .32794 L .59291 .3178 L p F P
0 g
s
.788 .429 .377 r
.24652 .46722 m .26137 .47177 L .25744 .46295 L p F P
0 g
s
.788 .429 .377 r
.24517 .464 m .24652 .46722 L p .25744 .46295 L F P
0 g
s
.788 .429 .377 r
.25744 .46295 m .24842 .46019 L .24517 .464 L p F P
0 g
s
.842 .598 .57 r
.18883 .41775 m .20086 .42346 L .20225 .41298 L p F P
0 g
s
.842 .598 .57 r
.20225 .41298 m .19027 .40726 L .18883 .41775 L p F P
0 g
s
.557 .777 .981 r
.35063 .32172 m .35608 .32578 L p .32664 .32446 L F P
0 g
s
.557 .777 .981 r
.32664 .32446 m .34639 .32112 L .35063 .32172 L p F P
0 g
s
.493 .767 .992 r
.34639 .32112 m .32664 .32446 L .31965 .31838 L p F P
0 g
s
.503 .316 .56 r
.64264 .41538 m .62634 .42352 L .6257 .4129 L p F P
0 g
s
.503 .316 .56 r
.6257 .4129 m .63936 .40606 L .64264 .41538 L p F P
0 g
s
.492 .185 .374 r
.57781 .46809 m .57803 .46706 L .55442 .47241 L p F P
0 g
s
.492 .185 .374 r
.55442 .47241 m .55375 .47533 L .57781 .46809 L p F P
0 g
s
.617 .187 .204 r
.38333 .50199 m .39016 .5055 L .38053 .50509 L closepath p F P
0 g
s
.755 .361 .306 r
.28545 .47829 m .28117 .48226 L .27677 .47608 L closepath p F P
0 g
s
.668 .217 .173 r
.32605 .4989 m .34542 .50179 L .33594 .49464 L p F P
0 g
s
.668 .217 .173 r
.31757 .49223 m .32605 .4989 L p .33594 .49464 L F P
0 g
s
.668 .217 .173 r
.33594 .49464 m .31806 .49188 L .31757 .49223 L p F P
0 g
s
.841 .631 .618 r
.17867 .40135 m .19027 .40726 L .19339 .39621 L p F P
0 g
s
.841 .631 .618 r
.19339 .39621 m .18186 .39027 L .17867 .40135 L p F P
0 g
s
.831 .552 .515 r
.20402 .43473 m .21382 .43881 L .21354 .42888 L p F P
0 g
s
.831 .552 .515 r
.21354 .42888 m .20631 .42587 L .20402 .43473 L p F P
0 g
s
.554 .467 .71 r
.66383 .36491 m .65987 .35015 L .63927 .3627 L p F P
0 g
s
.554 .467 .71 r
.65399 .3709 m .66383 .36491 L p .63927 .3627 L F P
0 g
s
.554 .467 .71 r
.63927 .3627 m .64127 .36989 L .65399 .3709 L p F P
0 g
s
.581 .509 .739 r
.63494 .34953 m .63927 .3627 L .65987 .35015 L p F P
0 g
s
.583 .531 .762 r
.63349 .34561 m .63494 .34953 L .6591 .34768 L p F P
0 g
s
.581 .509 .739 r
.65987 .35015 m .6591 .34768 L .63494 .34953 L p F P
0 g
s
.747 .708 .815 r
.21461 .32867 m .20821 .33318 L .20105 .32379 L p F P
0 g
s
.778 .706 .784 r
.1952 .34564 m .20821 .33318 L .20105 .32379 L p F P
0 g
s
.505 .09 .188 r
.47201 .49916 m .4878 .50084 L .46938 .50322 L closepath p F P
0 g
s
.46 .048 .172 r
.51396 .49089 m .50023 .49345 L .49644 .49969 L p F P
0 g
s
.824 .675 .699 r
.17584 .37239 m .18693 .37856 L p .18713 .36207 L F P
0 g
s
.836 .659 .662 r
.17068 .38415 m .18186 .39027 L .18693 .37856 L p F P
0 g
s
.836 .659 .662 r
.18693 .37856 m .17584 .37239 L .17068 .38415 L p F P
0 g
s
.824 .675 .699 r
.18713 .36207 m .18322 .35986 L .17584 .37239 L p F P
0 g
s
.813 .685 .723 r
.18465 .35784 m .18322 .35986 L .18713 .36207 L closepath p F P
0 g
s
.778 .706 .784 r
.20105 .32379 m .18416 .33938 L .1952 .34564 L p F P
0 g
s
.795 .69 .749 r
.17757 .34665 m .18416 .33938 L .1952 .34564 L p F P
0 g
s
.795 .69 .749 r
.1952 .34564 m .18465 .35784 L .17757 .34665 L p F P
0 g
s
.556 .454 .693 r
.64127 .36989 m .65399 .3709 L .64314 .37733 L closepath p F P
0 g
s
.604 .561 .779 r
.62879 .3341 m .63349 .34561 L .65392 .33277 L p F P
0 g
s
.583 .531 .762 r
.6591 .34768 m .65392 .33277 L .63349 .34561 L p F P
0 g
s
.823 .507 .454 r
.21569 .44825 m .22902 .4534 L .22711 .44397 L p F P
0 g
s
.823 .507 .454 r
.22711 .44397 m .21382 .43881 L .21569 .44825 L p F P
0 g
s
.512 .793 .996 r
.38485 .32633 m .38558 .32679 L p .35608 .32578 L F P
0 g
s
.512 .793 .996 r
.35608 .32578 m .36494 .32453 L .38485 .32633 L p F P
0 g
s
.54 .768 .982 r
.35608 .32578 m .36494 .32453 L .35063 .32172 L closepath p F P
0 g
s
.798 .443 .385 r
.24842 .46019 m .24517 .464 L .24283 .45834 L closepath p F P
0 g
s
.451 .148 .359 r
.60171 .45673 m .6028 .45165 L .57958 .46007 L p F P
0 g
s
.451 .148 .359 r
.57958 .46007 m .57803 .46706 L .60171 .45673 L p F P
0 g
s
.732 .715 .835 r
.21461 .32867 m .23102 .3181 L .22382 .30975 L p F P
0 g
s
.732 .715 .835 r
.22382 .30975 m .20265 .32272 L .21461 .32867 L p F P
0 g
s
.747 .708 .815 r
.20105 .32379 m .20265 .32272 L .21461 .32867 L p F P
0 g
s
.756 .36 .304 r
.26699 .48006 m .26137 .47177 L .27677 .47608 L p F P
0 g
s
.756 .36 .304 r
.27974 .48357 m .26699 .48006 L p .27677 .47608 L F P
0 g
s
.756 .36 .304 r
.27677 .47608 m .28117 .48226 L .27974 .48357 L p F P
0 g
s
.585 .163 .208 r
.41279 .50464 m .4164 .50603 L .41165 .5061 L closepath p F P
0 g
s
.535 .413 .66 r
.66652 .37802 m .64572 .3903 L .64314 .37733 L p F P
0 g
s
.535 .413 .66 r
.66574 .374 m .66652 .37802 L p .64314 .37733 L F P
0 g
s
.535 .413 .66 r
.64314 .37733 m .65399 .3709 L .66574 .374 L p F P
0 g
s
.461 .202 .435 r
.62536 .44146 m .62619 .43321 L .60376 .44281 L p F P
0 g
s
.461 .202 .435 r
.62399 .44262 m .62536 .44146 L p .60376 .44281 L F P
0 g
s
.461 .202 .435 r
.60376 .44281 m .6028 .45165 L .62399 .44262 L p F P
0 g
s
.547 .131 .203 r
.44238 .50368 m .4475 .50495 L .44118 .50541 L closepath p F P
0 g
s
.691 .248 .195 r
.31806 .49188 m .31757 .49223 L .31689 .49167 L closepath p F P
0 g
s
.605 .806 .977 r
.44417 .32609 m .41608 .32759 L .41515 .32693 L p F P
0 g
s
.586 .799 .981 r
.41608 .32759 m .41515 .32693 L .41229 .32756 L closepath p F P
0 g
s
.508 .805 .999 r
.38558 .32679 m .38732 .32652 L .41229 .32756 L p F P
0 g
s
.56 .828 .996 r
.40844 .32318 m .38732 .32652 L .41229 .32756 L p F P
0 g
s
.56 .828 .996 r
.41229 .32756 m .41515 .32693 L .40844 .32318 L p F P
0 g
s
.437 .084 .267 r
.57525 .47526 m .57781 .46809 L .55375 .47533 L p F P
0 g
s
.437 .084 .267 r
.55375 .47533 m .55109 .48251 L .57525 .47526 L p F P
0 g
s
.815 .693 .731 r
.18322 .35986 m .18465 .35784 L .17757 .34665 L p F P
0 g
s
.691 .248 .194 r
.30771 .49562 m .29942 .48812 L .31689 .49167 L p F P
0 g
s
.691 .248 .194 r
.31172 .49643 m .30771 .49562 L p .31689 .49167 L F P
0 g
s
.691 .248 .194 r
.31689 .49167 m .31757 .49223 L .31172 .49643 L p F P
0 g
s
.525 .795 .995 r
.38558 .32679 m .38732 .32652 L .38485 .32633 L closepath p F P
0 g
s
.838 .56 .516 r
.20104 .43342 m .20402 .43473 L .20631 .42587 L p F P
0 g
s
.838 .56 .516 r
.20631 .42587 m .20086 .42346 L .20104 .43342 L p F P
0 g
s
.676 .75 .907 r
.53363 .31894 m .55715 .3104 L .56325 .31742 L p F P
0 g
s
.678 .791 .934 r
.55715 .3104 m .53363 .31894 L .52744 .3133 L p F P
0 g
s
.667 .792 .942 r
.50402 .32139 m .52744 .3133 L .53363 .31894 L p F P
0 g
s
.669 .701 .87 r
.56325 .31742 m .58688 .30906 L .59291 .3178 L p F P
0 g
s
.678 .739 .897 r
.58688 .30906 m .56325 .31742 L .55715 .3104 L p F P
0 g
s
.828 .683 .703 r
.1651 .36604 m .17584 .37239 L .18322 .35986 L p F P
0 g
s
.828 .683 .703 r
.18322 .35986 m .1726 .35345 L .1651 .36604 L p F P
0 g
s
.815 .693 .731 r
.17757 .34665 m .1726 .35345 L .18322 .35986 L p F P
0 g
s
.604 .561 .779 r
.65392 .33277 m .65285 .33 L .62879 .3341 L p F P
0 g
s
.608 .59 .807 r
.62377 .32335 m .62879 .3341 L .65285 .33 L p F P
0 g
s
.8 .444 .383 r
.23251 .46234 m .22902 .4534 L .24283 .45834 L p F P
0 g
s
.8 .444 .383 r
.24328 .46615 m .23251 .46234 L p .24283 .45834 L F P
0 g
s
.8 .444 .383 r
.24283 .45834 m .24517 .464 L .24328 .46615 L p F P
0 g
s
.682 .235 .185 r
.31757 .49223 m .32605 .4989 L .31172 .49643 L closepath p F P
0 g
s
.655 .83 .967 r
.52744 .3133 m .50402 .32139 L .49771 .31682 L p F P
0 g
s
.637 .823 .972 r
.4744 .32395 m .49771 .31682 L .50402 .32139 L p F P
0 g
s
.457 .046 .17 r
.5261 .48858 m .52497 .4905 L .51396 .49089 L closepath p F P
0 g
s
.46 .048 .172 r
.52248 .49487 m .52497 .4905 L .51396 .49089 L p F P
0 g
s
.46 .048 .172 r
.49644 .49969 m .52248 .49487 L p .51396 .49089 L F P
0 g
s
.529 .795 .994 r
.40163 .32024 m .40844 .32318 L .38732 .32652 L p F P
0 g
s
.529 .795 .994 r
.37876 .32247 m .40163 .32024 L p .38732 .32652 L F P
0 g
s
.529 .795 .994 r
.38732 .32652 m .38485 .32633 L .37876 .32247 L p F P
0 g
s
.523 .792 .994 r
.38485 .32633 m .37876 .32247 L .36494 .32453 L closepath p F P
0 g
s
.605 .806 .977 r
.41515 .32693 m .43818 .32238 L p .44417 .32609 L F P
0 g
s
.436 .818 .99 r
.43818 .32238 m .41515 .32693 L .40844 .32318 L p F P
0 g
s
.605 .806 .977 r
.44491 .32605 m .44477 .32594 L .44417 .32609 L closepath p F P
0 g
s
.605 .806 .977 r
.43818 .32238 m .44477 .32594 L .44417 .32609 L p F P
0 g
s
.624 .848 .985 r
.49765 .31678 m .49771 .31682 L .4744 .32395 L p F P
0 g
s
.624 .848 .985 r
.4744 .32395 m .4723 .32272 L .49765 .31678 L p F P
0 g
s
.607 .807 .977 r
.46795 .32011 m .4723 .32272 L .44491 .32605 L p F P
0 g
s
.607 .807 .977 r
.44491 .32605 m .44477 .32594 L .46795 .32011 L p F P
0 g
s
.513 .848 .997 r
.46795 .32011 m .44477 .32594 L .43818 .32238 L p F P
0 g
s
.636 .747 .928 r
.26067 .31613 m .28307 .30982 L .29018 .31657 L p F P
0 g
s
.613 .746 .94 r
.28307 .30982 m .26067 .31613 L .25352 .30852 L p F P
0 g
s
.69 .736 .886 r
.23102 .3181 m .25352 .30852 L .26067 .31613 L p F P
0 g
s
.65 .647 .833 r
.59291 .3178 m .6167 .31036 L .62272 .32124 L p F P
0 g
s
.663 .683 .859 r
.6167 .31036 m .59291 .3178 L .58688 .30906 L p F P
0 g
s
.677 .738 .897 r
.25352 .30852 m .23102 .3181 L .22382 .30975 L p F P
0 g
s
.514 .031 .048 r
.4164 .50603 m .41165 .5061 L .40594 .51083 L p F P
0 g
s
.558 .083 .083 r
.40559 .51082 m .40594 .51083 L .41165 .5061 L p F P
0 g
s
.558 .083 .083 r
.41165 .5061 m .39016 .5055 L .40559 .51082 L p F P
0 g
s
.521 .05 .078 r
.44118 .50541 m .4164 .50603 L .43479 .51042 L p F P
0 g
s
.514 .031 .048 r
.40594 .51083 m .43479 .51042 L .4164 .50603 L p F P
0 g
s
.85 .606 .57 r
.17719 .41185 m .18883 .41775 L .19027 .40726 L p F P
0 g
s
.85 .606 .57 r
.19027 .40726 m .17867 .40135 L .17719 .41185 L p F P
0 g
s
.467 .25 .499 r
.63754 .42757 m .62619 .43321 L .62634 .42352 L p F P
0 g
s
.467 .25 .499 r
.62634 .42352 m .64264 .41538 L .63754 .42757 L p F P
0 g
s
.847 .567 .515 r
.18894 .42774 m .20104 .43342 L .20086 .42346 L p F P
0 g
s
.847 .567 .515 r
.20086 .42346 m .18883 .41775 L .18894 .42774 L p F P
0 g
s
.548 .057 .042 r
.38063 .5098 m .40559 .51082 L .39016 .5055 L p F P
0 g
s
.548 .057 .042 r
.37618 .50811 m .38063 .5098 L p .39016 .5055 L F P
0 g
s
.548 .057 .042 r
.39016 .5055 m .38053 .50509 L .37618 .50811 L p F P
0 g
s
.543 .768 .981 r
.37184 .31878 m .37876 .32247 L .36494 .32453 L p F P
0 g
s
.543 .768 .981 r
.34916 .32062 m .37184 .31878 L p .36494 .32453 L F P
0 g
s
.543 .768 .981 r
.36494 .32453 m .35063 .32172 L .34916 .32062 L p F P
0 g
s
.505 .356 .612 r
.66815 .38978 m .66652 .37802 L .64572 .3903 L p F P
0 g
s
.505 .356 .612 r
.64572 .3903 m .6473 .40202 L .66815 .38978 L p F P
0 g
s
.472 0 .042 r
.4475 .50495 m .44118 .50541 L .43587 .5104 L p F P
0 g
s
.521 .05 .078 r
.43479 .51042 m .43587 .5104 L .44118 .50541 L p F P
0 g
s
.848 .638 .619 r
.16746 .39524 m .17867 .40135 L .18186 .39027 L p F P
0 g
s
.848 .638 .619 r
.18186 .39027 m .17068 .38415 L .16746 .39524 L p F P
0 g
s
.572 .759 .966 r
.29018 .31657 m .31259 .3126 L .31965 .31838 L p F P
0 g
s
.522 .756 .981 r
.31259 .3126 m .29018 .31657 L .28307 .30982 L p F P
0 g
s
.588 .105 .077 r
.38053 .50509 m .37618 .50811 L .36682 .50398 L closepath p F P
0 g
s
.411 0 .146 r
.54859 .48702 m .55109 .48251 L .5261 .48858 L p F P
0 g
s
.411 0 .146 r
.5261 .48858 m .52497 .4905 L .54859 .48702 L p F P
0 g
s
.477 .009 .062 r
.46938 .50322 m .46546 .50725 L .4475 .50495 L closepath p F P
0 g
s
.472 0 .042 r
.46439 .50839 m .46546 .50725 L .4475 .50495 L p F P
0 g
s
.472 0 .042 r
.43587 .5104 m .46439 .50839 L p .4475 .50495 L F P
0 g
s
.5 .315 .56 r
.648 .41267 m .64264 .41538 L .63936 .40606 L p F P
0 g
s
.5 .315 .56 r
.63936 .40606 m .6473 .40202 L .648 .41267 L p F P
0 g
s
.773 .37 .291 r
.25203 .47554 m .26699 .48006 L .26137 .47177 L p F P
0 g
s
.773 .37 .291 r
.26137 .47177 m .24652 .46722 L .25203 .47554 L p F P
0 g
s
.832 .51 .444 r
.20281 .44289 m .21569 .44825 L .21382 .43881 L p F P
0 g
s
.832 .51 .444 r
.20188 .43792 m .20281 .44289 L p .21382 .43881 L F P
0 g
s
.832 .51 .444 r
.21382 .43881 m .20402 .43473 L .20188 .43792 L p F P
0 g
s
.711 .265 .19 r
.29074 .49185 m .30771 .49562 L .29942 .48812 L p F P
0 g
s
.711 .265 .19 r
.29942 .48812 m .28266 .4843 L .29074 .49185 L p F P
0 g
s
.626 .611 .815 r
.62272 .32124 m .62961 .31961 L .62377 .32335 L closepath p F P
0 g
s
.608 .59 .807 r
.64675 .31582 m .62961 .31961 L .62377 .32335 L p F P
0 g
s
.608 .59 .807 r
.65285 .33 m .64675 .31582 L p .62377 .32335 L F P
0 g
s
.842 .666 .664 r
.15987 .37783 m .17068 .38415 L .17584 .37239 L p F P
0 g
s
.842 .666 .664 r
.17584 .37239 m .1651 .36604 L .15987 .37783 L p F P
0 g
s
.742 .714 .826 r
.20265 .32272 m .19846 .32055 L .20105 .32379 L closepath p F P
0 g
s
.781 .718 .794 r
.18416 .33938 m .20105 .32379 L .19846 .32055 L p F P
0 g
s
.576 .074 .025 r
.37428 .50944 m .37618 .50811 L .36682 .50398 L p F P
0 g
s
.576 .074 .025 r
.35821 .50792 m .37428 .50944 L p .36682 .50398 L F P
0 g
s
.576 .074 .025 r
.34671 .50247 m .35821 .50792 L p .36682 .50398 L F P
0 g
s
.576 .074 .025 r
.36682 .50398 m .34745 .50206 L .34671 .50247 L p F P
0 g
s
.781 .718 .794 r
.17341 .33294 m .18416 .33938 L p .19846 .32055 L F P
0 g
s
.796 .7 .759 r
.17039 .33614 m .17341 .33294 L .18416 .33938 L p F P
0 g
s
.796 .7 .759 r
.18416 .33938 m .17757 .34665 L .17039 .33614 L p F P
0 g
s
.611 .841 .987 r
.49134 .31346 m .49765 .31678 L .4723 .32272 L p F P
0 g
s
.611 .841 .987 r
.4723 .32272 m .46795 .32011 L .49134 .31346 L p F P
0 g
s
.737 .715 .831 r
.20265 .32272 m .22382 .30975 L p .1938 .31478 L F P
0 g
s
.737 .715 .831 r
.1938 .31478 m .19846 .32055 L .20265 .32272 L p F P
0 g
s
.637 .626 .823 r
.62961 .31961 m .62272 .32124 L .6167 .31036 L p F P
0 g
s
.493 .767 .992 r
.31965 .31838 m .32828 .31751 L .34639 .32112 L p F P
0 g
s
.445 .731 .988 r
.32828 .31751 m .31965 .31838 L .31259 .3126 L p F P
0 g
s
.423 0 .025 r
.4878 .50084 m .46938 .50322 L .46546 .50725 L p F P
0 g
s
.817 .701 .737 r
.1726 .35345 m .17757 .34665 L .17039 .33614 L p F P
0 g
s
.798 .441 .381 r
.24517 .464 m .24652 .46722 L .24328 .46615 L closepath p F P
0 g
s
.565 .776 .977 r
.35063 .32172 m .34916 .32062 L .34639 .32112 L closepath p F P
0 g
s
.751 .354 .3 r
.28117 .48226 m .28266 .4843 L .27974 .48357 L closepath p F P
0 g
s
.817 .458 .376 r
.21909 .45721 m .23251 .46234 L .22902 .4534 L p F P
0 g
s
.817 .458 .376 r
.22902 .4534 m .21569 .44825 L .21909 .45721 L p F P
0 g
s
.534 .416 .664 r
.65399 .3709 m .66383 .36491 L .66574 .374 L closepath p F P
0 g
s
.553 .792 .988 r
.34217 .31594 m .32828 .31751 L .34639 .32112 L p F P
0 g
s
.553 .792 .988 r
.34639 .32112 m .34916 .32062 L .34217 .31594 L p F P
0 g
s
.455 .154 .365 r
.6011 .45966 m .60171 .45673 L .57803 .46706 L p F P
0 g
s
.455 .154 .365 r
.57803 .46706 m .57781 .46809 L .6011 .45966 L p F P
0 g
s
.611 .119 .059 r
.34745 .50206 m .34671 .50247 L .34542 .50179 L closepath p F P
0 g
s
.418 .012 .159 r
.54762 .48884 m .54859 .48702 L .52497 .4905 L p F P
0 g
s
.418 .012 .159 r
.52497 .4905 m .52248 .49487 L .54762 .48884 L p F P
0 g
s
.611 .119 .059 r
.33751 .50544 m .32605 .4989 L .34542 .50179 L p F P
0 g
s
.611 .119 .059 r
.34049 .50588 m .33751 .50544 L p .34542 .50179 L F P
0 g
s
.611 .119 .059 r
.34542 .50179 m .34671 .50247 L .34049 .50588 L p F P
0 g
s
.768 .722 .81 r
.1938 .31478 m .192 .31622 L .19846 .32055 L closepath p F P
0 g
s
.781 .718 .794 r
.19846 .32055 m .192 .31622 L .17341 .33294 L p F P
0 g
s
.833 .69 .706 r
.15471 .3595 m .1651 .36604 L .1726 .35345 L p F P
0 g
s
.833 .69 .706 r
.1726 .35345 m .16233 .34685 L .15471 .3595 L p F P
0 g
s
.817 .701 .737 r
.17039 .33614 m .16233 .34685 L .1726 .35345 L p F P
0 g
s
.409 .109 .342 r
.6028 .45165 m .60171 .45673 L .62399 .44262 L closepath p F P
0 g
s
.39 .041 .248 r
.59863 .46682 m .6011 .45966 L .57781 .46809 L p F P
0 g
s
.39 .041 .248 r
.57781 .46809 m .57525 .47526 L .59863 .46682 L p F P
0 g
s
.297 .734 .967 r
.37184 .31878 m .34916 .32062 L .34217 .31594 L p F P
0 g
s
.47 .292 .557 r
.66892 .40046 m .66815 .38978 L .6473 .40202 L p F P
0 g
s
.47 .292 .557 r
.6473 .40202 m .648 .41267 L .66892 .40046 L p F P
0 g
s
.637 .626 .823 r
.64384 .30987 m .62961 .31961 L p .6167 .31036 L F P
0 g
s
.622 .609 .816 r
.62961 .31961 m .64384 .30987 L .64675 .31582 L closepath p F P
0 g
s
.424 0 .034 r
.49644 .49969 m .49527 .50096 L .4878 .50084 L closepath p F P
0 g
s
.423 0 .025 r
.4917 .50497 m .49527 .50096 L .4878 .50084 L p F P
0 g
s
.423 0 .025 r
.4716 .50752 m .4917 .50497 L p .4878 .50084 L F P
0 g
s
.423 0 .025 r
.46546 .50725 m .4716 .50752 L p .4878 .50084 L F P
0 g
s
.713 .255 .163 r
.27448 .4878 m .29074 .49185 L .28266 .4843 L p F P
0 g
s
.713 .255 .163 r
.27337 .48669 m .27448 .4878 L p .28266 .4843 L F P
0 g
s
.713 .255 .163 r
.28266 .4843 m .27974 .48357 L .27337 .48669 L p F P
0 g
s
.593 .096 .042 r
.34671 .50247 m .35821 .50792 L .34049 .50588 L closepath p F P
0 g
s
.838 .519 .449 r
.20402 .43473 m .20188 .43792 L .20104 .43342 L closepath p F P
0 g
s
.857 .614 .569 r
.16594 .40575 m .17719 .41185 L .17867 .40135 L p F P
0 g
s
.857 .614 .569 r
.17867 .40135 m .16746 .39524 L .16594 .40575 L p F P
0 g
s
.678 .739 .897 r
.55715 .3104 m .58084 .30159 L .58688 .30906 L p F P
0 g
s
.687 .779 .921 r
.58084 .30159 m .55715 .3104 L .55103 .30456 L p F P
0 g
s
.678 .791 .934 r
.52744 .3133 m .55103 .30456 L .55715 .3104 L p F P
0 g
s
.778 .367 .272 r
.23764 .47078 m .25203 .47554 L .24652 .46722 L p F P
0 g
s
.778 .367 .272 r
.23703 .4698 m .23764 .47078 L p .24652 .46722 L F P
0 g
s
.778 .367 .272 r
.24652 .46722 m .24328 .46615 L .23703 .4698 L p F P
0 g
s
.855 .575 .513 r
.17726 .42185 m .18894 .42774 L .18883 .41775 L p F P
0 g
s
.855 .575 .513 r
.18883 .41775 m .17719 .41185 L .17726 .42185 L p F P
0 g
s
.663 .683 .859 r
.58688 .30906 m .61069 .30092 L .6167 .31036 L p F P
0 g
s
.676 .721 .883 r
.61069 .30092 m .58688 .30906 L .58084 .30159 L p F P
0 g
s
.732 .283 .186 r
.27974 .48357 m .27337 .48669 L .26699 .48006 L closepath p F P
0 g
s
.374 0 .001 r
.51881 .49921 m .52248 .49487 L .49644 .49969 L p F P
0 g
s
.374 0 .001 r
.49644 .49969 m .49527 .50096 L .51881 .49921 L p F P
0 g
s
.677 .738 .897 r
.22382 .30975 m .2463 .30104 L .25352 .30852 L p F P
0 g
s
.664 .738 .905 r
.2463 .30104 m .22382 .30975 L .21655 .30157 L p F P
0 g
s
.737 .715 .831 r
.22382 .30975 m .21655 .30157 L .1938 .31478 L p F P
0 g
s
.855 .646 .62 r
.15661 .38893 m .16746 .39524 L .17068 .38415 L p F P
0 g
s
.855 .646 .62 r
.17068 .38415 m .15987 .37783 L .15661 .38893 L p F P
0 g
s
.674 .839 .963 r
.54487 .29988 m .55103 .30456 L .52744 .3133 L p F P
0 g
s
.674 .839 .963 r
.54257 .30075 m .54487 .29988 L p .52744 .3133 L F P
0 g
s
.674 .839 .963 r
.52744 .3133 m .522 .30942 L .54257 .30075 L p F P
0 g
s
.655 .83 .967 r
.522 .30942 m .52744 .3133 L p .49771 .31682 L F P
0 g
s
.613 .746 .94 r
.25352 .30852 m .27589 .30321 L .28307 .30982 L p F P
0 g
s
.589 .742 .949 r
.27589 .30321 m .25352 .30852 L .2463 .30104 L p F P
0 g
s
.842 .522 .447 r
.19056 .43725 m .18894 .42774 L .20104 .43342 L p F P
0 g
s
.842 .522 .447 r
.19944 .44138 m .19056 .43725 L p .20104 .43342 L F P
0 g
s
.842 .522 .447 r
.20104 .43342 m .20188 .43792 L .19944 .44138 L p F P
0 g
s
.423 .17 .424 r
.62619 .43321 m .62536 .44146 L .63754 .42757 L closepath p F P
0 g
s
.79 .386 .287 r
.24328 .46615 m .23703 .4698 L .23251 .46234 L closepath p F P
0 g
s
.364 0 .131 r
.57238 .48066 m .57525 .47526 L .55109 .48251 L p F P
0 g
s
.364 0 .131 r
.55109 .48251 m .54859 .48702 L .57238 .48066 L p F P
0 g
s
.445 .731 .988 r
.31259 .3126 m .31366 .31257 L .32828 .31751 L p F P
0 g
s
.487 .781 .997 r
.33509 .31162 m .31366 .31257 L .32828 .31751 L p F P
0 g
s
.487 .781 .997 r
.32828 .31751 m .34217 .31594 L .33509 .31162 L p F P
0 g
s
.225 .719 .918 r
.40163 .32024 m .37876 .32247 L .37184 .31878 L p F P
0 g
s
.613 .102 .011 r
.31869 .5023 m .33751 .50544 L .32605 .4989 L p F P
0 g
s
.613 .102 .011 r
.31002 .49709 m .31869 .5023 L p .32605 .4989 L F P
0 g
s
.613 .102 .011 r
.32605 .4989 m .31172 .49643 L .31002 .49709 L p F P
0 g
s
.558 .487 .731 r
.6591 .34768 m .66316 .34785 L .65987 .35015 L closepath p F P
0 g
s
.556 .504 .753 r
.65392 .33277 m .6591 .34768 L .66316 .34785 L p F P
0 g
s
.539 .451 .704 r
.68361 .35115 m .66383 .36491 L .65987 .35015 L p F P
0 g
s
.539 .451 .704 r
.65987 .35015 m .66316 .34785 L .68361 .35115 L p F P
0 g
s
.655 .83 .967 r
.49771 .31682 m .49998 .31604 L .522 .30942 L p F P
0 g
s
.632 .872 .987 r
.49771 .31682 m .49998 .31604 L .49765 .31678 L closepath p F P
0 g
s
.637 .626 .823 r
.6167 .31036 m .64071 .30377 L .64384 .30987 L p F P
0 g
s
.652 .659 .844 r
.64071 .30377 m .6167 .31036 L .61069 .30092 L p F P
0 g
s
.635 .869 .986 r
.49998 .31604 m .49765 .31678 L .49134 .31346 L p F P
0 g
s
.848 .674 .667 r
.14943 .37131 m .15987 .37783 L .1651 .36604 L p F P
0 g
s
.848 .674 .667 r
.1651 .36604 m .15471 .3595 L .14943 .37131 L p F P
0 g
s
.781 .723 .799 r
.1634 .32658 m .17341 .33294 L .192 .31622 L p F P
0 g
s
.796 .709 .769 r
.17341 .33294 m .1634 .32658 L .17039 .33614 L closepath p F P
0 g
s
.463 .246 .497 r
.64791 .42236 m .63754 .42757 L .64264 .41538 L p F P
0 g
s
.463 .246 .497 r
.64264 .41538 m .648 .41267 L .64791 .42236 L p F P
0 g
s
.584 .54 .771 r
.65285 .33 m .65839 .32953 L .65392 .33277 L closepath p F P
0 g
s
.556 .504 .753 r
.67731 .32896 m .65839 .32953 L .65392 .33277 L p F P
0 g
s
.556 .504 .753 r
.67958 .33595 m .67731 .32896 L p .65392 .33277 L F P
0 g
s
.556 .504 .753 r
.66316 .34785 m .67958 .33595 L p .65392 .33277 L F P
0 g
s
.766 .726 .816 r
.192 .31622 m .1938 .31478 L .18648 .30605 L p F P
0 g
s
.766 .726 .816 r
.18648 .30605 m .18229 .3093 L .192 .31622 L p F P
0 g
s
.781 .723 .799 r
.16312 .32621 m .1634 .32658 L p .192 .31622 L F P
0 g
s
.781 .723 .799 r
.192 .31622 m .18229 .3093 L .16312 .32621 L p F P
0 g
s
.826 .462 .367 r
.20616 .45186 m .21909 .45721 L .21569 .44825 L p F P
0 g
s
.826 .462 .367 r
.21569 .44825 m .20281 .44289 L .20616 .45186 L p F P
0 g
s
.82 .71 .744 r
.16233 .34685 m .17039 .33614 L .1634 .32658 L p F P
0 g
s
.522 .756 .981 r
.31145 .31172 m .31259 .3126 L p .28307 .30982 L F P
0 g
s
.522 .756 .981 r
.28307 .30982 m .29765 .30811 L .31145 .31172 L p F P
0 g
s
.482 .729 .979 r
.29765 .30811 m .28307 .30982 L .27589 .30321 L p F P
0 g
s
.723 .735 .86 r
.21655 .30157 m .1938 .31478 L .18648 .30605 L p F P
0 g
s
.654 .831 .968 r
.522 .30942 m .52121 .30884 L .49998 .31604 L closepath p F P
0 g
s
.635 .869 .986 r
.51493 .30562 m .52121 .30884 L .49998 .31604 L p F P
0 g
s
.635 .869 .986 r
.49134 .31346 m .51493 .30562 L p .49998 .31604 L F P
0 g
s
.436 .818 .99 r
.40844 .32318 m .43151 .3198 L .43818 .32238 L p F P
0 g
s
.255 .749 .91 r
.43151 .3198 m .40844 .32318 L .40163 .32024 L p F P
0 g
s
.598 .555 .777 r
.65839 .32953 m .65285 .33 L .64675 .31582 L p F P
0 g
s
.524 .872 .989 r
.49134 .31346 m .46795 .32011 L .46143 .31738 L p F P
0 g
s
.513 .848 .997 r
.43818 .32238 m .46143 .31738 L .46795 .32011 L p F P
0 g
s
.379 .82 .952 r
.46143 .31738 m .43818 .32238 L .43151 .3198 L p F P
0 g
s
.5 .393 .664 r
.68381 .35122 m .68361 .35115 L .66383 .36491 L p F P
0 g
s
.5 .393 .664 r
.68651 .36421 m .68381 .35122 L p .66383 .36491 L F P
0 g
s
.5 .393 .664 r
.66961 .37593 m .68651 .36421 L p .66383 .36491 L F P
0 g
s
.5 .393 .664 r
.66383 .36491 m .66574 .374 L .66961 .37593 L p F P
0 g
s
.382 0 .017 r
.51797 .50024 m .51881 .49921 L .49527 .50096 L p F P
0 g
s
.382 0 .017 r
.49527 .50096 m .4917 .50497 L .51797 .50024 L p F P
0 g
s
.565 .079 .06 r
.37618 .50811 m .38063 .5098 L .37428 .50944 L closepath p F P
0 g
s
.733 .282 .181 r
.25926 .48335 m .25203 .47554 L .26699 .48006 L p F P
0 g
s
.733 .282 .181 r
.27228 .4872 m .25926 .48335 L p .26699 .48006 L F P
0 g
s
.733 .282 .181 r
.26699 .48006 m .27337 .48669 L .27228 .4872 L p F P
0 g
s
.538 .455 .709 r
.68377 .35104 m .68361 .35115 L .66316 .34785 L p F P
0 g
s
.538 .455 .709 r
.66316 .34785 m .67958 .33595 L .68377 .35104 L p F P
0 g
s
.644 .143 .045 r
.31172 .49643 m .31002 .49709 L .30771 .49562 L closepath p F P
0 g
s
.841 .52 .446 r
.20188 .43792 m .20281 .44289 L .19944 .44138 L closepath p F P
0 g
s
.414 .117 .349 r
.62399 .44262 m .60171 .45673 L .6011 .45966 L p F P
0 g
s
.644 .141 .04 r
.30084 .4988 m .29074 .49185 L .30771 .49562 L p F P
0 g
s
.644 .141 .04 r
.30376 .49944 m .30084 .4988 L p .30771 .49562 L F P
0 g
s
.644 .141 .04 r
.30771 .49562 m .31002 .49709 L .30376 .49944 L p F P
0 g
s
.82 .71 .744 r
.15241 .34007 m .16233 .34685 L p .1634 .32658 L F P
0 g
s
.837 .698 .709 r
.14468 .35276 m .15471 .3595 L .16233 .34685 L p F P
0 g
s
.837 .698 .709 r
.16233 .34685 m .15241 .34007 L .14468 .35276 L p F P
0 g
s
.793 .387 .282 r
.22406 .46569 m .21909 .45721 L .23251 .46234 L p F P
0 g
s
.793 .387 .282 r
.23618 .47026 m .22406 .46569 L p .23251 .46234 L F P
0 g
s
.793 .387 .282 r
.23251 .46234 m .23703 .4698 L .23618 .47026 L p F P
0 g
s
.427 .218 .491 r
.66889 .41016 m .66892 .40046 L .648 .41267 L p F P
0 g
s
.427 .218 .491 r
.648 .41267 m .64791 .42236 L .66889 .41016 L p F P
0 g
s
.457 .724 .983 r
.31259 .3126 m .31366 .31257 L .31145 .31172 L closepath p F P
0 g
s
.507 .388 .652 r
.66574 .374 m .66961 .37593 L .66652 .37802 L closepath p F P
0 g
s
.326 0 0 r
.54327 .49424 m .54762 .48884 L .52248 .49487 L p F P
0 g
s
.326 0 0 r
.53147 .49705 m .54327 .49424 L p .52248 .49487 L F P
0 g
s
.326 0 0 r
.52248 .49487 m .51881 .49921 L .53147 .49705 L p F P
0 g
s
.598 .555 .777 r
.67341 .31819 m .65839 .32953 L p .64675 .31582 L F P
0 g
s
.571 .521 .76 r
.65839 .32953 m .67341 .31819 L .67731 .32896 L closepath p F P
0 g
s
.864 .583 .51 r
.16597 .41576 m .17726 .42185 L .17719 .41185 L p F P
0 g
s
.864 .583 .51 r
.17719 .41185 m .16594 .40575 L .16597 .41576 L p F P
0 g
s
.865 .622 .568 r
.15506 .39946 m .16594 .40575 L .16746 .39524 L p F P
0 g
s
.865 .622 .568 r
.16746 .39524 m .15661 .38893 L .15506 .39946 L p F P
0 g
s
.459 .725 .983 r
.32952 .30847 m .33509 .31162 L .31366 .31257 L p F P
0 g
s
.459 .725 .983 r
.32575 .30756 m .32952 .30847 L p .31366 .31257 L F P
0 g
s
.459 .725 .983 r
.30546 .30709 m .32575 .30756 L p .31366 .31257 L F P
0 g
s
.459 .725 .983 r
.31366 .31257 m .31145 .31172 L .30546 .30709 L p F P
0 g
s
.439 0 .045 r
.46546 .50725 m .4716 .50752 L .46439 .50839 L closepath p F P
0 g
s
.398 0 0 r
.43479 .51042 m .40594 .51083 L .40585 .51088 L p F P
0 g
s
.457 0 0 r
.40594 .51083 m .40585 .51088 L .40559 .51082 L closepath p F P
0 g
s
.458 0 0 r
.39868 .51432 m .38063 .5098 L .40559 .51082 L p F P
0 g
s
.458 0 0 r
.39895 .51433 m .39868 .51432 L p .40559 .51082 L F P
0 g
s
.458 0 0 r
.40559 .51082 m .40585 .51088 L .39895 .51433 L p F P
0 g
s
.398 0 0 r
.40585 .51088 m .427 .51428 L p .43479 .51042 L F P
0 g
s
.419 0 0 r
.40585 .51088 m .427 .51428 L .39895 .51433 L closepath p F P
0 g
s
.598 .555 .777 r
.64675 .31582 m .67109 .31236 L .67341 .31819 L p F P
0 g
s
.599 .597 .821 r
.64384 .30987 m .64675 .31582 L .67109 .31236 L p F P
0 g
s
.415 0 0 r
.43587 .5104 m .43563 .51053 L .43479 .51042 L closepath p F P
0 g
s
.398 0 0 r
.42939 .51424 m .43563 .51053 L .43479 .51042 L p F P
0 g
s
.398 0 0 r
.427 .51428 m .42939 .51424 L p .43479 .51042 L F P
0 g
s
.857 .536 .444 r
.17881 .43138 m .19056 .43725 L .18894 .42774 L p F P
0 g
s
.857 .536 .444 r
.18894 .42774 m .17726 .42185 L .17881 .43138 L p F P
0 g
s
.367 0 0 r
.45885 .5121 m .46439 .50839 L .43587 .5104 L p F P
0 g
s
.367 0 0 r
.43587 .5104 m .43563 .51053 L .45885 .5121 L p F P
0 g
s
.477 .336 .61 r
.67689 .3839 m .66815 .38978 L .66652 .37802 L p F P
0 g
s
.477 .336 .61 r
.66652 .37802 m .66961 .37593 L .67689 .3839 L p F P
0 g
s
.427 .176 .428 r
.64706 .43116 m .64791 .42236 L .63754 .42757 L p F P
0 g
s
.427 .176 .428 r
.62531 .44205 m .64706 .43116 L p .63754 .42757 L F P
0 g
s
.427 .176 .428 r
.63754 .42757 m .62536 .44146 L .62531 .44205 L p F P
0 g
s
.535 .756 .978 r
.31145 .31172 m .30546 .30709 L .29765 .30811 L closepath p F P
0 g
s
.862 .654 .621 r
.14613 .38244 m .15661 .38893 L .15987 .37783 L p F P
0 g
s
.862 .654 .621 r
.15987 .37783 m .14943 .37131 L .14613 .38244 L p F P
0 g
s
.631 .124 .026 r
.31002 .49709 m .31869 .5023 L .30376 .49944 L closepath p F P
0 g
s
.373 0 0 r
.45831 .51248 m .45885 .5121 L .43563 .51053 L p F P
0 g
s
.373 0 0 r
.43563 .51053 m .42939 .51424 L .45831 .51248 L p F P
0 g
s
.455 0 0 r
.37443 .51301 m .39868 .51432 L .38063 .5098 L p F P
0 g
s
.455 0 0 r
.36904 .5115 m .37443 .51301 L p .38063 .5098 L F P
0 g
s
.455 0 0 r
.38063 .5098 m .37428 .50944 L .36904 .5115 L p F P
0 g
s
.508 0 0 r
.37428 .50944 m .36904 .5115 L .35821 .50792 L closepath p F P
0 g
s
.414 .117 .349 r
.6011 .45966 m .62365 .45001 L p .62399 .44262 L F P
0 g
s
.338 0 .226 r
.62126 .45714 m .62365 .45001 L .6011 .45966 L p F P
0 g
s
.338 0 .226 r
.6011 .45966 m .59863 .46682 L .62126 .45714 L p F P
0 g
s
.664 .738 .905 r
.21655 .30157 m .23902 .29362 L .2463 .30104 L p F P
0 g
s
.652 .736 .911 r
.23902 .29362 m .21655 .30157 L .20923 .2935 L p F P
0 g
s
.723 .735 .86 r
.18648 .30605 m .20923 .2935 L .21655 .30157 L p F P
0 g
s
.676 .721 .883 r
.58084 .30159 m .60469 .29274 L .61069 .30092 L p F P
0 g
s
.689 .759 .905 r
.60469 .29274 m .58084 .30159 L .57478 .29527 L p F P
0 g
s
.687 .779 .921 r
.55103 .30456 m .57478 .29527 L .58084 .30159 L p F P
0 g
s
.834 .464 .354 r
.19368 .44629 m .20616 .45186 L .20281 .44289 L p F P
0 g
s
.834 .464 .354 r
.19328 .44514 m .19368 .44629 L p .20281 .44289 L F P
0 g
s
.834 .464 .354 r
.20281 .44289 m .19944 .44138 L .19328 .44514 L p F P
0 g
s
.461 .203 .436 r
.62536 .44146 m .62399 .44262 L .62531 .44205 L closepath p F P
0 g
s
.414 .117 .349 r
.62365 .45001 m .62531 .44205 L .62399 .44262 L p F P
0 g
s
.652 .659 .844 r
.61069 .30092 m .63472 .29338 L .64071 .30377 L p F P
0 g
s
.668 .695 .867 r
.63472 .29338 m .61069 .30092 L .60469 .29274 L p F P
0 g
s
.748 .287 .157 r
.24473 .47862 m .25926 .48335 L .25203 .47554 L p F P
0 g
s
.748 .287 .157 r
.25203 .47554 m .23764 .47078 L .24473 .47862 L p F P
0 g
s
.807 .715 .763 r
.16312 .32621 m .16302 .32631 L .1634 .32658 L closepath p F P
0 g
s
.82 .71 .744 r
.1634 .32658 m .16302 .32631 L .15241 .34007 L p F P
0 g
s
.589 .742 .949 r
.2463 .30104 m .26866 .29667 L .27589 .30321 L p F P
0 g
s
.564 .737 .957 r
.26866 .29667 m .2463 .30104 L .23902 .29362 L p F P
0 g
s
.297 .734 .967 r
.36745 .31684 m .37184 .31878 L p .34217 .31594 L F P
0 g
s
.297 .734 .967 r
.34217 .31594 m .3599 .31578 L .36745 .31684 L p F P
0 g
s
.168 .66 .919 r
.3599 .31578 m .34217 .31594 L .33509 .31162 L p F P
0 g
s
.621 .619 .827 r
.64071 .30377 m .65599 .30046 L .64384 .30987 L closepath p F P
0 g
s
.599 .597 .821 r
.66501 .29867 m .65599 .30046 L .64384 .30987 L p F P
0 g
s
.599 .597 .821 r
.67109 .31236 m .66501 .29867 L p .64384 .30987 L F P
0 g
s
.693 .821 .944 r
.57478 .29527 m .55103 .30456 L .54487 .29988 L p F P
0 g
s
.853 .682 .669 r
.13934 .3646 m .14943 .37131 L .15471 .3595 L p F P
0 g
s
.853 .682 .669 r
.15471 .3595 m .14468 .35276 L .13934 .3646 L p F P
0 g
s
.778 .718 .796 r
.18229 .3093 m .16312 .32621 L .15573 .3169 L p F P
0 g
s
.809 .722 .769 r
.16302 .32631 m .16312 .32621 L .15573 .3169 L p F P
0 g
s
.663 .156 .029 r
.28432 .49482 m .30084 .4988 L .29074 .49185 L p F P
0 g
s
.663 .156 .029 r
.29074 .49185 m .27448 .4878 L .28432 .49482 L p F P
0 g
s
.809 .722 .769 r
.15573 .3169 m .15363 .31924 L .16302 .32631 L p F P
0 g
s
.823 .717 .748 r
.14285 .33308 m .15241 .34007 L .16302 .32631 L p F P
0 g
s
.823 .717 .748 r
.16302 .32631 m .15363 .31924 L .14285 .33308 L p F P
0 g
s
.316 0 0 r
.4716 .50752 m .46439 .50839 L .45885 .5121 L p F P
0 g
s
.307 0 .106 r
.59628 .4713 m .59863 .46682 L .57525 .47526 L p F P
0 g
s
.307 0 .106 r
.57525 .47526 m .57238 .48066 L .59628 .4713 L p F P
0 g
s
.474 .335 .612 r
.68824 .37608 m .67689 .3839 L .66961 .37593 L p F P
0 g
s
.474 .335 .612 r
.66961 .37593 m .68651 .36421 L .68824 .37608 L p F P
0 g
s
.358 .065 .324 r
.64548 .4391 m .64706 .43116 L .62531 .44205 L p F P
0 g
s
.358 .065 .324 r
.62531 .44205 m .62365 .45001 L .64548 .4391 L p F P
0 g
s
.371 0 .145 r
.5719 .48159 m .57238 .48066 L .54859 .48702 L p F P
0 g
s
.371 0 .145 r
.54859 .48702 m .54762 .48884 L .5719 .48159 L p F P
0 g
s
.674 .836 .961 r
.522 .30942 m .52121 .30884 L .54257 .30075 L closepath p F P
0 g
s
.764 .73 .821 r
.18229 .3093 m .18648 .30605 L .17909 .2975 L p F P
0 g
s
.764 .73 .821 r
.17909 .2975 m .1729 .3022 L .18229 .3093 L p F P
0 g
s
.778 .718 .796 r
.15573 .3169 m .1729 .3022 L .18229 .3093 L p F P
0 g
s
.482 0 0 r
.36662 .51245 m .36904 .5115 L .35821 .50792 L p F P
0 g
s
.482 0 0 r
.35252 .5109 m .36662 .51245 L p .35821 .50792 L F P
0 g
s
.482 0 0 r
.33937 .50619 m .35252 .5109 L p .35821 .50792 L F P
0 g
s
.482 0 0 r
.35821 .50792 m .34049 .50588 L .33937 .50619 L p F P
0 g
s
.841 .476 .363 r
.19944 .44138 m .19328 .44514 L .19056 .43725 L closepath p F P
0 g
s
.717 .736 .866 r
.20923 .2935 m .18648 .30605 L .17909 .2975 L p F P
0 g
s
.324 0 0 r
.4917 .50497 m .48887 .50703 L .4716 .50752 L closepath p F P
0 g
s
.316 0 0 r
.48594 .50922 m .48887 .50703 L .4716 .50752 L p F P
0 g
s
.316 0 0 r
.46181 .51209 m .48594 .50922 L p .4716 .50752 L F P
0 g
s
.316 0 0 r
.45885 .5121 m .46181 .51209 L p .4716 .50752 L F P
0 g
s
.655 .881 .981 r
.54257 .30075 m .52121 .30884 L .51493 .30562 L p F P
0 g
s
.809 .396 .266 r
.21103 .46036 m .22406 .46569 L .21909 .45721 L p F P
0 g
s
.809 .396 .266 r
.21909 .45721 m .20616 .45186 L .21103 .46036 L p F P
0 g
s
.482 .729 .979 r
.27589 .30321 m .28392 .30275 L .29765 .30811 L p F P
0 g
s
.531 .761 .981 r
.29826 .30169 m .28392 .30275 L .29765 .30811 L p F P
0 g
s
.531 .761 .981 r
.29765 .30811 m .30546 .30709 L .29826 .30169 L p F P
0 g
s
.443 .7 .975 r
.28392 .30275 m .27589 .30321 L .26866 .29667 L p F P
0 g
s
.635 .631 .829 r
.65599 .30046 m .64071 .30377 L .63472 .29338 L p F P
0 g
s
.225 .719 .918 r
.40062 .31995 m .40163 .32024 L p .37184 .31878 L F P
0 g
s
.225 .719 .918 r
.37184 .31878 m .38036 .3186 L .40062 .31995 L p F P
0 g
s
.321 .744 .975 r
.37184 .31878 m .38036 .3186 L .36745 .31684 L closepath p F P
0 g
s
.53 0 0 r
.34049 .50588 m .33937 .50619 L .33751 .50544 L closepath p F P
0 g
s
.842 .705 .713 r
.13503 .34582 m .14468 .35276 L .15241 .34007 L p F P
0 g
s
.842 .705 .713 r
.15241 .34007 m .14285 .33308 L .13503 .34582 L p F P
0 g
s
.437 .268 .553 r
.67904 .39368 m .66892 .40046 L .66815 .38978 L p F P
0 g
s
.437 .268 .553 r
.66815 .38978 m .67689 .3839 L .67904 .39368 L p F P
0 g
s
.727 .274 .174 r
.27337 .48669 m .27448 .4878 L .27228 .4872 L closepath p F P
0 g
s
.529 0 0 r
.33203 .50813 m .31869 .5023 L .33751 .50544 L p F P
0 g
s
.529 0 0 r
.33751 .50544 m .33937 .50619 L .33203 .50813 L p F P
0 g
s
.263 0 0 r
.56768 .48699 m .5719 .48159 L .54762 .48884 L p F P
0 g
s
.263 0 0 r
.54762 .48884 m .54327 .49424 L .56768 .48699 L p F P
0 g
s
.374 .129 .409 r
.6681 .41895 m .66889 .41016 L .64791 .42236 L p F P
0 g
s
.374 .129 .409 r
.64791 .42236 m .64706 .43116 L .6681 .41895 L p F P
0 g
s
.873 .591 .507 r
.15508 .40948 m .16597 .41576 L .16594 .40575 L p F P
0 g
s
.873 .591 .507 r
.16594 .40575 m .15506 .39946 L .15508 .40948 L p F P
0 g
s
.578 .894 .987 r
.51493 .30562 m .49134 .31346 L .48491 .3113 L p F P
0 g
s
.524 .872 .989 r
.46143 .31738 m .48491 .3113 L .49134 .31346 L p F P
0 g
s
.873 .63 .567 r
.14457 .39297 m .15506 .39946 L .15661 .38893 L p F P
0 g
s
.873 .63 .567 r
.15661 .38893 m .14613 .38244 L .14457 .39297 L p F P
0 g
s
.261 0 0 r
.51253 .50454 m .51797 .50024 L .4917 .50497 L p F P
0 g
s
.261 0 0 r
.4917 .50497 m .48887 .50703 L .51253 .50454 L p F P
0 g
s
.79 .383 .279 r
.23703 .4698 m .23764 .47078 L .23618 .47026 L closepath p F P
0 g
s
.866 .543 .438 r
.16748 .4253 m .17881 .43138 L .17726 .42185 L p F P
0 g
s
.866 .543 .438 r
.17726 .42185 m .16597 .41576 L .16748 .4253 L p F P
0 g
s
.655 .133 0 r
.26852 .49055 m .28432 .49482 L .27448 .4878 L p F P
0 g
s
.655 .133 0 r
.26565 .48837 m .26852 .49055 L p .27448 .4878 L F P
0 g
s
.655 .133 0 r
.27448 .4878 m .27228 .4872 L .26565 .48837 L p F P
0 g
s
.255 .749 .91 r
.43083 .31966 m .43151 .3198 L p .40163 .32024 L F P
0 g
s
.255 .749 .91 r
.40163 .32024 m .40462 .32001 L .43083 .31966 L p F P
0 g
s
.31 .769 .949 r
.40163 .32024 m .40462 .32001 L .40062 .31995 L closepath p F P
0 g
s
.868 .664 .623 r
.13939 .37797 m .14613 .38244 L .14943 .37131 L p F P
0 g
s
.868 .664 .623 r
.13724 .37153 m .13939 .37797 L p .14943 .37131 L F P
0 g
s
.868 .664 .623 r
.14943 .37131 m .13934 .3646 L .13724 .37153 L p F P
0 g
s
.534 0 0 r
.35252 .5109 m .33937 .50619 L .33203 .50813 L p F P
0 g
s
.748 .275 .124 r
.23076 .47365 m .24473 .47862 L .23764 .47078 L p F P
0 g
s
.748 .275 .124 r
.22907 .47167 m .23076 .47365 L p .23764 .47078 L F P
0 g
s
.748 .275 .124 r
.23764 .47078 m .23618 .47026 L .22907 .47167 L p F P
0 g
s
.48 .871 .969 r
.48488 .31129 m .48491 .3113 L .46143 .31738 L p F P
0 g
s
.48 .871 .969 r
.46143 .31738 m .45893 .31683 L .48488 .31129 L p F P
0 g
s
.379 .82 .952 r
.45893 .31683 m .46143 .31738 L p .43151 .3198 L F P
0 g
s
.681 .171 .018 r
.27228 .4872 m .26565 .48837 L .25926 .48335 L closepath p F P
0 g
s
.845 .479 .358 r
.18183 .44045 m .17881 .43138 L .19056 .43725 L p F P
0 g
s
.845 .479 .358 r
.19234 .44565 m .18183 .44045 L p .19056 .43725 L F P
0 g
s
.845 .479 .358 r
.19056 .43725 m .19328 .44514 L .19234 .44565 L p F P
0 g
s
.764 .301 .147 r
.23618 .47026 m .22907 .47167 L .22406 .46569 L closepath p F P
0 g
s
.379 .82 .952 r
.43151 .3198 m .43484 .31924 L .45893 .31683 L p F P
0 g
s
.371 .817 .947 r
.43151 .3198 m .43484 .31924 L .43083 .31966 L closepath p F P
0 g
s
.217 .661 .951 r
.32575 .30756 m .30546 .30709 L .29826 .30169 L p F P
0 g
s
.274 .758 .921 r
.43083 .31966 m .42476 .3183 L .40462 .32001 L closepath p F P
0 g
s
.324 .774 .956 r
.42065 .31807 m .42476 .3183 L .40462 .32001 L p F P
0 g
s
.324 .774 .956 r
.40949 .31801 m .42065 .31807 L p .40462 .32001 L F P
0 g
s
.324 .774 .956 r
.39474 .31817 m .40949 .31801 L p .40462 .32001 L F P
0 g
s
.324 .774 .956 r
.40462 .32001 m .40062 .31995 L .39474 .31817 L p F P
0 g
s
.252 .732 .933 r
.40062 .31995 m .39474 .31817 L .38036 .3186 L closepath p F P
0 g
s
.335 0 .006 r
.51881 .49921 m .53147 .49705 L .51797 .50024 L closepath p F P
0 g
s
.516 0 0 r
.3319 .50817 m .33203 .50813 L .31869 .5023 L p F P
0 g
s
.516 0 0 r
.31387 .50486 m .3319 .50817 L p .31869 .5023 L F P
0 g
s
.516 0 0 r
.30248 .49961 m .31387 .50486 L p .31869 .5023 L F P
0 g
s
.516 0 0 r
.31869 .5023 m .30376 .49944 L .30248 .49961 L p F P
0 g
s
.385 .822 .954 r
.43484 .31924 m .43083 .31966 L .42476 .3183 L p F P
0 g
s
.652 .736 .911 r
.20923 .2935 m .23169 .28621 L .23902 .29362 L p F P
0 g
s
.642 .733 .915 r
.23169 .28621 m .20923 .2935 L .20184 .28549 L p F P
0 g
s
.717 .736 .866 r
.17909 .2975 m .20184 .28549 L .20923 .2935 L p F P
0 g
s
.859 .691 .672 r
.13242 .35967 m .13934 .3646 L .14468 .35276 L p F P
0 g
s
.859 .691 .672 r
.13038 .35597 m .13242 .35967 L p .14468 .35276 L F P
0 g
s
.859 .691 .672 r
.14468 .35276 m .13503 .34582 L .13038 .35597 L p F P
0 g
s
.778 .725 .804 r
.1729 .3022 m .15573 .3169 L .14827 .30794 L p F P
0 g
s
.81 .728 .774 r
.15363 .31924 m .15573 .3169 L .14827 .30794 L p F P
0 g
s
.443 .7 .975 r
.26866 .29667 m .27199 .29667 L .28392 .30275 L p F P
0 g
s
.484 .744 .986 r
.291 .29632 m .27199 .29667 L .28392 .30275 L p F P
0 g
s
.484 .744 .986 r
.28392 .30275 m .29826 .30169 L .291 .29632 L p F P
0 g
s
.518 .443 .711 r
.70278 .33538 m .68377 .35104 L .67958 .33595 L p F P
0 g
s
.518 .443 .711 r
.7024 .33392 m .70278 .33538 L p .67958 .33595 L F P
0 g
s
.518 .443 .711 r
.67958 .33595 m .68681 .32996 L .7024 .33392 L p F P
0 g
s
.542 .484 .741 r
.67731 .32896 m .68681 .32996 L .67958 .33595 L closepath p F P
0 g
s
.537 .501 .763 r
.67341 .31819 m .67731 .32896 L .68681 .32996 L p F P
0 g
s
.81 .728 .774 r
.14827 .30794 m .14458 .31197 L .15363 .31924 L p F P
0 g
s
.826 .724 .752 r
.13365 .32588 m .14285 .33308 L .15363 .31924 L p F P
0 g
s
.826 .724 .752 r
.15363 .31924 m .14458 .31197 L .13365 .32588 L p F P
0 g
s
.387 .822 .956 r
.45893 .31683 m .45484 .31586 L .43484 .31924 L closepath p F P
0 g
s
.385 .822 .954 r
.44933 .31564 m .45484 .31586 L .43484 .31924 L p F P
0 g
s
.385 .822 .954 r
.44281 .31621 m .44933 .31564 L p .43484 .31924 L F P
0 g
s
.385 .822 .954 r
.43484 .31924 m .42494 .31831 L .44281 .31621 L F
.206 .73 .839 r
.44815 .31558 m .44281 .31621 L .44611 .31592 L p F P
0 g
s
.206 .73 .839 r
.44611 .31592 m .44933 .31564 L .44815 .31558 L p F P
0 g
s
.22 .739 .853 r
.44143 .31665 m .44812 .31558 L p .44281 .31621 L F P
0 g
s
.22 .739 .853 r
.44812 .31558 m .44815 .31558 L .44281 .31621 L p F P
0 g
s
.306 .795 .879 r
.47181 .31106 m .476 .31071 L .46666 .31244 L p F P
0 g
s
.324 .807 .879 r
.45484 .31586 m .44933 .31564 L .46326 .31307 L p F P
0 g
s
.324 .807 .879 r
.46326 .31307 m .476 .31071 L p .47288 .31147 L F P
0 g
s
.324 .807 .879 r
.45484 .31586 m .46326 .31307 L .47288 .31147 L F
.306 .795 .879 r
.46666 .31244 m .46326 .31307 L p .47181 .31106 L F P
0 g
s
.306 .795 .879 r
.45635 .31421 m .47181 .31106 L .46326 .31307 L F
.44933 .31564 m .44815 .31558 L .47181 .31106 L p F P
0 g
s
.122 .669 .703 r
.46864 .31213 m .47181 .31106 L .44815 .31558 L p F P
0 g
s
.122 .669 .703 r
.4621 .31322 m .46864 .31213 L p .44841 .31553 L F P
0 g
s
.122 .669 .703 r
.44815 .31558 m .44834 .31554 L .44841 .31553 L F
.44834 .31554 m .4621 .31322 L .44841 .31553 L F
.354 .829 .84 r
.476 .31071 m .47181 .31106 L .49571 .30388 L p F P
0 g
s
0 0 0 r
.47181 .31106 m .46864 .31213 L .47651 .30979 L p F P
0 g
s
.354 .829 .84 r
.50073 .30323 m .476 .31071 L p .49346 .30466 L F P
0 g
s
.354 .829 .84 r
.49637 .30379 m .50073 .30323 L p .49346 .30466 L F P
0 g
s
.354 .829 .84 r
.49346 .30466 m .49571 .30388 L .49499 .3042 L F
0 0 0 r
.49362 .30472 m .49571 .30388 L .47181 .31106 L p F P
0 g
s
.297 .773 .67 r
.49571 .30388 m .49362 .30472 L .49866 .30255 L p F P
0 g
s
.297 .773 .67 r
.49866 .30255 m .51674 .29474 L p .49571 .30388 L F P
0 g
s
.354 .829 .84 r
.49571 .30388 m .49637 .30379 L p .49499 .3042 L F P
0 g
s
0 0 0 r
.47651 .30979 m .49362 .30472 L p .4778 .30932 L F P
0 g
s
0 0 0 r
.47181 .31106 m .47329 .31066 L .4778 .30932 L F
.47329 .31066 m .47651 .30979 L .4778 .30932 L F
.306 .795 .879 r
.46326 .31307 m .44933 .31564 L p .45635 .31421 L F P
0 g
s
.122 .669 .703 r
.44143 .31665 m .4621 .31322 L p .45082 .31512 L F P
0 g
s
.122 .669 .703 r
.44815 .31558 m .44598 .31592 L p .45082 .31512 L F P
0 g
s
.122 .669 .703 r
.44598 .31592 m .44143 .31665 L p .45082 .31512 L F P
0 g
s
.385 .822 .954 r
.42476 .3183 m .44281 .31621 L p .42494 .31831 L F P
0 g
s
.668 .695 .867 r
.60469 .29274 m .62874 .28427 L .63472 .29338 L p F P
0 g
s
.683 .732 .887 r
.62874 .28427 m .60469 .29274 L .59869 .28571 L p F P
0 g
s
.689 .759 .905 r
.57478 .29527 m .59869 .28571 L .60469 .29274 L p F P
0 g
s
.816 .398 .251 r
.19848 .45481 m .21103 .46036 L .20616 .45186 L p F P
0 g
s
.816 .398 .251 r
.20616 .45186 m .19368 .44629 L .19848 .45481 L p F P
0 g
s
.763 .734 .825 r
.1729 .3022 m .17909 .2975 L .17163 .2891 L p F P
0 g
s
.763 .734 .825 r
.17163 .2891 m .16384 .2949 L .1729 .3022 L p F P
0 g
s
.778 .725 .804 r
.14827 .30794 m .16384 .2949 L .1729 .3022 L p F P
0 g
s
.331 .748 .978 r
.38916 .31716 m .39474 .31817 L .38036 .3186 L p F P
0 g
s
.331 .748 .978 r
.38459 .31675 m .38916 .31716 L p .38036 .3186 L F P
0 g
s
.331 .748 .978 r
.36485 .31568 m .38459 .31675 L p .38036 .3186 L F P
0 g
s
.331 .748 .978 r
.38036 .3186 m .36745 .31684 L .36485 .31568 L p F P
0 g
s
.702 .798 .925 r
.59869 .28571 m .57478 .29527 L .56869 .29008 L p F P
0 g
s
.693 .821 .944 r
.54487 .29988 m .56869 .29008 L .57478 .29527 L p F P
0 g
s
.564 .737 .957 r
.26173 .29044 m .26866 .29667 L p .23902 .29362 L F P
0 g
s
.564 .737 .957 r
.23902 .29362 m .26104 .29017 L .26173 .29044 L p F P
0 g
s
.539 .726 .961 r
.26104 .29017 m .23902 .29362 L .23169 .28621 L p F P
0 g
s
.572 .54 .781 r
.67109 .31236 m .6806 .31197 L .67341 .31819 L closepath p F P
0 g
s
.537 .501 .763 r
.69589 .31244 m .6806 .31197 L .67341 .31819 L p F P
0 g
s
.537 .501 .763 r
.69841 .32001 m .69589 .31244 L p .67341 .31819 L F P
0 g
s
.537 .501 .763 r
.68681 .32996 m .69841 .32001 L p .67341 .31819 L F P
0 g
s
.712 .737 .87 r
.20184 .28549 m .17909 .2975 L .17163 .2891 L p F P
0 g
s
.512 .409 .674 r
.68361 .35115 m .68377 .35104 L .68381 .35122 L closepath p F P
0 g
s
.472 .382 .673 r
.70567 .34876 m .70278 .33538 L .68377 .35104 L p F P
0 g
s
.472 .382 .673 r
.69459 .35781 m .70567 .34876 L p .68377 .35104 L F P
0 g
s
.472 .382 .673 r
.68377 .35104 m .68381 .35122 L .69459 .35781 L p F P
0 g
s
.483 .379 .66 r
.68381 .35122 m .69459 .35781 L .68651 .36421 L closepath p F P
0 g
s
.635 .631 .829 r
.66302 .2947 m .65599 .30046 L p .63472 .29338 L F P
0 g
s
.635 .631 .829 r
.63472 .29338 m .65899 .28695 L .66302 .2947 L p F P
0 g
s
.652 .664 .849 r
.65899 .28695 m .63472 .29338 L .62874 .28427 L p F P
0 g
s
.195 0 0 r
.53147 .49705 m .51797 .50024 L .51253 .50454 L p F P
0 g
s
.432 .265 .553 r
.68908 .3868 m .67904 .39368 L .67689 .3839 L p F P
0 g
s
.432 .265 .553 r
.67689 .3839 m .68824 .37608 L .68908 .3868 L p F P
0 g
s
.656 .878 .981 r
.54487 .29988 m .54257 .30075 L .54481 .29985 L closepath p F P
0 g
s
.655 .881 .981 r
.53868 .29642 m .54481 .29985 L .54257 .30075 L p F P
0 g
s
.655 .881 .981 r
.51493 .30562 m .53868 .29642 L p .54257 .30075 L F P
0 g
s
.388 .188 .483 r
.67646 .40511 m .66889 .41016 L .66892 .40046 L p F P
0 g
s
.388 .188 .483 r
.66892 .40046 m .67904 .39368 L .67646 .40511 L p F P
0 g
s
.477 0 0 r
.36904 .5115 m .37443 .51301 L .36662 .51245 L closepath p F P
0 g
s
.24 0 .07 r
.62026 .45904 m .62126 .45714 L .59863 .46682 L p F P
0 g
s
.24 0 .07 r
.59863 .46682 m .59628 .4713 L .62026 .45904 L p F P
0 g
s
.681 .167 .007 r
.2536 .48593 m .24473 .47862 L .25926 .48335 L p F P
0 g
s
.681 .167 .007 r
.26268 .48882 m .2536 .48593 L p .25926 .48335 L F P
0 g
s
.681 .167 .007 r
.25926 .48335 m .26565 .48837 L .26268 .48882 L p F P
0 g
s
.587 .553 .783 r
.6806 .31197 m .67109 .31236 L .66501 .29867 L p F P
0 g
s
.615 .612 .825 r
.65599 .30046 m .66302 .2947 L .66501 .29867 L closepath p F P
0 g
s
.279 0 .201 r
.6442 .44286 m .64548 .4391 L .62365 .45001 L p F P
0 g
s
.279 0 .201 r
.63151 .45202 m .6442 .44286 L p .62365 .45001 L F P
0 g
s
.279 0 .201 r
.62365 .45001 m .62126 .45714 L .63151 .45202 L p F P
0 g
s
.326 .745 .977 r
.36745 .31684 m .36485 .31568 L .3599 .31578 L closepath p F P
0 g
s
.316 0 .122 r
.59537 .47311 m .59628 .4713 L .57238 .48066 L p F P
0 g
s
.316 0 .122 r
.57238 .48066 m .5719 .48159 L .59537 .47311 L p F P
0 g
s
.455 .857 .969 r
.4784 .31047 m .48488 .31129 L .45893 .31683 L p F P
0 g
s
.455 .857 .969 r
.45893 .31683 m .45484 .31586 L .4784 .31047 L p F P
0 g
s
.558 0 0 r
.30376 .49944 m .30248 .49961 L .30084 .4988 L closepath p F P
0 g
s
.68 .884 .974 r
.56671 .28878 m .56869 .29008 L .54487 .29988 L p F P
0 g
s
.68 .884 .974 r
.54487 .29988 m .54481 .29985 L .56671 .28878 L p F P
0 g
s
.168 .66 .919 r
.33509 .31162 m .34167 .31212 L .3599 .31578 L p F P
0 g
s
.268 .683 .968 r
.33509 .31162 m .34167 .31212 L .32952 .30847 L closepath p F P
0 g
s
.69 .883 .97 r
.56258 .28602 m .56671 .28878 L .54481 .29985 L p F P
0 g
s
.69 .883 .97 r
.54481 .29985 m .53868 .29642 L .56258 .28602 L p F P
0 g
s
.846 .713 .716 r
.12575 .33867 m .13503 .34582 L .14285 .33308 L p F P
0 g
s
.846 .713 .716 r
.14285 .33308 m .13365 .32588 L .12575 .33867 L p F P
0 g
s
.882 .598 .503 r
.14457 .40299 m .15508 .40948 L .15506 .39946 L p F P
0 g
s
.882 .598 .503 r
.15506 .39946 m .14457 .39297 L .14457 .40299 L p F P
0 g
s
.766 .299 .137 r
.2175 .46839 m .21103 .46036 L .22406 .46569 L p F P
0 g
s
.766 .299 .137 r
.22662 .47206 m .2175 .46839 L p .22406 .46569 L F P
0 g
s
.766 .299 .137 r
.22406 .46569 m .22907 .47167 L .22662 .47206 L p F P
0 g
s
.875 .55 .431 r
.15655 .41902 m .16748 .4253 L .16597 .41576 L p F P
0 g
s
.875 .55 .431 r
.16597 .41576 m .15508 .40948 L .15655 .41902 L p F P
0 g
s
.269 0 0 r
.51245 .5046 m .51253 .50454 L .48887 .50703 L p F P
0 g
s
.269 0 0 r
.48887 .50703 m .48594 .50922 L .51245 .5046 L p F P
0 g
s
.882 .638 .566 r
.14002 .38997 m .14457 .39297 L .14613 .38244 L p F P
0 g
s
.882 .638 .566 r
.14613 .38244 m .13939 .37797 L .14002 .38997 L p F P
0 g
s
.554 0 0 r
.29496 .50045 m .28432 .49482 L .30084 .4988 L p F P
0 g
s
.554 0 0 r
.30084 .4988 m .30248 .49961 L .29496 .50045 L p F P
0 g
s
.28 .737 .954 r
.35776 .3131 m .34167 .31212 L .3599 .31578 L p F P
0 g
s
.28 .737 .954 r
.3599 .31578 m .36485 .31568 L .35776 .3131 L p F P
0 g
s
.457 .69 .967 r
.26866 .29667 m .27199 .29667 L .26173 .29044 L closepath p F P
0 g
s
.191 0 0 r
.59125 .47848 m .59537 .47311 L .5719 .48159 L p F P
0 g
s
.191 0 0 r
.5719 .48159 m .56768 .48699 L .59125 .47848 L p F P
0 g
s
.86 .49 .348 r
.17043 .43439 m .18183 .44045 L .17881 .43138 L p F P
0 g
s
.86 .49 .348 r
.17881 .43138 m .16748 .4253 L .17043 .43439 L p F P
0 g
s
.304 .02 .305 r
.6679 .41994 m .6681 .41895 L .64706 .43116 L p F P
0 g
s
.304 .02 .305 r
.65518 .43348 m .6679 .41994 L p .64706 .43116 L F P
0 g
s
.304 .02 .305 r
.64706 .43116 m .64548 .4391 L .65518 .43348 L p F P
0 g
s
.876 .673 .624 r
.13934 .3646 m .13242 .35967 L .13724 .37153 L closepath p F P
0 g
s
.255 0 0 r
.427 .51428 m .39895 .51433 L .39887 .51435 L p F P
0 g
s
.33 0 0 r
.39895 .51433 m .39887 .51435 L .39868 .51432 L closepath p F P
0 g
s
.328 0 0 r
.39187 .51605 m .37443 .51301 L .39868 .51432 L p F P
0 g
s
.328 0 0 r
.39868 .51432 m .39887 .51435 L .39187 .51605 L p F P
0 g
s
.285 0 0 r
.42939 .51424 m .42884 .51442 L .427 .51428 L closepath p F P
0 g
s
.255 0 0 r
.42199 .51663 m .42884 .51442 L .427 .51428 L p F P
0 g
s
.255 0 0 r
.39887 .51435 m .42199 .51663 L p .427 .51428 L F P
0 g
s
.224 0 0 r
.45218 .51485 m .45831 .51248 L .42939 .51424 L p F P
0 g
s
.224 0 0 r
.42939 .51424 m .42884 .51442 L .45218 .51485 L p F P
0 g
s
.329 0 0 r
.42199 .51663 m .39887 .51435 L .39187 .51605 L p F P
0 g
s
.565 .011 0 r
.31387 .50486 m .30248 .49961 L .29496 .50045 L p F P
0 g
s
.443 .314 .609 r
.70079 .36619 m .68824 .37608 L .68651 .36421 L p F P
0 g
s
.443 .314 .609 r
.68651 .36421 m .69459 .35781 L .70079 .36619 L p F P
0 g
s
.844 .477 .357 r
.19328 .44514 m .19368 .44629 L .19234 .44565 L closepath p F P
0 g
s
.195 0 0 r
.53794 .49864 m .54256 .49481 L .53147 .49705 L p F P
0 g
s
.195 0 0 r
.51364 .50432 m .53794 .49864 L p .53147 .49705 L F P
0 g
s
.195 0 0 r
.51253 .50454 m .51364 .50432 L p .53147 .49705 L F P
0 g
s
.189 0 0 r
.54327 .49424 m .54256 .49481 L .53147 .49705 L closepath p F P
0 g
s
.628 .916 .979 r
.53244 .29415 m .53868 .29642 L .51493 .30562 L p F P
0 g
s
.628 .916 .979 r
.53156 .2945 m .53244 .29415 L p .51493 .30562 L F P
0 g
s
.628 .916 .979 r
.51493 .30562 m .50951 .30393 L .53156 .2945 L p F P
0 g
s
.578 .894 .987 r
.50951 .30393 m .51493 .30562 L p .48491 .3113 L F P
0 g
s
.337 0 0 r
.45885 .5121 m .46181 .51209 L .45831 .51248 L closepath p F P
0 g
s
.278 0 0 r
.45218 .51485 m .42884 .51442 L .42199 .51663 L p F P
0 g
s
.456 .69 .967 r
.28367 .29087 m .291 .29632 L .27199 .29667 L p F P
0 g
s
.456 .69 .967 r
.26136 .29011 m .28367 .29087 L p .27199 .29667 L F P
0 g
s
.456 .69 .967 r
.27199 .29667 m .26173 .29044 L .26136 .29011 L p F P
0 g
s
.516 .446 .716 r
.68681 .32996 m .69841 .32001 L .7024 .33392 L closepath p F P
0 g
s
.311 0 0 r
.39046 .51639 m .39187 .51605 L .37443 .51301 L p F P
0 g
s
.311 0 0 r
.37161 .5151 m .39046 .51639 L p .37443 .51301 L F P
0 g
s
.311 0 0 r
.36186 .51316 m .37161 .5151 L p .37443 .51301 L F P
0 g
s
.311 0 0 r
.37443 .51301 m .36662 .51245 L .36186 .51316 L p F P
0 g
s
.821 .393 .224 r
.1864 .44904 m .19848 .45481 L .19368 .44629 L p F P
0 g
s
.821 .393 .224 r
.18506 .44653 m .1864 .44904 L p .19368 .44629 L F P
0 g
s
.821 .393 .224 r
.19368 .44629 m .19234 .44565 L .18506 .44653 L p F P
0 g
s
.587 .553 .783 r
.69196 .30178 m .6806 .31197 L p .66501 .29867 L F P
0 g
s
.587 .553 .783 r
.66501 .29867 m .68967 .29609 L .69196 .30178 L p F P
0 g
s
.586 .597 .83 r
.66302 .2947 m .66501 .29867 L .68967 .29609 L p F P
0 g
s
.149 0 0 r
.38459 .31675 m .36485 .31568 L .35776 .3131 L p F P
0 g
s
.165 0 0 r
.46181 .51209 m .45831 .51248 L .45218 .51485 L p F P
0 g
s
.381 0 0 r
.36662 .51245 m .36186 .51316 L .35252 .5109 L closepath p F P
0 g
s
.865 .698 .674 r
.12309 .34432 m .12575 .33867 L .13503 .34582 L p F P
0 g
s
.865 .698 .674 r
.13503 .34582 m .13038 .35597 L .12309 .34432 L p F P
0 g
s
.778 .732 .81 r
.16384 .2949 m .14827 .30794 L .14072 .29928 L p F P
0 g
s
.812 .734 .778 r
.14458 .31197 m .14827 .30794 L .14072 .29928 L p F P
0 g
s
.83 .41 .241 r
.19234 .44565 m .18506 .44653 L .18183 .44045 L closepath p F P
0 g
s
.182 0 0 r
.48594 .50922 m .48238 .51077 L .46181 .51209 L closepath p F P
0 g
s
.165 0 0 r
.47899 .51229 m .48238 .51077 L .46181 .51209 L p F P
0 g
s
.165 0 0 r
.45841 .51456 m .47899 .51229 L p .46181 .51209 L F P
0 g
s
.165 0 0 r
.45218 .51485 m .45841 .51456 L p .46181 .51209 L F P
0 g
s
.274 .686 .97 r
.35386 .31194 m .35776 .3131 L .34167 .31212 L p F P
0 g
s
.274 .686 .97 r
.34547 .31026 m .35386 .31194 L p .34167 .31212 L F P
0 g
s
.274 .686 .97 r
.32794 .30757 m .34547 .31026 L p .34167 .31212 L F P
0 g
s
.274 .686 .97 r
.34167 .31212 m .32952 .30847 L .32794 .30757 L p F P
0 g
s
.693 .171 0 r
.23945 .481 m .2536 .48593 L .24473 .47862 L p F P
0 g
s
.693 .171 0 r
.24473 .47862 m .23076 .47365 L .23945 .481 L p F P
0 g
s
.812 .734 .778 r
.14072 .29928 m .13589 .3045 L .14458 .31197 L p F P
0 g
s
.83 .731 .755 r
.12484 .31847 m .13365 .32588 L .14458 .31197 L p F P
0 g
s
.83 .731 .755 r
.14458 .31197 m .13589 .3045 L .12484 .31847 L p F P
0 g
s
.555 .516 .767 r
.6806 .31197 m .69196 .30178 L .69589 .31244 L closepath p F P
0 g
s
.642 .733 .915 r
.20184 .28549 m .2243 .27873 L .23169 .28621 L p F P
0 g
s
.633 .728 .917 r
.2243 .27873 m .20184 .28549 L .1944 .27749 L p F P
0 g
s
.712 .737 .87 r
.17163 .2891 m .1944 .27749 L .20184 .28549 L p F P
0 g
s
.763 .737 .829 r
.16384 .2949 m .17163 .2891 L .16411 .28081 L p F P
0 g
s
.763 .737 .829 r
.16411 .28081 m .15514 .2874 L .16384 .2949 L p F P
0 g
s
.778 .732 .81 r
.14072 .29928 m .15514 .2874 L .16384 .2949 L p F P
0 g
s
.571 .01 0 r
.28019 .49701 m .26852 .49055 L .28432 .49482 L p F P
0 g
s
.571 .01 0 r
.29378 .50055 m .28019 .49701 L p .28432 .49482 L F P
0 g
s
.571 .01 0 r
.28432 .49482 m .29496 .50045 L .29378 .50055 L p F P
0 g
s
.613 .621 .835 r
.65899 .28695 m .6742 .28403 L .66302 .2947 L closepath p F P
0 g
s
.586 .597 .83 r
.68358 .28247 m .6742 .28403 L .66302 .2947 L p F P
0 g
s
.586 .597 .83 r
.68967 .29609 m .68358 .28247 L p .66302 .2947 L F P
0 g
s
.578 .894 .987 r
.48491 .3113 m .48577 .31102 L .50951 .30393 L p F P
0 g
s
.491 .892 .941 r
.48491 .3113 m .48577 .31102 L .48488 .31129 L closepath p F P
0 g
s
.875 .664 .614 r
.13724 .37153 m .13609 .37571 L .13939 .37797 L closepath p F P
0 g
s
.886 .642 .564 r
.13454 .38625 m .14002 .38997 L .13939 .37797 L p F P
0 g
s
.886 .642 .564 r
.13939 .37797 m .13609 .37571 L .13454 .38625 L p F P
0 g
s
.503 .895 .948 r
.48577 .31102 m .48488 .31129 L .4784 .31047 L p F P
0 g
s
.882 .674 .617 r
.13609 .37571 m .13724 .37153 L .13242 .35967 L p F P
0 g
s
.217 .661 .951 r
.29826 .30169 m .31007 .30288 L .32575 .30756 L p F P
0 g
s
.165 .608 .936 r
.31007 .30288 m .29826 .30169 L .291 .29632 L p F P
0 g
s
.576 .895 .986 r
.50951 .30393 m .50859 .30363 L .48577 .31102 L closepath p F P
0 g
s
.503 .895 .948 r
.50219 .303 m .50859 .30363 L .48577 .31102 L p F P
0 g
s
.503 .895 .948 r
.4784 .31047 m .50219 .303 L p .48577 .31102 L F P
0 g
s
.108 0 0 r
.5665 .48796 m .56768 .48699 L .54327 .49424 L p F P
0 g
s
.108 0 0 r
.54327 .49424 m .54256 .49481 L .5665 .48796 L p F P
0 g
s
.534 0 0 r
.33203 .50813 m .33223 .50822 L .35252 .5109 L p F P
0 g
s
.378 0 0 r
.34979 .51289 m .33223 .50822 L .35252 .5109 L p F P
0 g
s
.378 0 0 r
.35725 .51383 m .34979 .51289 L p .35252 .5109 L F P
0 g
s
.378 0 0 r
.35252 .5109 m .36186 .51316 L .35725 .51383 L p F P
0 g
s
.683 .732 .887 r
.59869 .28571 m .62277 .27629 L .62874 .28427 L p F P
0 g
s
.7 .768 .905 r
.62277 .27629 m .59869 .28571 L .59267 .27974 L p F P
0 g
s
.702 .798 .925 r
.56869 .29008 m .59267 .27974 L .59869 .28571 L p F P
0 g
s
.709 .737 .873 r
.1944 .27749 m .17163 .2891 L .16411 .28081 L p F P
0 g
s
.652 .664 .849 r
.62874 .28427 m .65301 .27668 L .65899 .28695 L p F P
0 g
s
.669 .699 .869 r
.65301 .27668 m .62874 .28427 L .62277 .27629 L p F P
0 g
s
.779 .307 .117 r
.20483 .46286 m .2175 .46839 L .21103 .46036 L p F P
0 g
s
.779 .307 .117 r
.21103 .46036 m .19848 .45481 L .20483 .46286 L p F P
0 g
s
.38 .18 .479 r
.68909 .3965 m .67646 .40511 L .67904 .39368 L p F P
0 g
s
.38 .18 .479 r
.67904 .39368 m .68908 .3868 L .68909 .3965 L p F P
0 g
s
.539 .726 .961 r
.23169 .28621 m .24841 .28423 L .26104 .29017 L p F P
0 g
s
.521 .709 .957 r
.24841 .28423 m .23169 .28621 L .2243 .27873 L p F P
0 g
s
.144 .677 .856 r
.39474 .31817 m .40949 .31801 L .38916 .31716 L closepath p F P
0 g
s
.326 .091 .395 r
.6694 .41809 m .6681 .41895 L .66889 .41016 L p F P
0 g
s
.326 .091 .395 r
.66889 .41016 m .67646 .40511 L .6694 .41809 L p F P
0 g
s
.673 .155 0 r
.26565 .48837 m .26852 .49055 L .26268 .48882 L closepath p F P
0 g
s
.869 .689 .656 r
.13038 .35597 m .1297 .35767 L .13242 .35967 L closepath p F P
0 g
s
.882 .674 .617 r
.12655 .36874 m .13609 .37571 L p .13242 .35967 L F P
0 g
s
.882 .674 .617 r
.13242 .35967 m .1297 .35767 L .12655 .36874 L p F P
0 g
s
.891 .606 .498 r
.13578 .39719 m .14457 .40299 L .14457 .39297 L p F P
0 g
s
.891 .606 .498 r
.14457 .39297 m .14002 .38997 L .13578 .39719 L p F P
0 g
s
.324 .807 .879 r
.476 .31071 m .4784 .31047 L .45484 .31586 L p F P
0 g
s
.885 .557 .424 r
.14602 .41254 m .15655 .41902 L .15508 .40948 L p F P
0 g
s
.885 .557 .424 r
.15508 .40948 m .14457 .40299 L .14602 .41254 L p F P
0 g
s
.395 .238 .547 r
.70274 .37609 m .68908 .3868 L .68824 .37608 L p F P
0 g
s
.395 .238 .547 r
.68824 .37608 m .70079 .36619 L .70274 .37609 L p F P
0 g
s
.249 0 .086 r
.61805 .46337 m .62026 .45904 L .59628 .4713 L p F P
0 g
s
.249 0 .086 r
.59628 .4713 m .59537 .47311 L .61805 .46337 L p F P
0 g
s
.851 .722 .719 r
.11686 .3313 m .12575 .33867 L .13365 .32588 L p F P
0 g
s
.851 .722 .719 r
.13365 .32588 m .12484 .31847 L .11686 .3313 L p F P
0 g
s
.124 0 0 r
.5625 .49138 m .5665 .48796 L .54256 .49481 L p F P
0 g
s
.124 0 0 r
.54256 .49481 m .53794 .49864 L .5625 .49138 L p F P
0 g
s
.105 0 0 r
.50616 .50762 m .51245 .5046 L .48594 .50922 L p F P
0 g
s
.105 0 0 r
.48594 .50922 m .48238 .51077 L .50616 .50762 L p F P
0 g
s
.763 .295 .133 r
.22907 .47167 m .23076 .47365 L .22662 .47206 L closepath p F P
0 g
s
.894 .651 .563 r
.12495 .37929 m .13454 .38625 L .13609 .37571 L p F P
0 g
s
.894 .651 .563 r
.13609 .37571 m .12655 .36874 L .12495 .37929 L p F P
0 g
s
.204 .729 .839 r
.42476 .3183 m .44281 .31621 L .42065 .31807 L closepath p F P
0 g
s
.711 .87 .957 r
.58676 .2749 m .59267 .27974 L .56869 .29008 L p F P
0 g
s
.711 .87 .957 r
.56869 .29008 m .56671 .28878 L .58676 .2749 L p F P
0 g
s
.869 .496 .337 r
.15945 .42813 m .17043 .43439 L .16748 .4253 L p F P
0 g
s
.869 .496 .337 r
.16748 .4253 m .15655 .41902 L .15945 .42813 L p F P
0 g
s
.352 .728 .987 r
.32952 .30847 m .32794 .30757 L .32575 .30756 L closepath p F P
0 g
s
.874 .698 .66 r
.1297 .35767 m .13038 .35597 L .12309 .34432 L p F P
0 g
s
.522 0 0 r
.33203 .50813 m .33223 .50822 L .3319 .50817 L closepath p F P
0 g
s
.35 0 0 r
.33001 .50997 m .34979 .51289 L .33223 .50822 L p F P
0 g
s
.35 0 0 r
.32467 .50841 m .33001 .50997 L p .33223 .50822 L F P
0 g
s
.35 0 0 r
.33223 .50822 m .3319 .50817 L .32467 .50841 L p F P
0 g
s
.414 0 0 r
.3319 .50817 m .32467 .50841 L .31387 .50486 L closepath p F P
0 g
s
.438 .313 .612 r
.7075 .36074 m .70079 .36619 L .69459 .35781 L p F P
0 g
s
.438 .313 .612 r
.69459 .35781 m .70567 .34876 L .7075 .36074 L p F P
0 g
s
.629 .629 .832 r
.6742 .28403 m .65899 .28695 L .65301 .27668 L p F P
0 g
s
.874 .698 .66 r
.12309 .34432 m .12055 .35047 L .1297 .35767 L p F P
0 g
s
.889 .683 .618 r
.11736 .36157 m .12655 .36874 L .1297 .35767 L p F P
0 g
s
.889 .683 .618 r
.1297 .35767 m .12055 .35047 L .11736 .36157 L p F P
0 g
s
.336 .729 .983 r
.32071 .30372 m .31007 .30288 L .32575 .30756 L p F P
0 g
s
.336 .729 .983 r
.32575 .30756 m .32794 .30757 L .32071 .30372 L p F P
0 g
s
.574 .738 .953 r
.26173 .29044 m .26136 .29011 L .26104 .29017 L closepath p F P
0 g
s
.544 0 0 r
.2648 .49253 m .28019 .49701 L .26852 .49055 L p F P
0 g
s
.544 0 0 r
.25794 .48854 m .2648 .49253 L p .26852 .49055 L F P
0 g
s
.544 0 0 r
.26852 .49055 m .26268 .48882 L .25794 .48854 L p F P
0 g
s
.834 .41 .231 r
.17484 .44303 m .17043 .43439 L .18183 .44045 L p F P
0 g
s
.834 .41 .231 r
.18186 .44672 m .17484 .44303 L p .18183 .44045 L F P
0 g
s
.834 .41 .231 r
.18183 .44045 m .18506 .44653 L .18186 .44672 L p F P
0 g
s
.161 0 .022 r
.62126 .45714 m .62026 .45904 L .63151 .45202 L closepath p F P
0 g
s
.574 .737 .952 r
.25401 .28348 m .24841 .28423 L .26104 .29017 L p F P
0 g
s
.574 .737 .952 r
.26104 .29017 m .26136 .29011 L .25401 .28348 L p F P
0 g
s
.333 .672 .976 r
.28367 .29087 m .26136 .29011 L .25401 .28348 L p F P
0 g
s
.677 .14 0 r
.22588 .47583 m .23945 .481 L .23076 .47365 L p F P
0 g
s
.677 .14 0 r
.22116 .47166 m .22588 .47583 L p .23076 .47365 L F P
0 g
s
.677 .14 0 r
.23076 .47365 m .22662 .47206 L .22116 .47166 L p F P
0 g
s
.894 .611 .5 r
.13445 .3963 m .13578 .39719 L .14002 .38997 L p F P
0 g
s
.894 .611 .5 r
.14002 .38997 m .13454 .38625 L .13445 .3963 L p F P
0 g
s
0 .44 .72 r
.34547 .31026 m .32794 .30757 L .32071 .30372 L p F P
0 g
s
.11 0 0 r
.61475 .46764 m .61805 .46337 L .59537 .47311 L p F P
0 g
s
.11 0 0 r
.60183 .47392 m .61475 .46764 L p .59537 .47311 L F P
0 g
s
.11 0 0 r
.59537 .47311 m .59125 .47848 L .60183 .47392 L p F P
0 g
s
.693 .905 .971 r
.56258 .28602 m .53868 .29642 L .53244 .29415 L p F P
0 g
s
.711 .867 .955 r
.58662 .27479 m .58676 .2749 L .56671 .28878 L p F P
0 g
s
.711 .867 .955 r
.56671 .28878 m .56258 .28602 L .58662 .27479 L p F P
0 g
s
.207 0 .161 r
.64548 .4391 m .6442 .44286 L .65518 .43348 L closepath p F P
0 g
s
.871 .71 .68 r
.11563 .33387 m .11686 .3313 L .12575 .33867 L p F P
0 g
s
.871 .71 .68 r
.12575 .33867 m .12309 .34432 L .11563 .33387 L p F P
0 g
s
.779 .739 .816 r
.15514 .2874 m .14072 .29928 L .13308 .29088 L p F P
0 g
s
.815 .74 .782 r
.13589 .3045 m .14072 .29928 L .13308 .29088 L p F P
0 g
s
.582 .013 0 r
.26268 .48882 m .25794 .48854 L .2536 .48593 L closepath p F P
0 g
s
.701 .174 0 r
.22662 .47206 m .22116 .47166 L .2175 .46839 L closepath p F P
0 g
s
.314 .078 .387 r
.68833 .40523 m .6694 .41809 L .67646 .40511 L p F P
0 g
s
.314 .078 .387 r
.67646 .40511 m .68909 .3965 L .68833 .40523 L p F P
0 g
s
.815 .74 .782 r
.13308 .29088 m .12755 .29682 L .13589 .3045 L p F P
0 g
s
.833 .738 .759 r
.11641 .31085 m .12484 .31847 L .13589 .3045 L p F P
0 g
s
.833 .738 .759 r
.13589 .3045 m .12755 .29682 L .11641 .31085 L p F P
0 g
s
.784 .305 .094 r
.19265 .45711 m .20483 .46286 L .19848 .45481 L p F P
0 g
s
.784 .305 .094 r
.19848 .45481 m .1864 .44904 L .19265 .45711 L p F P
0 g
s
.565 .011 0 r
.29496 .50045 m .2964 .50117 L .31387 .50486 L p F P
0 g
s
.409 0 0 r
.31168 .50654 m .2964 .50117 L .31387 .50486 L p F P
0 g
s
.409 0 0 r
.32124 .50847 m .31168 .50654 L p .31387 .50486 L F P
0 g
s
.409 0 0 r
.31387 .50486 m .32467 .50841 L .32124 .50847 L p F P
0 g
s
.213 0 0 r
.51253 .50454 m .51364 .50432 L .51245 .5046 L closepath p F P
0 g
s
.763 .741 .833 r
.15514 .2874 m .16411 .28081 L .15652 .2726 L p F P
0 g
s
.763 .741 .833 r
.15652 .2726 m .14682 .27968 L .15514 .2874 L p F P
0 g
s
.779 .739 .816 r
.13308 .29088 m .14682 .27968 L .15514 .2874 L p F P
0 g
s
.336 0 0 r
.36186 .51316 m .37161 .5151 L .35725 .51383 L closepath p F P
0 g
s
.633 .728 .917 r
.1944 .27749 m .21687 .27115 L .2243 .27873 L p F P
0 g
s
.626 .724 .917 r
.21687 .27115 m .1944 .27749 L .1869 .26946 L p F P
0 g
s
.709 .737 .873 r
.16411 .28081 m .1869 .26946 L .1944 .27749 L p F P
0 g
s
.029 0 0 r
.51364 .50432 m .51245 .5046 L .50616 .50762 L p F P
0 g
s
.633 .914 .981 r
.50951 .30393 m .50859 .30363 L .53156 .2945 L closepath p F P
0 g
s
.029 0 0 r
.53794 .49864 m .53641 .49939 L .51364 .50432 L closepath p F P
0 g
s
.029 0 0 r
.53152 .5019 m .53641 .49939 L .51364 .50432 L p F P
0 g
s
.029 0 0 r
.51107 .5066 m .53152 .5019 L p .51364 .50432 L F P
0 g
s
.029 0 0 r
.50616 .50762 m .51107 .5066 L p .51364 .50432 L F P
0 g
s
.176 0 .041 r
.63151 .45202 m .62026 .45904 L .61805 .46337 L p F P
0 g
s
.473 .418 .716 r
.7193 .31928 m .70452 .31398 L .69841 .32001 L p F P
0 g
s
.473 .418 .716 r
.70372 .3345 m .7193 .31928 L p .69841 .32001 L F P
0 g
s
.473 .418 .716 r
.69841 .32001 m .7024 .33392 L .70372 .3345 L p F P
0 g
s
.522 .476 .747 r
.69589 .31244 m .70452 .31398 L .69841 .32001 L closepath p F P
0 g
s
.336 .147 .47 r
.70078 .38737 m .68909 .3965 L .68908 .3868 L p F P
0 g
s
.336 .147 .47 r
.68908 .3868 m .70274 .37609 L .70078 .38737 L p F P
0 g
s
.514 .492 .77 r
.69196 .30178 m .69589 .31244 L .70452 .31398 L p F P
0 g
s
.027 0 0 r
.59058 .47903 m .59125 .47848 L .56768 .48699 L p F P
0 g
s
.027 0 0 r
.56768 .48699 m .5665 .48796 L .59058 .47903 L p F P
0 g
s
.88 .708 .664 r
.12055 .35047 m .12309 .34432 L .11563 .33387 L p F P
0 g
s
.706 .737 .875 r
.1869 .26946 m .16411 .28081 L .15652 .2726 L p F P
0 g
s
.165 .608 .936 r
.291 .29632 m .29662 .29732 L .31007 .30288 L p F P
0 g
s
.241 .677 .959 r
.31341 .29989 m .29662 .29732 L .31007 .30288 L p F P
0 g
s
.241 .677 .959 r
.31007 .30288 m .32071 .30372 L .31341 .29989 L p F P
0 g
s
.894 .559 .407 r
.13587 .40586 m .14602 .41254 L .14457 .40299 L p F P
0 g
s
.894 .559 .407 r
.13463 .39748 m .13587 .40586 L p .14457 .40299 L F P
0 g
s
.894 .559 .407 r
.14457 .40299 m .13578 .39719 L .13463 .39748 L p F P
0 g
s
.669 .699 .869 r
.62277 .27629 m .64706 .26757 L .65301 .27668 L p F P
0 g
s
.688 .733 .885 r
.64706 .26757 m .62277 .27629 L .61679 .26935 L p F P
0 g
s
.7 .768 .905 r
.59267 .27974 m .61679 .26935 L .62277 .27629 L p F P
0 g
s
.903 .62 .497 r
.12482 .38936 m .13445 .3963 L .13454 .38625 L p F P
0 g
s
.903 .62 .497 r
.13454 .38625 m .12495 .37929 L .12482 .38936 L p F P
0 g
s
.556 .922 .943 r
.53156 .2945 m .50859 .30363 L .50219 .303 L p F P
0 g
s
.484 .411 .699 r
.7024 .33392 m .70372 .3345 L .70278 .33538 L closepath p F P
0 g
s
.521 .709 .957 r
.2243 .27873 m .23743 .27762 L .24841 .28423 L p F P
0 g
s
.507 .694 .953 r
.23743 .27762 m .2243 .27873 L .21687 .27115 L p F P
0 g
s
.452 .361 .663 r
.71322 .34171 m .70567 .34876 L .70278 .33538 L p F P
0 g
s
.452 .361 .663 r
.70278 .33538 m .70372 .3345 L .71322 .34171 L p F P
0 g
s
.878 .501 .325 r
.14887 .42165 m .15945 .42813 L .15655 .41902 L p F P
0 g
s
.878 .501 .325 r
.15655 .41902 m .14602 .41254 L .14887 .42165 L p F P
0 g
s
.576 .003 0 r
.25008 .48778 m .23945 .481 L .2536 .48593 L p F P
0 g
s
.576 .003 0 r
.25034 .48786 m .25008 .48778 L p .2536 .48593 L F P
0 g
s
.576 .003 0 r
.2536 .48593 m .25794 .48854 L .25034 .48786 L p F P
0 g
s
.237 0 .269 r
.6681 .41895 m .6679 .41994 L .6694 .41809 L closepath p F P
0 g
s
.903 .661 .562 r
.11573 .37214 m .12495 .37929 L .12655 .36874 L p F P
0 g
s
.903 .661 .562 r
.12655 .36874 m .11736 .36157 L .11573 .37214 L p F P
0 g
s
.555 .535 .787 r
.68967 .29609 m .6973 .2962 L .69196 .30178 L closepath p F P
0 g
s
.514 .492 .77 r
.71489 .29807 m .6973 .2962 L .69196 .30178 L p F P
0 g
s
.514 .492 .77 r
.71621 .30203 m .71489 .29807 L p .69196 .30178 L F P
0 g
s
.514 .492 .77 r
.70452 .31398 m .71621 .30203 L p .69196 .30178 L F P
0 g
s
.857 .73 .722 r
.10837 .32371 m .11686 .3313 L .12484 .31847 L p F P
0 g
s
.857 .73 .722 r
.12484 .31847 m .11641 .31085 L .10837 .32371 L p F P
0 g
s
.553 0 0 r
.29496 .50045 m .2964 .50117 L .29378 .50055 L closepath p F P
0 g
s
.111 .555 .916 r
.29662 .29732 m .291 .29632 L .28367 .29087 L p F P
0 g
s
.149 0 0 r
.35776 .3131 m .3637 .31401 L .38459 .31675 L p F P
0 g
s
0 .55 .808 r
.35776 .3131 m .3637 .31401 L .35386 .31194 L closepath p F P
0 g
s
.717 .839 .94 r
.6108 .26334 m .61679 .26935 L .59267 .27974 L p F P
0 g
s
.717 .839 .94 r
.58725 .27449 m .6108 .26334 L p .59267 .27974 L F P
0 g
s
.717 .839 .94 r
.59267 .27974 m .58676 .2749 L .58725 .27449 L p F P
0 g
s
.273 0 .196 r
.6442 .44286 m .63151 .45202 L .64312 .44616 L closepath p F P
0 g
s
.176 0 .041 r
.63995 .4523 m .64312 .44616 L .63151 .45202 L p F P
0 g
s
.176 0 .041 r
.61805 .46337 m .63995 .4523 L p .63151 .45202 L F P
0 g
s
.114 0 0 r
.5058 .5078 m .50616 .50762 L .48238 .51077 L p F P
0 g
s
.114 0 0 r
.48238 .51077 m .47899 .51229 L .5058 .5078 L p F P
0 g
s
.22 .739 .853 r
.44281 .31621 m .42065 .31807 L .41791 .31787 L p F P
0 g
s
0 0 0 r
.41791 .31787 m .44111 .31668 L .42841 .31746 L p F P
0 g
s
.075 .635 .781 r
.41368 .31803 m .42065 .31807 L .41791 .31787 L p F P
0 g
s
0 0 0 r
.42841 .31746 m .41204 .31847 L .41791 .31787 L p F P
0 g
s
.075 .635 .781 r
.41791 .31787 m .40949 .31801 L .41368 .31803 L p F P
0 g
s
.159 .686 .867 r
.41204 .31847 m .41791 .31787 L .40949 .31801 L p F P
0 g
s
.159 .686 .867 r
.40789 .31837 m .41204 .31847 L p .40949 .31801 L F P
0 g
s
.159 .686 .867 r
.40949 .31801 m .38916 .31716 L .38775 .31689 L p F P
0 g
s
.159 .686 .867 r
.38775 .31689 m .40789 .31837 L p .40949 .31801 L F P
0 g
s
.629 .629 .832 r
.68104 .27735 m .6742 .28403 L p .65301 .27668 L F P
0 g
s
.629 .629 .832 r
.65301 .27668 m .67757 .27065 L .68104 .27735 L p F P
0 g
s
.647 .661 .85 r
.67757 .27065 m .65301 .27668 L .64706 .26757 L p F P
0 g
s
.329 0 0 r
.42156 .51678 m .42199 .51663 L p .39187 .51605 L F P
0 g
s
.329 0 0 r
.39187 .51605 m .39573 .51652 L .42156 .51678 L p F P
0 g
s
.299 0 0 r
.39187 .51605 m .39573 .51652 L .39046 .51639 L closepath p F P
0 g
s
.455 .373 .675 r
.72387 .3314 m .71322 .34171 L .70372 .3345 L p F P
0 g
s
.455 .373 .675 r
.72152 .32075 m .72387 .3314 L p .70372 .3345 L F P
0 g
s
.455 .373 .675 r
.70372 .3345 m .7193 .31928 L .72152 .32075 L p F P
0 g
s
.698 .167 0 r
.21287 .47041 m .20483 .46286 L .2175 .46839 L p F P
0 g
s
.698 .167 0 r
.21384 .47082 m .21287 .47041 L p .2175 .46839 L F P
0 g
s
.698 .167 0 r
.2175 .46839 m .22116 .47166 L .21384 .47082 L p F P
0 g
s
.553 .725 .954 r
.24662 .27667 m .23743 .27762 L .24841 .28423 L p F P
0 g
s
.553 .725 .954 r
.24841 .28423 m .25401 .28348 L .24662 .27667 L p F P
0 g
s
.248 0 .279 r
.68699 .41203 m .68833 .40523 L .6694 .41809 L p F P
0 g
s
.248 0 .279 r
.68561 .41386 m .68699 .41203 L p .6694 .41809 L F P
0 g
s
.248 0 .279 r
.66653 .42681 m .68561 .41386 L p .6694 .41809 L F P
0 g
s
.248 0 .279 r
.6694 .41809 m .6679 .41994 L .66653 .42681 L p F P
0 g
s
.605 .609 .828 r
.6742 .28403 m .68104 .27735 L .68358 .28247 L closepath p F P
0 g
s
.834 .41 .23 r
.18506 .44653 m .1864 .44904 L .18186 .44672 L closepath p F P
0 g
s
.292 .005 .294 r
.6679 .41994 m .65518 .43348 L .66653 .42681 L closepath p F P
0 g
s
.572 .545 .786 r
.6973 .2962 m .68967 .29609 L .68358 .28247 L p F P
0 g
s
.847 .421 .217 r
.16378 .43678 m .17484 .44303 L .17043 .43439 L p F P
0 g
s
.847 .421 .217 r
.17043 .43439 m .15945 .42813 L .16378 .43678 L p F P
0 g
s
.074 .626 .824 r
.38916 .31716 m .38775 .31689 L .38459 .31675 L closepath p F P
0 g
s
.37 0 0 r
.29463 .50263 m .31168 .50654 L .2964 .50117 L p F P
0 g
s
.37 0 0 r
.28742 .49992 m .29463 .50263 L p .2964 .50117 L F P
0 g
s
.37 0 0 r
.2964 .50117 m .29378 .50055 L .28742 .49992 L p F P
0 g
s
.88 .708 .664 r
.11563 .33387 m .11176 .34308 L .12055 .35047 L p F P
0 g
s
.897 .692 .618 r
.10853 .3542 m .11736 .36157 L .12055 .35047 L p F P
0 g
s
.897 .692 .618 r
.12055 .35047 m .11176 .34308 L .10853 .3542 L p F P
0 g
s
0 .566 .729 r
.38066 .31639 m .3637 .31401 L .38459 .31675 L p F P
0 g
s
0 .566 .729 r
.38459 .31675 m .38775 .31689 L .38066 .31639 L p F P
0 g
s
.041 0 0 r
.58617 .48281 m .59058 .47903 L .5665 .48796 L p F P
0 g
s
.041 0 0 r
.5665 .48796 m .5625 .49138 L .58617 .48281 L p F P
0 g
s
.188 0 0 r
.45218 .51485 m .45841 .51456 L .45097 .51533 L closepath p F P
0 g
s
.278 0 0 r
.45097 .51533 m .45218 .51485 L p .42199 .51663 L F P
0 g
s
.22 0 .175 r
.65518 .43348 m .6442 .44286 L .64312 .44616 L p F P
0 g
s
.278 0 0 r
.42199 .51663 m .42357 .5167 L .45097 .51533 L p F P
0 g
s
.25 0 0 r
.42199 .51663 m .42357 .5167 L .42156 .51678 L closepath p F P
0 g
s
.428 0 0 r
.29378 .50055 m .28742 .49992 L .28019 .49701 L closepath p F P
0 g
s
.22 0 .175 r
.6642 .43377 m .66653 .42681 L .65518 .43348 L p F P
0 g
s
.22 0 .175 r
.64312 .44616 m .6642 .43377 L p .65518 .43348 L F P
0 g
s
.22 .739 .853 r
.44111 .31668 m .44143 .31665 L p .44281 .31621 L F P
0 g
s
.22 .739 .853 r
.41791 .31787 m .44111 .31668 L p .44281 .31621 L F P
0 g
s
.387 .233 .547 r
.70841 .37151 m .70274 .37609 L .70079 .36619 L p F P
0 g
s
.387 .233 .547 r
.70079 .36619 m .7075 .36074 L .70841 .37151 L p F P
0 g
s
.04 0 0 r
.42357 .5167 m .42156 .51678 L .4151 .51742 L p F P
0 g
s
.133 0 0 r
.42156 .51678 m .4151 .51742 L .39573 .51652 L closepath p F P
0 g
s
.076 0 0 r
.45097 .51533 m .44545 .5162 L .42357 .5167 L closepath p F P
0 g
s
.04 0 0 r
.44215 .51672 m .44545 .5162 L .42357 .5167 L p F P
0 g
s
.04 0 0 r
.4255 .51736 m .44215 .51672 L p .42357 .5167 L F P
0 g
s
.04 0 0 r
.4151 .51742 m .4255 .51736 L p .42357 .5167 L F P
0 g
s
.352 .828 .831 r
.50073 .30323 m .50219 .303 L .4784 .31047 L p F P
0 g
s
.352 .828 .831 r
.4784 .31047 m .476 .31071 L .50073 .30323 L p F P
0 g
s
.088 0 0 r
.4121 .51772 m .4151 .51742 L .39573 .51652 L p F P
0 g
s
.088 0 0 r
.39691 .51736 m .4121 .51772 L p .39573 .51652 L F P
0 g
s
.088 0 0 r
.38481 .51657 m .39691 .51736 L p .39573 .51652 L F P
0 g
s
.088 0 0 r
.39573 .51652 m .39046 .51639 L .38481 .51657 L p F P
0 g
s
.175 0 0 r
.39046 .51639 m .38481 .51657 L .37161 .5151 L closepath p F P
0 g
s
.404 .289 .608 r
.71867 .35038 m .7075 .36074 L .70567 .34876 L p F P
0 g
s
.404 .289 .608 r
.70567 .34876 m .71322 .34171 L .71867 .35038 L p F P
0 g
s
.725 .88 .953 r
.58662 .27479 m .56258 .28602 L .55643 .28309 L p F P
0 g
s
.693 .905 .971 r
.53244 .29415 m .55643 .28309 L .56258 .28602 L p F P
0 g
s
.776 .283 .041 r
.18094 .45114 m .19265 .45711 L .1864 .44904 L p F P
0 g
s
.776 .283 .041 r
.17693 .4458 m .18094 .45114 L p .1864 .44904 L F P
0 g
s
.776 .283 .041 r
.1864 .44904 m .18186 .44672 L .17693 .4458 L p F P
0 g
s
.339 0 0 r
.40789 .31837 m .38775 .31689 L .38066 .31639 L p F P
0 g
s
.333 .672 .976 r
.28166 .28933 m .28367 .29087 L p .25401 .28348 L F P
0 g
s
.333 .672 .976 r
.25401 .28348 m .2724 .28502 L .28166 .28933 L p F P
0 g
s
.307 .642 .967 r
.2724 .28502 m .25401 .28348 L .24662 .27667 L p F P
0 g
s
.877 .72 .684 r
.108 .32447 m .10837 .32371 L .11686 .3313 L p F P
0 g
s
.877 .72 .684 r
.11686 .3313 m .11563 .33387 L .108 .32447 L p F P
0 g
s
.565 0 0 r
.25794 .48854 m .2648 .49253 L .25034 .48786 L closepath p F P
0 g
s
0 0 0 r
.56048 .4924 m .5625 .49138 L .53794 .49864 L p F P
0 g
s
0 0 0 r
.53794 .49864 m .53641 .49939 L .56048 .4924 L p F P
0 g
s
.78 .745 .821 r
.14682 .27968 m .13308 .29088 L .12537 .28273 L p F P
0 g
s
.818 .746 .785 r
.12755 .29682 m .13308 .29088 L .12537 .28273 L p F P
0 g
s
0 0 0 r
.45841 .51456 m .45097 .51533 L .44545 .5162 L p F P
0 g
s
.111 .555 .916 r
.28367 .29087 m .2847 .29113 L .29662 .29732 L p F P
0 g
s
.145 .616 .925 r
.30106 .29495 m .2847 .29113 L .29662 .29732 L p F P
0 g
s
.145 .616 .925 r
.31135 .29881 m .30106 .29495 L p .29662 .29732 L F P
0 g
s
.145 .616 .925 r
.29662 .29732 m .31341 .29989 L .31135 .29881 L p F P
0 g
s
.003 .558 .817 r
.37935 .31645 m .38066 .31639 L .3637 .31401 L p F P
0 g
s
.003 .558 .817 r
.36262 .31402 m .37935 .31645 L p .3637 .31401 L F P
0 g
s
.003 .558 .817 r
.3637 .31401 m .35386 .31194 L .35058 .31095 L p F P
0 g
s
.003 .558 .817 r
.35058 .31095 m .36262 .31402 L p .3637 .31401 L F P
0 g
s
.49 .432 .719 r
.7208 .31776 m .7193 .31928 L .70452 .31398 L p F P
0 g
s
.49 .432 .719 r
.70452 .31398 m .71621 .30203 L .7208 .31776 L p F P
0 g
s
.123 0 0 r
.38015 .51669 m .38481 .51657 L .37161 .5151 L p F P
0 g
s
.123 0 0 r
.3723 .51603 m .38015 .51669 L p .37161 .5151 L F P
0 g
s
.123 0 0 r
.35465 .51372 m .3723 .51603 L p .37161 .5151 L F P
0 g
s
.123 0 0 r
.37161 .5151 m .35725 .51383 L .35465 .51372 L p F P
0 g
s
.818 .746 .785 r
.12537 .28273 m .11959 .28892 L .12755 .29682 L p F P
0 g
s
.837 .745 .762 r
.10838 .30299 m .11641 .31085 L .12755 .29682 L p F P
0 g
s
.837 .745 .762 r
.12755 .29682 m .11959 .28892 L .10838 .30299 L p F P
0 g
s
.886 .717 .667 r
.11176 .34308 m .11563 .33387 L .108 .32447 L p F P
0 g
s
.695 .162 0 r
.22116 .47166 m .22588 .47583 L .21384 .47082 L closepath p F P
0 g
s
.897 .567 .414 r
.13578 .39719 m .13463 .39748 L .13445 .3963 L closepath p F P
0 g
s
.007 0 0 r
.47899 .51229 m .47582 .51292 L .45841 .51456 L closepath p F P
0 g
s
0 0 0 r
.47065 .51398 m .47582 .51292 L .45841 .51456 L p F P
0 g
s
0 0 0 r
.46155 .51491 m .47065 .51398 L p .45841 .51456 L F P
0 g
s
0 0 0 r
.44545 .5162 m .46155 .51491 L p .45841 .51456 L F P
0 g
s
.587 .014 0 r
.23628 .48266 m .25008 .48778 L .23945 .481 L p F P
0 g
s
.587 .014 0 r
.23945 .481 m .22588 .47583 L .23628 .48266 L p F P
0 g
s
.764 .745 .835 r
.14682 .27968 m .15652 .2726 L .14887 .26447 L p F P
0 g
s
.764 .745 .835 r
.14887 .26447 m .1389 .27172 L .14682 .27968 L p F P
0 g
s
.78 .745 .821 r
.12537 .28273 m .1389 .27172 L .14682 .27968 L p F P
0 g
s
.572 .545 .786 r
.70941 .2832 m .6973 .2962 L p .68358 .28247 L F P
0 g
s
.572 .545 .786 r
.68358 .28247 m .70862 .28123 L .70941 .2832 L p F P
0 g
s
.566 .589 .835 r
.68104 .27735 m .68358 .28247 L .70862 .28123 L p F P
0 g
s
.533 .504 .769 r
.6973 .2962 m .70941 .2832 L .71489 .29807 L closepath p F P
0 g
s
.626 .724 .917 r
.1869 .26946 m .20939 .26341 L .21687 .27115 L p F P
0 g
s
.622 .719 .915 r
.20939 .26341 m .1869 .26946 L .17935 .2614 L p F P
0 g
s
.706 .737 .875 r
.15652 .2726 m .17935 .2614 L .1869 .26946 L p F P
0 g
s
.261 .036 .372 r
.69512 .39995 m .68833 .40523 L .68909 .3965 L p F P
0 g
s
.261 .036 .372 r
.68909 .3965 m .70078 .38737 L .69512 .39995 L p F P
0 g
s
.203 0 0 r
.35725 .51383 m .35465 .51372 L .34979 .51289 L closepath p F P
0 g
s
.79 .306 .066 r
.18186 .44672 m .17693 .4458 L .17484 .44303 L closepath p F P
0 g
s
.418 0 0 r
.27847 .49839 m .2648 .49253 L .28019 .49701 L p F P
0 g
s
.418 0 0 r
.28112 .49914 m .27847 .49839 L p .28019 .49701 L F P
0 g
s
.418 0 0 r
.28019 .49701 m .28742 .49992 L .28112 .49914 L p F P
0 g
s
0 .44 .72 r
.32071 .30372 m .32903 .30581 L .34547 .31026 L p F P
0 g
s
0 .376 .706 r
.32903 .30581 m .32071 .30372 L .31341 .29989 L p F P
0 g
s
.904 .572 .407 r
.12602 .39833 m .12482 .38936 L .13445 .3963 L p F P
0 g
s
.904 .572 .407 r
.13445 .3963 m .13463 .39748 L .12602 .39833 L p F P
0 g
s
.375 0 0 r
.32467 .50841 m .33001 .50997 L .32124 .50847 L closepath p F P
0 g
s
.016 0 0 r
.63895 .45353 m .63995 .4523 L .61805 .46337 L p F P
0 g
s
.016 0 0 r
.61805 .46337 m .61475 .46764 L .63895 .45353 L p F P
0 g
s
.913 .629 .493 r
.11556 .38222 m .12482 .38936 L .12495 .37929 L p F P
0 g
s
.913 .629 .493 r
.12495 .37929 m .11573 .37214 L .11556 .38222 L p F P
0 g
s
.022 .573 .828 r
.35386 .31194 m .35058 .31095 L .34547 .31026 L closepath p F P
0 g
s
.705 .736 .875 r
.17935 .2614 m .15652 .2726 L .14887 .26447 L p F P
0 g
s
.077 0 0 r
.6631 .4358 m .6642 .43377 L .64312 .44616 L p F P
0 g
s
.077 0 0 r
.64669 .44833 m .6631 .4358 L p .64312 .44616 L F P
0 g
s
.077 0 0 r
.64312 .44616 m .63995 .4523 L .64669 .44833 L p F P
0 g
s
.886 .506 .311 r
.13869 .41497 m .14887 .42165 L .14602 .41254 L p F P
0 g
s
.886 .506 .311 r
.14602 .41254 m .13587 .40586 L .13869 .41497 L p F P
0 g
s
.71 .178 0 r
.20054 .4647 m .21287 .47041 L .20483 .46286 L p F P
0 g
s
.71 .178 0 r
.20483 .46286 m .19265 .45711 L .20054 .4647 L p F P
0 g
s
.194 0 0 r
.3474 .51329 m .33001 .50997 L .34979 .51289 L p F P
0 g
s
.194 0 0 r
.34979 .51289 m .35465 .51372 L .3474 .51329 L p F P
0 g
s
.904 .575 .414 r
.13587 .40586 m .13463 .39748 L .12602 .39833 L p F P
0 g
s
.563 .923 .948 r
.53244 .29415 m .53156 .2945 L .53241 .29415 L closepath p F P
0 g
s
.556 .922 .943 r
.52615 .29322 m .53241 .29415 L .53156 .2945 L p F P
0 g
s
.556 .922 .943 r
.50219 .303 m .52615 .29322 L p .53156 .2945 L F P
0 g
s
.911 .67 .56 r
.10686 .36478 m .11573 .37214 L .11736 .36157 L p F P
0 g
s
.911 .67 .56 r
.11736 .36157 m .10853 .3542 L .10686 .36478 L p F P
0 g
s
.507 .694 .953 r
.21687 .27115 m .22753 .27053 L .23743 .27762 L p F P
0 g
s
.535 .712 .953 r
.23918 .26961 m .22753 .27053 L .23743 .27762 L p F P
0 g
s
.535 .712 .953 r
.23743 .27762 m .24662 .27667 L .23918 .26961 L p F P
0 g
s
.629 .946 .947 r
.55409 .28246 m .55643 .28309 L .53244 .29415 L p F P
0 g
s
.629 .946 .947 r
.53244 .29415 m .53241 .29415 L .55409 .28246 L p F P
0 g
s
.65 .95 .95 r
.55024 .28135 m .55409 .28246 L .53241 .29415 L p F P
0 g
s
.65 .95 .95 r
.53241 .29415 m .52615 .29322 L .55024 .28135 L p F P
0 g
s
.601 .616 .839 r
.67757 .27065 m .68799 .26903 L .68104 .27735 L closepath p F P
0 g
s
.566 .589 .835 r
.7025 .26729 m .68799 .26903 L .68104 .27735 L p F P
0 g
s
.566 .589 .835 r
.70862 .28123 m .7025 .26729 L p .68104 .27735 L F P
0 g
s
.862 .739 .725 r
.1003 .31589 m .10837 .32371 L .11641 .31085 L p F P
0 g
s
.862 .739 .725 r
.11641 .31085 m .10838 .30299 L .1003 .31589 L p F P
0 g
s
0 0 0 r
.49971 .5092 m .5058 .5078 L .47899 .51229 L p F P
0 g
s
0 0 0 r
.47899 .51229 m .47582 .51292 L .49971 .5092 L p F P
0 g
s
.647 .661 .85 r
.64706 .26757 m .6716 .2602 L .67757 .27065 L p F P
0 g
s
.667 .694 .866 r
.6716 .2602 m .64706 .26757 L .6411 .25948 L p F P
0 g
s
.688 .733 .885 r
.61679 .26935 m .6411 .25948 L .64706 .26757 L p F P
0 g
s
.707 .767 .899 r
.6411 .25948 m .61679 .26935 L .6108 .26334 L p F P
0 g
s
0 0 0 r
.55624 .49464 m .56048 .4924 L .53641 .49939 L p F P
0 g
s
0 0 0 r
.53641 .49939 m .53152 .5019 L .55624 .49464 L p F P
0 g
s
.497 .682 .949 r
.22753 .27053 m .21687 .27115 L .20939 .26341 L p F P
0 g
s
.854 .423 .199 r
.15315 .43032 m .16378 .43678 L .15945 .42813 L p F P
0 g
s
.854 .423 .199 r
.15945 .42813 m .14887 .42165 L .15315 .43032 L p F P
0 g
s
0 0 0 r
.59125 .47848 m .59058 .47903 L .60183 .47392 L closepath p F P
0 g
s
.346 .203 .54 r
.72048 .36037 m .70841 .37151 L .7075 .36074 L p F P
0 g
s
.346 .203 .54 r
.7075 .36074 m .71867 .35038 L .72048 .36037 L p F P
0 g
s
0 .553 .794 r
.34331 .30911 m .32903 .30581 L .34547 .31026 L p F P
0 g
s
0 .553 .794 r
.34547 .31026 m .35058 .31095 L .34331 .30911 L p F P
0 g
s
.886 .717 .667 r
.108 .32447 m .10332 .33548 L .11176 .34308 L p F P
0 g
s
.905 .702 .618 r
.10005 .34662 m .10853 .3542 L .11176 .34308 L p F P
0 g
s
.905 .702 .618 r
.11176 .34308 m .10332 .33548 L .10005 .34662 L p F P
0 g
s
.123 0 .122 r
.67007 .4298 m .6642 .43377 L .66653 .42681 L p F P
0 g
s
.123 0 .122 r
.66653 .42681 m .68561 .41386 L .67007 .4298 L p F P
0 g
s
.323 .136 .465 r
.70847 .38119 m .70078 .38737 L .70274 .37609 L p F P
0 g
s
.323 .136 .465 r
.70274 .37609 m .70841 .37151 L .70847 .38119 L p F P
0 g
s
0 0 0 r
.60183 .47392 m .59058 .47903 L .58617 .48281 L p F P
0 g
s
.153 .563 .929 r
.28367 .29087 m .2847 .29113 L .28166 .28933 L closepath p F P
0 g
s
.79 .301 .045 r
.16883 .44377 m .16378 .43678 L .17484 .44303 L p F P
0 g
s
.79 .301 .045 r
.17484 .44303 m .17693 .4458 L .16883 .44377 L p F P
0 g
s
.716 .837 .939 r
.58676 .2749 m .58662 .27479 L .58725 .27449 L closepath p F P
0 g
s
.711 .877 .959 r
.58725 .27449 m .58662 .27479 L .58055 .2709 L p F P
0 g
s
.725 .88 .953 r
.55643 .28309 m .58055 .2709 L .58662 .27479 L p F P
0 g
s
.154 0 0 r
.34574 .51316 m .3474 .51329 L .33001 .50997 L p F P
0 g
s
.154 0 0 r
.33081 .51072 m .34574 .51316 L p .33001 .50997 L F P
0 g
s
.154 0 0 r
.31728 .50788 m .33081 .51072 L p .33001 .50997 L F P
0 g
s
.154 0 0 r
.33001 .50997 m .32124 .50847 L .31728 .50788 L p F P
0 g
s
.198 0 0 r
.3723 .51603 m .35465 .51372 L .3474 .51329 L p F P
0 g
s
.717 .838 .939 r
.6108 .26334 m .58725 .27449 L .60564 .25897 L closepath p F P
0 g
s
.711 .877 .959 r
.60479 .25825 m .60564 .25897 L .58725 .27449 L p F P
0 g
s
.711 .877 .959 r
.58055 .2709 m .60479 .25825 L p .58725 .27449 L F P
0 g
s
.397 .287 .61 r
.72581 .34351 m .71867 .35038 L .71322 .34171 L p F P
0 g
s
.397 .287 .61 r
.71322 .34171 m .72387 .3314 L .72581 .34351 L p F P
0 g
s
.153 .563 .93 r
.28837 .28896 m .30106 .29495 L .2847 .29113 L p F P
0 g
s
.153 .563 .93 r
.2763 .28525 m .28837 .28896 L p .2847 .29113 L F P
0 g
s
.153 .563 .93 r
.2847 .29113 m .28166 .28933 L .2763 .28525 L p F P
0 g
s
.542 0 0 r
.22308 .47729 m .23628 .48266 L .22588 .47583 L p F P
0 g
s
.542 0 0 r
.21324 .47066 m .22308 .47729 L p .22588 .47583 L F P
0 g
s
.542 0 0 r
.22588 .47583 m .21384 .47082 L .21324 .47066 L p F P
0 g
s
.617 .621 .833 r
.68799 .26903 m .67757 .27065 L .6716 .2602 L p F P
0 g
s
.37 0 0 r
.26343 .49371 m .27847 .49839 L .2648 .49253 L p F P
0 g
s
.37 0 0 r
.2502 .48783 m .26343 .49371 L p .2648 .49253 L F P
0 g
s
.37 0 0 r
.2648 .49253 m .25034 .48786 L .2502 .48783 L p F P
0 g
s
.883 .731 .688 r
.10021 .31606 m .1003 .31589 L .10837 .32371 L p F P
0 g
s
.883 .731 .688 r
.10837 .32371 m .108 .32447 L .10021 .31606 L p F P
0 g
s
.048 0 0 r
.50616 .50762 m .51107 .5066 L .5058 .5078 L closepath p F P
0 g
s
.413 0 0 r
.36262 .31402 m .35058 .31095 L .34331 .30911 L p F P
0 g
s
.227 0 0 r
.32124 .50847 m .31728 .50788 L .31168 .50654 L closepath p F P
0 g
s
.893 .727 .668 r
.10332 .33548 m .108 .32447 L .10021 .31606 L p F P
0 g
s
0 0 0 r
.5847 .48354 m .58617 .48281 L .5625 .49138 L p F P
0 g
s
0 0 0 r
.5625 .49138 m .56048 .4924 L .5847 .48354 L p F P
0 g
s
.442 .878 .836 r
.52383 .29344 m .52615 .29322 L .50219 .303 L p F P
0 g
s
.442 .878 .836 r
.50219 .303 m .50073 .30323 L .52383 .29344 L p F P
0 g
s
.393 0 0 r
.28742 .49992 m .29463 .50263 L .28112 .49914 L closepath p F P
0 g
s
.366 .684 .979 r
.28166 .28933 m .2763 .28525 L .2724 .28502 L closepath p F P
0 g
s
.307 .642 .967 r
.24662 .27667 m .26098 .27853 L .2724 .28502 L p F P
0 g
s
.293 .616 .957 r
.26098 .27853 m .24662 .27667 L .23918 .26961 L p F P
0 g
s
0 0 0 r
.51107 .5066 m .5058 .5078 L .49971 .5092 L p F P
0 g
s
.164 0 0 r
.32907 .30525 m .31496 .30044 L .32903 .30581 L p F P
0 g
s
.164 0 0 r
.32903 .30581 m .34331 .30911 L .34157 .30872 L p F P
0 g
s
.164 0 0 r
.34157 .30872 m .32907 .30525 L p .32903 .30581 L F P
0 g
s
0 .376 .706 r
.31341 .29989 m .31496 .30044 L .32903 .30581 L p F P
0 g
s
.708 .171 0 r
.18871 .45875 m .20054 .4647 L .19265 .45711 L p F P
0 g
s
.708 .171 0 r
.19265 .45711 m .18094 .45114 L .18871 .45875 L p F P
0 g
s
.112 0 0 r
.61475 .46764 m .60183 .47392 L .61399 .46865 L closepath p F P
0 g
s
0 0 0 r
.60904 .47282 m .61399 .46865 L .60183 .47392 L p F P
0 g
s
0 0 0 r
.6079 .47335 m .60904 .47282 L p .60183 .47392 L F P
0 g
s
0 0 0 r
.58617 .48281 m .6079 .47335 L p .60183 .47392 L F P
0 g
s
.798 .317 .068 r
.18094 .45114 m .17693 .4458 L .16883 .44377 L p F P
0 g
s
.11 0 0 r
.38481 .51657 m .39691 .51736 L .38015 .51669 L closepath p F P
0 g
s
.913 .583 .405 r
.11679 .39184 m .11556 .38222 L .12482 .38936 L p F P
0 g
s
.913 .583 .405 r
.12517 .39825 m .11679 .39184 L p .12482 .38936 L F P
0 g
s
.913 .583 .405 r
.12482 .38936 m .12602 .39833 L .12517 .39825 L p F P
0 g
s
.622 .719 .915 r
.17935 .2614 m .20186 .2555 L .20939 .26341 L p F P
0 g
s
.621 .714 .913 r
.20186 .2555 m .17935 .2614 L .17175 .25327 L p F P
0 g
s
.705 .736 .875 r
.14887 .26447 m .17175 .25327 L .17935 .2614 L p F P
0 g
s
.904 .575 .414 r
.12602 .39833 m .1261 .39896 L .13587 .40586 L p F P
0 g
s
.894 .51 .296 r
.12891 .40808 m .13869 .41497 L .13587 .40586 L p F P
0 g
s
.894 .51 .296 r
.13587 .40586 m .1261 .39896 L .12891 .40808 L p F P
0 g
s
.922 .639 .488 r
.10666 .37487 m .11556 .38222 L .11573 .37214 L p F P
0 g
s
.922 .639 .488 r
.11573 .37214 m .10686 .36478 L .10666 .37487 L p F P
0 g
s
0 0 0 r
.52383 .50384 m .53016 .50223 L .52948 .50239 L p F P
0 g
s
0 0 0 r
.52948 .50239 m .51107 .5066 L p .52383 .50384 L F P
0 g
s
.22 .734 .704 r
.52383 .50384 m .52444 .50367 L .52382 .50385 L p F P
0 g
s
.22 .734 .704 r
.52382 .50385 m .52381 .50385 L .52383 .50384 L p F P
0 g
s
.205 .721 .686 r
.53016 .50223 m .52383 .50384 L p .52519 .50345 L F P
0 g
s
0 0 0 r
.53016 .50223 m .51107 .5066 L .53126 .50196 L p F P
0 g
s
.205 .721 .686 r
.55436 .4951 m .53016 .50223 L p .52519 .50345 L F P
0 g
s
0 0 0 r
.53126 .50196 m .53152 .5019 L .53016 .50223 L p F P
0 g
s
0 0 0 r
.49971 .5092 m .52383 .50384 L p .51107 .5066 L F P
0 g
s
.212 0 0 r
.30984 .50661 m .29463 .50263 L .31168 .50654 L p F P
0 g
s
.212 0 0 r
.31168 .50654 m .31728 .50788 L .30984 .50661 L p F P
0 g
s
0 0 0 r
.49782 .50965 m .49971 .5092 L .47582 .51292 L p F P
0 g
s
0 0 0 r
.47582 .51292 m .47065 .51398 L .49782 .50965 L p F P
0 g
s
.163 0 .242 r
.68833 .40523 m .68699 .41203 L .69512 .39995 L closepath p F P
0 g
s
.497 .682 .949 r
.20939 .26341 m .21843 .26306 L .22753 .27053 L p F P
0 g
s
.522 .698 .95 r
.2317 .26225 m .21843 .26306 L .22753 .27053 L p F P
0 g
s
.522 .698 .95 r
.22753 .27053 m .23918 .26961 L .2317 .26225 L p F P
0 g
s
.274 .099 .453 r
.71896 .37156 m .70847 .38119 L .70841 .37151 L p F P
0 g
s
.274 .099 .453 r
.70841 .37151 m .72048 .36037 L .71896 .37156 L p F P
0 g
s
.714 .95 .953 r
.57445 .26801 m .58055 .2709 L .55643 .28309 L p F P
0 g
s
.714 .95 .953 r
.57097 .26993 m .57445 .26801 L p .55643 .28309 L F P
0 g
s
.714 .95 .953 r
.55643 .28309 m .55409 .28246 L .57097 .26993 L p F P
0 g
s
.062 0 0 r
.4151 .51742 m .4255 .51736 L .4121 .51772 L closepath p F P
0 g
s
.86 .425 .179 r
.14292 .42365 m .15315 .43032 L .14887 .42165 L p F P
0 g
s
.86 .425 .179 r
.14887 .42165 m .13869 .41497 L .14292 .42365 L p F P
0 g
s
.92 .68 .558 r
.09835 .35722 m .10686 .36478 L .10853 .3542 L p F P
0 g
s
.92 .68 .558 r
.10853 .3542 m .10005 .34662 L .09835 .35722 L p F P
0 g
s
.001 0 0 r
.44545 .5162 m .46155 .51491 L .44215 .51672 L closepath p F P
0 g
s
.465 .891 .851 r
.51979 .29371 m .52383 .29344 L .50073 .30323 L p F P
0 g
s
.465 .891 .851 r
.50073 .30323 m .49571 .30388 L .51979 .29371 L p F P
0 g
s
.242 .018 .36 r
.70772 .38986 m .69512 .39995 L .70078 .38737 L p F P
0 g
s
.242 .018 .36 r
.70078 .38737 m .70847 .38119 L .70772 .38986 L p F P
0 g
s
.667 .694 .866 r
.6411 .25948 m .66564 .25081 L .6716 .2602 L p F P
0 g
s
.686 .726 .88 r
.66564 .25081 m .6411 .25948 L .63515 .2523 L p F P
0 g
s
.707 .767 .899 r
.6108 .26334 m .63515 .2523 L .6411 .25948 L p F P
0 g
s
.617 .621 .833 r
.69776 .25753 m .68799 .26903 L p .6716 .2602 L F P
0 g
s
.59 .598 .828 r
.68799 .26903 m .69776 .25753 L .7025 .26729 L closepath p F P
0 g
s
.417 0 0 r
.25034 .48786 m .2502 .48783 L .25008 .48778 L closepath p F P
0 g
s
.493 .672 .944 r
.21843 .26306 m .20939 .26341 L .20186 .2555 L p F P
0 g
s
.451 .374 .679 r
.7193 .31928 m .7208 .31776 L .72152 .32075 L closepath p F P
0 g
s
.398 0 0 r
.24248 .48566 m .23628 .48266 L .25008 .48778 L p F P
0 g
s
.398 0 0 r
.25008 .48778 m .2502 .48783 L .24248 .48566 L p F P
0 g
s
.426 0 0 r
.26343 .49371 m .2502 .48783 L .24248 .48566 L p F P
0 g
s
.575 0 0 r
.21384 .47082 m .21324 .47066 L .21287 .47041 L closepath p F P
0 g
s
.026 0 0 r
.6359 .45744 m .63895 .45353 L .61475 .46764 L p F P
0 g
s
.026 0 0 r
.61475 .46764 m .61399 .46865 L .6359 .45744 L p F P
0 g
s
.462 .415 .719 r
.73161 .30507 m .7208 .31776 L .71621 .30203 L p F P
0 g
s
.462 .415 .719 r
.71621 .30203 m .71868 .2991 L .73161 .30507 L p F P
0 g
s
.495 .462 .75 r
.71489 .29807 m .71868 .2991 L .71621 .30203 L closepath p F P
0 g
s
.339 0 0 r
.38066 .31639 m .38339 .31689 L .40789 .31837 L p F P
0 g
s
.256 0 0 r
.38066 .31639 m .38339 .31689 L .37935 .31645 L closepath p F P
0 g
s
.798 .309 .036 r
.15892 .43853 m .15315 .43032 L .16378 .43678 L p F P
0 g
s
.798 .309 .036 r
.16629 .44295 m .15892 .43853 L p .16378 .43678 L F P
0 g
s
.798 .309 .036 r
.16378 .43678 m .16883 .44377 L .16629 .44295 L p F P
0 g
s
.377 .68 .977 r
.26888 .27933 m .26098 .27853 L .2724 .28502 L p F P
0 g
s
.377 .68 .977 r
.2724 .28502 m .2763 .28525 L .26888 .27933 L p F P
0 g
s
.484 .475 .771 r
.70941 .2832 m .71489 .29807 L .71868 .2991 L p F P
0 g
s
.56 0 0 r
.20536 .46811 m .20054 .4647 L .21287 .47041 L p F P
0 g
s
.56 0 0 r
.21287 .47041 m .21324 .47066 L .20536 .46811 L p F P
0 g
s
0 .422 .784 r
.31341 .29989 m .31496 .30044 L .31135 .29881 L closepath p F P
0 g
s
.893 .727 .668 r
.10021 .31606 m .09524 .32767 L .10332 .33548 L p F P
0 g
s
.912 .712 .619 r
.09193 .33883 m .10005 .34662 L .10332 .33548 L p F P
0 g
s
.912 .712 .619 r
.10332 .33548 m .09524 .32767 L .09193 .33883 L p F P
0 g
s
0 0 0 r
.44111 .31668 m .41204 .31847 L .41095 .31857 L p F P
0 g
s
.144 0 0 r
.41204 .31847 m .41095 .31857 L .40789 .31837 L closepath p F P
0 g
s
0 0 0 r
.5847 .48354 m .56048 .4924 L p .57987 .48604 L F P
0 g
s
0 0 0 r
.56048 .4924 m .55624 .49464 L .58001 .48599 L p F P
0 g
s
.318 .801 .752 r
.55436 .4951 m .57871 .48631 L p .55829 .49388 L F P
0 g
s
.318 .801 .752 r
.55624 .49464 m .5561 .49467 L p .55829 .49388 L F P
0 g
s
.318 .801 .752 r
.5561 .49467 m .55436 .4951 L p .55829 .49388 L F P
0 g
s
0 0 0 r
.58001 .48599 m .58004 .48598 L p .57987 .48604 L F P
0 g
s
0 0 0 r
.58004 .48598 m .5847 .48354 L p .57987 .48604 L F P
0 g
s
.237 0 0 r
.40228 .32018 m .38339 .31689 L .40789 .31837 L p F P
0 g
s
.237 0 0 r
.40451 .32029 m .40228 .32018 L p .40789 .31837 L F P
0 g
s
.237 0 0 r
.40789 .31837 m .41095 .31857 L .40451 .32029 L p F P
0 g
s
.584 .008 0 r
.22308 .47729 m .21324 .47066 L .20536 .46811 L p F P
0 g
s
.729 .841 .933 r
.62918 .24593 m .63515 .2523 L .6108 .26334 L p F P
0 g
s
.729 .841 .933 r
.60783 .25673 m .62918 .24593 L p .6108 .26334 L F P
0 g
s
.729 .841 .933 r
.6108 .26334 m .60564 .25897 L .60783 .25673 L p F P
0 g
s
.617 .621 .833 r
.6716 .2602 m .69647 .25499 L .69776 .25753 L p F P
0 g
s
.636 .65 .847 r
.69647 .25499 m .6716 .2602 L .66564 .25081 L p F P
0 g
s
.394 .336 .674 r
.74027 .31261 m .73161 .30507 L .7208 .31776 L p F P
0 g
s
.394 .336 .674 r
.72803 .32678 m .74027 .31261 L p .7208 .31776 L F P
0 g
s
.394 .336 .674 r
.7208 .31776 m .72152 .32075 L .72803 .32678 L p F P
0 g
s
0 0 0 r
.63995 .4523 m .63895 .45353 L .64669 .44833 L closepath p F P
0 g
s
0 .425 .787 r
.31475 .29989 m .32907 .30525 L .31496 .30044 L p F P
0 g
s
0 .425 .787 r
.31496 .30044 m .30755 .29674 L .31475 .29989 L F
.31496 .30044 m .31135 .29881 L .30604 .29598 L p F P
0 g
s
.386 0 0 r
.3133 .29979 m .32432 .30408 L p .31475 .29989 L F P
0 g
s
.386 0 0 r
.32432 .30408 m .32745 .3053 L .31475 .29989 L p F P
0 g
s
0 .425 .787 r
.30604 .29598 m .31475 .29989 L p .30755 .29674 L F P
0 g
s
.221 0 0 r
.33081 .51072 m .31728 .50788 L .30984 .50661 L p F P
0 g
s
.415 .338 .662 r
.72152 .32075 m .72803 .32678 L .72387 .3314 L closepath p F P
0 g
s
0 .425 .696 r
.30789 .50623 m .30984 .50661 L .29463 .50263 L p F P
0 g
s
0 .425 .696 r
.29558 .50318 m .30789 .50623 L p .29463 .50263 L F P
0 g
s
0 .425 .696 r
.29463 .50263 m .28112 .49914 L .27984 .4988 L p F P
0 g
s
0 .425 .696 r
.27984 .4988 m .29558 .50318 L p .29463 .50263 L F P
0 g
s
.533 .523 .79 r
.70862 .28123 m .7108 .28141 L .70941 .2832 L closepath p F P
0 g
s
.484 .475 .771 r
.72993 .28511 m .7108 .28141 L .70941 .2832 L p F P
0 g
s
.484 .475 .771 r
.71868 .2991 m .72993 .28511 L p .70941 .2832 L F P
0 g
s
.246 0 0 r
.37881 .31825 m .40228 .32018 L .38339 .31689 L p F P
0 g
s
.246 0 0 r
.37347 .31663 m .37881 .31825 L p .38339 .31689 L F P
0 g
s
.246 0 0 r
.38339 .31689 m .37935 .31645 L .37347 .31663 L p F P
0 g
s
0 0 0 r
.63343 .4594 m .6359 .45744 L .61399 .46865 L p F P
0 g
s
0 0 0 r
.61399 .46865 m .60904 .47282 L .63343 .4594 L p F P
0 g
s
.021 0 0 r
.44143 .31665 m .44137 .31666 L .44111 .31668 L closepath p F P
0 g
s
0 0 0 r
.4347 .31918 m .44137 .31666 L .44111 .31668 L p F P
0 g
s
0 0 0 r
.43362 .31924 m .4347 .31918 L p .44111 .31668 L F P
0 g
s
0 0 0 r
.41095 .31857 m .43362 .31924 L p .44111 .31668 L F P
0 g
s
.102 .655 .702 r
.46513 .31324 m .46864 .31213 L .44143 .31665 L p F P
0 g
s
.102 .655 .702 r
.44143 .31665 m .44137 .31666 L .46513 .31324 L p F P
0 g
s
.335 .196 .539 r
.72679 .35433 m .72048 .36037 L .71867 .35038 L p F P
0 g
s
.335 .196 .539 r
.71867 .35038 m .72581 .34351 L .72679 .35433 L p F P
0 g
s
.547 .548 .807 r
.7108 .28141 m .70862 .28123 L .7025 .26729 L p F P
0 g
s
.081 0 0 r
.46232 .31493 m .46513 .31324 L .44137 .31666 L p F P
0 g
s
.081 0 0 r
.44137 .31666 m .4347 .31918 L .46232 .31493 L p F P
0 g
s
.314 0 0 r
.37935 .31645 m .37347 .31663 L .36262 .31402 L closepath p F P
0 g
s
.197 0 0 r
.41095 .31857 m .43362 .31924 L .40451 .32029 L closepath p F P
0 g
s
.237 .747 .72 r
.55436 .4951 m .55624 .49464 L .53152 .5019 L p F P
0 g
s
.237 .747 .72 r
.53152 .5019 m .53016 .50223 L .55436 .4951 L p F P
0 g
s
.715 .947 .955 r
.55409 .28246 m .55024 .28135 L .57097 .26993 L closepath p F P
0 g
s
.798 .317 .068 r
.16883 .44377 m .16968 .44496 L .18094 .45114 L p F P
0 g
s
.702 .162 0 r
.17736 .45258 m .18871 .45875 L .18094 .45114 L p F P
0 g
s
.702 .162 0 r
.18094 .45114 m .16968 .44496 L .17736 .45258 L p F P
0 g
s
0 .446 .842 r
.28837 .28896 m .2763 .28525 L .26888 .27933 L p F P
0 g
s
.471 .434 .735 r
.73761 .29774 m .73161 .30507 L .71868 .2991 L p F P
0 g
s
.471 .434 .735 r
.73441 .28682 m .73761 .29774 L p .71868 .2991 L F P
0 g
s
.471 .434 .735 r
.71868 .2991 m .72993 .28511 L .73441 .28682 L p F P
0 g
s
.073 .567 .894 r
.31135 .29881 m .30604 .29598 L .30106 .29495 L closepath p F P
0 g
s
0 0 0 r
.6642 .43377 m .6631 .4358 L .67007 .4298 L closepath p F P
0 g
s
.176 0 .253 r
.70617 .39755 m .70772 .38986 L .69512 .39995 L p F P
0 g
s
.176 0 .253 r
.6868 .41303 m .70617 .39755 L p .69512 .39995 L F P
0 g
s
.176 0 .253 r
.69512 .39995 m .68699 .41203 L .6868 .41303 L p F P
0 g
s
.586 .946 .883 r
.5451 .28097 m .55024 .28135 L .52615 .29322 L p F P
0 g
s
.586 .946 .883 r
.52615 .29322 m .52383 .29344 L .5451 .28097 L p F P
0 g
s
.547 .548 .807 r
.7025 .26729 m .721 .26767 L .7108 .28141 L p F P
0 g
s
.522 .513 .787 r
.73272 .28152 m .72993 .28511 L .7108 .28141 L p F P
0 g
s
.522 .513 .787 r
.72802 .2685 m .73272 .28152 L p .7108 .28141 L F P
0 g
s
.522 .513 .787 r
.7108 .28141 m .721 .26767 L .72802 .2685 L p F P
0 g
s
.146 .687 .824 r
.4255 .51736 m .4121 .51772 L .40814 .51739 L p F P
0 g
s
.057 .621 .776 r
.4121 .51772 m .40814 .51739 L .39691 .51736 L closepath p F P
0 g
s
.913 .583 .404 r
.12602 .39833 m .1261 .39896 L .12517 .39825 L closepath p F P
0 g
s
.103 .651 .823 r
.40113 .51675 m .40814 .51739 L .39691 .51736 L p F P
0 g
s
.103 .651 .823 r
.37771 .51635 m .40113 .51675 L p .39691 .51736 L F P
0 g
s
.103 .651 .823 r
.39691 .51736 m .38015 .51669 L .37771 .51635 L p F P
0 g
s
.108 .662 .784 r
.44215 .51672 m .43865 .5166 L .4255 .51736 L closepath p F P
0 g
s
.146 .687 .824 r
.43179 .51634 m .43865 .5166 L .4255 .51736 L p F P
0 g
s
.146 .687 .824 r
.40814 .51739 m .43179 .51634 L p .4255 .51736 L F P
0 g
s
.924 .593 .395 r
.10785 .38451 m .11679 .39184 L .11556 .38222 L p F P
0 g
s
.924 .593 .395 r
.11556 .38222 m .10666 .37487 L .10785 .38451 L p F P
0 g
s
.899 .506 .265 r
.11951 .40099 m .12891 .40808 L .1261 .39896 L p F P
0 g
s
.899 .506 .265 r
.11775 .39504 m .11951 .40099 L p .1261 .39896 L F P
0 g
s
.899 .506 .265 r
.1261 .39896 m .12517 .39825 L .11775 .39504 L p F P
0 g
s
.36 .261 .605 r
.73292 .33568 m .72581 .34351 L .72387 .3314 L p F P
0 g
s
.36 .261 .605 r
.72387 .3314 m .72803 .32678 L .73292 .33568 L p F P
0 g
s
.753 .878 .936 r
.60479 .25825 m .58055 .2709 L .57445 .26801 L p F P
0 g
s
0 0 0 r
.64669 .44833 m .63895 .45353 L .6359 .45744 L p F P
0 g
s
.293 .616 .957 r
.23918 .26961 m .2507 .27153 L .26098 .27853 L p F P
0 g
s
.287 .596 .949 r
.2507 .27153 m .23918 .26961 L .2317 .26225 L p F P
0 g
s
.931 .648 .483 r
.09812 .36732 m .10666 .37487 L .10686 .36478 L p F P
0 g
s
.931 .648 .483 r
.10686 .36478 m .09835 .35722 L .09812 .36732 L p F P
0 g
s
.198 .726 .829 r
.46155 .51491 m .44215 .51672 L .43865 .5166 L p F P
0 g
s
.413 0 0 r
.34331 .30911 m .3453 .30986 L .36262 .31402 L p F P
0 g
s
.352 0 0 r
.35901 .31496 m .3453 .30986 L .36262 .31402 L p F P
0 g
s
.352 0 0 r
.3705 .317 m .35901 .31496 L p .36262 .31402 L F P
0 g
s
.352 0 0 r
.36262 .31402 m .37347 .31663 L .3705 .317 L p F P
0 g
s
.018 .587 .776 r
.38015 .51669 m .37771 .51635 L .3723 .51603 L closepath p F P
0 g
s
0 0 0 r
.58617 .48281 m .5847 .48354 L .6079 .47335 L closepath p F P
0 g
s
.621 .714 .913 r
.17175 .25327 m .1943 .24738 L .20186 .2555 L p F P
0 g
s
.903 .517 .281 r
.12517 .39825 m .11775 .39504 L .11679 .39184 L closepath p F P
0 g
s
.404 0 0 r
.2347 .48319 m .22308 .47729 L .23628 .48266 L p F P
0 g
s
.404 0 0 r
.23628 .48266 m .24248 .48566 L .2347 .48319 L p F P
0 g
s
.493 .672 .944 r
.20186 .2555 m .21 .25527 L .21843 .26306 L p F P
0 g
s
.513 .686 .945 r
.22419 .25454 m .21 .25527 L .21843 .26306 L p F P
0 g
s
.513 .686 .945 r
.21843 .26306 m .2317 .26225 L .22419 .25454 L p F P
0 g
s
.183 0 .342 r
.71427 .38387 m .70772 .38986 L .70847 .38119 L p F P
0 g
s
.183 0 .342 r
.70847 .38119 m .71896 .37156 L .71427 .38387 L p F P
0 g
s
.864 .425 .156 r
.13309 .41677 m .14292 .42365 L .13869 .41497 L p F P
0 g
s
.864 .425 .156 r
.13869 .41497 m .12891 .40808 L .13309 .41677 L p F P
0 g
s
.227 0 0 r
.28112 .49914 m .27984 .4988 L .27847 .49839 L closepath p F P
0 g
s
.198 0 0 r
.3474 .51329 m .35048 .51375 L .3723 .51603 L p F P
0 g
s
.03 .595 .789 r
.37055 .51523 m .35048 .51375 L .3723 .51603 L p F P
0 g
s
.03 .595 .789 r
.3723 .51603 m .37771 .51635 L .37055 .51523 L p F P
0 g
s
.056 0 0 r
.6631 .4358 m .64669 .44833 L .66102 .43977 L closepath p F P
0 g
s
0 0 0 r
.65784 .44364 m .66102 .43977 L .64669 .44833 L p F P
0 g
s
0 0 0 r
.65142 .44813 m .65784 .44364 L p .64669 .44833 L F P
0 g
s
0 0 0 r
.6359 .45744 m .65142 .44813 L p .64669 .44833 L F P
0 g
s
.157 0 0 r
.3474 .51329 m .35048 .51375 L .34574 .51316 L closepath p F P
0 g
s
.929 .69 .556 r
.0902 .34944 m .09835 .35722 L .10005 .34662 L p F P
0 g
s
.929 .69 .556 r
.10005 .34662 m .09193 .33883 L .0902 .34944 L p F P
0 g
s
.22 0 .268 r
.68699 .41203 m .68561 .41386 L .6868 .41303 L closepath p F P
0 g
s
.563 0 0 r
.19743 .46517 m .18871 .45875 L .20054 .4647 L p F P
0 g
s
.563 0 0 r
.20054 .4647 m .20536 .46811 L .19743 .46517 L p F P
0 g
s
.205 0 0 r
.27224 .49653 m .26343 .49371 L .27847 .49839 L p F P
0 g
s
.205 0 0 r
.27847 .49839 m .27984 .4988 L .27224 .49653 L p F P
0 g
s
.094 0 .093 r
.68443 .41984 m .67007 .4298 L .68561 .41386 L p F P
0 g
s
.094 0 .093 r
.68561 .41386 m .6868 .41303 L .68443 .41984 L p F P
0 g
s
.541 .572 .835 r
.69776 .25753 m .7025 .26729 L .721 .26767 L p F P
0 g
s
.35 .654 .969 r
.26142 .273 m .2507 .27153 L .26098 .27853 L p F P
0 g
s
.35 .654 .969 r
.26098 .27853 m .26888 .27933 L .26142 .273 L p F P
0 g
s
0 0 0 r
.48916 .30643 m .4875 .30757 L .49092 .30608 L p F P
0 g
s
0 0 0 r
.48916 .30643 m .49362 .30472 L .48515 .30723 L p F P
0 g
s
.297 .773 .67 r
.51674 .29474 m .51979 .29371 L .49571 .30388 L p F P
0 g
s
.322 .792 .69 r
.51337 .2958 m .51674 .29474 L .51185 .29685 L p F P
0 g
s
.322 .792 .69 r
.51185 .29685 m .49362 .30472 L p .51337 .2958 L F P
0 g
s
.322 .792 .69 r
.49362 .30472 m .48916 .30643 L .51337 .2958 L p F P
0 g
s
0 0 0 r
.51067 .29745 m .51337 .2958 L .48916 .30643 L p F P
0 g
s
.394 .809 .613 r
.51337 .2958 m .51067 .29745 L .51482 .2948 L p F P
0 g
s
.394 .809 .613 r
.51482 .2948 m .53155 .28409 L p .51337 .2958 L F P
0 g
s
0 0 0 r
.49092 .30608 m .51067 .29745 L p .48916 .30643 L F P
0 g
s
0 0 0 r
.48515 .30723 m .46864 .31213 L p .48916 .30643 L F P
0 g
s
0 0 0 r
.46864 .31213 m .46513 .31324 L .48916 .30643 L p F P
0 g
s
.17 .707 .8 r
.47065 .51398 m .46919 .51399 L .46155 .51491 L closepath p F P
0 g
s
.198 .726 .829 r
.46249 .51398 m .46919 .51399 L .46155 .51491 L p F P
0 g
s
.198 .726 .829 r
.43865 .5166 m .46249 .51398 L p .46155 .51491 L F P
0 g
s
.802 .311 .009 r
.14862 .43188 m .15892 .43853 L .15315 .43032 L p F P
0 g
s
.802 .311 .009 r
.15315 .43032 m .14292 .42365 L .14862 .43188 L p F P
0 g
s
.093 .574 .905 r
.29862 .29181 m .28837 .28896 L .30106 .29495 L p F P
0 g
s
.093 .574 .905 r
.30106 .29495 m .30604 .29598 L .29862 .29181 L p F P
0 g
s
0 0 0 r
.67007 .4298 m .6631 .4358 L .66102 .43977 L p F P
0 g
s
.338 0 0 r
.34331 .30911 m .3453 .30986 L .34157 .30872 L closepath p F P
0 g
s
.015 0 .061 r
.70609 .39778 m .70617 .39755 L .6868 .41303 L p F P
0 g
s
.015 0 .061 r
.6939 .41229 m .70609 .39778 L p .6868 .41303 L F P
0 g
s
.015 0 .061 r
.6868 .41303 m .68443 .41984 L .6939 .41229 L p F P
0 g
s
0 0 0 r
.68213 .42399 m .68443 .41984 L .67007 .4298 L p F P
0 g
s
0 0 0 r
.67673 .42886 m .68213 .42399 L p .67007 .4298 L F P
0 g
s
0 0 0 r
.66102 .43977 m .67673 .42886 L p .67007 .4298 L F P
0 g
s
.228 0 0 r
.29558 .50318 m .27984 .4988 L .27224 .49653 L p F P
0 g
s
.493 .666 .939 r
.21 .25527 m .20186 .2555 L .1943 .24738 L p F P
0 g
s
.686 .726 .88 r
.63515 .2523 m .6597 .24233 L .66564 .25081 L p F P
0 g
s
.706 .756 .891 r
.6597 .24233 m .63515 .2523 L .62918 .24593 L p F P
0 g
s
.249 .762 .836 r
.49319 .50977 m .49782 .50965 L .47065 .51398 L p F P
0 g
s
.249 .762 .836 r
.47065 .51398 m .46919 .51399 L .49319 .50977 L p F P
0 g
s
.636 .65 .847 r
.66564 .25081 m .69049 .24411 L .69647 .25499 L p F P
0 g
s
.657 .681 .861 r
.69049 .24411 m .66564 .25081 L .6597 .24233 L p F P
0 g
s
.798 .31 .037 r
.16883 .44377 m .16968 .44496 L .16629 .44295 L closepath p F P
0 g
s
.066 .615 .833 r
.36747 .5147 m .37055 .51523 L .35048 .51375 L p F P
0 g
s
.066 .615 .833 r
.35529 .51324 m .36747 .5147 L p .35048 .51375 L F P
0 g
s
.066 .615 .833 r
.3401 .51188 m .35529 .51324 L p .35048 .51375 L F P
0 g
s
.066 .615 .833 r
.35048 .51375 m .34574 .51316 L .3401 .51188 L p F P
0 g
s
0 0 0 r
.6079 .47335 m .5847 .48354 L .58001 .48599 L p F P
0 g
s
.6 .951 .892 r
.544 .28087 m .5451 .28097 L .52383 .29344 L p F P
0 g
s
.6 .951 .892 r
.52383 .29344 m .51979 .29371 L .544 .28087 L p F P
0 g
s
0 0 0 r
.52381 .50385 m .52383 .50384 L .49971 .5092 L p F P
0 g
s
0 0 0 r
.49971 .5092 m .49782 .50965 L .52381 .50385 L p F P
0 g
s
0 .555 .787 r
.34574 .51316 m .3401 .51188 L .33081 .51072 L closepath p F P
0 g
s
.034 .601 .773 r
.40113 .51675 m .37771 .51635 L .37055 .51523 L p F P
0 g
s
.332 0 0 r
.34208 .31057 m .35901 .31496 L .3453 .30986 L p F P
0 g
s
.332 0 0 r
.33596 .30744 m .34208 .31057 L p .3453 .30986 L F P
0 g
s
.332 0 0 r
.3453 .30986 m .34157 .30872 L .33596 .30744 L p F P
0 g
s
.355 .264 .612 r
.74302 .32406 m .73292 .33568 L .72803 .32678 L p F P
0 g
s
.355 .264 .612 r
.74146 .31462 m .74302 .32406 L p .72803 .32678 L F P
0 g
s
.355 .264 .612 r
.72803 .32678 m .74027 .31261 L .74146 .31462 L p F P
0 g
s
.728 .838 .933 r
.60564 .25897 m .60479 .25825 L .60783 .25673 L closepath p F P
0 g
s
.29 .164 .53 r
.73464 .34574 m .72679 .35433 L .72581 .34351 L p F P
0 g
s
.29 .164 .53 r
.72581 .34351 m .73292 .33568 L .73464 .34574 L p F P
0 g
s
.257 .085 .447 r
.72688 .364 m .71896 .37156 L .72048 .36037 L p F P
0 g
s
.257 .085 .447 r
.72048 .36037 m .72679 .35433 L .72688 .364 L p F P
0 g
s
.669 .119 0 r
.16647 .44619 m .17736 .45258 L .16968 .44496 L p F P
0 g
s
.669 .119 0 r
.16077 .44039 m .16647 .44619 L p .16968 .44496 L F P
0 g
s
.669 .119 0 r
.16968 .44496 m .16629 .44295 L .16077 .44039 L p F P
0 g
s
.665 .964 .929 r
.57097 .26993 m .55024 .28135 L .5451 .28097 L p F P
0 g
s
.269 0 0 r
.34157 .30872 m .33596 .30744 L .32907 .30525 L closepath p F P
0 g
s
.318 .801 .752 r
.57871 .48631 m .58001 .48599 L .55624 .49464 L p F P
0 g
s
.725 .873 .95 r
.60783 .25673 m .60479 .25825 L .59876 .25406 L p F P
0 g
s
.753 .878 .936 r
.57445 .26801 m .59876 .25406 L .60479 .25825 L p F P
0 g
s
.582 .604 .839 r
.69647 .25499 m .69963 .25467 L .69776 .25753 L closepath p F P
0 g
s
.541 .572 .835 r
.72183 .25353 m .69963 .25467 L .69776 .25753 L p F P
0 g
s
.541 .572 .835 r
.72534 .26174 m .72183 .25353 L p .69776 .25753 L F P
0 g
s
.541 .572 .835 r
.721 .26767 m .72534 .26174 L p .69776 .25753 L F P
0 g
s
.212 .737 .805 r
.49319 .50977 m .46919 .51399 L .46249 .51398 L p F P
0 g
s
.081 .64 .775 r
.43179 .51634 m .40814 .51739 L .40113 .51675 L p F P
0 g
s
.4 0 0 r
.31475 .29989 m .30604 .29598 L .29862 .29181 L p F P
0 g
s
.426 0 0 r
.24248 .48566 m .2491 .48876 L .26343 .49371 L p F P
0 g
s
.42 0 0 r
.2491 .48876 m .24248 .48566 L .2347 .48319 L p F P
0 g
s
.584 .008 0 r
.20536 .46811 m .21043 .47167 L .22308 .47729 L p F P
0 g
s
.404 0 0 r
.22248 .47798 m .21043 .47167 L .22308 .47729 L p F P
0 g
s
.404 0 0 r
.2337 .48283 m .22248 .47798 L p .22308 .47729 L F P
0 g
s
.404 0 0 r
.22308 .47729 m .2347 .48319 L .2337 .48283 L p F P
0 g
s
.141 .686 .786 r
.46249 .51398 m .43865 .5166 L .43179 .51634 L p F P
0 g
s
.751 .875 .936 r
.60783 .25673 m .62918 .24593 L .6232 .24032 L p F P
0 g
s
.751 .875 .936 r
.6232 .24032 m .62133 .24138 L .60783 .25673 L p F P
0 g
s
.725 .873 .95 r
.59876 .25406 m .62133 .24138 L .60783 .25673 L p F P
0 g
s
.221 0 0 r
.30984 .50661 m .31247 .50722 L .33081 .51072 L p F P
0 g
s
.002 .564 .802 r
.33276 .51007 m .31247 .50722 L .33081 .51072 L p F P
0 g
s
.002 .564 .802 r
.33081 .51072 m .3401 .51188 L .33276 .51007 L p F P
0 g
s
.691 .149 0 r
.16629 .44295 m .16077 .44039 L .15892 .43853 L closepath p F P
0 g
s
0 .378 .68 r
.26459 .49402 m .2491 .48876 L .26343 .49371 L p F P
0 g
s
0 .378 .68 r
.26343 .49371 m .27224 .49653 L .26459 .49402 L p F P
0 g
s
.581 .006 0 r
.21043 .47167 m .20536 .46811 L .19743 .46517 L p F P
0 g
s
.598 .629 .852 r
.69963 .25467 m .69647 .25499 L .69049 .24411 L p F P
0 g
s
.909 .521 .264 r
.10954 .39034 m .10785 .38451 L .11679 .39184 L p F P
0 g
s
.909 .521 .264 r
.11679 .39184 m .11775 .39504 L .10954 .39034 L p F P
0 g
s
.933 .601 .385 r
.09929 .37697 m .10785 .38451 L .10666 .37487 L p F P
0 g
s
.933 .601 .385 r
.10666 .37487 m .09812 .36732 L .09929 .37697 L p F P
0 g
s
0 .446 .842 r
.26888 .27933 m .27708 .28239 L .28837 .28896 L p F P
0 g
s
0 .416 .837 r
.27708 .28239 m .26888 .27933 L .26142 .273 L p F P
0 g
s
.867 .424 .131 r
.12366 .40968 m .13309 .41677 L .12891 .40808 L p F P
0 g
s
.867 .424 .131 r
.12891 .40808 m .11951 .40099 L .12366 .40968 L p F P
0 g
s
.94 .657 .476 r
.08994 .35956 m .09812 .36732 L .09835 .35722 L p F P
0 g
s
.94 .657 .476 r
.09835 .35722 m .0902 .34944 L .08994 .35956 L p F P
0 g
s
.312 .803 .851 r
.51741 .50407 m .52381 .50385 L .49782 .50965 L p F P
0 g
s
.312 .803 .851 r
.49782 .50965 m .49319 .50977 L .51741 .50407 L p F P
0 g
s
.562 0 0 r
.18677 .45969 m .17736 .45258 L .18871 .45875 L p F P
0 g
s
.562 0 0 r
.19555 .46437 m .18677 .45969 L p .18871 .45875 L F P
0 g
s
.562 0 0 r
.18871 .45875 m .19743 .46517 L .19555 .46437 L p F P
0 g
s
.493 .666 .939 r
.1943 .24738 m .20214 .24718 L .21 .25527 L p F P
0 g
s
.51 .675 .939 r
.21665 .24646 m .20214 .24718 L .21 .25527 L p F P
0 g
s
.51 .675 .939 r
.21 .25527 m .22419 .25454 L .21665 .24646 L p F P
0 g
s
.032 .519 .88 r
.29103 .28716 m .27708 .28239 L .28837 .28896 L p F P
0 g
s
.032 .519 .88 r
.29132 .28731 m .29103 .28716 L p .28837 .28896 L F P
0 g
s
.032 .519 .88 r
.28837 .28896 m .29862 .29181 L .29132 .28731 L p F P
0 g
s
.287 .596 .949 r
.2317 .26225 m .24135 .26412 L .2507 .27153 L p F P
0 g
s
.29 .582 .942 r
.24135 .26412 m .2317 .26225 L .22419 .25454 L p F P
0 g
s
.408 0 0 r
.37347 .31663 m .37881 .31825 L .3705 .317 L closepath p F P
0 g
s
.181 0 0 r
.30984 .50661 m .31247 .50722 L .30789 .50623 L closepath p F P
0 g
s
.598 .629 .852 r
.69049 .24411 m .70789 .2414 L .69963 .25467 L p F P
0 g
s
.567 .578 .824 r
.71575 .24047 m .70789 .2414 L .69963 .25467 L p F P
0 g
s
.567 .578 .824 r
.69963 .25467 m .72183 .25353 L .71575 .24047 L p F P
0 g
s
.333 .629 .96 r
.25393 .26618 m .24135 .26412 L .2507 .27153 L p F P
0 g
s
.333 .629 .96 r
.2507 .27153 m .26142 .273 L .25393 .26618 L p F P
0 g
s
.267 0 0 r
.32745 .3053 m .31475 .29989 L .32907 .30525 L p F P
0 g
s
.267 0 0 r
.32954 .30597 m .32745 .3053 L p .32907 .30525 L F P
0 g
s
.267 0 0 r
.32907 .30525 m .33596 .30744 L .32954 .30597 L p F P
0 g
s
.067 0 .198 r
.70649 .39726 m .70617 .39755 L .70772 .38986 L p F P
0 g
s
.067 0 .198 r
.70772 .38986 m .71427 .38387 L .70649 .39726 L p F P
0 g
s
.407 .343 .673 r
.74095 .31178 m .74027 .31261 L .73161 .30507 L p F P
0 g
s
.407 .343 .673 r
.73161 .30507 m .73761 .29774 L .74095 .31178 L p F P
0 g
s
.8 .306 0 r
.13873 .42501 m .14862 .43188 L .14292 .42365 L p F P
0 g
s
.8 .306 0 r
.14292 .42365 m .13309 .41677 L .13873 .42501 L p F P
0 g
s
0 0 0 r
.6359 .45744 m .63343 .4594 L .65142 .44813 L closepath p F P
0 g
s
.014 0 0 r
.4875 .30757 m .48916 .30643 L .46513 .31324 L p F P
0 g
s
.014 0 0 r
.46513 .31324 m .46232 .31493 L .4875 .30757 L p F P
0 g
s
.312 .796 .743 r
.57261 .48784 m .57871 .48631 L .55436 .4951 L p F P
0 g
s
.312 .796 .743 r
.572 .48806 m .57261 .48784 L p .55436 .4951 L F P
0 g
s
.312 .796 .743 r
.55436 .4951 m .54872 .49657 L .572 .48806 L p F P
0 g
s
.205 .721 .686 r
.54872 .49657 m .55436 .4951 L p .52383 .50384 L F P
0 g
s
.91 .525 .272 r
.11951 .40099 m .11775 .39504 L .10954 .39034 L p F P
0 g
s
0 0 0 r
.66102 .43977 m .65784 .44364 L .67673 .42886 L closepath p F P
0 g
s
.712 .95 .953 r
.57445 .26801 m .57097 .26993 L .57383 .26783 L closepath p F P
0 g
s
.665 .964 .929 r
.56831 .26619 m .57383 .26783 L .57097 .26993 L p F P
0 g
s
.665 .964 .929 r
.54952 .27755 m .56831 .26619 L p .57097 .26993 L F P
0 g
s
.665 .964 .929 r
.5451 .28097 m .54952 .27755 L p .57097 .26993 L F P
0 g
s
.156 0 .326 r
.72613 .37258 m .71427 .38387 L .71896 .37156 L p F P
0 g
s
.156 0 .326 r
.71896 .37156 m .72688 .364 L .72613 .37258 L p F P
0 g
s
0 0 0 r
.60904 .47282 m .6079 .47335 L .60897 .47289 L closepath p F P
0 g
s
0 0 0 r
.60319 .47575 m .60897 .47289 L .6079 .47335 L p F P
0 g
s
0 0 0 r
.60319 .47575 m .59815 .47801 L .60285 .47592 L closepath p F P
0 g
s
.338 .786 .633 r
.60319 .47575 m .60285 .47592 L .60293 .47588 L p F P
0 g
s
0 0 0 r
.59815 .47801 m .60319 .47575 L p .60736 .47361 L F P
0 g
s
0 0 0 r
.58001 .48599 m .59815 .47801 L p .6079 .47335 L F P
0 g
s
0 0 0 r
.63343 .4594 m .60904 .47282 L p .61259 .47098 L F P
0 g
s
0 0 0 r
.63088 .4615 m .6313 .46115 L p .61259 .47098 L F P
0 g
s
0 0 0 r
.6313 .46115 m .63343 .4594 L p .61259 .47098 L F P
0 g
s
0 0 0 r
.6079 .47335 m .60736 .47361 L .60319 .47575 L F
.60904 .47282 m .60897 .47289 L .63088 .4615 L p F P
0 g
s
.345 .794 .646 r
.60319 .47575 m .62774 .46292 L p .60904 .47285 L F P
0 g
s
.345 .794 .646 r
.60897 .47289 m .60896 .47289 L p .60904 .47285 L F P
0 g
s
.345 .794 .646 r
.60896 .47289 m .60319 .47575 L p .60904 .47285 L F P
0 g
s
.338 .786 .633 r
.60293 .47588 m .62475 .46432 L p .60319 .47575 L F P
0 g
s
.047 .587 .849 r
.3313 .50967 m .33276 .51007 L .31247 .50722 L p F P
0 g
s
.047 .587 .849 r
.31688 .50669 m .3313 .50967 L p .31247 .50722 L F P
0 g
s
.047 .587 .849 r
.30237 .50443 m .31688 .50669 L p .31247 .50722 L F P
0 g
s
.047 .587 .849 r
.31247 .50722 m .30789 .50623 L .30237 .50443 L p F P
0 g
s
.202 .045 .432 r
.73344 .35687 m .72688 .364 L .72679 .35433 L p F P
0 g
s
.202 .045 .432 r
.72679 .35433 m .73464 .34574 L .73344 .35687 L p F P
0 g
s
.188 0 0 r
.43362 .31924 m .40451 .32029 L .40388 .32045 L p F P
0 g
s
.332 0 0 r
.40451 .32029 m .40388 .32045 L .40228 .32018 L closepath p F P
0 g
s
.386 0 0 r
.39428 .32286 m .37881 .31825 L .40228 .32018 L p F P
0 g
s
.386 0 0 r
.39773 .32311 m .39428 .32286 L p .40228 .32018 L F P
0 g
s
.386 0 0 r
.40228 .32018 m .40388 .32045 L .39773 .32311 L p F P
0 g
s
.657 .681 .861 r
.6597 .24233 m .68453 .23419 L .69049 .24411 L p F P
0 g
s
.677 .71 .873 r
.68453 .23419 m .6597 .24233 L .65376 .23464 L p F P
0 g
s
.706 .756 .891 r
.62918 .24593 m .65376 .23464 L .6597 .24233 L p F P
0 g
s
.345 .794 .646 r
.62774 .46292 m .63088 .4615 L .60897 .47289 L p F P
0 g
s
.756 .957 .937 r
.59269 .25069 m .59876 .25406 L .57445 .26801 L p F P
0 g
s
.756 .957 .937 r
.58953 .25272 m .59269 .25069 L p .57445 .26801 L F P
0 g
s
.756 .957 .937 r
.57445 .26801 m .57383 .26783 L .58953 .25272 L p F P
0 g
s
.678 .134 0 r
.15272 .43612 m .14862 .43188 L .15892 .43853 L p F P
0 g
s
.678 .134 0 r
.15892 .43853 m .16077 .44039 L .15272 .43612 L p F P
0 g
s
0 .534 .809 r
.30789 .50623 m .30237 .50443 L .29558 .50318 L closepath p F P
0 g
s
.234 0 0 r
.4347 .31918 m .43448 .31926 L .43362 .31924 L closepath p F P
0 g
s
.188 0 0 r
.42876 .32277 m .43448 .31926 L .43362 .31924 L p F P
0 g
s
.188 0 0 r
.42292 .32296 m .42876 .32277 L p .43362 .31924 L F P
0 g
s
.188 0 0 r
.40388 .32045 m .42292 .32296 L p .43362 .31924 L F P
0 g
s
.112 0 0 r
.45835 .31725 m .46232 .31493 L .4347 .31918 L p F P
0 g
s
.112 0 0 r
.4347 .31918 m .43448 .31926 L .45835 .31725 L p F P
0 g
s
.469 .436 .738 r
.72993 .28511 m .73272 .28152 L .73441 .28682 L closepath p F P
0 g
s
.359 0 0 r
.40388 .32045 m .42292 .32296 L .39773 .32311 L closepath p F P
0 g
s
.42 0 0 r
.2347 .48319 m .23539 .48353 L .2491 .48876 L p F P
0 g
s
0 .374 .691 r
.2506 .48889 m .23539 .48353 L .2491 .48876 L p F P
0 g
s
0 .374 .691 r
.26455 .49401 m .2506 .48889 L p .2491 .48876 L F P
0 g
s
0 .374 .691 r
.2491 .48876 m .26459 .49402 L .26455 .49401 L p F P
0 g
s
.727 .784 .898 r
.65376 .23464 m .62918 .24593 L .6232 .24032 L p F P
0 g
s
.581 .006 0 r
.19743 .46517 m .1983 .46581 L .21043 .47167 L p F P
0 g
s
.381 0 0 r
.21017 .47217 m .22248 .47798 L .21043 .47167 L p F P
0 g
s
.381 0 0 r
.21043 .47167 m .1983 .46581 L .21017 .47217 L p F P
0 g
s
.756 .954 .939 r
.57383 .26783 m .56831 .26619 L .58953 .25272 L closepath p F P
0 g
s
.507 .903 .771 r
.53777 .28175 m .544 .28087 L .51979 .29371 L p F P
0 g
s
.507 .903 .771 r
.51979 .29371 m .51674 .29474 L .53777 .28175 L p F P
0 g
s
.243 0 0 r
.45671 .31871 m .45835 .31725 L .43448 .31926 L p F P
0 g
s
.243 0 0 r
.43448 .31926 m .42876 .32277 L .45671 .31871 L p F P
0 g
s
.274 .153 .527 r
.74407 .33494 m .73464 .34574 L .73292 .33568 L p F P
0 g
s
.274 .153 .527 r
.73292 .33568 m .74302 .32406 L .74407 .33494 L p F P
0 g
s
.521 .514 .788 r
.721 .26767 m .72534 .26174 L .72802 .2685 L closepath p F P
0 g
s
.007 .572 .796 r
.35529 .51324 m .3401 .51188 L .33276 .51007 L p F P
0 g
s
.404 0 0 r
.37234 .3203 m .39428 .32286 L .37881 .31825 L p F P
0 g
s
.404 0 0 r
.36617 .31751 m .37234 .3203 L p .37881 .31825 L F P
0 g
s
.404 0 0 r
.37881 .31825 m .3705 .317 L .36617 .31751 L p F P
0 g
s
0 0 0 r
.68443 .41984 m .68213 .42399 L .6939 .41229 L closepath p F P
0 g
s
.617 .633 .843 r
.70789 .2414 m .69049 .24411 L .68453 .23419 L p F P
0 g
s
.695 .155 0 r
.16647 .44619 m .16077 .44039 L .15272 .43612 L p F P
0 g
s
.228 0 0 r
.27224 .49653 m .27972 .49876 L .29558 .50318 L p F P
0 g
s
.217 0 0 r
.27972 .49876 m .27224 .49653 L .26459 .49402 L p F P
0 g
s
.447 0 0 r
.3705 .317 m .36617 .31751 L .35901 .31496 L closepath p F P
0 g
s
.205 .721 .686 r
.52383 .50384 m .52444 .50367 L .54872 .49657 L p F P
0 g
s
.383 .845 .868 r
.52444 .50367 m .52381 .50385 L .51741 .50407 L p F P
0 g
s
.4 0 0 r
.29862 .29181 m .30223 .2938 L .31475 .29989 L p F P
0 g
s
.386 0 0 r
.31475 .29989 m .30223 .2938 L .3133 .29979 L p F P
0 g
s
.379 .843 .864 r
.54872 .49657 m .54814 .4966 L .52444 .50367 L closepath p F P
0 g
s
.383 .845 .868 r
.54183 .49683 m .54814 .4966 L .52444 .50367 L p F P
0 g
s
.383 .845 .868 r
.51741 .50407 m .54183 .49683 L p .52444 .50367 L F P
0 g
s
.547 0 0 r
.17576 .45332 m .18677 .45969 L .17736 .45258 L p F P
0 g
s
.547 0 0 r
.17736 .45258 m .16647 .44619 L .17576 .45332 L p F P
0 g
s
.916 .527 .251 r
.10139 .38443 m .09929 .37697 L .10785 .38451 L p F P
0 g
s
.916 .527 .251 r
.10785 .38451 m .10954 .39034 L .10139 .38443 L p F P
0 g
s
.457 0 0 r
.33596 .30744 m .34208 .31057 L .32954 .30597 L closepath p F P
0 g
s
0 .439 .855 r
.27969 .28051 m .29103 .28716 L .27708 .28239 L p F P
0 g
s
0 .439 .855 r
.27708 .28239 m .26687 .27533 L .27969 .28051 L p F P
0 g
s
0 .416 .837 r
.26142 .273 m .26687 .27533 L .27708 .28239 L p F P
0 g
s
.941 .608 .373 r
.09109 .36921 m .09929 .37697 L .09812 .36732 L p F P
0 g
s
.941 .608 .373 r
.09812 .36732 m .08994 .35956 L .09109 .36921 L p F P
0 g
s
0 .545 .828 r
.29486 .50177 m .27972 .49876 L .29558 .50318 L p F P
0 g
s
0 .545 .828 r
.29558 .50318 m .30237 .50443 L .29486 .50177 L p F P
0 g
s
.402 .853 .784 r
.58001 .48599 m .57871 .48631 L .59815 .47801 L closepath p F P
0 g
s
.91 .525 .272 r
.10954 .39034 m .1105 .39367 L .11951 .40099 L p F P
0 g
s
.868 .422 .104 r
.11463 .40237 m .12366 .40968 L .11951 .40099 L p F P
0 g
s
.868 .422 .104 r
.11951 .40099 m .1105 .39367 L .11463 .40237 L p F P
0 g
s
.022 0 .16 r
.7224 .38219 m .70649 .39726 L .71427 .38387 L p F P
0 g
s
.022 0 .16 r
.72511 .37735 m .7224 .38219 L p .71427 .38387 L F P
0 g
s
.022 0 .16 r
.71427 .38387 m .72613 .37258 L .72511 .37735 L p F P
0 g
s
.404 .395 .736 r
.75087 .27814 m .73899 .27177 L .73272 .28152 L p F P
0 g
s
.404 .395 .736 r
.74207 .29137 m .75087 .27814 L p .73272 .28152 L F P
0 g
s
.404 .395 .736 r
.73272 .28152 m .73441 .28682 L .74207 .29137 L p F P
0 g
s
.474 .465 .768 r
.72802 .2685 m .73899 .27177 L .73272 .28152 L closepath p F P
0 g
s
.424 .391 .718 r
.73441 .28682 m .74207 .29137 L .73761 .29774 L closepath p F P
0 g
s
.034 .601 .773 r
.40063 .5167 m .40113 .51675 L p .37055 .51523 L F P
0 g
s
.034 .601 .773 r
.37055 .51523 m .37756 .51545 L .40063 .5167 L p F P
0 g
s
.081 .633 .823 r
.37055 .51523 m .37756 .51545 L .36747 .5147 L closepath p F P
0 g
s
.29 .582 .942 r
.22419 .25454 m .23276 .25635 L .24135 .26412 L p F P
0 g
s
.328 .609 .95 r
.24642 .25879 m .23276 .25635 L .24135 .26412 L p F P
0 g
s
.328 .609 .95 r
.24135 .26412 m .25393 .26618 L .24642 .25879 L p F P
0 g
s
0 0 0 r
.65142 .44813 m .63343 .4594 L .63088 .4615 L p F P
0 g
s
.705 .971 .928 r
.5451 .28097 m .544 .28087 L .54952 .27755 L closepath p F P
0 g
s
.465 0 0 r
.35383 .31647 m .34208 .31057 L .35901 .31496 L p F P
0 g
s
.465 0 0 r
.36213 .31825 m .35383 .31647 L p .35901 .31496 L F P
0 g
s
.465 0 0 r
.35901 .31496 m .36617 .31751 L .36213 .31825 L p F P
0 g
s
.024 0 0 r
.4825 .31094 m .4875 .30757 L .46232 .31493 L p F P
0 g
s
.024 0 0 r
.46232 .31493 m .45835 .31725 L .4825 .31094 L p F P
0 g
s
.369 .318 .67 r
.74982 .29925 m .74095 .31178 L .73761 .29774 L p F P
0 g
s
.369 .318 .67 r
.73761 .29774 m .74207 .29137 L .74982 .29925 L p F P
0 g
s
.795 .299 0 r
.12926 .41792 m .13873 .42501 L .13309 .41677 L p F P
0 g
s
.795 .299 0 r
.13309 .41677 m .12366 .40968 L .12926 .41792 L p F P
0 g
s
.744 .907 .949 r
.62133 .24138 m .59876 .25406 L .59269 .25069 L p F P
0 g
s
0 .397 .836 r
.26687 .27533 m .26142 .273 L .25393 .26618 L p F P
0 g
s
0 .25 .66 r
.29862 .29181 m .30223 .2938 L .29132 .28731 L closepath p F P
0 g
s
.303 .575 .935 r
.23276 .25635 m .22419 .25454 L .21665 .24646 L p F P
0 g
s
.308 .8 .848 r
.51456 .50419 m .51741 .50407 L .49319 .50977 L p F P
0 g
s
.308 .8 .848 r
.49319 .50977 m .48825 .5099 L .51456 .50419 L p F P
0 g
s
.212 .737 .805 r
.48825 .5099 m .49319 .50977 L p .46249 .51398 L F P
0 g
s
.46 .478 .79 r
.72534 .26174 m .72802 .2685 L .73899 .27177 L p F P
0 g
s
.388 0 0 r
.2347 .48319 m .23539 .48353 L .2337 .48283 L closepath p F P
0 g
s
.558 0 0 r
.19743 .46517 m .1983 .46581 L .19555 .46437 L closepath p F P
0 g
s
0 .418 .764 r
.23725 .48346 m .2506 .48889 L .23539 .48353 L p F P
0 g
s
0 .418 .764 r
.22693 .47967 m .23725 .48346 L p .23539 .48353 L F P
0 g
s
0 .418 .764 r
.23539 .48353 m .2337 .48283 L .22693 .47967 L p F P
0 g
s
.081 .64 .775 r
.43153 .51633 m .43179 .51634 L p .40113 .51675 L F P
0 g
s
.081 .64 .775 r
.40113 .51675 m .40266 .51671 L .43153 .51633 L p F P
0 g
s
.124 .669 .821 r
.40113 .51675 m .40266 .51671 L .40063 .5167 L closepath p F P
0 g
s
.394 .847 .776 r
.59815 .47801 m .57871 .48631 L .57261 .48784 L p F P
0 g
s
.091 0 .305 r
.72945 .36899 m .72613 .37258 L .72688 .364 L p F P
0 g
s
.091 0 .305 r
.72688 .364 m .73344 .35687 L .72945 .36899 L p F P
0 g
s
.212 .737 .805 r
.46249 .51398 m .4749 .51191 L .48825 .5099 L p F P
0 g
s
.241 .756 .835 r
.46249 .51398 m .4749 .51191 L .46063 .51398 L closepath p F P
0 g
s
.141 .686 .786 r
.46063 .51398 m .46249 .51398 L p .43179 .51634 L F P
0 g
s
.517 .529 .807 r
.72183 .25353 m .72962 .25437 L .72534 .26174 L closepath p F P
0 g
s
.46 .478 .79 r
.7472 .25862 m .72962 .25437 L .72534 .26174 L p F P
0 g
s
.46 .478 .79 r
.73899 .27177 m .7472 .25862 L p .72534 .26174 L F P
0 g
s
.624 .961 .865 r
.54952 .27755 m .544 .28087 L .53777 .28175 L p F P
0 g
s
.673 .131 0 r
.14465 .43128 m .13873 .42501 L .14862 .43188 L p F P
0 g
s
.673 .131 0 r
.14862 .43188 m .15272 .43612 L .14465 .43128 L p F P
0 g
s
.346 .26 .614 r
.74027 .31261 m .74095 .31178 L .74146 .31462 L closepath p F P
0 g
s
0 .253 .636 r
.19841 .4661 m .21017 .47217 L .1983 .46581 L p F P
0 g
s
.358 0 0 r
.19555 .46437 m .18951 .4612 L .18677 .45969 L closepath p F P
0 g
s
0 .253 .636 r
.1983 .46581 m .19555 .46437 L .18951 .4612 L p F P
0 g
s
0 .253 .636 r
.18951 .4612 m .19841 .4661 L p .1983 .46581 L F P
0 g
s
0 .374 .727 r
.2337 .48283 m .22693 .47967 L .22248 .47798 L closepath p F P
0 g
s
.141 .686 .786 r
.43179 .51634 m .43294 .51623 L .46063 .51398 L p F P
0 g
s
.178 .711 .825 r
.43179 .51634 m .43294 .51623 L .43153 .51633 L closepath p F P
0 g
s
0 0 0 r
.70617 .39755 m .70609 .39778 L .70649 .39726 L closepath p F P
0 g
s
.262 .752 .914 r
.43153 .51633 m .42488 .51494 L .40266 .51671 L closepath p F P
0 g
s
.295 .765 .938 r
.41851 .51356 m .42488 .51494 L .40266 .51671 L p F P
0 g
s
.295 .765 .938 r
.41596 .51356 m .41851 .51356 L p .40266 .51671 L F P
0 g
s
.295 .765 .938 r
.39407 .51504 m .41596 .51356 L p .40266 .51671 L F P
0 g
s
.295 .765 .938 r
.40266 .51671 m .40063 .5167 L .39407 .51504 L p F P
0 g
s
.219 .718 .911 r
.40063 .5167 m .39407 .51504 L .37756 .51545 L closepath p F P
0 g
s
0 0 .002 r
.71173 .39665 m .7224 .38219 L .70649 .39726 L p F P
0 g
s
0 0 .002 r
.70376 .40417 m .71173 .39665 L p .70649 .39726 L F P
0 g
s
0 0 .002 r
.70649 .39726 m .70609 .39778 L .70376 .40417 L p F P
0 g
s
0 0 .023 r
.70609 .39778 m .6939 .41229 L .70376 .40417 L closepath p F P
0 g
s
.338 .798 .939 r
.43294 .51623 m .43153 .51633 L .42488 .51494 L p F P
0 g
s
0 0 0 r
.65784 .44364 m .65142 .44813 L .65696 .44474 L closepath p F P
0 g
s
0 0 0 r
.65235 .44821 m .65696 .44474 L .65142 .44813 L p F P
0 g
s
0 0 0 r
.64925 .45022 m .65235 .44821 L p .65142 .44813 L F P
0 g
s
0 0 0 r
.63088 .4615 m .64925 .45022 L p .65142 .44813 L F P
0 g
s
.312 .788 .92 r
.46063 .51398 m .45573 .51313 L .43294 .51623 L closepath p F P
0 g
s
.338 .798 .939 r
.4489 .51191 m .45573 .51313 L .43294 .51623 L p F P
0 g
s
.338 .798 .939 r
.42488 .51494 m .4489 .51191 L p .43294 .51623 L F P
0 g
s
.677 .71 .873 r
.65376 .23464 m .67858 .22511 L .68453 .23419 L p F P
0 g
s
.697 .737 .882 r
.67858 .22511 m .65376 .23464 L .6478 .22764 L p F P
0 g
s
.727 .784 .898 r
.6232 .24032 m .6478 .22764 L .65376 .23464 L p F P
0 g
s
.271 .209 .601 r
.75437 .30833 m .74982 .29925 L .74095 .31178 L p F P
0 g
s
.271 .209 .601 r
.74484 .32166 m .75437 .30833 L p .74095 .31178 L F P
0 g
s
.271 .209 .601 r
.74095 .31178 m .74146 .31462 L .74484 .32166 L p F P
0 g
s
.517 .909 .783 r
.53771 .28176 m .53777 .28175 L .51674 .29474 L p F P
0 g
s
.517 .909 .783 r
.51674 .29474 m .51337 .2958 L .53771 .28176 L p F P
0 g
s
.177 .025 .422 r
.74419 .34458 m .73344 .35687 L .73464 .34574 L p F P
0 g
s
.177 .025 .422 r
.73464 .34574 m .74407 .33494 L .74419 .34458 L p F P
0 g
s
.707 .972 .928 r
.56831 .26619 m .54952 .27755 L .5646 .26578 L closepath p F P
0 g
s
.624 .961 .865 r
.56212 .26545 m .5646 .26578 L .54952 .27755 L p F P
0 g
s
.624 .961 .865 r
.53798 .28158 m .56212 .26545 L p .54952 .27755 L F P
0 g
s
.624 .961 .865 r
.53777 .28175 m .53798 .28158 L p .54952 .27755 L F P
0 g
s
0 .547 .819 r
.31688 .50669 m .30237 .50443 L .29486 .50177 L p F P
0 g
s
.217 0 0 r
.26459 .49402 m .26462 .49403 L .27972 .49876 L p F P
0 g
s
0 .539 .834 r
.28395 .49813 m .26462 .49403 L .27972 .49876 L p F P
0 g
s
0 .539 .834 r
.29048 .50008 m .28395 .49813 L p .27972 .49876 L F P
0 g
s
0 .539 .834 r
.27972 .49876 m .29486 .50177 L .29048 .50008 L p F P
0 g
s
.917 .53 .256 r
.1105 .39367 m .10954 .39034 L .10139 .38443 L p F P
0 g
s
0 0 0 r
.67673 .42886 m .65784 .44364 L .65696 .44474 L p F P
0 g
s
.258 .733 .938 r
.38694 .51314 m .39407 .51504 L .37756 .51545 L p F P
0 g
s
.258 .733 .938 r
.36335 .51344 m .38694 .51314 L p .37756 .51545 L F P
0 g
s
.258 .733 .938 r
.37756 .51545 m .36747 .5147 L .36335 .51344 L p F P
0 g
s
.617 .633 .843 r
.71261 .23428 m .70789 .2414 L p .68453 .23419 L F P
0 g
s
.617 .633 .843 r
.68453 .23419 m .70973 .22879 L .71261 .23428 L p F P
0 g
s
.638 .66 .855 r
.70973 .22879 m .68453 .23419 L .67858 .22511 L p F P
0 g
s
0 .248 .658 r
.30098 .29355 m .3133 .29979 L .30223 .2938 L p F P
0 g
s
0 .248 .658 r
.30223 .2938 m .29132 .28731 L .29115 .2872 L p F P
0 g
s
0 .248 .658 r
.29115 .2872 m .30098 .29355 L p .30223 .2938 L F P
0 g
s
.307 .225 .598 r
.74146 .31462 m .74484 .32166 L .74302 .32406 L closepath p F P
0 g
s
.457 0 0 r
.33763 .31174 m .35383 .31647 L .34208 .31057 L p F P
0 g
s
.457 0 0 r
.32853 .30574 m .33763 .31174 L p .34208 .31057 L F P
0 g
s
.457 0 0 r
.34208 .31057 m .32954 .30597 L .32853 .30574 L p F P
0 g
s
.534 .552 .82 r
.72962 .25437 m .72183 .25353 L .71575 .24047 L p F P
0 g
s
.187 .688 .91 r
.36747 .5147 m .36335 .51344 L .35529 .51324 L closepath p F P
0 g
s
0 0 0 r
.70129 .40833 m .70376 .40417 L .6939 .41229 L p F P
0 g
s
0 0 0 r
.69742 .41234 m .70129 .40833 L p .6939 .41229 L F P
0 g
s
0 0 0 r
.68124 .42566 m .69742 .41234 L p .6939 .41229 L F P
0 g
s
0 0 0 r
.6939 .41229 m .68213 .42399 L .68124 .42566 L p F P
0 g
s
.695 .155 0 r
.15272 .43612 m .15602 .43957 L .16647 .44619 L p F P
0 g
s
.526 0 0 r
.16522 .44672 m .17576 .45332 L .16647 .44619 L p F P
0 g
s
.526 0 0 r
.16647 .44619 m .15602 .43957 L .16522 .44672 L p F P
0 g
s
.586 .609 .842 r
.70789 .2414 m .71261 .23428 L .71575 .24047 L closepath p F P
0 g
s
.751 .859 .929 r
.6232 .24032 m .62133 .24138 L .62255 .2398 L closepath p F P
0 g
s
.744 .907 .949 r
.61719 .23544 m .62255 .2398 L .62133 .24138 L p F P
0 g
s
.744 .907 .949 r
.59269 .25069 m .61719 .23544 L p .62133 .24138 L F P
0 g
s
0 0 0 r
.68213 .42399 m .67673 .42886 L .68124 .42566 L closepath p F P
0 g
s
0 0 0 r
.6771 .43038 m .68124 .42566 L .67673 .42886 L p F P
0 g
s
0 0 0 r
.65696 .44474 m .6771 .43038 L p .67673 .42886 L F P
0 g
s
0 .414 .849 r
.26963 .27331 m .27969 .28051 L .26687 .27533 L p F P
0 g
s
0 .414 .849 r
.26687 .27533 m .25755 .26788 L .26963 .27331 L p F P
0 g
s
0 .397 .836 r
.25393 .26618 m .25755 .26788 L .26687 .27533 L p F P
0 g
s
.385 .83 .942 r
.4749 .51191 m .46063 .51398 L .45573 .51313 L p F P
0 g
s
.754 .86 .927 r
.64182 .22125 m .6478 .22764 L .6232 .24032 L p F P
0 g
s
.754 .86 .927 r
.63216 .22687 m .64182 .22125 L p .6232 .24032 L F P
0 g
s
.754 .86 .927 r
.6232 .24032 m .62255 .2398 L .63216 .22687 L p F P
0 g
s
.45 .882 .883 r
.54872 .49657 m .54814 .4966 L .572 .48806 L closepath p F P
0 g
s
.527 0 0 r
.36617 .31751 m .37234 .3203 L .36213 .31825 L closepath p F P
0 g
s
.921 .532 .233 r
.09332 .37723 m .09109 .36921 L .09929 .37697 L p F P
0 g
s
.921 .532 .233 r
.09929 .37697 m .10139 .38443 L .09332 .37723 L p F P
0 g
s
.007 .572 .796 r
.33276 .51007 m .3351 .51031 L .35529 .51324 L p F P
0 g
s
.201 .694 .921 r
.35609 .51107 m .3351 .51031 L .35529 .51324 L p F P
0 g
s
.201 .694 .921 r
.35529 .51324 m .36335 .51344 L .35609 .51107 L p F P
0 g
s
.37 .328 .68 r
.75655 .28925 m .74982 .29925 L .74207 .29137 L p F P
0 g
s
.37 .328 .68 r
.75476 .28178 m .75655 .28925 L p .74207 .29137 L F P
0 g
s
.37 .328 .68 r
.74207 .29137 m .75087 .27814 L .75476 .28178 L p F P
0 g
s
.917 .53 .256 r
.10139 .38443 m .10188 .38615 L .1105 .39367 L p F P
0 g
s
.866 .419 .074 r
.10599 .39484 m .11463 .40237 L .1105 .39367 L p F P
0 g
s
.866 .419 .074 r
.1105 .39367 m .10188 .38615 L .10599 .39484 L p F P
0 g
s
0 0 0 r
.67691 .43051 m .6771 .43038 L .65696 .44474 L p F P
0 g
s
0 0 0 r
.65696 .44474 m .65235 .44821 L .67691 .43051 L p F P
0 g
s
.753 .858 .927 r
.62255 .2398 m .61719 .23544 L .63216 .22687 L closepath p F P
0 g
s
.445 .858 .699 r
.63088 .4615 m .62774 .46292 L .64925 .45022 L closepath p F P
0 g
s
.725 .975 .924 r
.58953 .25272 m .56831 .26619 L .5646 .26578 L p F P
0 g
s
.45 .882 .884 r
.572 .48806 m .54814 .4966 L .54183 .49683 L p F P
0 g
s
0 0 0 r
.50687 .29972 m .50531 .30117 L .50746 .29975 L p F P
0 g
s
0 0 0 r
.50687 .29972 m .51067 .29745 L .50565 .29965 L p F P
0 g
s
.394 .809 .613 r
.53155 .28409 m .53771 .28176 L .51337 .2958 L p F P
0 g
s
.405 .818 .624 r
.53135 .28417 m .53155 .28409 L .51067 .29745 L p F P
0 g
s
.405 .818 .624 r
.51067 .29745 m .50687 .29972 L .53135 .28417 L p F P
0 g
s
0 0 0 r
.50746 .29975 m .5261 .28753 L p .50687 .29972 L F P
0 g
s
0 0 0 r
.50565 .29965 m .4875 .30757 L p .50687 .29972 L F P
0 g
s
0 0 0 r
.4875 .30757 m .4825 .31094 L .50687 .29972 L p F P
0 g
s
.303 .575 .935 r
.21665 .24646 m .22488 .24822 L .23276 .25635 L p F P
0 g
s
.334 .594 .941 r
.23889 .25078 m .22488 .24822 L .23276 .25635 L p F P
0 g
s
.334 .594 .941 r
.23276 .25635 m .24642 .25879 L .23889 .25078 L p F P
0 g
s
.394 .847 .776 r
.59722 .47717 m .60285 .47592 L .59815 .47801 L p F P
0 g
s
.394 .847 .776 r
.57261 .48784 m .59722 .47717 L p .59815 .47801 L F P
0 g
s
0 .391 .755 r
.21911 .47569 m .21017 .47217 L .22248 .47798 L p F P
0 g
s
0 .391 .755 r
.22248 .47798 m .22693 .47967 L .21911 .47569 L p F P
0 g
s
.786 .29 0 r
.12019 .41062 m .12926 .41792 L .12366 .40968 L p F P
0 g
s
.786 .29 0 r
.12366 .40968 m .11463 .40237 L .12019 .41062 L p F P
0 g
s
.687 .149 0 r
.15602 .43957 m .15272 .43612 L .14465 .43128 L p F P
0 g
s
.368 .824 .928 r
.48825 .5099 m .48659 .50965 L .4749 .51191 L closepath p F P
0 g
s
.385 .83 .942 r
.47993 .50861 m .48659 .50965 L .4749 .51191 L p F P
0 g
s
.385 .83 .942 r
.45573 .51313 m .47993 .50861 L p .4749 .51191 L F P
0 g
s
.224 .117 .516 r
.74648 .33178 m .74407 .33494 L .74302 .32406 L p F P
0 g
s
.224 .117 .516 r
.74302 .32406 m .74484 .32166 L .74648 .33178 L p F P
0 g
s
.049 .597 .836 r
.33276 .51007 m .3351 .51031 L .3313 .50967 L closepath p F P
0 g
s
0 .401 .715 r
.26459 .49402 m .26462 .49403 L .26455 .49401 L closepath p F P
0 g
s
.051 .562 .877 r
.2692 .4932 m .28395 .49813 L .26462 .49403 L p F P
0 g
s
.051 .562 .877 r
.25693 .49043 m .2692 .4932 L p .26462 .49403 L F P
0 g
s
.051 .562 .877 r
.26462 .49403 m .26455 .49401 L .25693 .49043 L p F P
0 g
s
0 .52 .846 r
.26455 .49401 m .25693 .49043 L .2506 .48889 L closepath p F P
0 g
s
0 0 0 r
.6778 .42981 m .6771 .43038 L .68124 .42566 L p F P
0 g
s
0 0 0 r
.68124 .42566 m .69742 .41234 L .6778 .42981 L p F P
0 g
s
.355 0 0 r
.42292 .32296 m .39773 .32311 L .39669 .32356 L p F P
0 g
s
.47 0 0 r
.39773 .32311 m .39669 .32356 L .39428 .32286 L closepath p F P
0 g
s
0 .236 .635 r
.18157 .45662 m .17576 .45332 L .18677 .45969 L p F P
0 g
s
0 .236 .635 r
.18677 .45969 m .18951 .4612 L .18157 .45662 L p F P
0 g
s
.366 0 0 r
.32954 .30597 m .32853 .30574 L .32745 .3053 L closepath p F P
0 g
s
.443 .429 .748 r
.75296 .27482 m .75087 .27814 L .73899 .27177 L p F P
0 g
s
.443 .429 .748 r
.748 .25896 m .75296 .27482 L p .73899 .27177 L F P
0 g
s
.443 .429 .748 r
.73899 .27177 m .7472 .25862 L .748 .25896 L p F P
0 g
s
.338 .786 .633 r
.62475 .46432 m .62774 .46292 L .60319 .47575 L p F P
0 g
s
.395 0 0 r
.42876 .32277 m .42747 .32355 L .42292 .32296 L closepath p F P
0 g
s
.355 0 0 r
.42336 .32712 m .42747 .32355 L .42292 .32296 L p F P
0 g
s
.355 0 0 r
.41069 .32724 m .42336 .32712 L p .42292 .32296 L F P
0 g
s
.355 0 0 r
.39669 .32356 m .41069 .32724 L p .42292 .32296 L F P
0 g
s
.495 0 0 r
.38501 .326 m .37234 .3203 L .39428 .32286 L p F P
0 g
s
.495 0 0 r
.39147 .32667 m .38501 .326 L p .39428 .32286 L F P
0 g
s
.495 0 0 r
.39428 .32286 m .39669 .32356 L .39147 .32667 L p F P
0 g
s
.165 0 0 r
.48207 .31138 m .4825 .31094 L .45835 .31725 L p F P
0 g
s
.165 0 0 r
.45835 .31725 m .45671 .31871 L .48207 .31138 L p F P
0 g
s
.291 0 0 r
.45162 .32324 m .45671 .31871 L .42876 .32277 L p F P
0 g
s
.291 0 0 r
.45041 .3234 m .45162 .32324 L p .42876 .32277 L F P
0 g
s
.291 0 0 r
.42876 .32277 m .42747 .32355 L .45041 .3234 L p F P
0 g
s
.534 .552 .82 r
.71575 .24047 m .73691 .24143 L .72962 .25437 L p F P
0 g
s
.525 .576 .85 r
.71261 .23428 m .71575 .24047 L .73691 .24143 L p F P
0 g
s
.048 0 .275 r
.74179 .35494 m .72945 .36899 L .73344 .35687 L p F P
0 g
s
.048 0 .275 r
.74381 .34859 m .74179 .35494 L p .73344 .35687 L F P
0 g
s
.048 0 .275 r
.73344 .35687 m .74419 .34458 L .74381 .34859 L p F P
0 g
s
0 .39 .84 r
.25755 .26788 m .25393 .26618 L .24642 .25879 L p F P
0 g
s
.502 .513 .8 r
.74763 .25789 m .7472 .25862 L .72962 .25437 L p F P
0 g
s
.502 .513 .8 r
.74167 .24217 m .74763 .25789 L p .72962 .25437 L F P
0 g
s
.502 .513 .8 r
.72962 .25437 m .73691 .24143 L .74167 .24217 L p F P
0 g
s
.663 .125 0 r
.13644 .42567 m .12926 .41792 L .13873 .42501 L p F P
0 g
s
.663 .125 0 r
.13723 .42626 m .13644 .42567 L p .13873 .42501 L F P
0 g
s
.663 .125 0 r
.13873 .42501 m .14465 .43128 L .13723 .42626 L p F P
0 g
s
.231 .7 .943 r
.35147 .50947 m .35609 .51107 L .3351 .51031 L p F P
0 g
s
.231 .7 .943 r
.34422 .50829 m .35147 .50947 L p .3351 .51031 L F P
0 g
s
.231 .7 .943 r
.32537 .50737 m .34422 .50829 L p .3351 .51031 L F P
0 g
s
.231 .7 .943 r
.3351 .51031 m .3313 .50967 L .32537 .50737 L p F P
0 g
s
.351 0 0 r
.32103 .30379 m .3133 .29979 L .32745 .3053 L p F P
0 g
s
.351 0 0 r
.32745 .3053 m .32853 .30574 L .32103 .30379 L p F P
0 g
s
.49 .901 .814 r
.62193 .46483 m .62475 .46432 L .60285 .47592 L p F P
0 g
s
.49 .901 .814 r
.60285 .47592 m .59722 .47717 L .62193 .46483 L p F P
0 g
s
.432 .858 .944 r
.51092 .50367 m .51456 .50419 L .48825 .5099 L p F P
0 g
s
.432 .858 .944 r
.48825 .5099 m .48659 .50965 L .51092 .50367 L p F P
0 g
s
.166 .659 .918 r
.3313 .50967 m .32537 .50737 L .31688 .50669 L closepath p F P
0 g
s
.203 .104 .513 r
.75606 .31847 m .74648 .33178 L .74484 .32166 L p F P
0 g
s
.203 .104 .513 r
.74484 .32166 m .75437 .30833 L .75606 .31847 L p F P
0 g
s
0 .475 .848 r
.29132 .28731 m .29115 .2872 L .29103 .28716 L closepath p F P
0 g
s
.661 .112 0 r
.33763 .31174 m .32853 .30574 L .32103 .30379 L p F P
0 g
s
.378 .843 .865 r
.53968 .49691 m .54183 .49683 L .51741 .50407 L p F P
0 g
s
.378 .843 .865 r
.51741 .50407 m .51456 .50419 L .53968 .49691 L p F P
0 g
s
.472 0 0 r
.28364 .28201 m .27612 .27604 L p .27954 .27866 L F P
0 g
s
.019 .492 .875 r
.28721 .28492 m .29103 .28716 L p .28364 .28201 L F P
0 g
s
.019 .492 .875 r
.29103 .28716 m .29115 .2872 L .28364 .28201 L p F P
0 g
s
.489 0 0 r
.30098 .29355 m .29115 .2872 L .28364 .28201 L p F P
0 g
s
.489 0 0 r
.28364 .28201 m .29007 .28671 L .30098 .29355 L p F P
0 g
s
.472 0 0 r
.29007 .28671 m .28364 .28201 L p .27954 .27866 L F P
0 g
s
.019 .492 .875 r
.28364 .28201 m .27969 .28051 L .28721 .28492 L p F P
0 g
s
0 0 .132 r
.72613 .37258 m .72511 .37735 L .72945 .36899 L closepath p F P
0 g
s
.766 .941 .939 r
.59269 .25069 m .58953 .25272 L .5918 .25034 L closepath p F P
0 g
s
.725 .975 .924 r
.58659 .24819 m .5918 .25034 L .58953 .25272 L p F P
0 g
s
.725 .975 .924 r
.57097 .25925 m .58659 .24819 L p .58953 .25272 L F P
0 g
s
.725 .975 .924 r
.5646 .26578 m .57097 .25925 L p .58953 .25272 L F P
0 g
s
.479 0 0 r
.39669 .32356 m .41069 .32724 L .39147 .32667 L closepath p F P
0 g
s
.212 .707 .917 r
.38694 .51314 m .36335 .51344 L .35609 .51107 L p F P
0 g
s
0 .379 .738 r
.23725 .48346 m .22693 .47967 L .21911 .47569 L p F P
0 g
s
.788 .942 .927 r
.61114 .23119 m .61719 .23544 L .59269 .25069 L p F P
0 g
s
.788 .942 .927 r
.60197 .23759 m .61114 .23119 L p .59269 .25069 L F P
0 g
s
.788 .942 .927 r
.59269 .25069 m .5918 .25034 L .60197 .23759 L p F P
0 g
s
.638 .66 .855 r
.67858 .22511 m .70375 .21817 L .70973 .22879 L p F P
0 g
s
.658 .687 .866 r
.70375 .21817 m .67858 .22511 L .67263 .21672 L p F P
0 g
s
.697 .737 .882 r
.6478 .22764 m .67263 .21672 L .67858 .22511 L p F P
0 g
s
.352 0 0 r
.19841 .4661 m .18951 .4612 L .18157 .45662 L p F P
0 g
s
.526 0 0 r
.36484 .32273 m .38501 .326 L .37234 .3203 L p F P
0 g
s
.526 0 0 r
.35875 .31887 m .36484 .32273 L p .37234 .3203 L F P
0 g
s
.526 0 0 r
.37234 .3203 m .36213 .31825 L .35875 .31887 L p F P
0 g
s
.718 .762 .887 r
.67263 .21672 m .6478 .22764 L .64182 .22125 L p F P
0 g
s
.687 .149 0 r
.14465 .43128 m .14601 .43274 L .15602 .43957 L p F P
0 g
s
.5 0 0 r
.15514 .43989 m .16522 .44672 L .15602 .43957 L p F P
0 g
s
.5 0 0 r
.15602 .43957 m .14601 .43274 L .15514 .43989 L p F P
0 g
s
.357 0 0 r
.42747 .32355 m .45041 .3234 L .42336 .32712 L closepath p F P
0 g
s
.572 .61 .852 r
.70973 .22879 m .71523 .22834 L .71261 .23428 L closepath p F P
0 g
s
.525 .576 .85 r
.7355 .22785 m .71523 .22834 L .71261 .23428 L p F P
0 g
s
.525 .576 .85 r
.73944 .23679 m .7355 .22785 L p .71261 .23428 L F P
0 g
s
.525 .576 .85 r
.73691 .24143 m .73944 .23679 L p .71261 .23428 L F P
0 g
s
.922 .534 .236 r
.10188 .38615 m .10139 .38443 L .09332 .37723 L p F P
0 g
s
0 .403 .85 r
.26065 .26563 m .26963 .27331 L .25755 .26788 L p F P
0 g
s
0 .403 .85 r
.25755 .26788 m .24899 .26006 L .26065 .26563 L p F P
0 g
s
0 .39 .84 r
.24642 .25879 m .24899 .26006 L .25755 .26788 L p F P
0 g
s
.422 .854 .939 r
.51092 .50367 m .48659 .50965 L .47993 .50861 L p F P
0 g
s
.252 .742 .919 r
.41596 .51356 m .39407 .51504 L .38694 .51314 L p F P
0 g
s
.787 .939 .928 r
.5918 .25034 m .58659 .24819 L .60197 .23759 L closepath p F P
0 g
s
.182 0 0 r
.47736 .31618 m .48207 .31138 L .45671 .31871 L p F P
0 g
s
.182 0 0 r
.45671 .31871 m .45162 .32324 L .47736 .31618 L p F P
0 g
s
0 0 0 r
.70376 .40417 m .70129 .40833 L .71173 .39665 L closepath p F P
0 g
s
0 .547 .819 r
.29486 .50177 m .29986 .50262 L .31688 .50669 L p F P
0 g
s
.183 .664 .929 r
.31794 .50428 m .29986 .50262 L .31688 .50669 L p F P
0 g
s
.183 .664 .929 r
.31688 .50669 m .32537 .50737 L .31794 .50428 L p F P
0 g
s
.546 0 0 r
.36213 .31825 m .35875 .31887 L .35383 .31647 L closepath p F P
0 g
s
0 .391 .767 r
.21125 .47134 m .19841 .4661 L .21017 .47217 L p F P
0 g
s
0 .391 .767 r
.21017 .47217 m .21911 .47569 L .21125 .47134 L p F P
0 g
s
.355 .816 .927 r
.47993 .50861 m .45573 .51313 L .4489 .51191 L p F P
0 g
s
.33 .792 .939 r
.44846 .51182 m .4489 .51191 L .42488 .51494 L p F P
0 g
s
.33 .792 .939 r
.42488 .51494 m .41851 .51356 L .44846 .51182 L p F P
0 g
s
.117 0 .405 r
.74551 .34287 m .74419 .34458 L .74407 .33494 L p F P
0 g
s
.117 0 .405 r
.74407 .33494 m .74648 .33178 L .74551 .34287 L p F P
0 g
s
.018 .531 .865 r
.24922 .48654 m .23725 .48346 L .2506 .48889 L p F P
0 g
s
.018 .531 .865 r
.2506 .48889 m .25693 .49043 L .24922 .48654 L p F P
0 g
s
.922 .534 .236 r
.09332 .37723 m .09365 .3784 L .10188 .38615 L p F P
0 g
s
.862 .414 .042 r
.09774 .3871 m .10599 .39484 L .10188 .38615 L p F P
0 g
s
.862 .414 .042 r
.10188 .38615 m .09365 .3784 L .09774 .3871 L p F P
0 g
s
0 0 .142 r
.73519 .36804 m .74179 .35494 L .72945 .36899 L p F P
0 g
s
0 0 .142 r
.72453 .38009 m .73519 .36804 L p .72945 .36899 L F P
0 g
s
0 0 .142 r
.72945 .36899 m .72511 .37735 L .72453 .38009 L p F P
0 g
s
.036 .569 .856 r
.29486 .50177 m .29986 .50262 L .29048 .50008 L closepath p F P
0 g
s
.434 .85 .688 r
.64925 .45022 m .62774 .46292 L .62475 .46432 L p F P
0 g
s
.763 .978 .915 r
.5646 .26578 m .56212 .26545 L .57097 .25925 L closepath p F P
0 g
s
.589 .631 .861 r
.71523 .22834 m .70973 .22879 L .70375 .21817 L p F P
0 g
s
.418 0 0 r
.31122 .29992 m .30098 .29355 L .3133 .29979 L p F P
0 g
s
.418 0 0 r
.3165 .30228 m .31122 .29992 L p .3133 .29979 L F P
0 g
s
.418 0 0 r
.3133 .29979 m .32103 .30379 L .3165 .30228 L p F P
0 g
s
.313 .797 .744 r
.57261 .48784 m .572 .48806 L .5726 .48784 L closepath p F P
0 g
s
.45 .882 .884 r
.56642 .48798 m .5726 .48784 L .572 .48806 L p F P
0 g
s
.45 .882 .884 r
.54183 .49683 m .56642 .48798 L p .572 .48806 L F P
0 g
s
.774 .279 0 r
.11152 .40309 m .12019 .41062 L .11463 .40237 L p F P
0 g
s
.774 .279 0 r
.11463 .40237 m .10599 .39484 L .11152 .40309 L p F P
0 g
s
.399 .85 .775 r
.59546 .47757 m .59722 .47717 L .57261 .48784 L p F P
0 g
s
.399 .85 .775 r
.57261 .48784 m .5726 .48784 L .59546 .47757 L p F P
0 g
s
.521 .916 .9 r
.59115 .47756 m .59546 .47757 L .5726 .48784 L p F P
0 g
s
.521 .916 .9 r
.5726 .48784 m .56642 .48798 L .59115 .47756 L p F P
0 g
s
.551 0 0 r
.34775 .3183 m .33763 .31174 L .35383 .31647 L p F P
0 g
s
.551 0 0 r
.35399 .31991 m .34775 .3183 L p .35383 .31647 L F P
0 g
s
.551 0 0 r
.35383 .31647 m .35875 .31887 L .35399 .31991 L p F P
0 g
s
.283 .216 .603 r
.7588 .30178 m .75437 .30833 L .74982 .29925 L p F P
0 g
s
.283 .216 .603 r
.74982 .29925 m .75655 .28925 L .7588 .30178 L p F P
0 g
s
0 .24 .656 r
.1736 .4516 m .16522 .44672 L .17576 .45332 L p F P
0 g
s
0 .24 .656 r
.17576 .45332 m .18157 .45662 L .1736 .4516 L p F P
0 g
s
.679 .978 .872 r
.53777 .28175 m .53771 .28176 L .53798 .28158 L closepath p F P
0 g
s
.752 .881 .938 r
.63216 .22687 m .61719 .23544 L .61114 .23119 L p F P
0 g
s
.561 .925 .763 r
.53798 .28158 m .53771 .28176 L .53155 .28409 L p F P
0 g
s
.695 .981 .884 r
.56212 .26545 m .53798 .28158 L .55685 .2658 L closepath p F P
0 g
s
.561 .925 .763 r
.55588 .26585 m .55685 .2658 L .53798 .28158 L p F P
0 g
s
.561 .925 .763 r
.53224 .28351 m .55588 .26585 L p .53798 .28158 L F P
0 g
s
.561 .925 .763 r
.53155 .28409 m .53224 .28351 L p .53798 .28158 L F P
0 g
s
.486 .886 .95 r
.53544 .49629 m .53968 .49691 L .51456 .50419 L p F P
0 g
s
.486 .886 .95 r
.51456 .50419 m .51092 .50367 L .53544 .49629 L p F P
0 g
s
.647 .116 0 r
.12732 .41838 m .13644 .42567 L .12926 .41792 L p F P
0 g
s
.647 .116 0 r
.12926 .41792 m .12019 .41062 L .12732 .41838 L p F P
0 g
s
.004 0 .158 r
.72511 .37735 m .7224 .38219 L .72453 .38009 L closepath p F P
0 g
s
.008 .46 .869 r
.27612 .27604 m .26963 .27331 L .27969 .28051 L p F P
0 g
s
.008 .46 .869 r
.27969 .28051 m .28364 .28201 L .27612 .27604 L p F P
0 g
s
.087 0 .393 r
.75513 .32958 m .74551 .34287 L .74648 .33178 L p F P
0 g
s
.087 0 .393 r
.74648 .33178 m .75606 .31847 L .75513 .32958 L p F P
0 g
s
.666 .129 0 r
.14465 .43128 m .14601 .43274 L .13723 .42626 L closepath p F P
0 g
s
.007 .395 .849 r
.24899 .26006 m .24642 .25879 L .23889 .25078 L p F P
0 g
s
.589 .631 .861 r
.70375 .21817 m .72057 .21589 L .71523 .22834 L p F P
0 g
s
.554 .579 .834 r
.72941 .21509 m .72057 .21589 L .71523 .22834 L p F P
0 g
s
.554 .579 .834 r
.71523 .22834 m .7355 .22785 L .72941 .21509 L p F P
0 g
s
.216 .669 .948 r
.31237 .50182 m .31794 .50428 L .29986 .50262 L p F P
0 g
s
.216 .669 .948 r
.30811 .50071 m .31237 .50182 L p .29986 .50262 L F P
0 g
s
.216 .669 .948 r
.2873 .49855 m .30811 .50071 L p .29986 .50262 L F P
0 g
s
.216 .669 .948 r
.29986 .50262 m .29048 .50008 L .2873 .49855 L p F P
0 g
s
0 0 0 r
.72203 .38647 m .71173 .39665 L .7224 .38219 L p F P
0 g
s
0 0 0 r
.7224 .38219 m .72453 .38009 L .72203 .38647 L p F P
0 g
s
.191 .676 .928 r
.34422 .50829 m .32537 .50737 L .31794 .50428 L p F P
0 g
s
0 0 0 r
.65235 .44821 m .64925 .45022 L .6519 .44856 L closepath p F P
0 g
s
.434 .85 .688 r
.6467 .45064 m .6519 .44856 L .64925 .45022 L p F P
0 g
s
.434 .85 .688 r
.64014 .45463 m .6467 .45064 L p .64925 .45022 L F P
0 g
s
.434 .85 .688 r
.62475 .46432 m .64014 .45463 L p .64925 .45022 L F P
0 g
s
.012 .531 .859 r
.2692 .4932 m .25693 .49043 L .24922 .48654 L p F P
0 g
s
.428 0 0 r
.14551 .43284 m .15514 .43989 L .14601 .43274 L p F P
0 g
s
.428 0 0 r
.13656 .42577 m .14551 .43284 L p .14601 .43274 L F P
0 g
s
.428 0 0 r
.14601 .43274 m .13723 .42626 L .13656 .42577 L p F P
0 g
s
.753 .83 .911 r
.64182 .22125 m .63216 .22687 L .63709 .21665 L closepath p F P
0 g
s
.752 .881 .938 r
.63582 .2154 m .63709 .21665 L .63216 .22687 L p F P
0 g
s
.752 .881 .938 r
.61114 .23119 m .63582 .2154 L p .63216 .22687 L F P
0 g
s
.017 0 0 r
.50531 .30117 m .50687 .29972 L .4825 .31094 L p F P
0 g
s
.017 0 0 r
.4825 .31094 m .48207 .31138 L .50531 .30117 L p F P
0 g
s
.549 .916 .745 r
.6467 .45064 m .67146 .43401 L p .65636 .44525 L F P
0 g
s
.549 .916 .745 r
.6519 .44856 m .65172 .44863 L p .65636 .44525 L F P
0 g
s
.549 .916 .745 r
.65172 .44863 m .6467 .45064 L p .65636 .44525 L F P
0 g
s
0 0 0 r
.67691 .43051 m .65235 .44821 L p .66866 .43625 L F P
0 g
s
0 0 0 r
.67191 .43386 m .67204 .43378 L p .66866 .43625 L F P
0 g
s
0 0 0 r
.67204 .43378 m .67691 .43051 L p .66866 .43625 L F P
0 g
s
0 0 0 r
.65235 .44821 m .6519 .44856 L .67191 .43386 L p F P
0 g
s
.363 .327 .684 r
.75087 .27814 m .75296 .27482 L .75476 .28178 L closepath p F P
0 g
s
.658 .687 .866 r
.67263 .21672 m .69779 .20831 L .70375 .21817 L p F P
0 g
s
.678 .712 .874 r
.69779 .20831 m .67263 .21672 L .66668 .20891 L p F P
0 g
s
.718 .762 .887 r
.64182 .22125 m .66668 .20891 L .67263 .21672 L p F P
0 g
s
.451 .882 .883 r
.56367 .48805 m .56642 .48798 L .54183 .49683 L p F P
0 g
s
.451 .882 .883 r
.54183 .49683 m .53968 .49691 L .56367 .48805 L p F P
0 g
s
.716 .986 .881 r
.57097 .25925 m .56212 .26545 L .55685 .2658 L p F P
0 g
s
0 .379 .738 r
.21911 .47569 m .22453 .47776 L .23725 .48346 L p F P
0 g
s
.025 .528 .872 r
.24146 .48232 m .22453 .47776 L .23725 .48346 L p F P
0 g
s
.025 .528 .872 r
.23725 .48346 m .24922 .48654 L .24146 .48232 L p F P
0 g
s
.618 .078 0 r
.35875 .31887 m .36484 .32273 L .35399 .31991 L closepath p F P
0 g
s
.661 .112 0 r
.32103 .30379 m .32384 .30607 L .33763 .31174 L p F P
0 g
s
.663 .115 0 r
.33249 .31315 m .34775 .3183 L .33763 .31174 L p F P
0 g
s
.663 .115 0 r
.33763 .31174 m .32384 .30607 L .33249 .31315 L p F P
0 g
s
.352 0 0 r
.18157 .45662 m .18718 .45979 L .19841 .4661 L p F P
0 g
s
0 .392 .782 r
.20093 .46555 m .18718 .45979 L .19841 .4661 L p F P
0 g
s
0 .392 .782 r
.20877 .46986 m .20093 .46555 L p .19841 .4661 L F P
0 g
s
0 .392 .782 r
.19841 .4661 m .21125 .47134 L .20877 .46986 L p F P
0 g
s
.024 .406 .857 r
.25265 .2575 m .26065 .26563 L .24899 .26006 L p F P
0 g
s
.024 .406 .857 r
.24899 .26006 m .24112 .2519 L .25265 .2575 L p F P
0 g
s
.007 .395 .849 r
.23889 .25078 m .24112 .2519 L .24899 .26006 L p F P
0 g
s
0 0 0 r
.72593 .38208 m .72203 .38647 L .72453 .38009 L p F P
0 g
s
0 0 0 r
.72453 .38009 m .73519 .36804 L .72593 .38208 L p F P
0 g
s
0 0 0 r
.50045 .30562 m .50531 .30117 L .48207 .31138 L p F P
0 g
s
0 0 0 r
.48207 .31138 m .47736 .31618 L .50045 .30562 L p F P
0 g
s
.161 .635 .928 r
.29048 .50008 m .2873 .49855 L .28395 .49813 L closepath p F P
0 g
s
.549 .916 .745 r
.67146 .43401 m .67191 .43386 L .6519 .44856 L p F P
0 g
s
0 0 0 r
.7205 .38875 m .72203 .38647 L .71173 .39665 L p F P
0 g
s
0 0 0 r
.71309 .39734 m .7205 .38875 L p .71173 .39665 L F P
0 g
s
0 0 0 r
.70048 .40973 m .71309 .39734 L p .71173 .39665 L F P
0 g
s
0 0 0 r
.71173 .39665 m .70129 .40833 L .70048 .40973 L p F P
0 g
s
.783 .963 .923 r
.58659 .24819 m .57097 .25925 L .58168 .24684 L closepath p F P
0 g
s
.716 .986 .881 r
.58044 .24649 m .58168 .24684 L .57097 .25925 L p F P
0 g
s
.716 .986 .881 r
.55909 .26334 m .58044 .24649 L p .57097 .25925 L F P
0 g
s
.716 .986 .881 r
.55685 .2658 m .55909 .26334 L p .57097 .25925 L F P
0 g
s
.477 0 0 r
.29939 .29341 m .31122 .29992 L .30098 .29355 L p F P
0 g
s
.477 0 0 r
.30098 .29355 m .29007 .28671 L .29939 .29341 L p F P
0 g
s
.743 .827 .917 r
.6607 .2016 m .66668 .20891 L .64182 .22125 L p F P
0 g
s
.743 .827 .917 r
.63887 .21373 m .6607 .2016 L p .64182 .22125 L F P
0 g
s
.743 .827 .917 r
.64182 .22125 m .63709 .21665 L .63887 .21373 L p F P
0 g
s
0 .226 .639 r
.18718 .45979 m .18157 .45662 L .1736 .4516 L p F P
0 g
s
0 .386 .76 r
.22453 .47776 m .21911 .47569 L .21125 .47134 L p F P
0 g
s
.608 .633 .85 r
.72057 .21589 m .70375 .21817 L .69779 .20831 L p F P
0 g
s
0 0 .251 r
.74419 .34458 m .74381 .34859 L .74551 .34287 L closepath p F P
0 g
s
.509 .868 .63 r
.6771 .43038 m .67691 .43051 L .6778 .42981 L closepath p F P
0 g
s
.439 .431 .753 r
.7472 .25862 m .74763 .25789 L .748 .25896 L closepath p F P
0 g
s
.502 .514 .802 r
.73691 .24143 m .73944 .23679 L .74167 .24217 L closepath p F P
0 g
s
.504 .011 .02 r
.42336 .32712 m .42031 .32975 L .41069 .32724 L closepath p F P
0 g
s
.479 0 0 r
.41833 .33202 m .42031 .32975 L .41069 .32724 L p F P
0 g
s
.479 0 0 r
.39803 .33167 m .41833 .33202 L p .41069 .32724 L F P
0 g
s
.479 0 0 r
.38936 .32793 m .39803 .33167 L p .41069 .32724 L F P
0 g
s
.479 0 0 r
.41069 .32724 m .39147 .32667 L .38936 .32793 L p F P
0 g
s
.356 0 0 r
.45041 .3234 m .42336 .32712 L .42031 .32975 L p F P
0 g
s
.212 .707 .917 r
.38642 .51299 m .38694 .51314 L p .35609 .51107 L F P
0 g
s
.212 .707 .917 r
.35609 .51107 m .36517 .51106 L .38642 .51299 L p F P
0 g
s
.25 .721 .943 r
.35609 .51107 m .36517 .51106 L .35147 .50947 L closepath p F P
0 g
s
.567 .938 .842 r
.62475 .46432 m .62193 .46483 L .64014 .45463 L closepath p F P
0 g
s
.498 .86 .619 r
.6778 .42981 m .67691 .43051 L .67191 .43386 L p F P
0 g
s
0 0 0 r
.69621 .41411 m .6778 .42981 L .69742 .41234 L p F P
0 g
s
.498 .86 .619 r
.69614 .41415 m .69621 .41411 L .6778 .42981 L p F P
0 g
s
.498 .86 .619 r
.67343 .43258 m .69614 .41415 L p .6778 .42981 L F P
0 g
s
.498 .86 .619 r
.67191 .43386 m .67343 .43258 L p .6778 .42981 L F P
0 g
s
0 0 0 r
.70129 .40833 m .69742 .41234 L .70048 .40973 L closepath p F P
0 g
s
.565 .054 0 r
.39147 .32667 m .38936 .32793 L .38501 .326 L closepath p F P
0 g
s
.384 .378 .729 r
.748 .25896 m .75785 .26543 L .75296 .27482 L closepath p F P
0 g
s
.359 .381 .747 r
.74763 .25789 m .748 .25896 L .75785 .26543 L p F P
0 g
s
.491 .901 .81 r
.61732 .46569 m .62193 .46483 L .59722 .47717 L p F P
0 g
s
.491 .901 .81 r
.59722 .47717 m .59546 .47757 L .61732 .46569 L p F P
0 g
s
.443 .458 .78 r
.74167 .24217 m .75304 .24619 L .74763 .25789 L closepath p F P
0 g
s
.359 .381 .747 r
.76394 .25292 m .75304 .24619 L .74763 .25789 L p F P
0 g
s
.359 .381 .747 r
.75785 .26543 m .76394 .25292 L p .74763 .25789 L F P
0 g
s
.622 .056 0 r
.32103 .30379 m .32384 .30607 L .3165 .30228 L closepath p F P
0 g
s
0 .247 .677 r
.16559 .4461 m .15514 .43989 L .16522 .44672 L p F P
0 g
s
0 .247 .677 r
.16522 .44672 m .1736 .4516 L .16559 .4461 L p F P
0 g
s
0 0 0 r
.69742 .41234 m .70048 .40973 L .69621 .41411 L p F P
0 g
s
.28 .272 .672 r
.76502 .27355 m .75785 .26543 L .75296 .27482 L p F P
0 g
s
.28 .272 .672 r
.75834 .28614 m .76502 .27355 L p .75296 .27482 L F P
0 g
s
.28 .272 .672 r
.75296 .27482 m .75476 .28178 L .75834 .28614 L p F P
0 g
s
.182 .64 .939 r
.2797 .49465 m .2692 .4932 L .28395 .49813 L p F P
0 g
s
.182 .64 .939 r
.28395 .49813 m .2873 .49855 L .2797 .49465 L p F P
0 g
s
.484 .885 .949 r
.53544 .49629 m .51092 .50367 L .50435 .5027 L p F P
0 g
s
.422 .854 .939 r
.47993 .50861 m .50435 .5027 L .51092 .50367 L p F P
0 g
s
.757 .265 0 r
.10325 .39535 m .11152 .40309 L .10599 .39484 L p F P
0 g
s
.757 .265 0 r
.10599 .39484 m .09774 .3871 L .10325 .39535 L p F P
0 g
s
.573 .081 .048 r
.37521 .32932 m .36484 .32273 L .38501 .326 L p F P
0 g
s
.573 .081 .048 r
.38556 .33077 m .37521 .32932 L p .38501 .326 L F P
0 g
s
.573 .081 .048 r
.38501 .326 m .38936 .32793 L .38556 .33077 L p F P
0 g
s
.775 .962 .927 r
.60197 .23759 m .58659 .24819 L .58168 .24684 L p F P
0 g
s
0 0 .257 r
.75174 .34158 m .75513 .32958 L .74551 .34287 L p F P
0 g
s
0 0 .257 r
.74339 .35302 m .75174 .34158 L p .74551 .34287 L F P
0 g
s
0 0 .257 r
.74551 .34287 m .74381 .34859 L .74339 .35302 L p F P
0 g
s
.182 .09 .508 r
.75993 .31276 m .75606 .31847 L .75437 .30833 L p F P
0 g
s
.182 .09 .508 r
.75437 .30833 m .7588 .30178 L .75993 .31276 L p F P
0 g
s
.314 .282 .662 r
.75476 .28178 m .75834 .28614 L .75655 .28925 L closepath p F P
0 g
s
.541 .91 .954 r
.56014 .48748 m .56367 .48805 L .53968 .49691 L p F P
0 g
s
.541 .91 .954 r
.53968 .49691 m .53544 .49629 L .56014 .48748 L p F P
0 g
s
.023 .442 .87 r
.26859 .26917 m .26065 .26563 L .26963 .27331 L p F P
0 g
s
.023 .442 .87 r
.26963 .27331 m .27612 .27604 L .26859 .26917 L p F P
0 g
s
.621 .099 0 r
.11862 .41086 m .12732 .41838 L .12019 .41062 L p F P
0 g
s
.621 .099 0 r
.12019 .41062 m .11152 .40309 L .11862 .41086 L p F P
0 g
s
.252 .742 .919 r
.38694 .51314 m .38834 .51306 L .41596 .51356 L p F P
0 g
s
.286 .754 .943 r
.38694 .51314 m .38834 .51306 L .38642 .51299 L closepath p F P
0 g
s
.429 .822 .985 r
.44202 .50968 m .44846 .51182 L .41851 .51356 L p F P
0 g
s
.429 .822 .985 r
.41851 .51356 m .4179 .51335 L .44202 .50968 L p F P
0 g
s
.378 .796 .976 r
.41851 .51356 m .4179 .51335 L .41596 .51356 L closepath p F P
0 g
s
.389 .798 .981 r
.41086 .51078 m .38834 .51306 L .41596 .51356 L p F P
0 g
s
.389 .798 .981 r
.41596 .51356 m .4179 .51335 L .41086 .51078 L p F P
0 g
s
.434 .857 .948 r
.50339 .50255 m .50435 .5027 L .47993 .50861 L p F P
0 g
s
.434 .857 .948 r
.47993 .50861 m .47666 .50808 L .50339 .50255 L p F P
0 g
s
.355 .816 .927 r
.47666 .50808 m .47993 .50861 L p .4489 .51191 L F P
0 g
s
.425 .469 .802 r
.73944 .23679 m .74167 .24217 L .75304 .24619 L p F P
0 g
s
.18 .646 .936 r
.30811 .50071 m .2873 .49855 L .2797 .49465 L p F P
0 g
s
.404 .795 .988 r
.40377 .50807 m .41086 .51078 L .38834 .51306 L p F P
0 g
s
.404 .795 .988 r
.37977 .51029 m .40377 .50807 L p .38834 .51306 L F P
0 g
s
.404 .795 .988 r
.38834 .51306 m .38642 .51299 L .37977 .51029 L p F P
0 g
s
.345 .765 .977 r
.38642 .51299 m .37977 .51029 L .36517 .51106 L closepath p F P
0 g
s
0 0 0 r
.69641 .41391 m .69621 .41411 L .70048 .40973 L p F P
0 g
s
0 0 0 r
.70048 .40973 m .71309 .39734 L .69641 .41391 L p F P
0 g
s
.232 .182 .593 r
.76252 .29537 m .7588 .30178 L .75655 .28925 L p F P
0 g
s
.232 .182 .593 r
.75655 .28925 m .75834 .28614 L .76252 .29537 L p F P
0 g
s
.795 .908 .919 r
.61114 .23119 m .60197 .23759 L .60732 .22891 L closepath p F P
0 g
s
.775 .962 .927 r
.60506 .22753 m .60732 .22891 L .60197 .23759 L p F P
0 g
s
.775 .962 .927 r
.58382 .24392 m .60506 .22753 L p .60197 .23759 L F P
0 g
s
.775 .962 .927 r
.58168 .24684 m .58382 .24392 L p .60197 .23759 L F P
0 g
s
.416 .817 .982 r
.44202 .50968 m .4179 .51335 L .41086 .51078 L p F P
0 g
s
.358 0 0 r
.45162 .32324 m .45144 .32339 L .45041 .3234 L closepath p F P
0 g
s
.356 0 0 r
.4472 .32868 m .45144 .32339 L .45041 .3234 L p F P
0 g
s
.356 0 0 r
.42994 .33071 m .4472 .32868 L p .45041 .3234 L F P
0 g
s
.356 0 0 r
.42031 .32975 m .42994 .33071 L p .45041 .3234 L F P
0 g
s
.625 .061 0 r
.31946 .30713 m .33249 .31315 L .32384 .30607 L p F P
0 g
s
.625 .061 0 r
.31348 .30129 m .31946 .30713 L p .32384 .30607 L F P
0 g
s
.625 .061 0 r
.32384 .30607 m .3165 .30228 L .31348 .30129 L p F P
0 g
s
.355 .816 .927 r
.4489 .51191 m .45147 .51145 L .47666 .50808 L p F P
0 g
s
.381 .824 .946 r
.4489 .51191 m .45147 .51145 L .44846 .51182 L closepath p F P
0 g
s
.188 0 0 r
.47574 .31782 m .47736 .31618 L .45162 .32324 L p F P
0 g
s
.188 0 0 r
.45162 .32324 m .45144 .32339 L .47574 .31782 L p F P
0 g
s
.024 0 .27 r
.74381 .34859 m .74179 .35494 L .74339 .35302 L closepath p F P
0 g
s
.456 0 0 r
.13647 .42569 m .13723 .42626 L .13656 .42577 L p F P
0 g
s
.443 0 0 r
.13656 .42577 m .12851 .41931 L p .14262 .43054 L F P
0 g
s
.443 0 0 r
.14551 .43284 m .13656 .42577 L p .14262 .43054 L F P
0 g
s
.456 0 0 r
.13656 .42577 m .13644 .42567 L .13647 .42569 L p F P
0 g
s
0 .386 .76 r
.21125 .47134 m .21241 .4718 L .22453 .47776 L p F P
0 g
s
.036 .526 .881 r
.22948 .47654 m .21241 .4718 L .22453 .47776 L p F P
0 g
s
.036 .526 .881 r
.24076 .48191 m .22948 .47654 L p .22453 .47776 L F P
0 g
s
.036 .526 .881 r
.22453 .47776 m .24146 .48232 L .24076 .48191 L p F P
0 g
s
.493 .525 .819 r
.7355 .22785 m .74255 .22896 L .73944 .23679 L closepath p F P
0 g
s
.425 .469 .802 r
.75852 .23378 m .74255 .22896 L .73944 .23679 L p F P
0 g
s
.425 .469 .802 r
.75304 .24619 m .75852 .23378 L p .73944 .23679 L F P
0 g
s
.294 0 0 r
.47306 .32161 m .47574 .31782 L .45144 .32339 L p F P
0 g
s
.294 0 0 r
.45144 .32339 m .4472 .32868 L .47306 .32161 L p F P
0 g
s
.62 .081 0 r
.35688 .32532 m .37521 .32932 L .36484 .32273 L p F P
0 g
s
.62 .081 0 r
.35124 .32052 m .35688 .32532 L p .36484 .32273 L F P
0 g
s
.62 .081 0 r
.36484 .32273 m .35399 .31991 L .35124 .32052 L p F P
0 g
s
.584 .942 .911 r
.616 .46563 m .61732 .46569 L .59546 .47757 L p F P
0 g
s
.584 .942 .911 r
.59546 .47757 m .59115 .47756 L .616 .46563 L p F P
0 g
s
0 0 0 r
.52492 .28827 m .5261 .28753 L .52405 .28888 L p F P
0 g
s
0 0 0 r
.52405 .28888 m .50531 .30117 L p .52492 .28827 L F P
0 g
s
0 0 0 r
.5261 .28753 m .53135 .28417 L .50705 .2996 L p F P
0 g
s
0 0 0 r
.5076 .29925 m .5261 .28753 L .50705 .2996 L F
.52492 .28827 m .52118 .29174 L p .52586 .28762 L F P
0 g
s
.577 .906 .663 r
.5261 .28753 m .52492 .28827 L .52964 .28429 L closepath p F P
0 g
s
0 0 0 r
.52964 .28429 m .52492 .28827 L p .52586 .28762 L F P
0 g
s
0 0 0 r
.50132 .30504 m .52473 .28841 L p .50531 .30117 L F P
0 g
s
0 0 0 r
.52473 .28841 m .52492 .28827 L p .52432 .28867 L F P
0 g
s
0 0 0 r
.50531 .30117 m .52473 .28841 L .52432 .28867 L F
.50705 .2996 m .50687 .29972 L p .5076 .29925 L F P
0 g
s
.476 .848 .988 r
.45147 .51145 m .44846 .51182 L .44202 .50968 L p F P
0 g
s
0 .109 .572 r
.12851 .41931 m .12732 .41838 L .13644 .42567 L p F P
0 g
s
0 .109 .572 r
.13644 .42567 m .13656 .42577 L .12851 .41931 L p F P
0 g
s
.796 .908 .918 r
.62979 .21003 m .63582 .2154 L .61114 .23119 L p F P
0 g
s
.796 .908 .918 r
.61043 .22379 m .62979 .21003 L p .61114 .23119 L F P
0 g
s
.796 .908 .918 r
.61114 .23119 m .60732 .22891 L .61043 .22379 L p F P
0 g
s
.462 .848 .982 r
.47666 .50808 m .47319 .50701 L .45147 .51145 L closepath p F P
0 g
s
.476 .848 .988 r
.4664 .50483 m .47319 .50701 L .45147 .51145 L p F P
0 g
s
.476 .848 .988 r
.44202 .50968 m .4664 .50483 L p .45147 .51145 L F P
0 g
s
.568 .075 .044 r
.38936 .32793 m .39803 .33167 L .38556 .33077 L closepath p F P
0 g
s
0 .226 .639 r
.1736 .4516 m .17644 .45325 L .18718 .45979 L p F P
0 g
s
0 .397 .804 r
.19005 .45903 m .20093 .46555 L .18718 .45979 L p F P
0 g
s
0 .397 .804 r
.18718 .45979 m .17644 .45325 L .19005 .45903 L p F P
0 g
s
.373 .767 .987 r
.37254 .5072 m .37977 .51029 L .36517 .51106 L p F P
0 g
s
.373 .767 .987 r
.34878 .50825 m .37254 .5072 L p .36517 .51106 L F P
0 g
s
.373 .767 .987 r
.36517 .51106 m .35147 .50947 L .34878 .50825 L p F P
0 g
s
.472 0 0 r
.27612 .27604 m .2803 .27938 L .29007 .28671 L p F P
0 g
s
.467 0 0 r
.28901 .28629 m .29939 .29341 L .29007 .28671 L p F P
0 g
s
.467 0 0 r
.29007 .28671 m .2803 .27938 L .28901 .28629 L p F P
0 g
s
.678 .712 .874 r
.66668 .20891 m .69182 .19909 L .69779 .20831 L p F P
0 g
s
.698 .734 .879 r
.69182 .19909 m .66668 .20891 L .6607 .2016 L p F P
0 g
s
.523 .917 .898 r
.58655 .47755 m .59115 .47756 L .56642 .48798 L p F P
0 g
s
.523 .917 .898 r
.56642 .48798 m .56367 .48805 L .58655 .47755 L p F P
0 g
s
.012 .531 .859 r
.24922 .48654 m .25521 .48796 L .2692 .4932 L p F P
0 g
s
.186 .635 .942 r
.27206 .49047 m .25521 .48796 L .2692 .4932 L p F P
0 g
s
.186 .635 .942 r
.2692 .4932 m .2797 .49465 L .27206 .49047 L p F P
0 g
s
.215 .174 .594 r
.76928 .28278 m .76252 .29537 L .75834 .28614 L p F P
0 g
s
.215 .174 .594 r
.75834 .28614 m .76502 .27355 L .76928 .28278 L p F P
0 g
s
0 0 .071 r
.74168 .36027 m .73519 .36804 L .74179 .35494 L p F P
0 g
s
0 0 .071 r
.74179 .35494 m .74339 .35302 L .74168 .36027 L p F P
0 g
s
.563 .936 .838 r
.64014 .45463 m .62193 .46483 L .61732 .46569 L p F P
0 g
s
.608 .633 .85 r
.72505 .20659 m .72057 .21589 L p .69779 .20831 L F P
0 g
s
.608 .633 .85 r
.69779 .20831 m .72338 .20343 L .72505 .20659 L p F P
0 g
s
.628 .657 .859 r
.72338 .20343 m .69779 .20831 L .69182 .19909 L p F P
0 g
s
.742 .826 .916 r
.63709 .21665 m .63582 .2154 L .63887 .21373 L closepath p F P
0 g
s
.509 .547 .831 r
.74255 .22896 m .7355 .22785 L .72941 .21509 L p F P
0 g
s
.318 .738 .975 r
.35147 .50947 m .34878 .50825 L .34422 .50829 L closepath p F P
0 g
s
.619 .08 0 r
.35399 .31991 m .35124 .32052 L .34775 .3183 L closepath p F P
0 g
s
.03 .533 .874 r
.25521 .48796 m .24922 .48654 L .24146 .48232 L p F P
0 g
s
.452 0 .058 r
.42031 .32975 m .42994 .33071 L .41833 .33202 L closepath p F P
0 g
s
.191 .676 .928 r
.31794 .50428 m .32553 .50474 L .34422 .50829 L p F P
0 g
s
.227 .686 .948 r
.31794 .50428 m .32553 .50474 L .31237 .50182 L closepath p F P
0 g
s
.493 0 0 r
.3165 .30228 m .31348 .30129 L .31122 .29992 L closepath p F P
0 g
s
.574 .608 .849 r
.72057 .21589 m .72505 .20659 L .72941 .21509 L closepath p F P
0 g
s
0 .256 .7 r
.15647 .43942 m .14551 .43284 L .15514 .43989 L p F P
0 g
s
0 .256 .7 r
.16277 .44399 m .15647 .43942 L p .15514 .43989 L F P
0 g
s
0 .256 .7 r
.15514 .43989 m .16559 .4461 L .16277 .44399 L p F P
0 g
s
.122 .048 .492 r
.76415 .30556 m .75993 .31276 L .7588 .30178 L p F P
0 g
s
.122 .048 .492 r
.7588 .30178 m .76252 .29537 L .76415 .30556 L p F P
0 g
s
0 .083 .563 r
.2803 .27938 m .27612 .27604 L .26859 .26917 L p F P
0 g
s
.332 .739 .98 r
.34142 .50473 m .32553 .50474 L .34422 .50829 L p F P
0 g
s
.332 .739 .98 r
.34422 .50829 m .34878 .50825 L .34142 .50473 L p F P
0 g
s
.635 .957 .782 r
.53155 .28409 m .53135 .28417 L .53224 .28351 L closepath p F P
0 g
s
0 0 .041 r
.74594 .35446 m .74168 .36027 L .74339 .35302 L p F P
0 g
s
0 0 .041 r
.74339 .35302 m .75174 .34158 L .74594 .35446 L p F P
0 g
s
.052 0 .378 r
.76005 .32234 m .75513 .32958 L .75606 .31847 L p F P
0 g
s
.052 0 .378 r
.75606 .31847 m .75993 .31276 L .76005 .32234 L p F P
0 g
s
.512 .87 .986 r
.49771 .50081 m .50339 .50255 L .47666 .50808 L p F P
0 g
s
.512 .87 .986 r
.47666 .50808 m .47319 .50701 L .49771 .50081 L p F P
0 g
s
0 0 0 r
.50531 .30117 m .50045 .30562 L .50132 .30504 L p F P
0 g
s
.618 .077 0 r
.3413 .32026 m .33249 .31315 L .34775 .3183 L p F P
0 g
s
.618 .077 0 r
.34579 .32166 m .3413 .32026 L p .34775 .3183 L F P
0 g
s
.618 .077 0 r
.34775 .3183 m .35124 .32052 L .34579 .32166 L p F P
0 g
s
.484 .857 .631 r
.53224 .28351 m .53135 .28417 L .5261 .28753 L p F P
0 g
s
.68 .977 .822 r
.55588 .26585 m .53224 .28351 L .55013 .2673 L closepath p F P
0 g
s
.484 .857 .631 r
.54958 .26743 m .55013 .2673 L .53224 .28351 L p F P
0 g
s
.484 .857 .631 r
.52964 .28429 m .54958 .26743 L p .53224 .28351 L F P
0 g
s
.484 .857 .631 r
.5261 .28753 m .52964 .28429 L p .53224 .28351 L F P
0 g
s
0 .238 .668 r
.17644 .45325 m .1736 .4516 L .16559 .4461 L p F P
0 g
s
.743 .845 .927 r
.63887 .21373 m .63582 .2154 L .62979 .21003 L p F P
0 g
s
.765 .993 .876 r
.55685 .2658 m .55588 .26585 L .55909 .26334 L closepath p F P
0 g
s
0 .406 .793 r
.21125 .47134 m .21241 .4718 L .20877 .46986 L closepath p F P
0 g
s
0 0 0 r
.72203 .38647 m .7205 .38875 L .72593 .38208 L closepath p F P
0 g
s
.058 .435 .873 r
.26106 .26131 m .25265 .2575 L .26065 .26563 L p F P
0 g
s
.058 .435 .873 r
.26065 .26563 m .26859 .26917 L .26106 .26131 L p F P
0 g
s
.768 .848 .911 r
.63887 .21373 m .6607 .2016 L .65469 .19468 L p F P
0 g
s
.768 .848 .911 r
.65469 .19468 m .64511 .20066 L .63887 .21373 L p F P
0 g
s
.743 .845 .927 r
.62979 .21003 m .64511 .20066 L .63887 .21373 L p F P
0 g
s
.307 .295 .682 r
.77025 .26302 m .76502 .27355 L .75785 .26543 L p F P
0 g
s
.307 .295 .682 r
.76909 .25843 m .77025 .26302 L p .75785 .26543 L F P
0 g
s
.307 .295 .682 r
.75785 .26543 m .76394 .25292 L .76909 .25843 L p F P
0 g
s
.448 0 0 r
.3059 .29794 m .29939 .29341 L .31122 .29992 L p F P
0 g
s
.448 0 0 r
.31122 .29992 m .31348 .30129 L .3059 .29794 L p F P
0 g
s
.546 .911 .957 r
.56014 .48748 m .53544 .49629 L .52898 .49532 L p F P
0 g
s
.484 .885 .949 r
.50435 .5027 m .52898 .49532 L .53544 .49629 L p F P
0 g
s
.591 .079 0 r
.11034 .40311 m .11862 .41086 L .11152 .40309 L p F P
0 g
s
.591 .079 0 r
.11152 .40309 m .10325 .39535 L .11034 .40311 L p F P
0 g
s
.482 .882 .724 r
.6467 .45064 m .64014 .45463 L .64567 .45106 L closepath p F P
0 g
s
.563 .936 .838 r
.64091 .45164 m .64567 .45106 L .64014 .45463 L p F P
0 g
s
.563 .936 .838 r
.62398 .46137 m .64091 .45164 L p .64014 .45463 L F P
0 g
s
.563 .936 .838 r
.61732 .46569 m .62398 .46137 L p .64014 .45463 L F P
0 g
s
.091 .544 .908 r
.21772 .47036 m .22948 .47654 L .21241 .4718 L p F P
0 g
s
.091 .544 .908 r
.20337 .46627 m .21772 .47036 L p .21241 .4718 L F P
0 g
s
.091 .544 .908 r
.21241 .4718 m .20877 .46986 L .20337 .46627 L p F P
0 g
s
0 0 0 r
.7375 .36827 m .72593 .38208 L .73519 .36804 L p F P
0 g
s
0 0 0 r
.73969 .36481 m .7375 .36827 L p .73519 .36804 L F P
0 g
s
0 0 0 r
.73519 .36804 m .74168 .36027 L .73969 .36481 L p F P
0 g
s
0 0 0 r
.50028 .30578 m .50045 .30562 L .47736 .31618 L p F P
0 g
s
0 0 0 r
.47736 .31618 m .47574 .31782 L .50028 .30578 L p F P
0 g
s
.346 .754 .981 r
.37254 .5072 m .34878 .50825 L .34142 .50473 L p F P
0 g
s
.804 .961 .912 r
.58168 .24684 m .58044 .24649 L .58382 .24392 L closepath p F P
0 g
s
.703 .983 .822 r
.55909 .26334 m .55588 .26585 L .55013 .2673 L p F P
0 g
s
.592 .93 .957 r
.585 .47726 m .58655 .47755 L .56367 .48805 L p F P
0 g
s
.592 .93 .957 r
.56367 .48805 m .56014 .48748 L .585 .47726 L p F P
0 g
s
.558 .919 .742 r
.66586 .43581 m .67146 .43401 L .6467 .45064 L p F P
0 g
s
.558 .919 .742 r
.66417 .43698 m .66586 .43581 L p .6467 .45064 L F P
0 g
s
.558 .919 .742 r
.6467 .45064 m .64567 .45106 L .66417 .43698 L p F P
0 g
s
.03 .533 .874 r
.24146 .48232 m .2419 .48243 L .25521 .48796 L p F P
0 g
s
.192 .63 .945 r
.26336 .48582 m .2419 .48243 L .25521 .48796 L p F P
0 g
s
.192 .63 .945 r
.26567 .48675 m .26336 .48582 L p .25521 .48796 L F P
0 g
s
.192 .63 .945 r
.25521 .48796 m .27206 .49047 L .26567 .48675 L p F P
0 g
s
.509 .547 .831 r
.72941 .21509 m .74709 .21678 L .74255 .22896 L p F P
0 g
s
.467 .5 .809 r
.76016 .22979 m .75852 .23378 L .74255 .22896 L p F P
0 g
s
.467 .5 .809 r
.75588 .21881 m .76016 .22979 L p .74255 .22896 L F P
0 g
s
.467 .5 .809 r
.74255 .22896 m .74709 .21678 L .75588 .21881 L p F P
0 g
s
.397 .409 .755 r
.76622 .24789 m .76394 .25292 L .75304 .24619 L p F P
0 g
s
.397 .409 .755 r
.76227 .23576 m .76622 .24789 L p .75304 .24619 L F P
0 g
s
.397 .409 .755 r
.75304 .24619 m .75852 .23378 L .76227 .23576 L p F P
0 g
s
.794 .906 .919 r
.60732 .22891 m .60506 .22753 L .61043 .22379 L closepath p F P
0 g
s
.775 .997 .825 r
.55909 .26334 m .58044 .24649 L .57424 .24557 L p F P
0 g
s
.775 .997 .825 r
.57424 .24557 m .57133 .24817 L .55909 .26334 L p F P
0 g
s
.703 .983 .822 r
.55127 .26595 m .57133 .24817 L .55909 .26334 L p F P
0 g
s
.703 .983 .822 r
.55013 .2673 m .55127 .26595 L p .55909 .26334 L F P
0 g
s
0 .238 .668 r
.16559 .4461 m .1662 .44646 L .17644 .45325 L p F P
0 g
s
0 .406 .822 r
.1797 .45226 m .19005 .45903 L .17644 .45325 L p F P
0 g
s
0 .406 .822 r
.17644 .45325 m .1662 .44646 L .1797 .45226 L p F P
0 g
s
.734 .207 0 r
.31946 .30713 m .31348 .30129 L .3059 .29794 L p F P
0 g
s
.351 .735 .986 r
.33401 .50098 m .34142 .50473 L .32553 .50474 L p F P
0 g
s
.351 .735 .986 r
.31045 .5008 m .33401 .50098 L p .32553 .50474 L F P
0 g
s
.351 .735 .986 r
.32553 .50474 m .31237 .50182 L .31045 .5008 L p F P
0 g
s
0 .124 .602 r
.12044 .41229 m .11862 .41086 L .12732 .41838 L p F P
0 g
s
0 .124 .602 r
.12732 .41838 m .12851 .41931 L .12044 .41229 L p F P
0 g
s
.455 0 .063 r
.42994 .33071 m .41833 .33202 L .41364 .33743 L p F P
0 g
s
.578 .127 .145 r
.4112 .33739 m .41364 .33743 L .41833 .33202 L p F P
0 g
s
.578 .127 .145 r
.41833 .33202 m .39803 .33167 L .4112 .33739 L p F P
0 g
s
.498 .568 .857 r
.72505 .20659 m .72941 .21509 L .74709 .21678 L p F P
0 g
s
.69 .174 .002 r
.35124 .32052 m .35688 .32532 L .34579 .32166 L closepath p F P
0 g
s
.053 .518 .891 r
.20877 .46986 m .20337 .46627 L .20093 .46555 L closepath p F P
0 g
s
.57 .078 .049 r
.38566 .33599 m .4112 .33739 L .39803 .33167 L p F P
0 g
s
.57 .078 .049 r
.38189 .33354 m .38566 .33599 L p .39803 .33167 L F P
0 g
s
.57 .078 .049 r
.39803 .33167 m .38556 .33077 L .38189 .33354 L p F P
0 g
s
.491 .886 .954 r
.52877 .49529 m .52898 .49532 L .50435 .5027 L p F P
0 g
s
.491 .886 .954 r
.50435 .5027 m .50339 .50255 L .52877 .49529 L p F P
0 g
s
0 .083 .563 r
.26859 .26917 m .27149 .27162 L .2803 .27938 L p F P
0 g
s
0 .084 .565 r
.27985 .27864 m .28901 .28629 L .2803 .27938 L p F P
0 g
s
0 .084 .565 r
.2803 .27938 m .27149 .27162 L .27985 .27864 L p F P
0 g
s
.18 .646 .936 r
.2797 .49465 m .29232 .49609 L .30811 .50071 L p F P
0 g
s
.195 .645 .945 r
.29232 .49609 m .2797 .49465 L .27206 .49047 L p F P
0 g
s
.379 .784 .983 r
.40377 .50807 m .37977 .51029 L .37254 .5072 L p F P
0 g
s
.59 .944 .911 r
.60997 .46536 m .616 .46563 L .59115 .47756 L p F P
0 g
s
.59 .944 .911 r
.59707 .47167 m .60997 .46536 L p .59115 .47756 L F P
0 g
s
.59 .944 .911 r
.59115 .47756 m .58655 .47755 L .59707 .47167 L p F P
0 g
s
.632 .155 .102 r
.38556 .33077 m .38189 .33354 L .37521 .32932 L closepath p F P
0 g
s
.46 .004 .08 r
.4472 .32868 m .44438 .33219 L .42994 .33071 L closepath p F P
0 g
s
.455 0 .063 r
.44299 .33448 m .44438 .33219 L .42994 .33071 L p F P
0 g
s
.455 0 .063 r
.41364 .33743 m .44299 .33448 L p .42994 .33071 L F P
0 g
s
.789 .98 .904 r
.58382 .24392 m .58044 .24649 L .57424 .24557 L p F P
0 g
s
.443 0 0 r
.12851 .41931 m .13633 .42555 L .14551 .43284 L p F P
0 g
s
0 .108 .585 r
.13633 .42555 m .12851 .41931 L .12044 .41229 L p F P
0 g
s
.714 .186 0 r
.3271 .31465 m .3413 .32026 L .33249 .31315 L p F P
0 g
s
.714 .186 0 r
.33249 .31315 m .31946 .30713 L .3271 .31465 L p F P
0 g
s
.789 .98 .904 r
.57424 .24557 m .59249 .22998 L .58382 .24392 L p F P
0 g
s
.83 .977 .885 r
.58382 .24392 m .60506 .22753 L .59894 .2244 L p F P
0 g
s
.83 .977 .885 r
.59894 .2244 m .59249 .22998 L .58382 .24392 L p F P
0 g
s
0 0 0 r
.72571 .38324 m .7375 .36827 L .72593 .38208 L p F P
0 g
s
0 0 0 r
.71859 .39167 m .72571 .38324 L p .72593 .38208 L F P
0 g
s
0 0 0 r
.72593 .38208 m .7205 .38875 L .71859 .39167 L p F P
0 g
s
.631 .956 .787 r
.67191 .43386 m .67146 .43401 L .67343 .43258 L closepath p F P
0 g
s
.645 .968 .864 r
.64567 .45106 m .64091 .45164 L .66417 .43698 L closepath p F P
0 g
s
0 0 .356 r
.76342 .31663 m .76005 .32234 L .75993 .31276 L p F P
0 g
s
0 0 .356 r
.75993 .31276 m .76415 .30556 L .76342 .31663 L p F P
0 g
s
.628 .657 .859 r
.69182 .19909 m .71738 .19268 L .72338 .20343 L p F P
0 g
s
.648 .681 .868 r
.71738 .19268 m .69182 .19909 L .68585 .19039 L p F P
0 g
s
.698 .734 .879 r
.6607 .2016 m .68585 .19039 L .69182 .19909 L p F P
0 g
s
.093 .029 .485 r
.77094 .29299 m .76415 .30556 L .76252 .29537 L p F P
0 g
s
.093 .029 .485 r
.76252 .29537 m .76928 .28278 L .77094 .29299 L p F P
0 g
s
.508 .869 .986 r
.49771 .50081 m .47319 .50701 L .4664 .50483 L p F P
0 g
s
.556 .89 .986 r
.52244 .49329 m .52877 .49529 L .50339 .50255 L p F P
0 g
s
.556 .89 .986 r
.50339 .50255 m .49771 .50081 L .52244 .49329 L p F P
0 g
s
.416 .817 .982 r
.41086 .51078 m .43507 .50728 L .44202 .50968 L p F P
0 g
s
.417 .814 .985 r
.43507 .50728 m .41086 .51078 L .40377 .50807 L p F P
0 g
s
0 0 .204 r
.75919 .33061 m .75174 .34158 L .75513 .32958 L p F P
0 g
s
0 0 .204 r
.75513 .32958 m .76005 .32234 L .75919 .33061 L p F P
0 g
s
.716 .753 .881 r
.68585 .19039 m .6607 .2016 L .65469 .19468 L p F P
0 g
s
.632 .167 .131 r
.36539 .33266 m .35688 .32532 L .37521 .32932 L p F P
0 g
s
.632 .167 .131 r
.3799 .33527 m .36539 .33266 L p .37521 .32932 L F P
0 g
s
.632 .167 .131 r
.37521 .32932 m .38189 .33354 L .3799 .33527 L p F P
0 g
s
.459 .843 .985 r
.4664 .50483 m .44202 .50968 L .43507 .50728 L p F P
0 g
s
.124 0 0 r
.49625 .31101 m .50028 .30578 L .47574 .31782 L p F P
0 g
s
.124 0 0 r
.47574 .31782 m .47306 .32161 L .49625 .31101 L p F P
0 g
s
0 0 0 r
.7205 .38875 m .71309 .39734 L .71859 .39167 L closepath p F P
0 g
s
0 .267 .725 r
.14723 .43214 m .15647 .43942 L .14551 .43284 L p F P
0 g
s
0 .267 .725 r
.14551 .43284 m .13633 .42555 L .14723 .43214 L p F P
0 g
s
.629 .955 .784 r
.67343 .43258 m .67146 .43401 L .66586 .43581 L p F P
0 g
s
.303 .709 .976 r
.31237 .50182 m .31045 .5008 L .30811 .50071 L closepath p F P
0 g
s
.573 .909 .678 r
.69614 .41415 m .67343 .43258 L .69081 .41714 L closepath p F P
0 g
s
.629 .955 .784 r
.69075 .41715 m .69081 .41714 L .67343 .43258 L p F P
0 g
s
.629 .955 .784 r
.66586 .43581 m .69075 .41715 L p .67343 .43258 L F P
0 g
s
.309 0 0 r
.46898 .3274 m .47306 .32161 L .4472 .32868 L p F P
0 g
s
.309 0 0 r
.4669 .32795 m .46898 .3274 L p .4472 .32868 L F P
0 g
s
.309 0 0 r
.4472 .32868 m .44438 .33219 L .4669 .32795 L p F P
0 g
s
.793 .925 .924 r
.61043 .22379 m .60506 .22753 L .59894 .2244 L p F P
0 g
s
.555 .862 .561 r
.7106 .39935 m .69641 .41391 L .71309 .39734 L p F P
0 g
s
.555 .862 .561 r
.71545 .39437 m .7106 .39935 L p .71309 .39734 L F P
0 g
s
.555 .862 .561 r
.71309 .39734 m .71859 .39167 L .71545 .39437 L p F P
0 g
s
.453 0 0 r
.29799 .29318 m .28901 .28629 L .29939 .29341 L p F P
0 g
s
.453 0 0 r
.29905 .29386 m .29799 .29318 L p .29939 .29341 L F P
0 g
s
.453 0 0 r
.29939 .29341 m .3059 .29794 L .29905 .29386 L p F P
0 g
s
.551 .604 .86 r
.72338 .20343 m .72589 .20333 L .72505 .20659 L closepath p F P
0 g
s
.498 .568 .857 r
.74966 .20422 m .72589 .20333 L .72505 .20659 L p F P
0 g
s
.498 .568 .857 r
.75079 .20675 m .74966 .20422 L p .72505 .20659 L F P
0 g
s
.498 .568 .857 r
.74709 .21678 m .75079 .20675 L p .72505 .20659 L F P
0 g
s
.318 .71 .98 r
.30293 .49657 m .29232 .49609 L .30811 .50071 L p F P
0 g
s
.318 .71 .98 r
.30811 .50071 m .31045 .5008 L .30293 .49657 L p F P
0 g
s
.822 .917 .901 r
.61043 .22379 m .62979 .21003 L .62372 .20501 L p F P
0 g
s
.822 .917 .901 r
.62372 .20501 m .61649 .21074 L .61043 .22379 L p F P
0 g
s
.793 .925 .924 r
.59894 .2244 m .61649 .21074 L .61043 .22379 L p F P
0 g
s
.621 .93 .691 r
.69621 .41411 m .69614 .41415 L .69641 .41391 L closepath p F P
0 g
s
.615 .927 .685 r
.69641 .41391 m .69614 .41415 L .69081 .41714 L p F P
0 g
s
.615 .927 .685 r
.69097 .41698 m .7106 .39935 L .69641 .41391 L p F P
0 g
s
.615 .927 .685 r
.69081 .41714 m .69097 .41698 L p .69641 .41391 L F P
0 g
s
.64 .96 .919 r
.61732 .46569 m .616 .46563 L .62398 .46137 L closepath p F P
0 g
s
0 .112 .618 r
.27149 .27162 m .26859 .26917 L .26106 .26131 L p F P
0 g
s
.081 .525 .903 r
.19547 .46067 m .19005 .45903 L .20093 .46555 L p F P
0 g
s
.081 .525 .903 r
.20093 .46555 m .20337 .46627 L .19547 .46067 L p F P
0 g
s
.064 .545 .894 r
.24146 .48232 m .2419 .48243 L .24076 .48191 L closepath p F P
0 g
s
.231 .635 .957 r
.25042 .48007 m .26336 .48582 L .2419 .48243 L p F P
0 g
s
.231 .635 .957 r
.23368 .4773 m .25042 .48007 L p .2419 .48243 L F P
0 g
s
.231 .635 .957 r
.2419 .48243 m .24076 .48191 L .23368 .4773 L p F P
0 g
s
.327 .722 .982 r
.33401 .50098 m .31045 .5008 L .30293 .49657 L p F P
0 g
s
.189 .61 .945 r
.24076 .48191 m .23368 .4773 L .22948 .47654 L closepath p F P
0 g
s
.568 .625 .869 r
.72589 .20333 m .72338 .20343 L .71738 .19268 L p F P
0 g
s
.603 .931 .961 r
.585 .47726 m .56014 .48748 L .55379 .48642 L p F P
0 g
s
.546 .911 .957 r
.52898 .49532 m .55379 .48642 L .56014 .48748 L p F P
0 g
s
0 .259 .703 r
.16559 .4461 m .1662 .44646 L .16277 .44399 L closepath p F P
0 g
s
0 0 0 r
.74168 .36027 m .73969 .36481 L .74594 .35446 L closepath p F P
0 g
s
.198 .165 .593 r
.77271 .27588 m .76928 .28278 L .76502 .27355 L p F P
0 g
s
.198 .165 .593 r
.76502 .27355 m .77025 .26302 L .77271 .27588 L p F P
0 g
s
.693 .18 .01 r
.34886 .32792 m .36539 .33266 L .35688 .32532 L p F P
0 g
s
.693 .18 .01 r
.34363 .32213 m .34886 .32792 L p .35688 .32532 L F P
0 g
s
.693 .18 .01 r
.35688 .32532 m .34579 .32166 L .34363 .32213 L p F P
0 g
s
0 .435 .854 r
.16986 .44524 m .1797 .45226 L .1662 .44646 L p F P
0 g
s
0 .435 .854 r
.15758 .4399 m .16986 .44524 L p .1662 .44646 L F P
0 g
s
0 .435 .854 r
.1662 .44646 m .16277 .44399 L .15758 .4399 L p F P
0 g
s
.071 .523 .899 r
.21772 .47036 m .20337 .46627 L .19547 .46067 L p F P
0 g
s
.766 .862 .921 r
.64511 .20066 m .62979 .21003 L .62372 .20501 L p F P
0 g
s
.568 .625 .869 r
.71738 .19268 m .7283 .19173 L .72589 .20333 L p F P
0 g
s
.528 .566 .837 r
.74354 .19133 m .7283 .19173 L .72589 .20333 L p F P
0 g
s
.528 .566 .837 r
.72589 .20333 m .74966 .20422 L .74354 .19133 L p F P
0 g
s
.641 .96 .92 r
.62398 .46137 m .616 .46563 L .60997 .46536 L p F P
0 g
s
.734 .207 0 r
.3059 .29794 m .30811 .30042 L .31946 .30713 L p F P
0 g
s
.74 .216 0 r
.31495 .30822 m .3271 .31465 L .31946 .30713 L p F P
0 g
s
.74 .216 0 r
.31946 .30713 m .30811 .30042 L .31495 .30822 L p F P
0 g
s
0 0 0 r
.75487 .34138 m .74594 .35446 L .75174 .34158 L p F P
0 g
s
0 0 0 r
.75853 .33302 m .75487 .34138 L p .75174 .34158 L F P
0 g
s
0 0 0 r
.75174 .34158 m .75919 .33061 L .75853 .33302 L p F P
0 g
s
0 .14 .631 r
.11237 .40471 m .11034 .40311 L .11862 .41086 L p F P
0 g
s
0 .14 .631 r
.11862 .41086 m .12044 .41229 L .11237 .40471 L p F P
0 g
s
0 .112 .618 r
.26106 .26131 m .26355 .26345 L .27149 .27162 L p F P
0 g
s
0 .112 .619 r
.27179 .2705 m .27985 .27864 L .27149 .27162 L p F P
0 g
s
0 .112 .619 r
.27149 .27162 m .26355 .26345 L .27179 .2705 L p F P
0 g
s
0 0 0 r
.50045 .30562 m .50028 .30578 L .50132 .30504 L closepath p F P
0 g
s
0 0 .337 r
.77023 .30408 m .76342 .31663 L .76415 .30556 L p F P
0 g
s
0 0 .337 r
.76415 .30556 m .77094 .29299 L .77023 .30408 L p F P
0 g
s
.346 .754 .981 r
.3681 .50519 m .37254 .5072 L p .34142 .50473 L F P
0 g
s
.346 .754 .981 r
.34142 .50473 m .3599 .50408 L .3681 .50519 L p F P
0 g
s
.356 .75 .986 r
.3599 .50408 m .34142 .50473 L .33401 .50098 L p F P
0 g
s
.195 .645 .945 r
.27206 .49047 m .27741 .49113 L .29232 .49609 L p F P
0 g
s
.322 .704 .981 r
.29535 .49208 m .27741 .49113 L .29232 .49609 L p F P
0 g
s
.322 .704 .981 r
.29232 .49609 m .30293 .49657 L .29535 .49208 L p F P
0 g
s
.599 .951 .861 r
.64091 .45164 m .62398 .46137 L .63807 .452 L closepath p F P
0 g
s
.641 .96 .92 r
.63502 .45169 m .63807 .452 L .62398 .46137 L p F P
0 g
s
.641 .96 .92 r
.60997 .46536 m .63502 .45169 L p .62398 .46137 L F P
0 g
s
0 .415 .839 r
.16277 .44399 m .15758 .4399 L .15647 .43942 L closepath p F P
0 g
s
0 0 0 r
.50132 .30504 m .50028 .30578 L .49625 .31101 L p F P
0 g
s
.637 .173 .135 r
.38189 .33354 m .38566 .33599 L .3799 .33527 L closepath p F P
0 g
s
0 0 0 r
.52492 .28827 m .50132 .30504 L .52118 .29174 L closepath p F P
0 g
s
0 0 0 r
.5184 .2943 m .51661 .29652 L p .51872 .2944 L F P
0 g
s
0 0 0 r
.5184 .2943 m .52118 .29174 L .51768 .29408 L p F P
0 g
s
0 0 0 r
.52118 .29174 m .52847 .28456 L p .52964 .28429 L F P
0 g
s
.516 .836 .532 r
.52118 .29174 m .5184 .2943 L .52847 .28456 L closepath p F P
0 g
s
0 0 0 r
.52847 .28456 m .5184 .2943 L p .51872 .2944 L F P
0 g
s
0 0 0 r
.51768 .29408 m .50132 .30504 L p .5184 .2943 L F P
0 g
s
0 0 0 r
.50843 .3024 m .5184 .2943 L p .50132 .30504 L F P
0 g
s
0 0 0 r
.49625 .31101 m .50843 .3024 L p .50132 .30504 L F P
0 g
s
0 0 .176 r
.76042 .32854 m .75919 .33061 L .76005 .32234 L p F P
0 g
s
0 0 .176 r
.76005 .32234 m .76342 .31663 L .76042 .32854 L p F P
0 g
s
.298 .293 .685 r
.76394 .25292 m .76622 .24789 L .76909 .25843 L closepath p F P
0 g
s
.618 .89 .574 r
.71859 .39167 m .71545 .39437 L .72571 .38324 L closepath p F P
0 g
s
.548 .912 .958 r
.55286 .48626 m .55379 .48642 L .52898 .49532 L p F P
0 g
s
.548 .912 .958 r
.52898 .49532 m .52877 .49529 L .55286 .48626 L p F P
0 g
s
.785 .837 .892 r
.64511 .20066 m .65469 .19468 L .64866 .18808 L p F P
0 g
s
.785 .837 .892 r
.64866 .18808 m .64747 .1889 L .64511 .20066 L p F P
0 g
s
.766 .862 .921 r
.62372 .20501 m .64747 .1889 L .64511 .20066 L p F P
0 g
s
0 .108 .585 r
.12044 .41229 m .12759 .41803 L .13633 .42555 L p F P
0 g
s
0 .129 .62 r
.12759 .41803 m .12044 .41229 L .11237 .40471 L p F P
0 g
s
.648 .681 .868 r
.68585 .19039 m .71138 .18255 L .71738 .19268 L p F P
0 g
s
.666 .702 .873 r
.71138 .18255 m .68585 .19039 L .67985 .18211 L p F P
0 g
s
.716 .753 .881 r
.65469 .19468 m .67985 .18211 L .68585 .19039 L p F P
0 g
s
.598 .906 .983 r
.54736 .48443 m .55286 .48626 L .52877 .49529 L p F P
0 g
s
.598 .906 .983 r
.52877 .49529 m .52244 .49329 L .54736 .48443 L p F P
0 g
s
.675 .154 0 r
.34579 .32166 m .34363 .32213 L .3413 .32026 L closepath p F P
0 g
s
.113 0 0 r
.49358 .3145 m .49625 .31101 L .47306 .32161 L p F P
0 g
s
.113 0 0 r
.47082 .32654 m .49358 .3145 L p .47306 .32161 L F P
0 g
s
.113 0 0 r
.47306 .32161 m .46898 .3274 L .47082 .32654 L p F P
0 g
s
0 .281 .748 r
.13845 .42461 m .14723 .43214 L .13633 .42555 L p F P
0 g
s
0 .281 .748 r
.13633 .42555 m .12759 .41803 L .13845 .42461 L p F P
0 g
s
.638 .943 .957 r
.58655 .47755 m .585 .47726 L .59707 .47167 L closepath p F P
0 g
s
.367 0 .106 r
.44438 .33219 m .4669 .32795 L .44299 .33448 L closepath p F P
0 g
s
0 .087 .557 r
.28843 .28567 m .29799 .29318 L .28901 .28629 L p F P
0 g
s
0 .087 .557 r
.28901 .28629 m .27985 .27864 L .28843 .28567 L p F P
0 g
s
.225 .65 .956 r
.27206 .49047 m .27741 .49113 L .26567 .48675 L closepath p F P
0 g
s
.467 .5 .809 r
.74709 .21678 m .75079 .20675 L .75588 .21881 L closepath p F P
0 g
s
.697 .165 0 r
.3059 .29794 m .30811 .30042 L .29905 .29386 L closepath p F P
0 g
s
.392 .41 .759 r
.75852 .23378 m .76016 .22979 L .76227 .23576 L closepath p F P
0 g
s
.21 .612 .95 r
.22586 .4719 m .21772 .47036 L .22948 .47654 L p F P
0 g
s
.21 .612 .95 r
.22948 .47654 m .23368 .4773 L .22586 .4719 L p F P
0 g
s
.734 .769 .881 r
.67985 .18211 m .65469 .19468 L .64866 .18808 L p F P
0 g
s
.672 .143 0 r
.33488 .32221 m .3271 .31465 L .3413 .32026 L p F P
0 g
s
.672 .143 0 r
.33714 .32306 m .33488 .32221 L p .3413 .32026 L F P
0 g
s
.672 .143 0 r
.3413 .32026 m .34363 .32213 L .33714 .32306 L p F P
0 g
s
.379 .784 .983 r
.40211 .5074 m .40377 .50807 L p .37254 .5072 L F P
0 g
s
.379 .784 .983 r
.37254 .5072 m .38268 .50634 L .40211 .5074 L p F P
0 g
s
.402 .784 .991 r
.37254 .5072 m .38268 .50634 L .3681 .50519 L closepath p F P
0 g
s
.096 .524 .908 r
.18752 .45467 m .1797 .45226 L .19005 .45903 L p F P
0 g
s
.096 .524 .908 r
.19005 .45903 m .19547 .46067 L .18752 .45467 L p F P
0 g
s
.517 .061 .109 r
.43919 .34086 m .44299 .33448 L .41364 .33743 L p F P
0 g
s
.517 .061 .109 r
.42795 .34194 m .43919 .34086 L p .41364 .33743 L F P
0 g
s
.517 .061 .109 r
.41364 .33743 m .413 .33818 L .42795 .34194 L p F P
0 g
s
.58 .132 .151 r
.41364 .33743 m .413 .33818 L .4112 .33739 L closepath p F P
0 g
s
.581 .159 .205 r
.39591 .34283 m .38566 .33599 L .4112 .33739 L p F P
0 g
s
.581 .159 .205 r
.40939 .34347 m .39591 .34283 L p .4112 .33739 L F P
0 g
s
.581 .159 .205 r
.4112 .33739 m .413 .33818 L .40939 .34347 L p F P
0 g
s
.556 .889 .986 r
.52244 .49329 m .49771 .50081 L .49101 .49868 L p F P
0 g
s
.508 .869 .986 r
.4664 .50483 m .49101 .49868 L .49771 .50081 L p F P
0 g
s
0 0 0 r
.74678 .35512 m .75487 .34138 L .74594 .35446 L p F P
0 g
s
0 0 0 r
.73904 .36632 m .74678 .35512 L p .74594 .35446 L F P
0 g
s
0 0 0 r
.74594 .35446 m .73969 .36481 L .73904 .36632 L p F P
0 g
s
.763 .996 .821 r
.55013 .2673 m .54958 .26743 L .55127 .26595 L closepath p F P
0 g
s
.585 .64 .872 r
.7283 .19173 m .71738 .19268 L .71138 .18255 L p F P
0 g
s
.644 .967 .863 r
.66417 .43698 m .64091 .45164 L .63807 .452 L p F P
0 g
s
.666 .96 .749 r
.54958 .26743 m .52964 .28429 L .54413 .26985 L closepath p F P
0 g
s
0 0 0 r
.54321 .27026 m .54413 .26985 L .52964 .28429 L p F P
0 g
s
0 0 0 r
.52847 .28456 m .54321 .27026 L p .52964 .28429 L F P
0 g
s
.417 .814 .985 r
.43332 .50664 m .43507 .50728 L p .40377 .50807 L F P
0 g
s
.417 .814 .985 r
.40377 .50807 m .40918 .50733 L .43332 .50664 L p F P
0 g
s
.438 .814 .992 r
.40377 .50807 m .40918 .50733 L .40211 .5074 L closepath p F P
0 g
s
.64 .179 .142 r
.37444 .34013 m .39591 .34283 L .38566 .33599 L p F P
0 g
s
.64 .179 .142 r
.38566 .33599 m .3799 .33527 L .37444 .34013 L p F P
0 g
s
.518 .867 .99 r
.48965 .49823 m .49101 .49868 L .4664 .50483 L p F P
0 g
s
.518 .867 .99 r
.4664 .50483 m .46237 .50348 L .48965 .49823 L p F P
0 g
s
.459 .843 .985 r
.46237 .50348 m .4664 .50483 L p .43507 .50728 L F P
0 g
s
.527 .1 .172 r
.413 .33818 m .42795 .34194 L .40939 .34347 L closepath p F P
0 g
s
.641 .943 .958 r
.59707 .47167 m .585 .47726 L .57876 .47603 L p F P
0 g
s
.603 .931 .961 r
.55379 .48642 m .57876 .47603 L .585 .47726 L p F P
0 g
s
.689 .968 .751 r
.55127 .26595 m .54958 .26743 L .54413 .26985 L p F P
0 g
s
.822 .991 .868 r
.56226 .25117 m .55127 .26595 L .57133 .24817 L p F P
0 g
s
.689 .968 .751 r
.54576 .26771 m .56226 .25117 L .55127 .26595 L p F P
0 g
s
.689 .968 .751 r
.54413 .26985 m .54576 .26771 L p .55127 .26595 L F P
0 g
s
.459 .843 .985 r
.43507 .50728 m .44393 .50557 L .46237 .50348 L p F P
0 g
s
.477 .842 .992 r
.43507 .50728 m .44393 .50557 L .43332 .50664 L closepath p F P
0 g
s
.683 .233 .178 r
.374 .34005 m .37444 .34013 L .3799 .33527 L p F P
0 g
s
.683 .233 .178 r
.3799 .33527 m .36539 .33266 L .374 .34005 L p F P
0 g
s
.705 .175 0 r
.3044 .30113 m .31495 .30822 L .30811 .30042 L p F P
0 g
s
.705 .175 0 r
.29831 .29343 m .3044 .30113 L p .30811 .30042 L F P
0 g
s
.705 .175 0 r
.30811 .30042 m .29905 .29386 L .29831 .29343 L p F P
0 g
s
0 .425 .853 r
.14955 .43315 m .14723 .43214 L .15647 .43942 L p F P
0 g
s
0 .425 .853 r
.15647 .43942 m .15758 .4399 L .14955 .43315 L p F P
0 g
s
.822 .992 .866 r
.57424 .24557 m .57133 .24817 L .5731 .24555 L closepath p F P
0 g
s
.822 .991 .868 r
.56799 .24539 m .56226 .25117 L p .57133 .24817 L F P
0 g
s
.822 .991 .868 r
.57133 .24817 m .5731 .24555 L .56799 .24539 L p F P
0 g
s
.807 .993 .873 r
.59249 .22998 m .57424 .24557 L .5731 .24555 L p F P
0 g
s
.748 .254 .058 r
.34363 .32213 m .34886 .32792 L .33714 .32306 L closepath p F P
0 g
s
.063 .009 .477 r
.77394 .28696 m .77094 .29299 L .76928 .28278 L p F P
0 g
s
.063 .009 .477 r
.76928 .28278 m .77271 .27588 L .77394 .28696 L p F P
0 g
s
.326 .35 .732 r
.76227 .23576 m .76876 .24076 L .76622 .24789 L closepath p F P
0 g
s
.196 .225 .665 r
.77541 .2491 m .76876 .24076 L .76622 .24789 L p F P
0 g
s
.196 .225 .665 r
.77104 .26109 m .77541 .2491 L p .76622 .24789 L F P
0 g
s
.196 .225 .665 r
.76622 .24789 m .76909 .25843 L .77104 .26109 L p F P
0 g
s
.344 .7 .983 r
.28772 .4873 m .29535 .49208 L .27741 .49113 L p F P
0 g
s
.344 .7 .983 r
.26436 .4859 m .28772 .4873 L p .27741 .49113 L F P
0 g
s
.344 .7 .983 r
.27741 .49113 m .26567 .48675 L .26436 .4859 L p F P
0 g
s
.211 .617 .951 r
.25042 .48007 m .23368 .4773 L .22586 .4719 L p F P
0 g
s
.294 .348 .747 r
.76016 .22979 m .76227 .23576 L .76876 .24076 L p F P
0 g
s
.373 0 .115 r
.4669 .32795 m .44299 .33448 L .43919 .34086 L p F P
0 g
s
0 0 0 r
.73969 .36481 m .7375 .36827 L .73904 .36632 L closepath p F P
0 g
s
.841 .938 .889 r
.59894 .2244 m .59249 .22998 L .59558 .22295 L closepath p F P
0 g
s
.807 .993 .873 r
.59276 .2217 m .59558 .22295 L .59249 .22998 L p F P
0 g
s
.807 .993 .873 r
.57968 .23429 m .59276 .2217 L p .59249 .22998 L F P
0 g
s
.807 .993 .873 r
.5731 .24555 m .57968 .23429 L p .59249 .22998 L F P
0 g
s
0 .418 .848 r
.16986 .44524 m .15758 .4399 L .14955 .43315 L p F P
0 g
s
.294 .348 .747 r
.77251 .22886 m .76254 .22178 L .76016 .22979 L p F P
0 g
s
.294 .348 .747 r
.76876 .24076 m .77251 .22886 L p .76016 .22979 L F P
0 g
s
.396 .437 .786 r
.75588 .21881 m .76254 .22178 L .76016 .22979 L closepath p F P
0 g
s
.816 .94 .908 r
.61649 .21074 m .59894 .2244 L .59558 .22295 L p F P
0 g
s
0 0 .143 r
.76729 .31601 m .76042 .32854 L .76342 .31663 L p F P
0 g
s
0 0 .143 r
.76342 .31663 m .77023 .30408 L .76729 .31601 L p F P
0 g
s
.327 .722 .982 r
.33001 .49885 m .33401 .50098 L p .30293 .49657 L F P
0 g
s
.327 .722 .982 r
.30293 .49657 m .32204 .4969 L .33001 .49885 L p F P
0 g
s
.338 .717 .984 r
.32204 .4969 m .30293 .49657 L .29535 .49208 L p F P
0 g
s
.506 .819 1 r
.40918 .50733 m .40211 .5074 L .39662 .50462 L p F P
0 g
s
.462 .8 .999 r
.40211 .5074 m .39662 .50462 L .38268 .50634 L closepath p F P
0 g
s
0 0 0 r
.73535 .37104 m .72571 .38324 L .7375 .36827 L p F P
0 g
s
0 0 0 r
.7375 .36827 m .73904 .36632 L .73535 .37104 L p F P
0 g
s
.24 .241 .658 r
.76909 .25843 m .77104 .26109 L .77025 .26302 L closepath p F P
0 g
s
.493 .824 .999 r
.43332 .50664 m .42806 .50413 L .40918 .50733 L closepath p F P
0 g
s
.506 .819 1 r
.42099 .5006 m .42806 .50413 L .40918 .50733 L p F P
0 g
s
.506 .819 1 r
.39662 .50462 m .42099 .5006 L p .40918 .50733 L F P
0 g
s
.071 .523 .899 r
.19547 .46067 m .20657 .46391 L .21772 .47036 L p F P
0 g
s
.093 .525 .907 r
.20657 .46391 m .19547 .46067 L .18752 .45467 L p F P
0 g
s
.535 .841 .999 r
.44393 .50557 m .43332 .50664 L .42806 .50413 L p F P
0 g
s
.736 .287 .185 r
.35587 .33588 m .374 .34005 L .36539 .33266 L p F P
0 g
s
.736 .287 .185 r
.36539 .33266 m .34886 .32792 L .35587 .33588 L p F P
0 g
s
.137 .124 .578 r
.77497 .27045 m .77271 .27588 L .77025 .26302 L p F P
0 g
s
.137 .124 .578 r
.77025 .26302 m .77104 .26109 L .77497 .27045 L p F P
0 g
s
.597 .942 .779 r
.66586 .43581 m .66417 .43698 L .66551 .43593 L closepath p F P
0 g
s
.644 .967 .863 r
.66012 .43616 m .66551 .43593 L .66417 .43698 L p F P
0 g
s
.644 .967 .863 r
.64899 .44336 m .66012 .43616 L p .66417 .43698 L F P
0 g
s
.644 .967 .863 r
.63807 .452 m .64899 .44336 L p .66417 .43698 L F P
0 g
s
.842 .99 .857 r
.5731 .24555 m .56799 .24539 L .57968 .23429 L closepath p F P
0 g
s
.818 .878 .889 r
.62372 .20501 m .61649 .21074 L .61895 .20133 L closepath p F P
0 g
s
.816 .94 .908 r
.6176 .20027 m .61895 .20133 L .61649 .21074 L p F P
0 g
s
.816 .94 .908 r
.59834 .21696 m .6176 .20027 L p .61649 .21074 L F P
0 g
s
.816 .94 .908 r
.59558 .22295 m .59834 .21696 L p .61649 .21074 L F P
0 g
s
.606 .948 .922 r
.60997 .46536 m .59707 .47167 L .60829 .46527 L closepath p F P
0 g
s
.641 .943 .958 r
.60385 .46422 m .60829 .46527 L .59707 .47167 L p F P
0 g
s
.641 .943 .958 r
.57876 .47603 m .60385 .46422 L p .59707 .47167 L F P
0 g
s
.658 .965 .785 r
.6852 .41833 m .69075 .41715 L .66586 .43581 L p F P
0 g
s
.658 .965 .785 r
.68101 .42157 m .6852 .41833 L p .66586 .43581 L F P
0 g
s
.658 .965 .785 r
.66586 .43581 m .66551 .43593 L .68101 .42157 L p F P
0 g
s
.477 .796 .999 r
.38942 .50077 m .39662 .50462 L .38268 .50634 L p F P
0 g
s
.477 .796 .999 r
.36526 .50365 m .38942 .50077 L p .38268 .50634 L F P
0 g
s
.477 .796 .999 r
.38268 .50634 m .3681 .50519 L .36526 .50365 L p F P
0 g
s
.75 .235 0 r
.32183 .3161 m .33488 .32221 L .3271 .31465 L p F P
0 g
s
.75 .235 0 r
.3271 .31465 m .31495 .30822 L .32183 .3161 L p F P
0 g
s
.374 .444 .805 r
.75079 .20675 m .75588 .21881 L .76254 .22178 L p F P
0 g
s
.787 .876 .912 r
.64747 .1889 m .62372 .20501 L .61895 .20133 L p F P
0 g
s
.614 .837 .451 r
.73626 .36971 m .73535 .37104 L .73904 .36632 L p F P
0 g
s
.614 .837 .451 r
.73904 .36632 m .74678 .35512 L .73626 .36971 L p F P
0 g
s
.525 .845 .998 r
.46237 .50348 m .45954 .5022 L .44393 .50557 L closepath p F P
0 g
s
.535 .841 .999 r
.45261 .49891 m .45954 .5022 L .44393 .50557 L p F P
0 g
s
.535 .841 .999 r
.42806 .50413 m .45261 .49891 L p .44393 .50557 L F P
0 g
s
.713 .986 .879 r
.66551 .43593 m .66012 .43616 L .68101 .42157 L closepath p F P
0 g
s
.602 .931 .959 r
.5757 .47541 m .57876 .47603 L .55379 .48642 L p F P
0 g
s
.602 .931 .959 r
.55379 .48642 m .55286 .48626 L .5757 .47541 L p F P
0 g
s
0 .129 .62 r
.11237 .40471 m .11929 .41027 L .12759 .41803 L p F P
0 g
s
.433 .777 .997 r
.3681 .50519 m .36526 .50365 L .3599 .50408 L closepath p F P
0 g
s
.221 .608 .951 r
.218 .46614 m .20657 .46391 L .21772 .47036 L p F P
0 g
s
.221 .608 .951 r
.21772 .47036 m .22586 .4719 L .218 .46614 L p F P
0 g
s
.613 .887 .569 r
.73483 .37138 m .73535 .37104 L .72571 .38324 L p F P
0 g
s
.613 .887 .569 r
.72209 .38557 m .73483 .37138 L p .72571 .38324 L F P
0 g
s
.613 .887 .569 r
.71409 .39557 m .72209 .38557 L p .72571 .38324 L F P
0 g
s
.613 .887 .569 r
.72571 .38324 m .71545 .39437 L .71409 .39557 L p F P
0 g
s
.585 .64 .872 r
.71138 .18255 m .73108 .17988 L .7283 .19173 L p F P
0 g
s
.547 .594 .853 r
.73747 .17933 m .73108 .17988 L .7283 .19173 L p F P
0 g
s
.547 .594 .853 r
.7283 .19173 m .74354 .19133 L .73747 .17933 L p F P
0 g
s
.666 .702 .873 r
.67985 .18211 m .70538 .17291 L .71138 .18255 L p F P
0 g
s
.684 .72 .877 r
.70538 .17291 m .67985 .18211 L .67384 .17414 L p F P
0 g
s
.734 .769 .881 r
.64866 .18808 m .67384 .17414 L .67985 .18211 L p F P
0 g
s
0 .295 .769 r
.13014 .41684 m .13845 .42461 L .12759 .41803 L p F P
0 g
s
0 .295 .769 r
.12759 .41803 m .11929 .41027 L .13014 .41684 L p F P
0 g
s
0 .124 .627 r
.28024 .27756 m .28843 .28567 L .27985 .27864 L p F P
0 g
s
0 .124 .627 r
.27985 .27864 m .27179 .2705 L .28024 .27756 L p F P
0 g
s
.112 .112 .578 r
.77942 .25845 m .77497 .27045 L .77104 .26109 L p F P
0 g
s
.112 .112 .578 r
.77104 .26109 m .77541 .2491 L .77942 .25845 L p F P
0 g
s
0 0 0 r
.75919 .33061 m .75853 .33302 L .76042 .32854 L closepath p F P
0 g
s
.114 .523 .912 r
.17955 .44826 m .16986 .44524 L .1797 .45226 L p F P
0 g
s
.114 .523 .912 r
.1797 .45226 m .18752 .45467 L .17955 .44826 L p F P
0 g
s
.696 .972 .924 r
.63807 .452 m .63502 .45169 L .64899 .44336 L closepath p F P
0 g
s
.711 .985 .818 r
.69081 .41714 m .69075 .41715 L .69097 .41698 L closepath p F P
0 g
s
.575 .87 .561 r
.71545 .39437 m .7106 .39935 L .71409 .39557 L closepath p F P
0 g
s
.305 .679 .976 r
.26567 .48675 m .26436 .4859 L .26336 .48582 L closepath p F P
0 g
s
.713 .985 .82 r
.69097 .41698 m .69075 .41715 L .6852 .41833 L p F P
0 g
s
.356 .75 .986 r
.33401 .50098 m .34007 .50081 L .3599 .50408 L p F P
0 g
s
.443 .774 .997 r
.35792 .49946 m .34007 .50081 L .3599 .50408 L p F P
0 g
s
.443 .774 .997 r
.3599 .50408 m .36526 .50365 L .35792 .49946 L p F P
0 g
s
.688 .966 .742 r
.70424 .40267 m .69097 .41698 L .7106 .39935 L p F P
0 g
s
.713 .985 .82 r
.6852 .41833 m .70424 .40267 L .69097 .41698 L p F P
0 g
s
.377 .75 .991 r
.33401 .50098 m .34007 .50081 L .33001 .49885 L closepath p F P
0 g
s
.688 .966 .742 r
.71016 .39719 m .70424 .40267 L p .7106 .39935 L F P
0 g
s
.688 .966 .742 r
.7106 .39935 m .71409 .39557 L .71016 .39719 L p F P
0 g
s
.603 .643 .863 r
.73108 .17988 m .71138 .18255 L .70538 .17291 L p F P
0 g
s
.637 .917 .979 r
.57243 .47424 m .5757 .47541 L .55286 .48626 L p F P
0 g
s
.637 .917 .979 r
.55286 .48626 m .54736 .48443 L .57243 .47424 L p F P
0 g
s
.564 .86 .997 r
.48424 .49575 m .48965 .49823 L .46237 .50348 L p F P
0 g
s
.564 .86 .997 r
.46237 .50348 m .45954 .5022 L .48424 .49575 L p F P
0 g
s
.658 .965 .92 r
.62904 .45106 m .63502 .45169 L .60997 .46536 L p F P
0 g
s
.658 .965 .92 r
.62783 .45174 m .62904 .45106 L p .60997 .46536 L F P
0 g
s
.658 .965 .92 r
.60997 .46536 m .60829 .46527 L .62783 .45174 L p F P
0 g
s
.32 .678 .977 r
.25665 .48062 m .25042 .48007 L .26336 .48582 L p F P
0 g
s
.32 .678 .977 r
.26336 .48582 m .26436 .4859 L .25665 .48062 L p F P
0 g
s
.453 .508 .825 r
.74966 .20422 m .75129 .20461 L .75079 .20675 L closepath p F P
0 g
s
.374 .444 .805 r
.76561 .21002 m .75129 .20461 L .75079 .20675 L p F P
0 g
s
.374 .444 .805 r
.76254 .22178 m .76561 .21002 L p .75079 .20675 L F P
0 g
s
.504 0 0 r
.29905 .29386 m .29831 .29343 L .29799 .29318 L closepath p F P
0 g
s
0 0 0 r
.76217 .32873 m .76729 .31601 L .76042 .32854 L p F P
0 g
s
0 0 0 r
.75732 .33751 m .76217 .32873 L p .76042 .32854 L F P
0 g
s
0 0 0 r
.76042 .32854 m .75853 .33302 L .75732 .33751 L p F P
0 g
s
0 0 0 r
.49625 .31101 m .49358 .3145 L .50843 .3024 L closepath p F P
0 g
s
.783 .827 .886 r
.64866 .18808 m .64747 .1889 L .64768 .18706 L closepath p F P
0 g
s
.787 .876 .912 r
.64258 .18172 m .64768 .18706 L .64747 .1889 L p F P
0 g
s
.787 .876 .912 r
.62001 .19852 m .64258 .18172 L p .64747 .1889 L F P
0 g
s
.787 .876 .912 r
.61895 .20133 m .62001 .19852 L p .64747 .1889 L F P
0 g
s
.326 .687 .979 r
.28772 .4873 m .26436 .4859 L .25665 .48062 L p F P
0 g
s
.757 .822 .903 r
.66779 .1664 m .67384 .17414 L .64866 .18808 L p F P
0 g
s
.757 .822 .903 r
.65133 .17648 m .66779 .1664 L p .64866 .18808 L F P
0 g
s
.757 .822 .903 r
.64866 .18808 m .64768 .18706 L .65133 .17648 L p F P
0 g
s
0 0 .455 r
.77658 .2807 m .77394 .28696 L .77271 .27588 L p F P
0 g
s
0 0 .455 r
.77271 .27588 m .77497 .27045 L .77658 .2807 L p F P
0 g
s
.603 .905 .984 r
.54736 .48443 m .52244 .49329 L .51584 .49115 L p F P
0 g
s
.556 .889 .986 r
.49101 .49868 m .51584 .49115 L .52244 .49329 L p F P
0 g
s
0 .143 .641 r
.28317 .27996 m .28024 .27756 L .28843 .28567 L p F P
0 g
s
0 .143 .641 r
.28843 .28567 m .29072 .28751 L .28317 .27996 L p F P
0 g
s
.698 .204 0 r
.29072 .28751 m .28317 .27996 L p .28804 .28545 L F P
0 g
s
.698 .204 0 r
.29516 .29348 m .29072 .28751 L p .28804 .28545 L F P
0 g
s
0 .118 .575 r
.29072 .28751 m .28843 .28567 L .29274 .28905 L p F P
0 g
s
0 .118 .575 r
.29274 .28905 m .29799 .29318 L p .29072 .28751 L F P
0 g
s
0 .118 .575 r
.29799 .29318 m .29831 .29343 L .29072 .28751 L p F P
0 g
s
.339 0 .044 r
.46898 .3274 m .46885 .32759 L .4669 .32795 L closepath p F P
0 g
s
.373 0 .115 r
.46551 .33402 m .46885 .32759 L .4669 .32795 L p F P
0 g
s
.373 0 .115 r
.43919 .34086 m .46551 .33402 L p .4669 .32795 L F P
0 g
s
.223 .249 .677 r
.7793 .23717 m .77541 .2491 L .76876 .24076 L p F P
0 g
s
.223 .249 .677 r
.76876 .24076 m .77251 .22886 L .7793 .23717 L p F P
0 g
s
.752 .262 .07 r
.34107 .33044 m .35587 .33588 L .34886 .32792 L p F P
0 g
s
.752 .262 .07 r
.33595 .32325 m .34107 .33044 L p .34886 .32792 L F P
0 g
s
.752 .262 .07 r
.34886 .32792 m .33714 .32306 L .33595 .32325 L p F P
0 g
s
.468 .531 .839 r
.75129 .20461 m .74966 .20422 L .74354 .19133 L p F P
0 g
s
0 0 .314 r
.77402 .29645 m .77023 .30408 L .77094 .29299 L p F P
0 g
s
0 0 .314 r
.77094 .29299 m .77394 .28696 L .77402 .29645 L p F P
0 g
s
.745 .236 0 r
.3044 .30113 m .29831 .29343 L .29072 .28751 L p F P
0 g
s
.837 .937 .892 r
.59558 .22295 m .59276 .2217 L .59834 .21696 L closepath p F P
0 g
s
.007 .429 .862 r
.1415 .42595 m .13845 .42461 L .14723 .43214 L p F P
0 g
s
.007 .429 .862 r
.14723 .43214 m .14955 .43315 L .1415 .42595 L p F P
0 g
s
.12 0 0 r
.46898 .3274 m .46885 .32759 L .47082 .32654 L closepath p F P
0 g
s
.465 .79 .999 r
.38942 .50077 m .36526 .50365 L .35792 .49946 L p F P
0 g
s
.231 0 .076 r
.47082 .32654 m .46885 .32759 L .46551 .33402 L p F P
0 g
s
0 0 0 r
.75853 .33302 m .75487 .34138 L .75732 .33751 L closepath p F P
0 g
s
.468 .531 .839 r
.74354 .19133 m .7534 .19309 L .75129 .20461 L p F P
0 g
s
.41 .473 .814 r
.76838 .19826 m .76561 .21002 L .75129 .20461 L p F P
0 g
s
.41 .473 .814 r
.75129 .20461 m .7534 .19309 L .76838 .19826 L p F P
0 g
s
.757 .821 .903 r
.64768 .18706 m .64258 .18172 L .65133 .17648 L closepath p F P
0 g
s
.185 0 .013 r
.49358 .3145 m .47082 .32654 L .49227 .31677 L closepath p F P
0 g
s
.231 0 .076 r
.48868 .32312 m .49227 .31677 L .47082 .32654 L p F P
0 g
s
.231 0 .076 r
.46551 .33402 m .48868 .32312 L p .47082 .32654 L F P
0 g
s
.323 .369 .755 r
.77587 .217 m .77251 .22886 L .76254 .22178 L p F P
0 g
s
.323 .369 .755 r
.76254 .22178 m .76561 .21002 L .77587 .217 L p F P
0 g
s
.456 .767 .996 r
.35054 .49502 m .35792 .49946 L .34007 .50081 L p F P
0 g
s
.456 .767 .996 r
.32655 .49673 m .35054 .49502 L p .34007 .50081 L F P
0 g
s
.456 .767 .996 r
.34007 .50081 m .33001 .49885 L .32655 .49673 L p F P
0 g
s
.53 .105 .179 r
.42795 .34194 m .40939 .34347 L .4055 .34929 L p F P
0 g
s
.632 .218 .24 r
.40939 .34347 m .4055 .34929 L .39591 .34283 L closepath p F P
0 g
s
.563 .887 .989 r
.51535 .49099 m .51584 .49115 L .49101 .49868 L p F P
0 g
s
.563 .887 .989 r
.49101 .49868 m .48965 .49823 L .51535 .49099 L p F P
0 g
s
.733 .977 .741 r
.71409 .39557 m .71016 .39719 L .72209 .38557 L closepath p F P
0 g
s
.763 .251 0 r
.3107 .30921 m .32183 .3161 L .31495 .30822 L p F P
0 g
s
.763 .251 0 r
.31495 .30822 m .3044 .30113 L .3107 .30921 L p F P
0 g
s
.686 .951 .955 r
.60829 .46527 m .60385 .46422 L .62783 .45174 L closepath p F P
0 g
s
.495 .814 1 r
.42099 .5006 m .39662 .50462 L .38942 .50077 L p F P
0 g
s
.645 .189 .155 r
.40525 .34974 m .4055 .34929 L .39591 .34283 L p F P
0 g
s
.645 .189 .155 r
.38196 .34778 m .40525 .34974 L p .39591 .34283 L F P
0 g
s
.645 .189 .155 r
.37427 .34029 m .38196 .34778 L p .39591 .34283 L F P
0 g
s
.645 .189 .155 r
.39591 .34283 m .37444 .34013 L .37427 .34029 L p F P
0 g
s
0 .418 .848 r
.14955 .43315 m .16053 .43797 L .16986 .44524 L p F P
0 g
s
0 .425 .859 r
.16053 .43797 m .14955 .43315 L .1415 .42595 L p F P
0 g
s
.211 .617 .951 r
.22586 .4719 m .2382 .47402 L .25042 .48007 L p F P
0 g
s
.227 .615 .954 r
.2382 .47402 m .22586 .4719 L .218 .46614 L p F P
0 g
s
.565 .857 .997 r
.48424 .49575 m .45954 .5022 L .45261 .49891 L p F P
0 g
s
.53 .837 .999 r
.45261 .49891 m .42806 .50413 L .42099 .5006 L p F P
0 g
s
.534 .122 .206 r
.43919 .34086 m .43716 .34434 L .42795 .34194 L closepath p F P
0 g
s
.53 .105 .179 r
.43563 .34764 m .43716 .34434 L .42795 .34194 L p F P
0 g
s
.53 .105 .179 r
.40637 .34969 m .43563 .34764 L p .42795 .34194 L F P
0 g
s
.53 .105 .179 r
.4055 .34929 m .40637 .34969 L p .42795 .34194 L F P
0 g
s
.414 .748 .994 r
.33001 .49885 m .32655 .49673 L .32204 .4969 L closepath p F P
0 g
s
.093 .525 .907 r
.18752 .45467 m .19599 .45719 L .20657 .46391 L p F P
0 g
s
.232 .604 .952 r
.2101 .46 m .19599 .45719 L .20657 .46391 L p F P
0 g
s
.232 .604 .952 r
.20657 .46391 m .218 .46614 L .2101 .46 L p F P
0 g
s
.115 .526 .913 r
.19599 .45719 m .18752 .45467 L .17955 .44826 L p F P
0 g
s
0 0 0 r
.75441 .34306 m .74678 .35512 L .75487 .34138 L p F P
0 g
s
0 0 0 r
.75487 .34138 m .75732 .33751 L .75441 .34306 L p F P
0 g
s
.652 .945 .958 r
.59765 .46271 m .60385 .46422 L .57876 .47603 L p F P
0 g
s
.652 .945 .958 r
.59496 .46399 m .59765 .46271 L p .57876 .47603 L F P
0 g
s
.652 .945 .958 r
.57876 .47603 m .5757 .47541 L .59496 .46399 L p F P
0 g
s
.697 .972 .925 r
.64899 .44336 m .63502 .45169 L .62904 .45106 L p F P
0 g
s
.801 .876 .902 r
.61895 .20133 m .6176 .20027 L .62001 .19852 L closepath p F P
0 g
s
.599 .874 .993 r
.50916 .48808 m .51535 .49099 L .48965 .49823 L p F P
0 g
s
.599 .874 .993 r
.48965 .49823 m .48424 .49575 L .50916 .48808 L p F P
0 g
s
.338 .717 .984 r
.29535 .49208 m .30584 .49232 L .32204 .4969 L p F P
0 g
s
.351 .713 .985 r
.30584 .49232 m .29535 .49208 L .28772 .4873 L p F P
0 g
s
.401 0 .135 r
.46205 .34078 m .46551 .33402 L .43919 .34086 L p F P
0 g
s
.401 0 .135 r
.45852 .34166 m .46205 .34078 L p .43919 .34086 L F P
0 g
s
.401 0 .135 r
.43919 .34086 m .43716 .34434 L .45852 .34166 L p F P
0 g
s
.718 .211 .024 r
.33714 .32306 m .33595 .32325 L .33488 .32221 L closepath p F P
0 g
s
.132 .522 .915 r
.17154 .44143 m .16053 .43797 L .16986 .44524 L p F P
0 g
s
.132 .522 .915 r
.16986 .44524 m .17955 .44826 L .17154 .44143 L p F P
0 g
s
0 0 .444 r
.78107 .26871 m .77658 .2807 L .77497 .27045 L p F P
0 g
s
0 0 .444 r
.77497 .27045 m .77942 .25845 L .78107 .26871 L p F P
0 g
s
.326 .672 .976 r
.24888 .47502 m .2382 .47402 L .25042 .48007 L p F P
0 g
s
.326 .672 .976 r
.25042 .48007 m .25665 .48062 L .24888 .47502 L p F P
0 g
s
.685 .239 .187 r
.37444 .34013 m .37427 .34029 L .374 .34005 L closepath p F P
0 g
s
.683 .242 .198 r
.36289 .34391 m .35587 .33588 L .374 .34005 L p F P
0 g
s
.683 .242 .198 r
.36917 .34533 m .36289 .34391 L p .374 .34005 L F P
0 g
s
.683 .242 .198 r
.374 .34005 m .37427 .34029 L .36917 .34533 L p F P
0 g
s
.485 .551 .848 r
.7534 .19309 m .74354 .19133 L .73747 .17933 L p F P
0 g
s
.684 .72 .877 r
.67384 .17414 m .69936 .16366 L .70538 .17291 L p F P
0 g
s
.7 .735 .878 r
.69936 .16366 m .67384 .17414 L .66779 .1664 L p F P
0 g
s
.759 .986 .754 r
.54413 .26985 m .54321 .27026 L .54576 .26771 L closepath p F P
0 g
s
.7 .264 .212 r
.37427 .34029 m .38196 .34778 L .36917 .34533 L closepath p F P
0 g
s
.716 .194 0 r
.32822 .32333 m .32183 .3161 L .33488 .32221 L p F P
0 g
s
.716 .194 0 r
.33488 .32221 m .33595 .32325 L .32822 .32333 L p F P
0 g
s
.425 .745 .993 r
.31905 .4919 m .30584 .49232 L .32204 .4969 L p F P
0 g
s
.425 .745 .993 r
.32204 .4969 m .32655 .49673 L .31905 .4919 L p F P
0 g
s
.836 .947 .893 r
.59834 .21696 m .59276 .2217 L .58653 .2193 L p F P
0 g
s
.882 .971 .839 r
.57968 .23429 m .59276 .2217 L .58653 .2193 L p F P
0 g
s
.603 .643 .863 r
.7333 .17155 m .73108 .17988 L p .70538 .17291 L F P
0 g
s
.603 .643 .863 r
.70538 .17291 m .73141 .1681 L .7333 .17155 L p F P
0 g
s
.621 .663 .869 r
.73141 .1681 m .70538 .17291 L .69936 .16366 L p F P
0 g
s
0 0 .286 r
.77601 .29178 m .77402 .29645 L .77394 .28696 L p F P
0 g
s
0 0 .286 r
.77394 .28696 m .77658 .2807 L .77601 .29178 L p F P
0 g
s
.863 .934 .869 r
.59834 .21696 m .6176 .20027 L .61143 .19571 L p F P
0 g
s
.863 .934 .869 r
.61143 .19571 m .60221 .20455 L .59834 .21696 L p F P
0 g
s
.836 .947 .893 r
.58653 .2193 m .60221 .20455 L .59834 .21696 L p F P
0 g
s
.882 .971 .839 r
.58653 .2193 m .58435 .22164 L .57968 .23429 L p F P
0 g
s
.826 .997 .843 r
.56941 .23766 m .58435 .22164 L .57968 .23429 L p F P
0 g
s
.826 .997 .843 r
.56542 .24558 m .56941 .23766 L p .57968 .23429 L F P
0 g
s
.826 .997 .843 r
.57968 .23429 m .56799 .24539 L .56542 .24558 L p F P
0 g
s
0 0 .098 r
.77302 .30443 m .76729 .31601 L .77023 .30408 L p F P
0 g
s
0 0 .098 r
.77023 .30408 m .77402 .29645 L .77302 .30443 L p F P
0 g
s
.846 .996 .833 r
.56799 .24539 m .56226 .25117 L .56542 .24558 L closepath p F P
0 g
s
.802 .884 .905 r
.62001 .19852 m .6176 .20027 L .61143 .19571 L p F P
0 g
s
.846 .995 .835 r
.555 .2535 m .54576 .26771 L .56226 .25117 L p F P
0 g
s
.846 .995 .835 r
.56167 .24585 m .555 .2535 L p .56226 .25117 L F P
0 g
s
.846 .995 .835 r
.56226 .25117 m .56542 .24558 L .56167 .24585 L p F P
0 g
s
.681 .978 .884 r
.66012 .43616 m .64899 .44336 L .65762 .43626 L closepath p F P
0 g
s
.697 .972 .925 r
.65428 .43567 m .65762 .43626 L .64899 .44336 L p F P
0 g
s
.697 .972 .925 r
.62904 .45106 m .65428 .43567 L p .64899 .44336 L F P
0 g
s
.825 .885 .887 r
.62001 .19852 m .64258 .18172 L .63646 .17548 L p F P
0 g
s
.825 .885 .887 r
.63646 .17548 m .62324 .18629 L .62001 .19852 L p F P
0 g
s
.802 .884 .905 r
.61143 .19571 m .62324 .18629 L .62001 .19852 L p F P
0 g
s
0 0 0 r
.50843 .3024 m .49358 .3145 L .49227 .31677 L p F P
0 g
s
.819 .371 .17 r
.34107 .33044 m .33595 .32325 L .32822 .32333 L p F P
0 g
s
.681 .946 .678 r
.54141 .26906 m .555 .2535 L .54576 .26771 L p F P
0 g
s
.681 .946 .678 r
.53862 .27317 m .54141 .26906 L p .54576 .26771 L F P
0 g
s
.681 .946 .678 r
.54576 .26771 m .54321 .27026 L .53862 .27317 L p F P
0 g
s
.704 .906 .548 r
.74457 .35682 m .73626 .36971 L .74678 .35512 L p F P
0 g
s
.704 .906 .548 r
.75409 .34337 m .74457 .35682 L p .74678 .35512 L F P
0 g
s
.704 .906 .548 r
.74678 .35512 m .75441 .34306 L .75409 .34337 L p F P
0 g
s
.663 .94 .675 r
.54321 .27026 m .52847 .28456 L .53862 .27317 L closepath p F P
0 g
s
0 0 0 r
.75485 .34225 m .75441 .34306 L .75732 .33751 L p F P
0 g
s
0 0 0 r
.75732 .33751 m .76217 .32873 L .75485 .34225 L p F P
0 g
s
0 0 0 r
.5184 .2943 m .50843 .3024 L .51661 .29652 L closepath p F P
0 g
s
0 0 0 r
.51238 .30183 m .51661 .29652 L .50843 .3024 L p F P
0 g
s
0 0 0 r
.49227 .31677 m .51238 .30183 L p .50843 .3024 L F P
0 g
s
.567 .619 .864 r
.73108 .17988 m .7333 .17155 L .73747 .17933 L closepath p F P
0 g
s
.033 .433 .869 r
.13343 .41829 m .13014 .41684 L .13845 .42461 L p F P
0 g
s
.033 .433 .869 r
.13845 .42461 m .1415 .42595 L .13343 .41829 L p F P
0 g
s
.646 .915 .979 r
.57243 .47424 m .54736 .48443 L .54086 .4822 L p F P
0 g
s
.603 .905 .984 r
.51584 .49115 m .54086 .4822 L .54736 .48443 L p F P
0 g
s
.443 .76 .996 r
.35054 .49502 m .32655 .49673 L .31905 .4919 L p F P
0 g
s
0 0 0 r
.53677 .27434 m .53862 .27317 L .52847 .28456 L p F P
0 g
s
0 0 0 r
.52757 .28472 m .53677 .27434 L p .52847 .28456 L F P
0 g
s
0 0 0 r
.51661 .29652 m .52757 .28472 L p .52847 .28456 L F P
0 g
s
.714 .986 .88 r
.68101 .42157 m .66012 .43616 L .65762 .43626 L p F P
0 g
s
.087 .1 .576 r
.78334 .24653 m .77942 .25845 L .77541 .2491 L p F P
0 g
s
.087 .1 .576 r
.77541 .2491 m .7793 .23717 L .78334 .24653 L p F P
0 g
s
.326 .687 .979 r
.28452 .48517 m .28772 .4873 L p .25665 .48062 L F P
0 g
s
.326 .687 .979 r
.25665 .48062 m .27656 .48195 L .28452 .48517 L p F P
0 g
s
.338 .682 .979 r
.27656 .48195 m .25665 .48062 L .24888 .47502 L p F P
0 g
s
.745 .236 0 r
.29072 .28751 m .29516 .29348 L .3044 .30113 L p F P
0 g
s
.753 .247 0 r
.30113 .30167 m .3107 .30921 L .3044 .30113 L p F P
0 g
s
.753 .247 0 r
.3044 .30113 m .29516 .29348 L .30113 .30167 L p F P
0 g
s
.732 .952 .651 r
.73535 .37104 m .73483 .37138 L .73626 .36971 L closepath p F P
0 g
s
.758 .827 .906 r
.65133 .17648 m .64258 .18172 L .63646 .17548 L p F P
0 g
s
.779 .343 .214 r
.34689 .3389 m .36289 .34391 L .35587 .33588 L p F P
0 g
s
.779 .343 .214 r
.35587 .33588 m .34107 .33044 L .34689 .3389 L p F P
0 g
s
.672 .925 .973 r
.5757 .47541 m .57243 .47424 L .59496 .46399 L closepath p F P
0 g
s
.433 .052 .214 r
.43716 .34434 m .45852 .34166 L .43563 .34764 L closepath p F P
0 g
s
.732 .952 .652 r
.73174 .37228 m .74457 .35682 L .73626 .36971 L p F P
0 g
s
.732 .952 .652 r
.73047 .37425 m .73174 .37228 L p .73626 .36971 L F P
0 g
s
.732 .952 .652 r
.73626 .36971 m .73483 .37138 L .73047 .37425 L p F P
0 g
s
.351 .713 .985 r
.28772 .4873 m .29056 .48738 L .30584 .49232 L p F P
0 g
s
.429 .739 .992 r
.31149 .48679 m .29056 .48738 L .30584 .49232 L p F P
0 g
s
.429 .739 .992 r
.30584 .49232 m .31905 .4919 L .31149 .48679 L p F P
0 g
s
.115 .526 .913 r
.17955 .44826 m .18598 .4502 L .19599 .45719 L p F P
0 g
s
.245 .599 .951 r
.20216 .45348 m .18598 .4502 L .19599 .45719 L p F P
0 g
s
.245 .599 .951 r
.19599 .45719 m .2101 .46 L .20216 .45348 L p F P
0 g
s
.687 .951 .955 r
.62783 .45174 m .60385 .46422 L .59765 .46271 L p F P
0 g
s
.71 .946 .651 r
.73483 .37138 m .72209 .38557 L .73047 .37425 L closepath p F P
0 g
s
.465 .79 .999 r
.35792 .49946 m .38215 .49672 L .38942 .50077 L p F P
0 g
s
.474 .784 .998 r
.38215 .49672 m .35792 .49946 L .35054 .49502 L p F P
0 g
s
0 .425 .859 r
.1415 .42595 m .1517 .43044 L .16053 .43797 L p F P
0 g
s
.03 .432 .868 r
.1517 .43044 m .1415 .42595 L .13343 .41829 L p F P
0 g
s
0 0 0 r
.5118 .30257 m .51238 .30183 L .49227 .31677 L p F P
0 g
s
0 0 0 r
.49626 .31741 m .5118 .30257 L p .49227 .31677 L F P
0 g
s
0 0 0 r
.49227 .31677 m .48868 .32312 L .49626 .31741 L p F P
0 g
s
.776 .82 .887 r
.65133 .17648 m .66779 .1664 L .66171 .1588 L p F P
0 g
s
.776 .82 .887 r
.66171 .1588 m .6526 .16491 L .65133 .17648 L p F P
0 g
s
.758 .827 .906 r
.63646 .17548 m .6526 .16491 L .65133 .17648 L p F P
0 g
s
.607 .903 .985 r
.53953 .48173 m .54086 .4822 L .51584 .49115 L p F P
0 g
s
.607 .903 .985 r
.51584 .49115 m .51535 .49099 L .53953 .48173 L p F P
0 g
s
.485 .551 .848 r
.73747 .17933 m .75527 .18156 L .7534 .19309 L p F P
0 g
s
.472 .568 .871 r
.7333 .17155 m .73747 .17933 L .75527 .18156 L p F P
0 g
s
.205 0 .068 r
.48676 .32657 m .48868 .32312 L .46551 .33402 L p F P
0 g
s
.205 0 .068 r
.4651 .33931 m .48676 .32657 L p .46551 .33402 L F P
0 g
s
.205 0 .068 r
.46551 .33402 m .46205 .34078 L .4651 .33931 L p F P
0 g
s
.23 .266 .692 r
.78098 .23127 m .7793 .23717 L .77251 .22886 L p F P
0 g
s
.23 .266 .692 r
.77743 .21873 m .78098 .23127 L p .77251 .22886 L F P
0 g
s
.23 .266 .692 r
.77251 .22886 m .77587 .217 L .77743 .21873 L p F P
0 g
s
.696 .981 .821 r
.6852 .41833 m .68101 .42157 L .68409 .41857 L closepath p F P
0 g
s
.714 .986 .88 r
.67952 .41831 m .68409 .41857 L .68101 .42157 L p F P
0 g
s
.714 .986 .88 r
.6664 .42772 m .67952 .41831 L p .68101 .42157 L F P
0 g
s
.714 .986 .88 r
.65762 .43626 m .6664 .42772 L p .68101 .42157 L F P
0 g
s
.227 .615 .954 r
.218 .46614 m .22666 .46767 L .2382 .47402 L p F P
0 g
s
.334 .665 .974 r
.24107 .46908 m .22666 .46767 L .2382 .47402 L p F P
0 g
s
.334 .665 .974 r
.2382 .47402 m .24888 .47502 L .24107 .46908 L p F P
0 g
s
.744 .224 0 r
.31705 .31735 m .3107 .30921 L .32183 .3161 L p F P
0 g
s
.744 .224 0 r
.32713 .32308 m .31705 .31735 L p .32183 .3161 L F P
0 g
s
.744 .224 0 r
.32183 .3161 m .32822 .32333 L .32713 .32308 L p F P
0 g
s
.726 .988 .819 r
.70424 .40267 m .6852 .41833 L .68409 .41857 L p F P
0 g
s
0 0 0 r
.76834 .31637 m .76217 .32873 L .76729 .31601 L p F P
0 g
s
0 0 0 r
.77275 .30524 m .76834 .31637 L p .76729 .31601 L F P
0 g
s
0 0 0 r
.76729 .31601 m .77302 .30443 L .77275 .30524 L p F P
0 g
s
.428 .495 .826 r
.76903 .195 m .76838 .19826 L .7534 .19309 L p F P
0 g
s
.428 .495 .826 r
.76449 .18415 m .76903 .195 L p .7534 .19309 L F P
0 g
s
.428 .495 .826 r
.7534 .19309 m .75527 .18156 L .76449 .18415 L p F P
0 g
s
.243 .611 .955 r
.22666 .46767 m .218 .46614 L .2101 .46 L p F P
0 g
s
0 0 .258 r
.78054 .2798 m .77601 .29178 L .77658 .2807 L p F P
0 g
s
0 0 .258 r
.77658 .2807 m .78107 .26871 L .78054 .2798 L p F P
0 g
s
.632 .884 .987 r
.53428 .47916 m .53953 .48173 L .51535 .49099 L p F P
0 g
s
.632 .884 .987 r
.51535 .49099 m .50916 .48808 L .53428 .47916 L p F P
0 g
s
.861 .993 .826 r
.56542 .24558 m .56167 .24585 L .56941 .23766 L closepath p F P
0 g
s
.733 .977 .741 r
.72966 .37444 m .73047 .37425 L .72209 .38557 L p F P
0 g
s
.733 .977 .741 r
.71503 .38906 m .72966 .37444 L p .72209 .38557 L F P
0 g
s
.733 .977 .741 r
.70835 .39794 m .71503 .38906 L p .72209 .38557 L F P
0 g
s
.733 .977 .741 r
.72209 .38557 m .71016 .39719 L .70835 .39794 L p F P
0 g
s
.583 .182 .249 r
.4055 .34929 m .40637 .34969 L .40525 .34974 L closepath p F P
0 g
s
.152 .522 .917 r
.16351 .43416 m .1517 .43044 L .16053 .43797 L p F P
0 g
s
.152 .522 .917 r
.16053 .43797 m .17154 .44143 L .16351 .43416 L p F P
0 g
s
.343 .396 .772 r
.77633 .21513 m .77587 .217 L .76561 .21002 L p F P
0 g
s
.343 .396 .772 r
.77082 .19968 m .77633 .21513 L p .76561 .21002 L F P
0 g
s
.343 .396 .772 r
.76561 .21002 m .76838 .19826 L .77082 .19968 L p F P
0 g
s
.706 .971 .742 r
.71016 .39719 m .70424 .40267 L .70835 .39794 L closepath p F P
0 g
s
.726 .988 .819 r
.70469 .39825 m .70835 .39794 L .70424 .40267 L p F P
0 g
s
.726 .988 .819 r
.69396 .40731 m .70469 .39825 L p .70424 .40267 L F P
0 g
s
.726 .988 .819 r
.68409 .41857 m .69396 .40731 L p .70424 .40267 L F P
0 g
s
.495 .814 1 r
.38942 .50077 m .41386 .49688 L .42099 .5006 L p F P
0 g
s
.506 .809 .999 r
.41386 .49688 m .38942 .50077 L .38215 .49672 L p F P
0 g
s
.138 .526 .918 r
.18598 .4502 m .17955 .44826 L .17154 .44143 L p F P
0 g
s
.601 .871 .993 r
.50916 .48808 m .48424 .49575 L .47741 .49248 L p F P
0 g
s
.565 .857 .997 r
.45261 .49891 m .47741 .49248 L .48424 .49575 L p F P
0 g
s
.588 .193 .262 r
.40637 .34969 m .40525 .34974 L .40154 .35662 L p F P
0 g
s
.674 .289 .308 r
.38979 .35564 m .40154 .35662 L .40525 .34974 L p F P
0 g
s
.674 .289 .308 r
.40525 .34974 m .38196 .34778 L .38979 .35564 L p F P
0 g
s
.585 .207 .292 r
.43563 .34764 m .40637 .34969 L .41911 .35583 L p F P
0 g
s
.588 .193 .262 r
.40154 .35662 m .41911 .35583 L .40637 .34969 L p F P
0 g
s
.621 .663 .869 r
.69936 .16366 m .72537 .15751 L .73141 .1681 L p F P
0 g
s
.638 .682 .875 r
.72537 .15751 m .69936 .16366 L .69333 .1547 L p F P
0 g
s
.7 .735 .878 r
.66779 .1664 m .69333 .1547 L .69936 .16366 L p F P
0 g
s
0 0 0 r
.51369 .30042 m .51238 .30183 L .51661 .29652 L p F P
0 g
s
0 0 0 r
.51661 .29652 m .52757 .28472 L .51369 .30042 L p F P
0 g
s
0 0 .068 r
.77337 .30363 m .77302 .30443 L .77402 .29645 L p F P
0 g
s
0 0 .068 r
.77402 .29645 m .77601 .29178 L .77337 .30363 L p F P
0 g
s
.53 .837 .999 r
.42099 .5006 m .44563 .49545 L .45261 .49891 L p F P
0 g
s
.536 .833 .999 r
.44563 .49545 m .42099 .5006 L .41386 .49688 L p F P
0 g
s
.565 .855 .997 r
.47741 .49248 m .45261 .49891 L .44563 .49545 L p F P
0 g
s
.368 .71 .986 r
.28772 .4873 m .29056 .48738 L .28452 .48517 L closepath p F P
0 g
s
.743 .975 .924 r
.65762 .43626 m .65428 .43567 L .6664 .42772 L closepath p F P
0 g
s
.715 .747 .878 r
.69333 .1547 m .66779 .1664 L .66171 .1588 L p F P
0 g
s
.767 .991 .888 r
.68409 .41857 m .67952 .41831 L .69396 .40731 L closepath p F P
0 g
s
.819 .371 .17 r
.32822 .32333 m .32867 .32407 L .34107 .33044 L p F P
0 g
s
.823 .382 .187 r
.33369 .33281 m .34689 .3389 L .34107 .33044 L p F P
0 g
s
.823 .382 .187 r
.34107 .33044 m .32867 .32407 L .33369 .33281 L p F P
0 g
s
.703 .272 .223 r
.36948 .3522 m .38979 .35564 L .38196 .34778 L p F P
0 g
s
.703 .272 .223 r
.3665 .3481 m .36948 .3522 L p .38196 .34778 L F P
0 g
s
.703 .272 .223 r
.38196 .34778 m .36917 .34533 L .3665 .3481 L p F P
0 g
s
.44 .063 .227 r
.45852 .34166 m .43563 .34764 L .4324 .35491 L p F P
0 g
s
.585 .207 .292 r
.41911 .35583 m .4324 .35491 L .43563 .34764 L p F P
0 g
s
.531 .606 .874 r
.73141 .1681 m .73342 .16809 L .7333 .17155 L closepath p F P
0 g
s
.472 .568 .871 r
.75698 .16998 m .73342 .16809 L .7333 .17155 L p F P
0 g
s
.472 .568 .871 r
.75527 .18156 m .75698 .16998 L p .7333 .17155 L F P
0 g
s
.675 .922 .973 r
.59496 .46399 m .57243 .47424 L .56604 .47185 L p F P
0 g
s
.646 .915 .979 r
.54086 .4822 m .56604 .47185 L .57243 .47424 L p F P
0 g
s
.445 .732 .988 r
.30388 .48139 m .31149 .48679 L .29056 .48738 L p F P
0 g
s
.445 .732 .988 r
.28006 .48197 m .30388 .48139 L p .29056 .48738 L F P
0 g
s
.445 .732 .988 r
.29056 .48738 m .28452 .48517 L .28006 .48197 L p F P
0 g
s
.675 .965 .931 r
.62904 .45106 m .62783 .45174 L .62881 .45103 L closepath p F P
0 g
s
.687 .951 .955 r
.62296 .44927 m .62881 .45103 L .62783 .45174 L p F P
0 g
s
.687 .951 .955 r
.59765 .46271 m .62296 .44927 L p .62783 .45174 L F P
0 g
s
.671 .816 .374 r
.76113 .32989 m .75485 .34225 L .76217 .32873 L p F P
0 g
s
.671 .816 .374 r
.76217 .32873 m .76834 .31637 L .76113 .32989 L p F P
0 g
s
0 0 .428 r
.78498 .25681 m .78107 .26871 L .77942 .25845 L p F P
0 g
s
0 0 .428 r
.77942 .25845 m .78334 .24653 L .78498 .25681 L p F P
0 g
s
.698 .204 0 r
.28317 .27996 m .28708 .28533 L .29516 .29348 L p F P
0 g
s
.709 .217 0 r
.29293 .29355 m .30113 .30167 L .29516 .29348 L p F P
0 g
s
.709 .217 0 r
.29516 .29348 m .28708 .28533 L .29293 .29355 L p F P
0 g
s
.716 .975 .924 r
.64834 .43455 m .65428 .43567 L .62904 .45106 L p F P
0 g
s
.716 .975 .924 r
.6467 .43558 m .64834 .43455 L p .62904 .45106 L F P
0 g
s
.716 .975 .924 r
.62904 .45106 m .62881 .45103 L .6467 .43558 L p F P
0 g
s
.726 .952 .949 r
.62881 .45103 m .62296 .44927 L .6467 .43558 L closepath p F P
0 g
s
.821 .887 .891 r
.62324 .18629 m .61143 .19571 L .6052 .19118 L p F P
0 g
s
.877 .906 .846 r
.60221 .20455 m .61143 .19571 L .6052 .19118 L p F P
0 g
s
.725 .301 .24 r
.36917 .34533 m .3665 .3481 L .36289 .34391 L closepath p F P
0 g
s
.788 .999 .839 r
.70835 .39794 m .70469 .39825 L .71503 .38906 L closepath p F P
0 g
s
.877 .906 .846 r
.6052 .19118 m .60347 .193 L .60221 .20455 L p F P
0 g
s
.858 .95 .873 r
.58782 .20932 m .60347 .193 L .60221 .20455 L p F P
0 g
s
.858 .95 .873 r
.58504 .21878 m .58782 .20932 L p .60221 .20455 L F P
0 g
s
.858 .95 .873 r
.60221 .20455 m .58653 .2193 L .58504 .21878 L p F P
0 g
s
.545 .624 .881 r
.73342 .16809 m .73141 .1681 L .72537 .15751 L p F P
0 g
s
.886 .942 .844 r
.58653 .2193 m .58435 .22164 L .58504 .21878 L closepath p F P
0 g
s
.443 .76 .996 r
.31905 .4919 m .34309 .49035 L .35054 .49502 L p F P
0 g
s
.454 .752 .993 r
.34309 .49035 m .31905 .4919 L .31149 .48679 L p F P
0 g
s
.138 .526 .918 r
.17154 .44143 m .17653 .44295 L .18598 .4502 L p F P
0 g
s
.259 .595 .95 r
.19419 .44655 m .17653 .44295 L .18598 .4502 L p F P
0 g
s
.259 .595 .95 r
.18598 .4502 m .20216 .45348 L .19419 .44655 L p F P
0 g
s
.886 .941 .845 r
.57349 .22516 m .56941 .23766 L .58435 .22164 L p F P
0 g
s
.886 .941 .845 r
.58023 .21707 m .57349 .22516 L p .58435 .22164 L F P
0 g
s
.886 .941 .845 r
.58435 .22164 m .58504 .21878 L .58023 .21707 L p F P
0 g
s
.243 .611 .955 r
.2101 .46 m .21577 .46102 L .22666 .46767 L p F P
0 g
s
.342 .659 .972 r
.23322 .4628 m .21577 .46102 L .22666 .46767 L p F P
0 g
s
.342 .659 .972 r
.22666 .46767 m .24107 .46908 L .23322 .4628 L p F P
0 g
s
.407 .715 .986 r
.28452 .48517 m .28006 .48197 L .27656 .48195 L closepath p F P
0 g
s
0 0 .026 r
.77795 .29167 m .77337 .30363 L .77601 .29178 L p F P
0 g
s
0 0 .026 r
.77601 .29178 m .78054 .2798 L .77795 .29167 L p F P
0 g
s
.837 .866 .865 r
.62324 .18629 m .63646 .17548 L .63029 .16925 L p F P
0 g
s
.837 .866 .865 r
.63029 .16925 m .62396 .17489 L .62324 .18629 L p F P
0 g
s
.821 .887 .891 r
.6052 .19118 m .62396 .17489 L .62324 .18629 L p F P
0 g
s
.765 .259 0 r
.30711 .30994 m .31705 .31735 L .3107 .30921 L p F P
0 g
s
.765 .259 0 r
.3107 .30921 m .30113 .30167 L .30711 .30994 L p F P
0 g
s
.338 .682 .979 r
.24888 .47502 m .2637 .47607 L .27656 .48195 L p F P
0 g
s
.35 .676 .977 r
.2637 .47607 m .24888 .47502 L .24107 .46908 L p F P
0 g
s
.726 .3 .236 r
.35265 .34746 m .34689 .3389 L .36289 .34391 L p F P
0 g
s
.726 .3 .236 r
.36392 .35067 m .35265 .34746 L p .36289 .34391 L F P
0 g
s
.726 .3 .236 r
.36289 .34391 m .3665 .3481 L .36392 .35067 L p F P
0 g
s
.545 .624 .881 r
.72537 .15751 m .73324 .15713 L .73342 .16809 L p F P
0 g
s
.513 .596 .875 r
.7572 .16799 m .75698 .16998 L .73342 .16809 L p F P
0 g
s
.513 .596 .875 r
.75212 .15768 m .7572 .16799 L p .73342 .16809 L F P
0 g
s
.513 .596 .875 r
.73342 .16809 m .73324 .15713 L .75212 .15768 L p F P
0 g
s
.774 .832 .897 r
.6526 .16491 m .63646 .17548 L .63029 .16925 L p F P
0 g
s
.03 .432 .868 r
.13343 .41829 m .14338 .42265 L .1517 .43044 L p F P
0 g
s
.759 .969 .686 r
.53862 .27317 m .53677 .27434 L .54141 .26906 L closepath p F P
0 g
s
.647 .915 .979 r
.56224 .47039 m .56604 .47185 L .54086 .4822 L p F P
0 g
s
.647 .915 .979 r
.54086 .4822 m .53953 .48173 L .56224 .47039 L p F P
0 g
s
.85 .998 .814 r
.56063 .24048 m .57349 .22516 L .56941 .23766 L p F P
0 g
s
.85 .998 .814 r
.55819 .24636 m .56063 .24048 L p .56941 .23766 L F P
0 g
s
.85 .998 .814 r
.56941 .23766 m .56167 .24585 L .55819 .24636 L p F P
0 g
s
.745 .917 .552 r
.75441 .34306 m .75409 .34337 L .75485 .34225 L closepath p F P
0 g
s
.061 .086 .573 r
.78385 .24476 m .78334 .24653 L .7793 .23717 L p F P
0 g
s
.061 .086 .573 r
.7793 .23717 m .78098 .23127 L .78385 .24476 L p F P
0 g
s
.875 .993 .8 r
.56167 .24585 m .555 .2535 L .55819 .24636 L closepath p F P
0 g
s
.172 .521 .918 r
.15545 .42645 m .14338 .42265 L .1517 .43044 L p F P
0 g
s
.172 .521 .918 r
.1517 .43044 m .16351 .43416 L .15545 .42645 L p F P
0 g
s
.83 .363 .089 r
.32822 .32333 m .32867 .32407 L .32713 .32308 L closepath p F P
0 g
s
.747 .919 .554 r
.75173 .34421 m .76113 .32989 L .75485 .34225 L p F P
0 g
s
.747 .919 .554 r
.75029 .34702 m .75173 .34421 L p .75485 .34225 L F P
0 g
s
.747 .919 .554 r
.75485 .34225 m .75409 .34337 L .75029 .34702 L p F P
0 g
s
.731 .915 .553 r
.75409 .34337 m .74457 .35682 L .75029 .34702 L closepath p F P
0 g
s
.876 .944 .856 r
.58504 .21878 m .58023 .21707 L .58782 .20932 L closepath p F P
0 g
s
.474 .784 .998 r
.38001 .49546 m .38215 .49672 L p .35054 .49502 L F P
0 g
s
.474 .784 .998 r
.35054 .49502 m .36483 .49345 L .38001 .49546 L p F P
0 g
s
.487 .778 .996 r
.36483 .49345 m .35054 .49502 L .34309 .49035 L p F P
0 g
s
.259 .608 .955 r
.21577 .46102 m .2101 .46 L .20216 .45348 L p F P
0 g
s
.835 .373 .105 r
.32258 .32589 m .33369 .33281 L .32867 .32407 L p F P
0 g
s
.835 .373 .105 r
.32048 .32174 m .32258 .32589 L p .32867 .32407 L F P
0 g
s
.835 .373 .105 r
.32867 .32407 m .32713 .32308 L .32048 .32174 L p F P
0 g
s
.424 .03 .185 r
.46205 .34078 m .4618 .34128 L .45852 .34166 L closepath p F P
0 g
s
.44 .063 .227 r
.45913 .34826 m .4618 .34128 L .45852 .34166 L p F P
0 g
s
.44 .063 .227 r
.4324 .35491 m .45913 .34826 L p .45852 .34166 L F P
0 g
s
.745 .974 .925 r
.6664 .42772 m .65428 .43567 L .64834 .43455 L p F P
0 g
s
.875 .993 .8 r
.54865 .25549 m .54141 .26906 L .555 .2535 L p F P
0 g
s
.875 .993 .8 r
.55528 .2468 m .54865 .25549 L p .555 .2535 L F P
0 g
s
.875 .993 .8 r
.555 .2535 m .55819 .24636 L .55528 .2468 L p F P
0 g
s
.16 .527 .92 r
.17653 .44295 m .17154 .44143 L .16351 .43416 L p F P
0 g
s
.417 .711 .984 r
.27235 .47615 m .2637 .47607 L .27656 .48195 L p F P
0 g
s
.417 .711 .984 r
.27656 .48195 m .28006 .48197 L .27235 .47615 L p F P
0 g
s
.638 .682 .875 r
.69333 .1547 m .71932 .14732 L .72537 .15751 L p F P
0 g
s
.653 .697 .878 r
.71932 .14732 m .69333 .1547 L .68726 .14595 L p F P
0 g
s
.715 .747 .878 r
.66171 .1588 m .68726 .14595 L .69333 .1547 L p F P
0 g
s
.787 .813 .873 r
.6526 .16491 m .66171 .1588 L .65558 .15125 L p F P
0 g
s
.787 .813 .873 r
.65558 .15125 m .65178 .15402 L .6526 .16491 L p F P
0 g
s
.774 .832 .897 r
.63029 .16925 m .65178 .15402 L .6526 .16491 L p F P
0 g
s
.662 .892 .98 r
.55957 .46902 m .56224 .47039 L .53953 .48173 L p F P
0 g
s
.662 .892 .98 r
.53953 .48173 m .53428 .47916 L .55957 .46902 L p F P
0 g
s
.216 0 .085 r
.46205 .34078 m .4618 .34128 L .4651 .33931 L closepath p F P
0 g
s
.663 .942 .963 r
.59765 .46271 m .59496 .46399 L .59725 .46261 L closepath p F P
0 g
s
.675 .922 .973 r
.59136 .46018 m .59725 .46261 L .59496 .46399 L p F P
0 g
s
.675 .922 .973 r
.56604 .47185 m .59136 .46018 L p .59496 .46399 L F P
0 g
s
0 0 0 r
.48868 .32312 m .48676 .32657 L .49626 .31741 L closepath p F P
0 g
s
.775 .272 0 r
.32713 .32308 m .32048 .32174 L .31705 .31735 L closepath p F P
0 g
s
.636 .881 .986 r
.53428 .47916 m .50916 .48808 L .50242 .48478 L p F P
0 g
s
.601 .871 .993 r
.47741 .49248 m .50242 .48478 L .50916 .48808 L p F P
0 g
s
.214 .262 .696 r
.77587 .217 m .77633 .21513 L .77743 .21873 L closepath p F P
0 g
s
.428 .495 .826 r
.75827 .17025 m .75698 .16998 L .75527 .18156 L p F P
0 g
s
.428 .495 .826 r
.75527 .18156 m .76449 .18415 L .75827 .17025 L p F P
0 g
s
.701 .951 .954 r
.61734 .44753 m .62296 .44927 L .59765 .46271 L p F P
0 g
s
.701 .951 .954 r
.59765 .46271 m .59725 .46261 L .61734 .44753 L p F P
0 g
s
.297 0 .192 r
.4651 .33931 m .4618 .34128 L .45913 .34826 L p F P
0 g
s
.506 .809 .999 r
.41351 .49668 m .41386 .49688 L p .38215 .49672 L F P
0 g
s
.506 .809 .999 r
.38215 .49672 m .38756 .49586 L .41351 .49668 L p F P
0 g
s
.516 .803 .998 r
.38215 .49672 m .38756 .49586 L .38001 .49546 L closepath p F P
0 g
s
0 0 0 r
.77302 .30443 m .77275 .30524 L .77337 .30363 L closepath p F P
0 g
s
.747 .987 .896 r
.67952 .41831 m .6664 .42772 L .67575 .41806 L closepath p F P
0 g
s
.745 .974 .925 r
.67374 .41752 m .67575 .41806 L .6664 .42772 L p F P
0 g
s
.745 .974 .925 r
.64834 .43455 m .67374 .41752 L p .6664 .42772 L F P
0 g
s
.728 .757 .876 r
.68726 .14595 m .66171 .1588 L .65558 .15125 L p F P
0 g
s
.687 .928 .616 r
.53743 .27026 m .54865 .25549 L .54141 .26906 L p F P
0 g
s
.687 .928 .616 r
.53345 .27704 m .53743 .27026 L p .54141 .26906 L F P
0 g
s
.687 .928 .616 r
.54141 .26906 m .53677 .27434 L .53345 .27704 L p F P
0 g
s
.254 0 .132 r
.48676 .32657 m .4651 .33931 L .48533 .32987 L closepath p F P
0 g
s
.297 0 .192 r
.48231 .33711 m .48533 .32987 L .4651 .33931 L p F P
0 g
s
.297 0 .192 r
.45913 .34826 m .48231 .33711 L p .4651 .33931 L F P
0 g
s
.708 .926 .964 r
.6168 .44728 m .61734 .44753 L .59725 .46261 L p F P
0 g
s
.708 .926 .964 r
.59725 .46261 m .59136 .46018 L .6168 .44728 L p F P
0 g
s
.336 .397 .777 r
.76838 .19826 m .76903 .195 L .77082 .19968 L closepath p F P
0 g
s
.808 .985 .717 r
.73931 .35958 m .73174 .37228 L .74457 .35682 L p F P
0 g
s
.808 .985 .717 r
.74912 .34751 m .73931 .35958 L p .74457 .35682 L F P
0 g
s
.808 .985 .717 r
.74457 .35682 m .75029 .34702 L .74912 .34751 L p F P
0 g
s
0 0 .223 r
.78443 .26794 m .78054 .2798 L .78107 .26871 L p F P
0 g
s
0 0 .223 r
.78107 .26871 m .78498 .25681 L .78443 .26794 L p F P
0 g
s
.606 .867 .992 r
.4981 .48257 m .50242 .48478 L .47741 .49248 L p F P
0 g
s
.606 .867 .992 r
.47741 .49248 m .47201 .48979 L .4981 .48257 L p F P
0 g
s
.565 .855 .997 r
.47201 .48979 m .47741 .49248 L p .44563 .49545 L F P
0 g
s
.433 .723 .986 r
.30388 .48139 m .28006 .48197 L .27235 .47615 L p F P
0 g
s
.752 .335 .258 r
.3665 .3481 m .36948 .3522 L .36392 .35067 L closepath p F P
0 g
s
.805 .997 .779 r
.73047 .37425 m .72966 .37444 L .73174 .37228 L closepath p F P
0 g
s
.591 .2 .271 r
.41911 .35583 m .40154 .35662 L .39787 .36365 L p F P
0 g
s
.675 .293 .314 r
.39756 .36362 m .39787 .36365 L .40154 .35662 L p F P
0 g
s
.675 .293 .314 r
.40154 .35662 m .38979 .35564 L .39756 .36362 L p F P
0 g
s
.818 .392 .231 r
.33859 .34167 m .35265 .34746 L .34689 .3389 L p F P
0 g
s
.818 .392 .231 r
.34689 .3389 m .33369 .33281 L .33859 .34167 L p F P
0 g
s
0 0 0 r
.77335 .30428 m .77795 .29167 L .77337 .30363 L p F P
0 g
s
0 0 0 r
.77084 .31079 m .77335 .30428 L p .77337 .30363 L F P
0 g
s
0 0 0 r
.77337 .30363 m .77275 .30524 L .77084 .31079 L p F P
0 g
s
.68 .925 .615 r
.53677 .27434 m .52757 .28472 L .53345 .27704 L closepath p F P
0 g
s
.536 .833 .999 r
.44389 .49453 m .44563 .49545 L p .41386 .49688 L F P
0 g
s
.536 .833 .999 r
.41386 .49688 m .41525 .49659 L .44389 .49453 L p F P
0 g
s
.547 .826 .997 r
.41386 .49688 m .41525 .49659 L .41351 .49668 L closepath p F P
0 g
s
.249 .322 .743 r
.77082 .19968 m .77783 .20554 L .77633 .21513 L closepath p F P
0 g
s
.083 .173 .661 r
.78411 .21405 m .77783 .20554 L .77633 .21513 L p F P
0 g
s
.083 .173 .661 r
.78221 .22548 m .78411 .21405 L p .77633 .21513 L F P
0 g
s
.083 .173 .661 r
.77633 .21513 m .77743 .21873 L .78221 .22548 L p F P
0 g
s
.139 .195 .659 r
.77743 .21873 m .78221 .22548 L .78098 .23127 L closepath p F P
0 g
s
.565 .855 .997 r
.44563 .49545 m .45831 .49219 L .47201 .48979 L p F P
0 g
s
.577 .847 .995 r
.44563 .49545 m .45831 .49219 L .44389 .49453 L closepath p F P
0 g
s
0 0 0 r
.77275 .30524 m .76834 .31637 L .77084 .31079 L closepath p F P
0 g
s
.588 .214 .301 r
.4324 .35491 m .42971 .36117 L .41911 .35583 L closepath p F P
0 g
s
.591 .2 .271 r
.42928 .3624 m .42971 .36117 L .41911 .35583 L p F P
0 g
s
.591 .2 .271 r
.39787 .36365 m .42928 .3624 L p .41911 .35583 L F P
0 g
s
.769 .99 .889 r
.69396 .40731 m .67952 .41831 L .67575 .41806 L p F P
0 g
s
.56 .637 .884 r
.73324 .15713 m .72537 .15751 L .71932 .14732 L p F P
0 g
s
.579 .816 .989 r
.41525 .49659 m .41351 .49668 L .40669 .49228 L p F P
0 g
s
.548 .805 .993 r
.41351 .49668 m .40669 .49228 L .38756 .49586 L closepath p F P
0 g
s
.723 .346 .335 r
.3754 .36081 m .39756 .36362 L .38979 .35564 L p F P
0 g
s
.723 .346 .335 r
.38979 .35564 m .36948 .3522 L .3754 .36081 L p F P
0 g
s
.573 .823 .992 r
.44389 .49453 m .43859 .49124 L .41525 .49659 L closepath p F P
0 g
s
.579 .816 .989 r
.43149 .48656 m .43859 .49124 L .41525 .49659 L p F P
0 g
s
.579 .816 .989 r
.40669 .49228 m .43149 .48656 L p .41525 .49659 L F P
0 g
s
.678 .923 .61 r
.52621 .28505 m .51369 .30042 L .52757 .28472 L p F P
0 g
s
.678 .923 .61 r
.53025 .27968 m .52621 .28505 L p .52757 .28472 L F P
0 g
s
.678 .923 .61 r
.52757 .28472 m .53345 .27704 L .53025 .27968 L p F P
0 g
s
.259 .608 .955 r
.20216 .45348 m .20551 .45409 L .21577 .46102 L p F P
0 g
s
.351 .653 .969 r
.22532 .45614 m .20551 .45409 L .21577 .46102 L p F P
0 g
s
.351 .653 .969 r
.21577 .46102 m .23322 .4628 L .22532 .45614 L p F P
0 g
s
.469 .095 .247 r
.4563 .35595 m .45913 .34826 L .4324 .35491 L p F P
0 g
s
.469 .095 .247 r
.4348 .36104 m .4563 .35595 L p .4324 .35491 L F P
0 g
s
.469 .095 .247 r
.4324 .35491 m .42971 .36117 L .4348 .36104 L p F P
0 g
s
.556 .799 .989 r
.39945 .48734 m .40669 .49228 L .38756 .49586 L p F P
0 g
s
.556 .799 .989 r
.37484 .492 m .39945 .48734 L p .38756 .49586 L F P
0 g
s
.556 .799 .989 r
.38756 .49586 m .38001 .49546 L .37484 .492 L p F P
0 g
s
.16 .527 .92 r
.16351 .43416 m .16764 .43542 L .17653 .44295 L p F P
0 g
s
.273 .591 .948 r
.18619 .43921 m .16764 .43542 L .17653 .44295 L p F P
0 g
s
.273 .591 .948 r
.17653 .44295 m .19419 .44655 L .18619 .43921 L p F P
0 g
s
0 0 0 r
.51238 .30183 m .5118 .30257 L .51369 .30042 L closepath p F P
0 g
s
0 .034 .548 r
.78599 .23495 m .78385 .24476 L .78098 .23127 L p F P
0 g
s
0 .034 .548 r
.78098 .23127 m .78221 .22548 L .78599 .23495 L p F P
0 g
s
.808 .997 .782 r
.7243 .37569 m .73931 .35958 L .73174 .37228 L p F P
0 g
s
.808 .997 .782 r
.73174 .37228 m .72966 .37444 L .7243 .37569 L p F P
0 g
s
.21 .316 .754 r
.76903 .195 m .77082 .19968 L .77783 .20554 L p F P
0 g
s
.719 .226 0 r
.29879 .30186 m .30711 .30994 L .30113 .30167 L p F P
0 g
s
.719 .226 0 r
.30113 .30167 m .29293 .29355 L .29879 .30186 L p F P
0 g
s
.783 .991 .761 r
.71503 .38906 m .72966 .37444 L .7243 .37569 L p F P
0 g
s
.772 .997 .847 r
.70469 .39825 m .69396 .40731 L .70114 .39851 L closepath p F P
0 g
s
.769 .99 .889 r
.69909 .39815 m .70114 .39851 L .69396 .40731 L p F P
0 g
s
.769 .99 .889 r
.67965 .41332 m .69909 .39815 L p .69396 .40731 L F P
0 g
s
.769 .99 .889 r
.67575 .41806 m .67965 .41332 L p .69396 .40731 L F P
0 g
s
.522 .786 .993 r
.38001 .49546 m .37484 .492 L .36483 .49345 L closepath p F P
0 g
s
.79 .999 .841 r
.71503 .38906 m .70469 .39825 L .70114 .39851 L p F P
0 g
s
.336 .42 .8 r
.76449 .18415 m .76982 .18688 L .76903 .195 L closepath p F P
0 g
s
.21 .316 .754 r
.77911 .19422 m .76982 .18688 L .76903 .195 L p F P
0 g
s
.21 .316 .754 r
.77783 .20554 m .77911 .19422 L p .76903 .195 L F P
0 g
s
.783 .991 .761 r
.7243 .37569 m .72407 .37592 L .71503 .38906 L p F P
0 g
s
.79 .999 .841 r
.70448 .39375 m .72407 .37592 L .71503 .38906 L p F P
0 g
s
.79 .999 .841 r
.70114 .39851 m .70448 .39375 L p .71503 .38906 L F P
0 g
s
.602 .833 .987 r
.45831 .49219 m .44389 .49453 L .43859 .49124 L p F P
0 g
s
0 0 0 r
.51527 .29977 m .50509 .31352 L .50486 .31397 L p F P
0 g
s
0 0 0 r
.50486 .31397 m .50581 .31267 L p .51527 .29977 L F P
0 g
s
0 0 0 r
.52468 .28693 m .51369 .30042 L p .51527 .29977 L F P
0 g
s
0 0 0 r
.50857 .30778 m .51527 .29977 L p .51369 .30042 L F P
0 g
s
0 0 0 r
.50857 .30778 m .50509 .31352 L .51527 .29977 L closepath p F P
0 g
s
0 0 0 r
.50581 .31267 m .51529 .29968 L p .51527 .29977 L F P
0 g
s
0 0 0 r
.51527 .29977 m .52621 .28505 L .52468 .28693 L p F P
0 g
s
0 0 0 r
.51369 .30042 m .5118 .30257 L .50857 .30778 L p F P
0 g
s
.683 .922 .972 r
.585 .45747 m .59136 .46018 L .56604 .47185 L p F P
0 g
s
.683 .922 .972 r
.57574 .4618 m .585 .45747 L p .56604 .47185 L F P
0 g
s
.683 .922 .972 r
.56604 .47185 m .56224 .47039 L .57574 .4618 L p F P
0 g
s
0 0 0 r
.5118 .30257 m .49626 .31741 L .50857 .30778 L closepath p F P
0 g
s
.35 .676 .977 r
.24107 .46908 m .25162 .46986 L .2637 .47607 L p F P
0 g
s
.361 .67 .975 r
.25162 .46986 m .24107 .46908 L .23322 .4628 L p F P
0 g
s
.065 0 .046 r
.50509 .31352 m .50857 .30778 L .49626 .31741 L p F P
0 g
s
.065 0 .046 r
.50417 .31457 m .50509 .31352 L p .49626 .31741 L F P
0 g
s
.065 0 .046 r
.48533 .32987 m .50417 .31457 L p .49626 .31741 L F P
0 g
s
.065 0 .046 r
.49626 .31741 m .48676 .32657 L .48533 .32987 L p F P
0 g
s
.454 .752 .993 r
.34215 .48972 m .34309 .49035 L p .31149 .48679 L F P
0 g
s
.454 .752 .993 r
.31149 .48679 m .32748 .48578 L .34215 .48972 L p F P
0 g
s
.466 .746 .99 r
.32748 .48578 m .31149 .48679 L .30388 .48139 L p F P
0 g
s
.754 .239 0 r
.31278 .31771 m .30711 .30994 L .31705 .31735 L p F P
0 g
s
.754 .239 0 r
.31705 .31735 m .32048 .32174 L .31278 .31771 L p F P
0 g
s
.423 .704 .981 r
.2646 .47001 m .25162 .46986 L .2637 .47607 L p F P
0 g
s
.423 .704 .981 r
.2637 .47607 m .27235 .47615 L .2646 .47001 L p F P
0 g
s
0 0 .412 r
.7852 .25603 m .78498 .25681 L .78334 .24653 L p F P
0 g
s
0 0 .412 r
.78334 .24653 m .78385 .24476 L .7852 .25603 L p F P
0 g
s
.882 .991 .795 r
.55819 .24636 m .55528 .2468 L .56063 .24048 L closepath p F P
0 g
s
.487 .778 .996 r
.34309 .49035 m .34455 .49018 L .36483 .49345 L p F P
0 g
s
.529 .779 .989 r
.36748 .4868 m .34455 .49018 L .36483 .49345 L p F P
0 g
s
.529 .779 .989 r
.36483 .49345 m .37484 .492 L .36748 .4868 L p F P
0 g
s
.756 .344 .27 r
.35872 .35619 m .3754 .36081 L .36948 .3522 L p F P
0 g
s
.756 .344 .27 r
.36948 .3522 m .36392 .35067 L .35872 .35619 L p F P
0 g
s
.837 .886 .876 r
.62396 .17489 m .6052 .19118 L .60345 .18989 L p F P
0 g
s
.871 .881 .84 r
.6052 .19118 m .60347 .193 L .60345 .18989 L closepath p F P
0 g
s
.871 .881 .841 r
.58917 .19767 m .58782 .20932 L .60347 .193 L p F P
0 g
s
.871 .881 .841 r
.59892 .18655 m .58917 .19767 L p .60347 .193 L F P
0 g
s
.871 .881 .841 r
.60347 .193 m .60345 .18989 L .59892 .18655 L p F P
0 g
s
.728 .951 .949 r
.6467 .43558 m .62296 .44927 L .61734 .44753 L p F P
0 g
s
.742 .867 .444 r
.76659 .3177 m .76113 .32989 L .76834 .31637 L p F P
0 g
s
.742 .867 .444 r
.7683 .31435 m .76659 .3177 L p .76834 .31637 L F P
0 g
s
.742 .867 .444 r
.76834 .31637 m .77084 .31079 L .7683 .31435 L p F P
0 g
s
.846 .85 .847 r
.62396 .17489 m .63029 .16925 L .62406 .16293 L p F P
0 g
s
.846 .85 .847 r
.62406 .16293 m .6229 .16405 L .62396 .17489 L p F P
0 g
s
.837 .886 .876 r
.60448 .18144 m .6229 .16405 L .62396 .17489 L p F P
0 g
s
.837 .886 .876 r
.60345 .18989 m .60448 .18144 L p .62396 .17489 L F P
0 g
s
.56 .637 .884 r
.71932 .14732 m .73286 .14613 L .73324 .15713 L p F P
0 g
s
.517 .587 .864 r
.746 .14586 m .73286 .14613 L .73324 .15713 L p F P
0 g
s
.517 .587 .864 r
.73324 .15713 m .75212 .15768 L .746 .14586 L p F P
0 g
s
.788 .834 .887 r
.65178 .15402 m .63029 .16925 L .62406 .16293 L p F P
0 g
s
.35 .442 .815 r
.76982 .18688 m .76449 .18415 L .75827 .17025 L p F P
0 g
s
.597 .84 .991 r
.47201 .48979 m .47051 .48889 L .45831 .49219 L closepath p F P
0 g
s
.602 .833 .987 r
.46355 .48447 m .47051 .48889 L .45831 .49219 L p F P
0 g
s
.602 .833 .987 r
.43859 .49124 m .46355 .48447 L p .45831 .49219 L F P
0 g
s
0 0 .38 r
.7876 .24526 m .7852 .25603 L .78385 .24476 L p F P
0 g
s
0 0 .38 r
.78385 .24476 m .78599 .23495 L .7876 .24526 L p F P
0 g
s
.761 .351 .275 r
.35842 .35611 m .35872 .35619 L .36392 .35067 L p F P
0 g
s
.761 .351 .275 r
.36392 .35067 m .35265 .34746 L .35842 .35611 L p F P
0 g
s
.876 .944 .856 r
.57506 .21347 m .58917 .19767 L .58782 .20932 L p F P
0 g
s
.876 .944 .856 r
.57473 .21511 m .57506 .21347 L p .58782 .20932 L F P
0 g
s
.876 .944 .856 r
.58782 .20932 m .58023 .21707 L .57473 .21511 L p F P
0 g
s
0 0 0 r
.78184 .27983 m .77795 .29167 L .78054 .2798 L p F P
0 g
s
0 0 0 r
.78054 .2798 m .78443 .26794 L .78184 .27983 L p F P
0 g
s
.855 .424 .193 r
.32692 .33494 m .33859 .34167 L .33369 .33281 L p F P
0 g
s
.855 .424 .193 r
.33369 .33281 m .32258 .32589 L .32692 .33494 L p F P
0 g
s
.653 .697 .878 r
.68726 .14595 m .71326 .13744 L .71932 .14732 L p F P
0 g
s
.667 .71 .88 r
.71326 .13744 m .68726 .14595 L .68116 .13732 L p F P
0 g
s
.728 .757 .876 r
.65558 .15125 m .68116 .13732 L .68726 .14595 L p F P
0 g
s
.275 .605 .953 r
.20551 .45409 m .20216 .45348 L .19419 .44655 L p F P
0 g
s
.183 .528 .921 r
.16764 .43542 m .16351 .43416 L .15545 .42645 L p F P
0 g
s
.905 .932 .82 r
.58023 .21707 m .57349 .22516 L .57473 .21511 L closepath p F P
0 g
s
.668 .887 .978 r
.55957 .46902 m .53428 .47916 L .52763 .47579 L p F P
0 g
s
.636 .881 .986 r
.50242 .48478 m .52763 .47579 L .53428 .47916 L p F P
0 g
s
.496 .773 .994 r
.34309 .49035 m .34455 .49018 L .34215 .48972 L closepath p F P
0 g
s
0 .015 .542 r
.78794 .22351 m .78599 .23495 L .78221 .22548 L p F P
0 g
s
0 .015 .542 r
.78221 .22548 m .78411 .21405 L .78794 .22351 L p F P
0 g
s
.847 .884 .866 r
.60345 .18989 m .59892 .18655 L .60448 .18144 L closepath p F P
0 g
s
.905 .932 .82 r
.56377 .22825 m .56063 .24048 L .57349 .22516 L p F P
0 g
s
.905 .932 .82 r
.57386 .2148 m .56377 .22825 L p .57349 .22516 L F P
0 g
s
.905 .932 .82 r
.57349 .22516 m .57473 .21511 L .57386 .2148 L p F P
0 g
s
.54 .774 .985 r
.36006 .48128 m .36748 .4868 L .34455 .49018 L p F P
0 g
s
.54 .774 .985 r
.3356 .48493 m .36006 .48128 L p .34455 .49018 L F P
0 g
s
.54 .774 .985 r
.34455 .49018 m .34215 .48972 L .3356 .48493 L p F P
0 g
s
.784 .799 .866 r
.65558 .15125 m .65178 .15402 L .64971 .14407 L closepath p F P
0 g
s
.788 .834 .887 r
.6494 .14368 m .64971 .14407 L .65178 .15402 L p F P
0 g
s
.788 .834 .887 r
.62406 .16293 m .6494 .14368 L p .65178 .15402 L F P
0 g
s
.574 .649 .887 r
.73286 .14613 m .71932 .14732 L .71326 .13744 L p F P
0 g
s
.625 .849 .985 r
.49562 .48105 m .4981 .48257 L .47201 .48979 L p F P
0 g
s
.625 .849 .985 r
.47201 .48979 m .47051 .48889 L .49562 .48105 L p F P
0 g
s
.274 0 .192 r
.47979 .34335 m .48231 .33711 L .45913 .34826 L p F P
0 g
s
.274 0 .192 r
.47459 .34689 m .47979 .34335 L p .45913 .34826 L F P
0 g
s
.274 0 .192 r
.45913 .34826 m .4563 .35595 L .47459 .34689 L p F P
0 g
s
.502 .759 .988 r
.34215 .48972 m .3356 .48493 L .32748 .48578 L closepath p F P
0 g
s
.741 .789 .891 r
.67503 .12874 m .68116 .13732 L .65558 .15125 L p F P
0 g
s
.741 .789 .891 r
.64977 .14347 m .67503 .12874 L p .65558 .15125 L F P
0 g
s
.741 .789 .891 r
.65558 .15125 m .64971 .14407 L .64977 .14347 L p F P
0 g
s
.275 .605 .953 r
.19419 .44655 m .19589 .44686 L .20551 .45409 L p F P
0 g
s
.36 .647 .965 r
.21739 .44911 m .19589 .44686 L .20551 .45409 L p F P
0 g
s
.36 .647 .965 r
.20551 .45409 m .22532 .45614 L .21739 .44911 L p F P
0 g
s
.769 .951 .625 r
.53345 .27704 m .53025 .27968 L .53743 .27026 L closepath p F P
0 g
s
.87 .427 .117 r
.32258 .32589 m .32048 .32174 L .31278 .31771 L p F P
0 g
s
.82 .949 .599 r
.75732 .33201 m .75173 .34421 L .76113 .32989 L p F P
0 g
s
.82 .949 .599 r
.76113 .32989 m .76659 .3177 L .75732 .33201 L p F P
0 g
s
0 0 .017 r
.49081 .33021 m .48231 .33711 L .48533 .32987 L p F P
0 g
s
0 0 .017 r
.48533 .32987 m .50417 .31457 L .49081 .33021 L p F P
0 g
s
.639 .877 .985 r
.52238 .47301 m .52763 .47579 L .50242 .48478 L p F P
0 g
s
.639 .877 .985 r
.50242 .48478 m .4981 .48257 L .52238 .47301 L p F P
0 g
s
.809 .397 .267 r
.34337 .35066 m .35842 .35611 L .35265 .34746 L p F P
0 g
s
.809 .397 .267 r
.35265 .34746 m .33859 .34167 L .34337 .35066 L p F P
0 g
s
.563 .791 .985 r
.39945 .48734 m .37484 .492 L .36748 .4868 L p F P
0 g
s
.433 .723 .986 r
.27235 .47615 m .29622 .47569 L .30388 .48139 L p F P
0 g
s
.443 .715 .982 r
.29622 .47569 m .27235 .47615 L .2646 .47001 L p F P
0 g
s
.779 .97 .92 r
.67575 .41806 m .67374 .41752 L .67965 .41332 L closepath p F P
0 g
s
.101 .189 .67 r
.7855 .2027 m .78411 .21405 L .77783 .20554 L p F P
0 g
s
.101 .189 .67 r
.77783 .20554 m .77911 .19422 L .7855 .2027 L p F P
0 g
s
.731 .97 .932 r
.64834 .43455 m .6467 .43558 L .64792 .43446 L closepath p F P
0 g
s
.728 .951 .949 r
.6423 .43234 m .64792 .43446 L .6467 .43558 L p F P
0 g
s
.728 .951 .949 r
.61885 .44615 m .6423 .43234 L p .6467 .43558 L F P
0 g
s
.728 .951 .949 r
.61734 .44753 m .61885 .44615 L p .6467 .43558 L F P
0 g
s
.834 .986 .71 r
.75029 .34702 m .74912 .34751 L .75173 .34421 L closepath p F P
0 g
s
.448 .523 .842 r
.75698 .16998 m .7572 .16799 L .75827 .17025 L closepath p F P
0 g
s
.183 .528 .921 r
.15545 .42645 m .15929 .42761 L .16764 .43542 L p F P
0 g
s
.288 .587 .944 r
.17815 .43144 m .15929 .42761 L .16764 .43542 L p F P
0 g
s
.288 .587 .944 r
.16764 .43542 m .18619 .43921 L .17815 .43144 L p F P
0 g
s
.763 .974 .921 r
.66785 .41581 m .67374 .41752 L .64834 .43455 L p F P
0 g
s
.763 .974 .921 r
.66019 .42106 m .66785 .41581 L p .64834 .43455 L F P
0 g
s
.763 .974 .921 r
.64834 .43455 m .64792 .43446 L .66019 .42106 L p F P
0 g
s
.877 .993 .79 r
.55263 .243 m .56377 .22825 L .56063 .24048 L p F P
0 g
s
.877 .993 .79 r
.55117 .24757 m .55263 .243 L p .56063 .24048 L F P
0 g
s
.877 .993 .79 r
.56063 .24048 m .55528 .2468 L .55117 .24757 L p F P
0 g
s
.688 .897 .972 r
.56224 .47039 m .55957 .46902 L .57574 .4618 L closepath p F P
0 g
s
.717 .918 .962 r
.6168 .44728 m .59136 .46018 L .585 .45747 L p F P
0 g
s
.484 .135 .298 r
.42971 .36117 m .4348 .36104 L .42928 .3624 L closepath p F P
0 g
s
.236 .336 .764 r
.77994 .18296 m .77911 .19422 L .76982 .18688 L p F P
0 g
s
.236 .336 .764 r
.76982 .18688 m .77042 .1757 L .77994 .18296 L p F P
0 g
s
.35 .442 .815 r
.75827 .17025 m .77042 .1757 L .76982 .18688 L p F P
0 g
s
.778 .876 .449 r
.77084 .31079 m .7683 .31435 L .77335 .30428 L closepath p F P
0 g
s
.587 .808 .984 r
.43149 .48656 m .40669 .49228 L .39945 .48734 L p F P
0 g
s
.629 .841 .981 r
.49562 .48105 m .47051 .48889 L .46355 .48447 L p F P
0 g
s
.324 .448 .832 r
.7572 .16799 m .75827 .17025 L .77042 .1757 L p F P
0 g
s
.649 .271 .315 r
.42663 .37054 m .42928 .3624 L .39787 .36365 L p F P
0 g
s
.649 .271 .315 r
.40637 .37133 m .42663 .37054 L p .39787 .36365 L F P
0 g
s
.649 .271 .315 r
.39787 .36365 m .39777 .36386 L .40637 .37133 L p F P
0 g
s
.679 .305 .33 r
.39787 .36365 m .39777 .36386 L .39756 .36362 L closepath p F P
0 g
s
.759 .947 .94 r
.64792 .43446 m .6423 .43234 L .66019 .42106 L closepath p F P
0 g
s
.361 .67 .975 r
.23322 .4628 m .2403 .46333 L .25162 .46986 L p F P
0 g
s
.428 .697 .977 r
.2568 .46355 m .2403 .46333 L .25162 .46986 L p F P
0 g
s
.428 .697 .977 r
.25162 .46986 m .2646 .47001 L .2568 .46355 L p F P
0 g
s
.67 .306 .347 r
.3811 .36959 m .3754 .36081 L .39756 .36362 L p F P
0 g
s
.67 .306 .347 r
.39462 .37126 m .3811 .36959 L p .39756 .36362 L F P
0 g
s
.67 .306 .347 r
.39756 .36362 m .39777 .36386 L .39462 .37126 L p F P
0 g
s
.906 .983 .769 r
.55528 .2468 m .54865 .25549 L .55117 .24757 L closepath p F P
0 g
s
.608 .825 .983 r
.46355 .48447 m .43859 .49124 L .43149 .48656 L p F P
0 g
s
.641 .276 .334 r
.39777 .36386 m .40637 .37133 L .39462 .37126 L closepath p F P
0 g
s
.806 .985 .889 r
.70114 .39851 m .69909 .39815 L .70448 .39375 L closepath p F P
0 g
s
.715 .216 0 r
.30473 .31022 m .29879 .30186 L .30711 .30994 L p F P
0 g
s
.715 .216 0 r
.3091 .31437 m .30473 .31022 L p .30711 .30994 L F P
0 g
s
.715 .216 0 r
.30711 .30994 m .31278 .31771 L .3091 .31437 L p F P
0 g
s
0 0 .187 r
.78517 .2653 m .78443 .26794 L .78498 .25681 L p F P
0 g
s
0 0 .187 r
.78498 .25681 m .7852 .25603 L .78517 .2653 L p F P
0 g
s
.418 .516 .852 r
.75212 .15768 m .757 .15891 L .7572 .16799 L closepath p F P
0 g
s
.324 .448 .832 r
.77059 .16457 m .757 .15891 L .7572 .16799 L p F P
0 g
s
.324 .448 .832 r
.77042 .1757 m .77059 .16457 L p .7572 .16799 L F P
0 g
s
.709 .77 .277 r
.77728 .29247 m .77335 .30428 L .77795 .29167 L p F P
0 g
s
.709 .77 .277 r
.77795 .29167 m .78184 .27983 L .77728 .29247 L p F P
0 g
s
.493 .152 .316 r
.4348 .36104 m .42928 .3624 L .42663 .37054 L p F P
0 g
s
0 0 .155 r
.7872 .25636 m .78517 .2653 L .7852 .25603 L p F P
0 g
s
0 0 .155 r
.7852 .25603 m .7876 .24526 L .7872 .25636 L p F P
0 g
s
.838 .987 .714 r
.74578 .34713 m .75732 .33201 L .75173 .34421 L p F P
0 g
s
.838 .987 .714 r
.74481 .34922 m .74578 .34713 L p .75173 .34421 L F P
0 g
s
.838 .987 .714 r
.75173 .34421 m .74912 .34751 L .74481 .34922 L p F P
0 g
s
.906 .984 .768 r
.54261 .25737 m .53743 .27026 L .54865 .25549 L p F P
0 g
s
.906 .984 .768 r
.54881 .24803 m .54261 .25737 L p .54865 .25549 L F P
0 g
s
.906 .984 .768 r
.54865 .25549 m .55117 .24757 L .54881 .24803 L p F P
0 g
s
.466 .746 .99 r
.30388 .48139 m .31175 .48088 L .32748 .48578 L p F P
0 g
s
.509 .753 .984 r
.32807 .47916 m .31175 .48088 L .32748 .48578 L p F P
0 g
s
.509 .753 .984 r
.32748 .48578 m .3356 .48493 L .32807 .47916 L p F P
0 g
s
.827 .987 .717 r
.74912 .34751 m .73931 .35958 L .74481 .34922 L closepath p F P
0 g
s
.373 .665 .971 r
.2403 .46333 m .23322 .4628 L .22532 .45614 L p F P
0 g
s
.87 .427 .117 r
.31278 .31771 m .31306 .31831 L .32258 .32589 L p F P
0 g
s
.877 .442 .14 r
.3171 .32747 m .32692 .33494 L .32258 .32589 L p F P
0 g
s
.877 .442 .14 r
.32258 .32589 m .31306 .31831 L .3171 .32747 L p F P
0 g
s
.486 .132 .291 r
.4563 .35595 m .45454 .36096 L .4348 .36104 L closepath p F P
0 g
s
.493 .152 .316 r
.45369 .36401 m .45454 .36096 L .4348 .36104 L p F P
0 g
s
.493 .152 .316 r
.42663 .37054 m .45369 .36401 L p .4348 .36104 L F P
0 g
s
.782 .967 .921 r
.67965 .41332 m .67374 .41752 L .66785 .41581 L p F P
0 g
s
.762 .361 .292 r
.3629 .3653 m .3811 .36959 L .3754 .36081 L p F P
0 g
s
.762 .361 .292 r
.35858 .35636 m .3629 .3653 L p .3754 .36081 L F P
0 g
s
.762 .361 .292 r
.3754 .36081 m .35872 .35619 L .35858 .35636 L p F P
0 g
s
.478 .742 .986 r
.31175 .48088 m .30388 .48139 L .29622 .47569 L p F P
0 g
s
.793 .989 .889 r
.67965 .41332 m .69909 .39815 L .69337 .39705 L p F P
0 g
s
.793 .989 .889 r
.69337 .39705 m .68995 .39978 L .67965 .41332 L p F P
0 g
s
.782 .967 .921 r
.66785 .41581 m .68995 .39978 L .67965 .41332 L p F P
0 g
s
.667 .71 .88 r
.68116 .13732 m .70717 .12779 L .71326 .13744 L p F P
0 g
s
.679 .721 .881 r
.70717 .12779 m .68116 .13732 L .67503 .12874 L p F P
0 g
s
.691 .892 .971 r
.57574 .4618 m .55957 .46902 L .55302 .46551 L p F P
0 g
s
.668 .887 .978 r
.52763 .47579 m .55302 .46551 L .55957 .46902 L p F P
0 g
s
.824 .998 .782 r
.7439 .34924 m .74481 .34922 L .73931 .35958 L p F P
0 g
s
.824 .998 .782 r
.73096 .36339 m .7439 .34924 L p .73931 .35958 L F P
0 g
s
.824 .998 .782 r
.72421 .37571 m .73096 .36339 L p .73931 .35958 L F P
0 g
s
.824 .998 .782 r
.73931 .35958 m .7243 .37569 L .72421 .37571 L p F P
0 g
s
.853 .434 .232 r
.33111 .34414 m .34337 .35066 L .33859 .34167 L p F P
0 g
s
.853 .434 .232 r
.33859 .34167 m .32692 .33494 L .33111 .34414 L p F P
0 g
s
.291 .601 .951 r
.19589 .44686 m .19419 .44655 L .18619 .43921 L p F P
0 g
s
.805 .832 .872 r
.64317 .13603 m .6494 .14368 L .62406 .16293 L p F P
0 g
s
.805 .832 .872 r
.62219 .15297 m .64317 .13603 L p .62406 .16293 L F P
0 g
s
.805 .832 .872 r
.62406 .16293 m .62235 .16116 L .62219 .15297 L p F P
0 g
s
.84 .835 .841 r
.62406 .16293 m .6229 .16405 L .62235 .16116 L closepath p F P
0 g
s
.84 .834 .841 r
.60408 .17029 m .60448 .18144 L .6229 .16405 L p F P
0 g
s
.84 .834 .841 r
.61778 .15643 m .60408 .17029 L p .6229 .16405 L F P
0 g
s
.84 .834 .841 r
.6229 .16405 m .62235 .16116 L .61778 .15643 L p F P
0 g
s
0 0 .357 r
.78957 .23384 m .7876 .24526 L .78599 .23495 L p F P
0 g
s
0 0 .357 r
.78599 .23495 m .78794 .22351 L .78957 .23384 L p F P
0 g
s
.574 .649 .887 r
.71326 .13744 m .73239 .13507 L .73286 .14613 L p F P
0 g
s
.534 .609 .874 r
.73989 .13458 m .73239 .13507 L .73286 .14613 L p F P
0 g
s
.534 .609 .874 r
.73286 .14613 m .746 .14586 L .73989 .13458 L p F P
0 g
s
.717 .92 .574 r
.5333 .27151 m .54261 .25737 L .53743 .27026 L p F P
0 g
s
.717 .92 .574 r
.52852 .28134 m .5333 .27151 L p .53743 .27026 L F P
0 g
s
.717 .92 .574 r
.53743 .27026 m .53025 .27968 L .52852 .28134 L p F P
0 g
s
.846 .877 .864 r
.59256 .18165 m .60408 .17029 L .60448 .18144 L p F P
0 g
s
.846 .877 .864 r
.60448 .18144 m .59892 .18655 L .59256 .18165 L p F P
0 g
s
.901 .891 .811 r
.58917 .19767 m .59892 .18655 L .59256 .18165 L p F P
0 g
s
.732 .925 .956 r
.61734 .44753 m .6168 .44728 L .61885 .44615 L closepath p F P
0 g
s
.809 .983 .891 r
.70448 .39375 m .69909 .39815 L .69337 .39705 L p F P
0 g
s
.586 .66 .888 r
.73239 .13507 m .71326 .13744 L .70717 .12779 L p F P
0 g
s
.65 .857 .979 r
.52092 .47209 m .52238 .47301 L .4981 .48257 L p F P
0 g
s
.65 .857 .979 r
.4981 .48257 m .49562 .48105 L .52092 .47209 L p F P
0 g
s
.822 .994 .861 r
.71277 .38081 m .70448 .39375 L .72407 .37592 L p F P
0 g
s
.809 .983 .891 r
.69337 .39705 m .71277 .38081 L .70448 .39375 L p F P
0 g
s
.81 .998 .787 r
.7243 .37569 m .72407 .37592 L .72421 .37571 L closepath p F P
0 g
s
.822 .994 .861 r
.71877 .37521 m .71277 .38081 L p .72407 .37592 L F P
0 g
s
.822 .994 .861 r
.72407 .37592 m .72421 .37571 L .71877 .37521 L p F P
0 g
s
.291 .601 .951 r
.18619 .43921 m .18689 .43934 L .19589 .44686 L p F P
0 g
s
.37 .641 .96 r
.20942 .44168 m .18689 .43934 L .19589 .44686 L p F P
0 g
s
.37 .641 .96 r
.19589 .44686 m .21739 .44911 L .20942 .44168 L p F P
0 g
s
.431 .534 .862 r
.757 .15891 m .75212 .15768 L .746 .14586 L p F P
0 g
s
.843 .992 .849 r
.72421 .37571 m .71877 .37521 L .73096 .36339 L closepath p F P
0 g
s
.734 .921 .955 r
.61885 .44615 m .6168 .44728 L .61054 .4443 L p F P
0 g
s
.717 .918 .962 r
.585 .45747 m .61054 .4443 L .6168 .44728 L p F P
0 g
s
.545 .766 .979 r
.36006 .48128 m .3356 .48493 L .32807 .47916 L p F P
0 g
s
.785 .881 .456 r
.77075 .30584 m .77728 .29247 L .77335 .30428 L p F P
0 g
s
.785 .881 .456 r
.76745 .31552 m .77075 .30584 L p .77335 .30428 L F P
0 g
s
.785 .881 .456 r
.77335 .30428 m .7683 .31435 L .76745 .31552 L p F P
0 g
s
.901 .891 .811 r
.59256 .18165 m .58848 .18668 L .58917 .19767 L p F P
0 g
s
.899 .89 .812 r
.57604 .20189 m .57506 .21347 L .58917 .19767 L p F P
0 g
s
.899 .89 .812 r
.58917 .19767 m .58848 .18668 L .57604 .20189 L p F P
0 g
s
.743 .949 .946 r
.61885 .44615 m .6423 .43234 L .63619 .42993 L p F P
0 g
s
.743 .949 .946 r
.63619 .42993 m .63468 .43083 L .61885 .44615 L p F P
0 g
s
.734 .921 .955 r
.61054 .4443 m .63468 .43083 L .61885 .44615 L p F P
0 g
s
.725 .923 .576 r
.53025 .27968 m .52621 .28505 L .52852 .28134 L closepath p F P
0 g
s
.891 .938 .838 r
.57473 .21511 m .57386 .2148 L .57506 .21347 L closepath p F P
0 g
s
.741 .789 .891 r
.64971 .14407 m .6494 .14368 L .64977 .14347 L closepath p F P
0 g
s
.373 .665 .971 r
.22532 .45614 m .22971 .45647 L .2403 .46333 L p F P
0 g
s
.434 .69 .972 r
.24896 .45674 m .22971 .45647 L .2403 .46333 L p F P
0 g
s
.434 .69 .972 r
.2403 .46333 m .2568 .46355 L .24896 .45674 L p F P
0 g
s
0 0 0 r
.78383 .2727 m .78184 .27983 L .78443 .26794 L p F P
0 g
s
0 0 0 r
.78443 .26794 m .78517 .2653 L .78383 .2727 L p F P
0 g
s
.67 .885 .977 r
.54641 .46184 m .55302 .46551 L .52763 .47579 L p F P
0 g
s
.67 .885 .977 r
.53337 .46717 m .54641 .46184 L p .52763 .47579 L F P
0 g
s
.67 .885 .977 r
.52763 .47579 m .52238 .47301 L .53337 .46717 L p F P
0 g
s
.741 .788 .891 r
.64977 .14347 m .6494 .14368 L .64317 .13603 L p F P
0 g
s
.757 .795 .884 r
.64977 .14347 m .67503 .12874 L .66884 .12016 L p F P
0 g
s
.757 .795 .884 r
.66884 .12016 m .64957 .13214 L .64977 .14347 L p F P
0 g
s
.741 .788 .891 r
.64317 .13603 m .64957 .13214 L .64977 .14347 L p F P
0 g
s
.478 .742 .986 r
.29622 .47569 m .29686 .47565 L .31175 .48088 L p F P
0 g
s
.515 .747 .979 r
.32049 .47307 m .29686 .47565 L .31175 .48088 L p F P
0 g
s
.515 .747 .979 r
.31175 .48088 m .32807 .47916 L .32049 .47307 L p F P
0 g
s
.805 .832 .872 r
.62235 .16116 m .61778 .15643 L .62219 .15297 L closepath p F P
0 g
s
.763 .362 .293 r
.35872 .35619 m .35858 .35636 L .35842 .35611 L closepath p F P
0 g
s
0 0 .534 r
.78936 .21217 m .78794 .22351 L .78411 .21405 L p F P
0 g
s
0 0 .534 r
.78411 .21405 m .7855 .2027 L .78936 .21217 L p F P
0 g
s
.721 .918 .567 r
.52379 .28601 m .51527 .29977 L .52621 .28505 L p F P
0 g
s
.721 .918 .567 r
.52621 .28505 m .52852 .28134 L .52379 .28601 L p F P
0 g
s
.773 .363 .275 r
.34808 .35975 m .34337 .35066 L .35842 .35611 L p F P
0 g
s
.773 .363 .275 r
.35331 .36161 m .34808 .35975 L p .35842 .35611 L F P
0 g
s
.773 .363 .275 r
.35842 .35611 m .35858 .35636 L .35331 .36161 L p F P
0 g
s
.285 0 .208 r
.4563 .35595 m .45454 .36096 L .47459 .34689 L closepath p F P
0 g
s
.443 .715 .982 r
.29544 .47507 m .29622 .47569 L p .2646 .47001 L F P
0 g
s
.443 .715 .982 r
.2646 .47001 m .28398 .46966 L .29544 .47507 L p F P
0 g
s
.452 .709 .977 r
.28398 .46966 m .2646 .47001 L .2568 .46355 L p F P
0 g
s
.808 .414 .307 r
.35858 .35636 m .3629 .3653 L .35331 .36161 L closepath p F P
0 g
s
.891 .933 .838 r
.56742 .21226 m .57604 .20189 L .57506 .21347 L p F P
0 g
s
.891 .933 .838 r
.57506 .21347 m .57386 .2148 L .56742 .21226 L p F P
0 g
s
.938 .935 .769 r
.56377 .22825 m .57386 .2148 L .56742 .21226 L p F P
0 g
s
.563 .791 .985 r
.36748 .4868 m .39216 .48206 L .39945 .48734 L p F P
0 g
s
.573 .782 .978 r
.39216 .48206 m .36748 .4868 L .36006 .48128 L p F P
0 g
s
.69 .915 .971 r
.585 .45747 m .57574 .4618 L .5834 .45675 L closepath p F P
0 g
s
.691 .892 .971 r
.57856 .454 m .5834 .45675 L .57574 .4618 L p F P
0 g
s
.691 .892 .971 r
.55302 .46551 m .57856 .454 L p .57574 .4618 L F P
0 g
s
0 0 .032 r
.48231 .33711 m .47979 .34335 L .49081 .33021 L closepath p F P
0 g
s
.654 .848 .975 r
.52092 .47209 m .49562 .48105 L .48875 .47657 L p F P
0 g
s
.629 .841 .981 r
.46355 .48447 m .48875 .47657 L .49562 .48105 L p F P
0 g
s
.431 .534 .862 r
.746 .14586 m .7563 .14801 L .757 .15891 L p F P
0 g
s
.35 .466 .837 r
.77035 .1535 m .77059 .16457 L .757 .15891 L p F P
0 g
s
.35 .466 .837 r
.757 .15891 m .7563 .14801 L .77035 .1535 L p F P
0 g
s
.86 .414 .024 r
.31278 .31771 m .31306 .31831 L .3091 .31437 L closepath p F P
0 g
s
.774 .878 .455 r
.7683 .31435 m .76659 .3177 L .76745 .31552 L closepath p F P
0 g
s
.905 .984 .768 r
.55117 .24757 m .54881 .24803 L .55263 .243 L closepath p F P
0 g
s
.081 .184 .672 r
.7864 .19141 m .7855 .2027 L .77911 .19422 L p F P
0 g
s
.081 .184 .672 r
.77911 .19422 m .77994 .18296 L .7864 .19141 L p F P
0 g
s
0 0 0 r
.78486 .26819 m .78383 .2727 L .78517 .2653 L p F P
0 g
s
0 0 0 r
.78517 .2653 m .7872 .25636 L .78486 .26819 L p F P
0 g
s
.587 .808 .984 r
.39945 .48734 m .42433 .48154 L .43149 .48656 L p F P
0 g
s
.597 .798 .976 r
.42433 .48154 m .39945 .48734 L .39216 .48206 L p F P
0 g
s
.871 .432 .052 r
.3088 .31936 m .3171 .32747 L .31306 .31831 L p F P
0 g
s
.871 .432 .052 r
.30516 .31084 m .3088 .31936 L p .31306 .31831 L F P
0 g
s
.871 .432 .052 r
.31306 .31831 m .3091 .31437 L .30516 .31084 L p F P
0 g
s
.634 .833 .977 r
.48875 .47657 m .46355 .48447 L .45654 .47972 L p F P
0 g
s
.608 .825 .983 r
.43149 .48656 m .45654 .47972 L .46355 .48447 L p F P
0 g
s
.23 .341 .771 r
.78032 .17176 m .77994 .18296 L .77042 .1757 L p F P
0 g
s
.23 .341 .771 r
.77042 .1757 m .77059 .16457 L .78032 .17176 L p F P
0 g
s
.632 .293 .379 r
.42663 .37054 m .40637 .37133 L .41477 .37927 L p F P
0 g
s
.646 .288 .35 r
.39151 .37913 m .41477 .37927 L .40637 .37133 L p F P
0 g
s
.646 .288 .35 r
.40637 .37133 m .39462 .37126 L .39151 .37913 L p F P
0 g
s
.712 .359 .377 r
.38657 .37854 m .39151 .37913 L .39462 .37126 L p F P
0 g
s
.712 .359 .377 r
.39462 .37126 m .3811 .36959 L .38657 .37854 L p F P
0 g
s
.616 .815 .977 r
.45654 .47972 m .43149 .48656 L .42433 .48154 L p F P
0 g
s
.857 .967 .642 r
.76207 .31999 m .75732 .33201 L .76659 .3177 L p F P
0 g
s
.857 .967 .642 r
.76335 .31794 m .76207 .31999 L p .76659 .3177 L F P
0 g
s
.857 .967 .642 r
.76659 .3177 m .76745 .31552 L .76335 .31794 L p F P
0 g
s
0 0 0 r
.52364 .28616 m .52379 .28601 L .51527 .29977 L p F P
0 g
s
0 0 0 r
.51529 .29968 m .52364 .28616 L p .51527 .29977 L F P
0 g
s
.761 .945 .94 r
.66019 .42106 m .6423 .43234 L .63619 .42993 L p F P
0 g
s
.938 .935 .769 r
.56742 .21226 m .56427 .21689 L .56377 .22825 L p F P
0 g
s
.938 .935 .768 r
.55461 .23113 m .55263 .243 L .56377 .22825 L p F P
0 g
s
.938 .935 .768 r
.56377 .22825 m .56427 .21689 L .55461 .23113 L p F P
0 g
s
.511 .177 .336 r
.4515 .37265 m .45369 .36401 L .42663 .37054 L p F P
0 g
s
.511 .177 .336 r
.42663 .37054 m .4241 .37891 L .4515 .37265 L p F P
0 g
s
.632 .293 .379 r
.41477 .37927 m .4241 .37891 L .42663 .37054 L p F P
0 g
s
.882 .457 .179 r
.32095 .33678 m .33111 .34414 L .32692 .33494 L p F P
0 g
s
.882 .457 .179 r
.32692 .33494 m .3171 .32747 L .32095 .33678 L p F P
0 g
s
.72 .921 .961 r
.60422 .44117 m .61054 .4443 L .585 .45747 L p F P
0 g
s
.72 .921 .961 r
.59847 .44418 m .60422 .44117 L p .585 .45747 L F P
0 g
s
.72 .921 .961 r
.585 .45747 m .5834 .45675 L .59847 .44418 L p F P
0 g
s
.794 .938 .58 r
.52393 .28571 m .52379 .28601 L .52852 .28134 L p F P
0 g
s
.794 .938 .58 r
.52852 .28134 m .5333 .27151 L .52393 .28571 L p F P
0 g
s
.384 .659 .967 r
.22971 .45647 m .22532 .45614 L .21739 .44911 L p F P
0 g
s
0 0 .112 r
.78919 .24495 m .7872 .25636 L .7876 .24526 L p F P
0 g
s
0 0 .112 r
.7876 .24526 m .78957 .23384 L .78919 .24495 L p F P
0 g
s
.763 .409 .385 r
.36701 .37472 m .38657 .37854 L .3811 .36959 L p F P
0 g
s
.763 .409 .385 r
.3811 .36959 m .3629 .3653 L .36701 .37472 L p F P
0 g
s
.444 .551 .87 r
.7563 .14801 m .746 .14586 L .73989 .13458 L p F P
0 g
s
.485 .736 .982 r
.29622 .47569 m .29686 .47565 L .29544 .47507 L closepath p F P
0 g
s
.689 .729 .881 r
.70106 .11831 m .67503 .12874 L .66884 .12016 L p F P
0 g
s
.679 .721 .881 r
.67503 .12874 m .70106 .11831 L .70717 .12779 L p F P
0 g
s
.878 .964 .634 r
.76745 .31552 m .76335 .31794 L .77075 .30584 L closepath p F P
0 g
s
.781 .822 .348 r
.78052 .28079 m .77728 .29247 L .78184 .27983 L p F P
0 g
s
.781 .822 .348 r
.78212 .27621 m .78052 .28079 L p .78184 .27983 L F P
0 g
s
.781 .822 .348 r
.78184 .27983 m .78383 .2727 L .78212 .27621 L p F P
0 g
s
.529 .744 .973 r
.31285 .46665 m .32049 .47307 L .29686 .47565 L p F P
0 g
s
.529 .744 .973 r
.28853 .46936 m .31285 .46665 L p .29686 .47565 L F P
0 g
s
.529 .744 .973 r
.29686 .47565 m .29544 .47507 L .28853 .46936 L p F P
0 g
s
.307 .598 .948 r
.18689 .43934 m .18619 .43921 L .17815 .43144 L p F P
0 g
s
.586 .66 .888 r
.70717 .12779 m .7319 .12392 L .73239 .13507 L p F P
0 g
s
.599 .665 .885 r
.7319 .12392 m .70717 .12779 L .70106 .11831 L p F P
0 g
s
.848 .441 .267 r
.33514 .35347 m .34808 .35975 L .34337 .35066 L p F P
0 g
s
.848 .441 .267 r
.34337 .35066 m .33111 .34414 L .33514 .35347 L p F P
0 g
s
.489 .727 .977 r
.29544 .47507 m .28853 .46936 L .28398 .46966 L closepath p F P
0 g
s
0 0 0 r
.50509 .31352 m .50417 .31457 L .50486 .31397 L closepath p F P
0 g
s
.307 .598 .948 r
.17815 .43144 m .17853 .43151 L .18689 .43934 L p F P
0 g
s
.38 .635 .955 r
.20142 .43386 m .17853 .43151 L .18689 .43934 L p F P
0 g
s
.38 .635 .955 r
.18689 .43934 m .20942 .44168 L .20142 .43386 L p F P
0 g
s
0 0 0 r
.50158 .32078 m .49081 .33021 L .50417 .31457 L p F P
0 g
s
0 0 0 r
.50417 .31457 m .50486 .31397 L .50158 .32078 L p F P
0 g
s
.737 .242 0 r
.3091 .31437 m .30516 .31084 L .30473 .31022 L closepath p F P
0 g
s
.907 .983 .77 r
.54483 .24545 m .55461 .23113 L .55263 .243 L p F P
0 g
s
.907 .983 .77 r
.5441 .24886 m .54483 .24545 L p .55263 .243 L F P
0 g
s
.907 .983 .77 r
.55263 .243 m .54881 .24803 L .5441 .24886 L p F P
0 g
s
.715 .894 .961 r
.5834 .45675 m .57856 .454 L .59847 .44418 L closepath p F P
0 g
s
.88 .989 .735 r
.75071 .3351 m .74578 .34713 L .75732 .33201 L p F P
0 g
s
.88 .989 .735 r
.75732 .33201 m .76207 .31999 L .75071 .3351 L p F P
0 g
s
.773 .964 .927 r
.66785 .41581 m .66019 .42106 L .66531 .41503 L closepath p F P
0 g
s
.761 .945 .94 r
.66186 .41342 m .66531 .41503 L .66019 .42106 L p F P
0 g
s
.761 .945 .94 r
.63619 .42993 m .66186 .41342 L p .66019 .42106 L F P
0 g
s
.345 .031 .282 r
.47459 .34689 m .45454 .36096 L .45369 .36401 L p F P
0 g
s
0 0 0 r
.50684 .31362 m .50158 .32078 L .50486 .31397 L p F P
0 g
s
0 0 0 r
.50486 .31397 m .51529 .29968 L .50684 .31362 L p F P
0 g
s
.384 .659 .967 r
.21739 .44911 m .21984 .44929 L .22971 .45647 L p F P
0 g
s
.441 .684 .967 r
.24107 .44958 m .21984 .44929 L .22971 .45647 L p F P
0 g
s
.441 .684 .967 r
.22971 .45647 m .24896 .45674 L .24107 .44958 L p F P
0 g
s
.803 .825 .868 r
.62219 .15297 m .61778 .15643 L .61142 .14962 L p F P
0 g
s
.863 .848 .827 r
.60408 .17029 m .61778 .15643 L .61142 .14962 L p F P
0 g
s
.865 .995 .802 r
.74481 .34922 m .7439 .34924 L .74578 .34713 L closepath p F P
0 g
s
.817 .824 .855 r
.62219 .15297 m .64317 .13603 L .63688 .12818 L p F P
0 g
s
.817 .824 .855 r
.63688 .12818 m .62041 .1422 L .62219 .15297 L p F P
0 g
s
.803 .825 .868 r
.61142 .14962 m .62041 .1422 L .62219 .15297 L p F P
0 g
s
.55 .628 .882 r
.73378 .12372 m .7319 .12392 L .73239 .13507 L p F P
0 g
s
.55 .628 .882 r
.73239 .13507 m .73989 .13458 L .73378 .12372 L p F P
0 g
s
.935 .966 .742 r
.54881 .24803 m .54261 .25737 L .5441 .24886 L closepath p F P
0 g
s
.699 .885 .966 r
.57856 .454 m .55302 .46551 L .54641 .46184 L p F P
0 g
s
.789 .965 .918 r
.68995 .39978 m .66785 .41581 L .66531 .41503 L p F P
0 g
s
.855 .865 .847 r
.58626 .17616 m .60206 .15966 L .60408 .17029 L p F P
0 g
s
.855 .865 .847 r
.58628 .17642 m .58626 .17616 L p .60408 .17029 L F P
0 g
s
.855 .865 .847 r
.60408 .17029 m .59256 .18165 L .58628 .17642 L p F P
0 g
s
.863 .848 .827 r
.61142 .14962 m .60206 .15966 L .60408 .17029 L p F P
0 g
s
0 0 .329 r
.79099 .22251 m .78957 .23384 L .78794 .22351 L p F P
0 g
s
0 0 .329 r
.78794 .22351 m .78936 .21217 L .79099 .22251 L p F P
0 g
s
.673 .863 .971 r
.52238 .47301 m .52092 .47209 L .53337 .46717 L closepath p F P
0 g
s
.545 .766 .979 r
.32807 .47916 m .35259 .47541 L .36006 .48128 L p F P
0 g
s
.554 .758 .973 r
.35259 .47541 m .32807 .47916 L .32049 .47307 L p F P
0 g
s
.111 0 .146 r
.49834 .32775 m .50158 .32078 L .49081 .33021 L p F P
0 g
s
.111 0 .146 r
.47939 .34458 m .49834 .32775 L p .49081 .33021 L F P
0 g
s
.111 0 .146 r
.49081 .33021 m .47979 .34335 L .47939 .34458 L p F P
0 g
s
.889 .858 .804 r
.59256 .18165 m .58848 .18668 L .58628 .17642 L closepath p F P
0 g
s
.751 .787 .883 r
.64957 .13214 m .64317 .13603 L .63688 .12818 L p F P
0 g
s
.812 .427 .326 r
.35206 .3692 m .36701 .37472 L .3629 .3653 L p F P
0 g
s
.812 .427 .326 r
.35053 .36475 m .35206 .3692 L p .3629 .3653 L F P
0 g
s
.812 .427 .326 r
.3629 .3653 m .35331 .36161 L .35053 .36475 L p F P
0 g
s
.89 .859 .804 r
.57497 .19098 m .57604 .20189 L .58848 .18668 L p F P
0 g
s
.89 .859 .804 r
.58613 .17629 m .57497 .19098 L p .58848 .18668 L F P
0 g
s
.89 .859 .804 r
.58848 .18668 m .58628 .17642 L .58613 .17629 L p F P
0 g
s
.869 .994 .806 r
.73849 .34923 m .75071 .3351 L .74578 .34713 L p F P
0 g
s
.869 .994 .806 r
.74578 .34713 m .7439 .34924 L .73849 .34923 L p F P
0 g
s
.86 .997 .795 r
.73096 .36339 m .7439 .34924 L .73849 .34923 L p F P
0 g
s
.303 0 .225 r
.47979 .34335 m .47459 .34689 L .47939 .34458 L closepath p F P
0 g
s
.345 .031 .282 r
.47694 .35271 m .47939 .34458 L .47459 .34689 L p F P
0 g
s
.345 .031 .282 r
.45369 .36401 m .47694 .35271 L p .47459 .34689 L F P
0 g
s
.452 .709 .977 r
.2568 .46355 m .27212 .46326 L .28398 .46966 L p F P
0 g
s
.461 .702 .972 r
.27212 .46326 m .2568 .46355 L .24896 .45674 L p F P
0 g
s
.739 .918 .953 r
.63468 .43083 m .61054 .4443 L .60422 .44117 L p F P
0 g
s
.936 .966 .739 r
.53643 .2593 m .5333 .27151 L .54261 .25737 L p F P
0 g
s
.936 .966 .739 r
.54225 .24921 m .53643 .2593 L p .54261 .25737 L F P
0 g
s
.936 .966 .739 r
.54261 .25737 m .5441 .24886 L .54225 .24921 L p F P
0 g
s
.763 .787 .873 r
.64957 .13214 m .66884 .12016 L .66261 .1115 L p F P
0 g
s
.763 .787 .873 r
.66261 .1115 m .64743 .12145 L .64957 .13214 L p F P
0 g
s
.751 .787 .883 r
.63688 .12818 m .64743 .12145 L .64957 .13214 L p F P
0 g
s
.804 .981 .897 r
.69337 .39705 m .68995 .39978 L .69206 .39677 L closepath p F P
0 g
s
.789 .965 .918 r
.68753 .39494 m .69206 .39677 L .68995 .39978 L p F P
0 g
s
.789 .965 .918 r
.67071 .40741 m .68753 .39494 L p .68995 .39978 L F P
0 g
s
.789 .965 .918 r
.66531 .41503 m .67071 .40741 L p .68995 .39978 L F P
0 g
s
.335 .034 .297 r
.4746 .36107 m .47694 .35271 L .45369 .36401 L p F P
0 g
s
.335 .034 .297 r
.45369 .36401 m .4515 .37265 L .4746 .36107 L p F P
0 g
s
.818 .981 .889 r
.71277 .38081 m .69337 .39705 L .69206 .39677 L p F P
0 g
s
.867 .92 .525 r
.77404 .29417 m .77075 .30584 L .77728 .29247 L p F P
0 g
s
.867 .92 .525 r
.77728 .29247 m .78052 .28079 L .77404 .29417 L p F P
0 g
s
.676 .854 .967 r
.53337 .46717 m .52092 .47209 L .51414 .46755 L p F P
0 g
s
.654 .848 .975 r
.48875 .47657 m .51414 .46755 L .52092 .47209 L p F P
0 g
s
.573 .782 .978 r
.36006 .48128 m .38482 .47637 L .39216 .48206 L p F P
0 g
s
.591 .769 .964 r
.38482 .47637 m .36006 .48128 L .35259 .47541 L p F P
0 g
s
.719 .694 .155 r
.7869 .2568 m .78486 .26819 L .7872 .25636 L p F P
0 g
s
.719 .694 .155 r
.7872 .25636 m .78919 .24495 L .7869 .2568 L p F P
0 g
s
.86 .997 .795 r
.73849 .34923 m .73684 .35109 L .73096 .36339 L p F P
0 g
s
.845 .991 .851 r
.71945 .36829 m .73684 .35109 L .73096 .36339 L p F P
0 g
s
.845 .991 .851 r
.71617 .37491 m .71945 .36829 L p .73096 .36339 L F P
0 g
s
.845 .991 .851 r
.73096 .36339 m .71877 .37521 L .71617 .37491 L p F P
0 g
s
0 0 .537 r
.78995 .20466 m .78936 .21217 L .7855 .2027 L p F P
0 g
s
0 0 .537 r
.78732 .19356 m .78995 .20466 L p .7855 .2027 L F P
0 g
s
0 0 .537 r
.7855 .2027 m .7864 .19141 L .78732 .19356 L p F P
0 g
s
.887 .46 .099 r
.31254 .32871 m .32095 .33678 L .3171 .32747 L p F P
0 g
s
.887 .46 .099 r
.3171 .32747 m .3088 .31936 L .31254 .32871 L p F P
0 g
s
.835 .992 .858 r
.71877 .37521 m .71277 .38081 L .71617 .37491 L closepath p F P
0 g
s
.818 .981 .889 r
.71312 .3739 m .71617 .37491 L .71277 .38081 L p F P
0 g
s
.818 .981 .889 r
.6979 .38691 m .71312 .3739 L p .71277 .38081 L F P
0 g
s
.818 .981 .889 r
.69206 .39677 m .6979 .38691 L p .71277 .38081 L F P
0 g
s
.444 .551 .87 r
.73989 .13458 m .75519 .13717 L .7563 .14801 L p F P
0 g
s
.455 .566 .877 r
.75519 .13717 m .73989 .13458 L .73378 .12372 L p F P
0 g
s
.902 .913 .819 r
.56343 .20592 m .57497 .19098 L .57604 .20189 L p F P
0 g
s
.902 .913 .819 r
.5635 .2104 m .56343 .20592 L p .57604 .20189 L F P
0 g
s
.902 .913 .819 r
.57604 .20189 m .56742 .21226 L .5635 .2104 L p F P
0 g
s
.496 .721 .972 r
.28079 .46268 m .27212 .46326 L .28398 .46966 L p F P
0 g
s
.496 .721 .972 r
.28398 .46966 m .28853 .46936 L .28079 .46268 L p F P
0 g
s
.017 0 .126 r
.49825 .32796 m .49834 .32775 L .47939 .34458 L p F P
0 g
s
.017 0 .126 r
.48909 .34191 m .49825 .32796 L p .47939 .34458 L F P
0 g
s
.017 0 .126 r
.47939 .34458 m .47694 .35271 L .48909 .34191 L p F P
0 g
s
.358 .48 .847 r
.76988 .14642 m .77035 .1535 L .7563 .14801 L p F P
0 g
s
.358 .48 .847 r
.76766 .14159 m .76988 .14642 L p .7563 .14801 L F P
0 g
s
.358 .48 .847 r
.7563 .14801 m .75519 .13717 L .76766 .14159 L p F P
0 g
s
.657 .84 .97 r
.51414 .46755 m .48875 .47657 L .48181 .47177 L p F P
0 g
s
.634 .833 .977 r
.45654 .47972 m .48181 .47177 L .48875 .47657 L p F P
0 g
s
.597 .798 .976 r
.39216 .48206 m .41712 .47607 L .42433 .48154 L p F P
0 g
s
.618 .781 .959 r
.41712 .47607 m .39216 .48206 L .38482 .47637 L p F P
0 g
s
.811 .829 .355 r
.78383 .2727 m .78212 .27621 L .78486 .26819 L closepath p F P
0 g
s
.884 .469 .215 r
.32462 .34624 m .33514 .35347 L .33111 .34414 L p F P
0 g
s
.884 .469 .215 r
.33111 .34414 m .32095 .33678 L .32462 .34624 L p F P
0 g
s
.798 .408 .315 r
.35331 .36161 m .35053 .36475 L .34808 .35975 L closepath p F P
0 g
s
.094 .21 .694 r
.78645 .19013 m .7864 .19141 L .77994 .18296 L p F P
0 g
s
.094 .21 .694 r
.78041 .17187 m .78645 .19013 L p .77994 .18296 L F P
0 g
s
.094 .21 .694 r
.77994 .18296 m .78032 .17176 L .78041 .17187 L p F P
0 g
s
.395 .654 .962 r
.21984 .44929 m .21739 .44911 L .20942 .44168 L p F P
0 g
s
.784 .938 .93 r
.66531 .41503 m .66186 .41342 L .67071 .40741 L closepath p F P
0 g
s
.637 .306 .394 r
.4241 .37891 m .42192 .38681 L .41477 .37927 L closepath p F P
0 g
s
.653 .306 .371 r
.42174 .38758 m .42192 .38681 L .41477 .37927 L p F P
0 g
s
.653 .306 .371 r
.39183 .38765 m .42174 .38758 L p .41477 .37927 L F P
0 g
s
.653 .306 .371 r
.38972 .38423 m .39183 .38765 L p .41477 .37927 L F P
0 g
s
.653 .306 .371 r
.41477 .37927 m .39151 .37913 L .38972 .38423 L p F P
0 g
s
.64 .821 .97 r
.48181 .47177 m .45654 .47972 L .44946 .47458 L p F P
0 g
s
.616 .815 .977 r
.42433 .48154 m .44946 .47458 L .45654 .47972 L p F P
0 g
s
.628 .801 .965 r
.44946 .47458 m .42433 .48154 L .41712 .47607 L p F P
0 g
s
.715 .371 .394 r
.39151 .37913 m .38972 .38423 L .38657 .37854 L closepath p F P
0 g
s
.248 .368 .789 r
.78031 .17159 m .78032 .17176 L .77059 .16457 L p F P
0 g
s
.248 .368 .789 r
.77397 .15587 m .78031 .17159 L p .77059 .16457 L F P
0 g
s
.248 .368 .789 r
.77059 .16457 m .77035 .1535 L .77397 .15587 L p F P
0 g
s
.533 .206 .36 r
.44947 .38157 m .4515 .37265 L .4241 .37891 L p F P
0 g
s
.533 .206 .36 r
.42362 .38716 m .44947 .38157 L p .4241 .37891 L F P
0 g
s
.533 .206 .36 r
.4241 .37891 m .42192 .38681 L .42362 .38716 L p F P
0 g
s
.812 .954 .909 r
.69206 .39677 m .68753 .39494 L .6979 .38691 L closepath p F P
0 g
s
.93 .896 .773 r
.56742 .21226 m .56427 .21689 L .5635 .2104 L closepath p F P
0 g
s
.91 .961 .637 r
.52864 .27295 m .52393 .28571 L .5333 .27151 L p F P
0 g
s
.91 .961 .637 r
.5333 .27151 m .53643 .2593 L .52864 .27295 L p F P
0 g
s
.708 .369 .4 r
.37072 .38435 m .36701 .37472 L .38657 .37854 L p F P
0 g
s
.708 .369 .4 r
.38867 .38741 m .37072 .38435 L p .38657 .37854 L F P
0 g
s
.708 .369 .4 r
.38657 .37854 m .38972 .38423 L .38867 .38741 L p F P
0 g
s
.599 .665 .885 r
.7316 .11996 m .7319 .12392 L p .70106 .11831 L F P
0 g
s
.599 .665 .885 r
.70106 .11831 m .72767 .11325 L .7316 .11996 L p F P
0 g
s
.61 .677 .888 r
.72767 .11325 m .70106 .11831 L .69491 .10892 L p F P
0 g
s
.689 .729 .881 r
.66884 .12016 m .69491 .10892 L .70106 .11831 L p F P
0 g
s
.697 .735 .88 r
.69491 .10892 m .66884 .12016 L .66261 .1115 L p F P
0 g
s
.529 .734 .969 r
.31285 .46665 m .28853 .46936 L .28079 .46268 L p F P
0 g
s
.395 .654 .962 r
.20942 .44168 m .21071 .44178 L .21984 .44929 L p F P
0 g
s
.448 .677 .962 r
.23315 .44206 m .21071 .44178 L .21984 .44929 L p F P
0 g
s
.448 .677 .962 r
.21984 .44929 m .24107 .44958 L .23315 .44206 L p F P
0 g
s
.675 .876 .974 r
.54641 .46184 m .53337 .46717 L .54476 .46086 L closepath p F P
0 g
s
.676 .854 .967 r
.53972 .4574 m .54476 .46086 L .53337 .46717 L p F P
0 g
s
.676 .854 .967 r
.51414 .46755 m .53972 .4574 L p .53337 .46717 L F P
0 g
s
.93 .896 .773 r
.55413 .22006 m .55461 .23113 L .56427 .21689 L p F P
0 g
s
.93 .896 .773 r
.56089 .20917 m .55413 .22006 L p .56427 .21689 L F P
0 g
s
.93 .896 .773 r
.56427 .21689 m .5635 .2104 L .56089 .20917 L p F P
0 g
s
.819 .414 .28 r
.33904 .36293 m .33514 .35347 L .34808 .35975 L p F P
0 g
s
.819 .414 .28 r
.34766 .36687 m .33904 .36293 L p .34808 .35975 L F P
0 g
s
.819 .414 .28 r
.34808 .35975 m .35053 .36475 L .34766 .36687 L p F P
0 g
s
.717 .889 .959 r
.59847 .44418 m .57856 .454 L .57205 .45014 L p F P
0 g
s
.699 .885 .966 r
.54641 .46184 m .57205 .45014 L .57856 .454 L p F P
0 g
s
.884 .966 .641 r
.76557 .30829 m .77404 .29417 L .77075 .30584 L p F P
0 g
s
.884 .966 .641 r
.76264 .31833 m .76557 .30829 L p .77075 .30584 L F P
0 g
s
.884 .966 .641 r
.77075 .30584 m .76335 .31794 L .76264 .31833 L p F P
0 g
s
.749 .939 .947 r
.63619 .42993 m .63468 .43083 L .63574 .42974 L closepath p F P
0 g
s
.739 .918 .953 r
.62997 .42655 m .63574 .42974 L .63468 .43083 L p F P
0 g
s
.739 .918 .953 r
.60422 .44117 m .62997 .42655 L p .63468 .43083 L F P
0 g
s
0 0 .063 r
.79059 .23365 m .78919 .24495 L .78957 .23384 L p F P
0 g
s
0 0 .063 r
.78957 .23384 m .79099 .22251 L .79059 .23365 L p F P
0 g
s
.774 .941 .935 r
.65579 .41042 m .66186 .41342 L .63619 .42993 L p F P
0 g
s
.774 .941 .935 r
.64584 .41693 m .65579 .41042 L p .63619 .42993 L F P
0 g
s
.774 .941 .935 r
.63619 .42993 m .63574 .42974 L .64584 .41693 L p F P
0 g
s
.761 .914 .941 r
.63574 .42974 m .62997 .42655 L .64584 .41693 L closepath p F P
0 g
s
.823 .836 .366 r
.78273 .26936 m .7869 .2568 L .78486 .26819 L p F P
0 g
s
.823 .836 .366 r
.78112 .27818 m .78273 .26936 L p .78486 .26819 L F P
0 g
s
.823 .836 .366 r
.78486 .26819 m .78212 .27621 L .78112 .27818 L p F P
0 g
s
.785 .931 .567 r
.52379 .28601 m .52364 .28616 L .52393 .28571 L closepath p F P
0 g
s
.809 .815 .856 r
.62041 .1422 m .61142 .14962 L .605 .14239 L p F P
0 g
s
.863 .83 .813 r
.60206 .15966 m .61142 .14962 L .605 .14239 L p F P
0 g
s
.76 .916 .543 r
.52089 .28664 m .52864 .27295 L .52393 .28571 L p F P
0 g
s
.76 .916 .543 r
.51923 .29103 m .52089 .28664 L p .52393 .28571 L F P
0 g
s
.76 .916 .543 r
.52393 .28571 m .52364 .28616 L .51923 .29103 L p F P
0 g
s
.793 .925 .549 r
.52364 .28616 m .51529 .29968 L .51923 .29103 L closepath p F P
0 g
s
.84 .968 .884 r
.71617 .37491 m .71312 .3739 L .71945 .36829 L closepath p F P
0 g
s
.819 .811 .843 r
.62041 .1422 m .63688 .12818 L .63054 .12006 L p F P
0 g
s
.819 .811 .843 r
.63054 .12006 m .61725 .13185 L .62041 .1422 L p F P
0 g
s
.809 .815 .856 r
.605 .14239 m .61725 .13185 L .62041 .1422 L p F P
0 g
s
.816 .469 .399 r
.35495 .37912 m .37072 .38435 L .36701 .37472 L p F P
0 g
s
.816 .469 .399 r
.36701 .37472 m .35206 .3692 L .35495 .37912 L p F P
0 g
s
.554 .758 .973 r
.32049 .47307 m .34508 .46916 L .35259 .47541 L p F P
0 g
s
.567 .747 .962 r
.34508 .46916 m .32049 .47307 L .31285 .46665 L p F P
0 g
s
.566 .645 .888 r
.7319 .12392 m .7316 .11996 L .73378 .12372 L closepath p F P
0 g
s
.863 .83 .813 r
.605 .14239 m .59874 .14941 L .60206 .15966 L p F P
0 g
s
.859 .828 .816 r
.5841 .16551 m .58626 .17616 L .60206 .15966 L p F P
0 g
s
.859 .828 .816 r
.60206 .15966 m .59874 .14941 L .5841 .16551 L p F P
0 g
s
0 0 0 r
.49848 .32756 m .49834 .32775 L .50158 .32078 L p F P
0 g
s
0 0 0 r
.50158 .32078 m .50684 .31362 L .49848 .32756 L p F P
0 g
s
.949 .921 .747 r
.54552 .23398 m .54483 .24545 L .55461 .23113 L p F P
0 g
s
.949 .921 .747 r
.55461 .23113 m .55413 .22006 L .54552 .23398 L p F P
0 g
s
.878 .967 .644 r
.76335 .31794 m .76207 .31999 L .76264 .31833 L closepath p F P
0 g
s
.758 .784 .875 r
.64743 .12145 m .63688 .12818 L .63054 .12006 L p F P
0 g
s
.928 .971 .747 r
.5441 .24886 m .54225 .24921 L .54483 .24545 L closepath p F P
0 g
s
.701 .882 .965 r
.56547 .44609 m .57205 .45014 L .54641 .46184 L p F P
0 g
s
.701 .882 .965 r
.56401 .44676 m .56547 .44609 L p .54641 .46184 L F P
0 g
s
.701 .882 .965 r
.54641 .46184 m .54476 .46086 L .56401 .44676 L p F P
0 g
s
.896 .988 .759 r
.75478 .32325 m .75071 .3351 L .76207 .31999 L p F P
0 g
s
.896 .988 .759 r
.75811 .31869 m .75478 .32325 L p .76207 .31999 L F P
0 g
s
.896 .988 .759 r
.76207 .31999 m .76264 .31833 L .75811 .31869 L p F P
0 g
s
.461 .702 .972 r
.24896 .45674 m .26112 .45649 L .27212 .46326 L p F P
0 g
s
.5 .715 .967 r
.273 .45568 m .26112 .45649 L .27212 .46326 L p F P
0 g
s
.5 .715 .967 r
.27212 .46326 m .28079 .46268 L .273 .45568 L p F P
0 g
s
.469 .696 .967 r
.26112 .45649 m .24896 .45674 L .24107 .44958 L p F P
0 g
s
.455 .566 .877 r
.73378 .12372 m .75365 .12638 L .75519 .13717 L p F P
0 g
s
.442 .579 .895 r
.7316 .11996 m .73378 .12372 L .75365 .12638 L p F P
0 g
s
.862 .864 .84 r
.58628 .17642 m .58613 .17629 L .58626 .17616 L closepath p F P
0 g
s
0 0 .298 r
.79147 .2162 m .79099 .22251 L .78936 .21217 L p F P
0 g
s
0 0 .298 r
.78936 .21217 m .78995 .20466 L .79147 .2162 L p F P
0 g
s
.856 .849 .835 r
.57962 .17033 m .5841 .16551 L .58626 .17616 L p F P
0 g
s
.856 .849 .835 r
.58626 .17616 m .58613 .17629 L .57962 .17033 L p F P
0 g
s
.908 .859 .781 r
.57497 .19098 m .58613 .17629 L .57962 .17033 L p F P
0 g
s
.694 .354 .396 r
.38972 .38423 m .39183 .38765 L .38867 .38741 L closepath p F P
0 g
s
.858 .476 .324 r
.35053 .36475 m .35206 .3692 L .34766 .36687 L closepath p F P
0 g
s
.785 .933 .929 r
.67071 .40741 m .66186 .41342 L .65579 .41042 L p F P
0 g
s
.339 .049 .317 r
.4726 .36896 m .4746 .36107 L .4515 .37265 L p F P
0 g
s
.339 .049 .317 r
.47085 .37053 m .4726 .36896 L p .4515 .37265 L F P
0 g
s
.339 .049 .317 r
.4515 .37265 m .44947 .38157 L .47085 .37053 L p F P
0 g
s
.897 .477 .132 r
.31609 .33821 m .32462 .34624 L .32095 .33678 L p F P
0 g
s
.897 .477 .132 r
.32095 .33678 m .31254 .32871 L .31609 .33821 L p F P
0 g
s
.725 .911 .959 r
.60422 .44117 m .59847 .44418 L .60275 .4404 L closepath p F P
0 g
s
.717 .889 .959 r
.59782 .43727 m .60275 .4404 L .59847 .44418 L p F P
0 g
s
.717 .889 .959 r
.57205 .45014 m .59782 .43727 L p .59847 .44418 L F P
0 g
s
.767 .781 .864 r
.64743 .12145 m .66261 .1115 L .65633 .10272 L p F P
0 g
s
.767 .781 .864 r
.65633 .10272 m .64395 .11117 L .64743 .12145 L p F P
0 g
s
.758 .784 .875 r
.63054 .12006 m .64395 .11117 L .64743 .12145 L p F P
0 g
s
.817 .835 .365 r
.78212 .27621 m .78052 .28079 L .78112 .27818 L closepath p F P
0 g
s
.591 .769 .964 r
.37976 .47208 m .38482 .47637 L p .35259 .47541 L F P
0 g
s
.591 .769 .964 r
.35259 .47541 m .37368 .47089 L .37976 .47208 L p F P
0 g
s
.615 .757 .947 r
.37368 .47089 m .35259 .47541 L .34508 .46916 L p F P
0 g
s
.909 .983 .747 r
.76264 .31833 m .75811 .31869 L .76557 .30829 L closepath p F P
0 g
s
.912 .908 .805 r
.5635 .2104 m .56089 .20917 L .56343 .20592 L closepath p F P
0 g
s
.805 .957 .913 r
.67071 .40741 m .68753 .39494 L .68161 .3924 L p F P
0 g
s
.805 .957 .913 r
.68161 .3924 m .679 .39438 L .67071 .40741 L p F P
0 g
s
.785 .933 .929 r
.65579 .41042 m .679 .39438 L .67071 .40741 L p F P
0 g
s
.679 .846 .963 r
.53972 .4574 m .51414 .46755 L .5073 .4627 L p F P
0 g
s
.657 .84 .97 r
.48181 .47177 m .5073 .4627 L .51414 .46755 L p F P
0 g
s
.884 .48 .249 r
.32811 .35584 m .33904 .36293 L .33514 .35347 L p F P
0 g
s
.884 .48 .249 r
.33514 .35347 m .32462 .34624 L .32811 .35584 L p F P
0 g
s
.786 .917 .534 r
.51361 .3002 m .50684 .31362 L .51529 .29968 L p F P
0 g
s
.786 .917 .534 r
.51692 .2937 m .51361 .3002 L p .51529 .29968 L F P
0 g
s
.786 .917 .534 r
.51529 .29968 m .51923 .29103 L .51692 .2937 L p F P
0 g
s
.697 .859 .96 r
.54476 .46086 m .53972 .4574 L .56401 .44676 L closepath p F P
0 g
s
.749 .914 .948 r
.62369 .42291 m .62997 .42655 L .60422 .44117 L p F P
0 g
s
.749 .914 .948 r
.61275 .42922 m .62369 .42291 L p .60422 .44117 L F P
0 g
s
.749 .914 .948 r
.60422 .44117 m .60275 .4404 L .61275 .42922 L p F P
0 g
s
.505 .616 .896 r
.72767 .11325 m .72977 .11328 L .7316 .11996 L closepath p F P
0 g
s
.442 .579 .895 r
.75166 .11567 m .72977 .11328 L .7316 .11996 L p F P
0 g
s
.442 .579 .895 r
.75365 .12638 m .75166 .11567 L p .7316 .11996 L F P
0 g
s
.933 .964 .756 r
.5368 .24797 m .54552 .23398 L .54483 .24545 L p F P
0 g
s
.933 .964 .756 r
.53663 .24977 m .5368 .24797 L p .54483 .24545 L F P
0 g
s
.933 .964 .756 r
.54483 .24545 m .54225 .24921 L .53663 .24977 L p F P
0 g
s
.881 .99 .804 r
.74126 .33917 m .75478 .32325 L .75071 .3351 L p F P
0 g
s
.881 .99 .804 r
.73764 .3492 m .74126 .33917 L p .75071 .3351 L F P
0 g
s
.881 .99 .804 r
.75071 .3351 m .73849 .34923 L .73764 .3492 L p F P
0 g
s
.405 .648 .956 r
.21071 .44178 m .20942 .44168 L .20142 .43386 L p F P
0 g
s
0 0 .525 r
.7864 .19141 m .78645 .19013 L .78732 .19356 L closepath p F P
0 g
s
.037 0 .152 r
.48017 .35613 m .4746 .36107 L .47694 .35271 L p F P
0 g
s
.037 0 .152 r
.47694 .35271 m .48909 .34191 L .48017 .35613 L p F P
0 g
s
.783 .735 .209 r
.7883 .24552 m .7869 .2568 L .78919 .24495 L p F P
0 g
s
.783 .735 .209 r
.78919 .24495 m .79059 .23365 L .7883 .24552 L p F P
0 g
s
.618 .781 .959 r
.41384 .47326 m .41712 .47607 L p .38482 .47637 L F P
0 g
s
.618 .781 .959 r
.38482 .47637 m .39865 .47276 L .41384 .47326 L p F P
0 g
s
.618 .78 .959 r
.38482 .47637 m .39865 .47276 L .37976 .47208 L closepath p F P
0 g
s
.902 .937 .567 r
.77662 .28265 m .77404 .29417 L .78052 .28079 L p F P
0 g
s
.902 .937 .567 r
.77735 .28109 m .77662 .28265 L p .78052 .28079 L F P
0 g
s
.902 .937 .567 r
.78052 .28079 m .78112 .27818 L .77735 .28109 L p F P
0 g
s
.534 .223 .387 r
.42192 .38681 m .42362 .38716 L .42174 .38758 L closepath p F P
0 g
s
.36 .48 .846 r
.76143 .12875 m .75365 .12638 L .75519 .13717 L p F P
0 g
s
.36 .48 .846 r
.75519 .13717 m .76766 .14159 L .76143 .12875 L p F P
0 g
s
.908 .859 .781 r
.57962 .17033 m .57226 .18057 L .57497 .19098 L p F P
0 g
s
.907 .859 .783 r
.56166 .19519 m .56343 .20592 L .57497 .19098 L p F P
0 g
s
.907 .859 .783 r
.57497 .19098 m .57226 .18057 L .56166 .19519 L p F P
0 g
s
.61 .677 .888 r
.69491 .10892 m .72153 .10305 L .72767 .11325 L p F P
0 g
s
.62 .687 .892 r
.72153 .10305 m .69491 .10892 L .68872 .09958 L p F P
0 g
s
.697 .735 .88 r
.66261 .1115 m .68872 .09958 L .69491 .10892 L p F P
0 g
s
.958 .939 .718 r
.54225 .24921 m .53643 .2593 L .53663 .24977 L closepath p F P
0 g
s
.405 .648 .956 r
.20142 .43386 m .20232 .43392 L .21071 .44178 L p F P
0 g
s
.454 .67 .956 r
.22518 .43417 m .20232 .43392 L .21071 .44178 L p F P
0 g
s
.454 .67 .956 r
.21071 .44178 m .23315 .44206 L .22518 .43417 L p F P
0 g
s
.66 .828 .964 r
.5073 .4627 m .48181 .47177 L .47482 .46653 L p F P
0 g
s
.64 .821 .97 r
.44946 .47458 m .47482 .46653 L .48181 .47177 L p F P
0 g
s
.813 .95 .909 r
.6979 .38691 m .68753 .39494 L .68161 .3924 L p F P
0 g
s
.704 .739 .879 r
.68872 .09958 m .66261 .1115 L .65633 .10272 L p F P
0 g
s
.67 .365 .448 r
.42174 .38758 m .39183 .38765 L .3964 .39709 L p F P
0 g
s
.701 .376 .425 r
.38631 .39632 m .3964 .39709 L .39183 .38765 L p F P
0 g
s
.701 .376 .425 r
.39183 .38765 m .38867 .38741 L .38631 .39632 L p F P
0 g
s
.548 .253 .418 r
.42362 .38716 m .42174 .38758 L .41999 .39703 L p F P
0 g
s
.67 .365 .448 r
.3964 .39709 m .41999 .39703 L .42174 .38758 L p F P
0 g
s
.628 .801 .965 r
.44404 .47017 m .44946 .47458 L p .41712 .47607 L F P
0 g
s
.628 .801 .965 r
.41712 .47607 m .43203 .47177 L .44404 .47017 L p F P
0 g
s
.633 .786 .955 r
.41712 .47607 m .43203 .47177 L .41384 .47326 L closepath p F P
0 g
s
0 .112 .639 r
.78041 .17187 m .7862 .18043 L .78645 .19013 L closepath p F P
0 g
s
0 0 .446 r
.78983 .19001 m .7862 .18043 L .78645 .19013 L p F P
0 g
s
0 0 .446 r
.79006 .20097 m .78983 .19001 L p .78645 .19013 L F P
0 g
s
0 0 .446 r
.78645 .19013 m .78732 .19356 L .79006 .20097 L p F P
0 g
s
.746 .425 .44 r
.37387 .39427 m .38631 .39632 L .38867 .38741 L p F P
0 g
s
.746 .425 .44 r
.38867 .38741 m .37072 .38435 L .37387 .39427 L p F P
0 g
s
.647 .805 .959 r
.47079 .46308 m .47482 .46653 L .44946 .47458 L p F P
0 g
s
.647 .805 .959 r
.44946 .47458 m .44404 .47017 L .47079 .46308 L p F P
0 g
s
.874 .992 .81 r
.73849 .34923 m .73684 .35109 L .73764 .3492 L closepath p F P
0 g
s
.548 .245 .405 r
.44947 .38157 m .42362 .38716 L .44014 .39246 L p F P
0 g
s
.548 .253 .418 r
.41999 .39703 m .44014 .39246 L .42362 .38716 L p F P
0 g
s
.861 .492 .35 r
.34263 .37259 m .35495 .37912 L .35206 .3692 L p F P
0 g
s
.861 .492 .35 r
.34241 .37172 m .34263 .37259 L p .35206 .3692 L F P
0 g
s
.861 .492 .35 r
.35206 .3692 m .34766 .36687 L .34241 .37172 L p F P
0 g
s
.067 .201 .695 r
.78032 .17176 m .78031 .17159 L .78041 .17187 L closepath p F P
0 g
s
0 .082 .628 r
.78031 .17159 m .78041 .17187 L .7862 .18043 L p F P
0 g
s
.861 .974 .861 r
.72466 .35616 m .71945 .36829 L .73684 .35109 L p F P
0 g
s
.861 .974 .861 r
.73293 .3478 m .72466 .35616 L p .73684 .35109 L F P
0 g
s
.861 .974 .861 r
.73684 .35109 m .73764 .3492 L .73293 .3478 L p F P
0 g
s
.117 .269 .744 r
.77397 .15587 m .77943 .16092 L .78031 .17159 L closepath p F P
0 g
s
0 .082 .628 r
.78539 .16957 m .77943 .16092 L .78031 .17159 L p F P
0 g
s
0 .082 .628 r
.7862 .18043 m .78539 .16957 L p .78031 .17159 L F P
0 g
s
.529 .734 .969 r
.28079 .46268 m .30517 .4599 L .31285 .46665 L p F P
0 g
s
.535 .727 .963 r
.30517 .4599 m .28079 .46268 L .273 .45568 L p F P
0 g
s
.836 .971 .885 r
.6979 .38691 m .71312 .3739 L .70736 .37181 L p F P
0 g
s
.836 .971 .885 r
.70736 .37181 m .70438 .37441 L .6979 .38691 L p F P
0 g
s
.813 .95 .909 r
.68161 .3924 m .70438 .37441 L .6979 .38691 L p F P
0 g
s
0 0 .481 r
.78732 .19356 m .79006 .20097 L .78995 .20466 L closepath p F P
0 g
s
.235 .368 .794 r
.77035 .1535 m .76988 .14642 L .77397 .15587 L closepath p F P
0 g
s
.738 .889 .948 r
.60275 .4404 m .59782 .43727 L .61275 .42922 L closepath p F P
0 g
s
.842 .964 .884 r
.71945 .36829 m .71312 .3739 L .70736 .37181 L p F P
0 g
s
.842 .964 .884 r
.70736 .37181 m .72466 .35616 L .71945 .36829 L p F P
0 g
s
.917 .931 .56 r
.78112 .27818 m .77735 .28109 L .78273 .26936 L closepath p F P
0 g
s
.906 .888 .803 r
.55428 .20521 m .56166 .19519 L .56343 .20592 L p F P
0 g
s
.906 .888 .803 r
.56343 .20592 m .56089 .20917 L .55428 .20521 L p F P
0 g
s
0 0 0 r
.50707 .31354 m .49848 .32756 L .50684 .31362 L p F P
0 g
s
0 0 0 r
.50684 .31362 m .51361 .3002 L .50707 .31354 L p F P
0 g
s
.874 .971 .849 r
.73764 .3492 m .73293 .3478 L .74126 .33917 L closepath p F P
0 g
s
.959 .939 .714 r
.52981 .26137 m .52864 .27295 L .53643 .2593 L p F P
0 g
s
.959 .939 .714 r
.5356 .2499 m .52981 .26137 L p .53643 .2593 L F P
0 g
s
.959 .939 .714 r
.53643 .2593 m .53663 .24977 L .5356 .2499 L p F P
0 g
s
.946 .879 .736 r
.55413 .22006 m .56089 .20917 L .55428 .20521 L p F P
0 g
s
.836 .452 .324 r
.34766 .36687 m .34241 .37172 L .33904 .36293 L closepath p F P
0 g
s
.725 .88 .953 r
.59782 .43727 m .57205 .45014 L .56547 .44609 L p F P
0 g
s
.469 .696 .967 r
.24107 .44958 m .25098 .44935 L .26112 .45649 L p F P
0 g
s
.505 .708 .962 r
.26517 .44836 m .25098 .44935 L .26112 .45649 L p F P
0 g
s
.505 .708 .962 r
.26112 .45649 m .273 .45568 L .26517 .44836 L p F P
0 g
s
.703 .574 .707 r
.39799 .83366 m .42934 .83328 L .40885 .8515 L p F P
0 g
s
.703 .574 .707 r
.40885 .8515 m .40366 .85156 L .39799 .83366 L p F P
0 g
s
.703 .591 .728 r
.42934 .83328 m .39799 .83366 L .39789 .8334 L p F P
0 g
s
.715 .581 .703 r
.3976 .83365 m .39799 .83366 L .40366 .85156 L p F P
0 g
s
.714 .597 .724 r
.39799 .83366 m .39789 .8334 L .3976 .83365 L closepath p F P
0 g
s
.715 .581 .703 r
.40366 .85156 m .38017 .85101 L .3976 .83365 L p F P
0 g
s
.719 .588 .708 r
.37047 .83271 m .3976 .83365 L .38017 .85101 L p F P
0 g
s
.714 .596 .723 r
.3907 .81456 m .37047 .83271 L .3976 .83365 L p F P
0 g
s
.714 .596 .723 r
.391 .81457 m .3907 .81456 L p .3976 .83365 L F P
0 g
s
.714 .596 .723 r
.3976 .83365 m .39789 .8334 L .391 .81457 L p F P
0 g
s
.703 .591 .728 r
.39789 .8334 m .42131 .81452 L p .42934 .83328 L F P
0 g
s
.706 .592 .726 r
.39789 .8334 m .42131 .81452 L .391 .81457 L closepath p F P
0 g
s
.703 .556 .686 r
.40478 .85575 m .40885 .8515 L .40366 .85156 L closepath p F P
0 g
s
.715 .569 .689 r
.40366 .85156 m .40478 .85575 L .39367 .86825 L p F P
0 g
s
.715 .569 .689 r
.38017 .85101 m .40366 .85156 L p .39367 .86825 L F P
0 g
s
.807 .479 .434 r
.35728 .38931 m .37387 .39427 L .37072 .38435 L p F P
0 g
s
.807 .479 .434 r
.37072 .38435 m .35495 .37912 L .35728 .38931 L p F P
0 g
s
0 0 .257 r
.79163 .21135 m .79147 .2162 L .78995 .20466 L p F P
0 g
s
0 0 .257 r
.78995 .20466 m .79006 .20097 L .79163 .21135 L p F P
0 g
s
.699 .555 .688 r
.40885 .8515 m .43593 .85093 L p .42468 .86809 L F P
0 g
s
.699 .555 .688 r
.40478 .85575 m .40885 .8515 L p .42468 .86809 L F P
0 g
s
.7 .569 .704 r
.43593 .85093 m .40885 .8515 L .42934 .83328 L p F P
0 g
s
0 0 .012 r
.79122 .22511 m .79059 .23365 L .79099 .22251 L p F P
0 g
s
0 0 .012 r
.79099 .22251 m .79147 .2162 L .79122 .22511 L p F P
0 g
s
.513 .627 .901 r
.72977 .11328 m .72767 .11325 L .72153 .10305 L p F P
0 g
s
.925 .968 .677 r
.76823 .29678 m .76557 .30829 L .77404 .29417 L p F P
0 g
s
.925 .968 .677 r
.77404 .29417 m .77662 .28265 L .76823 .29678 L p F P
0 g
s
.699 .555 .688 r
.42468 .86809 m .40818 .86844 L .40478 .85575 L p F P
0 g
s
.711 .563 .684 r
.40818 .86844 m .40478 .85575 L .39367 .86825 L closepath p F P
0 g
s
.7 .569 .704 r
.42934 .83328 m .43051 .83326 L .43593 .85093 L p F P
0 g
s
.7 .586 .724 r
.43051 .83326 m .43027 .83256 L .42934 .83328 L closepath p F P
0 g
s
.703 .591 .728 r
.42389 .81449 m .43027 .83256 L .42934 .83328 L p F P
0 g
s
.703 .591 .728 r
.42131 .81452 m .42389 .81449 L p .42934 .83328 L F P
0 g
s
.687 .561 .707 r
.43051 .83326 m .4615 .83142 L p .44283 .85052 L F P
0 g
s
.687 .561 .707 r
.44283 .85052 m .43593 .85093 L .43051 .83326 L p F P
0 g
s
.691 .581 .727 r
.4557 .81452 m .4615 .83142 L .43051 .83326 L p F P
0 g
s
.691 .581 .727 r
.43051 .83326 m .43027 .83256 L .4557 .81452 L p F P
0 g
s
.811 .804 .844 r
.61725 .13185 m .605 .14239 L .59852 .13463 L p F P
0 g
s
.861 .813 .801 r
.59874 .14941 m .605 .14239 L .59852 .13463 L p F P
0 g
s
.691 .58 .726 r
.45514 .81286 m .4557 .81452 L .43027 .83256 L p F P
0 g
s
.691 .58 .726 r
.43027 .83256 m .42389 .81449 L .45514 .81286 L p F P
0 g
s
.762 .909 .94 r
.64584 .41693 m .62997 .42655 L .62369 .42291 L p F P
0 g
s
.715 .569 .689 r
.3723 .86017 m .38017 .85101 L p .39367 .86825 L F P
0 g
s
.719 .571 .687 r
.3723 .86017 m .38017 .85101 L .36964 .85064 L closepath p F P
0 g
s
.719 .588 .708 r
.36541 .83792 m .37047 .83271 L p .38017 .85101 L F P
0 g
s
.719 .588 .708 r
.38017 .85101 m .36964 .85064 L .36541 .83792 L p F P
0 g
s
.686 .543 .686 r
.43715 .85564 m .44283 .85052 L .43593 .85093 L closepath p F P
0 g
s
.699 .555 .688 r
.43593 .85093 m .43715 .85564 L .42468 .86809 L p F P
0 g
s
.819 .799 .833 r
.61725 .13185 m .63054 .12006 L .62413 .11163 L p F P
0 g
s
.819 .799 .833 r
.62413 .11163 m .61296 .12184 L .61725 .13185 L p F P
0 g
s
.811 .804 .844 r
.59852 .13463 m .61296 .12184 L .61725 .13185 L p F P
0 g
s
.567 .747 .962 r
.33835 .46322 m .34508 .46916 L p .31285 .46665 L F P
0 g
s
.567 .747 .962 r
.31285 .46665 m .3368 .46258 L .33835 .46322 L p F P
0 g
s
.583 .74 .951 r
.3368 .46258 m .31285 .46665 L .30517 .4599 L p F P
0 g
s
.639 .778 .948 r
.43203 .47177 m .41384 .47326 L .40986 .46967 L p F P
0 g
s
.627 .775 .951 r
.41384 .47326 m .40986 .46967 L .39865 .47276 L closepath p F P
0 g
s
.07 .257 .747 r
.76988 .14642 m .77397 .15587 L .77943 .16092 L p F P
0 g
s
.723 .589 .706 r
.36541 .83792 m .37047 .83271 L .36358 .83239 L closepath p F P
0 g
s
.721 .606 .727 r
.36449 .81335 m .3907 .81456 L .37047 .83271 L p F P
0 g
s
.721 .606 .727 r
.35841 .81897 m .36449 .81335 L p .37047 .83271 L F P
0 g
s
.721 .606 .727 r
.37047 .83271 m .36358 .83239 L .35841 .81897 L p F P
0 g
s
.762 .779 .867 r
.64395 .11117 m .63054 .12006 L .62413 .11163 L p F P
0 g
s
.725 .574 .685 r
.36964 .85064 m .35465 .84963 L p .36648 .86734 L F P
0 g
s
.725 .574 .685 r
.36648 .86734 m .3723 .86017 L .36964 .85064 L p F P
0 g
s
.729 .593 .704 r
.36964 .85064 m .36541 .83792 L .35465 .84963 L closepath p F P
0 g
s
.861 .813 .801 r
.59852 .13463 m .59433 .13948 L .59874 .14941 L p F P
0 g
s
.858 .812 .803 r
.58044 .15533 m .5841 .16551 L .59874 .14941 L p F P
0 g
s
.858 .812 .803 r
.59874 .14941 m .59433 .13948 L .58044 .15533 L p F P
0 g
s
.683 .542 .688 r
.43715 .85564 m .44283 .85052 L p .46212 .86618 L F P
0 g
s
.683 .542 .688 r
.46212 .86618 m .44028 .86764 L .43715 .85564 L p F P
0 g
s
.696 .55 .685 r
.44028 .86764 m .43715 .85564 L .42468 .86809 L closepath p F P
0 g
s
.706 .608 .745 r
.42131 .81452 m .391 .81457 L .39092 .81439 L p F P
0 g
s
.716 .613 .741 r
.391 .81457 m .39092 .81439 L .3907 .81456 L closepath p F P
0 g
s
.716 .613 .741 r
.38388 .79746 m .36449 .81335 L .3907 .81456 L p F P
0 g
s
.716 .613 .741 r
.3907 .81456 m .39092 .81439 L .38388 .79746 L p F P
0 g
s
.683 .542 .688 r
.44283 .85052 m .46675 .84893 L p .46212 .86618 L F P
0 g
s
.685 .557 .705 r
.46675 .84893 m .46263 .8352 L .44283 .85052 L closepath p F P
0 g
s
.687 .561 .707 r
.4615 .83142 m .46263 .8352 L .44283 .85052 L p F P
0 g
s
.706 .608 .745 r
.39092 .81439 m .41633 .79554 L p .42131 .81452 L F P
0 g
s
.709 .605 .738 r
.41633 .79554 m .39092 .81439 L .38388 .79746 L p F P
0 g
s
.703 .602 .741 r
.42389 .81449 m .42332 .81307 L .42131 .81452 L closepath p F P
0 g
s
.706 .608 .745 r
.41633 .79554 m .42332 .81307 L .42131 .81452 L p F P
0 g
s
.698 .537 .666 r
.41154 .88386 m .42468 .86809 L .40818 .86844 L closepath p F P
0 g
s
.706 .542 .664 r
.40818 .86844 m .39367 .86825 L p .41111 .88442 L F P
0 g
s
.706 .542 .664 r
.41111 .88442 m .41154 .88386 L .40818 .86844 L p F P
0 g
s
.513 .627 .901 r
.72153 .10305 m .72644 .103 L .72977 .11328 L p F P
0 g
s
.464 .593 .897 r
.74927 .10545 m .75166 .11567 L .72977 .11328 L p F P
0 g
s
.464 .593 .897 r
.74904 .10501 m .74927 .10545 L p .72977 .11328 L F P
0 g
s
.464 .593 .897 r
.72977 .11328 m .72644 .103 L .74904 .10501 L p F P
0 g
s
.694 .598 .744 r
.44875 .79635 m .45514 .81286 L .42389 .81449 L p F P
0 g
s
.694 .598 .744 r
.42389 .81449 m .42332 .81307 L .44875 .79635 L p F P
0 g
s
.733 .602 .71 r
.36358 .83239 m .36541 .83792 L .35465 .84963 L p F P
0 g
s
.476 .69 .961 r
.25098 .44935 m .24107 .44958 L .23315 .44206 L p F P
0 g
s
.733 .602 .71 r
.3461 .83099 m .36358 .83239 L p .35465 .84963 L F P
0 g
s
.731 .61 .723 r
.36358 .83239 m .35841 .81897 L .3461 .83099 L closepath p F P
0 g
s
.628 .774 .95 r
.40258 .46218 m .40986 .46967 L .39865 .47276 L p F P
0 g
s
.628 .774 .95 r
.37743 .47001 m .40258 .46218 L p .39865 .47276 L F P
0 g
s
.628 .774 .95 r
.39865 .47276 m .37976 .47208 L .37743 .47001 L p F P
0 g
s
.694 .593 .739 r
.44875 .79635 m .42332 .81307 L .41633 .79554 L p F P
0 g
s
.706 .542 .664 r
.39367 .86825 m .38205 .88403 L .41111 .88442 L p F P
0 g
s
.715 .551 .666 r
.37444 .86778 m .39367 .86825 L .38205 .88403 L p F P
0 g
s
.715 .569 .689 r
.39367 .86825 m .37444 .86778 L .3723 .86017 L p F P
0 g
s
.895 .869 .429 r
.78417 .2581 m .78273 .26936 L .7869 .2568 L p F P
0 g
s
.895 .869 .429 r
.7869 .2568 m .7883 .24552 L .78417 .2581 L p F P
0 g
s
.726 .576 .685 r
.37444 .86778 m .3723 .86017 L .36648 .86734 L closepath p F P
0 g
s
.699 .539 .667 r
.42468 .86809 m .44028 .86764 L p .41167 .88443 L F P
0 g
s
.699 .539 .667 r
.41167 .88443 m .41154 .88386 L .42468 .86809 L p F P
0 g
s
.905 .494 .165 r
.31944 .34786 m .32811 .35584 L .32462 .34624 L p F P
0 g
s
.905 .494 .165 r
.32462 .34624 m .31609 .33821 L .31944 .34786 L p F P
0 g
s
.605 .766 .957 r
.37976 .47208 m .37743 .47001 L .37368 .47089 L closepath p F P
0 g
s
.715 .551 .666 r
.38205 .88403 m .37807 .88394 L .37444 .86778 L p F P
0 g
s
.726 .558 .663 r
.36648 .86734 m .37444 .86778 L .37807 .88394 L p F P
0 g
s
.681 .523 .666 r
.44028 .86764 m .46212 .86618 L .44546 .88337 L p F P
0 g
s
.681 .523 .666 r
.44546 .88337 m .44365 .88349 L .44028 .86764 L p F P
0 g
s
.699 .539 .667 r
.44028 .86764 m .44365 .88349 L .41167 .88443 L p F P
0 g
s
.946 .879 .736 r
.55428 .20521 m .55175 .20959 L .55413 .22006 L p F P
0 g
s
.948 .879 .734 r
.54393 .22324 m .54552 .23398 L .55413 .22006 L p F P
0 g
s
.948 .879 .734 r
.55413 .22006 m .55175 .20959 L .54393 .22324 L p F P
0 g
s
.725 .574 .685 r
.35465 .84963 m .34202 .86566 L .36648 .86734 L p F P
0 g
s
.735 .585 .688 r
.33346 .84788 m .35465 .84963 L .34202 .86566 L p F P
0 g
s
.733 .602 .71 r
.33275 .84588 m .3461 .83099 L p .35465 .84963 L F P
0 g
s
.733 .602 .71 r
.35465 .84963 m .33346 .84788 L .33275 .84588 L p F P
0 g
s
.638 .79 .955 r
.44404 .47017 m .44233 .46869 L .43203 .47177 L closepath p F P
0 g
s
.639 .778 .948 r
.43516 .46152 m .44233 .46869 L .43203 .47177 L p F P
0 g
s
.639 .778 .948 r
.40986 .46967 m .43516 .46152 L p .43203 .47177 L F P
0 g
s
0 0 0 r
.49834 .32775 m .49825 .32796 L .49848 .32756 L closepath p F P
0 g
s
.673 .549 .706 r
.46263 .8352 m .46933 .83062 L .4615 .83142 L closepath p F P
0 g
s
.675 .568 .727 r
.46933 .83062 m .4615 .83142 L .4557 .81452 L p F P
0 g
s
.358 .079 .347 r
.45385 .38765 m .44767 .39085 L .44947 .38157 L p F P
0 g
s
.358 .079 .347 r
.44947 .38157 m .47085 .37053 L .45385 .38765 L p F P
0 g
s
.548 .245 .405 r
.44014 .39246 m .44767 .39085 L .44947 .38157 L p F P
0 g
s
.726 .558 .663 r
.37807 .88394 m .35627 .88273 L .36648 .86734 L p F P
0 g
s
.731 .565 .667 r
.34202 .86566 m .36648 .86734 L .35627 .88273 L p F P
0 g
s
.725 .608 .725 r
.35841 .81897 m .36449 .81335 L .35605 .81283 L closepath p F P
0 g
s
.723 .623 .745 r
.38247 .79408 m .38388 .79746 L .36449 .81335 L p F P
0 g
s
.723 .623 .745 r
.36222 .79287 m .38247 .79408 L p .36449 .81335 L F P
0 g
s
.723 .623 .745 r
.35133 .80205 m .36222 .79287 L p .36449 .81335 L F P
0 g
s
.723 .623 .745 r
.36449 .81335 m .35605 .81283 L .35133 .80205 L p F P
0 g
s
0 0 0 r
.50078 .32683 m .50707 .31354 L .49848 .32756 L p F P
0 g
s
0 0 0 r
.4955 .33532 m .50078 .32683 L p .49848 .32756 L F P
0 g
s
0 0 0 r
.49848 .32756 m .49825 .32796 L .4955 .33532 L p F P
0 g
s
.736 .619 .729 r
.35605 .81283 m .35841 .81897 L .3461 .83099 L p F P
0 g
s
.671 .55 .708 r
.46263 .8352 m .46933 .83062 L p .48688 .84677 L F P
0 g
s
.671 .55 .708 r
.48688 .84677 m .46675 .84893 L .46263 .8352 L p F P
0 g
s
.698 .851 .955 r
.56401 .44676 m .53972 .4574 L .53297 .45249 L p F P
0 g
s
.679 .846 .963 r
.5073 .4627 m .53297 .45249 L .53972 .4574 L p F P
0 g
s
0 0 0 r
.49825 .32796 m .48909 .34191 L .4955 .33532 L closepath p F P
0 g
s
.857 .829 .82 r
.57304 .16358 m .58044 .15533 L .5841 .16551 L p F P
0 g
s
.857 .829 .82 r
.5841 .16551 m .57962 .17033 L .57304 .16358 L p F P
0 g
s
.738 .604 .708 r
.33275 .84588 m .3461 .83099 L .32682 .82911 L closepath p F P
0 g
s
.736 .619 .729 r
.3408 .8114 m .35605 .81283 L p .3461 .83099 L F P
0 g
s
.736 .619 .729 r
.32574 .82647 m .3408 .8114 L p .3461 .83099 L F P
0 g
s
.736 .619 .729 r
.3461 .83099 m .32682 .82911 L .32574 .82647 L p F P
0 g
s
.77 .776 .858 r
.64395 .11117 m .65633 .10272 L .64999 .09377 L p F P
0 g
s
.77 .776 .858 r
.64999 .09377 m .63946 .10118 L .64395 .11117 L p F P
0 g
s
.762 .779 .867 r
.62413 .11163 m .63946 .10118 L .64395 .11117 L p F P
0 g
s
.668 .53 .687 r
.46952 .85983 m .48688 .84677 L .46675 .84893 L closepath p F P
0 g
s
.683 .542 .688 r
.46675 .84893 m .46952 .85983 L .46212 .86618 L p F P
0 g
s
.827 .926 .541 r
.51923 .29103 m .51692 .2937 L .52089 .28664 L closepath p F P
0 g
s
.675 .568 .727 r
.4557 .81452 m .45891 .8125 L p .46933 .83062 L F P
0 g
s
.677 .568 .725 r
.4557 .81452 m .45891 .8125 L .45514 .81286 L closepath p F P
0 g
s
.902 .832 .768 r
.57226 .18057 m .57962 .17033 L .57304 .16358 L p F P
0 g
s
.678 .586 .745 r
.45891 .8125 m .45514 .81286 L .44875 .79635 L p F P
0 g
s
.777 .928 .933 r
.65579 .41042 m .64584 .41693 L .65191 .40841 L closepath p F P
0 g
s
.762 .909 .94 r
.64963 .40695 m .65191 .40841 L .64584 .41693 L p F P
0 g
s
.762 .909 .94 r
.62369 .42291 m .64963 .40695 L p .64584 .41693 L F P
0 g
s
0 0 .221 r
.79143 .2004 m .79163 .21135 L .79006 .20097 L p F P
0 g
s
0 0 .221 r
.79006 .20097 m .78983 .19001 L .79143 .2004 L p F P
0 g
s
.953 .945 .635 r
.52324 .27467 m .52089 .28664 L .52864 .27295 L p F P
0 g
s
.953 .945 .635 r
.52864 .27295 m .52981 .26137 L .52324 .27467 L p F P
0 g
s
.87 .467 .266 r
.33137 .36561 m .32811 .35584 L .33904 .36293 L p F P
0 g
s
.87 .467 .266 r
.34167 .37191 m .33137 .36561 L p .33904 .36293 L F P
0 g
s
.87 .467 .266 r
.33904 .36293 m .34241 .37172 L .34167 .37191 L p F P
0 g
s
.615 .757 .947 r
.34508 .46916 m .35662 .46628 L .37368 .47089 L p F P
0 g
s
.613 .767 .953 r
.34508 .46916 m .35662 .46628 L .33835 .46322 L closepath p F P
0 g
s
.733 .627 .741 r
.35605 .81283 m .35133 .80205 L .3408 .8114 L closepath p F P
0 g
s
.61 .749 .944 r
.37002 .46277 m .35662 .46628 L .37368 .47089 L p F P
0 g
s
.61 .749 .944 r
.37368 .47089 m .37743 .47001 L .37002 .46277 L p F P
0 g
s
.671 .55 .708 r
.46933 .83062 m .49119 .82828 L p .48688 .84677 L F P
0 g
s
.673 .565 .725 r
.49119 .82828 m .48813 .81923 L .46933 .83062 L closepath p F P
0 g
s
.675 .568 .727 r
.48499 .80985 m .48813 .81923 L .46933 .83062 L p F P
0 g
s
.675 .568 .727 r
.45891 .8125 m .48499 .80985 L p .46933 .83062 L F P
0 g
s
.694 .593 .739 r
.4475 .79309 m .44875 .79635 L p .41633 .79554 L F P
0 g
s
.694 .593 .739 r
.41633 .79554 m .41806 .79436 L .4475 .79309 L p F P
0 g
s
.697 .598 .743 r
.41633 .79554 m .41806 .79436 L .41589 .79444 L closepath p F P
0 g
s
.709 .605 .738 r
.41589 .79444 m .41633 .79554 L p .38388 .79746 L F P
0 g
s
.677 .583 .742 r
.48499 .80985 m .4812 .79983 L .45891 .8125 L closepath p F P
0 g
s
.678 .586 .745 r
.4776 .79027 m .4812 .79983 L .45891 .8125 L p F P
0 g
s
.678 .586 .745 r
.45549 .79238 m .4776 .79027 L p .45891 .8125 L F P
0 g
s
.678 .586 .745 r
.44875 .79635 m .45549 .79238 L p .45891 .8125 L F P
0 g
s
.707 .544 .665 r
.41167 .88443 m .41154 .88386 L .41111 .88442 L closepath p F P
0 g
s
.709 .605 .738 r
.38388 .79746 m .38814 .7942 L .41589 .79444 L p F P
0 g
s
.712 .611 .743 r
.38388 .79746 m .38814 .7942 L .38247 .79408 L closepath p F P
0 g
s
.07 .257 .747 r
.77802 .15017 m .76934 .14261 L .76988 .14642 L p F P
0 g
s
.07 .257 .747 r
.77943 .16092 m .77802 .15017 L p .76988 .14642 L F P
0 g
s
.234 .385 .811 r
.76766 .14159 m .76934 .14261 L .76988 .14642 L closepath p F P
0 g
s
.696 .615 .761 r
.41806 .79436 m .41589 .79444 L .40929 .77963 L p F P
0 g
s
.707 .62 .757 r
.41589 .79444 m .40929 .77963 L .38814 .7942 L closepath p F P
0 g
s
.693 .514 .641 r
.41167 .88443 m .44365 .88349 L p .43494 .89892 L F P
0 g
s
.693 .514 .641 r
.43494 .89892 m .4141 .89953 L .41167 .88443 L p F P
0 g
s
.706 .523 .639 r
.41111 .88442 m .41167 .88443 L .4141 .89953 L p F P
0 g
s
.706 .523 .639 r
.4141 .89953 m .40234 .89948 L .41111 .88442 L p F P
0 g
s
.71 .529 .642 r
.38205 .88403 m .41111 .88442 L .40234 .89948 L p F P
0 g
s
.694 .609 .758 r
.4475 .79309 m .44176 .77979 L .41806 .79436 L closepath p F P
0 g
s
.696 .615 .761 r
.43835 .77188 m .44176 .77979 L .41806 .79436 L p F P
0 g
s
.696 .615 .761 r
.42057 .77248 m .43835 .77188 L p .41806 .79436 L F P
0 g
s
.696 .615 .761 r
.40929 .77963 m .42057 .77248 L p .41806 .79436 L F P
0 g
s
.913 .981 .752 r
.75778 .31166 m .76823 .29678 L .76557 .30829 L p F P
0 g
s
.913 .981 .752 r
.75607 .31877 m .75778 .31166 L p .76557 .30829 L F P
0 g
s
.913 .981 .752 r
.76557 .30829 m .75811 .31869 L .75607 .31877 L p F P
0 g
s
.652 .794 .95 r
.46777 .46036 m .47079 .46308 L .44404 .47017 L p F P
0 g
s
.652 .794 .95 r
.44404 .47017 m .44233 .46869 L .46777 .46036 L p F P
0 g
s
.62 .687 .892 r
.68872 .09958 m .71537 .09302 L .72153 .10305 L p F P
0 g
s
.627 .696 .894 r
.71537 .09302 m .68872 .09958 L .68249 .09023 L p F P
0 g
s
.704 .739 .879 r
.65633 .10272 m .68249 .09023 L .68872 .09958 L p F P
0 g
s
.71 .627 .762 r
.40625 .77281 m .40929 .77963 L .38814 .7942 L p F P
0 g
s
.71 .627 .762 r
.39001 .77248 m .40625 .77281 L p .38814 .7942 L F P
0 g
s
.71 .627 .762 r
.37678 .78186 m .39001 .77248 L p .38814 .7942 L F P
0 g
s
.71 .627 .762 r
.38814 .7942 m .38247 .79408 L .37678 .78186 L p F P
0 g
s
.678 .519 .663 r
.46212 .86618 m .47099 .86554 L .47428 .8813 L p F P
0 g
s
.678 .519 .663 r
.47428 .8813 m .44546 .88337 L .46212 .86618 L p F P
0 g
s
.681 .539 .686 r
.47099 .86554 m .46952 .85983 L .46212 .86618 L closepath p F P
0 g
s
.721 .631 .757 r
.38247 .79408 m .37678 .78186 L .36222 .79287 L closepath p F P
0 g
s
.71 .529 .642 r
.37898 .88945 m .38205 .88403 L p .40234 .89948 L F P
0 g
s
.714 .531 .641 r
.37898 .88945 m .38205 .88403 L .37807 .88394 L closepath p F P
0 g
s
.67 .533 .689 r
.47099 .86554 m .46952 .85983 L .48688 .84677 L p F P
0 g
s
.721 .535 .639 r
.37807 .88394 m .35627 .88273 L p .37398 .89888 L F P
0 g
s
.721 .535 .639 r
.37398 .89888 m .37898 .88945 L .37807 .88394 L p F P
0 g
s
.735 .585 .688 r
.34202 .86566 m .33863 .86538 L .33346 .84788 L p F P
0 g
s
.744 .591 .685 r
.33123 .84763 m .33346 .84788 L .33863 .86538 L p F P
0 g
s
.742 .606 .706 r
.33346 .84788 m .33275 .84588 L .33123 .84763 L closepath p F P
0 g
s
.742 .606 .706 r
.33123 .84763 m .33275 .84588 L .32682 .82911 L p F P
0 g
s
.731 .565 .667 r
.33959 .86945 m .34202 .86566 L p .35627 .88273 L F P
0 g
s
.736 .568 .665 r
.33959 .86945 m .34202 .86566 L .33863 .86538 L closepath p F P
0 g
s
.79 .928 .926 r
.679 .39438 m .65579 .41042 L .65191 .40841 L p F P
0 g
s
.744 .591 .685 r
.33863 .86538 m .31985 .86332 L .33123 .84763 L p F P
0 g
s
.75 .601 .692 r
.31004 .84499 m .33123 .84763 L .31985 .86332 L p F P
0 g
s
.742 .606 .706 r
.32358 .82871 m .31004 .84499 L .33123 .84763 L p F P
0 g
s
.742 .606 .706 r
.32682 .82911 m .32358 .82871 L p .33123 .84763 L F P
0 g
s
.679 .836 .959 r
.53297 .45249 m .5073 .4627 L .50039 .45743 L p F P
0 g
s
.66 .828 .964 r
.47482 .46653 m .50039 .45743 L .5073 .4627 L p F P
0 g
s
.672 .725 .889 r
.40258 .46218 m .37743 .47001 L .37002 .46277 L p F P
0 g
s
.663 .509 .666 r
.47099 .86554 m .50049 .86224 L p .49018 .87953 L F P
0 g
s
.663 .509 .666 r
.49018 .87953 m .47428 .8813 L .47099 .86554 L p F P
0 g
s
.67 .533 .689 r
.49633 .84571 m .50049 .86224 L .47099 .86554 L p F P
0 g
s
.67 .533 .689 r
.48688 .84677 m .49633 .84571 L p .47099 .86554 L F P
0 g
s
.708 .742 .878 r
.68249 .09023 m .65633 .10272 L .64999 .09377 L p F P
0 g
s
.677 .501 .639 r
.44395 .8854 m .44546 .88337 L .44365 .88349 L closepath p F P
0 g
s
.693 .514 .641 r
.44365 .88349 m .44395 .8854 L .43494 .89892 L p F P
0 g
s
.741 .618 .723 r
.3408 .8114 m .32574 .82647 L .31862 .80916 L p F P
0 g
s
.741 .618 .723 r
.31862 .80916 m .31886 .80892 L .3408 .8114 L p F P
0 g
s
.733 .628 .741 r
.33875 .79082 m .31886 .80892 L .3408 .8114 L p F P
0 g
s
.733 .628 .741 r
.34678 .79169 m .33875 .79082 L p .3408 .8114 L F P
0 g
s
.733 .628 .741 r
.3408 .8114 m .35133 .80205 L .34678 .79169 L p F P
0 g
s
.68 .586 .743 r
.44875 .79635 m .45549 .79238 L .4475 .79309 L closepath p F P
0 g
s
.867 .53 .412 r
.34453 .38293 m .35728 .38931 L .35495 .37912 L p F P
0 g
s
.867 .53 .412 r
.35495 .37912 m .34263 .37259 L .34453 .38293 L p F P
0 g
s
.676 .388 .476 r
.41999 .39703 m .3964 .39709 L .3996 .4071 L p F P
0 g
s
.708 .404 .46 r
.38448 .40593 m .3996 .4071 L .3964 .39709 L p F P
0 g
s
.708 .404 .46 r
.3964 .39709 m .38631 .39632 L .38448 .40593 L p F P
0 g
s
.062 0 .183 r
.4746 .36107 m .4726 .36896 L .48017 .35613 L closepath p F P
0 g
s
.741 .571 .663 r
.33863 .86538 m .31985 .86332 L p .33259 .88084 L F P
0 g
s
.741 .571 .663 r
.33259 .88084 m .33959 .86945 L .33863 .86538 L p F P
0 g
s
.675 .5 .641 r
.44546 .88337 m .47428 .8813 L p .47472 .89644 L F P
0 g
s
.675 .5 .641 r
.44395 .8854 m .44546 .88337 L p .47472 .89644 L F P
0 g
s
.562 .285 .454 r
.44014 .39246 m .41999 .39703 L .41866 .40704 L p F P
0 g
s
.676 .388 .476 r
.3996 .4071 m .41866 .40704 L .41999 .39703 L p F P
0 g
s
.727 .625 .744 r
.35133 .80205 m .36222 .79287 L .34678 .79169 L closepath p F P
0 g
s
.681 .603 .762 r
.45549 .79238 m .4475 .79309 L .44176 .77979 L p F P
0 g
s
.744 .623 .725 r
.32682 .82911 m .32574 .82647 L .32358 .82871 L closepath p F P
0 g
s
.902 .832 .768 r
.57304 .16358 m .56821 .17057 L .57226 .18057 L p F P
0 g
s
.901 .832 .768 r
.5582 .185 m .56166 .19519 L .57226 .18057 L p F P
0 g
s
.901 .832 .768 r
.57226 .18057 m .56821 .17057 L .5582 .185 L p F P
0 g
s
.675 .5 .641 r
.47472 .89644 m .44604 .89851 L .44395 .8854 L p F P
0 g
s
.689 .51 .639 r
.44604 .89851 m .44395 .8854 L .43494 .89892 L closepath p F P
0 g
s
0 0 .448 r
.78906 .17915 m .78983 .19001 L .7862 .18043 L p F P
0 g
s
0 0 .448 r
.7862 .18043 m .78539 .16957 L .78906 .17915 L p F P
0 g
s
.372 .502 .86 r
.75523 .11659 m .75166 .11567 L .75365 .12638 L p F P
0 g
s
.372 .502 .86 r
.75365 .12638 m .76143 .12875 L .75523 .11659 L p F P
0 g
s
.239 .402 .824 r
.76934 .14261 m .76766 .14159 L .76143 .12875 L p F P
0 g
s
.731 .565 .667 r
.35627 .88273 m .34251 .88179 L .33959 .86945 L p F P
0 g
s
.741 .572 .664 r
.34251 .88179 m .33959 .86945 L .33259 .88084 L closepath p F P
0 g
s
.724 .639 .763 r
.3721 .77185 m .37678 .78186 L .36222 .79287 L p F P
0 g
s
.724 .639 .763 r
.36371 .77123 m .3721 .77185 L p .36222 .79287 L F P
0 g
s
.724 .639 .763 r
.34418 .7864 m .36371 .77123 L p .36222 .79287 L F P
0 g
s
.724 .639 .763 r
.36222 .79287 m .34678 .79169 L .34418 .7864 L p F P
0 g
s
.71 .529 .642 r
.40234 .89948 m .38061 .89918 L .37898 .88945 L p F P
0 g
s
.722 .537 .64 r
.38061 .89918 m .37898 .88945 L .37398 .89888 L closepath p F P
0 g
s
.671 .728 .892 r
.43516 .46152 m .40986 .46967 L .40258 .46218 L p F P
0 g
s
.739 .883 .946 r
.61275 .42922 m .59782 .43727 L .59134 .43298 L p F P
0 g
s
.725 .88 .953 r
.56547 .44609 m .59134 .43298 L .59782 .43727 L p F P
0 g
s
.744 .624 .725 r
.32358 .82871 m .32574 .82647 L .31862 .80916 L p F P
0 g
s
0 0 0 r
.79131 .22248 m .79122 .22511 L .79147 .2162 L p F P
0 g
s
0 0 0 r
.79147 .2162 m .79163 .21135 L .79131 .22248 L p F P
0 g
s
.748 .444 .469 r
.37609 .4046 m .38448 .40593 L .38631 .39632 L p F P
0 g
s
.748 .444 .469 r
.38631 .39632 m .37387 .39427 L .37609 .4046 L p F P
0 g
s
.669 .547 .707 r
.49633 .84571 m .49505 .84143 L .48688 .84677 L closepath p F P
0 g
s
.671 .55 .708 r
.49119 .82828 m .49505 .84143 L .48688 .84677 L p F P
0 g
s
.752 .619 .712 r
.3031 .82583 m .32358 .82871 L .31004 .84499 L p F P
0 g
s
.744 .624 .725 r
.31862 .80916 m .3031 .82583 L .32358 .82871 L p F P
0 g
s
.909 .983 .756 r
.75811 .31869 m .75478 .32325 L .75607 .31877 L closepath p F P
0 g
s
.721 .535 .639 r
.35627 .88273 m .34861 .89746 L .37398 .89888 L p F P
0 g
s
.731 .547 .643 r
.34251 .88179 m .35627 .88273 L .34861 .89746 L p F P
0 g
s
.535 .727 .963 r
.273 .45568 m .29744 .45281 L .30517 .4599 L p F P
0 g
s
.54 .721 .957 r
.29744 .45281 m .273 .45568 L .26517 .44836 L p F P
0 g
s
.663 .804 .951 r
.49509 .45293 m .50039 .45743 L .47482 .46653 L p F P
0 g
s
.663 .804 .951 r
.47482 .46653 m .47079 .46308 L .49509 .45293 L p F P
0 g
s
.955 .899 .731 r
.5361 .23694 m .5368 .24797 L .54552 .23398 L p F P
0 g
s
.955 .899 .731 r
.54552 .23398 m .54393 .22324 L .5361 .23694 L p F P
0 g
s
0 0 .024 r
.4928 .34316 m .48017 .35613 L .48909 .34191 L p F P
0 g
s
0 0 .024 r
.48909 .34191 m .4955 .33532 L .4928 .34316 L p F P
0 g
s
.66 .759 .923 r
.46777 .46036 m .44233 .46869 L .43516 .46152 L p F P
0 g
s
.679 .599 .759 r
.4776 .79027 m .47424 .78229 L .45549 .79238 L closepath p F P
0 g
s
.681 .603 .762 r
.46881 .76931 m .47424 .78229 L .45549 .79238 L p F P
0 g
s
.681 .603 .762 r
.45908 .77018 m .46881 .76931 L p .45549 .79238 L F P
0 g
s
.681 .603 .762 r
.44176 .77979 m .45908 .77018 L p .45549 .79238 L F P
0 g
s
.846 .779 .275 r
.78909 .23435 m .7883 .24552 L .79059 .23365 L p F P
0 g
s
.846 .779 .275 r
.79026 .22812 m .78909 .23435 L p .79059 .23365 L F P
0 g
s
.846 .779 .275 r
.79059 .23365 m .79122 .22511 L .79026 .22812 L p F P
0 g
s
.656 .538 .708 r
.49505 .84143 m .49119 .82828 L .51974 .82394 L p F P
0 g
s
.661 .558 .728 r
.51374 .80583 m .51974 .82394 L .49119 .82828 L p F P
0 g
s
.661 .558 .728 r
.49119 .82828 m .48813 .81923 L .51374 .80583 L p F P
0 g
s
.925 .934 .571 r
.77818 .27138 m .78417 .2581 L .78273 .26936 L p F P
0 g
s
.925 .934 .571 r
.77683 .28146 m .77818 .27138 L p .78273 .26936 L F P
0 g
s
.925 .934 .571 r
.78273 .26936 m .77735 .28109 L .77683 .28146 L p F P
0 g
s
.661 .557 .727 r
.51365 .80557 m .51374 .80583 L .48813 .81923 L p F P
0 g
s
.661 .557 .727 r
.48813 .81923 m .48499 .80985 L .51365 .80557 L p F P
0 g
s
.699 .616 .76 r
.40929 .77963 m .42057 .77248 L .40625 .77281 L closepath p F P
0 g
s
.895 .972 .821 r
.74468 .32748 m .74126 .33917 L .75478 .32325 L p F P
0 g
s
.895 .972 .821 r
.75269 .31786 m .74468 .32748 L p .75478 .32325 L F P
0 g
s
.895 .972 .821 r
.75478 .32325 m .75607 .31877 L .75269 .31786 L p F P
0 g
s
.476 .69 .961 r
.23315 .44206 m .2417 .44184 L .25098 .44935 L p F P
0 g
s
.509 .702 .957 r
.25729 .44072 m .2417 .44184 L .25098 .44935 L p F P
0 g
s
.509 .702 .957 r
.25098 .44935 m .26517 .44836 L .25729 .44072 L p F P
0 g
s
0 .088 .633 r
.78404 .15881 m .78539 .16957 L .77943 .16092 L p F P
0 g
s
0 .088 .633 r
.77943 .16092 m .77802 .15017 L .78404 .15881 L p F P
0 g
s
.665 .576 .746 r
.5068 .78715 m .51365 .80557 L .48499 .80985 L p F P
0 g
s
.665 .576 .746 r
.48499 .80985 m .4812 .79983 L .5068 .78715 L p F P
0 g
s
.714 .629 .761 r
.37678 .78186 m .39001 .77248 L .3721 .77185 L closepath p F P
0 g
s
.657 .54 .71 r
.49633 .84571 m .49505 .84143 L .52068 .82719 L p F P
0 g
s
.656 .538 .708 r
.51974 .82394 m .52068 .82719 L .49505 .84143 L p F P
0 g
s
.733 .643 .758 r
.34678 .79169 m .34418 .7864 L .33875 .79082 L closepath p F P
0 g
s
.731 .547 .643 r
.34861 .89746 m .34521 .89724 L .34251 .88179 L p F P
0 g
s
.742 .554 .64 r
.33259 .88084 m .34251 .88179 L .34521 .89724 L p F P
0 g
s
.239 .402 .824 r
.76143 .12875 m .76728 .132 L .76934 .14261 L p F P
0 g
s
.091 .28 .762 r
.77609 .13952 m .77802 .15017 L .76934 .14261 L p F P
0 g
s
.091 .28 .762 r
.76934 .14261 m .76728 .132 L .77609 .13952 L p F P
0 g
s
.651 .518 .688 r
.49633 .84571 m .52481 .84132 L p .51559 .85992 L F P
0 g
s
.651 .518 .688 r
.51559 .85992 m .50049 .86224 L .49633 .84571 L p F P
0 g
s
.657 .54 .71 r
.52068 .82719 m .52481 .84132 L .49633 .84571 L p F P
0 g
s
.838 .931 .553 r
.51674 .28798 m .52324 .27467 L .52089 .28664 L p F P
0 g
s
.838 .931 .553 r
.51469 .29619 m .51674 .28798 L p .52089 .28664 L F P
0 g
s
.838 .931 .553 r
.52089 .28664 m .51692 .2937 L .51469 .29619 L p F P
0 g
s
.521 .636 .904 r
.72644 .103 m .72153 .10305 L .71537 .09302 L p F P
0 g
s
.689 .491 .614 r
.4141 .89953 m .43494 .89892 L .42832 .91346 L p F P
0 g
s
.689 .491 .614 r
.42832 .91346 m .41556 .91383 L .4141 .89953 L p F P
0 g
s
.703 .501 .612 r
.40234 .89948 m .4141 .89953 L .41556 .91383 L p F P
0 g
s
.703 .501 .612 r
.41556 .91383 m .39664 .91375 L .40234 .89948 L p F P
0 g
s
.707 .506 .614 r
.38061 .89918 m .40234 .89948 L .39664 .91375 L p F P
0 g
s
.741 .571 .663 r
.31985 .86332 m .31075 .87841 L .33259 .88084 L p F P
0 g
s
.751 .583 .668 r
.30016 .86082 m .31985 .86332 L .31075 .87841 L p F P
0 g
s
.75 .601 .692 r
.29971 .85942 m .31004 .84499 L p .31985 .86332 L F P
0 g
s
.75 .601 .692 r
.31985 .86332 m .30016 .86082 L .29971 .85942 L p F P
0 g
s
.659 .488 .641 r
.47637 .89438 m .49018 .87953 L .47428 .8813 L closepath p F P
0 g
s
.675 .5 .641 r
.47428 .8813 m .47637 .89438 L .47472 .89644 L p F P
0 g
s
.809 .945 .913 r
.68161 .3924 m .679 .39438 L .68043 .39186 L closepath p F P
0 g
s
.79 .928 .926 r
.67558 .38895 m .68043 .39186 L .679 .39438 L p F P
0 g
s
.79 .928 .926 r
.65465 .40369 m .67558 .38895 L p .679 .39438 L F P
0 g
s
.79 .928 .926 r
.65191 .40841 m .65465 .40369 L p .679 .39438 L F P
0 g
s
.683 .604 .761 r
.44176 .77979 m .45908 .77018 L .43835 .77188 L closepath p F P
0 g
s
.799 .493 .472 r
.35876 .39989 m .37609 .4046 L .37387 .39427 L p F P
0 g
s
.799 .493 .472 r
.37387 .39427 m .35728 .38931 L .35876 .39989 L p F P
0 g
s
.664 .575 .745 r
.50641 .78608 m .5068 .78715 L .4812 .79983 L p F P
0 g
s
.664 .575 .745 r
.4812 .79983 m .4776 .79027 L .50641 .78608 L p F P
0 g
s
.707 .506 .614 r
.39664 .91375 m .38207 .91355 L .38061 .89918 L p F P
0 g
s
.72 .516 .612 r
.37398 .89888 m .38061 .89918 L .38207 .91355 L p F P
0 g
s
.625 .763 .945 r
.36256 .45476 m .37002 .46277 L .35662 .46628 L p F P
0 g
s
.625 .763 .945 r
.33751 .46245 m .36256 .45476 L p .35662 .46628 L F P
0 g
s
.625 .763 .945 r
.35662 .46628 m .33835 .46322 L .33751 .46245 L p F P
0 g
s
.819 .945 .906 r
.70438 .37441 m .68161 .3924 L .68043 .39186 L p F P
0 g
s
.744 .625 .726 r
.31862 .80916 m .31886 .80892 L .3185 .80887 L closepath p F P
0 g
s
.741 .639 .747 r
.31748 .7881 m .33875 .79082 L .31886 .80892 L p F P
0 g
s
.741 .639 .747 r
.3114 .79378 m .31748 .7881 L p .31886 .80892 L F P
0 g
s
.741 .639 .747 r
.31886 .80892 m .3185 .80887 L .3114 .79378 L p F P
0 g
s
.755 .604 .69 r
.29971 .85942 m .31004 .84499 L .29435 .84274 L closepath p F P
0 g
s
.752 .619 .712 r
.29274 .83851 m .3031 .82583 L p .31004 .84499 L F P
0 g
s
.752 .619 .712 r
.31004 .84499 m .29435 .84274 L .29274 .83851 L p F P
0 g
s
.753 .636 .731 r
.3185 .80887 m .31862 .80916 L .3031 .82583 L p F P
0 g
s
.948 .952 .733 r
.53663 .24977 m .5356 .2499 L .5368 .24797 L closepath p F P
0 g
s
.698 .631 .778 r
.42057 .77248 m .40625 .77281 L .40221 .76462 L p F P
0 g
s
.709 .636 .774 r
.40625 .77281 m .40221 .76462 L .39001 .77248 L closepath p F P
0 g
s
.753 .636 .731 r
.29898 .80581 m .3185 .80887 L p .3031 .82583 L F P
0 g
s
.749 .643 .743 r
.3185 .80887 m .3114 .79378 L .29898 .80581 L closepath p F P
0 g
s
.734 .644 .759 r
.33696 .77182 m .31748 .7881 L .33875 .79082 L p F P
0 g
s
.734 .644 .759 r
.33875 .79082 m .34418 .7864 L .33696 .77182 L p F P
0 g
s
.686 .487 .612 r
.43494 .89892 m .44604 .89851 L .4475 .91276 L p F P
0 g
s
.686 .487 .612 r
.4475 .91276 m .42832 .91346 L .43494 .89892 L p F P
0 g
s
.72 .516 .612 r
.38207 .91355 m .36892 .91297 L .37398 .89888 L p F P
0 g
s
.725 .522 .616 r
.34861 .89746 m .37398 .89888 L .36892 .91297 L p F P
0 g
s
.742 .554 .64 r
.34521 .89724 m .32568 .89536 L .33259 .88084 L p F P
0 g
s
.747 .562 .645 r
.31075 .87841 m .33259 .88084 L .32568 .89536 L p F P
0 g
s
.729 .638 .757 r
.36371 .77123 m .34418 .7864 L .33696 .77182 L p F P
0 g
s
.711 .642 .778 r
.39508 .75025 m .40221 .76462 L .39001 .77248 L p F P
0 g
s
.711 .642 .778 r
.36964 .76707 m .39508 .75025 L p .39001 .77248 L F P
0 g
s
.711 .642 .778 r
.39001 .77248 m .3721 .77185 L .36964 .76707 L p F P
0 g
s
.695 .625 .774 r
.43835 .77188 m .43473 .76427 L .42057 .77248 L closepath p F P
0 g
s
.698 .631 .778 r
.42767 .74946 m .43473 .76427 L .42057 .77248 L p F P
0 g
s
.698 .631 .778 r
.40221 .76462 m .42767 .74946 L p .42057 .77248 L F P
0 g
s
.904 .858 .785 r
.54795 .19955 m .5582 .185 L .56166 .19519 L p F P
0 g
s
.904 .858 .785 r
.54824 .20056 m .54795 .19955 L p .56166 .19519 L F P
0 g
s
.904 .858 .785 r
.56166 .19519 m .55428 .20521 L .54824 .20056 L p F P
0 g
s
.668 .594 .763 r
.49986 .7702 m .50641 .78608 L .4776 .79027 L p F P
0 g
s
.668 .594 .763 r
.4776 .79027 m .47424 .78229 L .49986 .7702 L p F P
0 g
s
.67 .476 .613 r
.44604 .89851 m .47472 .89644 L .46671 .91139 L p F P
0 g
s
.67 .476 .613 r
.46671 .91139 m .4475 .91276 L .44604 .89851 L p F P
0 g
s
.875 .967 .85 r
.72884 .34427 m .74468 .32748 L .74126 .33917 L p F P
0 g
s
.875 .967 .85 r
.72823 .34626 m .72884 .34427 L p .74126 .33917 L F P
0 g
s
.875 .967 .85 r
.74126 .33917 m .73293 .3478 L .72823 .34626 L p F P
0 g
s
.751 .902 .945 r
.62369 .42291 m .61275 .42922 L .61983 .42058 L closepath p F P
0 g
s
.739 .883 .946 r
.61733 .41881 m .61983 .42058 L .61275 .42922 L p F P
0 g
s
.739 .883 .946 r
.59134 .43298 m .61733 .41881 L p .61275 .42922 L F P
0 g
s
.647 .497 .665 r
.50199 .86951 m .51559 .85992 L .50049 .86224 L closepath p F P
0 g
s
.663 .509 .666 r
.50049 .86224 m .50199 .86951 L .49018 .87953 L p F P
0 g
s
.683 .62 .779 r
.45908 .77018 m .43835 .77188 L .43473 .76427 L p F P
0 g
s
.721 .647 .774 r
.3721 .77185 m .36964 .76707 L .36371 .77123 L closepath p F P
0 g
s
.811 .791 .834 r
.61296 .12184 m .59852 .13463 L .59196 .1263 L p F P
0 g
s
.856 .798 .792 r
.59433 .13948 m .59852 .13463 L .59196 .1263 L p F P
0 g
s
.87 .968 .855 r
.73293 .3478 m .72466 .35616 L .72823 .34626 L closepath p F P
0 g
s
.881 .934 .556 r
.51692 .2937 m .51361 .3002 L .51469 .29619 L closepath p F P
0 g
s
.757 .622 .71 r
.29274 .83851 m .3031 .82583 L .28684 .8232 L closepath p F P
0 g
s
.753 .636 .731 r
.28561 .82043 m .29898 .80581 L p .3031 .82583 L F P
0 g
s
.753 .636 .731 r
.3031 .82583 m .28684 .8232 L .28561 .82043 L p F P
0 g
s
.704 .872 .961 r
.56547 .44609 m .56401 .44676 L .56514 .44588 L closepath p F P
0 g
s
.698 .851 .955 r
.55882 .44114 m .56514 .44588 L .56401 .44676 L p F P
0 g
s
.698 .851 .955 r
.53297 .45249 m .55882 .44114 L p .56401 .44676 L F P
0 g
s
.583 .74 .951 r
.30517 .4599 m .32464 .4562 L .3368 .46258 L p F P
0 g
s
.596 .738 .943 r
.32464 .4562 m .30517 .4599 L .29744 .45281 L p F P
0 g
s
.817 .788 .825 r
.61296 .12184 m .62413 .11163 L .61767 .10284 L p F P
0 g
s
.817 .788 .825 r
.61767 .10284 m .6077 .1121 L .61296 .12184 L p F P
0 g
s
.811 .791 .834 r
.59196 .1263 m .6077 .1121 L .61296 .12184 L p F P
0 g
s
.764 .772 .859 r
.63946 .10118 m .62413 .11163 L .61767 .10284 L p F P
0 g
s
.482 .683 .955 r
.2417 .44184 m .23315 .44206 L .22518 .43417 L p F P
0 g
s
.84 .959 .887 r
.70736 .37181 m .70438 .37441 L .70584 .37121 L closepath p F P
0 g
s
.819 .945 .906 r
.70149 .36878 m .70584 .37121 L .70438 .37441 L p F P
0 g
s
.819 .945 .906 r
.6851 .38197 m .70149 .36878 L p .70438 .37441 L F P
0 g
s
.819 .945 .906 r
.68043 .39186 m .6851 .38197 L p .70438 .37441 L F P
0 g
s
.565 .283 .445 r
.44767 .39085 m .4469 .3965 L .44014 .39246 L closepath p F P
0 g
s
.562 .285 .454 r
.44641 .40083 m .4469 .3965 L .44014 .39246 L p F P
0 g
s
.562 .285 .454 r
.41866 .40704 m .44641 .40083 L p .44014 .39246 L F P
0 g
s
.848 .958 .881 r
.72466 .35616 m .70736 .37181 L .70584 .37121 L p F P
0 g
s
.95 .934 .744 r
.52886 .24952 m .5361 .23694 L .5368 .24797 L p F P
0 g
s
.95 .934 .744 r
.5368 .24797 m .5356 .2499 L .52886 .24952 L p F P
0 g
s
.848 .958 .881 r
.72726 .34575 m .72823 .34626 L .72466 .35616 L p F P
0 g
s
.848 .958 .881 r
.70922 .36236 m .72726 .34575 L p .72466 .35616 L F P
0 g
s
.848 .958 .881 r
.70584 .37121 m .70922 .36236 L p .72466 .35616 L F P
0 g
s
.165 0 .261 r
.49126 .34824 m .4928 .34316 L .48017 .35613 L p F P
0 g
s
.165 0 .261 r
.48894 .3533 m .49126 .34824 L p .48017 .35613 L F P
0 g
s
.165 0 .261 r
.47244 .36973 m .48894 .3533 L p .48017 .35613 L F P
0 g
s
.165 0 .261 r
.48017 .35613 m .4726 .36896 L .47244 .36973 L p F P
0 g
s
.727 .877 .951 r
.5848 .42848 m .59134 .43298 L .56547 .44609 L p F P
0 g
s
.727 .877 .951 r
.57904 .43141 m .5848 .42848 L p .56547 .44609 L F P
0 g
s
.727 .877 .951 r
.56547 .44609 m .56514 .44588 L .57904 .43141 L p F P
0 g
s
.856 .798 .792 r
.59196 .1263 m .58897 .12983 L .59433 .13948 L p F P
0 g
s
.854 .797 .794 r
.57548 .14555 m .58044 .15533 L .59433 .13948 L p F P
0 g
s
.854 .797 .794 r
.59433 .13948 m .58897 .12983 L .57548 .14555 L p F P
0 g
s
.729 .638 .757 r
.33696 .77182 m .34039 .7691 L .36371 .77123 L p F P
0 g
s
.722 .648 .775 r
.36243 .75323 m .34039 .7691 L .36371 .77123 L p F P
0 g
s
.722 .648 .775 r
.36371 .77123 m .36964 .76707 L .36243 .75323 L p F P
0 g
s
.661 .49 .643 r
.49018 .87953 m .50376 .87796 L p .47668 .89629 L F P
0 g
s
.661 .49 .643 r
.47668 .89629 m .47637 .89438 L .49018 .87953 L p F P
0 g
s
.661 .508 .665 r
.50376 .87796 m .50199 .86951 L .49018 .87953 L closepath p F P
0 g
s
.668 .593 .762 r
.49783 .76526 m .49986 .7702 L .47424 .78229 L p F P
0 g
s
.668 .593 .762 r
.47424 .78229 m .46881 .76931 L .49783 .76526 L p F P
0 g
s
.725 .522 .616 r
.346 .90482 m .34861 .89746 L p .36892 .91297 L F P
0 g
s
.73 .525 .614 r
.346 .90482 m .34861 .89746 L .34521 .89724 L closepath p F P
0 g
s
.913 .512 .202 r
.32254 .35769 m .33137 .36561 L .32811 .35584 L p F P
0 g
s
.913 .512 .202 r
.32811 .35584 m .31944 .34786 L .32254 .35769 L p F P
0 g
s
.76 .626 .061 r
.79115 .21153 m .79131 .22248 L .79163 .21135 L p F P
0 g
s
.76 .626 .061 r
.79163 .21135 m .79143 .2004 L .79115 .21153 L p F P
0 g
s
.521 .636 .904 r
.71537 .09302 m .72263 .09281 L .72644 .103 L p F P
0 g
s
.467 .588 .891 r
.74286 .09407 m .72263 .09281 L .72644 .103 L p F P
0 g
s
.467 .588 .891 r
.72644 .103 m .74904 .10501 L .74286 .09407 L p F P
0 g
s
.805 .919 .914 r
.68043 .39186 m .67558 .38895 L .6851 .38197 L closepath p F P
0 g
s
.979 .904 .666 r
.52981 .26137 m .5356 .2499 L .52886 .24952 L p F P
0 g
s
.701 .629 .773 r
.42767 .74946 m .40221 .76462 L .39508 .75025 L p F P
0 g
s
.717 .855 .947 r
.56514 .44588 m .55882 .44114 L .57904 .43141 L closepath p F P
0 g
s
.648 .499 .667 r
.50376 .87796 m .50199 .86951 L .51559 .85992 L p F P
0 g
s
.735 .529 .613 r
.34521 .89724 m .32568 .89536 L p .34375 .91149 L F P
0 g
s
.735 .529 .613 r
.34375 .91149 m .346 .90482 L .34521 .89724 L p F P
0 g
s
.93 .843 .735 r
.55428 .20521 m .55175 .20959 L .54824 .20056 L closepath p F P
0 g
s
.922 .935 .572 r
.77735 .28109 m .77662 .28265 L .77683 .28146 L closepath p F P
0 g
s
.715 .641 .773 r
.39508 .75025 m .36964 .76707 L .36243 .75323 L p F P
0 g
s
.903 .536 .329 r
.34241 .37172 m .34263 .37259 L .34167 .37191 L closepath p F P
0 g
s
.751 .583 .668 r
.31075 .87841 m .30443 .87762 L .30016 .86082 L p F P
0 g
s
.76 .588 .664 r
.29888 .86063 m .30016 .86082 L .30443 .87762 L p F P
0 g
s
.758 .605 .688 r
.30016 .86082 m .29971 .85942 L .29888 .86063 L closepath p F P
0 g
s
.758 .605 .688 r
.29888 .86063 m .29971 .85942 L .29435 .84274 L p F P
0 g
s
.758 .605 .688 r
.29435 .84274 m .28996 .842 L p .29888 .86063 L F P
0 g
s
.76 .623 .708 r
.29435 .84274 m .29274 .83851 L .28996 .842 L closepath p F P
0 g
s
.76 .588 .664 r
.30443 .87762 m .29049 .87552 L .29888 .86063 L p F P
0 g
s
.766 .595 .666 r
.27963 .85741 m .29888 .86063 L .29049 .87552 L p F P
0 g
s
.758 .605 .688 r
.28996 .842 m .27963 .85741 L .29888 .86063 L p F P
0 g
s
.938 .966 .701 r
.77016 .28541 m .76823 .29678 L .77662 .28265 L p F P
0 g
s
.938 .966 .701 r
.77218 .28191 m .77016 .28541 L p .77662 .28265 L F P
0 g
s
.938 .966 .701 r
.77662 .28265 m .77683 .28146 L .77218 .28191 L p F P
0 g
s
.905 .968 .809 r
.75607 .31877 m .75269 .31786 L .75778 .31166 L closepath p F P
0 g
s
.583 .749 .956 r
.33835 .46322 m .33751 .46245 L .3368 .46258 L closepath p F P
0 g
s
.683 .62 .779 r
.43473 .76427 m .46026 .75086 L p .45908 .77018 L F P
0 g
s
.686 .618 .774 r
.46026 .75086 m .43473 .76427 L .42767 .74946 L p F P
0 g
s
.771 .905 .934 r
.64338 .40276 m .64963 .40695 L .62369 .42291 L p F P
0 g
s
.771 .905 .934 r
.62314 .41543 m .64338 .40276 L p .62369 .42291 L F P
0 g
s
.771 .905 .934 r
.62369 .42291 m .61983 .42058 L .62314 .41543 L p F P
0 g
s
.672 .498 .641 r
.47668 .89629 m .47637 .89438 L .47472 .89644 L closepath p F P
0 g
s
.76 .624 .708 r
.28996 .842 m .29274 .83851 L .28684 .8232 L p F P
0 g
s
.682 .616 .776 r
.46881 .76931 m .46727 .76599 L .45908 .77018 L closepath p F P
0 g
s
.683 .62 .779 r
.46026 .75086 m .46727 .76599 L .45908 .77018 L p F P
0 g
s
.39 .133 .4 r
.44767 .39085 m .4469 .3965 L .45385 .38765 L closepath p F P
0 g
s
.662 .793 .944 r
.49342 .45142 m .49509 .45293 L .47079 .46308 L p F P
0 g
s
.662 .793 .944 r
.47079 .46308 m .46777 .46036 L .49342 .45142 L p F P
0 g
s
.243 .417 .836 r
.76728 .132 m .76143 .12875 L .75523 .11659 L p F P
0 g
s
.746 .642 .746 r
.3114 .79378 m .31748 .7881 L .30804 .78671 L closepath p F P
0 g
s
.741 .655 .765 r
.33532 .76854 m .33696 .77182 L .31748 .7881 L p F P
0 g
s
.741 .655 .765 r
.31935 .76626 m .33532 .76854 L p .31748 .7881 L F P
0 g
s
.741 .655 .765 r
.30411 .77928 m .31935 .76626 L p .31748 .7881 L F P
0 g
s
.741 .655 .765 r
.31748 .7881 m .30804 .78671 L .30411 .77928 L p F P
0 g
s
.747 .562 .645 r
.30634 .88782 m .31075 .87841 L p .32568 .89536 L F P
0 g
s
.752 .565 .643 r
.30634 .88782 m .31075 .87841 L .30443 .87762 L closepath p F P
0 g
s
.907 .557 .367 r
.33438 .37565 m .34453 .38293 L .34263 .37259 L p F P
0 g
s
.907 .557 .367 r
.34263 .37259 m .34167 .37191 L .33438 .37565 L p F P
0 g
s
.668 .473 .612 r
.47472 .89644 m .47668 .89629 L .47816 .91051 L p F P
0 g
s
.668 .473 .612 r
.47816 .91051 m .46671 .91139 L .47472 .89644 L p F P
0 g
s
.75 .644 .743 r
.29898 .80581 m .3114 .79378 L .30804 .78671 L p F P
0 g
s
.875 .926 .539 r
.51021 .30154 m .50707 .31354 L .51361 .3002 L p F P
0 g
s
.875 .926 .539 r
.51361 .3002 m .51469 .29619 L .51021 .30154 L p F P
0 g
s
.651 .461 .613 r
.47816 .91051 m .47668 .89629 L .50614 .89291 L p F P
0 g
s
.661 .49 .643 r
.50376 .87796 m .50614 .89291 L .47668 .89629 L p F P
0 g
s
.779 .903 .928 r
.65191 .40841 m .64963 .40695 L .65465 .40369 L closepath p F P
0 g
s
.64 .526 .708 r
.52068 .82719 m .53443 .821 L .51974 .82394 L closepath p F P
0 g
s
.644 .546 .729 r
.53443 .821 m .51974 .82394 L .51374 .80583 L p F P
0 g
s
.769 .615 .689 r
.27137 .83856 m .28996 .842 L .27963 .85741 L p F P
0 g
s
.76 .624 .708 r
.28366 .82261 m .27137 .83856 L .28996 .842 L p F P
0 g
s
.76 .624 .708 r
.28684 .8232 m .28366 .82261 L p .28996 .842 L F P
0 g
s
.587 .739 .948 r
.32992 .45509 m .32464 .4562 L .3368 .46258 L p F P
0 g
s
.587 .739 .948 r
.3368 .46258 m .33751 .46245 L .32992 .45509 L p F P
0 g
s
.932 .843 .734 r
.54052 .21308 m .54393 .22324 L .55175 .20959 L p F P
0 g
s
.932 .843 .734 r
.54759 .20006 m .54052 .21308 L p .55175 .20959 L F P
0 g
s
.932 .843 .734 r
.55175 .20959 m .54824 .20056 L .54759 .20006 L p F P
0 g
s
.771 .77 .852 r
.63946 .10118 m .64999 .09377 L .64361 .08462 L p F P
0 g
s
.771 .77 .852 r
.64361 .08462 m .6341 .09142 L .63946 .10118 L p F P
0 g
s
.764 .772 .859 r
.61767 .10284 m .6341 .09142 L .63946 .10118 L p F P
0 g
s
.759 .637 .725 r
.29898 .80581 m .28561 .82043 L .27836 .80432 L p F P
0 g
s
.759 .637 .725 r
.27836 .80432 m .28007 .8024 L .29898 .80581 L p F P
0 g
s
.75 .644 .743 r
.29775 .7849 m .28007 .8024 L .29898 .80581 L p F P
0 g
s
.75 .644 .743 r
.30804 .78671 m .29775 .7849 L p .29898 .80581 L F P
0 g
s
.853 .808 .806 r
.56638 .1559 m .57548 .14555 L .58044 .15533 L p F P
0 g
s
.853 .808 .806 r
.58044 .15533 m .57304 .16358 L .56638 .1559 L p F P
0 g
s
.641 .528 .71 r
.52481 .84132 m .52068 .82719 L .53443 .821 L p F P
0 g
s
.648 .499 .667 r
.51559 .85992 m .52895 .85783 L p .50376 .87796 L F P
0 g
s
.65 .518 .688 r
.52895 .85783 m .52765 .85271 L .51559 .85992 L closepath p F P
0 g
s
.651 .518 .688 r
.52481 .84132 m .52765 .85271 L .51559 .85992 L p F P
0 g
s
.64 .473 .641 r
.50614 .89291 m .50376 .87796 L .5322 .87353 L p F P
0 g
s
.648 .499 .667 r
.52895 .85783 m .5322 .87353 L .50376 .87796 L p F P
0 g
s
.929 .883 .467 r
.78496 .24696 m .78417 .2581 L .7883 .24552 L p F P
0 g
s
.929 .883 .467 r
.7883 .24552 m .78909 .23435 L .78496 .24696 L p F P
0 g
s
.667 .726 .893 r
.36256 .45476 m .33751 .46245 L .32992 .45509 L p F P
0 g
s
.88 .504 .325 r
.33428 .37559 m .33438 .37565 L .34167 .37191 L p F P
0 g
s
.88 .504 .325 r
.34167 .37191 m .33137 .36561 L .33428 .37559 L p F P
0 g
s
.627 .696 .894 r
.68249 .09023 m .70918 .08313 L .71537 .09302 L p F P
0 g
s
.632 .702 .896 r
.70918 .08313 m .68249 .09023 L .67622 .08085 L p F P
0 g
s
.708 .742 .878 r
.64999 .09377 m .67622 .08085 L .68249 .09023 L p F P
0 g
s
.644 .546 .729 r
.51374 .80583 m .51494 .80532 L p .53443 .821 L F P
0 g
s
.645 .545 .727 r
.51374 .80583 m .51494 .80532 L .51365 .80557 L closepath p F P
0 g
s
.648 .565 .747 r
.51494 .80532 m .51365 .80557 L .5068 .78715 L p F P
0 g
s
.946 .959 .69 r
.77683 .28146 m .77218 .28191 L .77818 .27138 L closepath p F P
0 g
s
.67 .61 .779 r
.4929 .75438 m .49783 .76526 L .46881 .76931 L p F P
0 g
s
.67 .61 .779 r
.46881 .76931 m .46727 .76599 L .4929 .75438 L p F P
0 g
s
.732 .645 .762 r
.33696 .77182 m .34039 .7691 L .33532 .76854 L closepath p F P
0 g
s
.684 .464 .582 r
.41556 .91383 m .42832 .91346 L .42547 .92706 L p F P
0 g
s
.684 .464 .582 r
.42547 .92706 m .41601 .92733 L .41556 .91383 L p F P
0 g
s
.699 .476 .581 r
.39664 .91375 m .41556 .91383 L .41601 .92733 L p F P
0 g
s
.756 .568 .642 r
.30443 .87762 m .29049 .87552 L p .30404 .89288 L F P
0 g
s
.756 .568 .642 r
.30404 .89288 m .30634 .88782 L .30443 .87762 L p F P
0 g
s
.644 .546 .729 r
.51494 .80532 m .54122 .80006 L p .53443 .821 L F P
0 g
s
.648 .565 .747 r
.54122 .80006 m .53951 .79544 L .51494 .80532 L closepath p F P
0 g
s
.648 .565 .747 r
.53406 .78059 m .53951 .79544 L .51494 .80532 L p F P
0 g
s
.648 .565 .747 r
.51208 .78496 m .53406 .78059 L p .51494 .80532 L F P
0 g
s
.648 .565 .747 r
.5068 .78715 m .51208 .78496 L p .51494 .80532 L F P
0 g
s
.699 .476 .581 r
.41601 .92733 m .39411 .92723 L .39664 .91375 L p F P
0 g
s
.704 .48 .582 r
.38207 .91355 m .39664 .91375 L .39411 .92723 L p F P
0 g
s
.728 .658 .78 r
.35934 .74736 m .36243 .75323 L .34039 .7691 L p F P
0 g
s
.728 .658 .78 r
.3464 .74598 m .35934 .74736 L p .34039 .7691 L F P
0 g
s
.728 .658 .78 r
.32968 .7583 m .3464 .74598 L p .34039 .7691 L F P
0 g
s
.728 .658 .78 r
.34039 .7691 m .33532 .76854 L .32968 .7583 L p F P
0 g
s
0 0 0 r
.49474 .34008 m .4928 .34316 L .4955 .33532 L p F P
0 g
s
0 0 0 r
.4955 .33532 m .50078 .32683 L .49474 .34008 L p F P
0 g
s
.699 .842 .951 r
.55882 .44114 m .53297 .45249 L .52616 .44723 L p F P
0 g
s
.679 .836 .959 r
.50039 .45743 m .52616 .44723 L .53297 .45249 L p F P
0 g
s
.635 .506 .689 r
.52765 .85271 m .52481 .84132 L .55231 .83581 L p F P
0 g
s
.641 .528 .71 r
.54726 .81842 m .55231 .83581 L .52481 .84132 L p F P
0 g
s
.641 .528 .71 r
.53443 .821 m .54726 .81842 L p .52481 .84132 L F P
0 g
s
.76 .639 .727 r
.28684 .8232 m .28561 .82043 L .28366 .82261 L closepath p F P
0 g
s
.704 .48 .582 r
.39411 .92723 m .38246 .92708 L .38207 .91355 L p F P
0 g
s
.718 .491 .581 r
.36892 .91297 m .38207 .91355 L .38246 .92708 L p F P
0 g
s
.861 .547 .455 r
.34567 .39362 m .35876 .39989 L .35728 .38931 L p F P
0 g
s
.861 .547 .455 r
.35728 .38931 m .34453 .38293 L .34567 .39362 L p F P
0 g
s
.832 .932 .896 r
.70584 .37121 m .70149 .36878 L .70922 .36236 L closepath p F P
0 g
s
.893 .809 .758 r
.56821 .17057 m .57304 .16358 L .56638 .1559 L p F P
0 g
s
.681 .461 .581 r
.42832 .91346 m .4475 .91276 L .44801 .92624 L p F P
0 g
s
.681 .461 .581 r
.44801 .92624 m .42547 .92706 L .42832 .91346 L p F P
0 g
s
.735 .529 .613 r
.32568 .89536 m .32108 .90931 L .34375 .91149 L p F P
0 g
s
.747 .54 .615 r
.30737 .89333 m .32568 .89536 L .32108 .90931 L p F P
0 g
s
.747 .562 .645 r
.32568 .89536 m .30737 .89333 L .30634 .88782 L p F P
0 g
s
.725 .522 .616 r
.36892 .91297 m .34674 .91174 L .346 .90482 L p F P
0 g
s
.737 .53 .614 r
.34674 .91174 m .346 .90482 L .34375 .91149 L closepath p F P
0 g
s
.685 .422 .518 r
.41866 .40704 m .3996 .4071 L .40036 .41804 L p F P
0 g
s
.718 .446 .513 r
.38364 .4167 m .40036 .41804 L .3996 .4071 L p F P
0 g
s
.718 .446 .513 r
.3996 .4071 m .38448 .40593 L .38364 .4167 L p F P
0 g
s
.671 .608 .776 r
.4929 .75438 m .46727 .76599 L .46026 .75086 L p F P
0 g
s
.749 .658 .76 r
.30804 .78671 m .30411 .77928 L .29775 .7849 L closepath p F P
0 g
s
.585 .337 .507 r
.44595 .41181 m .44641 .40083 L .41866 .40704 L p F P
0 g
s
.585 .337 .507 r
.41866 .40704 m .41808 .41798 L .44595 .41181 L p F P
0 g
s
.685 .422 .518 r
.40036 .41804 m .41808 .41798 L .41866 .40704 L p F P
0 g
s
.762 .641 .728 r
.28366 .82261 m .28561 .82043 L .27836 .80432 L p F P
0 g
s
0 0 .181 r
.79067 .18954 m .79143 .2004 L .78983 .19001 L p F P
0 g
s
0 0 .181 r
.78983 .19001 m .78906 .17915 L .79067 .18954 L p F P
0 g
s
.737 .661 .776 r
.33532 .76854 m .32968 .7583 L .31935 .76626 L closepath p F P
0 g
s
.711 .743 .877 r
.67622 .08085 m .64999 .09377 L .64361 .08462 L p F P
0 g
s
.696 .696 .846 r
.37002 .46277 m .39527 .45323 L .39473 .45242 L p F P
0 g
s
.696 .696 .846 r
.36256 .45476 m .37002 .46277 L p .39473 .45242 L F P
0 g
s
.672 .725 .889 r
.37002 .46277 m .39527 .45323 L .40258 .46218 L p F P
0 g
s
.771 .634 .709 r
.26566 .81895 m .28366 .82261 L .27137 .83856 L p F P
0 g
s
.762 .641 .728 r
.27836 .80432 m .26566 .81895 L .28366 .82261 L p F P
0 g
s
.354 .066 .329 r
.4726 .36896 m .47085 .37053 L .47244 .36973 L closepath p F P
0 g
s
.38 .107 .37 r
.47088 .37919 m .45385 .38765 L .47085 .37053 L p F P
0 g
s
.38 .107 .37 r
.47085 .37053 m .47244 .36973 L .47088 .37919 L p F P
0 g
s
.718 .491 .581 r
.38246 .92708 m .36661 .92638 L .36892 .91297 L p F P
0 g
s
.722 .496 .582 r
.34674 .91174 m .36892 .91297 L .36661 .92638 L p F P
0 g
s
.664 .448 .581 r
.4475 .91276 m .46671 .91139 L .46335 .92516 L p F P
0 g
s
.664 .448 .581 r
.46335 .92516 m .44801 .92624 L .4475 .91276 L p F P
0 g
s
.649 .565 .746 r
.5068 .78715 m .51208 .78496 L .50641 .78608 L closepath p F P
0 g
s
.652 .583 .765 r
.51208 .78496 m .50641 .78608 L .49986 .7702 L p F P
0 g
s
.636 .509 .691 r
.52895 .85783 m .52765 .85271 L .55346 .84047 L p F P
0 g
s
.635 .506 .689 r
.55231 .83581 m .55346 .84047 L .52765 .85271 L p F P
0 g
s
.671 .728 .892 r
.40258 .46218 m .42797 .45272 L .43516 .46152 L p F P
0 g
s
.689 .678 .834 r
.40258 .46218 m .42797 .45272 L .42719 .45148 L p F P
0 g
s
.689 .678 .834 r
.39527 .45323 m .40258 .46218 L p .42719 .45148 L F P
0 g
s
.979 .904 .666 r
.52886 .24952 m .52834 .25065 L .52981 .26137 L p F P
0 g
s
.981 .903 .658 r
.52254 .26369 m .52324 .27467 L .52981 .26137 L p F P
0 g
s
.981 .903 .658 r
.52981 .26137 m .52834 .25065 L .52254 .26369 L p F P
0 g
s
.867 .781 .283 r
.79122 .22511 m .79026 .22812 L .79131 .22248 L closepath p F P
0 g
s
.751 .477 .517 r
.3765 .41564 m .38364 .4167 L .38448 .40593 L p F P
0 g
s
.751 .477 .517 r
.38448 .40593 m .37609 .4046 L .3765 .41564 L p F P
0 g
s
.082 0 .267 r
.48387 .36631 m .47088 .37919 L .47244 .36973 L p F P
0 g
s
.082 0 .267 r
.47244 .36973 m .48894 .3533 L .48387 .36631 L p F P
0 g
s
.701 .629 .773 r
.4274 .74889 m .42767 .74946 L p .39508 .75025 L F P
0 g
s
.701 .629 .773 r
.39508 .75025 m .39673 .74925 L .4274 .74889 L p F P
0 g
s
.704 .636 .778 r
.39508 .75025 m .39673 .74925 L .39458 .74924 L closepath p F P
0 g
s
.715 .641 .773 r
.39458 .74924 m .39508 .75025 L p .36243 .75323 L F P
0 g
s
.757 .568 .642 r
.30737 .89333 m .30634 .88782 L .30404 .89288 L closepath p F P
0 g
s
.422 .172 .427 r
.46972 .38922 m .47088 .37919 L .45385 .38765 L p F P
0 g
s
.422 .172 .427 r
.44641 .40083 m .46972 .38922 L p .45385 .38765 L F P
0 g
s
.422 .172 .427 r
.45385 .38765 m .4469 .3965 L .44641 .40083 L p F P
0 g
s
.893 .809 .758 r
.56638 .1559 m .563 .16091 L .56821 .17057 L p F P
0 g
s
.893 .809 .758 r
.55331 .17525 m .5582 .185 L .56821 .17057 L p F P
0 g
s
.893 .809 .758 r
.56821 .17057 m .563 .16091 L .55331 .17525 L p F P
0 g
s
.54 .721 .957 r
.26517 .44836 m .28966 .4454 L .29744 .45281 L p F P
0 g
s
.544 .715 .951 r
.28966 .4454 m .26517 .44836 L .25729 .44072 L p F P
0 g
s
.677 .813 .948 r
.51928 .44152 m .52616 .44723 L .50039 .45743 L p F P
0 g
s
.677 .813 .948 r
.50394 .44746 m .51928 .44152 L p .50039 .45743 L F P
0 g
s
.677 .813 .948 r
.50039 .45743 m .49509 .45293 L .50394 .44746 L p F P
0 g
s
.482 .683 .955 r
.22518 .43417 m .23329 .43394 L .2417 .44184 L p F P
0 g
s
.514 .696 .951 r
.24937 .43275 m .23329 .43394 L .2417 .44184 L p F P
0 g
s
.514 .696 .951 r
.2417 .44184 m .25729 .44072 L .24937 .43275 L p F P
0 g
s
.629 .484 .667 r
.5322 .87353 m .52895 .85783 L .55644 .85232 L p F P
0 g
s
.636 .509 .691 r
.55346 .84047 m .55644 .85232 L .52895 .85783 L p F P
0 g
s
.699 .643 .79 r
.4274 .74889 m .42056 .73587 L .39673 .74925 L closepath p F P
0 g
s
.701 .649 .795 r
.41405 .72353 m .42056 .73587 L .39673 .74925 L p F P
0 g
s
.701 .649 .795 r
.41136 .72353 m .41405 .72353 L p .39673 .74925 L F P
0 g
s
.701 .649 .795 r
.3879 .73703 m .41136 .72353 L p .39673 .74925 L F P
0 g
s
.701 .649 .795 r
.39673 .74925 m .39458 .74924 L .3879 .73703 L p F P
0 g
s
.715 .641 .773 r
.36243 .75323 m .37007 .74807 L .39458 .74924 L p F P
0 g
s
.712 .654 .79 r
.39458 .74924 m .3879 .73703 L .37007 .74807 L closepath p F P
0 g
s
.66 .759 .923 r
.43516 .46152 m .46068 .45284 L .46777 .46036 L p F P
0 g
s
.667 .707 .877 r
.43516 .46152 m .46068 .45284 L .45506 .44532 L p F P
0 g
s
.667 .707 .877 r
.42797 .45272 m .43516 .46152 L p .45506 .44532 L F P
0 g
s
.93 .966 .761 r
.75983 .30029 m .75778 .31166 L .76823 .29678 L p F P
0 g
s
.93 .966 .761 r
.76823 .29678 m .77016 .28541 L .75983 .30029 L p F P
0 g
s
.686 .618 .774 r
.45831 .74667 m .46026 .75086 L p .42767 .74946 L F P
0 g
s
.686 .618 .774 r
.42767 .74946 m .4289 .7488 L .45831 .74667 L p F P
0 g
s
.688 .623 .778 r
.42767 .74946 m .4289 .7488 L .4274 .74889 L closepath p F P
0 g
s
.383 .523 .873 r
.75166 .11567 m .74927 .10545 L .75523 .11659 L closepath p F P
0 g
s
.718 .648 .779 r
.36243 .75323 m .37007 .74807 L .35934 .74736 L closepath p F P
0 g
s
.687 .638 .795 r
.4289 .7488 m .4274 .74889 L .42056 .73587 L p F P
0 g
s
.722 .496 .582 r
.36661 .92638 m .34707 .92531 L .34674 .91174 L p F P
0 g
s
.735 .506 .582 r
.34375 .91149 m .34674 .91174 L .34707 .92531 L p F P
0 g
s
.756 .568 .642 r
.29049 .87552 m .28416 .88989 L .30404 .89288 L p F P
0 g
s
.768 .582 .646 r
.27133 .87229 m .29049 .87552 L .28416 .88989 L p F P
0 g
s
.766 .595 .666 r
.29049 .87552 m .27133 .87229 L .27963 .85741 L p F P
0 g
s
.771 .603 .67 r
.26115 .85395 m .27963 .85741 L .27133 .87229 L p F P
0 g
s
.769 .615 .689 r
.27963 .85741 m .26115 .85395 L .27137 .83856 L p F P
0 g
s
.66 .767 .929 r
.49342 .45142 m .46777 .46036 L .46068 .45284 L p F P
0 g
s
.526 .644 .908 r
.72263 .09281 m .71537 .09302 L .70918 .08313 L p F P
0 g
s
.685 .633 .791 r
.45831 .74667 m .45322 .73664 L .4289 .7488 L closepath p F P
0 g
s
.687 .638 .795 r
.44614 .72276 m .45322 .73664 L .4289 .7488 L p F P
0 g
s
.687 .638 .795 r
.42056 .73587 m .44614 .72276 L p .4289 .7488 L F P
0 g
s
.652 .582 .764 r
.53406 .78059 m .53257 .77694 L .51208 .78496 L closepath p F P
0 g
s
.652 .583 .765 r
.52564 .75985 m .53257 .77694 L .51208 .78496 L p F P
0 g
s
.652 .583 .765 r
.49986 .7702 m .52564 .75985 L p .51208 .78496 L F P
0 g
s
.758 .657 .75 r
.2794 .78127 m .29775 .7849 L .28007 .8024 L p F P
0 g
s
.75 .661 .762 r
.29676 .76557 m .2794 .78127 L .29775 .7849 L p F P
0 g
s
.75 .661 .762 r
.29775 .7849 m .30411 .77928 L .29676 .76557 L p F P
0 g
s
0 0 .425 r
.78774 .16838 m .78906 .17915 L .78539 .16957 L p F P
0 g
s
0 0 .425 r
.78539 .16957 m .78404 .15881 L .78774 .16838 L p F P
0 g
s
.883 .926 .54 r
.51027 .30132 m .51021 .30154 L .51469 .29619 L p F P
0 g
s
.883 .926 .54 r
.51469 .29619 m .51674 .28798 L .51027 .30132 L p F P
0 g
s
.644 .546 .729 r
.54122 .80006 m .54646 .81601 L .53443 .821 L p F P
0 g
s
.644 .547 .73 r
.54726 .81842 m .54646 .81601 L .53443 .821 L closepath p F P
0 g
s
.747 .656 .76 r
.31935 .76626 m .30411 .77928 L .29676 .76557 L p F P
0 g
s
.735 .506 .582 r
.34707 .92531 m .34158 .92485 L .34375 .91149 L p F P
0 g
s
.74 .511 .582 r
.32108 .90931 m .34375 .91149 L .34158 .92485 L p F P
0 g
s
.747 .54 .615 r
.32108 .90931 m .30898 .90799 L .30737 .89333 L p F P
0 g
s
.757 .548 .613 r
.30404 .89288 m .30737 .89333 L .30898 .90799 L p F P
0 g
s
.661 .445 .58 r
.46671 .91139 m .47816 .91051 L .47873 .92397 L p F P
0 g
s
.661 .445 .58 r
.47873 .92397 m .46335 .92516 L .46671 .91139 L p F P
0 g
s
.792 .517 .521 r
.35874 .41107 m .3765 .41564 L .37609 .4046 L p F P
0 g
s
.792 .517 .521 r
.37609 .4046 m .35876 .39989 L .35874 .41107 L p F P
0 g
s
.779 .897 .926 r
.65465 .40369 m .64963 .40695 L .64338 .40276 L p F P
0 g
s
.946 .856 .72 r
.53325 .2266 m .5361 .23694 L .54393 .22324 L p F P
0 g
s
.946 .856 .72 r
.54393 .22324 m .54052 .21308 L .53325 .2266 L p F P
0 g
s
.747 .656 .76 r
.29676 .76557 m .29973 .76297 L .31935 .76626 L p F P
0 g
s
.738 .664 .777 r
.32234 .74516 m .29973 .76297 L .31935 .76626 L p F P
0 g
s
.738 .664 .777 r
.31935 .76626 m .32968 .7583 L .32234 .74516 L p F P
0 g
s
.634 .447 .613 r
.50614 .89291 m .53463 .8885 L p .52128 .90505 L F P
0 g
s
.634 .447 .613 r
.52128 .90505 m .50768 .90714 L .50614 .89291 L p F P
0 g
s
.64 .473 .641 r
.5322 .87353 m .53463 .8885 L .50614 .89291 L p F P
0 g
s
.651 .461 .613 r
.50614 .89291 m .50768 .90714 L .47816 .91051 L p F P
0 g
s
.763 .644 .729 r
.27836 .80432 m .28007 .8024 L .27722 .80183 L closepath p F P
0 g
s
.758 .657 .75 r
.271 .78976 m .2794 .78127 L p .28007 .8024 L F P
0 g
s
.758 .657 .75 r
.28007 .8024 m .27722 .80183 L .271 .78976 L p F P
0 g
s
.715 .661 .795 r
.38067 .72393 m .3879 .73703 L .37007 .74807 L p F P
0 g
s
.715 .661 .795 r
.35517 .74009 m .38067 .72393 L p .37007 .74807 L F P
0 g
s
.715 .661 .795 r
.37007 .74807 m .35934 .74736 L .35517 .74009 L p F P
0 g
s
.757 .548 .613 r
.30898 .90799 m .29976 .90674 L .30404 .89288 L p F P
0 g
s
.763 .554 .614 r
.28416 .88989 m .30404 .89288 L .29976 .90674 L p F P
0 g
s
.774 .623 .693 r
.25354 .83486 m .27137 .83856 L .26115 .85395 L p F P
0 g
s
.771 .634 .709 r
.27137 .83856 m .25354 .83486 L .26566 .81895 L p F P
0 g
s
.745 .872 .939 r
.61733 .41881 m .59134 .43298 L .5848 .42848 L p F P
0 g
s
.866 .913 .509 r
.50517 .31422 m .50078 .32683 L .50707 .31354 L p F P
0 g
s
.866 .913 .509 r
.51009 .30171 m .50517 .31422 L p .50707 .31354 L F P
0 g
s
.866 .913 .509 r
.50707 .31354 m .51021 .30154 L .51009 .30171 L p F P
0 g
s
.766 .645 .727 r
.26566 .81895 m .27836 .80432 L .27722 .80183 L p F P
0 g
s
.653 .583 .764 r
.52562 .75981 m .52564 .75985 L .49986 .7702 L p F P
0 g
s
.653 .583 .764 r
.49986 .7702 m .49783 .76526 L .52562 .75981 L p F P
0 g
s
.8 .919 .918 r
.65465 .40369 m .67558 .38895 L .66947 .3851 L p F P
0 g
s
.8 .919 .918 r
.66947 .3851 m .66099 .39116 L .65465 .40369 L p F P
0 g
s
.779 .897 .926 r
.64338 .40276 m .66099 .39116 L .65465 .40369 L p F P
0 g
s
0 .074 .628 r
.78217 .14814 m .78404 .15881 L .77802 .15017 L p F P
0 g
s
0 .074 .628 r
.77802 .15017 m .77609 .13952 L .78217 .14814 L p F P
0 g
s
.243 .417 .836 r
.75523 .11659 m .76471 .12149 L .76728 .132 L p F P
0 g
s
.073 .279 .766 r
.77364 .12896 m .77609 .13952 L .76728 .132 L p F P
0 g
s
.073 .279 .766 r
.76728 .132 m .76471 .12149 L .77364 .12896 L p F P
0 g
s
.884 .791 .301 r
.78905 .22338 m .79115 .21153 L .79131 .22248 L p F P
0 g
s
.884 .791 .301 r
.78915 .23136 m .78905 .22338 L p .79131 .22248 L F P
0 g
s
.884 .791 .301 r
.79131 .22248 m .79026 .22812 L .78915 .23136 L p F P
0 g
s
.644 .431 .58 r
.47873 .92397 m .47816 .91051 L .50768 .90714 L p F P
0 g
s
.671 .608 .776 r
.48766 .74282 m .4929 .75438 L p .46026 .75086 L F P
0 g
s
.671 .608 .776 r
.46026 .75086 m .47348 .74472 L .48766 .74282 L p F P
0 g
s
.672 .612 .779 r
.46026 .75086 m .47348 .74472 L .45831 .74667 L closepath p F P
0 g
s
.766 .645 .727 r
.27722 .80183 m .2625 .79855 L p .26566 .81895 L F P
0 g
s
.765 .659 .746 r
.27722 .80183 m .271 .78976 L .2625 .79855 L closepath p F P
0 g
s
.733 .659 .776 r
.3464 .74598 m .32968 .7583 L .32234 .74516 L p F P
0 g
s
.724 .665 .791 r
.35934 .74736 m .35517 .74009 L .3464 .74598 L closepath p F P
0 g
s
.656 .601 .781 r
.51869 .74432 m .52562 .75981 L .49783 .76526 L p F P
0 g
s
.656 .601 .781 r
.49783 .76526 m .4929 .75438 L .51869 .74432 L p F P
0 g
s
.958 .933 .606 r
.77902 .26025 m .77818 .27138 L .78417 .2581 L p F P
0 g
s
.958 .933 .606 r
.78417 .2581 m .78496 .24696 L .77902 .26025 L p F P
0 g
s
.216 .418 .845 r
.74927 .10545 m .75523 .11659 L .76471 .12149 L p F P
0 g
s
.623 .461 .642 r
.5322 .87353 m .55973 .86805 L p .53624 .88818 L F P
0 g
s
.623 .461 .642 r
.53624 .88818 m .53463 .8885 L .5322 .87353 L p F P
0 g
s
.629 .484 .667 r
.55644 .85232 m .55973 .86805 L .5322 .87353 L p F P
0 g
s
.756 .881 .935 r
.61983 .42058 m .61733 .41881 L .62314 .41543 L closepath p F P
0 g
s
.672 .628 .796 r
.47348 .74472 m .45831 .74667 L .45322 .73664 L p F P
0 g
s
.895 .816 .762 r
.54343 .18968 m .54795 .19955 L .5582 .185 L p F P
0 g
s
.895 .816 .762 r
.5582 .185 m .55331 .17525 L .54343 .18968 L p F P
0 g
s
.907 .963 .812 r
.74728 .31597 m .75983 .30029 L .75778 .31166 L p F P
0 g
s
.907 .963 .812 r
.74725 .31617 m .74728 .31597 L p .75778 .31166 L F P
0 g
s
.907 .963 .812 r
.75778 .31166 m .75269 .31786 L .74725 .31617 L p F P
0 g
s
.775 .642 .714 r
.24843 .81502 m .26566 .81895 L .25354 .83486 L p F P
0 g
s
.766 .645 .727 r
.2625 .79855 m .24843 .81502 L .26566 .81895 L p F P
0 g
s
.808 .777 .825 r
.6077 .1121 m .59196 .1263 L .58534 .11732 L p F P
0 g
s
.85 .784 .786 r
.58897 .12983 m .59196 .1263 L .58534 .11732 L p F P
0 g
s
.764 .764 .853 r
.6341 .09142 m .61767 .10284 L .61114 .09365 L p F P
0 g
s
.813 .777 .819 r
.6077 .1121 m .61767 .10284 L .61114 .09365 L p F P
0 g
s
.813 .777 .819 r
.61114 .09365 m .60154 .10262 L .6077 .1121 L p F P
0 g
s
.808 .777 .825 r
.58534 .11732 m .60154 .10262 L .6077 .1121 L p F P
0 g
s
.596 .738 .943 r
.29744 .45281 m .31352 .44938 L .32464 .4562 L p F P
0 g
s
.608 .737 .936 r
.31352 .44938 m .29744 .45281 L .28966 .4454 L p F P
0 g
s
.74 .511 .582 r
.34158 .92485 m .31886 .92267 L .32108 .90931 L p F P
0 g
s
.745 .516 .583 r
.30898 .90799 m .32108 .90931 L .31886 .92267 L p F P
0 g
s
.921 .535 .248 r
.32528 .36772 m .33428 .37559 L .33137 .36561 L p F P
0 g
s
.921 .535 .248 r
.33137 .36561 m .32254 .35769 L .32528 .36772 L p F P
0 g
s
.597 .734 .94 r
.32227 .44738 m .31352 .44938 L .32464 .4562 L p F P
0 g
s
.597 .734 .94 r
.32464 .4562 m .32992 .45509 L .32227 .44738 L p F P
0 g
s
.677 .431 .542 r
.41601 .92733 m .42547 .92706 L .42665 .93966 L p F P
0 g
s
.677 .431 .542 r
.42665 .93966 m .41537 .93998 L .41601 .92733 L p F P
0 g
s
.693 .445 .543 r
.39411 .92723 m .41601 .92733 L .41537 .93998 L p F P
0 g
s
.849 .783 .788 r
.56934 .13613 m .57548 .14555 L .58897 .12983 L p F P
0 g
s
.849 .783 .788 r
.58897 .12983 m .58273 .12041 L .56934 .13613 L p F P
0 g
s
.85 .784 .786 r
.58534 .11732 m .58273 .12041 L .58897 .12983 L p F P
0 g
s
.693 .445 .543 r
.41537 .93998 m .39498 .93989 L .39411 .92723 L p F P
0 g
s
.698 .448 .542 r
.38246 .92708 m .39411 .92723 L .39498 .93989 L p F P
0 g
s
.733 .659 .776 r
.32234 .74516 m .32492 .74322 L .3464 .74598 L p F P
0 g
s
.726 .668 .793 r
.34786 .72751 m .32492 .74322 L .3464 .74598 L p F P
0 g
s
.726 .668 .793 r
.3464 .74598 m .35517 .74009 L .34786 .72751 L p F P
0 g
s
.624 .517 .712 r
.55231 .83581 m .54726 .81842 L .57383 .81175 L p F P
0 g
s
.629 .538 .733 r
.57245 .80758 m .57383 .81175 L .54726 .81842 L p F P
0 g
s
.629 .538 .733 r
.54726 .81842 m .54646 .81601 L .57245 .80758 L p F P
0 g
s
.98 .916 .633 r
.5169 .27671 m .51674 .28798 L .52324 .27467 L p F P
0 g
s
.98 .916 .633 r
.52324 .27467 m .52254 .26369 L .5169 .27671 L p F P
0 g
s
.629 .536 .731 r
.56779 .79334 m .57245 .80758 L .54646 .81601 L p F P
0 g
s
.629 .536 .731 r
.54646 .81601 m .54122 .80006 L .56779 .79334 L p F P
0 g
s
.698 .448 .542 r
.39498 .93989 m .3817 .93971 L .38246 .92708 L p F P
0 g
s
.713 .461 .543 r
.36661 .92638 m .38246 .92708 L .3817 .93971 L p F P
0 g
s
.673 .428 .542 r
.42547 .92706 m .44801 .92624 L .4475 .93891 L p F P
0 g
s
.673 .428 .542 r
.4475 .93891 m .42665 .93966 L .42547 .92706 L p F P
0 g
s
.904 .964 .815 r
.75269 .31786 m .74468 .32748 L .74725 .31617 L closepath p F P
0 g
s
.633 .557 .75 r
.56549 .78707 m .56779 .79334 L .54122 .80006 L p F P
0 g
s
.633 .557 .75 r
.54122 .80006 m .53951 .79544 L .56549 .78707 L p F P
0 g
s
.806 .912 .912 r
.6851 .38197 m .67558 .38895 L .66947 .3851 L p F P
0 g
s
.705 .649 .791 r
.41136 .72353 m .3879 .73703 L .38067 .72393 L p F P
0 g
s
.911 .588 .421 r
.33529 .38633 m .34567 .39362 L .34453 .38293 L p F P
0 g
s
.911 .588 .421 r
.33431 .37574 m .33529 .38633 L p .34453 .38293 L F P
0 g
s
.911 .588 .421 r
.34453 .38293 m .33438 .37565 L .33431 .37574 L p F P
0 g
s
.526 .644 .908 r
.70918 .08313 m .71832 .08271 L .72263 .09281 L p F P
0 g
s
.475 .603 .899 r
.73667 .08346 m .71832 .08271 L .72263 .09281 L p F P
0 g
s
.475 .603 .899 r
.72263 .09281 m .74286 .09407 L .73667 .08346 L p F P
0 g
s
.768 .582 .646 r
.26582 .88483 m .27133 .87229 L p .28416 .88989 L F P
0 g
s
.774 .585 .645 r
.26582 .88483 m .27133 .87229 L .26287 .87072 L closepath p F P
0 g
s
.771 .603 .67 r
.25916 .85761 m .26115 .85395 L p .27133 .87229 L F P
0 g
s
.771 .603 .67 r
.27133 .87229 m .26287 .87072 L .25916 .85761 L p F P
0 g
s
.633 .555 .749 r
.56065 .77382 m .56549 .78707 L .53951 .79544 L p F P
0 g
s
.633 .555 .749 r
.53951 .79544 m .53406 .78059 L .56065 .77382 L p F P
0 g
s
.448 .227 .485 r
.46931 .40018 m .46972 .38922 L .44641 .40083 L p F P
0 g
s
.448 .227 .485 r
.44641 .40083 m .44595 .41181 L .46931 .40018 L p F P
0 g
s
.881 .791 .3 r
.79026 .22812 m .78909 .23435 L .78915 .23136 L closepath p F P
0 g
s
.69 .64 .795 r
.44569 .72188 m .44614 .72276 L .42056 .73587 L p F P
0 g
s
.69 .64 .795 r
.42056 .73587 m .41405 .72353 L .44569 .72188 L p F P
0 g
s
.777 .607 .668 r
.25916 .85761 m .26115 .85395 L .25793 .85328 L closepath p F P
0 g
s
.774 .623 .693 r
.25212 .83706 m .25354 .83486 L p .26115 .85395 L F P
0 g
s
.774 .623 .693 r
.26115 .85395 m .25793 .85328 L .25212 .83706 L p F P
0 g
s
.617 .494 .689 r
.55346 .84047 m .55231 .83581 L .5789 .82919 L p F P
0 g
s
.624 .517 .712 r
.57383 .81175 m .5789 .82919 L .55231 .83581 L p F P
0 g
s
.859 .943 .873 r
.72823 .34626 m .72726 .34575 L .72884 .34427 L closepath p F P
0 g
s
.713 .461 .543 r
.3817 .93971 m .36724 .93908 L .36661 .92638 L p F P
0 g
s
.718 .465 .543 r
.34707 .92531 m .36661 .92638 L .36724 .93908 L p F P
0 g
s
.657 .601 .781 r
.51562 .73744 m .51869 .74432 L .4929 .75438 L p F P
0 g
s
.657 .601 .781 r
.4929 .75438 m .48766 .74282 L .51562 .73744 L p F P
0 g
s
.764 .661 .749 r
.271 .78976 m .2794 .78127 L .26484 .77801 L closepath p F P
0 g
s
.758 .673 .768 r
.29483 .76204 m .29676 .76557 L .2794 .78127 L p F P
0 g
s
.758 .673 .768 r
.28165 .75919 m .29483 .76204 L p .2794 .78127 L F P
0 g
s
.758 .673 .768 r
.26357 .77582 m .28165 .75919 L p .2794 .78127 L F P
0 g
s
.758 .673 .768 r
.2794 .78127 m .26484 .77801 L .26357 .77582 L p F P
0 g
s
.719 .661 .791 r
.38067 .72393 m .35517 .74009 L .34786 .72751 L p F P
0 g
s
.656 .413 .541 r
.44801 .92624 m .46335 .92516 L .46498 .93768 L p F P
0 g
s
.656 .413 .541 r
.46498 .93768 m .4475 .93891 L .44801 .92624 L p F P
0 g
s
.751 .663 .765 r
.29676 .76557 m .29973 .76297 L .29483 .76204 L closepath p F P
0 g
s
.745 .675 .783 r
.32089 .74261 m .32234 .74516 L .29973 .76297 L p F P
0 g
s
.745 .675 .783 r
.30554 .73979 m .32089 .74261 L p .29973 .76297 L F P
0 g
s
.745 .675 .783 r
.28931 .75283 m .30554 .73979 L p .29973 .76297 L F P
0 g
s
.745 .675 .783 r
.29973 .76297 m .29483 .76204 L .28931 .75283 L p F P
0 g
s
.718 .846 .943 r
.57904 .43141 m .55882 .44114 L .55209 .43585 L p F P
0 g
s
.699 .842 .951 r
.52616 .44723 m .55209 .43585 L .55882 .44114 L p F P
0 g
s
.763 .554 .614 r
.29976 .90674 m .27987 .90375 L .28416 .88989 L p F P
0 g
s
.769 .56 .616 r
.26625 .88688 m .28416 .88989 L .27987 .90375 L p F P
0 g
s
.768 .582 .646 r
.28416 .88989 m .26625 .88688 L .26582 .88483 L p F P
0 g
s
.745 .516 .583 r
.31886 .92267 m .30929 .92164 L .30898 .90799 L p F P
0 g
s
.757 .525 .582 r
.29976 .90674 m .30898 .90799 L .30929 .92164 L p F P
0 g
s
.952 .892 .734 r
.52595 .24017 m .53325 .2266 L .5361 .23694 L p F P
0 g
s
.952 .892 .734 r
.52789 .24921 m .52595 .24017 L p .5361 .23694 L F P
0 g
s
.952 .892 .734 r
.5361 .23694 m .52886 .24952 L .52789 .24921 L p F P
0 g
s
.671 .624 .793 r
.48766 .74282 m .48591 .73928 L .47348 .74472 L closepath p F P
0 g
s
.672 .628 .796 r
.4789 .72518 m .48591 .73928 L .47348 .74472 L p F P
0 g
s
.672 .628 .796 r
.45322 .73664 m .4789 .72518 L p .47348 .74472 L F P
0 g
s
.829 .932 .898 r
.6851 .38197 m .70149 .36878 L .69552 .36524 L p F P
0 g
s
.829 .932 .898 r
.69552 .36524 m .68984 .3699 L .6851 .38197 L p F P
0 g
s
.806 .912 .912 r
.66947 .3851 m .68984 .3699 L .6851 .38197 L p F P
0 g
s
.909 .856 .777 r
.54824 .20056 m .54759 .20006 L .54795 .19955 L closepath p F P
0 g
s
.618 .496 .691 r
.55644 .85232 m .55346 .84047 L .57949 .83157 L p F P
0 g
s
.617 .494 .689 r
.5789 .82919 m .57949 .83157 L .55346 .84047 L p F P
0 g
s
.879 .944 .852 r
.73167 .33273 m .72884 .34427 L .74468 .32748 L p F P
0 g
s
.879 .944 .852 r
.74715 .31612 m .73167 .33273 L p .74468 .32748 L F P
0 g
s
.879 .944 .852 r
.74468 .32748 m .74725 .31617 L .74715 .31612 L p F P
0 g
s
.767 .662 .747 r
.2625 .79855 m .271 .78976 L .26484 .77801 L p F P
0 g
s
.815 .659 .11 r
.7904 .20069 m .79115 .21153 L .79143 .2004 L p F P
0 g
s
.815 .659 .11 r
.79143 .2004 m .79067 .18954 L .7904 .20069 L p F P
0 g
s
.697 .479 .587 r
.41808 .41798 m .40036 .41804 L .39596 .43085 L p F P
0 g
s
.728 .512 .597 r
.38496 .42993 m .39596 .43085 L .40036 .41804 L p F P
0 g
s
.728 .512 .597 r
.40036 .41804 m .38364 .4167 L .38496 .42993 L p F P
0 g
s
.855 .572 .509 r
.34558 .40483 m .35874 .41107 L .35876 .39989 L p F P
0 g
s
.855 .572 .509 r
.35876 .39989 m .34567 .39362 L .34558 .40483 L p F P
0 g
s
.632 .702 .896 r
.67622 .08085 m .70295 .07334 L .70918 .08313 L p F P
0 g
s
.635 .707 .898 r
.70295 .07334 m .67622 .08085 L .66989 .07142 L p F P
0 g
s
.711 .743 .877 r
.64361 .08462 m .66989 .07142 L .67622 .08085 L p F P
0 g
s
.609 .412 .59 r
.44654 .42163 m .44595 .41181 L .41808 .41798 L p F P
0 g
s
.609 .412 .59 r
.44313 .4252 m .44654 .42163 L p .41808 .41798 L F P
0 g
s
.609 .412 .59 r
.41808 .41798 m .41907 .43075 L .44313 .4252 L p F P
0 g
s
.697 .479 .587 r
.39596 .43085 m .41907 .43075 L .41808 .41798 L p F P
0 g
s
.779 .608 .667 r
.25793 .85328 m .24386 .85011 L p .25325 .86872 L F P
0 g
s
.779 .608 .667 r
.25325 .86872 m .25916 .85761 L .25793 .85328 L p F P
0 g
s
.781 .626 .689 r
.25793 .85328 m .25212 .83706 L .24386 .85011 L closepath p F P
0 g
s
.769 .764 .848 r
.6341 .09142 m .64361 .08462 L .63716 .07526 L p F P
0 g
s
.769 .764 .848 r
.63716 .07526 m .62798 .08188 L .6341 .09142 L p F P
0 g
s
.764 .764 .853 r
.61114 .09365 m .62798 .08188 L .6341 .09142 L p F P
0 g
s
.637 .575 .768 r
.55855 .76861 m .56065 .77382 L .53406 .78059 L p F P
0 g
s
.637 .575 .768 r
.53406 .78059 m .53257 .77694 L .55855 .76861 L p F P
0 g
s
.779 .607 .667 r
.26287 .87072 m .25916 .85761 L .25325 .86872 L closepath p F P
0 g
s
.846 .787 .794 r
.55965 .14722 m .56934 .13613 L .57548 .14555 L p F P
0 g
s
.846 .787 .794 r
.57548 .14555 m .56638 .1559 L .55965 .14722 L p F P
0 g
s
.667 .726 .893 r
.32992 .45509 m .35509 .44586 L .36256 .45476 L p F P
0 g
s
.687 .722 .876 r
.32992 .45509 m .35509 .44586 L .35406 .44453 L p F P
0 g
s
.687 .722 .876 r
.32227 .44738 m .32992 .45509 L p .35406 .44453 L F P
0 g
s
.78 .627 .691 r
.25212 .83706 m .25354 .83486 L .25112 .83432 L closepath p F P
0 g
s
.775 .642 .714 r
.24486 .81982 m .24843 .81502 L p .25354 .83486 L F P
0 g
s
.775 .642 .714 r
.25354 .83486 m .25112 .83432 L .24486 .81982 L p F P
0 g
s
.775 .659 .735 r
.24582 .7944 m .2625 .79855 L .24843 .81502 L p F P
0 g
s
.767 .662 .747 r
.26198 .77731 m .24582 .7944 L .2625 .79855 L p F P
0 g
s
.767 .662 .747 r
.26484 .77801 m .26198 .77731 L p .2625 .79855 L F P
0 g
s
.69 .759 .266 r
.50046 .32704 m .49474 .34008 L .50078 .32683 L p F P
0 g
s
.69 .759 .266 r
.50078 .32683 m .50517 .31422 L .50046 .32704 L p F P
0 g
s
.675 .626 .793 r
.4789 .72518 m .45322 .73664 L .44614 .72276 L p F P
0 g
s
.752 .677 .779 r
.29483 .76204 m .28931 .75283 L .28165 .75919 L closepath p F P
0 g
s
.895 .826 .771 r
.54081 .19348 m .54343 .18968 L .54795 .19955 L p F P
0 g
s
.895 .826 .771 r
.54795 .19955 m .54759 .20006 L .54081 .19348 L p F P
0 g
s
.718 .465 .543 r
.36724 .93908 m .34617 .93794 L .34707 .92531 L p F P
0 g
s
.731 .477 .544 r
.34158 .92485 m .34707 .92531 L .34617 .93794 L p F P
0 g
s
.625 .417 .58 r
.50768 .90714 m .52128 .90505 L .51541 .91955 L p F P
0 g
s
.625 .417 .58 r
.51541 .91955 m .50833 .92062 L .50768 .90714 L p F P
0 g
s
.644 .431 .58 r
.50768 .90714 m .50833 .92062 L .47873 .92397 L p F P
0 g
s
.637 .572 .765 r
.55855 .76861 m .53257 .77694 L .52564 .75985 L p F P
0 g
s
.832 .925 .895 r
.70922 .36236 m .70149 .36878 L .69552 .36524 L p F P
0 g
s
.931 .82 .714 r
.54052 .21308 m .54759 .20006 L .54081 .19348 L p F P
0 g
s
.782 .628 .69 r
.24386 .85011 m .25212 .83706 L .25112 .83432 L p F P
0 g
s
.653 .411 .541 r
.46335 .92516 m .47873 .92397 L .47833 .93666 L p F P
0 g
s
.653 .411 .541 r
.47833 .93666 m .46498 .93768 L .46335 .92516 L p F P
0 g
s
.776 .587 .644 r
.26287 .87072 m .25325 .86872 L p .26504 .88665 L F P
0 g
s
.776 .587 .644 r
.26504 .88665 m .26582 .88483 L .26287 .87072 L p F P
0 g
s
.782 .628 .69 r
.25112 .83432 m .23684 .8308 L p .24386 .85011 L F P
0 g
s
.781 .644 .71 r
.25112 .83432 m .24486 .81982 L .23684 .8308 L closepath p F P
0 g
s
.859 .936 .873 r
.72146 .34252 m .73167 .33273 L .72884 .34427 L p F P
0 g
s
.859 .936 .873 r
.72884 .34427 m .72726 .34575 L .72146 .34252 L p F P
0 g
s
.858 .944 .874 r
.70922 .36236 m .72726 .34575 L .72146 .34252 L p F P
0 g
s
.858 .944 .874 r
.72146 .34252 m .71284 .3506 L .70922 .36236 L p F P
0 g
s
.832 .925 .895 r
.69552 .36524 m .71284 .3506 L .70922 .36236 L p F P
0 g
s
.696 .696 .846 r
.39473 .45242 m .37032 .45103 L .36256 .45476 L p F P
0 g
s
.705 .737 .876 r
.37032 .45103 m .36256 .45476 L .35509 .44586 L p F P
0 g
s
.611 .472 .668 r
.55973 .86805 m .55644 .85232 L .58305 .84575 L p F P
0 g
s
.618 .496 .691 r
.57949 .83157 m .58305 .84575 L .55644 .85232 L p F P
0 g
s
.737 .666 .781 r
.32234 .74516 m .32492 .74322 L .32089 .74261 L closepath p F P
0 g
s
.757 .525 .582 r
.30929 .92164 m .29764 .92007 L .29976 .90674 L p F P
0 g
s
.763 .531 .582 r
.27987 .90375 m .29976 .90674 L .29764 .92007 L p F P
0 g
s
.712 .743 .876 r
.66989 .07142 m .64361 .08462 L .63716 .07526 L p F P
0 g
s
.752 .532 .598 r
.37262 .42825 m .38496 .42993 L .38364 .4167 L p F P
0 g
s
.752 .532 .598 r
.38364 .4167 m .3765 .41564 L .37262 .42825 L p F P
0 g
s
.731 .477 .544 r
.34617 .93794 m .34199 .93759 L .34158 .92485 L p F P
0 g
s
.737 .481 .543 r
.31886 .92267 m .34158 .92485 L .34199 .93759 L p F P
0 g
s
.675 .801 .942 r
.49509 .45293 m .49342 .45142 L .50394 .44746 L closepath p F P
0 g
s
.614 .431 .611 r
.53473 .88944 m .53624 .88818 L .53463 .8885 L closepath p F P
0 g
s
.634 .447 .613 r
.53463 .8885 m .53473 .88944 L .52128 .90505 L p F P
0 g
s
.689 .678 .834 r
.42719 .45148 m .39693 .45245 L .39527 .45323 L p F P
0 g
s
.692 .689 .843 r
.39693 .45245 m .39473 .45242 L .39527 .45323 L closepath p F P
0 g
s
.95 .956 .696 r
.7712 .27425 m .77902 .26025 L .77818 .27138 L p F P
0 g
s
.95 .956 .696 r
.77056 .28197 m .7712 .27425 L p .77818 .27138 L F P
0 g
s
.95 .956 .696 r
.77818 .27138 m .77218 .28191 L .77056 .28197 L p F P
0 g
s
.756 .874 .932 r
.62314 .41543 m .61733 .41881 L .61089 .41405 L p F P
0 g
s
.745 .872 .939 r
.5848 .42848 m .61089 .41405 L .61733 .41881 L p F P
0 g
s
.731 .677 .798 r
.34321 .71964 m .34786 .72751 L .32492 .74322 L p F P
0 g
s
.731 .677 .798 r
.33555 .71853 m .34321 .71964 L p .32492 .74322 L F P
0 g
s
.731 .677 .798 r
.31492 .73295 m .33555 .71853 L p .32492 .74322 L F P
0 g
s
.731 .677 .798 r
.32492 .74322 m .32089 .74261 L .31492 .73295 L p F P
0 g
s
.883 .788 .751 r
.563 .16091 m .56638 .1559 L .55965 .14722 L p F P
0 g
s
.615 .433 .613 r
.5362 .90271 m .53473 .88944 L .53624 .88818 L p F P
0 g
s
.632 .445 .612 r
.5362 .90271 m .53473 .88944 L .52128 .90505 L closepath p F P
0 g
s
.615 .433 .613 r
.53624 .88818 m .56218 .88302 L p .5362 .90271 L F P
0 g
s
.622 .46 .642 r
.56218 .88302 m .5606 .87346 L .53624 .88818 L closepath p F P
0 g
s
.623 .461 .642 r
.55973 .86805 m .5606 .87346 L .53624 .88818 L p F P
0 g
s
.705 .554 .68 r
.39693 .45245 m .42085 .43774 L .41907 .43075 L p F P
0 g
s
.705 .554 .68 r
.39473 .45242 m .39693 .45245 L p .41907 .43075 L F P
0 g
s
.697 .625 .772 r
.42085 .43774 m .39693 .45245 L .42719 .45148 L closepath p F P
0 g
s
.705 .554 .68 r
.38806 .43945 m .39473 .45242 L p .41907 .43075 L F P
0 g
s
.713 .649 .784 r
.38806 .43945 m .37032 .45103 L .39473 .45242 L closepath p F P
0 g
s
.659 .618 .797 r
.51172 .72945 m .51562 .73744 L .48766 .74282 L p F P
0 g
s
.659 .618 .797 r
.48766 .74282 m .48591 .73928 L .51172 .72945 L p F P
0 g
s
.955 .894 .506 r
.78513 .23593 m .78496 .24696 L .78909 .23435 L p F P
0 g
s
.955 .894 .506 r
.78564 .23433 m .78513 .23593 L p .78909 .23435 L F P
0 g
s
.955 .894 .506 r
.78909 .23435 m .78915 .23136 L .78564 .23433 L p F P
0 g
s
.698 .832 .947 r
.55209 .43585 m .52616 .44723 L .51928 .44152 L p F P
0 g
s
.667 .707 .877 r
.45506 .44532 m .44114 .44786 L .42797 .45272 L p F P
0 g
s
.661 .668 .846 r
.44114 .44786 m .42719 .45148 L .42797 .45272 L closepath p F P
0 g
s
.74 .68 .793 r
.32089 .74261 m .31492 .73295 L .30554 .73979 L closepath p F P
0 g
s
0 0 0 r
.4928 .34316 m .49126 .34824 L .49474 .34008 L closepath p F P
0 g
s
.787 .559 .592 r
.35564 .4234 m .37262 .42825 L .3765 .41564 L p F P
0 g
s
.787 .559 .592 r
.3765 .41564 m .35874 .41107 L .35564 .4234 L p F P
0 g
s
.634 .396 .54 r
.47833 .93666 m .47873 .92397 L .50833 .92062 L p F P
0 g
s
.781 .646 .713 r
.24486 .81982 m .24843 .81502 L .24206 .81343 L closepath p F P
0 g
s
.775 .659 .735 r
.23747 .80435 m .24582 .7944 L p .24843 .81502 L F P
0 g
s
.775 .659 .735 r
.24843 .81502 m .24206 .81343 L .23747 .80435 L p F P
0 g
s
.134 0 .331 r
.48022 .37887 m .46972 .38922 L .47088 .37919 L p F P
0 g
s
.134 0 .331 r
.47088 .37919 m .48387 .36631 L .48022 .37887 L p F P
0 g
s
.773 .894 .929 r
.62314 .41543 m .64338 .40276 L .63707 .39834 L p F P
0 g
s
.773 .894 .929 r
.63707 .39834 m .63039 .40257 L .62314 .41543 L p F P
0 g
s
.756 .874 .932 r
.61089 .41405 m .63039 .40257 L .62314 .41543 L p F P
0 g
s
.544 .715 .951 r
.25729 .44072 m .28184 .43766 L .28966 .4454 L p F P
0 g
s
.547 .709 .946 r
.28184 .43766 m .25729 .44072 L .24937 .43275 L p F P
0 g
s
.53 .65 .911 r
.71832 .08271 m .70918 .08313 L .70295 .07334 L p F P
0 g
s
0 0 .137 r
.78935 .17879 m .79067 .18954 L .78906 .17915 L p F P
0 g
s
0 0 .137 r
.78906 .17915 m .78774 .16838 L .78935 .17879 L p F P
0 g
s
.883 .788 .751 r
.55965 .14722 m .55673 .15157 L .563 .16091 L p F P
0 g
s
.883 .788 .751 r
.54712 .16589 m .55331 .17525 L .563 .16091 L p F P
0 g
s
.883 .788 .751 r
.563 .16091 m .55673 .15157 L .54712 .16589 L p F P
0 g
s
.653 .541 .714 r
.42719 .45148 m .44114 .44786 L p .44687 .42444 L F P
0 g
s
.653 .541 .714 r
.42085 .43774 m .42719 .45148 L p .44687 .42444 L F P
0 g
s
.968 .923 .599 r
.51139 .28974 m .51027 .30132 L .51674 .28798 L p F P
0 g
s
.968 .923 .599 r
.51674 .28798 m .5169 .27671 L .51139 .28974 L p F P
0 g
s
.66 .618 .796 r
.51172 .72945 m .48591 .73928 L .4789 .72518 L p F P
0 g
s
.776 .587 .644 r
.26625 .88688 m .26582 .88483 L .26504 .88665 L closepath p F P
0 g
s
.689 .654 .81 r
.43903 .70993 m .44569 .72188 L .41405 .72353 L p F P
0 g
s
.689 .654 .81 r
.41405 .72353 m .41342 .72243 L .43903 .70993 L p F P
0 g
s
.699 .658 .806 r
.41405 .72353 m .41342 .72243 L .41136 .72353 L closepath p F P
0 g
s
.705 .649 .791 r
.38067 .72393 m .38217 .72305 L .41136 .72353 L p F P
0 g
s
.7 .661 .808 r
.40622 .70999 m .38217 .72305 L .41136 .72353 L p F P
0 g
s
.7 .661 .808 r
.41136 .72353 m .41342 .72243 L .40622 .70999 L p F P
0 g
s
.764 .675 .764 r
.26484 .77801 m .26357 .77582 L .26198 .77731 L closepath p F P
0 g
s
.74 .618 .723 r
.37032 .45103 m .38806 .43945 L .38496 .42993 L p F P
0 g
s
.74 .618 .723 r
.35581 .44539 m .37032 .45103 L p .38496 .42993 L F P
0 g
s
.705 .737 .876 r
.35509 .44586 m .35581 .44539 L .37032 .45103 L p F P
0 g
s
.66 .767 .929 r
.46068 .45284 m .4864 .44412 L .49342 .45142 L p F P
0 g
s
.658 .708 .884 r
.45506 .44532 m .46068 .45284 L .4864 .44412 L p F P
0 g
s
.637 .572 .765 r
.55225 .75299 m .55855 .76861 L p .52564 .75985 L F P
0 g
s
.637 .572 .765 r
.52564 .75985 m .52628 .75964 L .55225 .75299 L p F P
0 g
s
.638 .574 .766 r
.52564 .75985 m .52628 .75964 L .52562 .75981 L closepath p F P
0 g
s
.641 .593 .784 r
.52628 .75964 m .52562 .75981 L .51869 .74432 L p F P
0 g
s
.783 .647 .711 r
.23684 .8308 m .24486 .81982 L .24206 .81343 L p F P
0 g
s
.968 .864 .683 r
.52886 .24952 m .52834 .25065 L .52789 .24921 L closepath p F P
0 g
s
.776 .587 .644 r
.25325 .86872 m .24732 .88299 L .26504 .88665 L p F P
0 g
s
.788 .598 .643 r
.23614 .86484 m .25325 .86872 L .24732 .88299 L p F P
0 g
s
.779 .608 .667 r
.24386 .85011 m .23614 .86484 L .25325 .86872 L p F P
0 g
s
.623 .415 .579 r
.52128 .90505 m .5362 .90271 L .53691 .9162 L p F P
0 g
s
.623 .415 .579 r
.53691 .9162 m .51541 .91955 L .52128 .90505 L p F P
0 g
s
.769 .56 .616 r
.27987 .90375 m .26803 .90179 L .26625 .88688 L p F P
0 g
s
.778 .567 .614 r
.26504 .88665 m .26625 .88688 L .26803 .90179 L p F P
0 g
s
.641 .592 .784 r
.55225 .75299 m .55161 .75155 L .52628 .75964 L closepath p F P
0 g
s
.641 .593 .784 r
.54468 .73589 m .55161 .75155 L .52628 .75964 L p F P
0 g
s
.641 .593 .784 r
.51869 .74432 m .54468 .73589 L p .52628 .75964 L F P
0 g
s
.707 .656 .796 r
.38067 .72393 m .38217 .72305 L .38015 .72299 L closepath p F P
0 g
s
.719 .661 .791 r
.38015 .72299 m .38067 .72393 L p .34786 .72751 L F P
0 g
s
.676 .772 .923 r
.50394 .44746 m .49342 .45142 L .4864 .44412 L p F P
0 g
s
.333 .499 .873 r
.74904 .10501 m .74915 .10505 L .74927 .10545 L closepath p F P
0 g
s
.216 .418 .845 r
.76162 .11108 m .74915 .10505 L .74927 .10545 L p F P
0 g
s
.216 .418 .845 r
.76471 .12149 m .76162 .11108 L p .74927 .10545 L F P
0 g
s
.691 .654 .808 r
.43903 .70993 m .41342 .72243 L .40622 .70999 L p F P
0 g
s
.778 .567 .614 r
.26803 .90179 m .26098 .90045 L .26504 .88665 L p F P
0 g
s
.784 .573 .614 r
.24732 .88299 m .26504 .88665 L .26098 .90045 L p F P
0 g
s
.97 .864 .678 r
.51955 .25344 m .52254 .26369 L .52834 .25065 L p F P
0 g
s
.97 .864 .678 r
.52202 .24746 m .51955 .25344 L p .52834 .25065 L F P
0 g
s
.97 .864 .678 r
.52834 .25065 m .52789 .24921 L .52202 .24746 L p F P
0 g
s
.704 .668 .812 r
.39898 .69762 m .40622 .70999 L .38217 .72305 L p F P
0 g
s
.704 .668 .812 r
.37339 .71182 m .39898 .69762 L p .38217 .72305 L F P
0 g
s
.704 .668 .812 r
.38217 .72305 m .38015 .72299 L .37339 .71182 L p F P
0 g
s
.719 .661 .791 r
.34786 .72751 m .35769 .72115 L .38015 .72299 L p F P
0 g
s
.715 .672 .807 r
.38015 .72299 m .37339 .71182 L .35769 .72115 L closepath p F P
0 g
s
.335 .511 .882 r
.74915 .10505 m .74904 .10501 L .74286 .09407 L p F P
0 g
s
.791 .62 .669 r
.22735 .846 m .24386 .85011 L .23614 .86484 L p F P
0 g
s
.782 .628 .69 r
.23684 .8308 m .22735 .846 L .24386 .85011 L p F P
0 g
s
.335 .511 .882 r
.74286 .09407 m .74534 .09482 L .74915 .10505 L p F P
0 g
s
.233 .437 .855 r
.75799 .10077 m .76162 .11108 L .74915 .10505 L p F P
0 g
s
.233 .437 .855 r
.74915 .10505 m .74534 .09482 L .75799 .10077 L p F P
0 g
s
.763 .674 .764 r
.28165 .75919 m .26357 .77582 L .25603 .76313 L p F P
0 g
s
.763 .674 .764 r
.25603 .76313 m .26466 .75504 L .28165 .75919 L p F P
0 g
s
.754 .681 .781 r
.28181 .74055 m .26466 .75504 L .28165 .75919 L p F P
0 g
s
.754 .681 .781 r
.28165 .75919 m .28931 .75283 L .28181 .74055 L p F P
0 g
s
.766 .679 .766 r
.26198 .77731 m .26357 .77582 L .25603 .76313 L p F P
0 g
s
.775 .676 .754 r
.24578 .77296 m .26198 .77731 L .24582 .7944 L p F P
0 g
s
.766 .679 .766 r
.25603 .76313 m .24578 .77296 L .26198 .77731 L p F P
0 g
s
.737 .481 .543 r
.34199 .93759 m .31921 .93542 L .31886 .92267 L p F P
0 g
s
.742 .486 .543 r
.30929 .92164 m .31886 .92267 L .31921 .93542 L p F P
0 g
s
.603 .445 .641 r
.5606 .87346 m .55973 .86805 L .58639 .86152 L p F P
0 g
s
.611 .472 .668 r
.58305 .84575 m .58639 .86152 L .55973 .86805 L p F P
0 g
s
.949 .957 .698 r
.77218 .28191 m .77016 .28541 L .77056 .28197 L closepath p F P
0 g
s
.783 .647 .711 r
.24206 .81343 m .23215 .81078 L p .23684 .8308 L F P
0 g
s
.781 .661 .731 r
.24206 .81343 m .23747 .80435 L .23215 .81078 L closepath p F P
0 g
s
.75 .677 .78 r
.30554 .73979 m .28931 .75283 L .28181 .74055 L p F P
0 g
s
.722 .669 .797 r
.34786 .72751 m .35769 .72115 L .34321 .71964 L closepath p F P
0 g
s
0 0 .398 r
.78588 .15771 m .78774 .16838 L .78404 .15881 L p F P
0 g
s
0 0 .398 r
.78404 .15881 m .78217 .14814 L .78588 .15771 L p F P
0 g
s
.728 .867 .947 r
.5848 .42848 m .57904 .43141 L .58287 .42708 L closepath p F P
0 g
s
.718 .846 .943 r
.57818 .42328 m .58287 .42708 L .57904 .43141 L p F P
0 g
s
.718 .846 .943 r
.55209 .43585 m .57818 .42328 L p .57904 .43141 L F P
0 g
s
.962 .886 .499 r
.78915 .23136 m .78564 .23433 L .78905 .22338 L closepath p F P
0 g
s
.675 .626 .793 r
.47548 .71832 m .4789 .72518 L p .44614 .72276 L F P
0 g
s
.675 .626 .793 r
.44614 .72276 m .44887 .72152 L .47548 .71832 L p F P
0 g
s
.676 .631 .797 r
.44614 .72276 m .44887 .72152 L .44569 .72188 L closepath p F P
0 g
s
.931 .82 .714 r
.54081 .19348 m .5356 .20339 L .54052 .21308 L p F P
0 g
s
.932 .82 .712 r
.52863 .21681 m .53325 .2266 L .54052 .21308 L p F P
0 g
s
.932 .82 .712 r
.54052 .21308 m .5356 .20339 L .52863 .21681 L p F P
0 g
s
.606 .731 .933 r
.31458 .43939 m .3033 .44218 L .31352 .44938 L p F P
0 g
s
.606 .731 .933 r
.31352 .44938 m .32227 .44738 L .31458 .43939 L p F P
0 g
s
.608 .737 .936 r
.28966 .4454 m .3033 .44218 L .31352 .44938 L p F P
0 g
s
.763 .531 .582 r
.29764 .92007 m .2777 .91709 L .27987 .90375 L p F P
0 g
s
.768 .536 .583 r
.26803 .90179 m .27987 .90375 L .2777 .91709 L p F P
0 g
s
.958 .886 .718 r
.52789 .24921 m .52202 .24746 L .52595 .24017 L closepath p F P
0 g
s
0 0 .001 r
.49618 .33975 m .50046 .32704 L .49474 .34008 L p F P
0 g
s
0 0 .001 r
.49037 .35141 m .49618 .33975 L p .49474 .34008 L F P
0 g
s
0 0 .001 r
.49474 .34008 m .49126 .34824 L .49037 .35141 L p F P
0 g
s
.676 .646 .813 r
.44887 .72152 m .44569 .72188 L .43903 .70993 L p F P
0 g
s
.931 .954 .774 r
.76113 .28908 m .75983 .30029 L .77016 .28541 L p F P
0 g
s
.931 .954 .774 r
.76679 .28077 m .76113 .28908 L p .77016 .28541 L F P
0 g
s
.931 .954 .774 r
.77016 .28541 m .77056 .28197 L .76679 .28077 L p F P
0 g
s
.666 .388 .49 r
.41537 .93998 m .42665 .93966 L .43232 .95117 L p F P
0 g
s
.666 .388 .49 r
.43232 .95117 m .41353 .9517 L .41537 .93998 L p F P
0 g
s
.684 .405 .493 r
.39498 .93989 m .41537 .93998 L .41353 .9517 L p F P
0 g
s
.705 .554 .68 r
.41907 .43075 m .39596 .43085 L .38806 .43945 L p F P
0 g
s
.73 .592 .702 r
.39596 .43085 m .38496 .42993 L .38806 .43945 L closepath p F P
0 g
s
.793 .64 .692 r
.22088 .82648 m .23684 .8308 L .22735 .846 L p F P
0 g
s
.783 .647 .711 r
.23215 .81078 m .22088 .82648 L .23684 .8308 L p F P
0 g
s
.684 .405 .493 r
.41353 .9517 m .39962 .95164 L .39498 .93989 L p F P
0 g
s
.688 .407 .491 r
.3817 .93971 m .39498 .93989 L .39962 .95164 L p F P
0 g
s
.639 .511 .69 r
.44313 .4252 m .41907 .43075 L .42085 .43774 L closepath p F P
0 g
s
.781 .664 .733 r
.23747 .80435 m .24582 .7944 L .23013 .79008 L closepath p F P
0 g
s
.775 .676 .754 r
.22999 .78985 m .24578 .77296 L p .24582 .7944 L F P
0 g
s
.775 .676 .754 r
.24582 .7944 m .23013 .79008 L .22999 .78985 L p F P
0 g
s
.742 .486 .543 r
.31921 .93542 m .30821 .93425 L .30929 .92164 L p F P
0 g
s
.754 .497 .543 r
.29764 .92007 m .30929 .92164 L .30821 .93425 L p F P
0 g
s
.75 .677 .78 r
.28181 .74055 m .28743 .73595 L .30554 .73979 L p F P
0 g
s
.741 .684 .795 r
.30745 .72107 m .28743 .73595 L .30554 .73979 L p F P
0 g
s
.741 .684 .795 r
.30554 .73979 m .31492 .73295 L .30745 .72107 L p F P
0 g
s
.053 .278 .77 r
.77065 .1185 m .77364 .12896 L .76471 .12149 L p F P
0 g
s
.053 .278 .77 r
.76471 .12149 m .76162 .11108 L .77065 .1185 L p F P
0 g
s
.674 .642 .809 r
.47548 .71832 m .47185 .71162 L .44887 .72152 L closepath p F P
0 g
s
.676 .646 .813 r
.46477 .69864 m .47185 .71162 L .44887 .72152 L p F P
0 g
s
.676 .646 .813 r
.43903 .70993 m .46477 .69864 L p .44887 .72152 L F P
0 g
s
.688 .407 .491 r
.39962 .95164 m .37966 .95138 L .3817 .93971 L p F P
0 g
s
.705 .422 .494 r
.36724 .93908 m .3817 .93971 L .37966 .95138 L p F P
0 g
s
0 .058 .62 r
.77976 .13756 m .78217 .14814 L .77609 .13952 L p F P
0 g
s
0 .058 .62 r
.77609 .13952 m .77364 .12896 L .77976 .13756 L p F P
0 g
s
.662 .386 .492 r
.42665 .93966 m .4475 .93891 L .44585 .95069 L p F P
0 g
s
.662 .386 .492 r
.44585 .95069 m .43232 .95117 L .42665 .93966 L p F P
0 g
s
.604 .447 .643 r
.56218 .88302 m .5606 .87346 L .5867 .86342 L p F P
0 g
s
.603 .445 .641 r
.58639 .86152 m .5867 .86342 L .5606 .87346 L p F P
0 g
s
.884 .542 .396 r
.33438 .37565 m .33431 .37574 L .33428 .37559 L closepath p F P
0 g
s
.782 .891 .922 r
.66099 .39116 m .64338 .40276 L .63707 .39834 L p F P
0 g
s
.932 .578 .332 r
.32637 .37368 m .32528 .36772 L .33428 .37559 L p F P
0 g
s
.932 .578 .332 r
.33428 .37559 m .33431 .37574 L .32637 .37368 L p F P
0 g
s
.717 .68 .813 r
.36606 .69987 m .37339 .71182 L .35769 .72115 L p F P
0 g
s
.717 .68 .813 r
.34049 .71536 m .36606 .69987 L p .35769 .72115 L F P
0 g
s
.717 .68 .813 r
.35769 .72115 m .34321 .71964 L .34049 .71536 L p F P
0 g
s
.748 .87 .936 r
.60438 .40903 m .61089 .41405 L .5848 .42848 L p F P
0 g
s
.748 .87 .936 r
.58892 .41766 m .60438 .40903 L p .5848 .42848 L F P
0 g
s
.748 .87 .936 r
.5848 .42848 m .58287 .42708 L .58892 .41766 L p F P
0 g
s
.946 .623 .388 r
.33529 .38633 m .33431 .37574 L .32637 .37368 L p F P
0 g
s
.907 .62 .488 r
.3352 .39753 m .34558 .40483 L .34567 .39362 L p F P
0 g
s
.907 .62 .488 r
.34567 .39362 m .33529 .38633 L .3352 .39753 L p F P
0 g
s
.52 .335 .571 r
.47043 .41301 m .46931 .40018 L .44595 .41181 L p F P
0 g
s
.52 .335 .571 r
.44989 .42287 m .47043 .41301 L p .44595 .41181 L F P
0 g
s
.52 .335 .571 r
.44595 .41181 m .44654 .42163 L .44989 .42287 L p F P
0 g
s
.653 .541 .714 r
.44687 .42444 m .44313 .4252 L .42085 .43774 L p F P
0 g
s
.74 .618 .723 r
.38496 .42993 m .37262 .42825 L .35581 .44539 L p F P
0 g
s
.883 .79 .753 r
.53732 .18032 m .54343 .18968 L .55331 .17525 L p F P
0 g
s
.883 .79 .753 r
.55331 .17525 m .54712 .16589 L .53732 .18032 L p F P
0 g
s
.935 .809 .351 r
.78832 .21255 m .78905 .22338 L .79115 .21153 L p F P
0 g
s
.935 .809 .351 r
.79115 .21153 m .7904 .20069 L .78832 .21255 L p F P
0 g
s
.616 .736 .931 r
.3033 .44218 m .28966 .4454 L .28184 .43766 L p F P
0 g
s
.603 .4 .578 r
.53691 .9162 m .5362 .90271 L .56381 .89726 L p F P
0 g
s
.615 .433 .613 r
.56218 .88302 m .56381 .89726 L .5362 .90271 L p F P
0 g
s
.606 .506 .714 r
.5789 .82919 m .57383 .81175 L .59951 .80392 L p F P
0 g
s
.613 .528 .735 r
.5987 .80148 m .59951 .80392 L .57383 .81175 L p F P
0 g
s
.613 .528 .735 r
.57383 .81175 m .57245 .80758 L .5987 .80148 L p F P
0 g
s
.705 .422 .494 r
.37966 .95138 m .37111 .951 L .36724 .93908 L p F P
0 g
s
.708 .421 .487 r
.34617 .93794 m .36724 .93908 L .37111 .951 L p F P
0 g
s
.669 .684 .855 r
.45355 .44304 m .44114 .44786 L .45506 .44532 L closepath p F P
0 g
s
.653 .541 .714 r
.44114 .44786 m .45355 .44304 L .44687 .42444 L p F P
0 g
s
.736 .678 .795 r
.33555 .71853 m .31492 .73295 L .30745 .72107 L p F P
0 g
s
.612 .526 .733 r
.59342 .78541 m .5987 .80148 L .57245 .80758 L p F P
0 g
s
.612 .526 .733 r
.57245 .80758 m .56779 .79334 L .59342 .78541 L p F P
0 g
s
.643 .369 .489 r
.4475 .93891 m .46498 .93768 L .4721 .94887 L p F P
0 g
s
.643 .369 .489 r
.4721 .94887 m .44585 .95069 L .4475 .93891 L p F P
0 g
s
.618 .547 .753 r
.59171 .78074 m .59342 .78541 L .56779 .79334 L p F P
0 g
s
.618 .547 .753 r
.56779 .79334 m .56549 .78707 L .59171 .78074 L p F P
0 g
s
.783 .664 .732 r
.23215 .81078 m .23747 .80435 L .23013 .79008 L p F P
0 g
s
.642 .592 .784 r
.54233 .73057 m .54468 .73589 L .51869 .74432 L p F P
0 g
s
.642 .592 .784 r
.51869 .74432 m .51562 .73744 L .54233 .73057 L p F P
0 g
s
.613 .379 .538 r
.50833 .92062 m .51541 .91955 L .51859 .93174 L p F P
0 g
s
.613 .379 .538 r
.51859 .93174 m .50804 .93333 L .50833 .92062 L p F P
0 g
s
.634 .396 .54 r
.50833 .92062 m .50804 .93333 L .47833 .93666 L p F P
0 g
s
.848 .613 .583 r
.34313 .41693 m .35564 .4234 L .35874 .41107 L p F P
0 g
s
.848 .613 .583 r
.35874 .41107 m .34558 .40483 L .34313 .41693 L p F P
0 g
s
.676 .772 .923 r
.51233 .43487 m .51614 .4386 L .50394 .44746 L p F P
0 g
s
.676 .772 .923 r
.4864 .44412 m .51233 .43487 L p .50394 .44746 L F P
0 g
s
.679 .8 .939 r
.51928 .44152 m .50394 .44746 L .51614 .4386 L closepath p F P
0 g
s
.97 .929 .625 r
.77921 .24925 m .77902 .26025 L .78496 .24696 L p F P
0 g
s
.97 .929 .625 r
.78496 .24696 m .78513 .23593 L .77921 .24925 L p F P
0 g
s
.66 .618 .796 r
.4789 .72518 m .50474 .71515 L .51172 .72945 L p F P
0 g
s
.66 .62 .798 r
.50372 .71307 m .50474 .71515 L .4789 .72518 L p F P
0 g
s
.66 .62 .798 r
.4789 .72518 m .47548 .71832 L .50372 .71307 L p F P
0 g
s
.868 .913 .51 r
.51021 .30154 m .51009 .30171 L .51027 .30132 L closepath p F P
0 g
s
.617 .546 .752 r
.58625 .76576 m .59171 .78074 L .56549 .78707 L p F P
0 g
s
.617 .546 .752 r
.56549 .78707 m .56065 .77382 L .58625 .76576 L p F P
0 g
s
.599 .481 .691 r
.57949 .83157 m .5789 .82919 L .60462 .82144 L p F P
0 g
s
.606 .506 .714 r
.59951 .80392 m .60462 .82144 L .5789 .82919 L p F P
0 g
s
.911 .931 .557 r
.50597 .30279 m .51139 .28974 L .51027 .30132 L p F P
0 g
s
.911 .931 .557 r
.50554 .30678 m .50597 .30279 L p .51027 .30132 L F P
0 g
s
.911 .931 .557 r
.51027 .30132 m .51009 .30171 L .50554 .30678 L p F P
0 g
s
.754 .497 .543 r
.30821 .93425 m .29783 .93285 L .29764 .92007 L p F P
0 g
s
.76 .502 .542 r
.2777 .91709 m .29764 .92007 L .29783 .93285 L p F P
0 g
s
.954 .915 .551 r
.51009 .30171 m .50517 .31422 L .50554 .30678 L closepath p F P
0 g
s
.53 .65 .911 r
.70295 .07334 m .71347 .07272 L .71832 .08271 L p F P
0 g
s
.481 .615 .907 r
.73047 .07314 m .71347 .07272 L .71832 .08271 L p F P
0 g
s
.481 .615 .907 r
.71832 .08271 m .73667 .08346 L .73047 .07314 L p F P
0 g
s
.794 .659 .714 r
.2167 .80624 m .23215 .81078 L .22088 .82648 L p F P
0 g
s
.783 .664 .732 r
.22985 .79 m .2167 .80624 L .23215 .81078 L p F P
0 g
s
.783 .664 .732 r
.23013 .79008 m .22985 .79 L p .23215 .81078 L F P
0 g
s
.768 .536 .583 r
.2777 .91709 m .26834 .91556 L .26803 .90179 L p F P
0 g
s
.778 .544 .581 r
.26098 .90045 m .26803 .90179 L .26834 .91556 L p F P
0 g
s
.599 .484 .693 r
.58305 .84575 m .57949 .83157 L .60579 .82614 L p F P
0 g
s
.599 .481 .691 r
.60462 .82144 m .60579 .82614 L .57949 .83157 L p F P
0 g
s
.727 .683 .808 r
.34321 .71964 m .34049 .71536 L .33555 .71853 L closepath p F P
0 g
s
.781 .632 .695 r
.35406 .44453 m .35581 .44539 L .37262 .42825 L p F P
0 g
s
.781 .632 .695 r
.34764 .43507 m .35406 .44453 L p .37262 .42825 L F P
0 g
s
.781 .632 .695 r
.37262 .42825 m .35564 .4234 L .34764 .43507 L p F P
0 g
s
.708 .421 .487 r
.34445 .94691 m .34617 .93794 L p .37111 .951 L F P
0 g
s
.725 .441 .496 r
.34445 .94691 m .34199 .93759 L .34617 .93794 L closepath p F P
0 g
s
.635 .707 .898 r
.66989 .07142 m .69669 .06362 L .70295 .07334 L p F P
0 g
s
.636 .711 .901 r
.69669 .06362 m .66989 .07142 L .66353 .0619 L p F P
0 g
s
.712 .743 .876 r
.63716 .07526 m .66353 .0619 L .66989 .07142 L p F P
0 g
s
0 0 .032 r
.49126 .34824 m .48894 .3533 L .49037 .35141 L closepath p F P
0 g
s
.611 .378 .538 r
.51541 .91955 m .53691 .9162 L .53672 .92894 L p F P
0 g
s
.611 .378 .538 r
.53672 .92894 m .51859 .93174 L .51541 .91955 L p F P
0 g
s
.645 .61 .8 r
.53774 .72105 m .54233 .73057 L .51562 .73744 L p F P
0 g
s
.645 .61 .8 r
.51562 .73744 m .51172 .72945 L .53774 .72105 L p F P
0 g
s
.622 .566 .771 r
.58476 .76208 m .58625 .76576 L .56065 .77382 L p F P
0 g
s
.622 .566 .771 r
.56065 .77382 m .55855 .76861 L .58476 .76208 L p F P
0 g
s
.64 .368 .491 r
.46498 .93768 m .47833 .93666 L .47686 .94851 L p F P
0 g
s
.64 .368 .491 r
.47686 .94851 m .4721 .94887 L .46498 .93768 L p F P
0 g
s
.788 .598 .643 r
.24732 .88299 m .23023 .87911 L .23614 .86484 L p F P
0 g
s
.794 .606 .647 r
.21965 .86074 m .23614 .86484 L .23023 .87911 L p F P
0 g
s
.791 .62 .669 r
.23614 .86484 m .21965 .86074 L .22735 .846 L p F P
0 g
s
.593 .417 .612 r
.56381 .89726 m .56218 .88302 L .58888 .87652 L p F P
0 g
s
.604 .447 .643 r
.5867 .86342 m .58888 .87652 L .56218 .88302 L p F P
0 g
s
.784 .573 .614 r
.26098 .90045 m .24326 .89679 L .24732 .88299 L p F P
0 g
s
.79 .58 .616 r
.23023 .87911 m .24732 .88299 L .24326 .89679 L p F P
0 g
s
.915 .945 .807 r
.74876 .30474 m .74728 .31597 L .75983 .30029 L p F P
0 g
s
.915 .945 .807 r
.75983 .30029 m .76113 .28908 L .74876 .30474 L p F P
0 g
s
.73 .443 .492 r
.34199 .93759 m .34445 .94691 L .34389 .94953 L p F P
0 g
s
.73 .443 .492 r
.31921 .93542 m .34199 .93759 L p .34389 .94953 L F P
0 g
s
.938 .949 .764 r
.77056 .28197 m .76679 .28077 L .7712 .27425 L closepath p F P
0 g
s
.8 .906 .915 r
.66947 .3851 m .66099 .39116 L .66488 .38206 L closepath p F P
0 g
s
.782 .891 .922 r
.66328 .38083 m .66488 .38206 L .66099 .39116 L p F P
0 g
s
.782 .891 .922 r
.63707 .39834 m .66328 .38083 L p .66099 .39116 L F P
0 g
s
.982 .866 .647 r
.51443 .2663 m .5169 .27671 L .52254 .26369 L p F P
0 g
s
.982 .866 .647 r
.52254 .26369 m .51955 .25344 L .51443 .2663 L p F P
0 g
s
.687 .722 .876 r
.35406 .44453 m .33457 .44205 L .32227 .44738 L p F P
0 g
s
.693 .758 .902 r
.33457 .44205 m .32227 .44738 L .31458 .43939 L p F P
0 g
s
.742 .732 .842 r
.35581 .44539 m .35406 .44453 L .35509 .44586 L closepath p F P
0 g
s
.691 .654 .808 r
.40622 .70999 m .43187 .69721 L .43903 .70993 L p F P
0 g
s
.693 .657 .81 r
.43187 .69721 m .40622 .70999 L .39898 .69762 L p F P
0 g
s
.708 .669 .81 r
.39898 .69762 m .37339 .71182 L .36606 .69987 L p F P
0 g
s
.769 .681 .766 r
.26466 .75504 m .25603 .76313 L .24845 .75064 L p F P
0 g
s
.769 .681 .766 r
.24845 .75064 m .24848 .75061 L .26466 .75504 L p F P
0 g
s
.758 .686 .782 r
.27049 .73171 m .24848 .75061 L .26466 .75504 L p F P
0 g
s
.758 .686 .782 r
.27745 .73356 m .27049 .73171 L p .26466 .75504 L F P
0 g
s
.758 .686 .782 r
.26466 .75504 m .28181 .74055 L .27745 .73356 L p F P
0 g
s
.658 .708 .884 r
.47933 .43519 m .466 .43937 L .45506 .44532 L p F P
0 g
s
.658 .708 .884 r
.4864 .44412 m .47933 .43519 L p .45506 .44532 L F P
0 g
s
.639 .672 .865 r
.45355 .44304 m .466 .43937 L .45506 .44532 L closepath p F P
0 g
s
.736 .678 .795 r
.30745 .72107 m .31578 .71515 L .33555 .71853 L p F P
0 g
s
.728 .687 .81 r
.33305 .70389 m .31578 .71515 L .33555 .71853 L p F P
0 g
s
.728 .687 .81 r
.33555 .71853 m .34049 .71536 L .33305 .70389 L p F P
0 g
s
.771 .683 .767 r
.24578 .77296 m .25603 .76313 L .24845 .75064 L p F P
0 g
s
.622 .565 .77 r
.57783 .74484 m .58476 .76208 L .55855 .76861 L p F P
0 g
s
.622 .565 .77 r
.57717 .745 m .57783 .74484 L p .55855 .76861 L F P
0 g
s
.622 .565 .77 r
.55855 .76861 m .55225 .75299 L .57717 .745 L p F P
0 g
s
.734 .85 .935 r
.58287 .42708 m .57818 .42328 L .58892 .41766 L closepath p F P
0 g
s
.797 .628 .673 r
.21144 .84168 m .22735 .846 L .21965 .86074 L p F P
0 g
s
.793 .64 .692 r
.22735 .846 m .21144 .84168 L .22088 .82648 L p F P
0 g
s
.937 .828 .711 r
.52166 .23028 m .52595 .24017 L .53325 .2266 L p F P
0 g
s
.937 .828 .711 r
.53325 .2266 m .52863 .21681 L .52166 .23028 L p F P
0 g
s
.662 .636 .814 r
.49772 .70181 m .50372 .71307 L .47548 .71832 L p F P
0 g
s
.662 .636 .814 r
.47548 .71832 m .47185 .71162 L .49772 .70181 L p F P
0 g
s
.781 .678 .75 r
.24578 .77296 m .22999 .78985 L .22237 .77699 L p F P
0 g
s
.781 .678 .75 r
.22237 .77699 m .23031 .76834 L .24578 .77296 L p F P
0 g
s
.771 .683 .767 r
.24845 .75064 m .23031 .76834 L .24578 .77296 L p F P
0 g
s
.778 .544 .581 r
.26834 .91556 m .25888 .91377 L .26098 .90045 L p F P
0 g
s
.785 .551 .582 r
.24326 .89679 m .26098 .90045 L .25888 .91377 L p F P
0 g
s
.717 .838 .939 r
.57818 .42328 m .55209 .43585 L .54531 .43021 L p F P
0 g
s
.698 .832 .947 r
.51928 .44152 m .54531 .43021 L .55209 .43585 L p F P
0 g
s
.592 .46 .669 r
.58639 .86152 m .58305 .84575 L .60883 .83808 L p F P
0 g
s
.599 .484 .693 r
.60579 .82614 m .60883 .83808 L .58305 .84575 L p F P
0 g
s
.809 .906 .908 r
.68984 .3699 m .66947 .3851 L .66488 .38206 L p F P
0 g
s
.619 .35 .488 r
.47686 .94851 m .47833 .93666 L .50804 .93333 L p F P
0 g
s
.882 .794 .757 r
.53395 .18524 m .53732 .18032 L .54343 .18968 L p F P
0 g
s
.882 .794 .757 r
.54343 .18968 m .54081 .19348 L .53395 .18524 L p F P
0 g
s
.754 .685 .784 r
.28181 .74055 m .28743 .73595 L .27745 .73356 L closepath p F P
0 g
s
.863 .687 .157 r
.78907 .18995 m .7904 .20069 L .79067 .18954 L p F P
0 g
s
.863 .687 .157 r
.79067 .18954 m .78935 .17879 L .78907 .18995 L p F P
0 g
s
.721 .681 .81 r
.36606 .69987 m .34049 .71536 L .33305 .70389 L p F P
0 g
s
.707 .696 .837 r
.34764 .43507 m .33457 .44205 L .35406 .44453 L closepath p F P
0 g
s
.678 .646 .81 r
.46477 .69864 m .43903 .70993 L .43187 .69721 L p F P
0 g
s
0 0 .114 r
.48839 .36032 m .48387 .36631 L .48894 .3533 L p F P
0 g
s
0 0 .114 r
.48894 .3533 m .49037 .35141 L .48839 .36032 L p F P
0 g
s
.747 .694 .801 r
.30187 .71238 m .30745 .72107 L .28743 .73595 L p F P
0 g
s
.747 .694 .801 r
.29735 .71133 m .30187 .71238 L p .28743 .73595 L F P
0 g
s
.747 .694 .801 r
.27424 .7288 m .29735 .71133 L p .28743 .73595 L F P
0 g
s
.747 .694 .801 r
.28743 .73595 m .27745 .73356 L .27424 .7288 L p F P
0 g
s
.616 .543 .749 r
.44687 .42444 m .45355 .44304 L .466 .43937 L p F P
0 g
s
.211 .043 .423 r
.47907 .39062 m .46931 .40018 L .46972 .38922 L p F P
0 g
s
.211 .043 .423 r
.46972 .38922 m .48022 .37887 L .47907 .39062 L p F P
0 g
s
.914 .789 .708 r
.5356 .20339 m .54081 .19348 L .53395 .18524 L p F P
0 g
s
.645 .61 .8 r
.53774 .72105 m .51172 .72945 L .50474 .71515 L p F P
0 g
s
.531 .656 .915 r
.71347 .07272 m .70295 .07334 L .69669 .06362 L p F P
0 g
s
.887 .942 .843 r
.74725 .31617 m .74715 .31612 L .74728 .31597 L closepath p F P
0 g
s
.78 .677 .75 r
.23013 .79008 m .22999 .78985 L .22985 .79 L closepath p F P
0 g
s
.508 .355 .608 r
.44654 .42163 m .44989 .42287 L .44687 .42444 L closepath p F P
0 g
s
.627 .441 .61 r
.44654 .42163 m .44313 .4252 L .44687 .42444 L closepath p F P
0 g
s
.798 .649 .697 r
.20553 .82193 m .22088 .82648 L .21144 .84168 L p F P
0 g
s
.794 .659 .714 r
.22088 .82648 m .20553 .82193 L .2167 .80624 L p F P
0 g
s
.783 .682 .753 r
.22985 .79 m .22999 .78985 L .22237 .77699 L p F P
0 g
s
.793 .675 .734 r
.21486 .78526 m .22985 .79 L .2167 .80624 L p F P
0 g
s
.783 .682 .753 r
.22237 .77699 m .21486 .78526 L .22985 .79 L p F P
0 g
s
.547 .709 .946 r
.24937 .43275 m .27397 .42963 L .28184 .43766 L p F P
0 g
s
.887 .934 .843 r
.74143 .31286 m .74876 .30474 L .74728 .31597 L p F P
0 g
s
.887 .934 .843 r
.74728 .31597 m .74715 .31612 L .74143 .31286 L p F P
0 g
s
.889 .942 .841 r
.73167 .33273 m .74715 .31612 L .74143 .31286 L p F P
0 g
s
.336 .52 .889 r
.74534 .09482 m .74286 .09407 L .73667 .08346 L p F P
0 g
s
.73 .443 .492 r
.34389 .94953 m .32243 .94749 L .31921 .93542 L p F P
0 g
s
.735 .446 .49 r
.30821 .93425 m .31921 .93542 L .32243 .94749 L p F P
0 g
s
.626 .584 .787 r
.55225 .75299 m .55161 .75155 L .57717 .745 L closepath p F P
0 g
s
.76 .502 .542 r
.29783 .93285 m .27783 .92989 L .2777 .91709 L p F P
0 g
s
.766 .507 .542 r
.26834 .91556 m .2777 .91709 L .27783 .92989 L p F P
0 g
s
.829 .919 .896 r
.69552 .36524 m .68984 .3699 L .69204 .36305 L closepath p F P
0 g
s
.809 .906 .908 r
.68947 .36114 m .69204 .36305 L .68984 .3699 L p F P
0 g
s
.809 .906 .908 r
.66591 .379 m .68947 .36114 L p .68984 .3699 L F P
0 g
s
.809 .906 .908 r
.66488 .38206 m .66591 .379 L p .68984 .3699 L F P
0 g
s
.758 .868 .928 r
.63039 .40257 m .61089 .41405 L .60438 .40903 L p F P
0 g
s
.692 .803 .934 r
.53846 .42415 m .54531 .43021 L .51928 .44152 L p F P
0 g
s
.692 .803 .934 r
.52398 .43018 m .53846 .42415 L p .51928 .44152 L F P
0 g
s
.692 .803 .934 r
.51928 .44152 m .51614 .4386 L .52398 .43018 L p F P
0 g
s
.626 .584 .787 r
.57717 .745 m .55161 .75155 L .54468 .73589 L p F P
0 g
s
.616 .543 .749 r
.47225 .42006 m .44989 .42287 L .44687 .42444 L p F P
0 g
s
.616 .543 .749 r
.47856 .43394 m .47225 .42006 L p .44687 .42444 L F P
0 g
s
.616 .543 .749 r
.466 .43937 m .47856 .43394 L p .44687 .42444 L F P
0 g
s
.961 .939 .706 r
.77145 .26326 m .7712 .27425 L .77902 .26025 L p F P
0 g
s
.961 .939 .706 r
.77902 .26025 m .77921 .24925 L .77145 .26326 L p F P
0 g
s
.663 .637 .813 r
.49772 .70181 m .47185 .71162 L .46477 .69864 L p F P
0 g
s
0 0 .014 r
.49249 .35232 m .48839 .36032 L .49037 .35141 L p F P
0 g
s
0 0 .014 r
.49037 .35141 m .49618 .33975 L .49249 .35232 L p F P
0 g
s
.836 .918 .89 r
.71284 .3506 m .69552 .36524 L .69204 .36305 L p F P
0 g
s
.739 .687 .8 r
.30745 .72107 m .31578 .71515 L .30187 .71238 L closepath p F P
0 g
s
.97 .887 .512 r
.78448 .2251 m .78832 .21255 L .78905 .22338 L p F P
0 g
s
.97 .887 .512 r
.78509 .23472 m .78448 .2251 L p .78905 .22338 L F P
0 g
s
.97 .887 .512 r
.78905 .22338 m .78564 .23433 L .78509 .23472 L p F P
0 g
s
.647 .753 .927 r
.51233 .43487 m .4864 .44412 L .47933 .43519 L p F P
0 g
s
.615 .731 .928 r
.30684 .43123 m .29395 .4346 L .3033 .44218 L p F P
0 g
s
.615 .731 .928 r
.3033 .44218 m .31458 .43939 L .30684 .43123 L p F P
0 g
s
.616 .736 .931 r
.28184 .43766 m .29395 .4346 L .3033 .44218 L p F P
0 g
s
.889 .942 .841 r
.74143 .31286 m .73365 .32138 L .73167 .33273 L p F P
0 g
s
.862 .928 .868 r
.71558 .33902 m .73365 .32138 L .73167 .33273 L p F P
0 g
s
.862 .928 .868 r
.73167 .33273 m .72146 .34252 L .71558 .33902 L p F P
0 g
s
.757 .732 .83 r
.33457 .44205 m .34764 .43507 L .3402 .4228 L p F P
0 g
s
.757 .732 .83 r
.3402 .4228 m .32239 .4355 L .33457 .44205 L p F P
0 g
s
.693 .758 .902 r
.31458 .43939 m .32239 .4355 L .33457 .44205 L p F P
0 g
s
.721 .496 0 r
.78748 .16813 m .78935 .17879 L .78774 .16838 L p F P
0 g
s
.721 .496 0 r
.78774 .16838 m .78588 .15771 L .78748 .16813 L p F P
0 g
s
.582 .431 .641 r
.5867 .86342 m .58639 .86152 L .61222 .85392 L p F P
0 g
s
.592 .46 .669 r
.60883 .83808 m .61222 .85392 L .58639 .86152 L p F P
0 g
s
.862 .932 .869 r
.71284 .3506 m .72146 .34252 L .71558 .33902 L p F P
0 g
s
.949 .906 .525 r
.50133 .31561 m .50046 .32704 L .50517 .31422 L p F P
0 g
s
.949 .906 .525 r
.50315 .30984 m .50133 .31561 L p .50517 .31422 L F P
0 g
s
.949 .906 .525 r
.50517 .31422 m .50554 .30678 L .50315 .30984 L p F P
0 g
s
.59 .36 .536 r
.53672 .92894 m .53691 .9162 L .5646 .91077 L p F P
0 g
s
.603 .4 .578 r
.56381 .89726 m .5646 .91077 L .53691 .9162 L p F P
0 g
s
.862 .932 .869 r
.71558 .33902 m .71554 .33906 L .71284 .3506 L p F P
0 g
s
.836 .918 .89 r
.69329 .35816 m .71554 .33906 L .71284 .3506 L p F P
0 g
s
.836 .918 .89 r
.69204 .36305 m .69329 .35816 L p .71284 .3506 L F P
0 g
s
.834 .711 .729 r
.3402 .4228 m .34313 .41693 L .35564 .4234 L p F P
0 g
s
.834 .711 .729 r
.35564 .4234 m .34764 .43507 L .3402 .4228 L p F P
0 g
s
.754 .696 .797 r
.27745 .73356 m .27424 .7288 L .27049 .73171 L closepath p F P
0 g
s
.735 .446 .49 r
.32243 .94749 m .30561 .94572 L .30821 .93425 L p F P
0 g
s
.749 .46 .493 r
.29783 .93285 m .30821 .93425 L .30561 .94572 L p F P
0 g
s
.336 .52 .889 r
.73667 .08346 m .741 .0847 L .74534 .09482 L p F P
0 g
s
.224 .441 .861 r
.75381 .09057 m .75799 .10077 L .74534 .09482 L p F P
0 g
s
.224 .441 .861 r
.74534 .09482 m .741 .0847 L .75381 .09057 L p F P
0 g
s
.733 .696 .815 r
.32556 .69257 m .33305 .70389 L .31578 .71515 L p F P
0 g
s
.733 .696 .815 r
.29992 .70955 m .32556 .69257 L p .31578 .71515 L F P
0 g
s
.733 .696 .815 r
.31578 .71515 m .30187 .71238 L .29992 .70955 L p F P
0 g
s
.583 .432 .643 r
.58888 .87652 m .5867 .86342 L .61314 .85936 L p F P
0 g
s
.582 .431 .641 r
.61222 .85392 m .61314 .85936 L .5867 .86342 L p F P
0 g
s
.898 .659 .568 r
.33313 .40951 m .34313 .41693 L .34558 .40483 L p F P
0 g
s
.898 .659 .568 r
.34558 .40483 m .3352 .39753 L .33313 .40951 L p F P
0 g
s
.798 .667 .719 r
.20187 .80148 m .2167 .80624 L .20553 .82193 L p F P
0 g
s
.793 .675 .734 r
.2167 .80624 m .20187 .80148 L .21486 .78526 L p F P
0 g
s
.57 .467 .698 r
.44989 .42287 m .47043 .41301 L .47225 .42006 L closepath p F P
0 g
s
.79 .58 .616 r
.24326 .89679 m .22612 .89293 L .23023 .87911 L p F P
0 g
s
.796 .587 .618 r
.22014 .87663 m .23023 .87911 L .22612 .89293 L p F P
0 g
s
.794 .606 .647 r
.21755 .8659 m .21965 .86074 L p .23023 .87911 L F P
0 g
s
.794 .606 .647 r
.23023 .87911 m .22014 .87663 L .21755 .8659 L p F P
0 g
s
.946 .623 .388 r
.32637 .37368 m .32679 .37828 L .33529 .38633 L p F P
0 g
s
.946 .658 .461 r
.32669 .3895 m .3352 .39753 L .33529 .38633 L p F P
0 g
s
.946 .658 .461 r
.33529 .38633 m .32679 .37828 L .32669 .3895 L p F P
0 g
s
.766 .507 .542 r
.27783 .92989 m .26707 .92815 L .26834 .91556 L p F P
0 g
s
.777 .517 .542 r
.25888 .91377 m .26834 .91556 L .26707 .92815 L p F P
0 g
s
.582 .383 .577 r
.5646 .91077 m .56381 .89726 L .59058 .8908 L p F P
0 g
s
.593 .417 .612 r
.58888 .87652 m .59058 .8908 L .56381 .89726 L p F P
0 g
s
.987 .878 .631 r
.50949 .27915 m .51139 .28974 L .5169 .27671 L p F P
0 g
s
.987 .878 .631 r
.5169 .27671 m .51443 .2663 L .50949 .27915 L p F P
0 g
s
.801 .611 .645 r
.21755 .8659 m .21965 .86074 L .21604 .85977 L closepath p F P
0 g
s
.797 .628 .673 r
.21057 .84339 m .21144 .84168 L p .21965 .86074 L F P
0 g
s
.797 .628 .673 r
.21965 .86074 m .21604 .85977 L .21057 .84339 L p F P
0 g
s
.941 .845 .721 r
.51509 .24292 m .52166 .23028 L .52595 .24017 L p F P
0 g
s
.941 .845 .721 r
.52595 .24017 m .52202 .24746 L .51509 .24292 L p F P
0 g
s
.914 .789 .708 r
.53395 .18524 m .52933 .19411 L .5356 .20339 L p F P
0 g
s
.916 .789 .706 r
.52243 .20753 m .52863 .21681 L .5356 .20339 L p F P
0 g
s
.916 .789 .706 r
.5356 .20339 m .52933 .19411 L .52243 .20753 L p F P
0 g
s
.647 .329 .419 r
.41032 .96237 m .41353 .9517 L .43232 .95117 L p F P
0 g
s
.668 .35 .426 r
.39962 .95164 m .41353 .9517 L .41032 .96237 L p F P
0 g
s
.668 .35 .426 r
.41032 .96237 m .40858 .96237 L .39962 .95164 L p F P
0 g
s
.668 .338 .406 r
.37966 .95138 m .39962 .95164 L .40858 .96237 L p F P
0 g
s
.596 .33 .483 r
.50804 .93333 m .51859 .93174 L .53183 .94142 L p F P
0 g
s
.596 .33 .483 r
.53183 .94142 m .50668 .94517 L .50804 .93333 L p F P
0 g
s
.619 .35 .488 r
.50804 .93333 m .50668 .94517 L .47686 .94851 L p F P
0 g
s
.785 .551 .582 r
.25888 .91377 m .24113 .91013 L .24326 .89679 L p F P
0 g
s
.791 .557 .583 r
.22612 .89293 m .24326 .89679 L .24113 .91013 L p F P
0 g
s
.693 .657 .81 r
.43008 .69405 m .43187 .69721 L p .39898 .69762 L F P
0 g
s
.693 .657 .81 r
.39898 .69762 m .40472 .69471 L .43008 .69405 L p F P
0 g
s
.695 .664 .815 r
.39898 .69762 m .40472 .69471 L .3973 .69478 L closepath p F P
0 g
s
.708 .669 .81 r
.3973 .69478 m .39898 .69762 L p .36606 .69987 L F P
0 g
s
0 0 .366 r
.78347 .14714 m .78588 .15771 L .78217 .14814 L p F P
0 g
s
0 0 .366 r
.78217 .14814 m .77976 .13756 L .78347 .14714 L p F P
0 g
s
.773 .688 .77 r
.24845 .75064 m .24848 .75061 L .24841 .75058 L closepath p F P
0 g
s
.765 .698 .788 r
.25478 .72706 m .27049 .73171 L .24848 .75061 L p F P
0 g
s
.765 .698 .788 r
.24075 .73929 m .25478 .72706 L p .24848 .75061 L F P
0 g
s
.765 .698 .788 r
.24848 .75061 m .24841 .75058 L .24075 .73929 L p F P
0 g
s
.776 .689 .768 r
.23031 .76834 m .24845 .75064 L .24841 .75058 L p F P
0 g
s
.776 .689 .768 r
.24841 .75058 m .23344 .74578 L p .23031 .76834 L F P
0 g
s
.771 .7 .784 r
.24841 .75058 m .24075 .73929 L .23344 .74578 L closepath p F P
0 g
s
.668 .338 .406 r
.37695 .95972 m .37966 .95138 L p .40858 .96237 L F P
0 g
s
.691 .372 .431 r
.37695 .95972 m .37111 .951 L .37966 .95138 L closepath p F P
0 g
s
.708 .669 .81 r
.36606 .69987 m .37688 .69376 L .3973 .69478 L p F P
0 g
s
.71 .676 .815 r
.36606 .69987 m .37688 .69376 L .36156 .69267 L closepath p F P
0 g
s
.721 .681 .81 r
.36156 .69267 m .36606 .69987 L p .33305 .70389 L F P
0 g
s
.803 .633 .671 r
.21057 .84339 m .21144 .84168 L .20983 .84121 L closepath p F P
0 g
s
.798 .649 .697 r
.20325 .8257 m .20553 .82193 L p .21144 .84168 L F P
0 g
s
.798 .649 .697 r
.21144 .84168 m .20983 .84121 L .20325 .8257 L p F P
0 g
s
.644 .33 .425 r
.44295 .96132 m .43232 .95117 L .44585 .95069 L closepath p F P
0 g
s
.647 .329 .419 r
.43232 .95117 m .44295 .96132 L p .41032 .96237 L F P
0 g
s
.749 .46 .493 r
.30561 .94572 m .30055 .94504 L .29783 .93285 L p F P
0 g
s
.755 .464 .49 r
.27783 .92989 m .29783 .93285 L .30055 .94504 L p F P
0 g
s
.029 .275 .772 r
.76712 .10815 m .77065 .1185 L .76162 .11108 L p F P
0 g
s
.029 .275 .772 r
.76162 .11108 m .75799 .10077 L .76712 .10815 L p F P
0 g
s
.802 .612 .645 r
.21604 .85977 m .20406 .85634 L p .2139 .87498 L F P
0 g
s
.802 .612 .645 r
.2139 .87498 m .21755 .8659 L .21604 .85977 L p F P
0 g
s
.803 .631 .669 r
.21604 .85977 m .21057 .84339 L .20406 .85634 L closepath p F P
0 g
s
.708 .421 .487 r
.37111 .951 m .34538 .94962 L .34445 .94691 L p F P
0 g
s
.713 .424 .485 r
.34538 .94962 m .34389 .94953 L .34445 .94691 L closepath p F P
0 g
s
.645 .61 .8 r
.50474 .71515 m .53077 .70663 L .53774 .72105 L p F P
0 g
s
.645 .612 .801 r
.53055 .70617 m .53077 .70663 L .50474 .71515 L p F P
0 g
s
.645 .612 .801 r
.50474 .71515 m .50372 .71307 L .53055 .70617 L p F P
0 g
s
.695 .368 .419 r
.37111 .951 m .37695 .95972 L .37611 .96191 L p F P
0 g
s
.695 .368 .419 r
.34538 .94962 m .37111 .951 L p .37611 .96191 L F P
0 g
s
.619 .734 .928 r
.29395 .4346 m .28184 .43766 L .27397 .42963 L p F P
0 g
s
.787 .685 .752 r
.23031 .76834 m .22237 .77699 L .21468 .76439 L p F P
0 g
s
.787 .685 .752 r
.21468 .76439 m .21552 .76347 L .23031 .76834 L p F P
0 g
s
.776 .689 .768 r
.23344 .74578 m .21552 .76347 L .23031 .76834 L p F P
0 g
s
.756 .701 .8 r
.26658 .71773 m .25478 .72706 L .27049 .73171 L p F P
0 g
s
.756 .701 .8 r
.27049 .73171 m .27424 .7288 L .26658 .71773 L p F P
0 g
s
.678 .646 .81 r
.46059 .69103 m .46477 .69864 L p .43187 .69721 L F P
0 g
s
.678 .646 .81 r
.43187 .69721 m .44123 .69302 L .46059 .69103 L p F P
0 g
s
.68 .652 .815 r
.43187 .69721 m .44123 .69302 L .43008 .69405 L closepath p F P
0 g
s
.804 .634 .67 r
.20406 .85634 m .21057 .84339 L .20983 .84121 L p F P
0 g
s
0 .04 .609 r
.77681 .12709 m .77976 .13756 L .77364 .12896 L p F P
0 g
s
0 .04 .609 r
.77364 .12896 m .77065 .1185 L .77681 .12709 L p F P
0 g
s
.804 .634 .67 r
.20983 .84121 m .19642 .83706 L p .20406 .85634 L F P
0 g
s
.803 .651 .693 r
.20983 .84121 m .20325 .8257 L .19642 .83706 L closepath p F P
0 g
s
.644 .661 .852 r
.466 .43937 m .47856 .43394 L .47933 .43519 L closepath p F P
0 g
s
0 0 .211 r
.48694 .36994 m .48022 .37887 L .48387 .36631 L p F P
0 g
s
0 0 .211 r
.48387 .36631 m .48839 .36032 L .48694 .36994 L p F P
0 g
s
.626 .584 .787 r
.54468 .73589 m .57091 .72915 L p .57717 .745 L F P
0 g
s
.626 .584 .787 r
.56785 .7222 m .57091 .72915 L .54468 .73589 L p F P
0 g
s
.626 .584 .787 r
.54468 .73589 m .54233 .73057 L .56785 .7222 L p F P
0 g
s
.616 .294 .401 r
.44585 .95069 m .4721 .94887 L p .47406 .95929 L F P
0 g
s
.616 .294 .401 r
.44295 .96132 m .44585 .95069 L p .47406 .95929 L F P
0 g
s
.752 .696 .798 r
.29735 .71133 m .27424 .7288 L .26658 .71773 L p F P
0 g
s
.801 .61 .644 r
.22014 .87663 m .21755 .8659 L .2139 .87498 L closepath p F P
0 g
s
.774 .883 .925 r
.63707 .39834 m .63039 .40257 L .63365 .39583 L closepath p F P
0 g
s
.758 .868 .928 r
.63067 .39339 m .63365 .39583 L .63039 .40257 L p F P
0 g
s
.758 .868 .928 r
.60438 .40903 m .63067 .39339 L p .63039 .40257 L F P
0 g
s
.648 .629 .817 r
.52379 .69332 m .53055 .70617 L .50372 .71307 L p F P
0 g
s
.648 .629 .817 r
.50372 .71307 m .49772 .70181 L .52379 .69332 L p F P
0 g
s
.692 .676 .829 r
.40472 .69471 m .3973 .69478 L .39169 .68598 L p F P
0 g
s
.704 .68 .824 r
.3973 .69478 m .39169 .68598 L .37688 .69376 L closepath p F P
0 g
s
.691 .67 .825 r
.43008 .69405 m .42467 .68522 L .40472 .69471 L closepath p F P
0 g
s
.692 .676 .829 r
.41742 .67357 m .42467 .68522 L .40472 .69471 L p F P
0 g
s
.692 .676 .829 r
.39169 .68598 m .41742 .67357 L p .40472 .69471 L F P
0 g
s
.721 .681 .81 r
.33305 .70389 m .35295 .69161 L .36156 .69267 L p F P
0 g
s
.725 .687 .813 r
.35295 .69161 m .33305 .70389 L .32556 .69257 L p F P
0 g
s
.788 .687 .753 r
.21486 .78526 m .22237 .77699 L .21468 .76439 L p F P
0 g
s
.777 .517 .542 r
.26707 .92815 m .25887 .92661 L .25888 .91377 L p F P
0 g
s
.784 .522 .541 r
.24113 .91013 m .25888 .91377 L .25887 .92661 L p F P
0 g
s
.938 .943 .767 r
.76171 .27801 m .77145 .26326 L .7712 .27425 L p F P
0 g
s
.938 .943 .767 r
.76169 .27885 m .76171 .27801 L p .7712 .27425 L F P
0 g
s
.938 .943 .767 r
.7712 .27425 m .76679 .28077 L .76169 .27885 L p F P
0 g
s
.962 .821 .657 r
.51955 .25344 m .52202 .24746 L .51509 .24292 L p F P
0 g
s
.686 .792 .931 r
.51614 .4386 m .51233 .43487 L .52398 .43018 L closepath p F P
0 g
s
.588 .495 .716 r
.60462 .82144 m .59951 .80392 L .61104 .79972 L p F P
0 g
s
.596 .519 .738 r
.59951 .80392 m .5987 .80148 L .61104 .79972 L closepath p F P
0 g
s
.596 .517 .736 r
.61104 .79972 m .5987 .80148 L .59342 .78541 L p F P
0 g
s
.734 .841 .93 r
.58892 .41766 m .57818 .42328 L .57149 .4176 L p F P
0 g
s
.717 .838 .939 r
.54531 .43021 m .57149 .4176 L .57818 .42328 L p F P
0 g
s
.595 .331 .486 r
.51859 .93174 m .53672 .92894 L .53553 .94085 L p F P
0 g
s
.595 .331 .486 r
.53553 .94085 m .53183 .94142 L .51859 .93174 L p F P
0 g
s
.741 .698 .811 r
.30187 .71238 m .29992 .70955 L .29735 .71133 L closepath p F P
0 g
s
.96 .819 .386 r
.787 .20183 m .78832 .21255 L .7904 .20069 L p F P
0 g
s
.96 .819 .386 r
.7904 .20069 m .78907 .18995 L .787 .20183 L p F P
0 g
s
.678 .665 .83 r
.44123 .69302 m .43008 .69405 L .42467 .68522 L p F P
0 g
s
.531 .656 .915 r
.69669 .06362 m .70807 .06285 L .71347 .07272 L p F P
0 g
s
.484 .625 .913 r
.72425 .06308 m .70807 .06285 L .71347 .07272 L p F P
0 g
s
.484 .625 .913 r
.71347 .07272 m .73047 .07314 L .72425 .06308 L p F P
0 g
s
.596 .517 .736 r
.59342 .78541 m .61698 .77664 L p .61104 .79972 L F P
0 g
s
.601 .539 .757 r
.59342 .78541 m .59171 .78074 L .61698 .77664 L closepath p F P
0 g
s
.63 .603 .804 r
.56398 .71413 m .56785 .7222 L .54233 .73057 L p F P
0 g
s
.63 .603 .804 r
.54233 .73057 m .53774 .72105 L .56398 .71413 L p F P
0 g
s
.805 .654 .695 r
.20325 .8257 m .20553 .82193 L .20098 .82048 L closepath p F P
0 g
s
.798 .667 .719 r
.19574 .81023 m .20187 .80148 L p .20553 .82193 L F P
0 g
s
.798 .667 .719 r
.20553 .82193 m .20098 .82048 L .19574 .81023 L p F P
0 g
s
.636 .711 .901 r
.66353 .0619 m .69038 .05396 L .69669 .06362 L p F P
0 g
s
.797 .685 .741 r
.20051 .78029 m .21486 .78526 L .20187 .80148 L p F P
0 g
s
.788 .687 .753 r
.21468 .76439 m .20051 .78029 L .21486 .78526 L p F P
0 g
s
.789 .885 .915 r
.657 .37579 m .66328 .38083 L .63707 .39834 L p F P
0 g
s
.789 .885 .915 r
.63567 .39026 m .657 .37579 L p .63707 .39834 L F P
0 g
s
.789 .885 .915 r
.63707 .39834 m .63365 .39583 L .63567 .39026 L p F P
0 g
s
.796 .587 .618 r
.22612 .89293 m .22237 .89203 L .22014 .87663 L p F P
0 g
s
.804 .592 .615 r
.2139 .87498 m .22014 .87663 L .22237 .89203 L p F P
0 g
s
.706 .687 .829 r
.38435 .67467 m .39169 .68598 L .37688 .69376 L p F P
0 g
s
.706 .687 .829 r
.35867 .68834 m .38435 .67467 L p .37688 .69376 L F P
0 g
s
.706 .687 .829 r
.37688 .69376 m .36156 .69267 L .35867 .68834 L p F P
0 g
s
.572 .402 .612 r
.59058 .8908 m .58888 .87652 L .61479 .86898 L p F P
0 g
s
.583 .432 .643 r
.61314 .85936 m .61479 .86898 L .58888 .87652 L p F P
0 g
s
.695 .368 .419 r
.37611 .96191 m .35299 .96065 L .34538 .94962 L p F P
0 g
s
.698 .369 .415 r
.34389 .94953 m .34538 .94962 L .35299 .96065 L p F P
0 g
s
.601 .537 .755 r
.61698 .77664 m .59171 .78074 L .58625 .76576 L p F P
0 g
s
.698 .369 .415 r
.35299 .96065 m .33987 .95982 L .34389 .94953 L p F P
0 g
s
.718 .39 .422 r
.32243 .94749 m .34389 .94953 L .33987 .95982 L p F P
0 g
s
.97 .888 .513 r
.78564 .23433 m .78513 .23593 L .78509 .23472 L closepath p F P
0 g
s
.663 .637 .813 r
.46477 .69864 m .49067 .68865 L .49772 .70181 L p F P
0 g
s
.664 .64 .816 r
.48925 .68601 m .49067 .68865 L .46477 .69864 L p F P
0 g
s
.664 .64 .816 r
.46477 .69864 m .46059 .69103 L .48925 .68601 L p F P
0 g
s
.579 .47 .693 r
.60579 .82614 m .60462 .82144 L .6295 .81253 L p F P
0 g
s
.588 .495 .716 r
.62527 .79818 m .6295 .81253 L .60462 .82144 L p F P
0 g
s
.588 .495 .716 r
.61104 .79972 m .62527 .79818 L p .60462 .82144 L F P
0 g
s
.713 .76 .889 r
.32239 .4355 m .31458 .43939 L .30684 .43123 L p F P
0 g
s
.937 .943 .768 r
.76679 .28077 m .76113 .28908 L .76169 .27885 L closepath p F P
0 g
s
.806 .654 .694 r
.19642 .83706 m .20325 .8257 L .20098 .82048 L p F P
0 g
s
.752 .696 .798 r
.26658 .71773 m .28064 .70694 L .29735 .71133 L p F P
0 g
s
.743 .703 .814 r
.29231 .69876 m .28064 .70694 L .29735 .71133 L p F P
0 g
s
.743 .703 .814 r
.29735 .71133 m .29992 .70955 L .29231 .69876 L p F P
0 g
s
.976 .923 .647 r
.77876 .23837 m .77921 .24925 L .78513 .23593 L p F P
0 g
s
.976 .923 .647 r
.78043 .2345 m .77876 .23837 L p .78513 .23593 L F P
0 g
s
.976 .923 .647 r
.78513 .23593 m .78509 .23472 L .78043 .2345 L p F P
0 g
s
.677 .66 .826 r
.46059 .69103 m .45765 .68606 L .44123 .69302 L closepath p F P
0 g
s
.678 .665 .83 r
.45049 .67412 m .45765 .68606 L .44123 .69302 L p F P
0 g
s
.678 .665 .83 r
.42467 .68522 m .45049 .67412 L p .44123 .69302 L F P
0 g
s
.581 .472 .695 r
.60883 .83808 m .60579 .82614 L .63246 .82409 L p F P
0 g
s
.579 .47 .693 r
.6295 .81253 m .63246 .82409 L .60579 .82614 L p F P
0 g
s
.793 .884 .912 r
.66488 .38206 m .66328 .38083 L .66591 .379 L closepath p F P
0 g
s
.623 .317 .432 r
.47607 .95194 m .4721 .94887 L .47686 .94851 L closepath p F P
0 g
s
.616 .294 .401 r
.4721 .94887 m .47607 .95194 L .47406 .95929 L p F P
0 g
s
.894 .843 .385 r
.49784 .32807 m .49618 .33975 L .50046 .32704 L p F P
0 g
s
.894 .843 .385 r
.50046 .32704 m .50133 .31561 L .49784 .32807 L p F P
0 g
s
.327 .206 .558 r
.48322 .4006 m .47043 .41301 L .46931 .40018 L p F P
0 g
s
.327 .206 .558 r
.46931 .40018 m .47907 .39062 L .48322 .4006 L p F P
0 g
s
.737 .698 .813 r
.32556 .69257 m .29992 .70955 L .29231 .69876 L p F P
0 g
s
.716 .69 .824 r
.36156 .69267 m .35867 .68834 L .35295 .69161 L closepath p F P
0 g
s
.601 .537 .755 r
.58625 .76576 m .60579 .75831 L p .61698 .77664 L F P
0 g
s
.606 .558 .774 r
.58625 .76576 m .58476 .76208 L .60579 .75831 L closepath p F P
0 g
s
.806 .654 .694 r
.20098 .82048 m .19094 .81712 L p .19642 .83706 L F P
0 g
s
.803 .669 .716 r
.20098 .82048 m .19574 .81023 L .19094 .81712 L closepath p F P
0 g
s
.594 .283 .411 r
.47686 .94851 m .50668 .94517 L .50409 .95604 L p F P
0 g
s
.594 .283 .411 r
.47607 .95194 m .47686 .94851 L p .50409 .95604 L F P
0 g
s
.962 .821 .657 r
.51509 .24292 m .51475 .24377 L .51955 .25344 L p F P
0 g
s
.965 .82 .65 r
.50991 .25655 m .51443 .2663 L .51955 .25344 L p F P
0 g
s
.965 .82 .65 r
.51955 .25344 m .51475 .24377 L .50991 .25655 L p F P
0 g
s
.918 .791 .706 r
.51554 .22098 m .52166 .23028 L .52863 .21681 L p F P
0 g
s
.918 .791 .706 r
.52863 .21681 m .52243 .20753 L .51554 .22098 L p F P
0 g
s
.818 .896 .898 r
.69204 .36305 m .68947 .36114 L .69329 .35816 L closepath p F P
0 g
s
.99 .888 .61 r
.50471 .29199 m .50597 .30279 L .51139 .28974 L p F P
0 g
s
.99 .888 .61 r
.51139 .28974 m .50949 .27915 L .50471 .29199 L p F P
0 g
s
.606 .557 .773 r
.60579 .75831 m .58476 .76208 L .57783 .74484 L p F P
0 g
s
.334 .529 .896 r
.741 .0847 m .73667 .08346 L .73047 .07314 L p F P
0 g
s
.755 .464 .49 r
.30055 .94504 m .28052 .94208 L .27783 .92989 L p F P
0 g
s
.76 .467 .488 r
.26707 .92815 m .27783 .92989 L .28052 .94208 L p F P
0 g
s
.746 .858 .932 r
.58892 .41766 m .60438 .40903 L .59781 .40376 L p F P
0 g
s
.746 .858 .932 r
.59781 .40376 m .59621 .40465 L .58892 .41766 L p F P
0 g
s
.734 .841 .93 r
.57149 .4176 m .59621 .40465 L .58892 .41766 L p F P
0 g
s
.98 .916 .636 r
.78509 .23472 m .78043 .2345 L .78448 .2251 L closepath p F P
0 g
s
.804 .592 .615 r
.22237 .89203 m .20998 .88875 L .2139 .87498 L p F P
0 g
s
.811 .599 .615 r
.19843 .87055 m .2139 .87498 L .20998 .88875 L p F P
0 g
s
.802 .612 .645 r
.20406 .85634 m .19843 .87055 L .2139 .87498 L p F P
0 g
s
.531 .66 .919 r
.70807 .06285 m .69669 .06362 L .69038 .05396 L p F P
0 g
s
.572 .446 .671 r
.61222 .85392 m .60883 .83808 L .63381 .82929 L p F P
0 g
s
.581 .472 .695 r
.63246 .82409 m .63381 .82929 L .60883 .83808 L p F P
0 g
s
.805 .673 .718 r
.19574 .81023 m .20187 .80148 L .1887 .79688 L closepath p F P
0 g
s
.797 .685 .741 r
.18811 .79589 m .20051 .78029 L p .20187 .80148 L F P
0 g
s
.797 .685 .741 r
.20187 .80148 m .1887 .79688 L .18811 .79589 L p F P
0 g
s
.793 .752 .815 r
.32239 .4355 m .3402 .4228 L .33272 .41052 L p F P
0 g
s
.793 .752 .815 r
.33272 .41052 m .31275 .42799 L .32239 .4355 L p F P
0 g
s
.713 .76 .889 r
.30684 .43123 m .31275 .42799 L .32239 .4355 L p F P
0 g
s
.814 .624 .645 r
.18913 .85171 m .20406 .85634 L .19843 .87055 L p F P
0 g
s
.804 .634 .67 r
.19642 .83706 m .18913 .85171 L .20406 .85634 L p F P
0 g
s
.791 .557 .583 r
.24113 .91013 m .2239 .9063 L .22612 .89293 L p F P
0 g
s
.798 .563 .583 r
.22237 .89203 m .22612 .89293 L .2239 .9063 L p F P
0 g
s
.91 .929 .814 r
.74946 .29368 m .74876 .30474 L .76113 .28908 L p F P
0 g
s
.91 .929 .814 r
.76126 .27859 m .74946 .29368 L p .76113 .28908 L F P
0 g
s
.91 .929 .814 r
.76113 .28908 m .76169 .27885 L .76126 .27859 L p F P
0 g
s
.63 .603 .805 r
.56398 .71413 m .53774 .72105 L .53077 .70663 L p F P
0 g
s
.725 .687 .813 r
.32556 .69257 m .33211 .68848 L .35295 .69161 L p F P
0 g
s
.718 .695 .827 r
.35122 .67741 m .33211 .68848 L .35295 .69161 L p F P
0 g
s
.718 .695 .827 r
.35295 .69161 m .35867 .68834 L .35122 .67741 L p F P
0 g
s
.716 .828 .935 r
.57149 .4176 m .54531 .43021 L .53846 .42415 L p F P
0 g
s
.871 .717 .689 r
.33272 .41052 m .33313 .40951 L .34313 .41693 L p F P
0 g
s
.871 .717 .689 r
.34313 .41693 m .3402 .4228 L .33272 .41052 L p F P
0 g
s
.718 .39 .422 r
.33987 .95982 m .32893 .95878 L .32243 .94749 L p F P
0 g
s
.72 .383 .407 r
.30561 .94572 m .32243 .94749 L .32893 .95878 L p F P
0 g
s
.903 .709 .204 r
.78718 .17932 m .78907 .18995 L .78935 .17879 L p F P
0 g
s
.903 .709 .204 r
.78935 .17879 m .78748 .16813 L .78718 .17932 L p F P
0 g
s
.649 .63 .817 r
.52379 .69332 m .49772 .70181 L .49067 .68865 L p F P
0 g
s
.566 .341 .533 r
.56449 .92353 m .5646 .91077 L .59145 .90434 L p F P
0 g
s
.59 .36 .536 r
.5646 .91077 m .56449 .92353 L .53672 .92894 L p F P
0 g
s
.582 .383 .577 r
.59058 .8908 m .59145 .90434 L .5646 .91077 L p F P
0 g
s
.931 .913 .526 r
.50554 .30678 m .50315 .30984 L .50597 .30279 L closepath p F P
0 g
s
.665 .655 .83 r
.48359 .67629 m .48925 .68601 L .46059 .69103 L p F P
0 g
s
.665 .655 .83 r
.46059 .69103 m .45765 .68606 L .48359 .67629 L p F P
0 g
s
.571 .31 .482 r
.53553 .94085 m .53672 .92894 L .56449 .92353 L p F P
0 g
s
.619 .734 .928 r
.27397 .42963 m .28556 .42661 L .29395 .4346 L p F P
0 g
s
.621 .733 .926 r
.29903 .42299 m .28556 .42661 L .29395 .4346 L p F P
0 g
s
.621 .733 .926 r
.29395 .4346 m .30684 .43123 L .29903 .42299 L p F P
0 g
s
.647 .753 .927 r
.47933 .43519 m .50533 .42712 L .51233 .43487 L p F P
0 g
s
.643 .66 .852 r
.47856 .43394 m .47933 .43519 L .50533 .42712 L p F P
0 g
s
.696 .677 .828 r
.41742 .67357 m .39169 .68598 L .38435 .67467 L p F P
0 g
s
.783 .703 .775 r
.21912 .74068 m .23344 .74578 L .21552 .76347 L p F P
0 g
s
.773 .705 .787 r
.23298 .72819 m .21912 .74068 L .23344 .74578 L p F P
0 g
s
.773 .705 .787 r
.23344 .74578 m .24075 .73929 L .23298 .72819 L p F P
0 g
s
.771 .702 .786 r
.25478 .72706 m .24075 .73929 L .23298 .72819 L p F P
0 g
s
.798 .563 .583 r
.2239 .9063 m .22278 .90603 L .22237 .89203 L p F P
0 g
s
.806 .57 .581 r
.20998 .88875 m .22237 .89203 L .22278 .90603 L p F P
0 g
s
.709 .688 .828 r
.38435 .67467 m .35867 .68834 L .35122 .67741 L p F P
0 g
s
.816 .646 .672 r
.18199 .83222 m .19642 .83706 L .18913 .85171 L p F P
0 g
s
.806 .654 .694 r
.19094 .81712 m .18199 .83222 L .19642 .83706 L p F P
0 g
s
.792 .877 .909 r
.66591 .379 m .66328 .38083 L .657 .37579 L p F P
0 g
s
.936 .698 .553 r
.32882 .40539 m .33313 .40951 L .3352 .39753 L p F P
0 g
s
.936 .698 .553 r
.32517 .39891 m .32882 .40539 L p .3352 .39753 L F P
0 g
s
.936 .698 .553 r
.3352 .39753 m .32669 .3895 L .32517 .39891 L p F P
0 g
s
.771 .702 .786 r
.23298 .72819 m .23986 .72211 L .25478 .72706 L p F P
0 g
s
.76 .707 .802 r
.25887 .70687 m .23986 .72211 L .25478 .72706 L p F P
0 g
s
.76 .707 .802 r
.25478 .72706 m .26658 .71773 L .25887 .70687 L p F P
0 g
s
.784 .522 .541 r
.25887 .92661 m .24108 .92297 L .24113 .91013 L p F P
0 g
s
.79 .528 .541 r
.2239 .9063 m .24113 .91013 L .24108 .92297 L p F P
0 g
s
.681 .667 .829 r
.45049 .67412 m .42467 .68522 L .41742 .67357 L p F P
0 g
s
.643 .66 .852 r
.49827 .4179 m .49656 .41827 L .47856 .43394 L p F P
0 g
s
.643 .66 .852 r
.50533 .42712 m .49827 .4179 L p .47856 .43394 L F P
0 g
s
.562 .557 .806 r
.47225 .42006 m .49656 .41827 L .47856 .43394 L closepath p F P
0 g
s
.815 .895 .9 r
.66591 .379 m .68947 .36114 L .68333 .35632 L p F P
0 g
s
.815 .895 .9 r
.68333 .35632 m .66897 .36736 L .66591 .379 L p F P
0 g
s
.792 .877 .909 r
.657 .37579 m .66897 .36736 L .66591 .379 L p F P
0 g
s
.791 .693 .756 r
.21468 .76439 m .21552 .76347 L .21369 .76281 L closepath p F P
0 g
s
.783 .703 .775 r
.20688 .75293 m .21912 .74068 L p .21552 .76347 L F P
0 g
s
.783 .703 .775 r
.21552 .76347 m .21369 .76281 L .20688 .75293 L p F P
0 g
s
.051 0 .357 r
.48644 .38077 m .47907 .39062 L .48022 .37887 L p F P
0 g
s
.051 0 .357 r
.48022 .37887 m .48694 .36994 L .48644 .38077 L p F P
0 g
s
.793 .693 .754 r
.20051 .78029 m .21468 .76439 L .21369 .76281 L p F P
0 g
s
.805 .673 .718 r
.19094 .81712 m .19574 .81023 L .1887 .79688 L p F P
0 g
s
.76 .467 .488 r
.28052 .94208 m .26405 .93945 L .26707 .92815 L p F P
0 g
s
.774 .481 .491 r
.25887 .92661 m .26707 .92815 L .26405 .93945 L p F P
0 g
s
.685 .766 .913 r
.52398 .43018 m .51233 .43487 L .50533 .42712 L p F P
0 g
s
.621 .565 .77 r
.57783 .74484 m .57717 .745 L .57781 .74479 L closepath p F P
0 g
s
.626 .584 .787 r
.57091 .72915 m .57781 .74479 L .57717 .745 L p F P
0 g
s
0 0 .122 r
.48977 .3646 m .48694 .36994 L .48839 .36032 L p F P
0 g
s
0 0 .122 r
.48839 .36032 m .49249 .35232 L .48977 .3646 L p F P
0 g
s
.606 .557 .773 r
.57783 .74484 m .60432 .74018 L p .60579 .75831 L F P
0 g
s
.604 .556 .773 r
.6023 .73515 m .60432 .74018 L .57783 .74484 L p F P
0 g
s
.604 .556 .773 r
.57783 .74484 m .57781 .74479 L .6023 .73515 L p F P
0 g
s
.61 .576 .791 r
.5974 .72406 m .6023 .73515 L .57781 .74479 L p F P
0 g
s
.61 .576 .791 r
.57781 .74479 m .57091 .72915 L .5974 .72406 L p F P
0 g
s
.587 .494 .716 r
.62527 .79818 m .61104 .79972 L .62431 .79487 L closepath p F P
0 g
s
.596 .517 .736 r
.61823 .77647 m .62431 .79487 L .61104 .79972 L p F P
0 g
s
.596 .517 .736 r
.61698 .77664 m .61823 .77647 L p .61104 .79972 L F P
0 g
s
.594 .283 .411 r
.50409 .95604 m .48841 .95779 L .47607 .95194 L p F P
0 g
s
.596 .279 .403 r
.48841 .95779 m .47406 .95929 L .47607 .95194 L closepath p F P
0 g
s
.757 .704 .802 r
.28064 .70694 m .26658 .71773 L .25887 .70687 L p F P
0 g
s
.793 .693 .754 r
.21369 .76281 m .20157 .75829 L p .20051 .78029 L F P
0 g
s
.787 .704 .772 r
.21369 .76281 m .20688 .75293 L .20157 .75829 L closepath p F P
0 g
s
.728 .694 .818 r
.32556 .69257 m .33211 .68848 L .32153 .6866 L closepath p F P
0 g
s
.737 .698 .813 r
.32153 .6866 m .32556 .69257 L p .29231 .69876 L F P
0 g
s
.89 .925 .838 r
.73564 .30928 m .74946 .29368 L .74876 .30474 L p F P
0 g
s
.89 .925 .838 r
.74876 .30474 m .74143 .31286 L .73564 .30928 L p F P
0 g
s
.334 .529 .896 r
.73047 .07314 m .73614 .07468 L .741 .0847 L p F P
0 g
s
.212 .445 .867 r
.74906 .08049 m .75381 .09057 L .741 .0847 L p F P
0 g
s
.212 .445 .867 r
.741 .0847 m .73614 .07468 L .74906 .08049 L p F P
0 g
s
.558 .366 .576 r
.59145 .90434 m .59058 .8908 L .61656 .88331 L p F P
0 g
s
.572 .402 .612 r
.61479 .86898 m .61656 .88331 L .59058 .8908 L p F P
0 g
s
.762 .855 .92 r
.63067 .39339 m .60438 .40903 L .59781 .40376 L p F P
0 g
s
.72 .383 .407 r
.30338 .95114 m .30561 .94572 L p .32893 .95878 L F P
0 g
s
.74 .415 .432 r
.30338 .95114 m .30055 .94504 L .30561 .94572 L closepath p F P
0 g
s
.777 .53 0 r
.78506 .15758 m .78748 .16813 L .78588 .15771 L p F P
0 g
s
.777 .53 0 r
.78588 .15771 m .78347 .14714 L .78506 .15758 L p F P
0 g
s
.666 .657 .831 r
.48359 .67629 m .45765 .68606 L .45049 .67412 L p F P
0 g
s
.562 .418 .642 r
.61222 .85392 m .63726 .84521 L p .63846 .86088 L F P
0 g
s
.562 .418 .642 r
.63846 .86088 m .61314 .85936 L .61222 .85392 L p F P
0 g
s
.572 .446 .671 r
.63381 .82929 m .63726 .84521 L .61222 .85392 L p F P
0 g
s
.963 .927 .713 r
.77104 .25241 m .77145 .26326 L .77921 .24925 L p F P
0 g
s
.963 .927 .713 r
.77921 .24925 m .77876 .23837 L .77104 .25241 L p F P
0 g
s
.771 .864 .918 r
.63365 .39583 m .63067 .39339 L .63567 .39026 L closepath p F P
0 g
s
.988 .88 .541 r
.78318 .2144 m .78448 .2251 L .78832 .21255 L p F P
0 g
s
.988 .88 .541 r
.78832 .21255 m .787 .20183 L .78318 .2144 L p F P
0 g
s
.816 .666 .696 r
.17699 .81207 m .19094 .81712 L .18199 .83222 L p F P
0 g
s
.805 .673 .718 r
.18764 .79649 m .17699 .81207 L .19094 .81712 L p F P
0 g
s
.805 .673 .718 r
.1887 .79688 m .18764 .79649 L p .19094 .81712 L F P
0 g
s
.668 .338 .406 r
.40858 .96237 m .37901 .96198 L .37695 .95972 L p F P
0 g
s
.671 .338 .401 r
.37901 .96198 m .37611 .96191 L .37695 .95972 L closepath p F P
0 g
s
.891 .929 .837 r
.73365 .32138 m .74143 .31286 L .73564 .30928 L p F P
0 g
s
.804 .688 .737 r
.20051 .78029 m .18811 .79589 L .18032 .78331 L p F P
0 g
s
.804 .688 .737 r
.18032 .78331 m .18676 .77508 L .20051 .78029 L p F P
0 g
s
.793 .693 .754 r
.20157 .75829 m .18676 .77508 L .20051 .78029 L p F P
0 g
s
.757 .704 .802 r
.25887 .70687 m .26485 .70222 L .28064 .70694 L p F P
0 g
s
.747 .709 .816 r
.28464 .68816 m .26485 .70222 L .28064 .70694 L p F P
0 g
s
.747 .709 .816 r
.28064 .70694 m .29231 .69876 L .28464 .68816 L p F P
0 g
s
.57 .262 .407 r
.50409 .95604 m .50668 .94517 L .53183 .94142 L p F P
0 g
s
.919 .797 .71 r
.50858 .23451 m .51554 .22098 L .52166 .23028 L p F P
0 g
s
.919 .797 .71 r
.5117 .23932 m .50858 .23451 L p .52166 .23028 L F P
0 g
s
.919 .797 .71 r
.52166 .23028 m .51509 .24292 L .5117 .23932 L p F P
0 g
s
.721 .703 .832 r
.34372 .66665 m .35122 .67741 L .33211 .68848 L p F P
0 g
s
.721 .703 .832 r
.31801 .68171 m .34372 .66665 L p .33211 .68848 L F P
0 g
s
.721 .703 .832 r
.33211 .68848 m .32153 .6866 L .31801 .68171 L p F P
0 g
s
.745 .411 .417 r
.30055 .94504 m .30338 .95114 L .30111 .9558 L p F P
0 g
s
.745 .411 .417 r
.28052 .94208 m .30055 .94504 L p .30111 .9558 L F P
0 g
s
.817 .888 .895 r
.69329 .35816 m .68947 .36114 L .68333 .35632 L p F P
0 g
s
.774 .481 .491 r
.26405 .93945 m .26113 .93891 L .25887 .92661 L p F P
0 g
s
.781 .485 .487 r
.24108 .92297 m .25887 .92661 L .26113 .93891 L p F P
0 g
s
.835 .898 .884 r
.69537 .34678 m .69329 .35816 L .71554 .33906 L p F P
0 g
s
.817 .888 .895 r
.68333 .35632 m .69537 .34678 L .69329 .35816 L p F P
0 g
s
.799 .767 .256 r
.49494 .34038 m .49249 .35232 L .49618 .33975 L p F P
0 g
s
.799 .767 .256 r
.49618 .33975 m .49784 .32807 L .49494 .34038 L p F P
0 g
s
.891 .929 .837 r
.73564 .30928 m .73482 .31019 L .73365 .32138 L p F P
0 g
s
.865 .919 .863 r
.71695 .32784 m .73482 .31019 L .73365 .32138 L p F P
0 g
s
.865 .919 .863 r
.71555 .339 m .71695 .32784 L p .73365 .32138 L F P
0 g
s
.865 .919 .863 r
.73365 .32138 m .71558 .33902 L .71555 .339 L p F P
0 g
s
.561 .461 .699 r
.49116 .40381 m .48322 .4006 L .47043 .41301 L p F P
0 g
s
.561 .461 .699 r
.49774 .41707 m .49116 .40381 L p .47043 .41301 L F P
0 g
s
.561 .461 .699 r
.49656 .41827 m .49774 .41707 L p .47043 .41301 L F P
0 g
s
.561 .461 .699 r
.47043 .41301 m .47225 .42006 L .49656 .41827 L p F P
0 g
s
.972 .827 .64 r
.50526 .2693 m .50949 .27915 L .51443 .2663 L p F P
0 g
s
.972 .827 .64 r
.51443 .2663 m .50991 .25655 L .50526 .2693 L p F P
0 g
s
.63 .603 .805 r
.53077 .70663 m .55703 .69968 L .56398 .71413 L p F P
0 g
s
.63 .604 .805 r
.55602 .69759 m .55703 .69968 L .53077 .70663 L p F P
0 g
s
.63 .604 .805 r
.53077 .70663 m .53055 .70617 L .55602 .69759 L p F P
0 g
s
.633 .622 .821 r
.55008 .6862 m .55602 .69759 L .53055 .70617 L p F P
0 g
s
.633 .622 .821 r
.53055 .70617 m .52379 .69332 L .55008 .6862 L p F P
0 g
s
.975 .915 .591 r
.5001 .30482 m .50471 .29199 L .50597 .30279 L p F P
0 g
s
.975 .915 .591 r
.50063 .31185 m .5001 .30482 L p .50597 .30279 L F P
0 g
s
.975 .915 .591 r
.50597 .30279 m .50315 .30984 L .50063 .31185 L p F P
0 g
s
.562 .419 .644 r
.61479 .86898 m .61314 .85936 L .63846 .86088 L closepath p F P
0 g
s
0 0 .34 r
.7815 .14016 m .78347 .14714 L .77976 .13756 L p F P
0 g
s
0 0 .34 r
.77916 .13302 m .7815 .14016 L p .77976 .13756 L F P
0 g
s
0 0 .34 r
.77976 .13756 m .77681 .12709 L .77916 .13302 L p F P
0 g
s
.003 .271 .773 r
.76301 .09792 m .76712 .10815 L .75799 .10077 L p F P
0 g
s
.003 .271 .773 r
.75799 .10077 m .75381 .09057 L .76301 .09792 L p F P
0 g
s
.861 .92 .868 r
.71558 .33902 m .71554 .33906 L .71555 .339 L closepath p F P
0 g
s
.835 .898 .884 r
.70957 .3344 m .69537 .34678 L p .71554 .33906 L F P
0 g
s
.835 .898 .884 r
.71554 .33906 m .71555 .339 L .70957 .3344 L p F P
0 g
s
.844 .898 .876 r
.71555 .339 m .70957 .3344 L .71695 .32784 L closepath p F P
0 g
s
.737 .698 .813 r
.29231 .69876 m .31314 .68473 L .32153 .6866 L p F P
0 g
s
.741 .705 .817 r
.31314 .68473 m .29231 .69876 L .28464 .68816 L p F P
0 g
s
.61 .233 .304 r
.41032 .96237 m .44291 .96147 L .43809 .97079 L p F P
0 g
s
.61 .233 .304 r
.40987 .96334 m .41032 .96237 L p .43809 .97079 L F P
0 g
s
.647 .329 .419 r
.44295 .96132 m .44291 .96147 L .41032 .96237 L p F P
0 g
s
.647 .29 .352 r
.40987 .96334 m .40858 .96237 L .41032 .96237 L closepath p F P
0 g
s
.639 .259 .309 r
.40858 .96237 m .40987 .96334 L .40514 .97154 L p F P
0 g
s
.639 .259 .309 r
.37901 .96198 m .40858 .96237 L p .40514 .97154 L F P
0 g
s
.811 .599 .615 r
.20998 .88875 m .19451 .88434 L .19843 .87055 L p F P
0 g
s
.818 .607 .617 r
.1835 .86593 m .19843 .87055 L .19451 .88434 L p F P
0 g
s
.814 .624 .645 r
.19843 .87055 m .1835 .86593 L .18913 .85171 L p F P
0 g
s
0 .027 .6 r
.77431 .11971 m .77681 .12709 L .77065 .1185 L p F P
0 g
s
0 .027 .6 r
.77245 .11545 m .77431 .11971 L p .77065 .1185 L F P
0 g
s
0 .027 .6 r
.77065 .1185 m .76712 .10815 L .77245 .11545 L p F P
0 g
s
.806 .57 .581 r
.22278 .90603 m .20785 .9021 L .20998 .88875 L p F P
0 g
s
.814 .577 .581 r
.19451 .88434 m .20998 .88875 L .20785 .9021 L p F P
0 g
s
.691 .802 .934 r
.53846 .42415 m .52398 .43018 L .53372 .41961 L closepath p F P
0 g
s
.685 .766 .913 r
.53154 .41741 m .53372 .41961 L .52398 .43018 L p F P
0 g
s
.685 .766 .913 r
.50533 .42712 m .53154 .41741 L p .52398 .43018 L F P
0 g
s
.649 .63 .817 r
.49067 .68865 m .51677 .68005 L .52379 .69332 L p F P
0 g
s
.649 .632 .82 r
.51625 .67908 m .51677 .68005 L .49067 .68865 L p F P
0 g
s
.649 .632 .82 r
.49067 .68865 m .48925 .68601 L .51625 .67908 L p F P
0 g
s
.609 .576 .791 r
.59221 .71228 m .5974 .72406 L .57091 .72915 L p F P
0 g
s
.609 .576 .791 r
.57091 .72915 m .56785 .7222 L .59221 .71228 L p F P
0 g
s
.639 .259 .309 r
.40514 .97154 m .39339 .97138 L .37901 .96198 L p F P
0 g
s
.641 .256 .3 r
.37611 .96191 m .37901 .96198 L .39339 .97138 L p F P
0 g
s
.801 .686 .737 r
.1887 .79688 m .18811 .79589 L .18764 .79649 L closepath p F P
0 g
s
.641 .256 .3 r
.39339 .97138 m .3705 .97089 L .37611 .96191 L p F P
0 g
s
.666 .285 .314 r
.35299 .96065 m .37611 .96191 L .3705 .97089 L p F P
0 g
s
.531 .66 .919 r
.69038 .05396 m .70207 .05312 L .70807 .06285 L p F P
0 g
s
.484 .634 .92 r
.718 .05326 m .70207 .05312 L .70807 .06285 L p F P
0 g
s
.484 .634 .92 r
.70807 .06285 m .72425 .06308 L .718 .05326 L p F P
0 g
s
.731 .706 .827 r
.32153 .6866 m .31801 .68171 L .31314 .68473 L closepath p F P
0 g
s
.821 .632 .647 r
.17472 .84687 m .18913 .85171 L .1835 .86593 L p F P
0 g
s
.816 .646 .672 r
.18913 .85171 m .17472 .84687 L .18199 .83222 L p F P
0 g
s
.805 .691 .74 r
.18764 .79649 m .18811 .79589 L .18032 .78331 L p F P
0 g
s
.816 .684 .718 r
.17414 .79123 m .18764 .79649 L .17699 .81207 L p F P
0 g
s
.805 .691 .74 r
.18032 .78331 m .17414 .79123 L .18764 .79649 L p F P
0 g
s
.616 .294 .401 r
.47406 .95929 m .44316 .96145 L .44295 .96132 L p F P
0 g
s
.619 .291 .393 r
.44316 .96145 m .44291 .96147 L .44295 .96132 L closepath p F P
0 g
s
.61 .233 .304 r
.43809 .97079 m .42555 .97114 L .40987 .96334 L p F P
0 g
s
.611 .228 .292 r
.42555 .97114 m .40514 .97154 L .40987 .96334 L closepath p F P
0 g
s
.728 .763 .881 r
.31275 .42799 m .30684 .43123 L .29903 .42299 L p F P
0 g
s
.584 .206 .293 r
.44291 .96147 m .44316 .96145 L .46443 .96918 L p F P
0 g
s
.584 .206 .293 r
.46443 .96918 m .43809 .97079 L .44291 .96147 L p F P
0 g
s
.584 .215 .308 r
.44316 .96145 m .47406 .95929 L .46964 .96881 L p F P
0 g
s
.584 .215 .308 r
.46964 .96881 m .46443 .96918 L .44316 .96145 L p F P
0 g
s
.79 .528 .541 r
.24108 .92297 m .22376 .91917 L .2239 .9063 L p F P
0 g
s
.797 .534 .54 r
.22278 .90603 m .2239 .9063 L .22376 .91917 L p F P
0 g
s
.651 .648 .834 r
.50972 .66772 m .51625 .67908 L .48925 .68601 L p F P
0 g
s
.651 .648 .834 r
.48925 .68601 m .48359 .67629 L .50972 .66772 L p F P
0 g
s
.797 .534 .54 r
.22376 .91917 m .22124 .91857 L .22278 .90603 L p F P
0 g
s
.807 .543 .539 r
.20785 .9021 m .22278 .90603 L .22124 .91857 L p F P
0 g
s
.734 .832 .926 r
.59621 .40465 m .57149 .4176 L .56474 .4116 L p F P
0 g
s
.716 .828 .935 r
.53846 .42415 m .56474 .4116 L .57149 .4176 L p F P
0 g
s
.696 .677 .828 r
.38435 .67467 m .41013 .66201 L .41742 .67357 L p F P
0 g
s
.698 .684 .833 r
.41013 .66201 m .38435 .67467 L .37696 .66349 L p F P
0 g
s
.709 .688 .828 r
.35122 .67741 m .37696 .66349 L .38435 .67467 L p F P
0 g
s
.789 .707 .773 r
.21912 .74068 m .20688 .75293 L .19899 .74188 L p F P
0 g
s
.789 .707 .773 r
.19899 .74188 m .20546 .73533 L .21912 .74068 L p F P
0 g
s
.778 .711 .789 r
.22515 .71734 m .20546 .73533 L .21912 .74068 L p F P
0 g
s
.778 .711 .789 r
.21912 .74068 m .23298 .72819 L .22515 .71734 L p F P
0 g
s
.979 .823 .418 r
.7851 .19122 m .787 .20183 L .78907 .18995 L p F P
0 g
s
.979 .823 .418 r
.78907 .18995 m .78718 .17932 L .7851 .19122 L p F P
0 g
s
.776 .709 .789 r
.23986 .72211 m .23298 .72819 L .22515 .71734 L p F P
0 g
s
.615 .595 .808 r
.59048 .70866 m .59221 .71228 L .56785 .7222 L p F P
0 g
s
.615 .595 .808 r
.56785 .7222 m .56398 .71413 L .59048 .70866 L p F P
0 g
s
.942 .924 .762 r
.7614 .26716 m .76171 .27801 L .77145 .26326 L p F P
0 g
s
.942 .924 .762 r
.77145 .26326 m .77104 .25241 L .7614 .26716 L p F P
0 g
s
.993 .877 .563 r
.50315 .30984 m .50133 .31561 L .50063 .31185 L closepath p F P
0 g
s
.549 .385 .612 r
.61656 .88331 m .61479 .86898 L .63846 .86088 L p F P
0 g
s
.776 .709 .789 r
.22515 .71734 m .22566 .71689 L .23986 .72211 L p F P
0 g
s
.764 .712 .804 r
.24996 .69717 m .22566 .71689 L .23986 .72211 L p F P
0 g
s
.764 .712 .804 r
.25241 .69805 m .24996 .69717 L p .23986 .72211 L F P
0 g
s
.764 .712 .804 r
.23986 .72211 m .25887 .70687 L .25241 .69805 L p F P
0 g
s
.822 .654 .674 r
.16809 .82717 m .18199 .83222 L .17472 .84687 L p F P
0 g
s
.816 .666 .696 r
.18199 .83222 m .16809 .82717 L .17699 .81207 L p F P
0 g
s
.33 .535 .902 r
.73614 .07468 m .73047 .07314 L .72425 .06308 L p F P
0 g
s
.681 .667 .829 r
.41742 .67357 m .44329 .66226 L .45049 .67412 L p F P
0 g
s
.683 .671 .833 r
.44329 .66226 m .41742 .67357 L .41013 .66201 L p F P
0 g
s
.666 .285 .314 r
.3705 .97089 m .36514 .9706 L .35299 .96065 L p F P
0 g
s
.657 .253 .267 r
.33987 .95982 m .35299 .96065 L .36514 .9706 L p F P
0 g
s
.712 .695 .832 r
.37696 .66349 m .35122 .67741 L .34372 .66665 L p F P
0 g
s
.79 .709 .775 r
.20157 .75829 m .20688 .75293 L .19899 .74188 L p F P
0 g
s
.801 .753 .809 r
.31275 .42799 m .33272 .41052 L .32882 .40539 L p F P
0 g
s
.801 .753 .809 r
.3044 .41995 m .31275 .42799 L p .32882 .40539 L F P
0 g
s
.728 .763 .881 r
.29903 .42299 m .3044 .41995 L .31275 .42799 L p F P
0 g
s
.745 .411 .417 r
.30111 .9558 m .28615 .95358 L .28052 .94208 L p F P
0 g
s
.748 .407 .406 r
.26405 .93945 m .28052 .94208 L .28615 .95358 L p F P
0 g
s
.907 .739 .662 r
.33313 .40951 m .32882 .40539 L .33272 .41052 L closepath p F P
0 g
s
.77 .857 .915 r
.63567 .39026 m .63067 .39339 L .6242 .38784 L p F P
0 g
s
.762 .855 .92 r
.59781 .40376 m .6242 .38784 L .63067 .39339 L p F P
0 g
s
.601 .537 .755 r
.60579 .75831 m .61126 .75745 L p .61698 .77664 L F P
0 g
s
.599 .537 .756 r
.61126 .75745 m .60579 .75831 L .61086 .75637 L closepath p F P
0 g
s
.606 .557 .773 r
.60432 .74018 m .61086 .75637 L .60579 .75831 L p F P
0 g
s
.94 .784 .66 r
.51509 .24292 m .51475 .24377 L .5117 .23932 L closepath p F P
0 g
s
.802 .705 .758 r
.18826 .75286 m .20157 .75829 L .18676 .77508 L p F P
0 g
s
.79 .709 .775 r
.19899 .74188 m .18826 .75286 L .20157 .75829 L p F P
0 g
s
.593 .515 .736 r
.61823 .77647 m .61698 .77664 L .61814 .77621 L closepath p F P
0 g
s
.601 .537 .755 r
.61126 .75745 m .61814 .77621 L .61698 .77664 L p F P
0 g
s
.544 .287 .476 r
.5634 .93546 m .56449 .92353 L .59143 .91713 L p F P
0 g
s
.566 .341 .533 r
.59145 .90434 m .59143 .91713 L .56449 .92353 L p F P
0 g
s
.571 .31 .482 r
.56449 .92353 m .5634 .93546 L .53553 .94085 L p F P
0 g
s
.741 .705 .817 r
.28464 .68816 m .2961 .68036 L .31314 .68473 L p F P
0 g
s
.733 .711 .831 r
.31039 .67139 m .2961 .68036 L .31314 .68473 L p F P
0 g
s
.733 .711 .831 r
.31314 .68473 m .31801 .68171 L .31039 .67139 L p F P
0 g
s
.567 .481 .718 r
.62527 .79818 m .62431 .79487 L .64824 .78454 L p F P
0 g
s
.575 .506 .74 r
.64512 .77526 m .64824 .78454 L .62431 .79487 L p F P
0 g
s
.575 .506 .74 r
.62431 .79487 m .61823 .77647 L .64512 .77526 L p F P
0 g
s
.942 .783 .654 r
.50364 .24733 m .50991 .25655 L .51475 .24377 L p F P
0 g
s
.942 .783 .654 r
.50808 .2355 m .50364 .24733 L p .51475 .24377 L F P
0 g
s
.942 .783 .654 r
.51475 .24377 m .5117 .23932 L .50808 .2355 L p F P
0 g
s
.567 .481 .718 r
.64824 .78454 m .65224 .79801 L .62527 .79818 L p F P
0 g
s
.568 .484 .72 r
.6295 .81253 m .62527 .79818 L .65224 .79801 L p F P
0 g
s
.241 .161 .56 r
.48802 .39413 m .48322 .4006 L .47907 .39062 L p F P
0 g
s
.241 .161 .56 r
.47907 .39062 m .48644 .38077 L .48802 .39413 L p F P
0 g
s
.574 .504 .739 r
.64192 .76565 m .64512 .77526 L .61823 .77647 L p F P
0 g
s
.574 .504 .739 r
.61823 .77647 m .61814 .77621 L .64192 .76565 L p F P
0 g
s
.582 .528 .76 r
.6381 .75536 m .64192 .76565 L .61814 .77621 L p F P
0 g
s
.582 .528 .76 r
.61814 .77621 m .61126 .75745 L .6381 .75536 L p F P
0 g
s
.981 .91 .644 r
.77758 .22766 m .78318 .2144 L .78448 .2251 L p F P
0 g
s
.981 .91 .644 r
.77835 .23419 m .77758 .22766 L p .78448 .2251 L F P
0 g
s
.981 .91 .644 r
.78448 .2251 m .78043 .2345 L .77835 .23419 L p F P
0 g
s
.657 .253 .267 r
.33585 .96597 m .33987 .95982 L p .36514 .9706 L F P
0 g
s
.695 .319 .331 r
.33585 .96597 m .32893 .95878 L .33987 .95982 L closepath p F P
0 g
s
.72 .383 .407 r
.32893 .95878 m .30662 .95644 L .30338 .95114 L p F P
0 g
s
.724 .384 .402 r
.30662 .95644 m .30111 .9558 L .30338 .95114 L closepath p F P
0 g
s
.76 .712 .807 r
.25887 .70687 m .26485 .70222 L .25241 .69805 L closepath p F P
0 g
s
.574 .276 .426 r
.53521 .94248 m .53183 .94142 L .53553 .94085 L closepath p F P
0 g
s
.57 .262 .407 r
.53183 .94142 m .53521 .94248 L p .50409 .95604 L F P
0 g
s
.789 .873 .91 r
.63567 .39026 m .657 .37579 L .65065 .37047 L p F P
0 g
s
.789 .873 .91 r
.65065 .37047 m .63889 .37853 L .63567 .39026 L p F P
0 g
s
.77 .857 .915 r
.6242 .38784 m .63889 .37853 L .63567 .39026 L p F P
0 g
s
.781 .485 .487 r
.26113 .93891 m .24332 .93527 L .24108 .92297 L p F P
0 g
s
.787 .489 .485 r
.22376 .91917 m .24108 .92297 L .24332 .93527 L p F P
0 g
s
.666 .657 .831 r
.45049 .67412 m .47647 .66421 L .48359 .67629 L p F P
0 g
s
.667 .659 .832 r
.47647 .66421 m .45049 .67412 L .44329 .66226 L p F P
0 g
s
.725 .705 .831 r
.34372 .66665 m .31801 .68171 L .31039 .67139 L p F P
0 g
s
.562 .46 .696 r
.6295 .81253 m .65356 .80239 L p .64513 .82463 L F P
0 g
s
.562 .46 .696 r
.64513 .82463 m .63246 .82409 L .6295 .81253 L p F P
0 g
s
.568 .484 .72 r
.65224 .79801 m .65356 .80239 L .6295 .81253 L p F P
0 g
s
.54 .321 .53 r
.59143 .91713 m .59145 .90434 L .61751 .89689 L p F P
0 g
s
.558 .366 .576 r
.61656 .88331 m .61751 .89689 L .59145 .90434 L p F P
0 g
s
.751 .719 .822 r
.27691 .67777 m .28464 .68816 L .26485 .70222 L p F P
0 g
s
.751 .719 .822 r
.25108 .69634 m .27691 .67777 L p .26485 .70222 L F P
0 g
s
.751 .719 .822 r
.26485 .70222 m .25241 .69805 L .25108 .69634 L p F P
0 g
s
.633 .623 .822 r
.55008 .6862 m .52379 .69332 L .51677 .68005 L p F P
0 g
s
.555 .185 .294 r
.46964 .96881 m .47406 .95929 L .48841 .95779 L p F P
0 g
s
.547 .252 .418 r
.53521 .94248 m .53553 .94085 L .5634 .93546 L p F P
0 g
s
.979 .834 .629 r
.50081 .28204 m .50471 .29199 L .50949 .27915 L p F P
0 g
s
.979 .834 .629 r
.50949 .27915 m .50526 .2693 L .50081 .28204 L p F P
0 g
s
.823 .674 .699 r
.16357 .8068 m .17699 .81207 L .16809 .82717 L p F P
0 g
s
.816 .684 .718 r
.17699 .81207 m .16357 .8068 L .17414 .79123 L p F P
0 g
s
.614 .597 .81 r
.59048 .70866 m .56398 .71413 L .55703 .69968 L p F P
0 g
s
.712 .808 .924 r
.55792 .40523 m .56474 .4116 L .53846 .42415 L p F P
0 g
s
.712 .808 .924 r
.5355 .41565 m .55792 .40523 L p .53846 .42415 L F P
0 g
s
.712 .808 .924 r
.53846 .42415 m .53372 .41961 L .5355 .41565 L p F P
0 g
s
.993 .869 .536 r
.49581 .31759 m .49784 .32807 L .50133 .31561 L p F P
0 g
s
.993 .869 .536 r
.49608 .31653 m .49581 .31759 L p .50133 .31561 L F P
0 g
s
.993 .869 .536 r
.50133 .31561 m .50063 .31185 L .49608 .31653 L p F P
0 g
s
.915 .926 .806 r
.76169 .27885 m .76126 .27859 L .76171 .27801 L closepath p F P
0 g
s
.81 .696 .738 r
.18676 .77508 m .18032 .78331 L .17245 .77109 L p F P
0 g
s
.81 .696 .738 r
.17245 .77109 m .17356 .76964 L .18676 .77508 L p F P
0 g
s
.802 .705 .758 r
.18676 .77508 m .17356 .76964 L .18826 .75286 L p F P
0 g
s
0 0 0 r
.49293 .35244 m .48977 .3646 L .49249 .35232 L p F P
0 g
s
0 0 0 r
.49249 .35232 m .49494 .34038 L .49293 .35244 L p F P
0 g
s
.694 .302 .3 r
.32893 .95878 m .33585 .96597 L .33369 .96852 L p F P
0 g
s
.694 .302 .3 r
.30662 .95644 m .32893 .95878 L p .33369 .96852 L F P
0 g
s
.58 .526 .759 r
.63448 .74553 m .6381 .75536 L .61126 .75745 L p F P
0 g
s
.58 .526 .759 r
.61126 .75745 m .61086 .75637 L .63448 .74553 L p F P
0 g
s
.936 .726 .247 r
.78473 .1688 m .78718 .17932 L .78748 .16813 L p F P
0 g
s
.936 .726 .247 r
.78748 .16813 m .78506 .15758 L .78473 .1688 L p F P
0 g
s
.588 .549 .778 r
.63114 .73733 m .63448 .74553 L .61086 .75637 L p F P
0 g
s
.588 .549 .778 r
.61086 .75637 m .60432 .74018 L .63114 .73733 L p F P
0 g
s
.562 .462 .699 r
.63381 .82929 m .63246 .82409 L .64513 .82463 L closepath p F P
0 g
s
.645 .76 .932 r
.53154 .41741 m .50533 .42712 L .49827 .4179 L p F P
0 g
s
.913 .917 .806 r
.75555 .2748 m .7614 .26716 L .76171 .27801 L p F P
0 g
s
.913 .917 .806 r
.76171 .27801 m .76126 .27859 L .75555 .2748 L p F P
0 g
s
0 0 .293 r
.48892 .37628 m .48644 .38077 L .48694 .36994 L p F P
0 g
s
0 0 .293 r
.48694 .36994 m .48977 .3646 L .48892 .37628 L p F P
0 g
s
.917 .922 .802 r
.74946 .29368 m .76126 .27859 L .75555 .2748 L p F P
0 g
s
.547 .252 .418 r
.5634 .93546 m .56169 .94413 L .53521 .94248 L p F P
0 g
s
.54 .233 .395 r
.53307 .95173 m .53521 .94248 L .56169 .94413 L p F P
0 g
s
.57 .262 .407 r
.53521 .94248 m .53307 .95173 L .50409 .95604 L p F P
0 g
s
.55 .433 .672 r
.63726 .84521 m .63381 .82929 L .64513 .82463 L p F P
0 g
s
.652 .65 .836 r
.50972 .66772 m .48359 .67629 L .47647 .66421 L p F P
0 g
s
.814 .577 .581 r
.20785 .9021 m .19234 .89771 L .19451 .88434 L p F P
0 g
s
.821 .584 .582 r
.17953 .87974 m .19451 .88434 L .19234 .89771 L p F P
0 g
s
.818 .607 .617 r
.19451 .88434 m .17953 .87974 L .1835 .86593 L p F P
0 g
s
.824 .615 .62 r
.16905 .86112 m .1835 .86593 L .17953 .87974 L p F P
0 g
s
.821 .632 .647 r
.1835 .86593 m .16905 .86112 L .17472 .84687 L p F P
0 g
s
.748 .407 .406 r
.26255 .94258 m .26405 .93945 L p .28615 .95358 L F P
0 g
s
.766 .438 .431 r
.26255 .94258 m .26113 .93891 L .26405 .93945 L closepath p F P
0 g
s
.81 .697 .741 r
.17414 .79123 m .18032 .78331 L .17245 .77109 L p F P
0 g
s
.562 .207 .324 r
.50209 .96118 m .48841 .95779 L .50409 .95604 L closepath p F P
0 g
s
.555 .185 .294 r
.48841 .95779 m .50209 .96118 L p .46964 .96881 L F P
0 g
s
.745 .712 .821 r
.2961 .68036 m .28464 .68816 L .27691 .67777 L p F P
0 g
s
.33 .535 .902 r
.72425 .06308 m .73072 .06478 L .73614 .07468 L p F P
0 g
s
.198 .447 .872 r
.74373 .07054 m .74906 .08049 L .73614 .07468 L p F P
0 g
s
.198 .447 .872 r
.73614 .07468 m .73072 .06478 L .74373 .07054 L p F P
0 g
s
.794 .869 .904 r
.66897 .36736 m .657 .37579 L .65065 .37047 L p F P
0 g
s
.981 .911 .644 r
.78043 .2345 m .77876 .23837 L .77835 .23419 L closepath p F P
0 g
s
.772 .433 .414 r
.26113 .93891 m .26255 .94258 L .2588 .94913 L p F P
0 g
s
.772 .433 .414 r
.24332 .93527 m .26113 .93891 L p .2588 .94913 L F P
0 g
s
.898 .71 .64 r
.32517 .39891 m .32421 .40163 L .32882 .40539 L closepath p F P
0 g
s
.801 .753 .809 r
.32882 .40539 m .32421 .40163 L .3044 .41995 L p F P
0 g
s
.807 .543 .539 r
.22124 .91857 m .20761 .915 L .20785 .9021 L p F P
0 g
s
.814 .549 .538 r
.19234 .89771 m .20785 .9021 L .20761 .915 L p F P
0 g
s
.827 .64 .65 r
.1608 .84185 m .17472 .84687 L .16905 .86112 L p F P
0 g
s
.822 .654 .674 r
.17472 .84687 m .1608 .84185 L .16809 .82717 L p F P
0 g
s
.922 .797 .705 r
.5117 .23932 m .50808 .2355 L .50858 .23451 L closepath p F P
0 g
s
.533 .347 .574 r
.61751 .89689 m .61656 .88331 L .64178 .87475 L p F P
0 g
s
.549 .385 .612 r
.64005 .86132 m .64178 .87475 L .61656 .88331 L p F P
0 g
s
.549 .385 .612 r
.63846 .86088 m .64005 .86132 L p .61656 .88331 L F P
0 g
s
.822 .692 .721 r
.16117 .78575 m .17414 .79123 L .16357 .8068 L p F P
0 g
s
.81 .697 .741 r
.17245 .77109 m .16117 .78575 L .17414 .79123 L p F P
0 g
s
.826 .559 .008 r
.78372 .1529 m .78506 .15758 L .78347 .14714 L p F P
0 g
s
.826 .559 .008 r
.78347 .14714 m .7815 .14016 L .78372 .1529 L p F P
0 g
s
.746 .85 .927 r
.59781 .40376 m .59621 .40465 L .59698 .40306 L closepath p F P
0 g
s
.734 .832 .926 r
.59115 .39774 m .59698 .40306 L .59621 .40465 L p F P
0 g
s
.734 .832 .926 r
.56474 .4116 m .59115 .39774 L p .59621 .40465 L F P
0 g
s
.586 .547 .778 r
.62573 .72399 m .63114 .73733 L .60432 .74018 L p F P
0 g
s
.586 .547 .778 r
.60432 .74018 m .6023 .73515 L .62573 .72399 L p F P
0 g
s
.765 .853 .916 r
.61766 .38201 m .6242 .38784 L .59781 .40376 L p F P
0 g
s
.765 .853 .916 r
.60003 .3927 m .61766 .38201 L p .59781 .40376 L F P
0 g
s
.765 .853 .916 r
.59781 .40376 m .59698 .40306 L .60003 .3927 L p F P
0 g
s
.994 .873 .558 r
.78128 .20381 m .78318 .2144 L .787 .20183 L p F P
0 g
s
.994 .873 .558 r
.787 .20183 m .7851 .19122 L .78128 .20381 L p F P
0 g
s
.745 .712 .821 r
.27691 .67777 m .28002 .67563 L .2961 .68036 L p F P
0 g
s
.736 .717 .833 r
.30271 .66125 m .28002 .67563 L .2961 .68036 L p F P
0 g
s
.736 .717 .833 r
.2961 .68036 m .31039 .67139 L .30271 .66125 L p F P
0 g
s
.694 .302 .3 r
.33369 .96852 m .31725 .96674 L .30662 .95644 L p F P
0 g
s
.68 .261 .244 r
.30111 .9558 m .30662 .95644 L .31725 .96674 L p F P
0 g
s
.698 .684 .833 r
.40977 .66145 m .41013 .66201 L p .37696 .66349 L F P
0 g
s
.698 .684 .833 r
.37696 .66349 m .38266 .66067 L .40977 .66145 L p F P
0 g
s
.7 .69 .837 r
.37696 .66349 m .38266 .66067 L .37478 .66027 L closepath p F P
0 g
s
.712 .695 .832 r
.37478 .66027 m .37696 .66349 L p .34372 .66665 L F P
0 g
s
.816 .884 .894 r
.66897 .36736 m .68333 .35632 L .67711 .35119 L p F P
0 g
s
.816 .884 .894 r
.67711 .35119 m .67098 .35596 L .66897 .36736 L p F P
0 g
s
.794 .869 .904 r
.65065 .37047 m .67098 .35596 L .66897 .36736 L p F P
0 g
s
.917 .922 .802 r
.75555 .2748 m .74943 .28276 L .74946 .29368 L p F P
0 g
s
.891 .915 .833 r
.73499 .29925 m .74943 .28276 L .74946 .29368 L p F P
0 g
s
.891 .915 .833 r
.73488 .30877 m .73499 .29925 L p .74946 .29368 L F P
0 g
s
.891 .915 .833 r
.74946 .29368 m .73564 .30928 L .73488 .30877 L p F P
0 g
s
.958 .914 .726 r
.76997 .24168 m .77104 .25241 L .77876 .23837 L p F P
0 g
s
.958 .914 .726 r
.77498 .23245 m .76997 .24168 L p .77876 .23837 L F P
0 g
s
.958 .914 .726 r
.77876 .23837 m .77835 .23419 L .77498 .23245 L p F P
0 g
s
.683 .671 .833 r
.4415 .65939 m .44329 .66226 L p .41013 .66201 L F P
0 g
s
.683 .671 .833 r
.41013 .66201 m .41159 .66137 L .4415 .65939 L p F P
0 g
s
.684 .678 .838 r
.41013 .66201 m .41159 .66137 L .40977 .66145 L closepath p F P
0 g
s
.795 .714 .776 r
.20546 .73533 m .19899 .74188 L .19104 .73115 L p F P
0 g
s
.795 .714 .776 r
.19104 .73115 m .19242 .72973 L .20546 .73533 L p F P
0 g
s
.782 .718 .791 r
.21241 .71132 m .19242 .72973 L .20546 .73533 L p F P
0 g
s
.782 .718 .791 r
.22444 .71639 m .21241 .71132 L p .20546 .73533 L F P
0 g
s
.782 .718 .791 r
.20546 .73533 m .22515 .71734 L .22444 .71639 L p F P
0 g
s
.78 .717 .794 r
.22515 .71734 m .22566 .71689 L .22444 .71639 L closepath p F P
0 g
s
.77 .724 .81 r
.23624 .6917 m .24996 .69717 L .22566 .71689 L p F P
0 g
s
.77 .724 .81 r
.21722 .7073 m .23624 .6917 L p .22566 .71689 L F P
0 g
s
.77 .724 .81 r
.22566 .71689 m .22444 .71639 L .21722 .7073 L p F P
0 g
s
.98 .896 .551 r
.50063 .31185 m .49608 .31653 L .5001 .30482 L closepath p F P
0 g
s
.948 .783 .644 r
.49907 .26008 m .50526 .2693 L .50991 .25655 L p F P
0 g
s
.948 .783 .644 r
.50991 .25655 m .50364 .24733 L .49907 .26008 L p F P
0 g
s
.594 .569 .796 r
.62421 .72056 m .62573 .72399 L .6023 .73515 L p F P
0 g
s
.594 .569 .796 r
.6023 .73515 m .5974 .72406 L .62421 .72056 L p F P
0 g
s
.828 .663 .678 r
.15468 .82192 m .16809 .82717 L .1608 .84185 L p F P
0 g
s
.823 .674 .699 r
.16809 .82717 m .15468 .82192 L .16357 .8068 L p F P
0 g
s
.516 .145 .276 r
.50409 .95604 m .53307 .95173 L .52913 .96141 L p F P
0 g
s
.516 .145 .276 r
.50209 .96118 m .50409 .95604 L p .52913 .96141 L F P
0 g
s
.682 .69 .851 r
.41159 .66137 m .40977 .66145 L .40278 .65132 L p F P
0 g
s
.694 .694 .846 r
.40977 .66145 m .40278 .65132 L .38266 .66067 L closepath p F P
0 g
s
.787 .489 .485 r
.24332 .93527 m .22595 .93148 L .22376 .91917 L p F P
0 g
s
.793 .494 .482 r
.22124 .91857 m .22376 .91917 L .22595 .93148 L p F P
0 g
s
.795 .716 .777 r
.18826 .75286 m .19899 .74188 L .19104 .73115 L p F P
0 g
s
.68 .684 .846 r
.4415 .65939 m .43604 .65113 L .41159 .66137 L closepath p F P
0 g
s
.682 .69 .851 r
.42874 .6404 m .43604 .65113 L .41159 .66137 L p F P
0 g
s
.682 .69 .851 r
.40278 .65132 m .42874 .6404 L p .41159 .66137 L F P
0 g
s
0 .265 .771 r
.75831 .08781 m .76301 .09792 L .75381 .09057 L p F P
0 g
s
0 .265 .771 r
.75381 .09057 m .74906 .08049 L .75831 .08781 L p F P
0 g
s
.614 .597 .81 r
.55703 .69968 m .58356 .69426 L .59048 .70866 L p F P
0 g
s
.613 .596 .81 r
.58019 .68726 m .58356 .69426 L .55703 .69968 L p F P
0 g
s
.613 .596 .81 r
.55703 .69968 m .55602 .69759 L .58019 .68726 L p F P
0 g
s
.712 .695 .832 r
.34372 .66665 m .35892 .65834 L .37478 .66027 L p F P
0 g
s
.714 .702 .837 r
.35892 .65834 m .34372 .66665 L .33617 .65605 L p F P
0 g
s
.725 .705 .831 r
.31039 .67139 m .33617 .65605 L .34372 .66665 L p F P
0 g
s
.758 .72 .818 r
.25241 .69805 m .25108 .69634 L .24996 .69717 L closepath p F P
0 g
s
.68 .261 .244 r
.29465 .96365 m .30111 .9558 L p .31725 .96674 L F P
0 g
s
.721 .334 .316 r
.29465 .96365 m .28615 .95358 L .30111 .9558 L closepath p F P
0 g
s
.775 .725 .806 r
.22444 .71639 m .21722 .7073 L .21241 .71132 L closepath p F P
0 g
s
0 0 .301 r
.77681 .12709 m .77431 .11971 L .77916 .13302 L closepath p F P
0 g
s
.538 .403 .645 r
.63993 .86037 m .63726 .84521 L .66153 .83535 L p F P
0 g
s
.55 .433 .672 r
.6596 .82671 m .66153 .83535 L .63726 .84521 L p F P
0 g
s
.55 .433 .672 r
.64513 .82463 m .6596 .82671 L p .63726 .84521 L F P
0 g
s
.562 .418 .642 r
.63726 .84521 m .63993 .86037 L .63846 .86088 L p F P
0 g
s
.633 .623 .822 r
.51677 .68005 m .54309 .67289 L .55008 .6862 L p F P
0 g
s
.633 .625 .824 r
.54167 .67022 m .54309 .67289 L .51677 .68005 L p F P
0 g
s
.633 .625 .824 r
.51677 .68005 m .51625 .67908 L .54167 .67022 L p F P
0 g
s
.748 .836 .918 r
.59698 .40306 m .59115 .39774 L .60003 .3927 L closepath p F P
0 g
s
.818 .88 .89 r
.69537 .34678 m .68333 .35632 L .67711 .35119 L p F P
0 g
s
.805 .714 .764 r
.17553 .7472 m .18826 .75286 L .17356 .76964 L p F P
0 g
s
.795 .716 .777 r
.19104 .73115 m .17553 .7472 L .18826 .75286 L p F P
0 g
s
.618 .615 .825 r
.57662 .68041 m .58019 .68726 L .55602 .69759 L p F P
0 g
s
.618 .615 .825 r
.55602 .69759 m .55008 .6862 L .57662 .68041 L p F P
0 g
s
.793 .494 .482 r
.22595 .93148 m .21751 .92952 L .22124 .91857 L p F P
0 g
s
.805 .507 .485 r
.20761 .915 m .22124 .91857 L .21751 .92952 L p F P
0 g
s
0 .008 .584 r
.76605 .10191 m .76301 .09792 L .76712 .10815 L p F P
0 g
s
0 .008 .584 r
.76712 .10815 m .77245 .11545 L .76605 .10191 L p F P
0 g
s
.667 .659 .832 r
.47087 .65482 m .47647 .66421 L p .44329 .66226 L F P
0 g
s
.667 .659 .832 r
.44329 .66226 m .45656 .65713 L .47087 .65482 L p F P
0 g
s
.669 .666 .838 r
.44329 .66226 m .45656 .65713 L .4415 .65939 L closepath p F P
0 g
s
.695 .7 .851 r
.39538 .64088 m .40278 .65132 L .38266 .66067 L p F P
0 g
s
.695 .7 .851 r
.3695 .65294 m .39538 .64088 L p .38266 .66067 L F P
0 g
s
.695 .7 .851 r
.38266 .66067 m .37478 .66027 L .3695 .65294 L p F P
0 g
s
.637 .641 .838 r
.53608 .66039 m .54167 .67022 L .51625 .67908 L p F P
0 g
s
.637 .641 .838 r
.51625 .67908 m .50972 .66772 L .53608 .66039 L p F P
0 g
s
.748 .407 .406 r
.28615 .95358 m .26655 .95045 L .26255 .94258 L p F P
0 g
s
.753 .409 .401 r
.26655 .95045 m .2588 .94913 L .26255 .94258 L closepath p F P
0 g
s
.986 .84 .615 r
.49657 .29476 m .5001 .30482 L .50471 .29199 L p F P
0 g
s
.986 .84 .615 r
.50471 .29199 m .50081 .28204 L .49657 .29476 L p F P
0 g
s
.76 .726 .821 r
.24321 .68649 m .23624 .6917 L .24996 .69717 L p F P
0 g
s
.76 .726 .821 r
.24996 .69717 m .25108 .69634 L .24321 .68649 L p F P
0 g
s
.889 .916 .836 r
.73564 .30928 m .73482 .31019 L .73488 .30877 L closepath p F P
0 g
s
.707 .704 .845 r
.37478 .66027 m .3695 .65294 L .35892 .65834 L closepath p F P
0 g
s
.861 .896 .859 r
.71751 .31682 m .71695 .32784 L .73482 .31019 L p F P
0 g
s
.861 .896 .859 r
.72971 .3046 m .71751 .31682 L p .73482 .31019 L F P
0 g
s
.861 .896 .859 r
.73482 .31019 m .73488 .30877 L .72971 .3046 L p F P
0 g
s
.756 .722 .821 r
.27691 .67777 m .25108 .69634 L .24321 .68649 L p F P
0 g
s
.842 .894 .876 r
.69537 .34678 m .70957 .3344 L .70349 .32945 L p F P
0 g
s
.842 .894 .876 r
.70349 .32945 m .69653 .33561 L .69537 .34678 L p F P
0 g
s
.818 .88 .89 r
.67711 .35119 m .69653 .33561 L .69537 .34678 L p F P
0 g
s
.321 .539 .908 r
.73072 .06478 m .72425 .06308 L .718 .05326 L p F P
0 g
s
.729 .713 .836 r
.33617 .65605 m .31039 .67139 L .30271 .66125 L p F P
0 g
s
.985 .836 .45 r
.4933 .32978 m .49494 .34038 L .49784 .32807 L p F P
0 g
s
.985 .836 .45 r
.49784 .32807 m .49581 .31759 L .4933 .32978 L p F P
0 g
s
.842 .889 .873 r
.71695 .32784 m .70957 .3344 L .70349 .32945 L p F P
0 g
s
.842 .889 .873 r
.70349 .32945 m .71751 .31682 L .71695 .32784 L p F P
0 g
s
0 0 .162 r
.49248 .36401 m .48892 .37628 L .48977 .3646 L p F P
0 g
s
0 0 .162 r
.48977 .3646 m .49293 .35244 L .49248 .36401 L p F P
0 g
s
.668 .679 .851 r
.45656 .65713 m .4415 .65939 L .43604 .65113 L p F P
0 g
s
.827 .684 .704 r
.15065 .80134 m .16357 .8068 L .15468 .82192 L p F P
0 g
s
.822 .692 .721 r
.16357 .8068 m .15065 .80134 L .16117 .78575 L p F P
0 g
s
.592 .568 .796 r
.6173 .70498 m .62421 .72056 L .5974 .72406 L p F P
0 g
s
.592 .568 .796 r
.60342 .70671 m .6173 .70498 L p .5974 .72406 L F P
0 g
s
.592 .568 .796 r
.5974 .72406 m .59221 .71228 L .60342 .70671 L p F P
0 g
s
.702 .796 .923 r
.53372 .41961 m .53154 .41741 L .5355 .41565 L closepath p F P
0 g
s
.515 .263 .471 r
.59044 .92908 m .59143 .91713 L .61758 .90971 L p F P
0 g
s
.54 .321 .53 r
.61751 .89689 m .61758 .90971 L .59143 .91713 L p F P
0 g
s
.544 .287 .476 r
.59143 .91713 m .59044 .92908 L .5634 .93546 L p F P
0 g
s
.815 .704 .742 r
.17245 .77109 m .17356 .76964 L .17057 .76831 L closepath p F P
0 g
s
.805 .714 .764 r
.16444 .75999 m .17553 .7472 L p .17356 .76964 L F P
0 g
s
.805 .714 .764 r
.17356 .76964 m .17057 .76831 L .16444 .75999 L p F P
0 g
s
.868 .896 .852 r
.73488 .30877 m .72971 .3046 L .73499 .29925 L closepath p F P
0 g
s
.513 .217 .401 r
.56169 .94413 m .5634 .93546 L .59044 .92908 L p F P
0 g
s
.816 .704 .742 r
.16117 .78575 m .17245 .77109 L .17057 .76831 L p F P
0 g
s
.732 .824 .922 r
.59115 .39774 m .56474 .4116 L .55792 .40523 L p F P
0 g
s
.652 .65 .836 r
.47647 .66421 m .50264 .65554 L .50972 .66772 L p F P
0 g
s
.652 .654 .839 r
.49812 .64787 m .50264 .65554 L .47647 .66421 L p F P
0 g
s
.652 .654 .839 r
.47647 .66421 m .47087 .65482 L .49812 .64787 L p F P
0 g
s
.429 .414 .741 r
.48322 .4006 m .48802 .39413 L .49116 .40381 L closepath p F P
0 g
s
.772 .433 .414 r
.2588 .94913 m .24819 .94696 L .24332 .93527 L p F P
0 g
s
.777 .434 .405 r
.22595 .93148 m .24332 .93527 L .24819 .94696 L p F P
0 g
s
.991 .823 .446 r
.78262 .18072 m .7851 .19122 L .78718 .17932 L p F P
0 g
s
.991 .823 .446 r
.78718 .17932 m .78473 .1688 L .78262 .18072 L p F P
0 g
s
.549 .432 .673 r
.6596 .82671 m .64513 .82463 L .65797 .8193 L closepath p F P
0 g
s
.562 .46 .696 r
.65356 .80239 m .65797 .8193 L .64513 .82463 L p F P
0 g
s
.724 .323 .29 r
.28615 .95358 m .29465 .96365 L .29416 .96409 L p F P
0 g
s
.724 .323 .29 r
.26655 .95045 m .28615 .95358 L p .29416 .96409 L F P
0 g
s
.821 .584 .582 r
.19234 .89771 m .1773 .89314 L .17953 .87974 L p F P
0 g
s
.828 .592 .582 r
.16847 .87611 m .17953 .87974 L .1773 .89314 L p F P
0 g
s
.824 .615 .62 r
.16698 .86835 m .16905 .86112 L p .17953 .87974 L F P
0 g
s
.824 .615 .62 r
.17953 .87974 m .16847 .87611 L .16698 .86835 L p F P
0 g
s
.714 .702 .837 r
.33617 .65605 m .33773 .65519 L .35892 .65834 L p F P
0 g
s
.709 .71 .849 r
.36199 .64279 m .33773 .65519 L .35892 .65834 L p F P
0 g
s
.709 .71 .849 r
.35892 .65834 m .3695 .65294 L .36199 .64279 L p F P
0 g
s
.962 .91 .717 r
.77835 .23419 m .77498 .23245 L .77758 .22766 L closepath p F P
0 g
s
.832 .622 .618 r
.16698 .86835 m .16905 .86112 L .16527 .85977 L closepath p F P
0 g
s
.827 .64 .65 r
.1601 .84366 m .1608 .84185 L p .16905 .86112 L F P
0 g
s
.827 .64 .65 r
.16905 .86112 m .16527 .85977 L .1601 .84366 L p F P
0 g
s
.657 .253 .267 r
.36514 .9706 m .34004 .96898 L .33585 .96597 L p F P
0 g
s
.659 .249 .257 r
.34004 .96898 m .33369 .96852 L .33585 .96597 L closepath p F P
0 g
s
.94 .91 .763 r
.7604 .25644 m .7614 .26716 L .77104 .25241 L p F P
0 g
s
.94 .91 .763 r
.77104 .25241 m .76997 .24168 L .7604 .25644 L p F P
0 g
s
.61 .656 .87 r
.49656 .41827 m .49774 .41707 L .49827 .4179 L closepath p F P
0 g
s
.548 .384 .611 r
.64005 .86132 m .63846 .86088 L .63993 .86037 L closepath p F P
0 g
s
.502 .016 .034 r
.40514 .97154 m .42555 .97114 L p .43067 .97809 L F P
0 g
s
.502 .016 .034 r
.40205 .97494 m .40514 .97154 L p .43067 .97809 L F P
0 g
s
.589 .151 .175 r
.40205 .97494 m .39339 .97138 L .40514 .97154 L closepath p F P
0 g
s
.814 .549 .538 r
.20761 .915 m .19206 .91062 L .19234 .89771 L p F P
0 g
s
.822 .556 .537 r
.1773 .89314 m .19234 .89771 L .19206 .91062 L p F P
0 g
s
.546 .062 .058 r
.39339 .97138 m .40205 .97494 L .39717 .97857 L p F P
0 g
s
.546 .062 .058 r
.3705 .97089 m .39339 .97138 L p .39717 .97857 L F P
0 g
s
.771 .85 .91 r
.63889 .37853 m .6242 .38784 L .61766 .38201 L p F P
0 g
s
.816 .704 .742 r
.17057 .76831 m .161 .76396 L p .16117 .78575 L F P
0 g
s
.809 .714 .761 r
.17057 .76831 m .16444 .75999 L .161 .76396 L closepath p F P
0 g
s
.748 .719 .825 r
.27691 .67777 m .28002 .67563 L .27365 .67352 L closepath p F P
0 g
s
.756 .722 .821 r
.27365 .67352 m .27691 .67777 L p .24321 .68649 L F P
0 g
s
.559 .125 .173 r
.43539 .97411 m .42555 .97114 L .43809 .97079 L closepath p F P
0 g
s
.502 .016 .034 r
.42555 .97114 m .43539 .97411 L .43067 .97809 L p F P
0 g
s
.138 .094 .541 r
.49253 .38648 m .48802 .39413 L .48644 .38077 L p F P
0 g
s
.138 .094 .541 r
.48644 .38077 m .48892 .37628 L .49253 .38648 L p F P
0 g
s
.526 .368 .61 r
.63993 .86037 m .66427 .85059 L p .65455 .86972 L F P
0 g
s
.526 .368 .61 r
.65455 .86972 m .64005 .86132 L .63993 .86037 L p F P
0 g
s
.538 .403 .645 r
.66153 .83535 m .66427 .85059 L .63993 .86037 L p F P
0 g
s
.645 .76 .932 r
.49827 .4179 m .52456 .40977 L .53154 .41741 L p F P
0 g
s
.643 .671 .861 r
.49774 .41707 m .49827 .4179 L .52456 .40977 L p F P
0 g
s
.835 .646 .648 r
.1601 .84366 m .1608 .84185 L .1593 .84127 L closepath p F P
0 g
s
.828 .663 .678 r
.15261 .82618 m .15468 .82192 L p .1608 .84185 L F P
0 g
s
.828 .663 .678 r
.1608 .84185 m .1593 .84127 L .15261 .82618 L p F P
0 g
s
.983 .892 .65 r
.77572 .21708 m .77758 .22766 L .78318 .2144 L p F P
0 g
s
.983 .892 .65 r
.78318 .2144 m .78128 .20381 L .77572 .21708 L p F P
0 g
s
.546 .062 .058 r
.36883 .97262 m .3705 .97089 L p .39717 .97857 L F P
0 g
s
.626 .191 .196 r
.36883 .97262 m .36514 .9706 L .3705 .97089 L closepath p F P
0 g
s
.739 .726 .839 r
.29496 .65132 m .30271 .66125 L .28002 .67563 L p F P
0 g
s
.739 .726 .839 r
.2691 .66788 m .29496 .65132 L p .28002 .67563 L F P
0 g
s
.739 .726 .839 r
.28002 .67563 m .27365 .67352 L .2691 .66788 L p F P
0 g
s
.667 .673 .847 r
.47087 .65482 m .46931 .65237 L .45656 .65713 L closepath p F P
0 g
s
.668 .679 .851 r
.46211 .64135 m .46931 .65237 L .45656 .65713 L p F P
0 g
s
.668 .679 .851 r
.43604 .65113 m .46211 .64135 L p .45656 .65713 L F P
0 g
s
.525 .368 .611 r
.64178 .87475 m .64005 .86132 L .65455 .86972 L closepath p F P
0 g
s
.473 0 .045 r
.43809 .97079 m .46443 .96918 L p .46267 .97631 L F P
0 g
s
.473 0 .045 r
.43539 .97411 m .43809 .97079 L p .46267 .97631 L F P
0 g
s
.617 .617 .828 r
.57662 .68041 m .55008 .6862 L .54309 .67289 L p F P
0 g
s
.513 .299 .527 r
.61758 .90971 m .61751 .89689 L .6428 .88839 L p F P
0 g
s
.533 .347 .574 r
.64178 .87475 m .6428 .88839 L .61751 .89689 L p F P
0 g
s
.547 .57 .829 r
.49116 .40381 m .50942 .40307 L .49774 .41707 L closepath p F P
0 g
s
.643 .671 .861 r
.51751 .40136 m .50942 .40307 L .49774 .41707 L p F P
0 g
s
.643 .671 .861 r
.52456 .40977 m .51751 .40136 L p .49774 .41707 L F P
0 g
s
.599 .589 .813 r
.59221 .71228 m .59048 .70866 L .60342 .70671 L closepath p F P
0 g
s
0 0 .255 r
.77916 .13302 m .78043 .13671 L .7815 .14016 L closepath p F P
0 g
s
.85 .575 .037 r
.78195 .14718 m .78372 .1529 L .7815 .14016 L p F P
0 g
s
.85 .575 .037 r
.7815 .14016 m .78043 .13671 L .78195 .14718 L p F P
0 g
s
.952 .784 .636 r
.4947 .27281 m .50081 .28204 L .50526 .2693 L p F P
0 g
s
.952 .784 .636 r
.50526 .2693 m .49907 .26008 L .4947 .27281 L p F P
0 g
s
.593 .117 .094 r
.36514 .9706 m .36883 .97262 L .36186 .97758 L p F P
0 g
s
.593 .117 .094 r
.34004 .96898 m .36514 .9706 L p .36186 .97758 L F P
0 g
s
.704 .378 0 r
.77431 .11971 m .77916 .13302 L .78043 .13671 L p F P
0 g
s
.833 .622 .618 r
.16527 .85977 m .1553 .85606 L p .1651 .87494 L F P
0 g
s
.833 .622 .618 r
.1651 .87494 m .16698 .86835 L .16527 .85977 L p F P
0 g
s
.832 .643 .647 r
.16527 .85977 m .1601 .84366 L .1553 .85606 L closepath p F P
0 g
s
.835 .647 .648 r
.1553 .85606 m .1601 .84366 L .1593 .84127 L p F P
0 g
s
.835 .647 .648 r
.1593 .84127 m .14756 .83657 L p .1553 .85606 L F P
0 g
s
.832 .665 .675 r
.1593 .84127 m .15261 .82618 L .14756 .83657 L closepath p F P
0 g
s
.701 .778 .911 r
.5355 .41565 m .53154 .41741 L .52456 .40977 L p F P
0 g
s
.805 .507 .485 r
.21751 .92952 m .20945 .92741 L .20761 .915 L p F P
0 g
s
.813 .512 .481 r
.19206 .91062 m .20761 .915 L .20945 .92741 L p F P
0 g
s
.827 .7 .723 r
.14872 .78006 m .16117 .78575 L .15065 .80134 L p F P
0 g
s
.816 .704 .742 r
.161 .76396 m .14872 .78006 L .16117 .78575 L p F P
0 g
s
.489 .126 .276 r
.52913 .96141 m .53307 .95173 L .56115 .94642 L p F P
0 g
s
.54 .233 .395 r
.56169 .94413 m .56115 .94642 L .53307 .95173 L p F P
0 g
s
.516 .145 .276 r
.52913 .96141 m .52179 .9625 L .50209 .96118 L p F P
0 g
s
.51 .127 .25 r
.52179 .9625 m .49989 .96562 L .50209 .96118 L closepath p F P
0 g
s
.555 .185 .294 r
.50209 .96118 m .49989 .96562 L .46964 .96881 L p F P
0 g
s
.696 .707 .856 r
.39538 .64088 m .3695 .65294 L .36199 .64279 L p F P
0 g
s
.637 .644 .841 r
.53608 .66039 m .50972 .66772 L .50264 .65554 L p F P
0 g
s
.96 .736 .287 r
.78211 .15976 m .78473 .1688 L .78506 .15758 L p F P
0 g
s
.96 .736 .287 r
.78506 .15758 m .78372 .1529 L .78211 .15976 L p F P
0 g
s
.683 .697 .857 r
.42874 .6404 m .40278 .65132 L .39538 .64088 L p F P
0 g
s
.599 .59 .813 r
.60342 .70671 m .59048 .70866 L .58356 .69426 L p F P
0 g
s
.788 .73 .798 r
.19984 .70548 m .21241 .71132 L .19242 .72973 L p F P
0 g
s
.778 .732 .81 r
.20921 .69759 m .19984 .70548 L .21241 .71132 L p F P
0 g
s
.778 .732 .81 r
.21241 .71132 m .21722 .7073 L .20921 .69759 L p F P
0 g
s
.799 .723 .78 r
.19104 .73115 m .19242 .72973 L .18852 .7279 L closepath p F P
0 g
s
.788 .73 .798 r
.18297 .72116 m .19984 .70548 L p .19242 .72973 L F P
0 g
s
.788 .73 .798 r
.19242 .72973 m .18852 .7279 L .18297 .72116 L p F P
0 g
s
.8 .723 .779 r
.17553 .7472 m .19104 .73115 L .18852 .7279 L p F P
0 g
s
.836 .669 .676 r
.15261 .82618 m .15468 .82192 L .14965 .81981 L closepath p F P
0 g
s
.827 .684 .704 r
.14487 .81127 m .15065 .80134 L p .15468 .82192 L F P
0 g
s
.827 .684 .704 r
.15468 .82192 m .14965 .81981 L .14487 .81127 L p F P
0 g
s
.775 .729 .81 r
.23624 .6917 m .21722 .7073 L .20921 .69759 L p F P
0 g
s
.701 .778 .911 r
.52456 .40977 m .53872 .40381 L .5355 .41565 L p F P
0 g
s
.697 .783 .918 r
.5355 .41565 m .55792 .40523 L .55103 .39847 L p F P
0 g
s
.697 .783 .918 r
.55103 .39847 m .53872 .40381 L .5355 .41565 L p F P
0 g
s
.321 .539 .908 r
.718 .05326 m .72475 .055 L .73072 .06478 L p F P
0 g
s
.181 .448 .875 r
.7378 .06073 m .74373 .07054 L .73072 .06478 L p F P
0 g
s
.181 .448 .875 r
.73072 .06478 m .72475 .055 L .7378 .06073 L p F P
0 g
s
.991 .862 .609 r
.49257 .30745 m .49657 .29476 L .5001 .30482 L p F P
0 g
s
.991 .862 .609 r
.49542 .31669 m .49257 .30745 L p .5001 .30482 L F P
0 g
s
.991 .862 .609 r
.5001 .30482 m .49608 .31653 L .49542 .31669 L p F P
0 g
s
.789 .863 .904 r
.63889 .37853 m .65065 .37047 L .64423 .36484 L p F P
0 g
s
.789 .863 .904 r
.64423 .36484 m .64103 .36705 L .63889 .37853 L p F P
0 g
s
.771 .85 .91 r
.61766 .38201 m .64103 .36705 L .63889 .37853 L p F P
0 g
s
.83 .619 .617 r
.16847 .87611 m .16698 .86835 L .1651 .87494 L closepath p F P
0 g
s
.716 .708 .842 r
.33617 .65605 m .33773 .65519 L .33522 .65475 L closepath p F P
0 g
s
.729 .713 .836 r
.33522 .65475 m .33617 .65605 L p .30271 .66125 L F P
0 g
s
0 0 .491 r
.77245 .11545 m .77322 .11676 L .77431 .11971 L closepath p F P
0 g
s
.704 .378 0 r
.77668 .12644 m .77322 .11676 L .77431 .11971 L p F P
0 g
s
.704 .378 0 r
.78043 .13671 m .77668 .12644 L p .77431 .11971 L F P
0 g
s
.55 .474 .723 r
.64824 .78454 m .6652 .77595 L p .66097 .79876 L F P
0 g
s
.55 .474 .723 r
.66097 .79876 m .65224 .79801 L .64824 .78454 L p F P
0 g
s
.557 .498 .745 r
.64824 .78454 m .64512 .77526 L .6652 .77595 L closepath p F P
0 g
s
.709 .716 .855 r
.35441 .63287 m .36199 .64279 L .33773 .65519 L p F P
0 g
s
.709 .716 .855 r
.32854 .64613 m .35441 .63287 L p .33773 .65519 L F P
0 g
s
.709 .716 .855 r
.33773 .65519 m .33522 .65475 L .32854 .64613 L p F P
0 g
s
.669 .685 .857 r
.46211 .64135 m .43604 .65113 L .42874 .6404 L p F P
0 g
s
.536 .115 .19 r
.46876 .9701 m .46443 .96918 L .46964 .96881 L closepath p F P
0 g
s
.473 0 .045 r
.46443 .96918 m .46876 .9701 L .46267 .97631 L p F P
0 g
s
.914 .906 .801 r
.74975 .27059 m .7604 .25644 L .7614 .26716 L p F P
0 g
s
.914 .906 .801 r
.7614 .26716 m .75555 .2748 L .74975 .27059 L p F P
0 g
s
.756 .722 .821 r
.24321 .68649 m .26528 .67043 L .27365 .67352 L p F P
0 g
s
.747 .728 .834 r
.27365 .67352 m .2691 .66788 L .26528 .67043 L closepath p F P
0 g
s
.558 .497 .744 r
.6652 .77595 m .64512 .77526 L .64192 .76565 L p F P
0 g
s
.593 .117 .094 r
.36186 .97758 m .35865 .97736 L .34004 .96898 L p F P
0 g
s
.534 .011 0 r
.33369 .96852 m .34004 .96898 L .35865 .97736 L p F P
0 g
s
.724 .323 .29 r
.29416 .96409 m .27586 .96107 L .26655 .95045 L p F P
0 g
s
.714 .293 .245 r
.2588 .94913 m .26655 .95045 L .27586 .96107 L p F P
0 g
s
.812 .719 .762 r
.17553 .7472 m .16444 .75999 L .15633 .74949 L p F P
0 g
s
.812 .719 .762 r
.15633 .74949 m .16336 .74131 L .17553 .7472 L p F P
0 g
s
.8 .723 .779 r
.18008 .72386 m .16336 .74131 L .17553 .7472 L p F P
0 g
s
.8 .723 .779 r
.18852 .7279 m .18008 .72386 L p .17553 .7472 L F P
0 g
s
.653 .668 .851 r
.49553 .64374 m .49812 .64787 L .47087 .65482 L p F P
0 g
s
.653 .668 .851 r
.47087 .65482 m .46931 .65237 L .49553 .64374 L p F P
0 g
s
.558 .497 .744 r
.64192 .76565 m .66188 .75517 L p .6652 .77595 L F P
0 g
s
.564 .521 .765 r
.64192 .76565 m .6381 .75536 L .66188 .75517 L closepath p F P
0 g
s
.775 .729 .81 r
.20921 .69759 m .22327 .68594 L .23624 .6917 L p F P
0 g
s
.764 .733 .824 r
.23526 .67689 m .22327 .68594 L .23624 .6917 L p F P
0 g
s
.764 .733 .824 r
.23624 .6917 m .24321 .68649 L .23526 .67689 L p F P
0 g
s
.729 .713 .836 r
.30271 .66125 m .31987 .65096 L .33522 .65475 L p F P
0 g
s
.722 .72 .848 r
.33522 .65475 m .32854 .64613 L .31987 .65096 L closepath p F P
0 g
s
.5 .077 .168 r
.46876 .9701 m .46964 .96881 L .49989 .96562 L p F P
0 g
s
.55 .476 .725 r
.65356 .80239 m .65224 .79801 L .66097 .79876 L closepath p F P
0 g
s
.537 .447 .7 r
.65797 .8193 m .65356 .80239 L .66097 .79876 L p F P
0 g
s
.952 .797 .348 r
.49159 .34176 m .49293 .35244 L .49494 .34038 L p F P
0 g
s
.952 .797 .348 r
.49494 .34038 m .4933 .32978 L .49159 .34176 L p F P
0 g
s
.836 .669 .676 r
.14756 .83657 m .15261 .82618 L .14965 .81981 L p F P
0 g
s
.534 .011 0 r
.32758 .97304 m .33369 .96852 L p .35865 .97736 L F P
0 g
s
.641 .181 .145 r
.32758 .97304 m .31725 .96674 L .33369 .96852 L closepath p F P
0 g
s
.828 .592 .582 r
.1773 .89314 m .16909 .89047 L .16847 .87611 L p F P
0 g
s
.834 .597 .58 r
.1651 .87494 m .16847 .87611 L .16909 .89047 L p F P
0 g
s
.546 .062 .058 r
.39717 .97857 m .38645 .97832 L .36883 .97262 L p F P
0 g
s
.543 .053 .042 r
.38645 .97832 m .36186 .97758 L .36883 .97262 L closepath p F P
0 g
s
.777 .434 .405 r
.24819 .94696 m .23084 .94316 L .22595 .93148 L p F P
0 g
s
.779 .425 .385 r
.21751 .92952 m .22595 .93148 L .23084 .94316 L p F P
0 g
s
.883 .593 .078 r
.77821 .13692 m .78195 .14718 L .78043 .13671 L p F P
0 g
s
.883 .593 .078 r
.78043 .13671 m .77668 .12644 L .77821 .13692 L p F P
0 g
s
.76 .73 .825 r
.26528 .67043 m .24321 .68649 L .23526 .67689 L p F P
0 g
s
.795 .862 .899 r
.67098 .35596 m .65065 .37047 L .64423 .36484 L p F P
0 g
s
0 0 .478 r
.77322 .11676 m .77245 .11545 L .76605 .10191 L p F P
0 g
s
.792 .73 .795 r
.18852 .7279 m .18297 .72116 L .18008 .72386 L closepath p F P
0 g
s
.565 .52 .764 r
.66188 .75517 m .6381 .75536 L .63448 .74553 L p F P
0 g
s
.917 .909 .798 r
.74943 .28276 m .75555 .2748 L .74975 .27059 L p F P
0 g
s
.731 .721 .841 r
.31987 .65096 m .30271 .66125 L .29496 .65132 L p F P
0 g
s
.654 .674 .856 r
.49553 .64374 m .46931 .65237 L .46211 .64135 L p F P
0 g
s
0 0 .463 r
.49524 .37453 m .49253 .38648 L .48892 .37628 L p F P
0 g
s
0 0 .463 r
.48892 .37628 m .49248 .36401 L .49524 .37453 L p F P
0 g
s
0 .257 .767 r
.75302 .07784 m .75831 .08781 L .74906 .08049 L p F P
0 g
s
0 .257 .767 r
.74906 .08049 m .74373 .07054 L .75302 .07784 L p F P
0 g
s
.813 .721 .764 r
.161 .76396 m .16444 .75999 L .15633 .74949 L p F P
0 g
s
.836 .689 .7 r
.15065 .80134 m .14487 .81127 L .13697 .79784 L p F P
0 g
s
.836 .689 .7 r
.13697 .79784 m .13821 .79567 L .15065 .80134 L p F P
0 g
s
.827 .7 .723 r
.15065 .80134 m .13821 .79567 L .14872 .78006 L p F P
0 g
s
.996 .864 .573 r
.77879 .19333 m .78128 .20381 L .7851 .19122 L p F P
0 g
s
.996 .864 .573 r
.7851 .19122 m .78262 .18072 L .77879 .19333 L p F P
0 g
s
.836 .669 .676 r
.14965 .81981 m .14185 .81645 L p .14756 .83657 L F P
0 g
s
.831 .685 .701 r
.14965 .81981 m .14487 .81127 L .14185 .81645 L closepath p F P
0 g
s
.747 .827 .913 r
.60003 .3927 m .59115 .39774 L .58443 .39134 L p F P
0 g
s
.732 .824 .922 r
.55792 .40523 m .58443 .39134 L .59115 .39774 L p F P
0 g
s
.714 .293 .245 r
.25348 .95453 m .2588 .94913 L p .27586 .96107 L F P
0 g
s
.752 .364 .318 r
.25348 .95453 m .24819 .94696 L .2588 .94913 L closepath p F P
0 g
s
.554 .491 .739 r
.48802 .39413 m .49116 .40381 L .50942 .40307 L p F P
0 g
s
.565 .52 .764 r
.63448 .74553 m .6511 .73648 L p .66188 .75517 L F P
0 g
s
.571 .542 .784 r
.63448 .74553 m .63114 .73733 L .6511 .73648 L closepath p F P
0 g
s
.834 .597 .58 r
.16909 .89047 m .1629 .88833 L .1651 .87494 L p F P
0 g
s
.842 .605 .58 r
.15143 .86987 m .1651 .87494 L .1629 .88833 L p F P
0 g
s
.833 .622 .618 r
.1553 .85606 m .15143 .86987 L .1651 .87494 L p F P
0 g
s
0 0 .478 r
.76605 .10191 m .76892 .1066 L .77322 .11676 L p F P
0 g
s
.723 .382 0 r
.77238 .11628 m .77668 .12644 L .77322 .11676 L p F P
0 g
s
.723 .382 0 r
.77322 .11676 m .76892 .1066 L .77238 .11628 L p F P
0 g
s
.554 .491 .739 r
.50966 .39209 m .49253 .38648 L .48802 .39413 L p F P
0 g
s
.554 .491 .739 r
.50942 .40307 m .50966 .39209 L p .48802 .39413 L F P
0 g
s
.825 .716 .745 r
.14898 .75805 m .161 .76396 L .14872 .78006 L p F P
0 g
s
.813 .721 .764 r
.15633 .74949 m .14898 .75805 L .161 .76396 L p F P
0 g
s
.96 .901 .72 r
.76935 .22905 m .77572 .21708 L .77758 .22766 L p F P
0 g
s
.96 .901 .72 r
.77758 .22766 m .77498 .23245 L .76935 .22905 L p F P
0 g
s
.447 0 .039 r
.46267 .97631 m .46876 .9701 L .49497 .97186 L p F P
0 g
s
.5 .077 .168 r
.49989 .96562 m .49497 .97186 L .46876 .9701 L p F P
0 g
s
.529 .419 .673 r
.65797 .8193 m .6813 .80802 L p .67234 .83027 L F P
0 g
s
.529 .419 .673 r
.67234 .83027 m .6596 .82671 L .65797 .8193 L p F P
0 g
s
.537 .447 .7 r
.67973 .80214 m .6813 .80802 L .65797 .8193 L p F P
0 g
s
.537 .447 .7 r
.66097 .79876 m .67973 .80214 L p .65797 .8193 L F P
0 g
s
.507 .327 .572 r
.65455 .86972 m .64178 .87475 L .6428 .88839 L p F P
0 g
s
0 .004 .577 r
.75972 .0896 m .75831 .08781 L .76301 .09792 L p F P
0 g
s
0 .004 .577 r
.76301 .09792 m .76605 .10191 L .75972 .0896 L p F P
0 g
s
.822 .556 .537 r
.19206 .91062 m .17695 .90607 L .1773 .89314 L p F P
0 g
s
.829 .563 .536 r
.16909 .89047 m .1773 .89314 L .17695 .90607 L p F P
0 g
s
.917 .909 .798 r
.74975 .27059 m .74869 .27199 L .74943 .28276 L p F P
0 g
s
.89 .895 .826 r
.73437 .28848 m .73499 .29925 L .74943 .28276 L p F P
0 g
s
.89 .895 .826 r
.74943 .28276 m .74869 .27199 L .73437 .28848 L p F P
0 g
s
.617 .617 .828 r
.54309 .67289 m .56967 .66714 L .57662 .68041 L p F P
0 g
s
.617 .617 .829 r
.56556 .65937 m .56967 .66714 L .54309 .67289 L p F P
0 g
s
.617 .617 .829 r
.54309 .67289 m .54167 .67022 L .56556 .65937 L p F P
0 g
s
.845 .634 .616 r
.14209 .85079 m .1553 .85606 L .15143 .86987 L p F P
0 g
s
.835 .647 .648 r
.14756 .83657 m .14209 .85079 L .1553 .85606 L p F P
0 g
s
.502 .016 .034 r
.43067 .97809 m .41782 .97834 L .40205 .97494 L p F P
0 g
s
.494 0 .006 r
.41782 .97834 m .39717 .97857 L .40205 .97494 L closepath p F P
0 g
s
.963 .733 .29 r
.78169 .15839 m .78211 .15976 L .78372 .1529 L p F P
0 g
s
.963 .733 .29 r
.78372 .1529 m .78195 .14718 L .78169 .15839 L p F P
0 g
s
.616 .122 .058 r
.31725 .96674 m .32758 .97304 L .32405 .97463 L p F P
0 g
s
.616 .122 .058 r
.29536 .96424 m .31725 .96674 L p .32405 .97463 L F P
0 g
s
.68 .261 .244 r
.31725 .96674 m .29536 .96424 L .29465 .96365 L p F P
0 g
s
.599 .59 .813 r
.58356 .69426 m .61038 .69031 L p .60342 .70671 L F P
0 g
s
.595 .588 .815 r
.60346 .67599 m .61038 .69031 L .58356 .69426 L p F P
0 g
s
.595 .588 .815 r
.60059 .6764 m .60346 .67599 L p .58356 .69426 L F P
0 g
s
.595 .588 .815 r
.58356 .69426 m .58019 .68726 L .60059 .6764 L p F P
0 g
s
.957 .785 .627 r
.49055 .28551 m .49657 .29476 L .50081 .28204 L p F P
0 g
s
.957 .785 .627 r
.50081 .28204 m .4947 .27281 L .49055 .28551 L p F P
0 g
s
.513 .217 .401 r
.59044 .92908 m .58837 .93993 L .56169 .94413 L p F P
0 g
s
.502 .191 .372 r
.56115 .94642 m .56169 .94413 L .58837 .93993 L p F P
0 g
s
.779 .425 .385 r
.21268 .93675 m .21751 .92952 L p .23084 .94316 L F P
0 g
s
.797 .459 .415 r
.21268 .93675 m .20945 .92741 L .21751 .92952 L closepath p F P
0 g
s
.814 .872 .89 r
.67711 .35119 m .67098 .35596 L .67188 .34667 L closepath p F P
0 g
s
.795 .862 .899 r
.67081 .34566 m .67188 .34667 L .67098 .35596 L p F P
0 g
s
.795 .862 .899 r
.64423 .36484 m .67081 .34566 L p .67098 .35596 L F P
0 g
s
.76 .73 .825 r
.23526 .67689 m .25172 .66481 L .26528 .67043 L p F P
0 g
s
.75 .734 .838 r
.26121 .65841 m .25172 .66481 L .26528 .67043 L p F P
0 g
s
.75 .734 .838 r
.26528 .67043 m .2691 .66788 L .26121 .65841 L p F P
0 g
s
.473 0 .045 r
.46267 .97631 m .45543 .97677 L .43539 .97411 L p F P
0 g
s
.461 0 .004 r
.45543 .97677 m .43067 .97809 L .43539 .97411 L closepath p F P
0 g
s
.571 .542 .783 r
.6511 .73648 m .63114 .73733 L .62573 .72399 L p F P
0 g
s
.761 .84 .912 r
.60003 .3927 m .61766 .38201 L .61105 .37586 L p F P
0 g
s
.761 .84 .912 r
.61105 .37586 m .60233 .38116 L .60003 .3927 L p F P
0 g
s
.747 .827 .913 r
.58443 .39134 m .60233 .38116 L .60003 .3927 L p F P
0 g
s
.963 .901 .713 r
.76997 .24168 m .77498 .23245 L .76935 .22905 L p F P
0 g
s
.622 .635 .843 r
.56269 .65428 m .56556 .65937 L .54167 .67022 L p F P
0 g
s
.622 .635 .843 r
.54167 .67022 m .53608 .66039 L .56269 .65428 L p F P
0 g
s
.528 .421 .675 r
.66153 .83535 m .6596 .82671 L .67234 .83027 L closepath p F P
0 g
s
.819 .872 .885 r
.69653 .33561 m .67711 .35119 L .67188 .34667 L p F P
0 g
s
.813 .512 .481 r
.20945 .92741 m .19388 .92304 L .19206 .91062 L p F P
0 g
s
.82 .517 .478 r
.17695 .90607 m .19206 .91062 L .19388 .92304 L p F P
0 g
s
.846 .659 .648 r
.13481 .83109 m .14756 .83657 L .14209 .85079 L p F P
0 g
s
.836 .669 .676 r
.14185 .81645 m .13481 .83109 L .14756 .83657 L p F P
0 g
s
.479 .185 .388 r
.58837 .93993 m .59044 .92908 L .61669 .92168 L p F P
0 g
s
.515 .263 .471 r
.61758 .90971 m .61669 .92168 L .59044 .92908 L p F P
0 g
s
.743 .729 .839 r
.29496 .65132 m .2691 .66788 L .26121 .65841 L p F P
0 g
s
.994 .82 .563 r
.49608 .31653 m .49581 .31759 L .49542 .31669 L closepath p F P
0 g
s
.591 .571 .8 r
.6173 .70498 m .60342 .70671 L .61538 .70066 L closepath p F P
0 g
s
.599 .59 .813 r
.61038 .69031 m .61538 .70066 L .60342 .70671 L p F P
0 g
s
.637 .644 .841 r
.50264 .65554 m .52904 .64817 L .53608 .66039 L p F P
0 g
s
.637 .647 .843 r
.5235 .63866 m .52904 .64817 L .50264 .65554 L p F P
0 g
s
.637 .647 .843 r
.50264 .65554 m .49812 .64787 L .5235 .63866 L p F P
0 g
s
.835 .69 .703 r
.14185 .81645 m .14487 .81127 L .13697 .79784 L p F P
0 g
s
.865 .887 .849 r
.72369 .29943 m .73437 .28848 L .73499 .29925 L p F P
0 g
s
.865 .887 .849 r
.73499 .29925 m .72971 .3046 L .72369 .29943 L p F P
0 g
s
.731 .721 .841 r
.29496 .65132 m .30342 .64624 L .31987 .65096 L p F P
0 g
s
.723 .726 .852 r
.32084 .6365 m .30342 .64624 L .31987 .65096 L p F P
0 g
s
.723 .726 .852 r
.31987 .65096 m .32854 .64613 L .32084 .6365 L p F P
0 g
s
.371 0 0 r
.49989 .96562 m .52179 .9625 L p .5228 .96911 L F P
0 g
s
.371 0 0 r
.49497 .97186 m .49989 .96562 L p .5228 .96911 L F P
0 g
s
.997 .81 .532 r
.48897 .32015 m .4933 .32978 L .49581 .31759 L p F P
0 g
s
.997 .81 .532 r
.49581 .31759 m .49542 .31669 L .48897 .32015 L p F P
0 g
s
.754 .35 .286 r
.24819 .94696 m .25348 .95453 L .25061 .95668 L p F P
0 g
s
.754 .35 .286 r
.23084 .94316 m .24819 .94696 L p .25061 .95668 L F P
0 g
s
.867 .891 .85 r
.71751 .31682 m .72971 .3046 L .72369 .29943 L p F P
0 g
s
.536 .448 .702 r
.67973 .80214 m .66097 .79876 L .67675 .79091 L closepath p F P
0 g
s
.55 .474 .723 r
.67244 .77674 m .67675 .79091 L .66097 .79876 L p F P
0 g
s
.55 .474 .723 r
.6652 .77595 m .67244 .77674 L p .66097 .79876 L F P
0 g
s
.484 .237 .464 r
.61669 .92168 m .61758 .90971 L .64297 .90124 L p F P
0 g
s
.513 .299 .527 r
.6428 .88839 m .64297 .90124 L .61758 .90971 L p F P
0 g
s
.832 .71 .73 r
.13676 .77416 m .14872 .78006 L .13821 .79567 L p F P
0 g
s
.825 .716 .745 r
.14872 .78006 m .13676 .77416 L .14898 .75805 L p F P
0 g
s
.842 .883 .87 r
.69653 .33561 m .70349 .32945 L .69733 .32417 L p F P
0 g
s
.842 .883 .87 r
.69733 .32417 m .69682 .32463 L .69653 .33561 L p F P
0 g
s
.819 .872 .885 r
.67196 .34481 m .69682 .32463 L .69653 .33561 L p F P
0 g
s
.819 .872 .885 r
.67188 .34667 m .67196 .34481 L p .69653 .33561 L F P
0 g
s
.73 .816 .918 r
.58443 .39134 m .55792 .40523 L .55103 .39847 L p F P
0 g
s
.843 .881 .868 r
.71751 .31682 m .70349 .32945 L .69733 .32417 L p F P
0 g
s
.998 .824 .483 r
.77957 .17033 m .78262 .18072 L .78473 .1688 L p F P
0 g
s
.998 .824 .483 r
.78142 .15987 m .77957 .17033 L p .78473 .1688 L F P
0 g
s
.998 .824 .483 r
.78473 .1688 m .78211 .15976 L .78142 .15987 L p F P
0 g
s
.603 .608 .83 r
.58019 .68726 m .57662 .68041 L .60059 .6764 L closepath p F P
0 g
s
.867 .891 .85 r
.72369 .29943 m .71725 .30598 L .71751 .31682 L p F P
0 g
s
.843 .881 .868 r
.69733 .32417 m .71725 .30598 L .71751 .31682 L p F P
0 g
s
.513 .386 .645 r
.66427 .85059 m .66153 .83535 L .67234 .83027 L p F P
0 g
s
.683 .697 .857 r
.39538 .64088 m .42139 .62993 L .42874 .6404 L p F P
0 g
s
.683 .706 .865 r
.42139 .62993 m .39538 .64088 L .38792 .63069 L p F P
0 g
s
.696 .707 .856 r
.36199 .64279 m .38792 .63069 L .39538 .64088 L p F P
0 g
s
.448 .085 .256 r
.55731 .95607 m .56115 .94642 L .58834 .94008 L p F P
0 g
s
.502 .191 .372 r
.58837 .93993 m .58834 .94008 L .56115 .94642 L p F P
0 g
s
.489 .126 .276 r
.56115 .94642 m .55731 .95607 L .52913 .96141 L p F P
0 g
s
.697 .715 .863 r
.38792 .63069 m .36199 .64279 L .35441 .63287 L p F P
0 g
s
.997 .851 .567 r
.48894 .32006 m .48897 .32015 L .49542 .31669 L p F P
0 g
s
.997 .851 .567 r
.49542 .31669 m .49257 .30745 L .48894 .32006 L p F P
0 g
s
.794 .735 .798 r
.19984 .70548 m .18297 .72116 L .17481 .71165 L p F P
0 g
s
.794 .735 .798 r
.17481 .71165 m .18791 .69937 L .19984 .70548 L p F P
0 g
s
.782 .739 .813 r
.20112 .68816 m .18791 .69937 L .19984 .70548 L p F P
0 g
s
.782 .739 .813 r
.19984 .70548 m .20921 .69759 L .20112 .68816 L p F P
0 g
s
.571 .542 .783 r
.62573 .72399 m .63288 .71992 L p .6511 .73648 L F P
0 g
s
.578 .563 .801 r
.62573 .72399 m .62421 .72056 L .63288 .71992 L closepath p F P
0 g
s
.683 .258 .231 r
.29536 .96424 m .29416 .96409 L .29465 .96365 L closepath p F P
0 g
s
.795 .737 .799 r
.18008 .72386 m .18297 .72116 L .17481 .71165 L p F P
0 g
s
.808 .734 .782 r
.16836 .71773 m .18008 .72386 L .16336 .74131 L p F P
0 g
s
.795 .737 .799 r
.17481 .71165 m .16836 .71773 L .18008 .72386 L p F P
0 g
s
.846 .681 .677 r
.12955 .81076 m .14185 .81645 L .13481 .83109 L p F P
0 g
s
.835 .69 .703 r
.13697 .79784 m .12955 .81076 L .14185 .81645 L p F P
0 g
s
.829 .563 .536 r
.17695 .90607 m .16715 .90293 L .16909 .89047 L p F P
0 g
s
.837 .57 .536 r
.1629 .88833 m .16909 .89047 L .16715 .90293 L p F P
0 g
s
.78 .737 .813 r
.22327 .68594 m .20921 .69759 L .20112 .68816 L p F P
0 g
s
.805 .459 .402 r
.20945 .92741 m .21268 .93675 L .21117 .93858 L p F P
0 g
s
.805 .459 .402 r
.19388 .92304 m .20945 .92741 L p .21117 .93858 L F P
0 g
s
.669 .685 .857 r
.42874 .6404 m .45486 .63056 L .46211 .64135 L p F P
0 g
s
.669 .693 .864 r
.45486 .63056 m .42874 .6404 L .42139 .62993 L p F P
0 g
s
.711 .724 .86 r
.35441 .63287 m .32854 .64613 L .32084 .6365 L p F P
0 g
s
.963 .901 .713 r
.76935 .22905 m .76828 .23107 L .76997 .24168 L p F P
0 g
s
.937 .896 .762 r
.75873 .24586 m .7604 .25644 L .76997 .24168 L p F P
0 g
s
.937 .896 .762 r
.76997 .24168 m .76828 .23107 L .75873 .24586 L p F P
0 g
s
.616 .122 .058 r
.32405 .97463 m .31183 .97311 L .29536 .96424 L p F P
0 g
s
.551 .012 0 r
.29416 .96409 m .29536 .96424 L .31183 .97311 L p F P
0 g
s
.578 .563 .802 r
.63288 .71992 m .62421 .72056 L .6173 .70498 L p F P
0 g
s
.551 .012 0 r
.28616 .96847 m .29416 .96409 L p .31183 .97311 L F P
0 g
s
.668 .196 .123 r
.28616 .96847 m .27586 .96107 L .29416 .96409 L closepath p F P
0 g
s
0 0 .459 r
.76892 .1066 m .76605 .10191 L .75972 .0896 L p F P
0 g
s
.867 .694 .167 r
.49116 .35334 m .49248 .36401 L .49293 .35244 L p F P
0 g
s
.867 .694 .167 r
.49293 .35244 m .49159 .34176 L .49116 .35334 L p F P
0 g
s
.69 .755 .901 r
.53872 .40381 m .52456 .40977 L .51751 .40136 L p F P
0 g
s
.771 .842 .905 r
.64103 .36705 m .61766 .38201 L .61105 .37586 L p F P
0 g
s
.78 .737 .813 r
.20112 .68816 m .21102 .6799 L .22327 .68594 L p F P
0 g
s
.768 .74 .827 r
.22723 .66755 m .21102 .6799 L .22327 .68594 L p F P
0 g
s
.768 .74 .827 r
.22327 .68594 m .23526 .67689 L .22723 .66755 L p F P
0 g
s
.818 .727 .765 r
.16336 .74131 m .15633 .74949 L .14813 .73941 L p F P
0 g
s
.818 .727 .765 r
.14813 .73941 m .15172 .73519 L .16336 .74131 L p F P
0 g
s
.808 .734 .782 r
.16336 .74131 m .15172 .73519 L .16836 .71773 L p F P
0 g
s
.981 .879 .657 r
.77324 .20662 m .77572 .21708 L .78128 .20381 L p F P
0 g
s
.981 .879 .657 r
.78128 .20381 m .77879 .19333 L .77324 .20662 L p F P
0 g
s
.654 .674 .856 r
.46211 .64135 m .48837 .63265 L .49553 .64374 L p F P
0 g
s
.655 .68 .862 r
.48837 .63265 m .46211 .64135 L .45486 .63056 L p F P
0 g
s
.603 .61 .832 r
.60059 .6764 m .57662 .68041 L .56967 .66714 L p F P
0 g
s
.64 .662 .856 r
.52196 .63619 m .5235 .63866 L .49812 .64787 L p F P
0 g
s
.64 .662 .856 r
.49812 .64787 m .49553 .64374 L .52196 .63619 L p F P
0 g
s
.764 .738 .829 r
.25172 .66481 m .23526 .67689 L .22723 .66755 L p F P
0 g
s
.977 .735 .32 r
.77795 .14813 m .78169 .15839 L .78195 .14718 L p F P
0 g
s
.977 .735 .32 r
.78195 .14718 m .77821 .13692 L .77795 .14813 L p F P
0 g
s
.621 .639 .847 r
.56269 .65428 m .53608 .66039 L .52904 .64817 L p F P
0 g
s
.818 .729 .766 r
.14898 .75805 m .15633 .74949 L .14813 .73941 L p F P
0 g
s
.732 .727 .846 r
.30342 .64624 m .29496 .65132 L .28715 .64161 L p F P
0 g
s
.743 .729 .839 r
.26121 .65841 m .28715 .64161 L .29496 .65132 L p F P
0 g
s
.842 .605 .58 r
.1629 .88833 m .1492 .88328 L .15143 .86987 L p F P
0 g
s
.85 .612 .579 r
.1382 .86462 m .15143 .86987 L .1492 .88328 L p F P
0 g
s
.845 .634 .616 r
.15143 .86987 m .1382 .86462 L .14209 .85079 L p F P
0 g
s
.842 .698 .703 r
.13697 .79784 m .13821 .79567 L .13446 .79383 L closepath p F P
0 g
s
.832 .71 .73 r
.12888 .78595 m .13676 .77416 L p .13821 .79567 L F P
0 g
s
.832 .71 .73 r
.13821 .79567 m .13446 .79383 L .12888 .78595 L p F P
0 g
s
.483 .277 .523 r
.66127 .88118 m .6428 .88839 L .64297 .90124 L p F P
0 g
s
.507 .327 .572 r
.6428 .88839 m .66127 .88118 L .65455 .86972 L p F P
0 g
s
.837 .57 .536 r
.16715 .90293 m .16244 .90131 L .1629 .88833 L p F P
0 g
s
.845 .577 .534 r
.1492 .88328 m .1629 .88833 L .16244 .90131 L p F P
0 g
s
.467 .052 .168 r
.52846 .96251 m .52179 .9625 L .52913 .96141 L closepath p F P
0 g
s
.371 0 0 r
.52179 .9625 m .52846 .96251 L .5228 .96911 L p F P
0 g
s
.963 .786 .616 r
.48666 .29817 m .49257 .30745 L .49657 .29476 L p F P
0 g
s
.963 .786 .616 r
.49657 .29476 m .49055 .28551 L .48666 .29817 L p F P
0 g
s
.504 .326 .573 r
.66622 .86507 m .65455 .86972 L .66127 .88118 L p F P
0 g
s
.526 .368 .61 r
.66427 .85059 m .66622 .86507 L .65455 .86972 L p F P
0 g
s
.842 .698 .703 r
.12955 .81076 m .13697 .79784 L .13446 .79383 L p F P
0 g
s
.83 .724 .747 r
.13748 .75192 m .14898 .75805 L .13676 .77416 L p F P
0 g
s
.818 .729 .766 r
.14813 .73941 m .13748 .75192 L .14898 .75805 L p F P
0 g
s
.853 .642 .617 r
.12934 .84533 m .14209 .85079 L .1382 .86462 L p F P
0 g
s
.846 .659 .648 r
.14209 .85079 m .12934 .84533 L .13481 .83109 L p F P
0 g
s
.496 .349 .611 r
.66622 .86507 m .66427 .85059 L .68786 .83962 L p F P
0 g
s
.513 .386 .645 r
.68749 .83766 m .68786 .83962 L .66427 .85059 L p F P
0 g
s
.513 .386 .645 r
.67234 .83027 m .68749 .83766 L p .66427 .85059 L F P
0 g
s
.82 .517 .478 r
.19388 .92304 m .17873 .91851 L .17695 .90607 L p F P
0 g
s
.826 .519 .47 r
.16715 .90293 m .17695 .90607 L .17873 .91851 L p F P
0 g
s
.243 .318 .742 r
.50943 .39066 m .50966 .39209 L .49253 .38648 L p F P
0 g
s
.243 .318 .742 r
.50326 .38082 m .50943 .39066 L p .49253 .38648 L F P
0 g
s
.243 .318 .742 r
.49253 .38648 m .49524 .37453 L .50326 .38082 L p F P
0 g
s
.754 .35 .286 r
.25061 .95668 m .23894 .95408 L .23084 .94316 L p F P
0 g
s
.756 .342 .266 r
.21381 .93923 m .23084 .94316 L .23894 .95408 L p F P
0 g
s
.779 .425 .385 r
.23084 .94316 m .21381 .93923 L .21268 .93675 L p F P
0 g
s
.764 .738 .829 r
.22723 .66755 m .23899 .65887 L .25172 .66481 L p F P
0 g
s
.753 .741 .841 r
.25325 .64917 m .23899 .65887 L .25172 .66481 L p F P
0 g
s
.753 .741 .841 r
.25172 .66481 m .26121 .65841 L .25325 .64917 L p F P
0 g
s
.732 .727 .846 r
.28715 .64161 m .28784 .6412 L .30342 .64624 L p F P
0 g
s
.725 .733 .857 r
.31308 .62709 m .28784 .6412 L .30342 .64624 L p F P
0 g
s
.725 .733 .857 r
.30342 .64624 m .32084 .6365 L .31308 .62709 L p F P
0 g
s
.913 .894 .796 r
.74715 .2614 m .75873 .24586 L .7604 .25644 L p F P
0 g
s
.913 .894 .796 r
.74836 .26948 m .74715 .2614 L p .7604 .25644 L F P
0 g
s
.913 .894 .796 r
.7604 .25644 m .74975 .27059 L .74836 .26948 L p F P
0 g
s
.91 .606 .118 r
.77391 .12677 m .77821 .13692 L .77668 .12644 L p F P
0 g
s
.91 .606 .118 r
.77668 .12644 m .77238 .11628 L .77391 .12677 L p F P
0 g
s
.544 .472 .725 r
.67244 .77674 m .6652 .77595 L .67127 .77283 L closepath p F P
0 g
s
.558 .497 .744 r
.66534 .75535 m .67127 .77283 L .6652 .77595 L p F P
0 g
s
.558 .497 .744 r
.66188 .75517 m .66534 .75535 L p .6652 .77595 L F P
0 g
s
0 .246 .76 r
.7471 .068 m .75302 .07784 L .74373 .07054 L p F P
0 g
s
0 .246 .76 r
.74373 .07054 m .7378 .06073 L .7471 .068 L p F P
0 g
s
.425 .01 .145 r
.52846 .96251 m .52913 .96141 L .55731 .95607 L p F P
0 g
s
.578 .563 .802 r
.6173 .70498 m .64446 .70319 L p .63288 .71992 L F P
0 g
s
.571 .56 .803 r
.63754 .68777 m .64446 .70319 L .6173 .70498 L p F P
0 g
s
.571 .56 .803 r
.63622 .68785 m .63754 .68777 L p .6173 .70498 L F P
0 g
s
.571 .56 .803 r
.6173 .70498 m .61538 .70066 L .63622 .68785 L p F P
0 g
s
.64 .668 .861 r
.52196 .63619 m .49553 .64374 L .48837 .63265 L p F P
0 g
s
.571 .542 .783 r
.63288 .71992 m .65139 .71933 L p .6511 .73648 L F P
0 g
s
.567 .543 .787 r
.65139 .71933 m .63288 .71992 L .64801 .71111 L closepath p F P
0 g
s
.578 .563 .802 r
.64446 .70319 m .64801 .71111 L .63288 .71992 L p F P
0 g
s
.788 .853 .9 r
.64423 .36484 m .64103 .36705 L .64152 .36236 L closepath p F P
0 g
s
.771 .842 .905 r
.63773 .35864 m .64152 .36236 L .64103 .36705 L p F P
0 g
s
.771 .842 .905 r
.61105 .37586 m .63773 .35864 L p .64103 .36705 L F P
0 g
s
.714 .293 .245 r
.27586 .96107 m .25669 .95778 L .25348 .95453 L p F P
0 g
s
.646 .144 .042 r
.27586 .96107 m .28616 .96847 L .28314 .96936 L p F P
0 g
s
.646 .144 .042 r
.25669 .95778 m .27586 .96107 L p .28314 .96936 L F P
0 g
s
.854 .668 .65 r
.12252 .82542 m .13481 .83109 L .12934 .84533 L p F P
0 g
s
.846 .681 .677 r
.13481 .83109 m .12252 .82542 L .12955 .81076 L p F P
0 g
s
.999 .788 .473 r
.48731 .33202 m .49159 .34176 L .4933 .32978 L p F P
0 g
s
.999 .788 .473 r
.48891 .32023 m .48731 .33202 L p .4933 .32978 L F P
0 g
s
.999 .788 .473 r
.4933 .32978 m .48897 .32015 L .48891 .32023 L p F P
0 g
s
.842 .698 .703 r
.13446 .79383 m .12632 .78977 L p .12955 .81076 L F P
0 g
s
.835 .71 .727 r
.13446 .79383 m .12888 .78595 L .12632 .78977 L closepath p F P
0 g
s
.69 .755 .901 r
.54408 .39123 m .54486 .39206 L .53872 .40381 L p F P
0 g
s
.69 .755 .901 r
.51751 .40136 m .54408 .39123 L p .53872 .40381 L F P
0 g
s
.697 .792 .924 r
.55103 .39847 m .53872 .40381 L .54486 .39206 L closepath p F P
0 g
s
.8 .854 .891 r
.66442 .33939 m .67081 .34566 L .64423 .36484 L p F P
0 g
s
.8 .854 .891 r
.64168 .35598 m .66442 .33939 L p .64423 .36484 L F P
0 g
s
.8 .854 .891 r
.64423 .36484 m .64152 .36236 L .64168 .35598 L p F P
0 g
s
0 0 .459 r
.75972 .0896 m .76407 .09655 L .76892 .1066 L p F P
0 g
s
.765 .406 0 r
.76753 .10623 m .77238 .11628 L .76892 .1066 L p F P
0 g
s
.765 .406 0 r
.76892 .1066 m .76407 .09655 L .76753 .10623 L p F P
0 g
s
.747 .738 .844 r
.28715 .64161 m .26121 .65841 L .25325 .64917 L p F P
0 g
s
.581 .583 .819 r
.61538 .70066 m .61038 .69031 L .63622 .68785 L closepath p F P
0 g
s
.995 .854 .586 r
.77572 .18297 m .77879 .19333 L .78262 .18072 L p F P
0 g
s
.995 .854 .586 r
.78262 .18072 m .77957 .17033 L .77572 .18297 L p F P
0 g
s
0 0 .564 r
.75344 .07836 m .75302 .07784 L .75831 .08781 L p F P
0 g
s
0 0 .564 r
.75831 .08781 m .75972 .0896 L .75344 .07836 L p F P
0 g
s
.747 .819 .909 r
.60233 .38116 m .58443 .39134 L .57764 .38461 L p F P
0 g
s
.73 .816 .918 r
.55103 .39847 m .57764 .38461 L .58443 .39134 L p F P
0 g
s
.534 .011 0 r
.35865 .97736 m .3344 .97547 L .32758 .97304 L p F P
0 g
s
.533 .007 0 r
.3344 .97547 m .32405 .97463 L .32758 .97304 L closepath p F P
0 g
s
.717 .291 .235 r
.25669 .95778 m .25061 .95668 L .25348 .95453 L closepath p F P
0 g
s
.511 .387 .647 r
.68749 .83766 m .67234 .83027 L .68499 .82423 L closepath p F P
0 g
s
.529 .419 .673 r
.6813 .80802 m .68499 .82423 L .67234 .83027 L p F P
0 g
s
.604 .701 .912 r
.51041 .39205 m .50966 .39209 L .50942 .40307 L p F P
0 g
s
.604 .701 .912 r
.50942 .40307 m .51751 .40136 L .51041 .39205 L p F P
0 g
s
.805 .459 .402 r
.21117 .93858 m .19809 .9349 L .19388 .92304 L p F P
0 g
s
.811 .461 .393 r
.17873 .91851 m .19388 .92304 L .19809 .9349 L p F P
0 g
s
.425 .01 .145 r
.55731 .95607 m .5551 .95956 L .52846 .96251 L p F P
0 g
s
.361 0 .007 r
.5228 .96911 m .52846 .96251 L .5551 .95956 L p F P
0 g
s
.959 .888 .717 r
.76588 .22061 m .77324 .20662 L .77572 .21708 L p F P
0 g
s
.959 .888 .717 r
.76756 .22779 m .76588 .22061 L p .77572 .21708 L F P
0 g
s
.959 .888 .717 r
.77572 .21708 m .76935 .22905 L .76756 .22779 L p F P
0 g
s
.383 0 0 r
.39428 .9799 m .39717 .97857 L .41782 .97834 L p F P
0 g
s
.438 0 0 r
.39428 .9799 m .38645 .97832 L .39717 .97857 L closepath p F P
0 g
s
.84 .716 .727 r
.13676 .77416 m .12888 .78595 L .12066 .77502 L p F P
0 g
s
.84 .716 .727 r
.12066 .77502 m .12528 .76806 L .13676 .77416 L p F P
0 g
s
.83 .724 .747 r
.13676 .77416 m .12528 .76806 L .13748 .75192 L p F P
0 g
s
.683 .706 .865 r
.38792 .63069 m .41398 .61983 L .42139 .62993 L p F P
0 g
s
.679 .722 .882 r
.41398 .61983 m .38792 .63069 L .3804 .62084 L p F P
0 g
s
.697 .715 .863 r
.35441 .63287 m .3804 .62084 L .38792 .63069 L p F P
0 g
s
.801 .856 .89 r
.67188 .34667 m .67081 .34566 L .67196 .34481 L closepath p F P
0 g
s
.397 0 0 r
.42782 .97959 m .41782 .97834 L .43067 .97809 L closepath p F P
0 g
s
.383 0 0 r
.41782 .97834 m .42782 .97959 L p .39428 .9799 L F P
0 g
s
.444 0 0 r
.38645 .97832 m .39428 .9799 L p .36083 .97802 L F P
0 g
s
.444 0 0 r
.36083 .97802 m .36186 .97758 L .38645 .97832 L p F P
0 g
s
.695 .729 .876 r
.3804 .62084 m .35441 .63287 L .34678 .62321 L p F P
0 g
s
.711 .724 .86 r
.32084 .6365 m .34678 .62321 L .35441 .63287 L p F P
0 g
s
.913 .895 .797 r
.74975 .27059 m .74869 .27199 L .74836 .26948 L closepath p F P
0 g
s
.552 .496 .747 r
.66534 .75535 m .66188 .75517 L .66476 .75363 L closepath p F P
0 g
s
.565 .52 .764 r
.65834 .73652 m .66476 .75363 L .66188 .75517 L p F P
0 g
s
.565 .52 .764 r
.6511 .73648 m .65834 .73652 L p .66188 .75517 L F P
0 g
s
.799 .743 .801 r
.18791 .69937 m .17481 .71165 L .16656 .70247 L p F P
0 g
s
.799 .743 .801 r
.16656 .70247 m .1766 .69301 L .18791 .69937 L p F P
0 g
s
.786 .746 .816 r
.19294 .67903 m .1766 .69301 L .18791 .69937 L p F P
0 g
s
.786 .746 .816 r
.18791 .69937 m .20112 .68816 L .19294 .67903 L p F P
0 g
s
.883 .88 .826 r
.73301 .27787 m .73437 .28848 L .74869 .27199 L p F P
0 g
s
.883 .88 .826 r
.74381 .26529 m .73301 .27787 L p .74869 .27199 L F P
0 g
s
.883 .88 .826 r
.74869 .27199 m .74836 .26948 L .74381 .26529 L p F P
0 g
s
.345 0 0 r
.42782 .97959 m .43067 .97809 L .45543 .97677 L p F P
0 g
s
.56 .52 .768 r
.65834 .73652 m .6511 .73648 L .65708 .73315 L closepath p F P
0 g
s
.571 .542 .783 r
.65139 .71933 m .65708 .73315 L .6511 .73648 L p F P
0 g
s
.853 .69 .679 r
.1177 .80487 m .12955 .81076 L .12252 .82542 L p F P
0 g
s
.842 .698 .703 r
.12632 .78977 m .1177 .80487 L .12955 .81076 L p F P
0 g
s
.8 .745 .802 r
.16836 .71773 m .17481 .71165 L .16656 .70247 L p F P
0 g
s
.669 .693 .864 r
.42139 .62993 m .44756 .6201 L .45486 .63056 L p F P
0 g
s
.668 .705 .875 r
.44756 .6201 m .42139 .62993 L .41398 .61983 L p F P
0 g
s
.603 .61 .832 r
.56967 .66714 m .59653 .66273 L p .60059 .6764 L F P
0 g
s
.599 .61 .834 r
.58958 .64957 m .59653 .66273 L .56967 .66714 L p F P
0 g
s
.599 .61 .834 r
.57976 .65115 m .58958 .64957 L p .56967 .66714 L F P
0 g
s
.599 .61 .834 r
.56967 .66714 m .56556 .65937 L .57976 .65115 L p F P
0 g
s
.813 .742 .786 r
.1572 .71136 m .16836 .71773 L .15172 .73519 L p F P
0 g
s
.8 .745 .802 r
.16656 .70247 m .1572 .71136 L .16836 .71773 L p F P
0 g
s
.786 .427 .378 r
.21381 .93923 m .21117 .93858 L .21268 .93675 L closepath p F P
0 g
s
0 0 .433 r
.76407 .09655 m .75972 .0896 L .75344 .07836 L p F P
0 g
s
.784 .745 .817 r
.21102 .6799 m .20112 .68816 L .19294 .67903 L p F P
0 g
s
.999 .817 .475 r
.78211 .15976 m .78142 .15987 L .78169 .15839 L closepath p F P
0 g
s
.5 0 0 r
.36083 .97802 m .35865 .97736 L .36186 .97758 L closepath p F P
0 g
s
.712 .732 .866 r
.34678 .62321 m .32084 .6365 L .31308 .62709 L p F P
0 g
s
0 0 .182 r
.49321 .36413 m .49524 .37453 L .49248 .36401 L p F P
0 g
s
0 0 .182 r
.49248 .36401 m .49116 .35334 L .49321 .36413 L p F P
0 g
s
.445 .157 .381 r
.61516 .93038 m .61669 .92168 L .64218 .91325 L p F P
0 g
s
.484 .237 .464 r
.64297 .90124 m .64218 .91325 L .61669 .92168 L p F P
0 g
s
.479 .185 .388 r
.61669 .92168 m .61516 .93038 L .58837 .93993 L p F P
0 g
s
.463 .154 .356 r
.58834 .94008 m .58837 .93993 L .61516 .93038 L p F P
0 g
s
.388 0 0 r
.35865 .97736 m .36083 .97802 L .35286 .97958 L p F P
0 g
s
.388 0 0 r
.35286 .97958 m .3344 .97547 L .35865 .97736 L p F P
0 g
s
.784 .745 .817 r
.19294 .67903 m .19945 .67357 L .21102 .6799 L p F P
0 g
s
.772 .747 .83 r
.21913 .65848 m .19945 .67357 L .21102 .6799 L p F P
0 g
s
.772 .747 .83 r
.21102 .6799 m .22723 .66755 L .21913 .65848 L p F P
0 g
s
.621 .639 .847 r
.52904 .64817 m .55568 .64206 L .56269 .65428 L p F P
0 g
s
.62 .64 .848 r
.54864 .62991 m .55568 .64206 L .52904 .64817 L p F P
0 g
s
.62 .64 .848 r
.53498 .63304 m .54864 .62991 L p .52904 .64817 L F P
0 g
s
.62 .64 .848 r
.52904 .64817 m .5235 .63866 L .53498 .63304 L p F P
0 g
s
.526 .461 .726 r
.67127 .77283 m .69333 .75956 L p .69406 .7809 L F P
0 g
s
.526 .461 .726 r
.69406 .7809 m .67244 .77674 L .67127 .77283 L p F P
0 g
s
.534 .487 .749 r
.69308 .75884 m .69333 .75956 L .67127 .77283 L p F P
0 g
s
.534 .487 .749 r
.67127 .77283 m .66534 .75535 L .69308 .75884 L p F P
0 g
s
.826 .519 .47 r
.16352 .91099 m .16715 .90293 L p .17873 .91851 L F P
0 g
s
.836 .535 .481 r
.16352 .91099 m .16244 .90131 L .16715 .90293 L closepath p F P
0 g
s
.404 .043 .236 r
.58461 .94971 m .58834 .94008 L .61466 .93267 L p F P
0 g
s
.463 .154 .356 r
.61516 .93038 m .61466 .93267 L .58834 .94008 L p F P
0 g
s
.448 .085 .256 r
.58834 .94008 m .58461 .94971 L .55731 .95607 L p F P
0 g
s
.526 .462 .728 r
.67675 .79091 m .67244 .77674 L .69406 .7809 L closepath p F P
0 g
s
.8 .848 .887 r
.67196 .34481 m .67081 .34566 L .66442 .33939 L p F P
0 g
s
.816 .855 .878 r
.6716 .33401 m .67196 .34481 L .69682 .32463 L p F P
0 g
s
.8 .848 .887 r
.66442 .33939 m .6716 .33401 L .67196 .34481 L p F P
0 g
s
.824 .736 .767 r
.15172 .73519 m .14813 .73941 L .13983 .72976 L p F P
0 g
s
.824 .736 .767 r
.13983 .72976 m .14061 .72884 L .15172 .73519 L p F P
0 g
s
.813 .742 .786 r
.15172 .73519 m .14061 .72884 L .1572 .71136 L p F P
0 g
s
.655 .68 .862 r
.45486 .63056 m .48117 .6218 L .48837 .63265 L p F P
0 g
s
.656 .689 .869 r
.48117 .6218 m .45486 .63056 L .44756 .6201 L p F P
0 g
s
.969 .785 .599 r
.48316 .31076 m .48894 .32006 L .49257 .30745 L p F P
0 g
s
.969 .785 .599 r
.49257 .30745 m .48666 .29817 L .48316 .31076 L p F P
0 g
s
.517 .436 .703 r
.67675 .79091 m .69406 .7809 L p .68781 .8044 L F P
0 g
s
.517 .436 .703 r
.68781 .8044 m .67973 .80214 L .67675 .79091 L p F P
0 g
s
.529 .482 .748 r
.68656 .73997 m .69308 .75884 L .66534 .75535 L p F P
0 g
s
.529 .482 .748 r
.66534 .75535 m .66476 .75363 L .68656 .73997 L p F P
0 g
s
.581 .584 .82 r
.63622 .68785 m .61038 .69031 L .60346 .67599 L p F P
0 g
s
.542 .511 .77 r
.68599 .73849 m .68656 .73997 L .66476 .75363 L p F P
0 g
s
.542 .511 .77 r
.66476 .75363 m .65834 .73652 L .68599 .73849 L p F P
0 g
s
.379 0 0 r
.4614 .97714 m .45543 .97677 L .46267 .97631 L closepath p F P
0 g
s
.345 0 0 r
.45543 .97677 m .4614 .97714 L p .42782 .97959 L F P
0 g
s
.731 .801 .908 r
.57079 .37754 m .57764 .38461 L .55103 .39847 L p F P
0 g
s
.731 .801 .908 r
.54484 .39086 m .57079 .37754 L p .55103 .39847 L F P
0 g
s
.731 .801 .908 r
.55103 .39847 m .54486 .39206 L .54484 .39086 L p F P
0 g
s
1 .811 .489 r
.77607 .15927 m .77795 .14813 L .78169 .15839 L p F P
0 g
s
1 .811 .489 r
.78169 .15839 m .78142 .15987 L .77607 .15927 L p F P
0 g
s
.474 .304 .57 r
.66735 .87877 m .66622 .86507 L .68989 .85418 L p F P
0 g
s
.496 .349 .611 r
.68786 .83962 m .68989 .85418 L .66622 .86507 L p F P
0 g
s
.504 .326 .573 r
.66127 .88118 m .66735 .87877 L .66622 .86507 L p F P
0 g
s
.865 .877 .844 r
.7176 .29388 m .73301 .27787 L .73437 .28848 L p F P
0 g
s
.865 .877 .844 r
.73437 .28848 m .72369 .29943 L .7176 .29388 L p F P
0 g
s
.823 .736 .768 r
.13748 .75192 m .14813 .73941 L .13983 .72976 L p F P
0 g
s
.839 .717 .729 r
.12632 .78977 m .12888 .78595 L .12066 .77502 L p F P
0 g
s
.756 .342 .266 r
.23894 .95408 m .22209 .95009 L .21381 .93923 L p F P
0 g
s
.745 .307 .212 r
.21117 .93858 m .21381 .93923 L .22209 .95009 L p F P
0 g
s
.759 .831 .908 r
.60233 .38116 m .61105 .37586 L .60437 .36941 L p F P
0 g
s
.759 .831 .908 r
.60437 .36941 m .60366 .36983 L .60233 .38116 L p F P
0 g
s
.747 .819 .909 r
.57764 .38461 m .60366 .36983 L .60233 .38116 L p F P
0 g
s
.646 .144 .042 r
.28314 .96936 m .27112 .96715 L .25669 .95778 L p F P
0 g
s
.6 .063 0 r
.25061 .95668 m .25669 .95778 L .27112 .96715 L p F P
0 g
s
.888 .88 .821 r
.74836 .26948 m .74381 .26529 L .74715 .2614 L closepath p F P
0 g
s
.444 0 0 r
.39428 .9799 m .3865 .98123 L .36083 .97802 L p F P
0 g
s
.005 .58 .744 r
.36083 .97802 m .3865 .98123 L .3832 .98091 L p F P
0 g
s
.005 .58 .744 r
.35286 .97958 m .36083 .97802 L p .3832 .98091 L F P
0 g
s
.326 0 0 r
.4614 .97714 m .46267 .97631 L .49329 .97326 L p F P
0 g
s
.447 0 .039 r
.49497 .97186 m .49329 .97326 L .46267 .97631 L p F P
0 g
s
.652 .76 .929 r
.54408 .39123 m .51751 .40136 L .51041 .39205 L p F P
0 g
s
.845 .577 .534 r
.16244 .90131 m .14872 .89627 L .1492 .88328 L p F P
0 g
s
.853 .585 .532 r
.13594 .87805 m .1492 .88328 L .14872 .89627 L p F P
0 g
s
.85 .612 .579 r
.1492 .88328 m .13594 .87805 L .1382 .86462 L p F P
0 g
s
.78 .839 .897 r
.64152 .36236 m .63773 .35864 L .64168 .35598 L closepath p F P
0 g
s
.858 .621 .579 r
.12541 .85918 m .1382 .86462 L .13594 .87805 L p F P
0 g
s
.853 .642 .617 r
.1382 .86462 m .12541 .85918 L .12934 .84533 L p F P
0 g
s
.768 .745 .833 r
.23899 .65887 m .22723 .66755 L .21913 .65848 L p F P
0 g
s
.734 .734 .85 r
.28715 .64161 m .28784 .6412 L .28635 .64065 L closepath p F P
0 g
s
.747 .738 .844 r
.28635 .64065 m .28715 .64161 L p .25325 .64917 L F P
0 g
s
1 .808 .48 r
.77957 .17033 m .78142 .15987 L .77607 .15927 L p F P
0 g
s
.866 .879 .844 r
.71725 .30598 m .72369 .29943 L .7176 .29388 L p F P
0 g
s
.724 .739 .863 r
.30525 .61792 m .31308 .62709 L .28784 .6412 L p F P
0 g
s
.724 .739 .863 r
.27926 .63247 m .30525 .61792 L p .28784 .6412 L F P
0 g
s
.724 .739 .863 r
.28784 .6412 m .28635 .64065 L .27926 .63247 L p F P
0 g
s
.959 .887 .717 r
.76935 .22905 m .76828 .23107 L .76756 .22779 L closepath p F P
0 g
s
.517 .437 .705 r
.6813 .80802 m .67973 .80214 L .68781 .8044 L closepath p F P
0 g
s
.839 .871 .866 r
.69733 .32417 m .69682 .32463 L .69677 .32365 L closepath p F P
0 g
s
.816 .855 .878 r
.69107 .31804 m .6716 .33401 L p .69682 .32463 L F P
0 g
s
.816 .855 .878 r
.69682 .32463 m .69677 .32365 L .69107 .31804 L p F P
0 g
s
.843 .871 .863 r
.71725 .30598 m .69733 .32417 L .69677 .32365 L p F P
0 g
s
.866 .879 .844 r
.7176 .29388 m .71622 .2953 L .71725 .30598 L p F P
0 g
s
.843 .871 .863 r
.696 .31393 m .71622 .2953 L .71725 .30598 L p F P
0 g
s
.843 .871 .863 r
.69677 .32365 m .696 .31393 L p .71725 .30598 L F P
0 g
s
.851 .709 .705 r
.11491 .78367 m .12632 .78977 L .1177 .80487 L p F P
0 g
s
.839 .717 .729 r
.12066 .77502 m .11491 .78367 L .12632 .78977 L p F P
0 g
s
.371 0 0 r
.5228 .96911 m .50909 .97111 L .49497 .97186 L p F P
0 g
s
.334 0 0 r
.50909 .97111 m .49329 .97326 L .49497 .97186 L closepath p F P
0 g
s
.745 .307 .212 r
.20347 .9437 m .21117 .93858 L p .22209 .95009 L F P
0 g
s
.784 .385 .296 r
.20347 .9437 m .19809 .9349 L .21117 .93858 L closepath p F P
0 g
s
.844 .54 .474 r
.16244 .90131 m .16352 .91099 L .1623 .91326 L p F P
0 g
s
.844 .54 .474 r
.14872 .89627 m .16244 .90131 L p .1623 .91326 L F P
0 g
s
.606 .629 .847 r
.56556 .65937 m .56269 .65428 L .57976 .65115 L closepath p F P
0 g
s
.451 .211 .458 r
.65853 .89522 m .64297 .90124 L .64218 .91325 L p F P
0 g
s
.483 .277 .523 r
.64297 .90124 m .65853 .89522 L .66127 .88118 L p F P
0 g
s
.747 .738 .844 r
.25325 .64917 m .27435 .63544 L .28635 .64065 L p F P
0 g
s
.738 .742 .855 r
.28635 .64065 m .27926 .63247 L .27435 .63544 L closepath p F P
0 g
s
.86 .651 .618 r
.11702 .83968 m .12934 .84533 L .12541 .85918 L p F P
0 g
s
.854 .668 .65 r
.12934 .84533 m .11702 .83968 L .12252 .82542 L p F P
0 g
s
.928 .881 .767 r
.75642 .2354 m .75873 .24586 L .76828 .23107 L p F P
0 g
s
.928 .881 .767 r
.76356 .22423 m .75642 .2354 L p .76828 .23107 L F P
0 g
s
.928 .881 .767 r
.76828 .23107 m .76756 .22779 L .76356 .22423 L p F P
0 g
s
.5 .403 .676 r
.68781 .8044 m .6813 .80802 L .68499 .82423 L p F P
0 g
s
.158 0 0 r
.3344 .97547 m .35286 .97958 L .34659 .97915 L p F P
0 g
s
.158 0 0 r
.32405 .97463 m .3344 .97547 L p .34659 .97915 L F P
0 g
s
.537 .507 .77 r
.67898 .72014 m .68599 .73849 L .65834 .73652 L p F P
0 g
s
.537 .507 .77 r
.67709 .71997 m .67898 .72014 L p .65834 .73652 L F P
0 g
s
.537 .507 .77 r
.65834 .73652 m .65708 .73315 L .67709 .71997 L p F P
0 g
s
.768 .745 .833 r
.21913 .65848 m .22704 .65261 L .23899 .65887 L p F P
0 g
s
.756 .747 .845 r
.24522 .64017 m .22704 .65261 L .23899 .65887 L p F P
0 g
s
.756 .747 .845 r
.23899 .65887 m .25325 .64917 L .24522 .64017 L p F P
0 g
s
.836 .733 .75 r
.12646 .74558 m .13748 .75192 L .12528 .76806 L p F P
0 g
s
.823 .736 .768 r
.13983 .72976 m .12646 .74558 L .13748 .75192 L p F P
0 g
s
.6 .063 0 r
.24471 .95921 m .25061 .95668 L p .27112 .96715 L F P
0 g
s
.707 .239 .138 r
.24471 .95921 m .23894 .95408 L .25061 .95668 L closepath p F P
0 g
s
.64 .668 .861 r
.48837 .63265 m .51485 .62503 L .52196 .63619 L p F P
0 g
s
.641 .674 .866 r
.51485 .62503 m .48837 .63265 L .48117 .6218 L p F P
0 g
s
.772 .83 .897 r
.63773 .35864 m .61105 .37586 L .60437 .36941 L p F P
0 g
s
.823 .856 .872 r
.69677 .32365 m .69107 .31804 L .696 .31393 L closepath p F P
0 g
s
.977 .866 .662 r
.77017 .19629 m .77324 .20662 L .77879 .19333 L p F P
0 g
s
.977 .866 .662 r
.77879 .19333 m .77572 .18297 L .77017 .19629 L p F P
0 g
s
.55 .534 .79 r
.65708 .73315 m .65139 .71933 L .67709 .71997 L closepath p F P
0 g
s
.383 0 0 r
.42782 .97959 m .42022 .98118 L .39428 .9799 L p F P
0 g
s
.096 .65 .796 r
.39428 .9799 m .42022 .98118 L .41771 .98097 L p F P
0 g
s
.096 .65 .796 r
.3865 .98123 m .39428 .9799 L p .41771 .98097 L F P
0 g
s
.988 .743 .36 r
.48684 .34364 m .49116 .35334 L .49159 .34176 L p F P
0 g
s
.988 .743 .36 r
.49159 .34176 m .48731 .33202 L .48684 .34364 L p F P
0 g
s
.985 .734 .346 r
.77365 .13799 m .77795 .14813 L .77821 .13692 L p F P
0 g
s
.985 .734 .346 r
.77821 .13692 m .77391 .12677 L .77365 .13799 L p F P
0 g
s
.366 0 .095 r
.5551 .95956 m .55731 .95607 L .58461 .94971 L p F P
0 g
s
.158 0 0 r
.31938 .97575 m .32405 .97463 L p .34659 .97915 L F P
0 g
s
.493 0 0 r
.31938 .97575 m .31183 .97311 L .32405 .97463 L closepath p F P
0 g
s
.326 0 0 r
.49329 .97326 m .48776 .97607 L .4614 .97714 L p F P
0 g
s
.075 .636 .71 r
.4614 .97714 m .48776 .97607 L .48174 .97681 L p F P
0 g
s
.075 .636 .71 r
.45399 .97954 m .4614 .97714 L p .48174 .97681 L F P
0 g
s
.345 0 0 r
.4614 .97714 m .45399 .97954 L .42782 .97959 L p F P
0 g
s
.861 .676 .651 r
.11066 .81956 m .12252 .82542 L .11702 .83968 L p F P
0 g
s
.853 .69 .679 r
.12252 .82542 m .11066 .81956 L .1177 .80487 L p F P
0 g
s
.595 .592 .819 r
.60346 .67599 m .60059 .6764 L .60301 .67508 L closepath p F P
0 g
s
.603 .61 .832 r
.59653 .66273 m .60301 .67508 L .60059 .6764 L p F P
0 g
s
.811 .461 .393 r
.19809 .9349 m .18295 .93036 L .17873 .91851 L p F P
0 g
s
.818 .463 .385 r
.16395 .91382 m .17873 .91851 L .18295 .93036 L p F P
0 g
s
.826 .519 .47 r
.17873 .91851 m .16395 .91382 L .16352 .91099 L p F P
0 g
s
.479 .273 .522 r
.66735 .87877 m .66127 .88118 L .65853 .89522 L p F P
0 g
s
.116 .667 .784 r
.42782 .97959 m .45399 .97954 L .4504 .9795 L p F P
0 g
s
.116 .667 .784 r
.42022 .98118 m .42782 .97959 L p .4504 .9795 L F P
0 g
s
.606 .632 .85 r
.57976 .65115 m .56269 .65428 L .55568 .64206 L p F P
0 g
s
.625 .656 .86 r
.5235 .63866 m .52196 .63619 L .53498 .63304 L closepath p F P
0 g
s
.75 .746 .849 r
.27435 .63544 m .25325 .64917 L .24522 .64017 L p F P
0 g
s
.581 .584 .82 r
.60346 .67599 m .63064 .6736 L p .63622 .68785 L F P
0 g
s
.575 .582 .823 r
.62432 .66072 m .63064 .6736 L .60346 .67599 L p F P
0 g
s
.575 .582 .823 r
.60346 .67599 m .60301 .67508 L .62432 .66072 L p F P
0 g
s
.931 .616 .155 r
.76906 .11672 m .77391 .12677 L .77238 .11628 L p F P
0 g
s
.931 .616 .155 r
.77238 .11628 m .76753 .10623 L .76906 .11672 L p F P
0 g
s
.491 .373 .647 r
.68499 .82423 m .70629 .8125 L p .68932 .83884 L F P
0 g
s
.491 .373 .647 r
.68932 .83884 m .68749 .83766 L .68499 .82423 L p F P
0 g
s
.5 .403 .676 r
.68499 .82423 m .70629 .8125 L .68781 .8044 L p F P
0 g
s
.55 .534 .789 r
.67709 .71997 m .65139 .71933 L .64801 .71111 L p F P
0 g
s
.932 .879 .761 r
.76756 .22779 m .76356 .22423 L .76588 .22061 L closepath p F P
0 g
s
.585 .604 .838 r
.62372 .65957 m .62432 .66072 L .60301 .67508 L p F P
0 g
s
.585 .604 .838 r
.60301 .67508 m .59653 .66273 L .62372 .65957 L p F P
0 g
s
.189 0 0 r
.48776 .97607 m .49329 .97326 L .50909 .97111 L p F P
0 g
s
.679 .722 .882 r
.4106 .61558 m .41398 .61983 L p .3804 .62084 L F P
0 g
s
.679 .722 .882 r
.3804 .62084 m .39482 .61509 L .4106 .61558 L p F P
0 g
s
.679 .722 .882 r
.3804 .62084 m .39482 .61509 L .37521 .61444 L closepath p F P
0 g
s
.695 .729 .876 r
.37521 .61444 m .3804 .62084 L p .34678 .62321 L F P
0 g
s
.381 0 0 r
.31183 .97311 m .31938 .97575 L .3112 .97586 L p F P
0 g
s
.381 0 0 r
.3112 .97586 m .29065 .97037 L .31183 .97311 L p F P
0 g
s
.551 .012 0 r
.31183 .97311 m .29065 .97037 L .28616 .96847 L p F P
0 g
s
.846 .724 .729 r
.12528 .76806 m .12066 .77502 L .11233 .76467 L p F P
0 g
s
.846 .724 .729 r
.11233 .76467 m .11426 .76174 L .12528 .76806 L p F P
0 g
s
.836 .733 .75 r
.12528 .76806 m .11426 .76174 L .12646 .74558 L p F P
0 g
s
.626 .662 .865 r
.53498 .63304 m .52196 .63619 L .51485 .62503 L p F P
0 g
s
.695 .729 .876 r
.34678 .62321 m .36889 .61328 L .37521 .61444 L p F P
0 g
s
.687 .743 .893 r
.36889 .61328 m .34678 .62321 L .33908 .61386 L p F P
0 g
s
.712 .732 .866 r
.31308 .62709 m .33908 .61386 L .34678 .62321 L p F P
0 g
s
.91 .876 .79 r
.74491 .25096 m .74715 .2614 L .75873 .24586 L p F P
0 g
s
.91 .876 .79 r
.75873 .24586 m .75642 .2354 L .74491 .25096 L p F P
0 g
s
.668 .705 .875 r
.44196 .61259 m .44756 .6201 L p .41398 .61983 L F P
0 g
s
.668 .705 .875 r
.41398 .61983 m .42949 .61414 L .44196 .61259 L p F P
0 g
s
.669 .718 .885 r
.41398 .61983 m .42949 .61414 L .4106 .61558 L closepath p F P
0 g
s
.548 .006 0 r
.29065 .97037 m .28314 .96936 L .28616 .96847 L closepath p F P
0 g
s
0 0 .433 r
.75344 .07836 m .75867 .08661 L .76407 .09655 L p F P
0 g
s
.802 .426 0 r
.76213 .09629 m .76753 .10623 L .76407 .09655 L p F P
0 g
s
.802 .426 0 r
.76407 .09655 m .75867 .08661 L .76213 .09629 L p F P
0 g
s
0 0 .543 r
.7472 .06812 m .7471 .068 L .75302 .07784 L p F P
0 g
s
0 0 .543 r
.75302 .07784 m .75344 .07836 L .7472 .06812 L p F P
0 g
s
.685 .184 .05 r
.23894 .95408 m .24471 .95921 L .23761 .9607 L p F P
0 g
s
.685 .184 .05 r
.22209 .95009 m .23894 .95408 L p .23761 .9607 L F P
0 g
s
.998 .83 .491 r
.48897 .32015 m .48891 .32023 L .48894 .32006 L closepath p F P
0 g
s
.803 .752 .805 r
.1766 .69301 m .16656 .70247 L .15821 .69365 L p F P
0 g
s
.803 .752 .805 r
.15821 .69365 m .16587 .6864 L .1766 .69301 L p F P
0 g
s
.79 .754 .819 r
.18468 .67022 m .16587 .6864 L .1766 .69301 L p F P
0 g
s
.79 .754 .819 r
.1766 .69301 m .19294 .67903 L .18468 .67022 L p F P
0 g
s
.86 .699 .681 r
.1063 .79879 m .1177 .80487 L .11066 .81956 L p F P
0 g
s
.851 .709 .705 r
.1177 .80487 m .1063 .79879 L .11491 .78367 L p F P
0 g
s
.981 .776 .555 r
.48165 .31782 m .48316 .31076 L .48894 .32006 L p F P
0 g
s
.981 .776 .555 r
.48894 .32006 m .48891 .32023 L .48165 .31782 L p F P
0 g
s
.98 .746 .512 r
.48731 .33202 m .48891 .32023 L .48165 .31782 L p F P
0 g
s
.804 .753 .805 r
.1572 .71136 m .16656 .70247 L .15821 .69365 L p F P
0 g
s
.815 .751 .792 r
.14659 .70475 m .1572 .71136 L .14061 .72884 L p F P
0 g
s
.804 .753 .805 r
.15821 .69365 m .14659 .70475 L .1572 .71136 L p F P
0 g
s
0 0 .399 r
.75867 .08661 m .75344 .07836 L .7472 .06812 L p F P
0 g
s
1 .808 .48 r
.77607 .15927 m .77594 .16006 L .77957 .17033 L p F P
0 g
s
.991 .842 .596 r
.77206 .17272 m .77572 .18297 L .77957 .17033 L p F P
0 g
s
.991 .842 .596 r
.77957 .17033 m .77594 .16006 L .77206 .17272 L p F P
0 g
s
.498 .405 .68 r
.70376 .79532 m .68781 .8044 L .70629 .8125 L p F P
0 g
s
.517 .436 .703 r
.70035 .78286 m .70376 .79532 L .68781 .8044 L p F P
0 g
s
.517 .436 .703 r
.69406 .7809 m .70035 .78286 L p .68781 .8044 L F P
0 g
s
.788 .753 .821 r
.19945 .67357 m .19294 .67903 L .18468 .67022 L p F P
0 g
s
.55 .534 .789 r
.64801 .71111 m .65975 .70298 L p .67709 .71997 L F P
0 g
s
.558 .556 .808 r
.64801 .71111 m .64446 .70319 L .65975 .70298 L closepath p F P
0 g
s
.788 .375 .266 r
.19809 .9349 m .20347 .9437 L .20093 .94482 L p F P
0 g
s
.788 .375 .266 r
.18295 .93036 m .19809 .9349 L p .20093 .94482 L F P
0 g
s
.745 .811 .904 r
.60366 .36983 m .57764 .38461 L .57079 .37754 L p F P
0 g
s
.712 .744 .876 r
.33908 .61386 m .31308 .62709 L .30525 .61792 L p F P
0 g
s
.778 .831 .893 r
.64168 .35598 m .63773 .35864 L .63115 .35194 L p F P
0 g
s
.772 .83 .897 r
.60437 .36941 m .63115 .35194 L .63773 .35864 L p F P
0 g
s
.446 .248 .516 r
.66759 .89166 m .66735 .87877 L .6911 .86794 L p F P
0 g
s
.479 .273 .522 r
.65853 .89522 m .66759 .89166 L .66735 .87877 L p F P
0 g
s
.474 .304 .57 r
.68989 .85418 m .6911 .86794 L .66735 .87877 L p F P
0 g
s
.788 .753 .821 r
.18468 .67022 m .18854 .66697 L .19945 .67357 L p F P
0 g
s
.775 .754 .834 r
.21095 .6497 m .18854 .66697 L .19945 .67357 L p F P
0 g
s
.775 .754 .834 r
.19945 .67357 m .21913 .65848 L .21095 .6497 L p F P
0 g
s
.656 .689 .869 r
.44756 .6201 m .47392 .61131 L .48117 .6218 L p F P
0 g
s
.656 .702 .881 r
.46975 .60572 m .47392 .61131 L .44756 .6201 L p F P
0 g
s
.656 .702 .881 r
.44756 .6201 m .44196 .61259 L .46975 .60572 L p F P
0 g
s
.846 .725 .731 r
.11491 .78367 m .12066 .77502 L .11233 .76467 L p F P
0 g
s
.445 .157 .381 r
.64218 .91325 m .64193 .91488 L .61516 .93038 L p F P
0 g
s
.421 .12 .347 r
.61466 .93267 m .61516 .93038 L .64193 .91488 L p F P
0 g
s
.797 .843 .886 r
.64168 .35598 m .66442 .33939 L .65796 .33278 L p F P
0 g
s
.797 .843 .886 r
.65796 .33278 m .64097 .34527 L .64168 .35598 L p F P
0 g
s
.778 .831 .893 r
.63115 .35194 m .64097 .34527 L .64168 .35598 L p F P
0 g
s
.954 .869 .715 r
.76283 .21029 m .76588 .22061 L .77324 .20662 L p F P
0 g
s
.954 .869 .715 r
.77324 .20662 m .77017 .19629 L .76283 .21029 L p F P
0 g
s
.013 .278 .777 r
.49606 .36809 m .49321 .36413 L .49524 .37453 L p F P
0 g
s
.013 .278 .777 r
.49524 .37453 m .50326 .38082 L .49606 .36809 L p F P
0 g
s
.829 .745 .771 r
.13983 .72976 m .14061 .72884 L .13687 .72653 L closepath p F P
0 g
s
.815 .751 .792 r
.13141 .7208 m .14659 .70475 L p .14061 .72884 L F P
0 g
s
.815 .751 .792 r
.14061 .72884 m .13687 .72653 L .13141 .7208 L p F P
0 g
s
.853 .585 .532 r
.14872 .89627 m .13542 .89106 L .13594 .87805 L p F P
0 g
s
.861 .592 .53 r
.12311 .87264 m .13594 .87805 L .13542 .89106 L p F P
0 g
s
.858 .621 .579 r
.13594 .87805 m .12311 .87264 L .12541 .85918 L p F P
0 g
s
.75 .746 .849 r
.24522 .64017 m .26193 .62927 L .27435 .63544 L p F P
0 g
s
.74 .748 .859 r
.27129 .62359 m .26193 .62927 L .27435 .63544 L p F P
0 g
s
.74 .748 .859 r
.27435 .63544 m .27926 .63247 L .27129 .62359 L p F P
0 g
s
.829 .745 .771 r
.12646 .74558 m .13983 .72976 L .13687 .72653 L p F P
0 g
s
.834 .524 .466 r
.16395 .91382 m .1623 .91326 L .16352 .91099 L closepath p F P
0 g
s
.866 .629 .579 r
.11305 .85356 m .12541 .85918 L .12311 .87264 L p F P
0 g
s
.86 .651 .618 r
.12541 .85918 m .11305 .85356 L .11702 .83968 L p F P
0 g
s
.189 0 0 r
.50909 .97111 m .5215 .97008 L p .48776 .97607 L F P
0 g
s
.283 0 0 r
.5215 .97008 m .50909 .97111 L .5228 .96911 L closepath p F P
0 g
s
.844 .54 .474 r
.1623 .91326 m .15015 .90882 L .14872 .89627 L p F P
0 g
s
.853 .546 .469 r
.13542 .89106 m .14872 .89627 L .15015 .90882 L p F P
0 g
s
.532 .651 .911 r
.50966 .39209 m .50943 .39066 L .51041 .39205 L closepath p F P
0 g
s
.884 .869 .818 r
.73778 .25936 m .74491 .25096 L .74715 .2614 L p F P
0 g
s
.884 .869 .818 r
.74715 .2614 m .74381 .26529 L .73778 .25936 L p F P
0 g
s
.717 .791 .91 r
.54486 .39206 m .54408 .39123 L .54484 .39086 L closepath p F P
0 g
s
.558 .557 .808 r
.65975 .70298 m .64446 .70319 L .63754 .68777 L p F P
0 g
s
.489 .373 .648 r
.68786 .83962 m .68749 .83766 L .68932 .83884 L closepath p F P
0 g
s
.771 .753 .837 r
.22704 .65261 m .21913 .65848 L .21095 .6497 L p F P
0 g
s
.728 .747 .867 r
.30525 .61792 m .27926 .63247 L .27129 .62359 L p F P
0 g
s
.366 0 .095 r
.58461 .94971 m .58196 .95394 L .5551 .95956 L p F P
0 g
s
.274 0 0 r
.5512 .96381 m .5551 .95956 L .58196 .95394 L p F P
0 g
s
.361 0 .007 r
.5551 .95956 m .5512 .96381 L .5228 .96911 L p F P
0 g
s
.652 .76 .929 r
.51041 .39205 m .53707 .38334 L .54408 .39123 L p F P
0 g
s
.651 .703 .885 r
.50943 .39066 m .51041 .39205 L .53707 .38334 L p F P
0 g
s
.641 .674 .866 r
.48117 .6218 m .5077 .6141 L .51485 .62503 L p F P
0 g
s
.642 .683 .873 r
.5077 .6141 m .48117 .6218 L .47392 .61131 L p F P
0 g
s
.868 .66 .619 r
.10512 .83385 m .11702 .83968 L .11305 .85356 L p F P
0 g
s
.861 .676 .651 r
.11702 .83968 m .10512 .83385 L .11066 .81956 L p F P
0 g
s
.858 .718 .707 r
.10395 .77736 m .11491 .78367 L .1063 .79879 L p F P
0 g
s
.846 .725 .731 r
.11233 .76467 m .10395 .77736 L .11491 .78367 L p F P
0 g
s
.145 0 0 r
.29065 .97037 m .3112 .97586 L .30693 .97506 L p F P
0 g
s
.145 0 0 r
.28314 .96936 m .29065 .97037 L p .30693 .97506 L F P
0 g
s
.887 .872 .817 r
.73301 .27787 m .74381 .26529 L .73778 .25936 L p F P
0 g
s
.667 .725 .893 r
.42949 .61414 m .4106 .61558 L .4065 .61061 L p F P
0 g
s
.675 .728 .889 r
.4106 .61558 m .4065 .61061 L .39482 .61509 L closepath p F P
0 g
s
.467 .329 .61 r
.68932 .83884 m .68786 .83962 L .68989 .85418 L p F P
0 g
s
.771 .753 .837 r
.21095 .6497 m .21585 .64604 L .22704 .65261 L p F P
0 g
s
.759 .755 .848 r
.23711 .63143 m .21585 .64604 L .22704 .65261 L p F P
0 g
s
.759 .755 .848 r
.22704 .65261 m .24522 .64017 L .23711 .63143 L p F P
0 g
s
.357 .002 .217 r
.61108 .94232 m .61466 .93267 L .64018 .92418 L p F P
0 g
s
.421 .12 .347 r
.64193 .91488 m .64018 .92418 L .61466 .93267 L p F P
0 g
s
.404 .043 .236 r
.61466 .93267 m .61108 .94232 L .58461 .94971 L p F P
0 g
s
.715 .78 .903 r
.54484 .39086 m .54408 .39123 L .53707 .38334 L p F P
0 g
s
.675 .729 .89 r
.39895 .60245 m .4065 .61061 L .39482 .61509 L p F P
0 g
s
.675 .729 .89 r
.37281 .61159 m .39895 .60245 L p .39482 .61509 L F P
0 g
s
.675 .729 .89 r
.39482 .61509 m .37521 .61444 L .37281 .61159 L p F P
0 g
s
.451 .211 .458 r
.64218 .91325 m .64535 .91203 L .65853 .89522 L p F P
0 g
s
.444 .203 .452 r
.66759 .89166 m .65853 .89522 L .64535 .91203 L p F P
0 g
s
.999 .799 .496 r
.77164 .14992 m .77365 .13799 L .77795 .14813 L p F P
0 g
s
.999 .799 .496 r
.77551 .15904 m .77164 .14992 L p .77795 .14813 L F P
0 g
s
.999 .799 .496 r
.77795 .14813 m .77607 .15927 L .77551 .15904 L p F P
0 g
s
.818 .463 .385 r
.18295 .93036 m .16818 .92568 L .16395 .91382 L p F P
0 g
s
.82 .451 .357 r
.1623 .91326 m .16395 .91382 L .16818 .92568 L p F P
0 g
s
.715 .78 .903 r
.53707 .38334 m .54274 .38063 L .54484 .39086 L p F P
0 g
s
.718 .784 .904 r
.54484 .39086 m .57079 .37754 L .56387 .37013 L p F P
0 g
s
.718 .784 .904 r
.56387 .37013 m .54274 .38063 L .54484 .39086 L p F P
0 g
s
.8 .84 .882 r
.6716 .33401 m .66442 .33939 L .65796 .33278 L p F P
0 g
s
.606 .632 .85 r
.55568 .64206 m .5826 .63716 L p .57976 .65115 L F P
0 g
s
.603 .635 .856 r
.5826 .63716 m .55568 .64206 L .54864 .62991 L p F P
0 g
s
.912 .606 .12 r
.48844 .35459 m .49321 .36413 L .49116 .35334 L p F P
0 g
s
.912 .606 .12 r
.49116 .35334 m .48684 .34364 L .48844 .35459 L p F P
0 g
s
.839 .743 .757 r
.11592 .73901 m .12646 .74558 L .11426 .76174 L p F P
0 g
s
.829 .745 .771 r
.13003 .72225 m .11592 .73901 L .12646 .74558 L p F P
0 g
s
.829 .745 .771 r
.13687 .72653 m .13003 .72225 L p .12646 .74558 L F P
0 g
s
.651 .703 .885 r
.52999 .37508 m .51695 .37854 L .50943 .39066 L p F P
0 g
s
.651 .703 .885 r
.53707 .38334 m .52999 .37508 L p .50943 .39066 L F P
0 g
s
.587 .647 .876 r
.50326 .38082 m .51695 .37854 L .50943 .39066 L closepath p F P
0 g
s
.582 .608 .843 r
.62372 .65957 m .59653 .66273 L .58958 .64957 L p F P
0 g
s
.467 .329 .61 r
.68989 .85418 m .69846 .84966 L .68932 .83884 L p F P
0 g
s
.463 .328 .612 r
.7106 .82727 m .68932 .83884 L .69846 .84966 L p F P
0 g
s
.491 .373 .647 r
.70799 .81372 m .7106 .82727 L .68932 .83884 L p F P
0 g
s
.491 .373 .647 r
.70629 .8125 m .70799 .81372 L p .68932 .83884 L F P
0 g
s
.69 .734 .884 r
.37521 .61444 m .37281 .61159 L .36889 .61328 L closepath p F P
0 g
s
.818 .751 .789 r
.13687 .72653 m .13141 .7208 L .13003 .72225 L closepath p F P
0 g
s
.145 0 0 r
.27774 .97002 m .28314 .96936 L p .30693 .97506 L F P
0 g
s
.521 0 0 r
.27774 .97002 m .27112 .96715 L .28314 .96936 L closepath p F P
0 g
s
.62 .646 .854 r
.54864 .62991 m .53498 .63304 L .5469 .62696 L closepath p F P
0 g
s
.626 .662 .865 r
.54157 .6185 m .5469 .62696 L .53498 .63304 L p F P
0 g
s
.626 .662 .865 r
.51485 .62503 m .54157 .6185 L p .53498 .63304 L F P
0 g
s
.82 .451 .357 r
.15368 .92068 m .1623 .91326 L p .16818 .92568 L F P
0 g
s
.837 .488 .393 r
.15368 .92068 m .15015 .90882 L .1623 .91326 L closepath p F P
0 g
s
.411 .135 .381 r
.64193 .91488 m .64535 .91203 L .64218 .91325 L closepath p F P
0 g
s
.158 0 0 r
.34659 .97915 m .34165 .97867 L .31938 .97575 L p F P
0 g
s
.191 0 0 r
.34165 .97867 m .31938 .97575 L .3112 .97586 L p F P
0 g
s
.82 .851 .871 r
.6716 .33401 m .69107 .31804 L .68474 .3115 L p F P
0 g
s
.82 .851 .871 r
.68474 .3115 m .67032 .32343 L .6716 .33401 L p F P
0 g
s
.8 .84 .882 r
.65796 .33278 m .67032 .32343 L .6716 .33401 L p F P
0 g
s
.887 .872 .817 r
.73778 .25936 m .73094 .26741 L .73301 .27787 L p F P
0 g
s
.864 .866 .839 r
.71432 .28482 m .73094 .26741 L .73301 .27787 L p F P
0 g
s
.864 .866 .839 r
.71566 .292 m .71432 .28482 L p .73301 .27787 L F P
0 g
s
.864 .866 .839 r
.73301 .27787 m .7176 .29388 L .71566 .292 L p F P
0 g
s
.665 .715 .885 r
.44196 .61259 m .4402 .61032 L .42949 .61414 L closepath p F P
0 g
s
.667 .725 .893 r
.43278 .6018 m .4402 .61032 L .42949 .61414 L p F P
0 g
s
.667 .725 .893 r
.4065 .61061 m .43278 .6018 L p .42949 .61414 L F P
0 g
s
.223 0 0 r
.5215 .97008 m .5228 .96911 L .5512 .96381 L p F P
0 g
s
.868 .686 .653 r
.09923 .8135 m .11066 .81956 L .10512 .83385 L p F P
0 g
s
.86 .699 .681 r
.11066 .81956 m .09923 .8135 L .1063 .79879 L p F P
0 g
s
.599 .615 .839 r
.58958 .64957 m .57976 .65115 L .58783 .64631 L closepath p F P
0 g
s
.606 .632 .85 r
.5826 .63716 m .58783 .64631 L .57976 .65115 L p F P
0 g
s
.745 .307 .212 r
.22209 .95009 m .20547 .946 L .20347 .9437 L p F P
0 g
s
.685 .184 .05 r
.23761 .9607 m .23455 .95996 L .22209 .95009 L p F P
0 g
s
.668 .148 0 r
.20547 .946 m .22209 .95009 L .23455 .95996 L p F P
0 g
s
.687 .743 .893 r
.33908 .61386 m .35116 .60882 L .36889 .61328 L p F P
0 g
s
.693 .75 .896 r
.36514 .60318 m .35116 .60882 L .36889 .61328 L p F P
0 g
s
.693 .75 .896 r
.36889 .61328 m .37281 .61159 L .36514 .60318 L p F P
0 g
s
.6 .063 0 r
.27112 .96715 m .25269 .96362 L .24471 .95921 L p F P
0 g
s
.599 .062 0 r
.25269 .96362 m .23761 .9607 L .24471 .95921 L closepath p F P
0 g
s
.82 .847 .868 r
.696 .31393 m .69107 .31804 L .68474 .3115 L p F P
0 g
s
.309 0 .058 r
.58196 .95394 m .58461 .94971 L .61108 .94232 L p F P
0 g
s
.862 .866 .841 r
.7176 .29388 m .71622 .2953 L .71566 .292 L closepath p F P
0 g
s
.927 .868 .76 r
.75764 .21847 m .76283 .21029 L .76588 .22061 L p F P
0 g
s
.927 .868 .76 r
.76588 .22061 m .76356 .22423 L .75764 .21847 L p F P
0 g
s
.837 .853 .857 r
.69432 .30343 m .696 .31393 L .71622 .2953 L p F P
0 g
s
.837 .853 .857 r
.7114 .28755 m .69432 .30343 L p .71622 .2953 L F P
0 g
s
.837 .853 .857 r
.71622 .2953 m .71566 .292 L .7114 .28755 L p F P
0 g
s
.571 .565 .808 r
.63754 .68777 m .63622 .68785 L .63727 .68718 L closepath p F P
0 g
s
.581 .584 .82 r
.63064 .6736 m .63727 .68718 L .63622 .68785 L p F P
0 g
s
.82 .847 .868 r
.68474 .3115 m .69432 .30343 L .696 .31393 L p F P
0 g
s
.626 .668 .87 r
.54157 .6185 m .51485 .62503 L .5077 .6141 L p F P
0 g
s
.38 .093 .346 r
.64018 .92418 m .64193 .91488 L .64535 .91203 L p F P
0 g
s
.971 .852 .666 r
.7665 .18606 m .77017 .19629 L .77572 .18297 L p F P
0 g
s
.971 .852 .666 r
.77572 .18297 m .77206 .17272 L .7665 .18606 L p F P
0 g
s
.752 .754 .853 r
.26193 .62927 m .24522 .64017 L .23711 .63143 L p F P
0 g
s
.758 .823 .903 r
.60437 .36941 m .60366 .36983 L .60368 .36871 L closepath p F P
0 g
s
.745 .811 .904 r
.59761 .36229 m .60368 .36871 L .60366 .36983 L p F P
0 g
s
.745 .811 .904 r
.57079 .37754 m .59761 .36229 L p .60366 .36983 L F P
0 g
s
.989 .731 .37 r
.76879 .12796 m .77365 .13799 L .77391 .12677 L p F P
0 g
s
.989 .731 .37 r
.77391 .12677 m .76906 .11672 L .76879 .12796 L p F P
0 g
s
.38 .093 .346 r
.64535 .91203 m .66683 .90364 L p .64018 .92418 L F P
0 g
s
.444 .203 .452 r
.64535 .91203 m .66683 .90364 L .66759 .89166 L p F P
0 g
s
.776 .826 .892 r
.6245 .3449 m .63115 .35194 L .60437 .36941 L p F P
0 g
s
.776 .826 .892 r
.60269 .3592 m .6245 .3449 L p .60437 .36941 L F P
0 g
s
.776 .826 .892 r
.60437 .36941 m .60368 .36871 L .60269 .3592 L p F P
0 g
s
.508 .432 .706 r
.70035 .78286 m .69406 .7809 L .69903 .77796 L closepath p F P
0 g
s
.526 .461 .726 r
.69333 .75956 m .69903 .77796 L .69406 .7809 L p F P
0 g
s
.655 .711 .889 r
.46662 .6017 m .46975 .60572 L .44196 .61259 L p F P
0 g
s
.655 .711 .889 r
.44196 .61259 m .4402 .61032 L .46662 .6017 L p F P
0 g
s
.98 .746 .512 r
.48165 .31782 m .48095 .32294 L .48731 .33202 L p F P
0 g
s
.983 .717 .437 r
.48043 .33458 m .48684 .34364 L .48731 .33202 L p F P
0 g
s
.983 .717 .437 r
.48731 .33202 m .48095 .32294 L .48043 .33458 L p F P
0 g
s
.558 .557 .808 r
.63754 .68777 m .66511 .68768 L p .65975 .70298 L F P
0 g
s
.549 .553 .811 r
.65819 .67255 m .66511 .68768 L .63754 .68777 L p F P
0 g
s
.549 .553 .811 r
.65639 .67254 m .65819 .67255 L p .63754 .68777 L F P
0 g
s
.549 .553 .811 r
.63754 .68777 m .63727 .68718 L .65639 .67254 L p F P
0 g
s
.788 .375 .266 r
.20093 .94482 m .19008 .94153 L .18295 .93036 L p F P
0 g
s
.791 .368 .245 r
.16818 .92568 m .18295 .93036 L .19008 .94153 L p F P
0 g
s
.93 .87 .756 r
.75642 .2354 m .76356 .22423 L .75764 .21847 L p F P
0 g
s
.562 .578 .827 r
.63727 .68718 m .63064 .6736 L .65639 .67254 L closepath p F P
0 g
s
.629 .781 .954 r
.39895 .60245 m .37281 .61159 L .36514 .60318 L p F P
0 g
s
.852 .734 .732 r
.11233 .76467 m .11426 .76174 L .10458 .75576 L closepath p F P
0 g
s
.839 .743 .757 r
.10387 .75499 m .11592 .73901 L p .11426 .76174 L F P
0 g
s
.839 .743 .757 r
.11426 .76174 m .10458 .75576 L .10387 .75499 L p F P
0 g
s
.686 .734 .887 r
.33908 .61386 m .35116 .60882 L .33217 .60585 L closepath p F P
0 g
s
.712 .744 .876 r
.33217 .60585 m .33908 .61386 L p .30525 .61792 L F P
0 g
s
.758 .814 .897 r
.60368 .36871 m .59761 .36229 L .60269 .3592 L closepath p F P
0 g
s
.632 .777 .95 r
.43278 .6018 m .4065 .61061 L .39895 .60245 L p F P
0 g
s
.867 .708 .683 r
.09532 .79251 m .1063 .79879 L .09923 .8135 L p F P
0 g
s
.858 .718 .707 r
.1063 .79879 m .09532 .79251 L .10395 .77736 L p F P
0 g
s
.42 0 0 r
.27112 .96715 m .27774 .97002 L .26934 .96944 L p F P
0 g
s
.42 0 0 r
.26934 .96944 m .25269 .96362 L .27112 .96715 L p F P
0 g
s
.223 0 0 r
.5512 .96381 m .54828 .96582 L .5215 .97008 L p F P
0 g
s
0 0 0 r
.54828 .96582 m .5215 .97008 L .51441 .97272 L p F P
0 g
s
.189 0 0 r
.5215 .97008 m .51441 .97272 L .48776 .97607 L p F P
0 g
s
.005 .58 .744 r
.3832 .98091 m .36781 .98014 L .35286 .97958 L p F P
0 g
s
0 .574 .735 r
.36781 .98014 m .34659 .97915 L .35286 .97958 L closepath p F P
0 g
s
.808 .76 .809 r
.16587 .6864 m .15821 .69365 L .14978 .68519 L p F P
0 g
s
.808 .76 .809 r
.14978 .68519 m .15574 .67952 L .16587 .6864 L p F P
0 g
s
.795 .762 .823 r
.17633 .66174 m .15574 .67952 L .16587 .6864 L p F P
0 g
s
.795 .762 .823 r
.16587 .6864 m .18468 .67022 L .17633 .66174 L p F P
0 g
s
.852 .734 .733 r
.10395 .77736 m .11233 .76467 L .10458 .75576 L p F P
0 g
s
.809 .761 .808 r
.14659 .70475 m .15821 .69365 L .14978 .68519 L p F P
0 g
s
.945 .622 .19 r
.76366 .10679 m .76906 .11672 L .76753 .10623 L p F P
0 g
s
.945 .622 .19 r
.76753 .10623 m .76213 .09629 L .76366 .10679 L p F P
0 g
s
.822 .758 .792 r
.14659 .70475 m .13141 .7208 L .12288 .71236 L p F P
0 g
s
.822 .758 .792 r
.12288 .71236 m .13651 .6979 L .14659 .70475 L p F P
0 g
s
.809 .761 .808 r
.14978 .68519 m .13651 .6979 L .14659 .70475 L p F P
0 g
s
.651 .743 .917 r
.46662 .6017 m .4402 .61032 L .43278 .6018 L p F P
0 g
s
.792 .761 .825 r
.18854 .66697 m .18468 .67022 L .17633 .66174 L p F P
0 g
s
.407 .173 .444 r
.66683 .90364 m .66759 .89166 L .69141 .88086 L p F P
0 g
s
.446 .248 .516 r
.6911 .86794 m .69141 .88086 L .66759 .89166 L p F P
0 g
s
.712 .744 .876 r
.30525 .61792 m .33056 .60523 L .33217 .60585 L p F P
0 g
s
.709 .753 .887 r
.33056 .60523 m .30525 .61792 L .29735 .60899 L p F P
0 g
s
.728 .747 .867 r
.27129 .62359 m .29735 .60899 L .30525 .61792 L p F P
0 g
s
.442 .281 .566 r
.69846 .84966 m .68989 .85418 L .6911 .86794 L p F P
0 g
s
.748 .305 .198 r
.20547 .946 m .20093 .94482 L .20347 .9437 L closepath p F P
0 g
s
.792 .761 .825 r
.17633 .66174 m .1783 .66008 L .18854 .66697 L p F P
0 g
s
.779 .762 .838 r
.20268 .64121 m .1783 .66008 L .18854 .66697 L p F P
0 g
s
.779 .762 .838 r
.18854 .66697 m .21095 .6497 L .20268 .64121 L p F P
0 g
s
0 0 .399 r
.7472 .06812 m .75272 .07678 L .75867 .08661 L p F P
0 g
s
.832 .444 0 r
.75618 .08647 m .76213 .09629 L .75867 .08661 L p F P
0 g
s
.832 .444 0 r
.75867 .08661 m .75272 .07678 L .75618 .08647 L p F P
0 g
s
.861 .592 .53 r
.13542 .89106 m .12254 .88568 L .12311 .87264 L p F P
0 g
s
.869 .6 .529 r
.11069 .86705 m .12311 .87264 L .12254 .88568 L p F P
0 g
s
.866 .629 .579 r
.12311 .87264 m .11069 .86705 L .11305 .85356 L p F P
0 g
s
.752 .754 .853 r
.23711 .63143 m .2504 .62274 L .26193 .62927 L p F P
0 g
s
.742 .755 .863 r
.26324 .61493 m .2504 .62274 L .26193 .62927 L p F P
0 g
s
.742 .755 .863 r
.26193 .62927 m .27129 .62359 L .26324 .61493 L p F P
0 g
s
.842 .853 .852 r
.71566 .292 m .7114 .28755 L .71432 .28482 L closepath p F P
0 g
s
.853 .546 .469 r
.15015 .90882 m .13683 .90362 L .13542 .89106 L p F P
0 g
s
.861 .553 .465 r
.12254 .88568 m .13542 .89106 L .13683 .90362 L p F P
0 g
s
.874 .638 .579 r
.1011 .84776 m .11305 .85356 L .11069 .86705 L p F P
0 g
s
.868 .66 .619 r
.11305 .85356 m .1011 .84776 L .10512 .83385 L p F P
0 g
s
.582 .608 .843 r
.58958 .64957 m .61679 .64655 L .62372 .65957 L p F P
0 g
s
.579 .605 .843 r
.60984 .6336 m .61679 .64655 L .58958 .64957 L p F P
0 g
s
.579 .605 .843 r
.60372 .63426 m .60984 .6336 L p .58958 .64957 L F P
0 g
s
.579 .605 .843 r
.58958 .64957 m .58783 .64631 L .60372 .63426 L p F P
0 g
s
.822 .759 .793 r
.13003 .72225 m .13141 .7208 L .12288 .71236 L p F P
0 g
s
.096 .65 .796 r
.41771 .98097 m .39637 .98098 L .3865 .98123 L p F P
0 g
s
.112 .661 .813 r
.39637 .98098 m .3832 .98091 L .3865 .98123 L closepath p F P
0 g
s
.836 .755 .774 r
.11997 .71544 m .13003 .72225 L .11592 .73901 L p F P
0 g
s
.822 .759 .793 r
.12288 .71236 m .11997 .71544 L .13003 .72225 L p F P
0 g
s
.999 .799 .497 r
.77607 .15927 m .77594 .16006 L .77551 .15904 L closepath p F P
0 g
s
.93 .87 .756 r
.75764 .21847 m .75347 .22508 L .75642 .2354 L p F P
0 g
s
.906 .863 .787 r
.74199 .24065 m .74491 .25096 L .75642 .2354 L p F P
0 g
s
.906 .863 .787 r
.75642 .2354 m .75347 .22508 L .74199 .24065 L p F P
0 g
s
.499 .449 .732 r
.6941 .75903 m .69333 .75956 L .69903 .77796 L p F P
0 g
s
.515 .481 .756 r
.69333 .75956 m .69308 .75884 L .6941 .75903 L closepath p F P
0 g
s
.09 .646 .704 r
.48174 .97681 m .48776 .97607 L .51441 .97272 L p F P
0 g
s
.516 .48 .755 r
.6941 .75903 m .69308 .75884 L .68656 .73997 L p F P
0 g
s
.494 .629 .911 r
.51695 .37854 m .50326 .38082 L .49606 .36809 L p F P
0 g
s
.603 .635 .856 r
.54864 .62991 m .5756 .62508 L .5826 .63716 L p F P
0 g
s
.603 .637 .858 r
.56857 .61309 m .5756 .62508 L .54864 .62991 L p F P
0 g
s
.603 .637 .858 r
.56704 .61337 m .56857 .61309 L p .54864 .62991 L F P
0 g
s
.603 .637 .858 r
.54864 .62991 m .5469 .62696 L .56704 .61337 L p F P
0 g
s
.984 .83 .612 r
.76782 .16259 m .77206 .17272 L .77594 .16006 L p F P
0 g
s
.984 .83 .612 r
.7703 .15436 m .76782 .16259 L p .77594 .16006 L F P
0 g
s
.984 .83 .612 r
.77594 .16006 m .77551 .15904 L .7703 .15436 L p F P
0 g
s
.642 .683 .873 r
.47392 .61131 m .5005 .60349 L .5077 .6141 L p F P
0 g
s
.645 .702 .888 r
.49499 .59588 m .5005 .60349 L .47392 .61131 L p F P
0 g
s
.645 .702 .888 r
.47392 .61131 m .46975 .60572 L .49499 .59588 L p F P
0 g
s
.489 .42 .706 r
.69903 .77796 m .71692 .76572 L p .71428 .78843 L F P
0 g
s
.489 .42 .706 r
.71428 .78843 m .70035 .78286 L .69903 .77796 L p F P
0 g
s
.499 .449 .732 r
.69903 .77796 m .71692 .76572 L .6941 .75903 L p F P
0 g
s
.55 .534 .789 r
.65975 .70298 m .67203 .70345 L p .67709 .71997 L F P
0 g
s
.544 .536 .796 r
.67203 .70345 m .65975 .70298 L .66903 .69629 L closepath p F P
0 g
s
.558 .557 .808 r
.66511 .68768 m .66903 .69629 L .65975 .70298 L p F P
0 g
s
.743 .803 .9 r
.59761 .36229 m .57079 .37754 L .56387 .37013 L p F P
0 g
s
.496 .452 .738 r
.71431 .74452 m .6941 .75903 L .71692 .76572 L p F P
0 g
s
.516 .48 .755 r
.71422 .74425 m .71431 .74452 L .6941 .75903 L p F P
0 g
s
.516 .48 .755 r
.6882 .73877 m .71422 .74425 L p .6941 .75903 L F P
0 g
s
.516 .48 .755 r
.68656 .73997 m .6882 .73877 L p .6941 .75903 L F P
0 g
s
.846 .491 .382 r
.15015 .90882 m .15368 .92068 L .15354 .92077 L p F P
0 g
s
.846 .491 .382 r
.13683 .90362 m .15015 .90882 L p .15354 .92077 L F P
0 g
s
.116 .667 .784 r
.4504 .9795 m .42991 .98052 L .42022 .98118 L p F P
0 g
s
.161 .698 .832 r
.42991 .98052 m .41771 .98097 L .42022 .98118 L closepath p F P
0 g
s
.875 .671 .623 r
.09365 .82783 m .10512 .83385 L .1011 .84776 L p F P
0 g
s
.868 .686 .653 r
.10512 .83385 m .09365 .82783 L .09923 .8135 L p F P
0 g
s
.774 .762 .842 r
.21585 .64604 m .21095 .6497 L .20268 .64121 L p F P
0 g
s
.778 .823 .888 r
.64097 .34527 m .63115 .35194 L .6245 .3449 L p F P
0 g
s
.73 .754 .872 r
.29735 .60899 m .27129 .62359 L .26324 .61493 L p F P
0 g
s
.075 .636 .71 r
.48174 .97681 m .47282 .97768 L .45399 .97954 L p F P
0 g
s
.153 .695 .799 r
.47282 .97768 m .4504 .9795 L .45399 .97954 L closepath p F P
0 g
s
.488 .421 .707 r
.70376 .79532 m .70035 .78286 L .71428 .78843 L closepath p F P
0 g
s
.589 .625 .856 r
.58783 .64631 m .5826 .63716 L .60372 .63426 L closepath p F P
0 g
s
.524 .505 .777 r
.68656 .73997 m .68599 .73849 L .6882 .73877 L closepath p F P
0 g
s
.68 .739 .895 r
.35738 .59546 m .36514 .60318 L .35116 .60882 L p F P
0 g
s
.68 .739 .895 r
.3313 .60488 m .35738 .59546 L p .35116 .60882 L F P
0 g
s
.68 .739 .895 r
.35116 .60882 m .33217 .60585 L .3313 .60488 L p F P
0 g
s
.668 .148 0 r
.23455 .95996 m .21844 .95572 L .20547 .946 L p F P
0 g
s
.623 .075 0 r
.20093 .94482 m .20547 .946 L .21844 .95572 L p F P
0 g
s
.864 .727 .709 r
.09342 .77085 m .10395 .77736 L .09532 .79251 L p F P
0 g
s
.852 .734 .733 r
.1037 .75521 m .09342 .77085 L .10395 .77736 L p F P
0 g
s
.852 .734 .733 r
.10458 .75576 m .1037 .75521 L p .10395 .77736 L F P
0 g
s
.985 .826 .603 r
.77551 .15904 m .7703 .15436 L .77164 .14992 L closepath p F P
0 g
s
.525 .505 .776 r
.6882 .73877 m .68599 .73849 L .67898 .72014 L p F P
0 g
s
.774 .762 .842 r
.20268 .64121 m .20543 .63916 L .21585 .64604 L p F P
0 g
s
.762 .762 .853 r
.22892 .62296 m .20543 .63916 L .21585 .64604 L p F P
0 g
s
.762 .762 .853 r
.21585 .64604 m .23711 .63143 L .22892 .62296 L p F P
0 g
s
.948 .855 .715 r
.75917 .2001 m .76283 .21029 L .77017 .19629 L p F P
0 g
s
.948 .855 .715 r
.77017 .19629 m .7665 .18606 L .75917 .2001 L p F P
0 g
s
.562 .579 .828 r
.65639 .67254 m .63064 .6736 L .62432 .66072 L p F P
0 g
s
.61 .655 .869 r
.5469 .62696 m .54157 .6185 L .56704 .61337 L closepath p F P
0 g
s
.47 .386 .679 r
.70762 .81175 m .70376 .79532 L .71428 .78843 L p F P
0 g
s
.498 .405 .68 r
.70629 .8125 m .70762 .81175 L .70376 .79532 L p F P
0 g
s
0 0 .519 r
.48882 .35534 m .48844 .35459 L .49321 .36413 L p F P
0 g
s
0 0 .519 r
.49321 .36413 m .49606 .36809 L .48882 .35534 L p F P
0 g
s
.847 .75 .756 r
.11592 .73901 m .10387 .75499 L .09525 .74633 L p F P
0 g
s
.847 .75 .756 r
.09525 .74633 m .10585 .73223 L .11592 .73901 L p F P
0 g
s
.836 .755 .774 r
.11592 .73901 m .10585 .73223 L .11997 .71544 L p F P
0 g
s
.795 .833 .88 r
.64097 .34527 m .65796 .33278 L .65143 .32581 L p F P
0 g
s
.795 .833 .88 r
.65143 .32581 m .63929 .3348 L .64097 .34527 L p F P
0 g
s
.778 .823 .888 r
.6245 .3449 m .63929 .3348 L .64097 .34527 L p F P
0 g
s
.125 0 0 r
.54828 .96582 m .5512 .96381 L .57869 .95747 L p F P
0 g
s
.274 0 0 r
.58196 .95394 m .57869 .95747 L .5512 .96381 L p F P
0 g
s
.507 .48 .761 r
.71422 .74425 m .6882 .73877 L .70718 .7244 L closepath p F P
0 g
s
.525 .505 .776 r
.7071 .72421 m .70718 .7244 L .6882 .73877 L p F P
0 g
s
.525 .505 .776 r
.67898 .72014 m .7071 .72421 L p .6882 .73877 L F P
0 g
s
.536 .511 .775 r
.67898 .72014 m .67709 .71997 L .67854 .71899 L closepath p F P
0 g
s
.55 .534 .789 r
.67203 .70345 m .67854 .71899 L .67709 .71997 L p F P
0 g
s
.242 0 0 r
.25269 .96362 m .26934 .96944 L .26327 .968 L p F P
0 g
s
.242 0 0 r
.23761 .9607 m .25269 .96362 L p .26327 .968 L F P
0 g
s
.623 .075 0 r
.19447 .94612 m .20093 .94482 L p .21844 .95572 L F P
0 g
s
.74 .263 .113 r
.19447 .94612 m .19008 .94153 L .20093 .94482 L closepath p F P
0 g
s
.145 0 0 r
.30693 .97506 m .29753 .97352 L .27774 .97002 L p F P
0 g
s
.199 0 0 r
.29753 .97352 m .27774 .97002 L .26934 .96944 L p F P
0 g
s
.876 .695 .655 r
.08823 .80726 m .09923 .8135 L .09365 .82783 L p F P
0 g
s
.867 .708 .683 r
.09923 .8135 m .08823 .80726 L .09532 .79251 L p F P
0 g
s
.882 .858 .813 r
.73166 .25294 m .74199 .24065 L .74491 .25096 L p F P
0 g
s
.882 .858 .813 r
.74491 .25096 m .73778 .25936 L .73166 .25294 L p F P
0 g
s
.71 .771 .9 r
.54274 .38063 m .53707 .38334 L .52999 .37508 L p F P
0 g
s
.626 .668 .87 r
.5077 .6141 m .53447 .60748 L .54157 .6185 L p F P
0 g
s
.627 .675 .876 r
.53447 .60748 m .5077 .6141 L .5005 .60349 L p F P
0 g
s
.309 0 .058 r
.61108 .94232 m .609 .94581 L .58196 .95394 L p F P
0 g
s
.194 0 0 r
.57869 .95747 m .58196 .95394 L .609 .94581 L p F P
0 g
s
.791 .368 .245 r
.19008 .94153 m .17542 .93681 L .16818 .92568 L p F P
0 g
s
.793 .362 .224 r
.15375 .92085 m .16818 .92568 L .17542 .93681 L p F P
0 g
s
.82 .451 .357 r
.16818 .92568 m .15375 .92085 L .15368 .92068 L p F P
0 g
s
.995 .786 .51 r
.76678 .13991 m .77164 .14992 L .77365 .13799 L p F P
0 g
s
.995 .786 .51 r
.77365 .13799 m .76879 .12796 L .76678 .13991 L p F P
0 g
s
.512 .497 .777 r
.70009 .70631 m .7071 .72421 L .67898 .72014 L p F P
0 g
s
.512 .497 .777 r
.69535 .70554 m .70009 .70631 L p .67898 .72014 L F P
0 g
s
.512 .497 .777 r
.67898 .72014 m .67854 .71899 L .69535 .70554 L p F P
0 g
s
.528 .526 .797 r
.67854 .71899 m .67203 .70345 L .69535 .70554 L closepath p F P
0 g
s
.963 .634 .27 r
.48509 .34999 m .48844 .35459 L .48684 .34364 L p F P
0 g
s
.963 .634 .27 r
.48154 .34328 m .48509 .34999 L p .48684 .34364 L F P
0 g
s
.963 .634 .27 r
.48684 .34364 m .48043 .33458 L .48154 .34328 L p F P
0 g
s
.884 .86 .812 r
.73094 .26741 m .73778 .25936 L .73166 .25294 L p F P
0 g
s
.478 .365 .646 r
.70799 .81372 m .70629 .8125 L .70762 .81175 L closepath p F P
0 g
s
.799 .831 .876 r
.67032 .32343 m .65796 .33278 L .65143 .32581 L p F P
0 g
s
.755 .761 .858 r
.2504 .62274 m .23711 .63143 L .22892 .62296 L p F P
0 g
s
.706 .746 .883 r
.33217 .60585 m .3313 .60488 L .33056 .60523 L closepath p F P
0 g
s
.71 .771 .9 r
.52999 .37508 m .53942 .37072 L .54274 .38063 L p F P
0 g
s
.71 .774 .903 r
.54274 .38063 m .56387 .37013 L .55689 .36237 L p F P
0 g
s
.71 .774 .903 r
.55689 .36237 m .53942 .37072 L .54274 .38063 L p F P
0 g
s
.442 .281 .566 r
.6911 .86794 m .70261 .86191 L .69846 .84966 L p F P
0 g
s
.437 .278 .566 r
.71274 .84195 m .69846 .84966 L .70261 .86191 L p F P
0 g
s
.463 .328 .612 r
.69846 .84966 m .71274 .84195 L .7106 .82727 L p F P
0 g
s
.647 .712 .895 r
.49326 .59358 m .49499 .59588 L .46975 .60572 L p F P
0 g
s
.647 .712 .895 r
.46975 .60572 m .46662 .6017 L .49326 .59358 L p F P
0 g
s
.216 .726 .889 r
.41259 .98005 m .39637 .98098 L .41771 .98097 L closepath p F P
0 g
s
.223 .729 .896 r
.39637 .98098 m .41259 .98005 L p .3787 .98006 L F P
0 g
s
.223 .729 .896 r
.3787 .98006 m .3832 .98091 L .39637 .98098 L p F P
0 g
s
.267 .758 .909 r
.41259 .98005 m .41771 .98097 L .42991 .98052 L p F P
0 g
s
.841 .743 .755 r
.10458 .75576 m .10387 .75499 L .1037 .75521 L closepath p F P
0 g
s
.153 .682 .865 r
.3787 .98006 m .36781 .98014 L .3832 .98091 L closepath p F P
0 g
s
.457 .351 .645 r
.70762 .81175 m .72931 .7977 L p .71824 .82251 L F P
0 g
s
.457 .351 .645 r
.71824 .82251 m .70799 .81372 L .70762 .81175 L p F P
0 g
s
.47 .386 .679 r
.72916 .7971 m .72931 .7977 L .70762 .81175 L p F P
0 g
s
.47 .386 .679 r
.71428 .78843 m .72916 .7971 L p .70762 .81175 L F P
0 g
s
.884 .86 .812 r
.73166 .25294 m .72816 .25709 L .73094 .26741 L p F P
0 g
s
.861 .85 .831 r
.71163 .27452 m .71432 .28482 L .73094 .26741 L p F P
0 g
s
.861 .85 .831 r
.73094 .26741 m .72816 .25709 L .71163 .27452 L p F P
0 g
s
.709 .753 .887 r
.29735 .60899 m .3179 .59904 L .33056 .60523 L p F P
0 g
s
.708 .756 .89 r
.32345 .59647 m .3179 .59904 L .33056 .60523 L p F P
0 g
s
.708 .756 .89 r
.33056 .60523 m .3313 .60488 L .32345 .59647 L p F P
0 g
s
.41 .22 .51 r
.70261 .86191 m .6911 .86794 L .69141 .88086 L p F P
0 g
s
.224 .737 .874 r
.44652 .97901 m .42991 .98052 L .4504 .9795 L closepath p F P
0 g
s
.267 .758 .909 r
.42991 .98052 m .44652 .97901 L p .41259 .98005 L F P
0 g
s
.846 .751 .758 r
.1037 .75521 m .10387 .75499 L .09525 .74633 L p F P
0 g
s
.301 0 .182 r
.66494 .91459 m .64018 .92418 L .63676 .93386 L p F P
0 g
s
.38 .093 .346 r
.66683 .90364 m .66494 .91459 L .64018 .92418 L p F P
0 g
s
.357 .002 .217 r
.64018 .92418 m .63676 .93386 L .61108 .94232 L p F P
0 g
s
.638 .78 .949 r
.35738 .59546 m .3313 .60488 L .32345 .59647 L p F P
0 g
s
.86 .744 .735 r
.09363 .74847 m .1037 .75521 L .09342 .77085 L p F P
0 g
s
.846 .751 .758 r
.09525 .74633 m .09363 .74847 L .1037 .75521 L p F P
0 g
s
.818 .84 .866 r
.67032 .32343 m .68474 .3115 L .67833 .30458 L p F P
0 g
s
.818 .84 .866 r
.67833 .30458 m .66817 .31305 L .67032 .32343 L p F P
0 g
s
.799 .831 .876 r
.65143 .32581 m .66817 .31305 L .67032 .32343 L p F P
0 g
s
.629 .781 .954 r
.36514 .60318 m .39129 .59573 L .39895 .60245 L p F P
0 g
s
.532 .803 .996 r
.36514 .60318 m .39129 .59573 L .39072 .59539 L p F P
0 g
s
.532 .803 .996 r
.35738 .59546 m .36514 .60318 L p .39072 .59539 L F P
0 g
s
.589 .629 .859 r
.60372 .63426 m .5826 .63716 L .5756 .62508 L p F P
0 g
s
.99 .725 .391 r
.76337 .11804 m .76879 .12796 L .76906 .11672 L p F P
0 g
s
.99 .725 .391 r
.76906 .11672 m .76366 .10679 L .76337 .11804 L p F P
0 g
s
.455 .351 .647 r
.7106 .82727 m .70799 .81372 L .71824 .82251 L closepath p F P
0 g
s
.874 .717 .685 r
.08478 .78604 m .09532 .79251 L .08823 .80726 L p F P
0 g
s
.864 .727 .709 r
.09532 .79251 m .08478 .78604 L .09342 .77085 L p F P
0 g
s
.126 .666 .843 r
.36781 .98014 m .3787 .98006 L p .34488 .97888 L F P
0 g
s
.126 .666 .843 r
.34488 .97888 m .34659 .97915 L .36781 .98014 L p F P
0 g
s
.924 .855 .756 r
.75162 .2121 m .75917 .2001 L .76283 .21029 L p F P
0 g
s
.924 .855 .756 r
.76283 .21029 m .75764 .21847 L .75162 .2121 L p F P
0 g
s
.965 .838 .668 r
.76223 .17596 m .7665 .18606 L .77206 .17272 L p F P
0 g
s
.965 .838 .668 r
.77206 .17272 m .76782 .16259 L .76223 .17596 L p F P
0 g
s
.812 .769 .813 r
.15574 .67952 m .14978 .68519 L .14124 .6771 L p F P
0 g
s
.812 .769 .813 r
.14124 .6771 m .14619 .67239 L .15574 .67952 L p F P
0 g
s
.799 .77 .827 r
.16789 .65361 m .14619 .67239 L .15574 .67952 L p F P
0 g
s
.799 .77 .827 r
.15574 .67952 m .17633 .66174 L .16789 .65361 L p F P
0 g
s
.562 .579 .828 r
.62432 .66072 m .62592 .65941 L p .65639 .67254 L F P
0 g
s
.569 .599 .843 r
.62432 .66072 m .62372 .65957 L .62592 .65941 L closepath p F P
0 g
s
.632 .777 .95 r
.39895 .60245 m .42526 .59492 L .43278 .6018 L p F P
0 g
s
.511 .823 1 r
.39129 .59573 m .39895 .60245 L p .42444 .59448 L F P
0 g
s
.531 .812 .998 r
.393 .59541 m .39072 .59539 L .39129 .59573 L closepath p F P
0 g
s
.511 .823 1 r
.393 .59541 m .39129 .59573 L p .39875 .59545 L F P
0 g
s
.511 .823 1 r
.42444 .59448 m .393 .59541 L p .39875 .59545 L F P
0 g
s
.59 .167 .207 r
.39818 .59599 m .39089 .5954 L .393 .59541 L F
.39072 .59539 m .393 .59541 L p .39089 .5954 L F P
0 g
s
.511 .823 1 r
.39895 .60245 m .42261 .59568 L p .42051 .5957 L F P
0 g
s
.59 .167 .207 r
.41546 .59792 m .39679 .59601 L .39818 .59599 L F
.39679 .59601 m .39072 .59539 L .39818 .59599 L F
.511 .823 1 r
.42526 .59492 m .42444 .59448 L p .42051 .5957 L F P
0 g
s
.511 .823 1 r
.42261 .59568 m .42526 .59492 L p .42051 .5957 L F P
0 g
s
.26 0 .04 r
.609 .94581 m .61108 .94232 L .63676 .93386 L p F P
0 g
s
.819 .838 .863 r
.69432 .30343 m .68474 .3115 L .67833 .30458 L p F P
0 g
s
.813 .769 .812 r
.13651 .6979 m .14978 .68519 L .14124 .6771 L p F P
0 g
s
.756 .806 .893 r
.60269 .3592 m .59761 .36229 L .59079 .35482 L p F P
0 g
s
.743 .803 .9 r
.56387 .37013 m .59079 .35482 L .59761 .36229 L p F P
0 g
s
.494 .629 .911 r
.49606 .36809 m .51458 .36824 L .51695 .37854 L p F P
0 g
s
.377 .584 .923 r
.51458 .36824 m .49606 .36809 L .48882 .35534 L p F P
0 g
s
.869 .6 .529 r
.12254 .88568 m .11007 .88012 L .11069 .86705 L p F P
0 g
s
.878 .609 .527 r
.09868 .86128 m .11069 .86705 L .11007 .88012 L p F P
0 g
s
.874 .638 .579 r
.11069 .86705 m .09868 .86128 L .1011 .84776 L p F P
0 g
s
.839 .843 .848 r
.70512 .28067 m .71163 .27452 L .71432 .28482 L p F P
0 g
s
.839 .843 .848 r
.71432 .28482 m .7114 .28755 L .70512 .28067 L p F P
0 g
s
.84 .847 .85 r
.69432 .30343 m .7114 .28755 L .70512 .28067 L p F P
0 g
s
.827 .767 .796 r
.13651 .6979 m .12288 .71236 L .11423 .70433 L p F P
0 g
s
.827 .767 .796 r
.11423 .70433 m .12696 .69081 L .13651 .6979 L p F P
0 g
s
.813 .769 .812 r
.14124 .6771 m .12696 .69081 L .13651 .6979 L p F P
0 g
s
.569 .601 .846 r
.62592 .65941 m .62372 .65957 L .61679 .64655 L p F P
0 g
s
.755 .761 .858 r
.22892 .62296 m .23976 .61586 L .2504 .62274 L p F P
0 g
s
.744 .762 .867 r
.25512 .60649 m .23976 .61586 L .2504 .62274 L p F P
0 g
s
.744 .762 .867 r
.2504 .62274 m .26324 .61493 L .25512 .60649 L p F P
0 g
s
.861 .553 .465 r
.13683 .90362 m .12392 .89825 L .12254 .88568 L p F P
0 g
s
.869 .559 .46 r
.11007 .88012 m .12254 .88568 L .12392 .89825 L p F P
0 g
s
.84 .847 .85 r
.70512 .28067 m .69185 .2931 L .69432 .30343 L p F P
0 g
s
.819 .838 .863 r
.67833 .30458 m .69185 .2931 L .69432 .30343 L p F P
0 g
s
.624 .735 .927 r
.52286 .36654 m .51458 .36824 L .51695 .37854 L p F P
0 g
s
.624 .735 .927 r
.51695 .37854 m .52999 .37508 L .52286 .36654 L p F P
0 g
s
.703 .759 .895 r
.3179 .59904 m .29735 .60899 L .28938 .6003 L p F P
0 g
s
.73 .754 .872 r
.26324 .61493 m .28938 .6003 L .29735 .60899 L p F P
0 g
s
.265 .764 .891 r
.44652 .97901 m .4504 .9795 L .47282 .97768 L p F P
0 g
s
.242 0 0 r
.23602 .96079 m .23761 .9607 L p .26327 .968 L F P
0 g
s
.586 .027 0 r
.23602 .96079 m .23455 .95996 L .23761 .9607 L closepath p F P
0 g
s
.61 .661 .875 r
.56704 .61337 m .54157 .6185 L .53447 .60748 L p F P
0 g
s
.796 .77 .83 r
.1783 .66008 m .17633 .66174 L .16789 .65361 L p F P
0 g
s
.796 .77 .83 r
.16789 .65361 m .16871 .65291 L .1783 .66008 L p F P
0 g
s
.783 .771 .842 r
.19432 .63304 m .16871 .65291 L .1783 .66008 L p F P
0 g
s
.783 .771 .842 r
.1783 .66008 m .20268 .64121 L .19432 .63304 L p F P
0 g
s
.651 .743 .917 r
.43278 .6018 m .45926 .59342 L .46662 .6017 L p F P
0 g
s
.627 .803 .967 r
.43278 .6018 m .45926 .59342 L .45339 .5885 L p F P
0 g
s
.627 .803 .967 r
.42526 .59492 m .43278 .6018 L p .45339 .5885 L F P
0 g
s
.528 .526 .797 r
.69535 .70554 m .67203 .70345 L .66903 .69629 L p F P
0 g
s
.191 0 0 r
.3112 .97586 m .31911 .97623 L .34165 .97867 L p F P
0 g
s
.074 .625 .825 r
.31911 .97623 m .30693 .97506 L .3112 .97586 L closepath p F P
0 g
s
.882 .648 .579 r
.0911 .84257 m .1011 .84776 L .09868 .86128 L p F P
0 g
s
.875 .671 .623 r
.0901 .84003 m .09365 .82783 L p .1011 .84776 L F P
0 g
s
.875 .671 .623 r
.1011 .84776 m .0911 .84257 L .0901 .84003 L p F P
0 g
s
.954 .624 .221 r
.75769 .09697 m .76366 .10679 L .76213 .09629 L p F P
0 g
s
.954 .624 .221 r
.76213 .09629 m .75618 .08647 L .75769 .09697 L p F P
0 g
s
.027 .592 .789 r
.34488 .97888 m .34165 .97867 L .34659 .97915 L closepath p F P
0 g
s
.77 .814 .888 r
.60269 .3592 m .6245 .3449 L .61779 .33751 L p F P
0 g
s
.77 .814 .888 r
.61779 .33751 m .60049 .34888 L .60269 .3592 L p F P
0 g
s
.756 .806 .893 r
.59079 .35482 m .60049 .34888 L .60269 .3592 L p F P
0 g
s
.72 .217 .038 r
.19008 .94153 m .19447 .94612 L .18552 .94636 L p F P
0 g
s
.72 .217 .038 r
.18552 .94636 m .17542 .93681 L .19008 .94153 L p F P
0 g
s
.562 .579 .828 r
.62592 .65941 m .65129 .65859 L p .65639 .67254 L F P
0 g
s
.553 .577 .832 r
.62592 .65941 m .65129 .65859 L .64437 .64476 L p F P
0 g
s
.553 .577 .832 r
.64437 .64476 m .64274 .6448 L .62592 .65941 L p F P
0 g
s
.569 .601 .846 r
.61679 .64655 m .64274 .6448 L .62592 .65941 L p F P
0 g
s
.347 .065 .336 r
.69076 .89288 m .66683 .90364 L .66494 .91459 L p F P
0 g
s
.407 .173 .444 r
.69141 .88086 m .69076 .89288 L .66683 .90364 L p F P
0 g
s
.846 .491 .382 r
.15354 .92077 m .14043 .91565 L .13683 .90362 L p F P
0 g
s
.853 .494 .372 r
.12392 .89825 m .13683 .90362 L .14043 .91565 L p F P
0 g
s
.507 0 0 r
.23455 .95996 m .23602 .96079 L .22738 .96007 L p F P
0 g
s
.507 0 0 r
.22738 .96007 m .21844 .95572 L .23455 .95996 L p F P
0 g
s
.826 .768 .797 r
.11997 .71544 m .12288 .71236 L .11423 .70433 L p F P
0 g
s
.232 .716 .93 r
.34165 .97867 m .34488 .97888 L .33689 .97619 L p F P
0 g
s
.232 .716 .93 r
.33689 .97619 m .31911 .97623 L .34165 .97867 L p F P
0 g
s
.652 .736 .911 r
.49326 .59358 m .46662 .6017 L .45926 .59342 L p F P
0 g
s
.926 .856 .753 r
.75347 .22508 m .75764 .21847 L .75162 .2121 L p F P
0 g
s
.841 .764 .778 r
.11041 .70839 m .11997 .71544 L .10585 .73223 L p F P
0 g
s
.826 .768 .797 r
.11423 .70433 m .11041 .70839 L .11997 .71544 L p F P
0 g
s
.528 .526 .797 r
.66903 .69629 m .67848 .68825 L p .69535 .70554 L F P
0 g
s
.537 .55 .816 r
.66903 .69629 m .66511 .68768 L .67848 .68825 L closepath p F P
0 g
s
.885 .678 .618 r
.09365 .82783 m .0901 .84003 L .08233 .82254 L p F P
0 g
s
.885 .678 .618 r
.08233 .82254 m .0826 .82162 L .09365 .82783 L p F P
0 g
s
.876 .695 .655 r
.09365 .82783 m .0826 .82162 L .08823 .80726 L p F P
0 g
s
0 0 0 r
.57529 .95976 m .54828 .96582 L .54131 .96771 L p F P
0 g
s
0 0 0 r
.51441 .97272 m .54131 .96771 L .54828 .96582 L p F P
0 g
s
.125 0 0 r
.57869 .95747 m .57529 .95976 L .54828 .96582 L p F P
0 g
s
.242 0 0 r
.26327 .968 m .2585 .96691 L .23602 .96079 L p F P
0 g
s
.305 0 0 r
.2585 .96691 m .23602 .96079 L .22738 .96007 L p F P
0 g
s
.777 .77 .846 r
.20543 .63916 m .20268 .64121 L .19432 .63304 L p F P
0 g
s
.731 .761 .877 r
.28938 .6003 m .26324 .61493 L .25512 .60649 L p F P
0 g
s
.431 .306 .608 r
.71824 .82251 m .7106 .82727 L .71274 .84195 L p F P
0 g
s
.871 .737 .712 r
.08333 .76414 m .09342 .77085 L .08478 .78604 L p F P
0 g
s
.86 .744 .735 r
.09342 .77085 m .08333 .76414 L .09363 .74847 L p F P
0 g
s
.18 .714 .812 r
.48047 .97679 m .47282 .97768 L .48174 .97681 L closepath p F P
0 g
s
.265 .764 .891 r
.47282 .97768 m .48047 .97679 L p .44652 .97901 L F P
0 g
s
.777 .77 .846 r
.19432 .63304 m .19577 .63195 L .20543 .63916 L p F P
0 g
s
.765 .77 .857 r
.22064 .61476 m .19577 .63195 L .20543 .63916 L p F P
0 g
s
.765 .77 .857 r
.20543 .63916 m .22892 .62296 L .22064 .61476 L p F P
0 g
s
.979 .814 .608 r
.76435 .14798 m .76678 .13991 L .77164 .14992 L p F P
0 g
s
.979 .814 .608 r
.77164 .14992 m .7703 .15436 L .76435 .14798 L p F P
0 g
s
.126 .666 .843 r
.3787 .98006 m .37088 .97695 L .34488 .97888 L p F P
0 g
s
.519 .798 .996 r
.37088 .97695 m .34488 .97888 L .33689 .97619 L p F P
0 g
s
.828 .454 .347 r
.15375 .92085 m .15354 .92077 L .15368 .92068 L closepath p F P
0 g
s
.926 .856 .753 r
.75162 .2121 m .74988 .21488 L .75347 .22508 L p F P
0 g
s
.901 .85 .784 r
.73841 .23049 m .74199 .24065 L .75347 .22508 L p F P
0 g
s
.901 .85 .784 r
.75347 .22508 m .74988 .21488 L .73841 .23049 L p F P
0 g
s
.793 .362 .224 r
.17542 .93681 m .1611 .93195 L .15375 .92085 L p F P
0 g
s
.784 .331 .169 r
.15354 .92077 m .15375 .92085 L .1611 .93195 L p F P
0 g
s
.784 .331 .169 r
.14432 .92316 m .15354 .92077 L p .1611 .93195 L F P
0 g
s
.825 .415 .268 r
.14432 .92316 m .14043 .91565 L .15354 .92077 L closepath p F P
0 g
s
.741 .795 .896 r
.59079 .35482 m .56387 .37013 L .55689 .36237 L p F P
0 g
s
.627 .675 .876 r
.5005 .60349 m .52732 .59673 L .53447 .60748 L p F P
0 g
s
.632 .693 .889 r
.52014 .58635 m .52732 .59673 L .5005 .60349 L p F P
0 g
s
.632 .693 .889 r
.50419 .59057 m .52014 .58635 L p .5005 .60349 L F P
0 g
s
.632 .693 .889 r
.5005 .60349 m .49499 .59588 L .50419 .59057 L p F P
0 g
s
.852 .759 .759 r
.10585 .73223 m .09525 .74633 L .08651 .73821 L p F P
0 g
s
.852 .759 .759 r
.08651 .73821 m .09626 .72523 L .10585 .73223 L p F P
0 g
s
.841 .764 .778 r
.10585 .73223 m .09626 .72523 L .11041 .70839 L p F P
0 g
s
.235 .752 .838 r
.48047 .97679 m .48174 .97681 L .51158 .97271 L p F P
0 g
s
.09 .646 .704 r
.51441 .97272 m .51158 .97271 L .48174 .97681 L p F P
0 g
s
.777 .815 .883 r
.63929 .3348 m .6245 .3449 L .61779 .33751 L p F P
0 g
s
.882 .706 .659 r
.07764 .80082 m .08823 .80726 L .0826 .82162 L p F P
0 g
s
.874 .717 .685 r
.08823 .80726 m .07764 .80082 L .08478 .78604 L p F P
0 g
s
.466 .387 .684 r
.72916 .7971 m .71428 .78843 L .72525 .78101 L closepath p F P
0 g
s
.489 .42 .706 r
.72152 .76771 m .72525 .78101 L .71428 .78843 L p F P
0 g
s
.489 .42 .706 r
.71692 .76572 m .72152 .76771 L p .71428 .78843 L F P
0 g
s
.537 .551 .817 r
.67848 .68825 m .66511 .68768 L .65819 .67255 L p F P
0 g
s
.942 .841 .715 r
.75489 .19002 m .75917 .2001 L .7665 .18606 L p F P
0 g
s
.942 .841 .715 r
.7665 .18606 m .76223 .17596 L .75489 .19002 L p F P
0 g
s
.042 0 0 r
.57529 .95976 m .57869 .95747 L .60529 .95004 L p F P
0 g
s
.194 0 0 r
.609 .94581 m .60529 .95004 L .57869 .95747 L p F P
0 g
s
.183 .692 .9 r
.31911 .97623 m .33689 .97619 L p .30302 .97405 L F P
0 g
s
.183 .692 .9 r
.30302 .97405 m .30693 .97506 L .31911 .97623 L p F P
0 g
s
.223 .729 .896 r
.41259 .98005 m .40492 .97687 L .3787 .98006 L p F P
0 g
s
.557 .805 .991 r
.40492 .97687 m .3787 .98006 L .37088 .97695 L p F P
0 g
s
.266 .773 .843 r
.51158 .97271 m .51441 .97272 L .54131 .96771 L p F P
0 g
s
.98 .814 .604 r
.76782 .16259 m .7703 .15436 L .76435 .14798 L p F P
0 g
s
.589 .629 .859 r
.5756 .62508 m .60288 .6214 L p .60372 .63426 L F P
0 g
s
.584 .633 .866 r
.60288 .6214 m .5756 .62508 L .56857 .61309 L p F P
0 g
s
.758 .326 0 r
.48844 .35459 m .48509 .34999 L .48882 .35534 L closepath p F P
0 g
s
.703 .763 .898 r
.53942 .37072 m .52999 .37508 L .52286 .36654 L p F P
0 g
s
.26 0 .04 r
.63676 .93386 m .63616 .93496 L .609 .94581 L p F P
0 g
s
.125 0 0 r
.60529 .95004 m .609 .94581 L .63616 .93496 L p F P
0 g
s
.566 .602 .848 r
.64274 .6448 m .61679 .64655 L .60984 .6336 L p F P
0 g
s
.703 .759 .895 r
.28938 .6003 m .30632 .59244 L .3179 .59904 L p F P
0 g
s
.704 .763 .898 r
.31552 .58832 m .30632 .59244 L .3179 .59904 L p F P
0 g
s
.704 .763 .898 r
.3179 .59904 m .32345 .59647 L .31552 .58832 L p F P
0 g
s
.623 .075 0 r
.21844 .95572 m .2025 .95138 L .19447 .94612 L p F P
0 g
s
.623 .074 0 r
.2025 .95138 m .19447 .94612 L .18552 .94636 L p F P
0 g
s
.267 .758 .909 r
.44652 .97901 m .43901 .97616 L .41259 .98005 L p F P
0 g
s
.566 .814 .991 r
.43901 .97616 m .41259 .98005 L .40492 .97687 L p F P
0 g
s
.989 .775 .521 r
.76134 .13001 m .76678 .13991 L .76879 .12796 L p F P
0 g
s
.989 .775 .521 r
.76879 .12796 m .76337 .11804 L .76134 .13001 L p F P
0 g
s
.377 .584 .923 r
.48882 .35534 m .50942 .35881 L .51458 .36824 L p F P
0 g
s
.392 .574 .911 r
.48509 .34999 m .48882 .35534 L .50942 .35881 L p F P
0 g
s
.235 .752 .838 r
.51158 .97271 m .50723 .97218 L .48047 .97679 L p F P
0 g
s
.509 .847 .996 r
.50723 .97218 m .48047 .97679 L .47312 .97473 L p F P
0 g
s
.265 .764 .891 r
.48047 .97679 m .47312 .97473 L .44652 .97901 L p F P
0 g
s
.757 .769 .863 r
.23976 .61586 m .22892 .62296 L .22064 .61476 L p F P
0 g
s
.552 .829 .997 r
.47312 .97473 m .44652 .97901 L .43901 .97616 L p F P
0 g
s
.879 .847 .808 r
.72546 .24602 m .73841 .23049 L .74199 .24065 L p F P
0 g
s
.879 .847 .808 r
.74199 .24065 m .73166 .25294 L .72546 .24602 L p F P
0 g
s
.793 .823 .875 r
.63929 .3348 m .65143 .32581 L .64482 .31848 L p F P
0 g
s
.793 .823 .875 r
.64482 .31848 m .63665 .32456 L .63929 .3348 L p F P
0 g
s
.777 .815 .883 r
.61779 .33751 m .63665 .32456 L .63929 .3348 L p F P
0 g
s
.052 .601 .835 r
.30302 .97405 m .29753 .97352 L .30693 .97506 L closepath p F P
0 g
s
.366 .142 .435 r
.70142 .87567 m .69141 .88086 L .69076 .89288 L p F P
0 g
s
.41 .22 .51 r
.69141 .88086 m .70142 .87567 L .70261 .86191 L p F P
0 g
s
.402 .214 .508 r
.71404 .8558 m .70261 .86191 L .70142 .87567 L p F P
0 g
s
.437 .278 .566 r
.70261 .86191 m .71404 .8558 L .71274 .84195 L p F P
0 g
s
.852 .76 .761 r
.09363 .74847 m .09525 .74633 L .08651 .73821 L p F P
0 g
s
.61 .661 .875 r
.53447 .60748 m .56151 .60198 L p .56704 .61337 L F P
0 g
s
.61 .667 .88 r
.56151 .60198 m .53447 .60748 L .52732 .59673 L p F P
0 g
s
.412 0 0 r
.21844 .95572 m .22738 .96007 L .21874 .95806 L p F P
0 g
s
.412 0 0 r
.21874 .95806 m .2025 .95138 L .21844 .95572 L p F P
0 g
s
.865 .754 .738 r
.08401 .74151 m .09363 .74847 L .08333 .76414 L p F P
0 g
s
.852 .76 .761 r
.08651 .73821 m .08401 .74151 L .09363 .74847 L p F P
0 g
s
.703 .18 0 r
.17542 .93681 m .18552 .94636 L .18397 .94619 L p F P
0 g
s
.703 .18 0 r
.1611 .93195 m .17542 .93681 L p .18397 .94619 L F P
0 g
s
.638 .78 .949 r
.32345 .59647 m .34953 .58858 L .35738 .59546 L p F P
0 g
s
.596 .781 .969 r
.32345 .59647 m .34953 .58858 L .34844 .58773 L p F P
0 g
s
.596 .781 .969 r
.31552 .58832 m .32345 .59647 L p .34844 .58773 L F P
0 g
s
.882 .648 .579 r
.09868 .86128 m .09347 .85861 L .0911 .84257 L p F P
0 g
s
.886 .65 .576 r
.08959 .84177 m .0911 .84257 L .09347 .85861 L p F P
0 g
s
.878 .672 .62 r
.0911 .84257 m .0901 .84003 L .08959 .84177 L closepath p F P
0 g
s
.881 .727 .687 r
.07466 .77936 m .08478 .78604 L .07764 .80082 L p F P
0 g
s
.871 .737 .712 r
.08478 .78604 m .07466 .77936 L .08333 .76414 L p F P
0 g
s
.878 .609 .527 r
.11007 .88012 m .098 .87438 L .09868 .86128 L p F P
0 g
s
.887 .617 .525 r
.09347 .85861 m .09868 .86128 L .098 .87438 L p F P
0 g
s
.869 .559 .46 r
.12392 .89825 m .1114 .89271 L .11007 .88012 L p F P
0 g
s
.878 .566 .455 r
.098 .87438 m .11007 .88012 L .1114 .89271 L p F P
0 g
s
.884 .679 .62 r
.08959 .84177 m .0901 .84003 L .08233 .82254 L p F P
0 g
s
.798 .823 .871 r
.66817 .31305 m .65143 .32581 L .64482 .31848 L p F P
0 g
s
.532 .803 .996 r
.39072 .59539 m .36534 .59403 L p .36885 .59543 L F P
0 g
s
.106 .652 .832 r
.36534 .59403 m .39072 .59539 L .38597 .59458 L p F P
0 g
s
.106 .652 .832 r
.38597 .59458 m .38342 .59414 L .37968 .59412 L p F P
0 g
s
.106 .652 .832 r
.37968 .59412 m .36534 .59403 L p .38597 .59458 L F P
0 g
s
.531 0 0 r
.36534 .59403 m .38342 .59414 L .37978 .59713 L p F P
0 g
s
.531 0 0 r
.37978 .59713 m .35536 .59005 L .36534 .59403 L F
.35026 .58857 m .36534 .59403 L p .35536 .59005 L F P
0 g
s
.532 .803 .996 r
.36534 .59403 m .35738 .59546 L p .36885 .59543 L F P
0 g
s
.569 .757 .966 r
.36534 .59403 m .35738 .59546 L .34953 .58858 L p F P
0 g
s
.569 .757 .966 r
.35026 .58857 m .36534 .59403 L p .35243 .58958 L F P
0 g
s
.569 .757 .966 r
.34953 .58858 m .35026 .58857 L p .35243 .58958 L F P
0 g
s
.531 0 0 r
.37978 .59713 m .36688 .59551 L .36013 .59269 L p F P
0 g
s
.531 0 0 r
.36013 .59269 m .35026 .58857 L p .36593 .59312 L F P
0 g
s
.531 0 0 r
.37978 .59713 m .36013 .59269 L .36593 .59312 L F
.709 .229 .107 r
.35026 .58857 m .36688 .59551 L p .34864 .58782 L F P
0 g
s
.709 .229 .107 r
.34844 .58773 m .35026 .58857 L p .34864 .58782 L F P
0 g
s
.548 .559 .817 r
.65819 .67255 m .65639 .67254 L .6577 .67149 L closepath p F P
0 g
s
.562 .579 .828 r
.65129 .65859 m .6577 .67149 L .65639 .67254 L p F P
0 g
s
.757 .769 .863 r
.22064 .61476 m .23001 .60862 L .23976 .61586 L p F P
0 g
s
.746 .769 .872 r
.24692 .59829 m .23001 .60862 L .23976 .61586 L p F P
0 g
s
.746 .769 .872 r
.23976 .61586 m .25512 .60649 L .24692 .59829 L p F P
0 g
s
.816 .778 .817 r
.14619 .67239 m .14124 .6771 L .13259 .66939 L p F P
0 g
s
.816 .778 .817 r
.13259 .66939 m .13722 .66499 L .14619 .67239 L p F P
0 g
s
.803 .779 .831 r
.15934 .64582 m .13722 .66499 L .14619 .67239 L p F P
0 g
s
.803 .779 .831 r
.14619 .67239 m .16789 .65361 L .15934 .64582 L p F P
0 g
s
.88 .848 .807 r
.72816 .25709 m .73166 .25294 L .72546 .24602 L p F P
0 g
s
.401 .252 .562 r
.72599 .83378 m .71274 .84195 L .71404 .8558 L p F P
0 g
s
.431 .306 .608 r
.71274 .84195 m .72599 .83378 L .71824 .82251 L p F P
0 g
s
.817 .778 .816 r
.12696 .69081 m .14124 .6771 L .13259 .66939 L p F P
0 g
s
.703 .763 .898 r
.52286 .36654 m .53501 .36109 L .53942 .37072 L p F P
0 g
s
.702 .767 .902 r
.53942 .37072 m .55689 .36237 L .54985 .35427 L p F P
0 g
s
.702 .767 .902 r
.54985 .35427 m .53501 .36109 L .53942 .37072 L p F P
0 g
s
.987 .717 .409 r
.75738 .10824 m .76337 .11804 L .76366 .10679 L p F P
0 g
s
.987 .717 .409 r
.76366 .10679 m .75769 .09697 L .75738 .10824 L p F P
0 g
s
.199 0 0 r
.26934 .96944 m .27802 .97023 L .29753 .97352 L p F P
0 g
s
.048 .6 .827 r
.27802 .97023 m .26327 .968 L .26934 .96944 L closepath p F P
0 g
s
.886 .65 .576 r
.09347 .85861 m .08719 .8553 L .08959 .84177 L p F P
0 g
s
.894 .659 .575 r
.07861 .83556 m .08959 .84177 L .08719 .8553 L p F P
0 g
s
.884 .679 .62 r
.08233 .82254 m .07861 .83556 L .08959 .84177 L p F P
0 g
s
.697 .762 .902 r
.30632 .59244 m .28938 .6003 L .28133 .59183 L p F P
0 g
s
.731 .761 .877 r
.25512 .60649 m .28133 .59183 L .28938 .6003 L p F P
0 g
s
.853 .494 .372 r
.14043 .91565 m .12752 .91029 L .12392 .89825 L p F P
0 g
s
.861 .498 .361 r
.1114 .89271 m .12392 .89825 L .12752 .91029 L p F P
0 g
s
.831 .776 .8 r
.12696 .69081 m .11423 .70433 L .10548 .69671 L p F P
0 g
s
.831 .776 .8 r
.10548 .69671 m .11794 .68347 L .12696 .69081 L p F P
0 g
s
.817 .778 .816 r
.13259 .66939 m .11794 .68347 L .12696 .69081 L p F P
0 g
s
.579 .611 .849 r
.60984 .6336 m .60372 .63426 L .60823 .63063 L closepath p F P
0 g
s
.589 .629 .859 r
.60288 .6214 m .60823 .63063 L .60372 .63426 L p F P
0 g
s
.223 .7 .937 r
.29753 .97352 m .30302 .97405 L .29483 .97072 L p F P
0 g
s
.223 .7 .937 r
.29483 .97072 m .27802 .97023 L .29753 .97352 L p F P
0 g
s
.88 .848 .807 r
.72546 .24602 m .7247 .24693 L .72816 .25709 L p F P
0 g
s
.858 .839 .826 r
.70821 .26438 m .71163 .27452 L .72816 .25709 L p F P
0 g
s
.858 .839 .826 r
.72816 .25709 m .7247 .24693 L .70821 .26438 L p F P
0 g
s
.799 .779 .834 r
.16871 .65291 m .16789 .65361 L .15934 .64582 L p F P
0 g
s
.799 .779 .834 r
.15934 .64582 m .15978 .64545 L .16871 .65291 L p F P
0 g
s
.786 .779 .846 r
.18587 .62518 m .15978 .64545 L .16871 .65291 L p F P
0 g
s
.786 .779 .846 r
.16871 .65291 m .19432 .63304 L .18587 .62518 L p F P
0 g
s
.537 .551 .817 r
.65819 .67255 m .68619 .67406 L p .67848 .68825 L F P
0 g
s
.525 .546 .82 r
.67928 .65932 m .68619 .67406 L .65819 .67255 L p F P
0 g
s
.525 .546 .82 r
.67084 .65878 m .67928 .65932 L p .65819 .67255 L F P
0 g
s
.525 .546 .82 r
.65819 .67255 m .6577 .67149 L .67084 .65878 L p F P
0 g
s
.425 .304 .611 r
.73244 .81341 m .71824 .82251 L .72599 .83378 L p F P
0 g
s
.457 .351 .645 r
.72931 .7977 m .73244 .81341 L .71824 .82251 L p F P
0 g
s
.98 .814 .604 r
.76435 .14798 m .76298 .15258 L .76782 .16259 L p F P
0 g
s
.958 .825 .67 r
.75736 .16598 m .76223 .17596 L .76782 .16259 L p F P
0 g
s
.958 .825 .67 r
.76782 .16259 m .76298 .15258 L .75736 .16598 L p F P
0 g
s
.919 .842 .752 r
.74566 .20481 m .75489 .19002 L .75917 .2001 L p F P
0 g
s
.919 .842 .752 r
.74601 .20565 m .74566 .20481 L p .75917 .2001 L F P
0 g
s
.919 .842 .752 r
.75917 .2001 m .75162 .2121 L .74601 .20565 L p F P
0 g
s
.541 .573 .836 r
.6577 .67149 m .65129 .65859 L .67084 .65878 L closepath p F P
0 g
s
.477 .417 .711 r
.72152 .76771 m .71692 .76572 L .72029 .76333 L closepath p F P
0 g
s
.496 .452 .738 r
.71692 .76572 m .72029 .76333 L .71431 .74452 L p F P
0 g
s
.816 .83 .86 r
.66817 .31305 m .67833 .30458 L .67184 .29727 L p F P
0 g
s
.816 .83 .86 r
.67184 .29727 m .66517 .30287 L .66817 .31305 L p F P
0 g
s
.798 .823 .871 r
.64482 .31848 m .66517 .30287 L .66817 .31305 L p F P
0 g
s
.635 .704 .896 r
.49499 .59588 m .49326 .59358 L .50419 .59057 L closepath p F P
0 g
s
.755 .799 .888 r
.60049 .34888 m .59079 .35482 L .58391 .34702 L p F P
0 g
s
.741 .795 .896 r
.55689 .36237 m .58391 .34702 L .59079 .35482 L p F P
0 g
s
.627 .803 .967 r
.45339 .5885 m .43893 .59096 L .42526 .59492 L p F P
0 g
s
.596 .854 .993 r
.43893 .59096 m .42444 .59448 L .42526 .59492 L closepath p F P
0 g
s
.831 .776 .8 r
.11041 .70839 m .11423 .70433 L .10548 .69671 L p F P
0 g
s
.361 .822 .919 r
.50723 .97218 m .51158 .97271 L .54051 .96764 L p F P
0 g
s
.266 .773 .843 r
.54131 .96771 m .54051 .96764 L .51158 .97271 L p F P
0 g
s
.818 .829 .858 r
.69185 .2931 m .67833 .30458 L .67184 .29727 L p F P
0 g
s
.032 .603 .718 r
.393 .59541 m .42444 .59448 L .41766 .59461 L p F P
0 g
s
.032 .603 .718 r
.41766 .59461 m .41755 .59461 L .4172 .59462 L p F P
0 g
s
.032 .603 .718 r
.4172 .59462 m .393 .59541 L p .41766 .59461 L F P
0 g
s
.59 .167 .207 r
.41546 .59792 m .39129 .59802 L .38624 .59553 L p F P
0 g
s
.59 .167 .207 r
.393 .59541 m .41755 .59461 L .41546 .59792 L p F P
0 g
s
.59 .167 .207 r
.38342 .59414 m .39072 .59539 L p .41546 .59792 L F P
0 g
s
.59 .167 .207 r
.38624 .59553 m .38342 .59414 L p .39342 .59532 L F P
0 g
s
.59 .167 .207 r
.41546 .59792 m .38624 .59553 L .39342 .59532 L F
.652 .736 .911 r
.45926 .59342 m .48597 .58493 L .49326 .59358 L p F P
0 g
s
.644 .802 .959 r
.45339 .5885 m .45926 .59342 L .48597 .58493 L p F P
0 g
s
.893 .688 .618 r
.08233 .82254 m .0826 .82162 L .08153 .82098 L closepath p F P
0 g
s
.882 .706 .659 r
.074 .81015 m .07764 .80082 L p .0826 .82162 L F P
0 g
s
.882 .706 .659 r
.0826 .82162 m .08153 .82098 L .074 .81015 L p F P
0 g
s
.772 .381 0 r
.48154 .34328 m .48241 .34541 L .48509 .34999 L closepath p F P
0 g
s
.392 .574 .911 r
.50276 .34982 m .48241 .34541 L .48509 .34999 L p F P
0 g
s
.392 .574 .911 r
.50942 .35881 m .50276 .34982 L p .48509 .34999 L F P
0 g
s
.837 .834 .843 r
.69876 .27337 m .70821 .26438 L .71163 .27452 L p F P
0 g
s
.837 .834 .843 r
.71163 .27452 m .70512 .28067 L .69876 .27337 L p F P
0 g
s
.845 .773 .781 r
.10133 .70111 m .11041 .70839 L .09626 .72523 L p F P
0 g
s
.831 .776 .8 r
.10548 .69671 m .10133 .70111 L .11041 .70839 L p F P
0 g
s
.838 .836 .844 r
.69185 .2931 m .70512 .28067 L .69876 .27337 L p F P
0 g
s
.838 .836 .844 r
.69876 .27337 m .68859 .28295 L .69185 .2931 L p F P
0 g
s
.818 .829 .858 r
.67184 .29727 m .68859 .28295 L .69185 .2931 L p F P
0 g
s
.827 .403 .233 r
.14043 .91565 m .14432 .92316 L .13832 .92362 L p F P
0 g
s
.827 .403 .233 r
.12752 .91029 m .14043 .91565 L p .13832 .92362 L F P
0 g
s
.893 .688 .618 r
.07861 .83556 m .08233 .82254 L .08153 .82098 L p F P
0 g
s
.595 .72 .932 r
.51567 .35781 m .50942 .35881 L .51458 .36824 L p F P
0 g
s
.595 .72 .932 r
.51458 .36824 m .52286 .36654 L .51567 .35781 L p F P
0 g
s
.893 .688 .618 r
.08153 .82098 m .07203 .8152 L p .07861 .83556 L F P
0 g
s
.885 .706 .655 r
.08153 .82098 m .074 .81015 L .07203 .8152 L closepath p F P
0 g
s
.602 .644 .864 r
.56857 .61309 m .56704 .61337 L .56822 .61251 L closepath p F P
0 g
s
.61 .661 .875 r
.56151 .60198 m .56822 .61251 L .56704 .61337 L p F P
0 g
s
.327 0 0 r
.42444 .59448 m .43893 .59096 L p .44454 .59184 L F P
0 g
s
.327 0 0 r
.41755 .59461 m .42444 .59448 L p .44454 .59184 L F P
0 g
s
.887 .617 .525 r
.098 .87438 m .09022 .87043 L .09347 .85861 L p F P
0 g
s
.891 .622 .525 r
.08719 .8553 m .09347 .85861 L .09022 .87043 L p F P
0 g
s
.732 .768 .881 r
.28133 .59183 m .25512 .60649 L .24692 .59829 L p F P
0 g
s
.781 .779 .851 r
.19577 .63195 m .19432 .63304 L .18587 .62518 L p F P
0 g
s
.877 .746 .714 r
.07368 .75722 m .08333 .76414 L .07466 .77936 L p F P
0 g
s
.865 .754 .738 r
.08333 .76414 m .07368 .75722 L .08401 .74151 L p F P
0 g
s
.634 .729 .916 r
.50419 .59057 m .49326 .59358 L .48597 .58493 L p F P
0 g
s
.768 .806 .883 r
.60049 .34888 m .61779 .33751 L .61101 .32977 L p F P
0 g
s
.768 .806 .883 r
.61101 .32977 m .59723 .33883 L .60049 .34888 L p F P
0 g
s
.755 .799 .888 r
.58391 .34702 m .59723 .33883 L .60049 .34888 L p F P
0 g
s
.781 .779 .851 r
.18587 .62518 m .18688 .62442 L .19577 .63195 L p F P
0 g
s
.768 .778 .861 r
.21227 .60683 m .18688 .62442 L .19577 .63195 L p F P
0 g
s
.768 .778 .861 r
.19577 .63195 m .22064 .61476 L .21227 .60683 L p F P
0 g
s
.301 0 .182 r
.66333 .91974 m .66494 .91459 L p .63676 .93386 L F P
0 g
s
.301 0 .182 r
.63676 .93386 m .64301 .93147 L .66333 .91974 L p F P
0 g
s
.218 0 .041 r
.63616 .93496 m .64301 .93147 L .63676 .93386 L closepath p F P
0 g
s
.566 .602 .848 r
.60984 .6336 m .63745 .63192 L p .64274 .6448 L F P
0 g
s
.558 .601 .852 r
.63051 .61926 m .63745 .63192 L .60984 .6336 L p F P
0 g
s
.558 .601 .852 r
.61878 .61991 m .63051 .61926 L p .60984 .6336 L F P
0 g
s
.558 .601 .852 r
.60984 .6336 m .60823 .63063 L .61878 .61991 L p F P
0 g
s
.584 .633 .866 r
.56857 .61309 m .59589 .60952 L .60288 .6214 L p F P
0 g
s
.582 .634 .868 r
.58886 .59776 m .59589 .60952 L .56857 .61309 L p F P
0 g
s
.582 .634 .868 r
.58277 .59856 m .58886 .59776 L p .56857 .61309 L F P
0 g
s
.582 .634 .868 r
.56857 .61309 m .56822 .61251 L .58277 .59856 L p F P
0 g
s
.528 .526 .797 r
.67848 .68825 m .69313 .68977 L p .69535 .70554 L F P
0 g
s
.519 .529 .805 r
.69313 .68977 m .67848 .68825 L .68856 .67915 L closepath p F P
0 g
s
.537 .551 .817 r
.68619 .67406 m .68856 .67915 L .67848 .68825 L p F P
0 g
s
.183 .692 .9 r
.33689 .97619 m .32888 .97208 L .30302 .97405 L p F P
0 g
s
.539 .784 .989 r
.32888 .97208 m .30302 .97405 L .29483 .97072 L p F P
0 g
s
.273 0 .208 r
.66333 .91974 m .67748 .90899 L .66494 .91459 L closepath p F P
0 g
s
.347 .065 .336 r
.69025 .89635 m .69076 .89288 L p .66494 .91459 L F P
0 g
s
.347 .065 .336 r
.66494 .91459 m .67748 .90899 L .69025 .89635 L p F P
0 g
s
.593 .653 .879 r
.56822 .61251 m .56151 .60198 L .58277 .59856 L closepath p F P
0 g
s
.47 .436 .738 r
.71454 .74433 m .71431 .74452 L .72029 .76333 L p F P
0 g
s
.49 .47 .763 r
.71431 .74452 m .71422 .74425 L .71454 .74433 L closepath p F P
0 g
s
.49 .47 .762 r
.71454 .74433 m .71422 .74425 L .70718 .7244 L p F P
0 g
s
.459 .405 .71 r
.72029 .76333 m .73427 .75193 L p .73414 .77413 L F P
0 g
s
.459 .405 .71 r
.73414 .77413 m .72152 .76771 L .72029 .76333 L p F P
0 g
s
.47 .436 .738 r
.72029 .76333 m .73427 .75193 L .71454 .74433 L p F P
0 g
s
0 0 0 r
.54131 .96771 m .56844 .96138 L .57529 .95976 L p F P
0 g
s
.042 0 0 r
.60529 .95004 m .60249 .95202 L .57529 .95976 L p F P
0 g
s
.19 .712 .684 r
.60249 .95202 m .57529 .95976 L .56844 .96138 L p F P
0 g
s
.92 .842 .752 r
.75162 .2121 m .74988 .21488 L .74601 .20565 L closepath p F P
0 g
s
.467 .44 .745 r
.73016 .73085 m .71454 .74433 L .73427 .75193 L p F P
0 g
s
.49 .47 .762 r
.70735 .72426 m .73016 .73085 L .71454 .74433 L p F P
0 g
s
.49 .47 .762 r
.70718 .7244 m .70735 .72426 L p .71454 .74433 L F P
0 g
s
.973 .8 .61 r
.75826 .14032 m .76134 .13001 L .76678 .13991 L p F P
0 g
s
.973 .8 .61 r
.76678 .13991 m .76435 .14798 L .75826 .14032 L p F P
0 g
s
.892 .714 .655 r
.07764 .80082 m .074 .81015 L .06545 .79939 L p F P
0 g
s
.892 .714 .655 r
.06545 .79939 m .06747 .79418 L .07764 .80082 L p F P
0 g
s
.881 .727 .687 r
.07764 .80082 m .06747 .79418 L .07466 .77936 L p F P
0 g
s
.458 .406 .712 r
.72525 .78101 m .72152 .76771 L .73414 .77413 L closepath p F P
0 g
s
.858 .769 .763 r
.09626 .72523 m .08651 .73821 L .07763 .73063 L p F P
0 g
s
.858 .769 .763 r
.07763 .73063 m .08713 .71801 L .09626 .72523 L p F P
0 g
s
.845 .773 .781 r
.09626 .72523 m .08713 .71801 L .10133 .70111 L p F P
0 g
s
.571 .623 .865 r
.60823 .63063 m .60288 .6214 L .61878 .61991 L closepath p F P
0 g
s
.739 .788 .892 r
.58391 .34702 m .55689 .36237 L .54985 .35427 L p F P
0 g
s
.891 .837 .785 r
.73418 .22045 m .73841 .23049 L .74988 .21488 L p F P
0 g
s
.891 .837 .785 r
.7455 .20503 m .73418 .22045 L p .74988 .21488 L F P
0 g
s
.891 .837 .785 r
.74988 .21488 m .74601 .20565 L .7455 .20503 L p F P
0 g
s
.073 0 0 r
.63106 .94151 m .63616 .93496 L .64301 .93147 L p F P
0 g
s
.125 0 0 r
.63616 .93496 m .63106 .94151 L .60529 .95004 L p F P
0 g
s
.263 0 0 r
.2025 .95138 m .21874 .95806 L .21279 .95598 L p F P
0 g
s
.263 0 0 r
.18665 .94698 m .2025 .95138 L p .21279 .95598 L F P
0 g
s
.623 .074 0 r
.18552 .94636 m .18665 .94698 L .2025 .95138 L p F P
0 g
s
.697 .762 .902 r
.28133 .59183 m .29568 .58545 L .30632 .59244 L p F P
0 g
s
.699 .767 .905 r
.30751 .58034 m .29568 .58545 L .30632 .59244 L p F P
0 g
s
.699 .767 .905 r
.30632 .59244 m .31552 .58832 L .30751 .58034 L p F P
0 g
s
.155 .667 .898 r
.27802 .97023 m .29483 .97072 L p .26094 .96731 L F P
0 g
s
.155 .667 .898 r
.26094 .96731 m .26327 .968 L .27802 .97023 L p F P
0 g
s
.366 .142 .435 r
.69076 .89288 m .69432 .89105 L .70142 .87567 L p F P
0 g
s
.355 .13 .428 r
.71443 .86876 m .70142 .87567 L .69432 .89105 L p F P
0 g
s
.402 .214 .508 r
.70142 .87567 m .71443 .86876 L .71404 .8558 L p F P
0 g
s
.509 .502 .784 r
.70009 .70631 m .69535 .70554 L .69869 .70273 L closepath p F P
0 g
s
.528 .526 .797 r
.69313 .68977 m .69869 .70273 L .69535 .70554 L p F P
0 g
s
.501 .497 .784 r
.70718 .7244 m .7071 .72421 L .70735 .72426 L closepath p F P
0 g
s
.5 .497 .784 r
.70735 .72426 m .7071 .72421 L .70009 .70631 L p F P
0 g
s
.447 .375 .683 r
.72525 .78101 m .73414 .77413 L p .72966 .79744 L F P
0 g
s
.447 .375 .683 r
.72966 .79744 m .72916 .7971 L .72525 .78101 L p F P
0 g
s
.479 .47 .77 r
.72187 .71093 m .70735 .72426 L .73016 .73085 L p F P
0 g
s
.5 .497 .784 r
.70009 .70631 m .72187 .71093 L .70735 .72426 L p F P
0 g
s
.541 .574 .838 r
.67084 .65878 m .65129 .65859 L .64437 .64476 L p F P
0 g
s
.703 .18 0 r
.18397 .94619 m .17237 .94209 L .1611 .93195 L p F P
0 g
s
.687 .15 0 r
.1471 .92694 m .1611 .93195 L .17237 .94209 L p F P
0 g
s
.784 .331 .169 r
.1611 .93195 m .1471 .92694 L .14432 .92316 L p F P
0 g
s
.519 .798 .996 r
.33689 .97619 m .36303 .9723 L .37088 .97695 L p F P
0 g
s
.597 .783 .969 r
.36303 .9723 m .33689 .97619 L .32888 .97208 L p F P
0 g
s
.776 .807 .878 r
.63665 .32456 m .61779 .33751 L .61101 .32977 L p F P
0 g
s
.935 .828 .714 r
.75001 .18007 m .75489 .19002 L .76223 .17596 L p F P
0 g
s
.935 .828 .714 r
.76223 .17596 m .75736 .16598 L .75001 .18007 L p F P
0 g
s
.61 .667 .88 r
.52732 .59673 m .55441 .59112 L .56151 .60198 L p F P
0 g
s
.612 .675 .886 r
.55441 .59112 m .52732 .59673 L .52014 .58635 L p F P
0 g
s
.697 .758 .899 r
.53501 .36109 m .52286 .36654 L .51567 .35781 L p F P
0 g
s
.305 0 0 r
.22738 .96007 m .24189 .96277 L .2585 .96691 L p F P
0 g
s
0 .487 .735 r
.24189 .96277 m .22738 .96007 L .21874 .95806 L p F P
0 g
s
.073 0 0 r
.64301 .93147 m .66153 .92417 L p .63106 .94151 L F P
0 g
s
.269 0 .14 r
.64301 .93147 m .66153 .92417 L .66333 .91974 L closepath p F P
0 g
s
.362 .184 .5 r
.72964 .84626 m .71404 .8558 L .71443 .86876 L p F P
0 g
s
.401 .252 .562 r
.71404 .8558 m .72964 .84626 L .72599 .83378 L p F P
0 g
s
.759 .777 .868 r
.23001 .60862 m .22064 .61476 L .21227 .60683 L p F P
0 g
s
.657 .85 .974 r
.45181 .58748 m .46476 .58273 L .45339 .5885 L closepath p F P
0 g
s
0 0 0 r
.45181 .58748 m .46476 .58273 L p .46229 .58384 L F P
0 g
s
.598 .832 .988 r
.44452 .59001 m .45339 .5885 L .45181 .58748 L p F P
0 g
s
0 0 0 r
.44454 .59184 m .45181 .58748 L p .46229 .58384 L F P
0 g
s
.598 .832 .988 r
.45181 .58748 m .43893 .59096 L .44452 .59001 L p F P
0 g
s
.327 0 0 r
.43893 .59096 m .45181 .58748 L .44454 .59184 L p F P
0 g
s
0 0 0 r
.60249 .95202 m .60529 .95004 L .63106 .94151 L p F P
0 g
s
.878 .566 .455 r
.1114 .89271 m .09929 .88699 L .098 .87438 L p F P
0 g
s
.887 .572 .446 r
.09022 .87043 m .098 .87438 L .09929 .88699 L p F P
0 g
s
.857 .769 .764 r
.08401 .74151 m .08651 .73821 L .07763 .73063 L p F P
0 g
s
.983 .763 .53 r
.75533 .12022 m .76134 .13001 L .76337 .11804 L p F P
0 g
s
.983 .763 .53 r
.76337 .11804 m .75738 .10824 L .75533 .12022 L p F P
0 g
s
.891 .622 .525 r
.09022 .87043 m .08641 .86844 L .08719 .8553 L p F P
0 g
s
.9 .631 .521 r
.07617 .84911 m .08719 .8553 L .08641 .86844 L p F P
0 g
s
.894 .659 .575 r
.08719 .8553 m .07617 .84911 L .07861 .83556 L p F P
0 g
s
.634 .729 .916 r
.51291 .57686 m .51687 .58198 L .50419 .59057 L p F P
0 g
s
.634 .729 .916 r
.48597 .58493 m .51291 .57686 L p .50419 .59057 L F P
0 g
s
.631 .704 .898 r
.52014 .58635 m .50419 .59057 L .51687 .58198 L closepath p F P
0 g
s
.557 .805 .991 r
.37088 .97695 m .39723 .97199 L .40492 .97687 L p F P
0 g
s
.621 .779 .957 r
.39723 .97199 m .37088 .97695 L .36303 .9723 L p F P
0 g
s
.378 .836 .91 r
.54051 .96764 m .54131 .96771 L .56844 .96138 L p F P
0 g
s
.311 .047 .342 r
.69025 .89635 m .69432 .89105 L .69076 .89288 L closepath p F P
0 g
s
.888 .737 .689 r
.06496 .77248 m .07466 .77936 L .06747 .79418 L p F P
0 g
s
.877 .746 .714 r
.07466 .77936 m .06496 .77248 L .07368 .75722 L p F P
0 g
s
.871 .763 .74 r
.07483 .73433 m .08401 .74151 L .07368 .75722 L p F P
0 g
s
.857 .769 .764 r
.07763 .73063 m .07483 .73433 L .08401 .74151 L p F P
0 g
s
.861 .498 .361 r
.12752 .91029 m .115 .90475 L .1114 .89271 L p F P
0 g
s
.869 .501 .349 r
.09929 .88699 m .1114 .89271 L .115 .90475 L p F P
0 g
s
.596 .781 .969 r
.34844 .58773 m .32817 .58533 L .31552 .58832 L p F P
0 g
s
.609 .74 .939 r
.32817 .58533 m .31552 .58832 L .30751 .58034 L p F P
0 g
s
.973 .8 .608 r
.76298 .15258 m .76435 .14798 L .75826 .14032 L p F P
0 g
s
.876 .835 .803 r
.72052 .23691 m .73418 .22045 L .73841 .23049 L p F P
0 g
s
.876 .835 .803 r
.72324 .2434 m .72052 .23691 L p .73841 .23049 L F P
0 g
s
.876 .835 .803 r
.73841 .23049 m .72546 .24602 L .72324 .2434 L p F P
0 g
s
.891 .715 .657 r
.07203 .8152 m .074 .81015 L .06545 .79939 L p F P
0 g
s
.759 .777 .868 r
.21227 .60683 m .22117 .601 L .23001 .60862 L p F P
0 g
s
.748 .776 .876 r
.23864 .59031 m .22117 .601 L .23001 .60862 L p F P
0 g
s
.748 .776 .876 r
.23001 .60862 m .24692 .59829 L .23864 .59031 L p F P
0 g
s
.445 .375 .684 r
.72931 .7977 m .72916 .7971 L .72966 .79744 L closepath p F P
0 g
s
.493 .493 .785 r
.72187 .71093 m .70009 .70631 L .69869 .70273 L p F P
0 g
s
0 .542 .806 r
.26094 .96731 m .2585 .96691 L .26327 .968 L closepath p F P
0 g
s
.566 .814 .991 r
.40492 .97687 m .43145 .97144 L .43901 .97616 L p F P
0 g
s
.625 .78 .956 r
.43145 .97144 m .40492 .97687 L .39723 .97199 L p F P
0 g
s
.903 .668 .574 r
.06802 .82916 m .07861 .83556 L .07617 .84911 L p F P
0 g
s
.893 .688 .618 r
.07203 .8152 m .06802 .82916 L .07861 .83556 L p F P
0 g
s
.418 .328 .647 r
.72966 .79744 m .72931 .7977 L .73244 .81341 L p F P
0 g
s
.791 .814 .87 r
.63665 .32456 m .64482 .31848 L .63815 .31075 L p F P
0 g
s
.791 .814 .87 r
.63815 .31075 m .63308 .31454 L .63665 .32456 L p F P
0 g
s
.776 .807 .878 r
.61101 .32977 m .63308 .31454 L .63665 .32456 L p F P
0 g
s
.418 .328 .647 r
.73244 .81341 m .73984 .808 L .72966 .79744 L p F P
0 g
s
.413 .329 .652 r
.74753 .78374 m .72966 .79744 L .73984 .808 L p F P
0 g
s
.447 .375 .683 r
.73414 .77413 m .74753 .78374 L .72966 .79744 L p F P
0 g
s
.443 .859 .956 r
.53423 .96642 m .54051 .96764 L .56835 .96137 L p F P
0 g
s
.378 .836 .91 r
.56844 .96138 m .56835 .96137 L .54051 .96764 L p F P
0 g
s
.361 .822 .919 r
.54051 .96764 m .53423 .96642 L .50723 .97218 L p F P
0 g
s
.691 .764 .907 r
.29568 .58545 m .28133 .59183 L .2732 .58359 L p F P
0 g
s
.732 .768 .881 r
.24692 .59829 m .2732 .58359 L .28133 .59183 L p F P
0 g
s
.493 .493 .785 r
.69869 .70273 m .70942 .69218 L p .72187 .71093 L F P
0 g
s
.504 .519 .806 r
.69869 .70273 m .69313 .68977 L .70942 .69218 L closepath p F P
0 g
s
.556 .849 .998 r
.53423 .96642 m .50723 .97218 L .49997 .96917 L p F P
0 g
s
.509 .847 .996 r
.47312 .97473 m .49997 .96917 L .50723 .97218 L p F P
0 g
s
.787 .328 .151 r
.1471 .92694 m .13832 .92362 L .14432 .92316 L closepath p F P
0 g
s
.552 .829 .997 r
.43901 .97616 m .4657 .97062 L .47312 .97473 L p F P
0 g
s
.618 .792 .965 r
.4657 .97062 m .43901 .97616 L .43145 .97144 L p F P
0 g
s
.423 .718 .986 r
.35026 .58857 m .34844 .58773 L .34953 .58858 L closepath p F P
0 g
s
.598 .815 .983 r
.49997 .96917 m .47312 .97473 L .4657 .97062 L p F P
0 g
s
.796 .814 .866 r
.66517 .30287 m .64482 .31848 L .63815 .31075 L p F P
0 g
s
.57 .626 .868 r
.61878 .61991 m .60288 .6214 L .59589 .60952 L p F P
0 g
s
.827 .403 .233 r
.13832 .92362 m .13373 .92171 L .12752 .91029 L p F P
0 g
s
.831 .399 .21 r
.115 .90475 m .12752 .91029 L .13373 .92171 L p F P
0 g
s
.644 .802 .959 r
.47861 .57792 m .46476 .58273 L .45339 .5885 L p F P
0 g
s
.644 .802 .959 r
.48597 .58493 m .47861 .57792 L p .45339 .5885 L F P
0 g
s
.147 .644 .912 r
.2585 .96691 m .26094 .96731 L .25253 .96384 L p F P
0 g
s
.147 .644 .912 r
.25253 .96384 m .24189 .96277 L .2585 .96691 L p F P
0 g
s
.697 .762 .902 r
.53501 .36109 m .54985 .35427 L .54274 .34584 L p F P
0 g
s
.697 .762 .902 r
.54274 .34584 m .52957 .35173 L .53501 .36109 L p F P
0 g
s
.697 .758 .899 r
.51567 .35781 m .52957 .35173 L .53501 .36109 L p F P
0 g
s
.255 0 .294 r
.69432 .89105 m .71381 .88075 L p .68889 .90377 L F P
0 g
s
.255 0 .294 r
.68889 .90377 m .69025 .89635 L .69432 .89105 L p F P
0 g
s
.355 .13 .428 r
.69432 .89105 m .71381 .88075 L .71443 .86876 L p F P
0 g
s
.182 0 .102 r
.66153 .92417 m .66333 .91974 L .67748 .90899 L p F P
0 g
s
.973 .8 .608 r
.75826 .14032 m .75755 .14269 L .76298 .15258 L p F P
0 g
s
.95 .811 .671 r
.7519 .15612 m .75736 .16598 L .76298 .15258 L p F P
0 g
s
.95 .811 .671 r
.76298 .15258 m .75755 .14269 L .7519 .15612 L p F P
0 g
s
.903 .699 .617 r
.06187 .80858 m .07203 .8152 L .06802 .82916 L p F P
0 g
s
.891 .715 .657 r
.06545 .79939 m .06187 .80858 L .07203 .8152 L p F P
0 g
s
.552 .583 .839 r
.64437 .64476 m .64274 .6448 L .64386 .64376 L closepath p F P
0 g
s
.566 .602 .848 r
.63745 .63192 m .64386 .64376 L .64274 .6448 L p F P
0 g
s
.541 0 0 r
.18665 .94698 m .18397 .94619 L .18552 .94636 L closepath p F P
0 g
s
.875 .835 .804 r
.72546 .24602 m .7247 .24693 L .72324 .2434 L closepath p F P
0 g
s
.592 .659 .884 r
.58277 .59856 m .56151 .60198 L .55441 .59112 L p F P
0 g
s
.851 .828 .824 r
.70407 .25439 m .70821 .26438 L .7247 .24693 L p F P
0 g
s
.851 .828 .824 r
.71915 .23837 m .70407 .25439 L p .7247 .24693 L F P
0 g
s
.851 .828 .824 r
.7247 .24693 m .72324 .2434 L .71915 .23837 L p F P
0 g
s
.709 .229 .107 r
.34153 .58362 m .34844 .58773 L p .36688 .59551 L F P
0 g
s
.479 .789 .999 r
.34153 .58362 m .32817 .58533 L .34844 .58773 L closepath p F P
0 g
s
.913 .827 .748 r
.74077 .19489 m .74566 .20481 L .75489 .19002 L p F P
0 g
s
.913 .827 .748 r
.75489 .19002 m .75001 .18007 L .74077 .19489 L p F P
0 g
s
.393 .247 .562 r
.73471 .82824 m .72599 .83378 L .72964 .84626 L p F P
0 g
s
.425 .304 .611 r
.72599 .83378 m .73471 .82824 L .73244 .81341 L p F P
0 g
s
.753 .791 .884 r
.59723 .33883 m .58391 .34702 L .57696 .33888 L p F P
0 g
s
.739 .788 .892 r
.54985 .35427 m .57696 .33888 L .58391 .34702 L p F P
0 g
s
.33 .044 .319 r
.67748 .90899 m .68889 .90377 L .69025 .89635 L closepath p F P
0 g
s
.541 .574 .838 r
.64437 .64476 m .67237 .64529 L p .67084 .65878 L F P
0 g
s
.53 .571 .841 r
.66546 .63183 m .67237 .64529 L .64437 .64476 L p F P
0 g
s
.53 .571 .841 r
.65461 .63154 m .66546 .63183 L p .64437 .64476 L F P
0 g
s
.53 .571 .841 r
.64437 .64476 m .64386 .64376 L .65461 .63154 L p F P
0 g
s
.263 0 0 r
.21279 .95598 m .20819 .9545 L .18665 .94698 L p F P
0 g
s
0 .454 .768 r
.19645 .95047 m .18397 .94619 L .19773 .95084 L F
.17661 .94474 m .18397 .94619 L p .20819 .9545 L F P
0 g
s
.563 0 0 r
.17661 .94474 m .17237 .94209 L .18397 .94619 L closepath p F P
0 g
s
.491 0 0 r
.17237 .94209 m .17661 .94474 L .1677 .94203 L p F P
0 g
s
0 .414 .703 r
.19397 .94957 m .18246 .94637 L p .1677 .94203 L F P
0 g
s
0 .414 .703 r
.18246 .94637 m .17661 .94474 L .16854 .94229 L p F P
0 g
s
0 .414 .703 r
.16854 .94229 m .1677 .94203 L p .18246 .94637 L F P
0 g
s
0 .454 .768 r
.18397 .94619 m .18665 .94698 L .19773 .95084 L p F P
0 g
s
0 .454 .768 r
.19773 .95084 m .20819 .9545 L p .19645 .95047 L F P
0 g
s
.155 .667 .898 r
.29483 .97072 m .28662 .96624 L .26094 .96731 L p F P
0 g
s
.512 .772 .99 r
.28662 .96624 m .26094 .96731 L .25253 .96384 L p F P
0 g
s
.813 .82 .855 r
.66517 .30287 m .67184 .29727 L .66528 .28955 L p F P
0 g
s
.813 .82 .855 r
.66528 .28955 m .66132 .29288 L .66517 .30287 L p F P
0 g
s
.796 .814 .866 r
.63815 .31075 m .66132 .29288 L .66517 .30287 L p F P
0 g
s
.182 0 .102 r
.67748 .90899 m .68889 .90377 L p .66153 .92417 L F P
0 g
s
.546 .596 .855 r
.64386 .64376 m .63745 .63192 L .65461 .63154 L closepath p F P
0 g
s
.664 .749 .913 r
.51291 .57686 m .48597 .58493 L .47861 .57792 L p F P
0 g
s
.734 .774 .886 r
.2732 .58359 m .24692 .59829 L .23864 .59031 L p F P
0 g
s
.883 .756 .717 r
.06445 .75009 m .07368 .75722 L .06496 .77248 L p F P
0 g
s
.871 .763 .74 r
.07368 .75722 m .06445 .75009 L .07483 .73433 L p F P
0 g
s
.816 .82 .853 r
.68859 .28295 m .67184 .29727 L .66528 .28955 L p F P
0 g
s
.504 .52 .806 r
.70942 .69218 m .69313 .68977 L .68856 .67915 L p F P
0 g
s
.835 .824 .838 r
.69232 .26563 m .70407 .25439 L .70821 .26438 L p F P
0 g
s
.835 .824 .838 r
.70821 .26438 m .69876 .27337 L .69232 .26563 L p F P
0 g
s
.835 .825 .839 r
.68859 .28295 m .69876 .27337 L .69232 .26563 L p F P
0 g
s
.57 .71 .936 r
.50842 .349 m .50276 .34982 L .50942 .35881 L p F P
0 g
s
.57 .71 .936 r
.50942 .35881 m .51567 .35781 L .50842 .349 L p F P
0 g
s
.887 .572 .446 r
.08676 .87325 m .09022 .87043 L p .09929 .88699 L F P
0 g
s
.892 .586 .461 r
.08676 .87325 m .08641 .86844 L .09022 .87043 L closepath p F P
0 g
s
.835 .825 .839 r
.69232 .26563 m .68456 .27298 L .68859 .28295 L p F P
0 g
s
.816 .82 .853 r
.66528 .28955 m .68456 .27298 L .68859 .28295 L p F P
0 g
s
.389 .279 .606 r
.73984 .808 m .73244 .81341 L .73471 .82824 L p F P
0 g
s
.687 .15 0 r
.17237 .94209 m .15871 .93699 L .1471 .92694 L p F P
0 g
s
.658 .105 0 r
.13832 .92362 m .1471 .92694 L .15871 .93699 L p F P
0 g
s
.9 .724 .655 r
.06747 .79418 m .06545 .79939 L .05668 .79003 L p F P
0 g
s
.9 .724 .655 r
.05668 .79003 m .05773 .78734 L .06747 .79418 L p F P
0 g
s
.888 .737 .689 r
.06747 .79418 m .05773 .78734 L .06496 .77248 L p F P
0 g
s
.693 .769 .91 r
.29944 .57241 m .28593 .57811 L .29568 .58545 L p F P
0 g
s
.693 .769 .91 r
.29568 .58545 m .30751 .58034 L .29944 .57241 L p F P
0 g
s
.691 .764 .907 r
.2732 .58359 m .28593 .57811 L .29568 .58545 L p F P
0 g
s
.174 .563 .934 r
.3155 .57897 m .33221 .58007 L p .32516 .57659 L F P
0 g
s
.174 .563 .934 r
.33221 .58007 m .33338 .58015 L .32516 .57659 L p F P
0 g
s
.174 .563 .934 r
.32516 .57659 m .30545 .57169 L .3155 .57897 L p F P
0 g
s
.109 .52 .911 r
.30545 .57169 m .32516 .57659 L .32098 .57344 L p F P
0 g
s
.888 .459 .111 r
.32516 .57659 m .3255 .57742 L .32376 .5759 L p F P
0 g
s
.888 .459 .111 r
.32376 .5759 m .32098 .57344 L .32516 .57659 L p F P
0 g
s
.831 .358 .037 r
.33338 .58015 m .32516 .57659 L p .3253 .57669 L F P
0 g
s
.339 .681 .979 r
.32817 .58533 m .34149 .58362 L p .33338 .58015 L F P
0 g
s
.339 .681 .979 r
.33338 .58015 m .3155 .57897 L .32817 .58533 L p F P
0 g
s
.831 .358 .037 r
.33599 .58459 m .33338 .58015 L p .3253 .57669 L F P
0 g
s
.339 .681 .979 r
.34149 .58362 m .34153 .58362 L .33338 .58015 L p F P
0 g
s
.609 .74 .939 r
.30751 .58034 m .3155 .57897 L .32817 .58533 L p F P
0 g
s
.766 .797 .878 r
.59723 .33883 m .61101 .32977 L .60416 .32165 L p F P
0 g
s
.766 .797 .878 r
.60416 .32165 m .59291 .32906 L .59723 .33883 L p F P
0 g
s
.753 .791 .884 r
.57696 .33888 m .59291 .32906 L .59723 .33883 L p F P
0 g
s
0 0 0 r
.63106 .94151 m .62987 .94247 L .60249 .95202 L p F P
0 g
s
0 0 0 r
.62987 .94247 m .64267 .93702 L .63106 .94151 L closepath p F P
0 g
s
0 0 0 r
.62987 .94247 m .62493 .94419 L p .62621 .94369 L F P
0 g
s
0 0 0 r
.60249 .95202 m .59579 .95385 L p .62621 .94369 L F P
0 g
s
0 0 0 r
.62493 .94419 m .60249 .95202 L p .62621 .94369 L F P
0 g
s
0 0 0 r
.59579 .95385 m .62333 .94498 L .62987 .94247 L p F P
0 g
s
0 0 0 r
.64267 .93702 m .62987 .94247 L .62333 .94498 L p F P
0 g
s
0 0 0 r
.65589 .93172 m .64267 .93702 L p .63172 .94153 L F P
0 g
s
0 0 0 r
.62333 .94498 m .63393 .94066 L .63172 .94153 L F
.63393 .94066 m .65589 .93172 L .63172 .94153 L F
.19 .712 .684 r
.56844 .96138 m .59579 .95385 L .60249 .95202 L p F P
0 g
s
.612 .675 .886 r
.52014 .58635 m .54728 .58051 L .55441 .59112 L p F P
0 g
s
.619 .699 .902 r
.5401 .57024 m .54728 .58051 L .52014 .58635 L p F P
0 g
s
.619 .699 .902 r
.52502 .57382 m .5401 .57024 L p .52014 .58635 L F P
0 g
s
.619 .699 .902 r
.52014 .58635 m .51687 .58198 L .52502 .57382 L p F P
0 g
s
.965 .786 .612 r
.75201 .13131 m .75533 .12022 L .76134 .13001 L p F P
0 g
s
.965 .786 .612 r
.76134 .13001 m .75826 .14032 L .75201 .13131 L p F P
0 g
s
.587 .103 .074 r
.39129 .59802 m .37978 .59713 L .38342 .59414 L closepath p F P
0 g
s
.894 .836 .781 r
.74601 .20565 m .7455 .20503 L .74566 .20481 L closepath p F P
0 g
s
.854 .828 .821 r
.72324 .2434 m .71915 .23837 L .72052 .23691 L closepath p F P
0 g
s
.737 .78 .887 r
.57696 .33888 m .54985 .35427 L .54274 .34584 L p F P
0 g
s
.43 .368 .687 r
.74564 .76482 m .73414 .77413 L .74753 .78374 L p F P
0 g
s
.459 .405 .71 r
.7433 .75677 m .74564 .76482 L .73414 .77413 L p F P
0 g
s
.459 .405 .71 r
.73427 .75193 m .7433 .75677 L p .73414 .77413 L F P
0 g
s
.539 .784 .989 r
.29483 .97072 m .32086 .96673 L .32888 .97208 L p F P
0 g
s
.604 .774 .962 r
.32086 .96673 m .29483 .97072 L .28662 .96624 L p F P
0 g
s
.504 .52 .806 r
.68856 .67915 m .69279 .67467 L p .70942 .69218 L F P
0 g
s
.515 .545 .825 r
.68856 .67915 m .68619 .67406 L .69279 .67467 L closepath p F P
0 g
s
.309 .094 .416 r
.72885 .86001 m .71443 .86876 L .71381 .88075 L p F P
0 g
s
.362 .184 .5 r
.71443 .86876 m .72885 .86001 L .72964 .84626 L p F P
0 g
s
.889 .825 .778 r
.73925 .19695 m .74077 .19489 L .74566 .20481 L p F P
0 g
s
.889 .825 .778 r
.74566 .20481 m .7455 .20503 L .73925 .19695 L p F P
0 g
s
.891 .826 .777 r
.73418 .22045 m .7455 .20503 L .73925 .19695 L p F P
0 g
s
.901 .591 .45 r
.08641 .86844 m .08676 .87325 L .07952 .87676 L p F P
0 g
s
.901 .591 .45 r
.07537 .86227 m .08641 .86844 L p .07952 .87676 L F P
0 g
s
.9 .631 .521 r
.08641 .86844 m .07537 .86227 L .07617 .84911 L p F P
0 g
s
.899 .725 .657 r
.06187 .80858 m .06545 .79939 L .05668 .79003 L p F P
0 g
s
.327 0 0 r
.44454 .59184 m .44062 .59257 L .41755 .59461 L p F P
0 g
s
.403 0 .115 r
.44062 .59257 m .41546 .59792 L .41755 .59461 L closepath p F P
0 g
s
.693 .756 .9 r
.52957 .35173 m .51567 .35781 L .50842 .349 L p F P
0 g
s
.909 .639 .518 r
.06556 .84274 m .07617 .84911 L .07537 .86227 L p F P
0 g
s
.903 .668 .574 r
.07617 .84911 m .06556 .84274 L .06802 .82916 L p F P
0 g
s
.928 .814 .713 r
.74452 .17024 m .75001 .18007 L .75736 .16598 L p F P
0 g
s
.928 .814 .713 r
.75736 .16598 m .7519 .15612 L .74452 .17024 L p F P
0 g
s
.869 .501 .349 r
.115 .90475 m .10288 .89905 L .09929 .88699 L p F P
0 g
s
.876 .505 .337 r
.08758 .8811 m .09929 .88699 L .10288 .89905 L p F P
0 g
s
.887 .572 .446 r
.09929 .88699 m .08758 .8811 L .08676 .87325 L p F P
0 g
s
.774 .799 .873 r
.63308 .31454 m .61101 .32977 L .60416 .32165 L p F P
0 g
s
.264 .705 .961 r
.24189 .96277 m .25253 .96384 L .2441 .95942 L p F P
0 g
s
.264 .705 .961 r
.2441 .95942 m .22486 .95871 L .24189 .96277 L p F P
0 g
s
0 .487 .735 r
.21874 .95806 m .22486 .95871 L .24189 .96277 L p F P
0 g
s
.57 .626 .868 r
.59589 .60952 m .62354 .607 L p .61878 .61991 L F P
0 g
s
.563 .631 .876 r
.62354 .607 m .59589 .60952 L .58886 .59776 L p F P
0 g
s
.514 .546 .827 r
.69279 .67467 m .68619 .67406 L .67928 .65932 L p F P
0 g
s
.597 .783 .969 r
.32888 .97208 m .35516 .96629 L .36303 .9723 L p F P
0 g
s
.642 .762 .936 r
.35516 .96629 m .32888 .97208 L .32086 .96673 L p F P
0 g
s
.523 .553 .828 r
.67928 .65932 m .67084 .65878 L .67632 .65306 L closepath p F P
0 g
s
.541 .574 .838 r
.67237 .64529 m .67632 .65306 L .67084 .65878 L p F P
0 g
s
.635 .866 .985 r
.46476 .58273 m .47781 .57746 L .47861 .57792 L closepath p F P
0 g
s
0 0 0 r
.46476 .58273 m .47781 .57746 L p .44454 .59184 L F P
0 g
s
.895 .748 .691 r
.05568 .7654 m .06496 .77248 L .05773 .78734 L p F P
0 g
s
.883 .756 .717 r
.06496 .77248 m .05568 .7654 L .06445 .75009 L p F P
0 g
s
.182 0 .102 r
.68889 .90377 m .68554 .9133 L .66153 .92417 L p F P
0 g
s
.072 0 0 r
.65735 .93036 m .66153 .92417 L .68554 .9133 L p F P
0 g
s
.073 0 0 r
.66153 .92417 m .65735 .93036 L p .63106 .94151 L F P
0 g
s
.911 .678 .572 r
.05783 .82257 m .06802 .82916 L .06556 .84274 L p F P
0 g
s
.903 .699 .617 r
.06802 .82916 m .05783 .82257 L .06187 .80858 L p F P
0 g
s
.571 .73 .95 r
.3155 .57897 m .30751 .58034 L .29944 .57241 L p F P
0 g
s
.545 .599 .858 r
.65461 .63154 m .63745 .63192 L .63051 .61926 L p F P
0 g
s
.625 .71 .907 r
.51687 .58198 m .51291 .57686 L .52502 .57382 L closepath p F P
0 g
s
.557 .608 .86 r
.63051 .61926 m .61878 .61991 L .62626 .61161 L closepath p F P
0 g
s
.57 .626 .868 r
.62354 .607 m .62626 .61161 L .61878 .61991 L p F P
0 g
s
.831 .399 .21 r
.13373 .92171 m .12128 .91616 L .115 .90475 L p F P
0 g
s
.834 .395 .187 r
.10288 .89905 m .115 .90475 L .12128 .91616 L p F P
0 g
s
.621 .779 .957 r
.36303 .9723 m .38951 .96561 L .39723 .97199 L p F P
0 g
s
.656 .752 .92 r
.38951 .96561 m .36303 .9723 L .35516 .96629 L p F P
0 g
s
.658 .105 0 r
.13504 .92336 m .13832 .92362 L p .15871 .93699 L F P
0 g
s
.78 .298 .085 r
.13504 .92336 m .13373 .92171 L .13832 .92362 L closepath p F P
0 g
s
.443 .869 .934 r
.56835 .96137 m .56844 .96138 L .59579 .95385 L p F P
0 g
s
.592 .659 .884 r
.55441 .59112 m .5818 .58665 L p .58277 .59856 L F P
0 g
s
.592 .665 .89 r
.5818 .58665 m .55441 .59112 L .54728 .58051 L p F P
0 g
s
.69 .767 .91 r
.28593 .57811 m .2732 .58359 L .265 .57555 L p F P
0 g
s
.734 .774 .886 r
.23864 .59031 m .265 .57555 L .2732 .58359 L p F P
0 g
s
.492 .879 .967 r
.56147 .95982 m .56835 .96137 L .59502 .95377 L p F P
0 g
s
.443 .869 .934 r
.59579 .95385 m .59502 .95377 L .56835 .96137 L p F P
0 g
s
.443 .859 .956 r
.56835 .96137 m .56147 .95982 L .53423 .96642 L p F P
0 g
s
.11 .627 .889 r
.22486 .95871 m .21279 .95598 L .21874 .95806 L closepath p F P
0 g
s
.891 .826 .777 r
.73925 .19695 m .7293 .21056 L .73418 .22045 L p F P
0 g
s
.871 .822 .797 r
.71563 .22706 m .72052 .23691 L .73418 .22045 L p F P
0 g
s
.871 .822 .797 r
.73418 .22045 m .7293 .21056 L .71563 .22706 L p F P
0 g
s
.353 .219 .555 r
.74665 .8196 m .73471 .82824 L .73611 .84218 L p F P
0 g
s
.389 .279 .606 r
.73471 .82824 m .74665 .8196 L .73984 .808 L p F P
0 g
s
.393 .247 .562 r
.72964 .84626 m .73611 .84218 L .73471 .82824 L p F P
0 g
s
.491 0 0 r
.1677 .94203 m .15871 .93699 L .17237 .94209 L p F P
0 g
s
.625 .78 .956 r
.39723 .97199 m .42386 .96505 L .43145 .97144 L p F P
0 g
s
.657 .748 .917 r
.42386 .96505 m .39723 .97199 L .38951 .96561 L p F P
0 g
s
.896 .579 .44 r
.08758 .8811 m .07952 .87676 L .08676 .87325 L closepath p F P
0 g
s
.443 .402 .717 r
.7433 .75677 m .73427 .75193 L .74037 .7467 L closepath p F P
0 g
s
.467 .44 .745 r
.73593 .73322 m .73016 .73085 L p .73427 .75193 L F P
0 g
s
.467 .44 .745 r
.73427 .75193 m .74037 .7467 L .73593 .73322 L p F P
0 g
s
.965 .786 .611 r
.75755 .14269 m .75826 .14032 L .75201 .13131 L p F P
0 g
s
.176 0 .132 r
.71184 .89176 m .68889 .90377 L .68554 .9133 L p F P
0 g
s
.255 0 .294 r
.71206 .89151 m .71184 .89176 L .68889 .90377 L p F P
0 g
s
.255 0 .294 r
.71381 .88075 m .71206 .89151 L p .68889 .90377 L F P
0 g
s
.789 .804 .865 r
.63308 .31454 m .63815 .31075 L .63141 .30263 L p F P
0 g
s
.789 .804 .865 r
.63141 .30263 m .62856 .30475 L .63308 .31454 L p F P
0 g
s
.774 .799 .873 r
.60416 .32165 m .62856 .30475 L .63308 .31454 L p F P
0 g
s
.911 .709 .617 r
.05211 .80177 m .06187 .80858 L .05783 .82257 L p F P
0 g
s
.899 .725 .657 r
.05668 .79003 m .05211 .80177 L .06187 .80858 L p F P
0 g
s
.618 .792 .965 r
.43145 .97144 m .45824 .96466 L .4657 .97062 L p F P
0 g
s
.65 .753 .925 r
.45824 .96466 m .43145 .97144 L .42386 .96505 L p F P
0 g
s
.073 0 0 r
.65735 .93036 m .64267 .93702 L .63106 .94151 L p F P
0 g
s
.351 .175 .497 r
.73611 .84218 m .72964 .84626 L .72885 .86001 L p F P
0 g
s
.574 .849 .996 r
.56147 .95982 m .53423 .96642 L .52707 .96282 L p F P
0 g
s
.556 .849 .998 r
.49997 .96917 m .52707 .96282 L .53423 .96642 L p F P
0 g
s
.794 .805 .861 r
.66132 .29288 m .63815 .31075 L .63141 .30263 L p F P
0 g
s
.598 .815 .983 r
.4657 .97062 m .49265 .96413 L .49997 .96917 L p F P
0 g
s
.636 .77 .944 r
.49265 .96413 m .4657 .97062 L .45824 .96466 L p F P
0 g
s
.965 .786 .611 r
.75201 .13131 m .75152 .13293 L .75755 .14269 L p F P
0 g
s
.942 .797 .672 r
.74584 .14639 m .7519 .15612 L .75755 .14269 L p F P
0 g
s
.942 .797 .672 r
.75755 .14269 m .75152 .13293 L .74584 .14639 L p F P
0 g
s
.381 .276 .609 r
.75326 .79781 m .73984 .808 L .74665 .8196 L p F P
0 g
s
.413 .329 .652 r
.75112 .78761 m .74753 .78374 L p .73984 .808 L F P
0 g
s
.413 .329 .652 r
.73984 .808 m .75326 .79781 L .75112 .78761 L p F P
0 g
s
.695 .759 .901 r
.52957 .35173 m .54274 .34584 L .53558 .33709 L p F P
0 g
s
.695 .759 .901 r
.53558 .33709 m .52296 .34268 L .52957 .35173 L p F P
0 g
s
.693 .756 .9 r
.50842 .349 m .52296 .34268 L .52957 .35173 L p F P
0 g
s
.615 .803 .972 r
.52707 .96282 m .49997 .96917 L .49265 .96413 L p F P
0 g
s
.504 .52 .806 r
.69279 .67467 m .71473 .67823 L p .70942 .69218 L F P
0 g
s
.489 .515 .811 r
.69279 .67467 m .71473 .67823 L .70778 .66257 L p F P
0 g
s
.489 .515 .811 r
.70778 .66257 m .70392 .66189 L .69279 .67467 L p F P
0 g
s
.514 .546 .827 r
.67928 .65932 m .70392 .66189 L .69279 .67467 L p F P
0 g
s
.582 .641 .875 r
.58886 .59776 m .58277 .59856 L .58679 .59438 L closepath p F P
0 g
s
.592 .659 .884 r
.5818 .58665 m .58679 .59438 L .58277 .59856 L p F P
0 g
s
.709 .229 .107 r
.36688 .59551 m .3491 .59083 L .34153 .58362 L p F P
0 g
s
.661 .11 0 r
.3491 .59083 m .34153 .58362 L .33338 .58015 L p F P
0 g
s
.766 .267 .025 r
.13373 .92171 m .13504 .92336 L .12583 .92159 L p F P
0 g
s
.766 .267 .025 r
.12583 .92159 m .12128 .91616 L .13373 .92171 L p F P
0 g
s
.907 .815 .745 r
.73525 .1851 m .74077 .19489 L .75001 .18007 L p F P
0 g
s
.907 .815 .745 r
.75001 .18007 m .74452 .17024 L .73525 .1851 L p F P
0 g
s
.752 .784 .879 r
.59291 .32906 m .57696 .33888 L .56995 .3304 L p F P
0 g
s
.737 .78 .887 r
.54274 .34584 m .56995 .3304 L .57696 .33888 L p F P
0 g
s
.85 .818 .817 r
.71275 .23012 m .71563 .22706 L .72052 .23691 L p F P
0 g
s
.85 .818 .817 r
.72052 .23691 m .71915 .23837 L .71275 .23012 L p F P
0 g
s
.851 .819 .817 r
.70407 .25439 m .71915 .23837 L .71275 .23012 L p F P
0 g
s
.675 .383 .47 r
.39129 .59802 m .41546 .59792 L .41389 .60912 L p F P
0 g
s
.675 .383 .47 r
.41389 .60912 m .39523 .60918 L .39129 .59802 L p F P
0 g
s
.709 .402 .455 r
.37978 .59713 m .39129 .59802 L .39523 .60918 L p F P
0 g
s
.571 .73 .95 r
.29944 .57241 m .30545 .57169 L .3155 .57897 L p F P
0 g
s
.558 .279 .448 r
.41389 .60912 m .41546 .59792 L .44062 .59257 L p F P
0 g
s
.508 .545 .829 r
.70392 .66189 m .67928 .65932 L .67632 .65306 L p F P
0 g
s
.456 .433 .745 r
.73593 .73322 m .73016 .73085 L .734 .72734 L closepath p F P
0 g
s
.479 .47 .77 r
.72877 .71306 m .72187 .71093 L p .73016 .73085 L F P
0 g
s
.479 .47 .77 r
.73016 .73085 m .734 .72734 L .72877 .71306 L p F P
0 g
s
.664 .749 .913 r
.47861 .57792 m .50563 .56843 L .51291 .57686 L p F P
0 g
s
.638 .866 .985 r
.47781 .57746 m .47861 .57792 L .50563 .56843 L p F P
0 g
s
.811 .81 .85 r
.66132 .29288 m .66528 .28955 L .65865 .28139 L p F P
0 g
s
.811 .81 .85 r
.65865 .28139 m .65663 .28309 L .66132 .29288 L p F P
0 g
s
.794 .805 .861 r
.63141 .30263 m .65663 .28309 L .66132 .29288 L p F P
0 g
s
.198 .676 .934 r
.22486 .95871 m .2441 .95942 L p .21008 .95491 L F P
0 g
s
.198 .676 .934 r
.21008 .95491 m .21279 .95598 L .22486 .95871 L p F P
0 g
s
.709 .402 .455 r
.39523 .60918 m .37763 .6079 L .37978 .59713 L p F P
0 g
s
.739 .427 .454 r
.36688 .59551 m .37978 .59713 L .37763 .6079 L p F P
0 g
s
.69 .767 .91 r
.265 .57555 m .27718 .57035 L .28593 .57811 L p F P
0 g
s
.688 .768 .912 r
.2913 .56445 m .27718 .57035 L .28593 .57811 L p F P
0 g
s
.688 .768 .912 r
.28593 .57811 m .29944 .57241 L .2913 .56445 L p F P
0 g
s
.813 .81 .847 r
.68456 .27298 m .66528 .28955 L .65865 .28139 L p F P
0 g
s
.622 .734 .927 r
.52502 .57382 m .51291 .57686 L .50563 .56843 L p F P
0 g
s
.908 .735 .656 r
.05773 .78734 m .05668 .79003 L .04769 .78213 L p F P
0 g
s
.908 .735 .656 r
.04769 .78213 m .0484 .7803 L .05773 .78734 L p F P
0 g
s
.895 .748 .691 r
.05773 .78734 m .0484 .7803 L .05568 .7654 L p F P
0 g
s
.493 .493 .785 r
.70942 .69218 m .72172 .695 L p .72187 .71093 L F P
0 g
s
.481 .494 .794 r
.72172 .695 m .70942 .69218 L .71724 .68392 L closepath p F P
0 g
s
.504 .52 .806 r
.71473 .67823 m .71724 .68392 L .70942 .69218 L p F P
0 g
s
.658 .105 0 r
.15871 .93699 m .14536 .93174 L .13504 .92336 L p F P
0 g
s
.659 .107 0 r
.14536 .93174 m .13504 .92336 L .12583 .92159 L p F P
0 g
s
.851 .819 .817 r
.71275 .23012 m .69921 .24457 L .70407 .25439 L p F P
0 g
s
.832 .814 .833 r
.6858 .25743 m .69921 .24457 L .70407 .25439 L p F P
0 g
s
.832 .814 .833 r
.70407 .25439 m .69232 .26563 L .6858 .25743 L p F P
0 g
s
0 .454 .768 r
.20819 .9545 m .19397 .94957 L .17661 .94474 L p F P
0 g
s
.469 .464 .77 r
.72877 .71306 m .72187 .71093 L .72637 .70652 L closepath p F P
0 g
s
.493 .493 .785 r
.72172 .695 m .72637 .70652 L .72187 .71093 L p F P
0 g
s
.512 .772 .99 r
.25253 .96384 m .27838 .96077 L .28662 .96624 L p F P
0 g
s
.578 .771 .971 r
.27838 .96077 m .25253 .96384 L .2441 .95942 L p F P
0 g
s
.831 .815 .834 r
.68456 .27298 m .69232 .26563 L .6858 .25743 L p F P
0 g
s
.831 .815 .834 r
.6858 .25743 m .67976 .26318 L .68456 .27298 L p F P
0 g
s
.813 .81 .847 r
.65865 .28139 m .67976 .26318 L .68456 .27298 L p F P
0 g
s
.677 .972 .911 r
.47115 .5775 m .49651 .56226 L .47781 .57746 L closepath p F P
0 g
s
.125 0 0 r
.47115 .5775 m .49651 .56226 L p .48696 .56874 L F P
0 g
s
0 0 0 r
.47781 .57746 m .47115 .5775 L p .44785 .59041 L F P
0 g
s
.125 0 0 r
.46917 .5808 m .47115 .5775 L p .48696 .56874 L F P
0 g
s
0 0 0 r
.44454 .59184 m .44785 .59041 L .47115 .5775 L F
.638 .866 .985 r
.49829 .56146 m .49651 .56226 L .47781 .57746 L p F P
0 g
s
.638 .866 .985 r
.50563 .56843 m .49829 .56146 L p .47781 .57746 L F P
0 g
s
.563 .631 .876 r
.58886 .59776 m .61656 .59537 L .62354 .607 L p F P
0 g
s
.56 .631 .878 r
.60954 .58389 m .61656 .59537 L .58886 .59776 L p F P
0 g
s
.56 .631 .878 r
.59314 .58529 m .60954 .58389 L p .58886 .59776 L F P
0 g
s
.56 .631 .878 r
.58886 .59776 m .58679 .59438 L .59314 .58529 L p F P
0 g
s
.907 .735 .657 r
.05211 .80177 m .05668 .79003 L .04769 .78213 L p F P
0 g
s
.508 .545 .829 r
.67632 .65306 m .68212 .64582 L p .70392 .66189 L F P
0 g
s
.52 .569 .845 r
.67632 .65306 m .67237 .64529 L .68212 .64582 L closepath p F P
0 g
s
.545 .599 .858 r
.63051 .61926 m .65853 .6188 L p .65461 .63154 L F P
0 g
s
.535 .597 .863 r
.6516 .60647 m .65853 .6188 L .63051 .61926 L p F P
0 g
s
.535 .597 .863 r
.62977 .60667 m .6516 .60647 L p .63051 .61926 L F P
0 g
s
.535 .597 .863 r
.63051 .61926 m .62626 .61161 L .62977 .60667 L p F P
0 g
s
.901 .591 .45 r
.07952 .87676 m .07635 .875 L .07537 .86227 L p F P
0 g
s
.91 .598 .443 r
.06473 .85592 m .07537 .86227 L .07635 .875 L p F P
0 g
s
.909 .639 .518 r
.07537 .86227 m .06473 .85592 L .06556 .84274 L p F P
0 g
s
.763 .789 .874 r
.59291 .32906 m .60416 .32165 L .59724 .31315 L p F P
0 g
s
.763 .789 .874 r
.59724 .31315 m .58751 .31956 L .59291 .32906 L p F P
0 g
s
.752 .784 .879 r
.56995 .3304 m .58751 .31956 L .59291 .32906 L p F P
0 g
s
.739 .427 .454 r
.37763 .6079 m .37012 .60688 L .36688 .59551 L p F P
0 g
s
.782 .469 .458 r
.3491 .59083 m .36688 .59551 L .37012 .60688 L p F P
0 g
s
.876 .505 .337 r
.10288 .89905 m .09115 .89317 L .08758 .8811 L p F P
0 g
s
.884 .507 .321 r
.07952 .87676 m .08758 .8811 L .09115 .89317 L p F P
0 g
s
.736 .773 .883 r
.56995 .3304 m .54274 .34584 L .53558 .33709 L p F P
0 g
s
.918 .649 .514 r
.05533 .83618 m .06556 .84274 L .06473 .85592 L p F P
0 g
s
.911 .678 .572 r
.06556 .84274 m .05533 .83618 L .05783 .82257 L p F P
0 g
s
.232 0 .297 r
.71206 .89151 m .72315 .87513 L .71381 .88075 L closepath p F P
0 g
s
.309 .094 .416 r
.71381 .88075 m .72315 .87513 L .72885 .86001 L p F P
0 g
s
.884 .813 .774 r
.73292 .18828 m .73525 .1851 L .74077 .19489 L p F P
0 g
s
.884 .813 .774 r
.74077 .19489 m .73925 .19695 L .73292 .18828 L p F P
0 g
s
.604 .774 .962 r
.28662 .96624 m .3128 .96031 L .32086 .96673 L p F P
0 g
s
.645 .761 .933 r
.3128 .96031 m .28662 .96624 L .27838 .96077 L p F P
0 g
s
.306 .142 .487 r
.74994 .83225 m .73611 .84218 L .73657 .85518 L p F P
0 g
s
.351 .175 .497 r
.72885 .86001 m .73657 .85518 L .73611 .84218 L p F P
0 g
s
.353 .219 .555 r
.73611 .84218 m .74994 .83225 L .74665 .8196 L p F P
0 g
s
.886 .814 .773 r
.7293 .21056 m .73925 .19695 L .73292 .18828 L p F P
0 g
s
.574 .65 .888 r
.58679 .59438 m .5818 .58665 L .59314 .58529 L closepath p F P
0 g
s
.921 .802 .711 r
.73842 .16055 m .74452 .17024 L .7519 .15612 L p F P
0 g
s
.921 .802 .711 r
.7519 .15612 m .74584 .14639 L .73842 .16055 L p F P
0 g
s
.426 .391 .716 r
.74037 .7467 m .74829 .73894 L p .75 .7608 L F P
0 g
s
.426 .391 .716 r
.75 .7608 m .7433 .75677 L .74037 .7467 L p F P
0 g
s
.439 .423 .745 r
.74037 .7467 m .73593 .73322 L .74829 .73894 L closepath p F P
0 g
s
.834 .395 .187 r
.12128 .91616 m .1092 .91044 L .10288 .89905 L p F P
0 g
s
.837 .391 .162 r
.09115 .89317 m .10288 .89905 L .1092 .91044 L p F P
0 g
s
.592 .665 .89 r
.54728 .58051 m .57472 .57593 L .5818 .58665 L p F P
0 g
s
.594 .673 .895 r
.57472 .57593 m .54728 .58051 L .5401 .57024 L p F P
0 g
s
.44 .423 .744 r
.74829 .73894 m .73593 .73322 L .734 .72734 L p F P
0 g
s
.772 .791 .868 r
.62856 .30475 m .60416 .32165 L .59724 .31315 L p F P
0 g
s
0 0 0 r
.64267 .93702 m .65589 .93172 L .65735 .93036 L closepath p F P
0 g
s
.411 0 0 r
.15871 .93699 m .1677 .94203 L .15877 .9385 L p F P
0 g
s
.411 0 0 r
.15877 .9385 m .14536 .93174 L .15871 .93699 L p F P
0 g
s
.44 .423 .744 r
.734 .72734 m .74285 .71807 L p .74829 .73894 L F P
0 g
s
.453 .455 .77 r
.734 .72734 m .72877 .71306 L .74285 .71807 L closepath p F P
0 g
s
0 .519 .822 r
.21008 .95491 m .20819 .9545 L .21279 .95598 L closepath p F P
0 g
s
.92 .688 .57 r
.04803 .81579 m .05783 .82257 L .05533 .83618 L p F P
0 g
s
.911 .709 .617 r
.05783 .82257 m .04803 .81579 L .05211 .80177 L p F P
0 g
s
.425 .391 .717 r
.74564 .76482 m .7433 .75677 L .75 .7608 L closepath p F P
0 g
s
.642 .762 .936 r
.32086 .96673 m .34727 .95908 L .35516 .96629 L p F P
0 g
s
.671 .743 .905 r
.34727 .95908 m .32086 .96673 L .3128 .96031 L p F P
0 g
s
.54 .718 .955 r
.30545 .57169 m .29944 .57241 L .2913 .56445 L p F P
0 g
s
.528 .579 .85 r
.66546 .63183 m .65461 .63154 L .66108 .6234 L closepath p F P
0 g
s
.545 .599 .858 r
.65853 .6188 m .66108 .6234 L .65461 .63154 L p F P
0 g
s
.397 .347 .685 r
.75 .7608 m .74564 .76482 L .74992 .78183 L p F P
0 g
s
.43 .368 .687 r
.74753 .78374 m .74992 .78183 L .74564 .76482 L p F P
0 g
s
.519 .571 .848 r
.68212 .64582 m .67237 .64529 L .66546 .63183 L p F P
0 g
s
.294 .079 .408 r
.73657 .85518 m .72885 .86001 L .72315 .87513 L p F P
0 g
s
.401 .32 .65 r
.75112 .78761 m .74753 .78374 L .74992 .78183 L closepath p F P
0 g
s
.619 .7 .903 r
.5401 .57024 m .52502 .57382 L .53516 .56355 L closepath p F P
0 g
s
.622 .734 .927 r
.53288 .56057 m .53516 .56355 L .52502 .57382 L p F P
0 g
s
.622 .734 .927 r
.50563 .56843 m .53288 .56057 L p .52502 .57382 L F P
0 g
s
.656 .752 .92 r
.35516 .96629 m .38176 .95786 L .38951 .96561 L p F P
0 g
s
.679 .729 .888 r
.38176 .95786 m .35516 .96629 L .34727 .95908 L p F P
0 g
s
.453 .455 .77 r
.74285 .71807 m .72877 .71306 L .72637 .70652 L p F P
0 g
s
.558 .279 .448 r
.44062 .59257 m .44412 .59408 L p .41389 .60912 L F P
0 g
s
.559 .258 .413 r
.44412 .59408 m .44062 .59257 L .44454 .59184 L closepath p F P
0 g
s
.551 .62 .874 r
.62626 .61161 m .62354 .607 L .62977 .60667 L closepath p F P
0 g
s
.481 .89 .932 r
.59502 .95377 m .59579 .95385 L .62333 .94498 L p F P
0 g
s
.657 .748 .917 r
.38951 .96561 m .41624 .95714 L .42386 .96505 L p F P
0 g
s
.676 .72 .882 r
.41624 .95714 m .38951 .96561 L .38176 .95786 L p F P
0 g
s
.102 .599 .902 r
.20819 .9545 m .21008 .95491 L .20141 .9508 L p F P
0 g
s
.102 .599 .902 r
.20141 .9508 m .19397 .94957 L .20819 .9545 L p F P
0 g
s
.453 .455 .77 r
.72637 .70652 m .73371 .69823 L p .74285 .71807 L F P
0 g
s
.467 .485 .794 r
.72637 .70652 m .72172 .695 L .73371 .69823 L closepath p F P
0 g
s
.886 .814 .773 r
.73292 .18828 m .72377 .20081 L .7293 .21056 L p F P
0 g
s
.866 .811 .793 r
.71008 .21734 m .71563 .22706 L .7293 .21056 L p F P
0 g
s
.866 .811 .793 r
.7293 .21056 m .72377 .20081 L .71008 .21734 L p F P
0 g
s
.919 .72 .617 r
.04275 .79476 m .05211 .80177 L .04803 .81579 L p F P
0 g
s
.907 .735 .657 r
.04769 .78213 m .04275 .79476 L .05211 .80177 L p F P
0 g
s
.749 .234 0 r
.12128 .91616 m .12583 .92159 L .11662 .91882 L p F P
0 g
s
.749 .234 0 r
.11662 .91882 m .1092 .91044 L .12128 .91616 L p F P
0 g
s
.36 .085 .354 r
.44412 .59408 m .44769 .59031 L .44454 .59184 L closepath p F P
0 g
s
0 0 0 r
.47115 .5775 m .44769 .59031 L .44454 .59184 L p F P
0 g
s
.65 .753 .925 r
.42386 .96505 m .45074 .95702 L .45824 .96466 L p F P
0 g
s
.667 .72 .888 r
.45074 .95702 m .42386 .96505 L .41624 .95714 L p F P
0 g
s
.517 .893 .965 r
.58894 .95248 m .59502 .95377 L .62068 .94491 L p F P
0 g
s
.481 .89 .932 r
.62333 .94498 m .62068 .94491 L .59502 .95377 L p F P
0 g
s
.492 .879 .967 r
.59502 .95377 m .58894 .95248 L .56147 .95982 L p F P
0 g
s
.786 .795 .86 r
.62856 .30475 m .63141 .30263 L .6246 .29409 L p F P
0 g
s
.786 .795 .86 r
.6246 .29409 m .6231 .29521 L .62856 .30475 L p F P
0 g
s
.772 .791 .868 r
.59724 .31315 m .6231 .29521 L .62856 .30475 L p F P
0 g
s
.198 .676 .934 r
.2441 .95942 m .23564 .95421 L .21008 .95491 L p F P
0 g
s
.498 .757 .988 r
.23564 .95421 m .21008 .95491 L .20141 .9508 L p F P
0 g
s
.381 .307 .648 r
.74992 .78183 m .76194 .77086 L p .75702 .79455 L F P
0 g
s
.381 .307 .648 r
.75702 .79455 m .75112 .78761 L .74992 .78183 L p F P
0 g
s
.397 .347 .685 r
.74992 .78183 m .76194 .77086 L .75 .7608 L p F P
0 g
s
.636 .77 .944 r
.45824 .96466 m .48526 .95724 L .49265 .96413 L p F P
0 g
s
.655 .731 .905 r
.48526 .95724 m .45824 .96466 L .45074 .95702 L p F P
0 g
s
0 0 0 r
.65589 .93172 m .65735 .93036 L .68483 .91457 L p F P
0 g
s
.072 0 0 r
.68554 .9133 m .68483 .91457 L .65735 .93036 L p F P
0 g
s
.782 .469 .458 r
.37012 .60688 m .3514 .60249 L .3491 .59083 L p F P
0 g
s
.853 .536 .449 r
.33599 .58459 m .3491 .59083 L .3514 .60249 L p F P
0 g
s
.661 .11 0 r
.33338 .58015 m .33599 .58459 L .3491 .59083 L p F P
0 g
s
.109 .52 .911 r
.29674 .56389 m .30545 .57169 L p .32098 .57344 L F P
0 g
s
.54 .718 .955 r
.2913 .56445 m .29674 .56389 L .30545 .57169 L p F P
0 g
s
.792 .796 .856 r
.65663 .28309 m .63141 .30263 L .6246 .29409 L p F P
0 g
s
.342 .212 .555 r
.75567 .81281 m .74665 .8196 L .74994 .83225 L p F P
0 g
s
.381 .276 .609 r
.74665 .8196 m .75567 .81281 L .75326 .79781 L p F P
0 g
s
.577 .856 .996 r
.58894 .95248 m .56147 .95982 L .5544 .956 L p F P
0 g
s
.574 .849 .996 r
.52707 .96282 m .5544 .956 L .56147 .95982 L p F P
0 g
s
.884 .507 .321 r
.07674 .8768 m .07952 .87676 L p .09115 .89317 L F P
0 g
s
.895 .541 .366 r
.07674 .8768 m .07635 .875 L .07952 .87676 L closepath p F P
0 g
s
.455 .206 .446 r
.44769 .59031 m .46917 .5808 L p .44321 .6032 L F P
0 g
s
.455 .206 .446 r
.44321 .6032 m .44412 .59408 L .44769 .59031 L p F P
0 g
s
.16 0 0 r
.44769 .59031 m .46917 .5808 L .47115 .5775 L closepath p F P
0 g
s
.55 .624 .878 r
.62977 .60667 m .62354 .607 L .61656 .59537 L p F P
0 g
s
.901 .803 .742 r
.72911 .17544 m .73525 .1851 L .74452 .17024 L p F P
0 g
s
.901 .803 .742 r
.74452 .17024 m .73842 .16055 L .72911 .17544 L p F P
0 g
s
.615 .803 .972 r
.49265 .96413 m .51982 .95719 L .52707 .96282 L p F P
0 g
s
.64 .756 .932 r
.51982 .95719 m .49265 .96413 L .48526 .95724 L p F P
0 g
s
.466 .485 .794 r
.73371 .69823 m .72172 .695 L .71724 .68392 L p F P
0 g
s
.75 .777 .875 r
.58751 .31956 m .56995 .3304 L .56287 .32158 L p F P
0 g
s
.736 .773 .883 r
.53558 .33709 m .56287 .32158 L .56995 .3304 L p F P
0 g
s
.691 .447 .549 r
.39523 .60918 m .41389 .60912 L .41396 .6221 L p F P
0 g
s
.691 .447 .549 r
.41396 .6221 m .39377 .62215 L .39523 .60918 L p F P
0 g
s
.724 .478 .554 r
.37763 .6079 m .39523 .60918 L .39377 .62215 L p F P
0 g
s
.558 .279 .448 r
.44412 .59408 m .44321 .6032 L .41389 .60912 L p F P
0 g
s
.598 .373 .546 r
.41396 .6221 m .41389 .60912 L .44321 .6032 L p F P
0 g
s
.573 .656 .893 r
.59314 .58529 m .5818 .58665 L .57472 .57593 L p F P
0 g
s
.619 .799 .968 r
.5544 .956 m .52707 .96282 L .51982 .95719 L p F P
0 g
s
.846 .808 .813 r
.70628 .2214 m .71008 .21734 L .71563 .22706 L p F P
0 g
s
.846 .808 .813 r
.71563 .22706 m .71275 .23012 L .70628 .2214 L p F P
0 g
s
.378 .306 .649 r
.75326 .79781 m .75112 .78761 L .75702 .79455 L closepath p F P
0 g
s
.847 .808 .813 r
.69921 .24457 m .71275 .23012 L .70628 .2214 L p F P
0 g
s
.665 .743 .908 r
.53288 .56057 m .50563 .56843 L .49829 .56146 L p F P
0 g
s
.39 .348 .692 r
.76296 .74815 m .75 .7608 L .76194 .77086 L p F P
0 g
s
.426 .391 .716 r
.74829 .73894 m .76296 .74815 L .75 .7608 L p F P
0 g
s
.724 .478 .554 r
.39377 .62215 m .37775 .62103 L .37763 .6079 L p F P
0 g
s
.753 .501 .55 r
.37012 .60688 m .37763 .6079 L .37775 .62103 L p F P
0 g
s
.807 .8 .845 r
.65663 .28309 m .65865 .28139 L .65194 .2728 L p F P
0 g
s
.807 .8 .845 r
.65194 .2728 m .6511 .27351 L .65663 .28309 L p F P
0 g
s
.792 .796 .856 r
.6246 .29409 m .6511 .27351 L .65663 .28309 L p F P
0 g
s
.811 .801 .842 r
.67976 .26318 m .65865 .28139 L .65194 .2728 L p F P
0 g
s
.847 .808 .813 r
.70628 .2214 m .69364 .2349 L .69921 .24457 L p F P
0 g
s
.829 .805 .828 r
.67921 .24878 m .69364 .2349 L .69921 .24457 L p F P
0 g
s
.829 .805 .828 r
.69921 .24457 m .6858 .25743 L .67921 .24878 L p F P
0 g
s
.151 0 .232 r
.72315 .87513 m .73597 .86716 L p .71203 .89166 L F P
0 g
s
.151 0 .232 r
.71203 .89166 m .71206 .89151 L .72315 .87513 L p F P
0 g
s
.294 .079 .408 r
.72315 .87513 m .73597 .86716 L .73657 .85518 L p F P
0 g
s
.508 .545 .829 r
.68212 .64582 m .70086 .648 L p .70392 .66189 L F P
0 g
s
.493 .543 .836 r
.68212 .64582 m .70086 .648 L .69394 .63381 L p F P
0 g
s
.493 .543 .836 r
.69394 .63381 m .69103 .63345 L .68212 .64582 L p F P
0 g
s
.519 .571 .848 r
.66546 .63183 m .69103 .63345 L .68212 .64582 L p F P
0 g
s
.055 0 0 r
.68483 .91457 m .68938 .9113 L .68554 .9133 L closepath p F P
0 g
s
.176 0 .132 r
.68554 .9133 m .68938 .9113 L .71184 .89176 L p F P
0 g
s
.91 .598 .443 r
.07635 .875 m .06568 .86867 L .06473 .85592 L p F P
0 g
s
.919 .606 .436 r
.05447 .84939 m .06473 .85592 L .06568 .86867 L p F P
0 g
s
.918 .649 .514 r
.06473 .85592 m .05447 .84939 L .05533 .83618 L p F P
0 g
s
.466 .485 .794 r
.71724 .68392 m .72088 .67945 L p .73371 .69823 L F P
0 g
s
.48 .514 .815 r
.71724 .68392 m .71473 .67823 L .72088 .67945 L closepath p F P
0 g
s
.902 .542 .348 r
.07635 .875 m .07674 .8768 L .06715 .87516 L p F P
0 g
s
.902 .542 .348 r
.06715 .87516 m .06568 .86867 L .07635 .875 L p F P
0 g
s
.513 .571 .852 r
.69103 .63345 m .66546 .63183 L .66108 .6234 L p F P
0 g
s
.828 .805 .829 r
.67976 .26318 m .6858 .25743 L .67921 .24878 L p F P
0 g
s
.828 .805 .829 r
.67921 .24878 m .67419 .25355 L .67976 .26318 L p F P
0 g
s
.811 .801 .842 r
.65194 .2728 m .67419 .25355 L .67976 .26318 L p F P
0 g
s
.578 .771 .971 r
.2441 .95942 m .27012 .95447 L .27838 .96077 L p F P
0 g
s
.622 .766 .948 r
.27012 .95447 m .2441 .95942 L .23564 .95421 L p F P
0 g
s
.753 .501 .55 r
.37775 .62103 m .36886 .61976 L .37012 .60688 L p F P
0 g
s
.792 .531 .542 r
.3514 .60249 m .37012 .60688 L .36886 .61976 L p F P
0 g
s
.927 .658 .51 r
.0455 .82943 m .05533 .83618 L .05447 .84939 L p F P
0 g
s
.92 .688 .57 r
.05533 .83618 m .0455 .82943 L .04803 .81579 L p F P
0 g
s
.326 0 0 r
.14536 .93174 m .15877 .9385 L .14981 .93426 L p F P
0 g
s
.326 0 0 r
.14981 .93426 m .13232 .92635 L .14536 .93174 L p F P
0 g
s
.659 .107 0 r
.12583 .92159 m .13232 .92635 L .14536 .93174 L p F P
0 g
s
0 0 0 r
.65101 .9344 m .65589 .93172 L .67986 .92066 L p F P
0 g
s
0 0 0 r
.68483 .91457 m .67986 .92066 L .65589 .93172 L p F P
0 g
s
0 0 0 r
.62333 .94498 m .65101 .9344 L .65589 .93172 L p F P
0 g
s
.531 .602 .869 r
.62977 .60667 m .6516 .60647 L .64464 .59429 L p F P
0 g
s
.531 .602 .869 r
.64464 .59429 m .63744 .59432 L .62977 .60667 L p F P
0 g
s
.55 .624 .878 r
.61656 .59537 m .63744 .59432 L .62977 .60667 L p F P
0 g
s
.241 .039 .393 r
.74944 .846 m .73657 .85518 L .73597 .86716 L p F P
0 g
s
.306 .142 .487 r
.73657 .85518 m .74944 .846 L .74994 .83225 L p F P
0 g
s
.594 .673 .895 r
.5401 .57024 m .56759 .56545 L .57472 .57593 L p F P
0 g
s
.595 .69 .909 r
.56042 .55523 m .56759 .56545 L .5401 .57024 L p F P
0 g
s
.595 .69 .909 r
.537 .55971 m .56042 .55523 L p .5401 .57024 L F P
0 g
s
.595 .69 .909 r
.5401 .57024 m .53516 .56355 L .537 .55971 L p F P
0 g
s
.342 .249 .603 r
.75702 .79455 m .75326 .79781 L .75567 .81281 L p F P
0 g
s
.761 .78 .869 r
.58751 .31956 m .59724 .31315 L .59026 .30427 L p F P
0 g
s
.761 .78 .869 r
.59026 .30427 m .58102 .31036 L .58751 .31956 L p F P
0 g
s
.75 .777 .875 r
.56287 .32158 m .58102 .31036 L .58751 .31956 L p F P
0 g
s
.837 .391 .162 r
.1092 .91044 m .09752 .90455 L .09115 .89317 L p F P
0 g
s
.839 .386 .136 r
.07983 .8871 m .09115 .89317 L .09752 .90455 L p F P
0 g
s
.884 .507 .321 r
.09115 .89317 m .07983 .8871 L .07674 .8768 L p F P
0 g
s
.89 .511 .31 r
.07983 .8871 m .07674 .8768 L .06715 .87516 L p F P
0 g
s
0 .414 .703 r
.1677 .94203 m .17986 .94457 L .19397 .94957 L p F P
0 g
s
0 .534 .836 r
.17986 .94457 m .1677 .94203 L .15877 .9385 L p F P
0 g
s
.479 .515 .817 r
.72088 .67945 m .71473 .67823 L .70778 .66257 L p F P
0 g
s
.599 .026 0 r
.13232 .92635 m .12583 .92159 L .11662 .91882 L p F P
0 g
s
.879 .802 .771 r
.72649 .179 m .72911 .17544 L .73525 .1851 L p F P
0 g
s
.879 .802 .771 r
.73525 .1851 m .73292 .18828 L .72649 .179 L p F P
0 g
s
0 0 0 r
.67986 .92066 m .68483 .91457 L .68938 .9113 L p F P
0 g
s
.645 .761 .933 r
.27838 .96077 m .30473 .95295 L .3128 .96031 L p F P
0 g
s
.673 .749 .908 r
.30473 .95295 m .27838 .96077 L .27012 .95447 L p F P
0 g
s
.929 .698 .568 r
.03863 .80882 m .04803 .81579 L .0455 .82943 L p F P
0 g
s
.919 .72 .617 r
.04803 .81579 m .03863 .80882 L .04275 .79476 L p F P
0 g
s
.88 .803 .769 r
.72377 .20081 m .73292 .18828 L .72649 .179 L p F P
0 g
s
.201 .652 .946 r
.19397 .94957 m .20141 .9508 L .19271 .94601 L p F P
0 g
s
.201 .652 .946 r
.19271 .94601 m .17986 .94457 L .19397 .94957 L p F P
0 g
s
0 0 0 r
.68938 .9113 m .70858 .90097 L p .67986 .92066 L F P
0 g
s
.14 0 .094 r
.71203 .89166 m .71184 .89176 L .68938 .9113 L p F P
0 g
s
.14 0 .094 r
.68938 .9113 m .70858 .90097 L .71203 .89166 L p F P
0 g
s
.407 .387 .724 r
.75902 .72768 m .74829 .73894 L .76296 .74815 L p F P
0 g
s
.44 .423 .744 r
.75829 .72554 m .75902 .72768 L .74829 .73894 L p F P
0 g
s
.44 .423 .744 r
.74285 .71807 m .75829 .72554 L p .74829 .73894 L F P
0 g
s
.77 .783 .863 r
.6231 .29521 m .59724 .31315 L .59026 .30427 L p F P
0 g
s
.671 .743 .905 r
.3128 .96031 m .33936 .95079 L .34727 .95908 L p F P
0 g
s
.692 .728 .878 r
.33936 .95079 m .3128 .96031 L .30473 .95295 L p F P
0 g
s
.248 0 .265 r
.71184 .89176 m .71203 .89166 L .71206 .89151 L closepath p F P
0 g
s
.07 0 .062 r
.73418 .87797 m .71203 .89166 L .70858 .90097 L p F P
0 g
s
.151 0 .232 r
.73597 .86716 m .73418 .87797 L .71203 .89166 L p F P
0 g
s
.485 .52 .819 r
.70778 .66257 m .70392 .66189 L .7062 .65905 L closepath p F P
0 g
s
.508 .545 .829 r
.70086 .648 m .7062 .65905 L .70392 .66189 L p F P
0 g
s
.679 .729 .888 r
.34727 .95908 m .37399 .94887 L .38176 .95786 L p F P
0 g
s
.695 .71 .86 r
.37399 .94887 m .34727 .95908 L .33936 .95079 L p F P
0 g
s
.56 .639 .886 r
.59314 .58529 m .60954 .58389 L .60249 .57258 L p F P
0 g
s
.56 .639 .886 r
.60249 .57258 m .6008 .57273 L .59314 .58529 L p F P
0 g
s
.573 .656 .893 r
.57472 .57593 m .6008 .57273 L .59314 .58529 L p F P
0 g
s
.513 .571 .852 r
.66108 .6234 m .664 .6189 L p .69103 .63345 L F P
0 g
s
.526 .594 .865 r
.66108 .6234 m .65853 .6188 L .664 .6189 L closepath p F P
0 g
s
.727 .197 0 r
.1092 .91044 m .11662 .91882 L .10776 .91532 L p F P
0 g
s
.727 .197 0 r
.09752 .90455 m .1092 .91044 L p .10776 .91532 L F P
0 g
s
.676 .72 .882 r
.38176 .95786 m .40859 .9478 L .41624 .95714 L p F P
0 g
s
.689 .697 .852 r
.40859 .9478 m .38176 .95786 L .37399 .94887 L p F P
0 g
s
.502 .906 .91 r
.62068 .94491 m .62333 .94498 L .65101 .9344 L p F P
0 g
s
.853 .536 .449 r
.3514 .60249 m .33752 .59649 L .33599 .58459 L p F P
0 g
s
.908 .59 .434 r
.3255 .57742 m .33599 .58459 L .33752 .59649 L p F P
0 g
s
.831 .358 .037 r
.32516 .57659 m .3255 .57742 L .33599 .58459 L p F P
0 g
s
.667 .72 .888 r
.41624 .95714 m .4432 .94778 L .45074 .95702 L p F P
0 g
s
.679 .693 .857 r
.4432 .94778 m .41624 .95714 L .40859 .9478 L p F P
0 g
s
.546 .627 .883 r
.63744 .59432 m .61656 .59537 L .60954 .58389 L p F P
0 g
s
.472 .274 .529 r
.44336 .61616 m .44321 .6032 L .4678 .59203 L p F P
0 g
s
.455 .206 .446 r
.46917 .5808 m .4678 .59203 L .44321 .6032 L p F P
0 g
s
.598 .373 .546 r
.44321 .6032 m .44336 .61616 L .41396 .6221 L p F P
0 g
s
.422 .422 .754 r
.75829 .72554 m .74285 .71807 L .75212 .70757 L closepath p F P
0 g
s
.453 .455 .77 r
.75104 .70472 m .75212 .70757 L .74285 .71807 L p F P
0 g
s
.453 .455 .77 r
.73371 .69823 m .75104 .70472 L p .74285 .71807 L F P
0 g
s
.342 .249 .603 r
.75567 .81281 m .76316 .8064 L .75702 .79455 L p F P
0 g
s
.332 .246 .607 r
.77103 .78184 m .75702 .79455 L .76316 .8064 L p F P
0 g
s
.381 .307 .648 r
.76194 .77086 m .77103 .78184 L .75702 .79455 L p F P
0 g
s
.88 .803 .769 r
.72649 .179 m .71759 .19119 L .72377 .20081 L p F P
0 g
s
.861 .801 .79 r
.70384 .20778 m .71008 .21734 L .72377 .20081 L p F P
0 g
s
.861 .801 .79 r
.72377 .20081 m .71759 .19119 L .70384 .20778 L p F P
0 g
s
.696 .472 .579 r
.39377 .62215 m .41396 .6221 L .41485 .63597 L p F P
0 g
s
.696 .472 .579 r
.41485 .63597 m .3897 .63603 L .39377 .62215 L p F P
0 g
s
.727 .505 .59 r
.37775 .62103 m .39377 .62215 L .3897 .63603 L p F P
0 g
s
.608 .406 .581 r
.41396 .6221 m .44336 .61616 L p .43632 .63162 L F P
0 g
s
.608 .406 .581 r
.43632 .63162 m .41485 .63597 L .41396 .6221 L p F P
0 g
s
.466 .485 .794 r
.72088 .67945 m .74365 .68596 L .73371 .69823 L p F P
0 g
s
.453 .488 .806 r
.72993 .6673 m .72088 .67945 L .74365 .68596 L p F P
0 g
s
.479 .515 .817 r
.70778 .66257 m .72993 .6673 L .72088 .67945 L p F P
0 g
s
.655 .731 .905 r
.45074 .95702 m .47783 .94861 L .48526 .95724 L p F P
0 g
s
.665 .698 .87 r
.47783 .94861 m .45074 .95702 L .4432 .94778 L p F P
0 g
s
.572 .663 .899 r
.6008 .57273 m .57472 .57593 L .56759 .56545 L p F P
0 g
s
.792 .531 .542 r
.36886 .61976 m .35047 .61527 L .3514 .60249 L p F P
0 g
s
.854 .588 .535 r
.33752 .59649 m .3514 .60249 L .35047 .61527 L p F P
0 g
s
.43 .446 .774 r
.73371 .69823 m .75104 .70472 L .74392 .68607 L p F P
0 g
s
.43 .446 .774 r
.74392 .68607 m .74365 .68596 L .73371 .69823 L p F P
0 g
s
.47 .512 .819 r
.72993 .6673 m .70778 .66257 L .7062 .65905 L p F P
0 g
s
.292 .131 .483 r
.75717 .82686 m .74994 .83225 L .74944 .846 L p F P
0 g
s
.342 .212 .555 r
.74994 .83225 m .75717 .82686 L .75567 .81281 L p F P
0 g
s
.524 .597 .869 r
.664 .6189 m .65853 .6188 L .6516 .60647 L p F P
0 g
s
.109 .52 .911 r
.32098 .57344 m .31614 .56981 L .29674 .56389 L p F P
0 g
s
.298 .18 .546 r
.76316 .8064 m .75567 .81281 L .75717 .82686 L p F P
0 g
s
.606 .703 .913 r
.53516 .56355 m .53288 .56057 L .537 .55971 L closepath p F P
0 g
s
.727 .505 .59 r
.3897 .63603 m .37893 .63529 L .37775 .62103 L p F P
0 g
s
.757 .526 .583 r
.36886 .61976 m .37775 .62103 L .37893 .63529 L p F P
0 g
s
.783 .786 .855 r
.6231 .29521 m .6246 .29409 L .61772 .28513 L p F P
0 g
s
.783 .786 .855 r
.61772 .28513 m .61667 .28591 L .6231 .29521 L p F P
0 g
s
.77 .783 .863 r
.59026 .30427 m .61667 .28591 L .6231 .29521 L p F P
0 g
s
.789 .787 .851 r
.6511 .27351 m .6246 .29409 L .61772 .28513 L p F P
0 g
s
.64 .756 .932 r
.48526 .95724 m .51251 .9497 L .51982 .95719 L p F P
0 g
s
.651 .715 .895 r
.51251 .9497 m .48526 .95724 L .47783 .94861 L p F P
0 g
s
.47 .512 .819 r
.7062 .65905 m .71254 .64973 L p .72993 .6673 L F P
0 g
s
.485 .539 .837 r
.7062 .65905 m .70086 .648 L .71254 .64973 L closepath p F P
0 g
s
.517 .893 .965 r
.62068 .94491 m .61661 .94428 L .58894 .95248 L p F P
0 g
s
.571 .871 .995 r
.61661 .94428 m .58894 .95248 L .58196 .94878 L p F P
0 g
s
.577 .856 .996 r
.5544 .956 m .58196 .94878 L .58894 .95248 L p F P
0 g
s
.498 .757 .988 r
.20141 .9508 m .22715 .94835 L .23564 .95421 L p F P
0 g
s
.553 .763 .975 r
.22715 .94835 m .20141 .9508 L .19271 .94601 L p F P
0 g
s
.842 .798 .809 r
.69973 .21218 m .70384 .20778 L .71008 .21734 L p F P
0 g
s
.842 .798 .809 r
.71008 .21734 m .70628 .2214 L .69973 .21218 L p F P
0 g
s
.619 .799 .968 r
.51982 .95719 m .54724 .95013 L .5544 .956 L p F P
0 g
s
.636 .749 .93 r
.54724 .95013 m .51982 .95719 L .51251 .9497 L p F P
0 g
s
.699 .865 .961 r
.49651 .56226 m .49774 .56109 L .49829 .56146 L closepath p F P
0 g
s
.125 0 0 r
.49651 .56226 m .49774 .56109 L p .46917 .5808 L F P
0 g
s
.757 .526 .583 r
.37893 .63529 m .36566 .63335 L .36886 .61976 L p F P
0 g
s
.8 .561 .576 r
.35047 .61527 m .36886 .61976 L .36566 .63335 L p F P
0 g
s
.842 .798 .808 r
.69364 .2349 m .70628 .2214 L .69973 .21218 L p F P
0 g
s
.616 .803 .972 r
.58196 .94878 m .5544 .956 L .54724 .95013 L p F P
0 g
s
0 .347 .715 r
.13232 .92635 m .14981 .93426 L .1466 .93256 L p F P
0 g
s
.599 .026 0 r
.11662 .91882 m .11962 .92081 L .13232 .92635 L p F P
0 g
s
0 .347 .715 r
.11962 .92081 m .13232 .92635 L p .1466 .93256 L F P
0 g
s
.648 .852 .978 r
.49774 .56109 m .49829 .56146 L .52561 .55174 L p F P
0 g
s
.665 .743 .908 r
.49829 .56146 m .52561 .55174 L .53288 .56057 L p F P
0 g
s
.909 .544 .33 r
.06568 .86867 m .06715 .87516 L .05764 .87183 L p F P
0 g
s
.909 .544 .33 r
.05764 .87183 m .05539 .86216 L .06568 .86867 L p F P
0 g
s
.919 .606 .436 r
.06568 .86867 m .05539 .86216 L .05447 .84939 L p F P
0 g
s
.928 .614 .428 r
.0446 .84267 m .05447 .84939 L .05539 .86216 L p F P
0 g
s
.927 .658 .51 r
.05447 .84939 m .0446 .84267 L .0455 .82943 L p F P
0 g
s
.125 0 0 r
.49774 .56109 m .49089 .55964 L p .46917 .5808 L F P
0 g
s
.136 0 .323 r
.48255 .56882 m .46917 .5808 L .4678 .59203 L p F P
0 g
s
0 0 .202 r
.48255 .56882 m .47808 .58284 L p .4856 .56677 L F P
0 g
s
.125 0 0 r
.49089 .55964 m .48255 .56882 L p .47908 .57115 L F P
0 g
s
.635 .9 .583 r
.48757 .56256 m .49089 .55964 L .48421 .56698 L p F P
0 g
s
.635 .9 .583 r
.48421 .56698 m .48255 .56882 L .48757 .56256 L p F P
0 g
s
.747 .963 .936 r
.49089 .55964 m .5099 .54749 L .49774 .56109 L closepath p F P
0 g
s
0 0 0 r
.48757 .56256 m .49089 .55964 L .5099 .54749 L p F P
0 g
s
0 0 0 r
.5099 .54749 m .51014 .53683 L p .48757 .56256 L F P
0 g
s
0 0 0 r
.49229 .55517 m .48757 .56256 L p .49171 .55784 L F P
0 g
s
0 0 0 r
.51014 .53683 m .49229 .55517 L p .49171 .55784 L F P
0 g
s
0 0 .101 r
.49229 .55517 m .48757 .56256 L p .49151 .55737 L F P
0 g
s
0 0 .101 r
.48584 .57337 m .48845 .56905 L .49229 .55517 L p F P
0 g
s
0 0 0 r
.49229 .55517 m .48845 .56905 L p .4932 .55096 L F P
0 g
s
0 0 0 r
.49513 .54362 m .49229 .55517 L p .4932 .55096 L F P
0 g
s
0 0 .101 r
.48757 .56256 m .48584 .57337 L p .49151 .55737 L F P
0 g
s
0 0 .202 r
.48757 .56256 m .48255 .56882 L p .4856 .56677 L F P
0 g
s
.125 0 0 r
.48255 .56882 m .46917 .5808 L p .47908 .57115 L F P
0 g
s
.513 .571 .852 r
.664 .6189 m .68703 .62057 L p .69103 .63345 L F P
0 g
s
.5 .57 .858 r
.664 .6189 m .68703 .62057 L .68011 .60768 L p F P
0 g
s
.5 .57 .858 r
.68011 .60768 m .67078 .60693 L .664 .6189 L p F P
0 g
s
.524 .597 .869 r
.6516 .60647 m .67078 .60693 L .664 .6189 L p F P
0 g
s
.804 .791 .84 r
.6511 .27351 m .65194 .2728 L .64517 .26376 L p F P
0 g
s
.804 .791 .84 r
.64517 .26376 m .64472 .26414 L .6511 .27351 L p F P
0 g
s
.789 .787 .851 r
.61772 .28513 m .64472 .26414 L .6511 .27351 L p F P
0 g
s
.603 .719 .926 r
.537 .55971 m .53288 .56057 L .52561 .55174 L p F P
0 g
s
.807 .792 .838 r
.67419 .25355 m .65194 .2728 L .64517 .26376 L p F P
0 g
s
.522 .904 .95 r
.61661 .94428 m .62068 .94491 L .64561 .93496 L p F P
0 g
s
.502 .906 .91 r
.65101 .9344 m .64561 .93496 L .62068 .94491 L p F P
0 g
s
.648 .852 .978 r
.5183 .54362 m .5099 .54749 L .49774 .56109 L p F P
0 g
s
.648 .852 .978 r
.52561 .55174 m .5183 .54362 L p .49774 .56109 L F P
0 g
s
.842 .798 .808 r
.69973 .21218 m .68735 .2254 L .69364 .2349 L p F P
0 g
s
.825 .795 .823 r
.67254 .23965 m .68735 .2254 L .69364 .2349 L p F P
0 g
s
.825 .795 .823 r
.69364 .2349 m .67921 .24878 L .67254 .23965 L p F P
0 g
s
.839 .386 .136 r
.09752 .90455 m .08623 .89848 L .07983 .8871 L p F P
0 g
s
.84 .381 .109 r
.06893 .88085 m .07983 .8871 L .08623 .89848 L p F P
0 g
s
.89 .511 .31 r
.06715 .87516 m .06893 .88085 L .07983 .8871 L p F P
0 g
s
.281 .69 .971 r
.17986 .94457 m .19271 .94601 L .18397 .94067 L p F P
0 g
s
.281 .69 .971 r
.18397 .94067 m .16575 .93951 L .17986 .94457 L p F P
0 g
s
0 .534 .836 r
.15877 .9385 m .16575 .93951 L .17986 .94457 L p F P
0 g
s
.936 .667 .505 r
.03606 .82249 m .0455 .82943 L .0446 .84267 L p F P
0 g
s
.929 .698 .568 r
.0455 .82943 m .03606 .82249 L .03863 .80882 L p F P
0 g
s
.824 .795 .825 r
.67419 .25355 m .67921 .24878 L .67254 .23965 L p F P
0 g
s
.824 .795 .825 r
.67254 .23965 m .66786 .24411 L .67419 .25355 L p F P
0 g
s
.807 .792 .838 r
.64517 .26376 m .66786 .24411 L .67419 .25355 L p F P
0 g
s
.622 .766 .948 r
.23564 .95421 m .26184 .94747 L .27012 .95447 L p F P
0 g
s
.653 .76 .928 r
.26184 .94747 m .23564 .95421 L .22715 .94835 L p F P
0 g
s
.148 0 .258 r
.74474 .86095 m .73597 .86716 L .73418 .87797 L p F P
0 g
s
.241 .039 .393 r
.73597 .86716 m .74474 .86095 L .74944 .846 L p F P
0 g
s
.611 .716 .92 r
.537 .55971 m .56042 .55523 L .55321 .54531 L p F P
0 g
s
.611 .716 .92 r
.55321 .54531 m .54036 .54822 L .537 .55971 L p F P
0 g
s
.603 .719 .926 r
.52561 .55174 m .54036 .54822 L .537 .55971 L p F P
0 g
s
.483 .541 .84 r
.71254 .64973 m .70086 .648 L .69394 .63381 L p F P
0 g
s
.356 .297 .653 r
.76927 .76378 m .76194 .77086 L .77103 .78184 L p F P
0 g
s
.39 .348 .692 r
.76582 .75067 m .76296 .74815 L p .76194 .77086 L F P
0 g
s
.39 .348 .692 r
.76194 .77086 m .76927 .76378 L .76582 .75067 L p F P
0 g
s
.699 .485 .595 r
.3897 .63603 m .41485 .63597 L .4162 .65037 L p F P
0 g
s
.699 .485 .595 r
.4162 .65037 m .38411 .65044 L .3897 .63603 L p F P
0 g
s
.727 .518 .607 r
.37893 .63529 m .3897 .63603 L .38411 .65044 L p F P
0 g
s
.614 .423 .6 r
.41485 .63597 m .43632 .63162 L .41822 .64997 L p F P
0 g
s
.614 .423 .6 r
.41822 .64997 m .4162 .65037 L .41485 .63597 L p F P
0 g
s
.673 .749 .908 r
.27012 .95447 m .29663 .9448 L .30473 .95295 L p F P
0 g
s
.694 .739 .886 r
.29663 .9448 m .27012 .95447 L .26184 .94747 L p F P
0 g
s
.546 .627 .883 r
.60954 .58389 m .63766 .58257 L p .63744 .59432 L F P
0 g
s
.538 .632 .892 r
.63766 .58257 m .60954 .58389 L .60249 .57258 L p F P
0 g
s
.695 .71 .86 r
.33936 .95079 m .3662 .93873 L .37399 .94887 L p F P
0 g
s
.708 .691 .832 r
.3662 .93873 m .33936 .95079 L .33143 .94154 L p F P
0 g
s
.692 .728 .878 r
.30473 .95295 m .33143 .94154 L .33936 .95079 L p F P
0 g
s
.689 .697 .852 r
.402 .93859 m .40859 .9478 L p .37399 .94887 L F P
0 g
s
.689 .697 .852 r
.37399 .94887 m .39756 .93856 L .402 .93859 L p F P
0 g
s
.702 .681 .827 r
.39756 .93856 m .37399 .94887 L .3662 .93873 L p F P
0 g
s
.707 .713 .853 r
.33143 .94154 m .30473 .95295 L .29663 .9448 L p F P
0 g
s
.727 .197 0 r
.10776 .91532 m .10731 .91509 L .09752 .90455 L p F P
0 g
s
.711 .175 0 r
.08623 .89848 m .09752 .90455 L .10731 .91509 L p F P
0 g
s
.679 .693 .857 r
.4358 .93727 m .4432 .94778 L p .40859 .9478 L F P
0 g
s
.679 .693 .857 r
.40859 .9478 m .43493 .93731 L .4358 .93727 L p F P
0 g
s
.679 .694 .857 r
.40859 .9478 m .43493 .93731 L .402 .93859 L closepath p F P
0 g
s
0 0 0 r
.67986 .92066 m .67879 .92146 L .65101 .9344 L p F P
0 g
s
.516 .916 .863 r
.64561 .93496 m .65101 .9344 L .67879 .92146 L p F P
0 g
s
.501 .322 .57 r
.44336 .61616 m .46805 .60506 L p .45094 .62706 L F P
0 g
s
.501 .322 .57 r
.45094 .62706 m .44373 .62204 L .44336 .61616 L p F P
0 g
s
.472 .274 .529 r
.4678 .59203 m .46805 .60506 L .44336 .61616 L p F P
0 g
s
.608 .406 .581 r
.44336 .61616 m .44373 .62204 L .43632 .63162 L p F P
0 g
s
.136 .618 .919 r
.16575 .93951 m .15877 .9385 L .14981 .93426 L p F P
0 g
s
.727 .518 .607 r
.38411 .65044 m .38071 .65021 L .37893 .63529 L p F P
0 g
s
.759 .539 .599 r
.36566 .63335 m .37893 .63529 L .38071 .65021 L p F P
0 g
s
.518 .598 .873 r
.67078 .60693 m .6516 .60647 L .64464 .59429 L p F P
0 g
s
.908 .59 .434 r
.33752 .59649 m .32655 .58948 L .3255 .57742 L p F P
0 g
s
.945 .63 .406 r
.32098 .57344 m .3255 .57742 L .32655 .58948 L p F P
0 g
s
.854 .588 .535 r
.35047 .61527 m .33658 .60928 L .33752 .59649 L p F P
0 g
s
.904 .638 .524 r
.32655 .58948 m .33752 .59649 L .33658 .60928 L p F P
0 g
s
.24 .093 .471 r
.7662 .81918 m .75717 .82686 L .75769 .8399 L p F P
0 g
s
.292 .131 .483 r
.74944 .846 m .75769 .8399 L .75717 .82686 L p F P
0 g
s
.298 .18 .546 r
.75717 .82686 m .7662 .81918 L .76316 .8064 L p F P
0 g
s
.524 0 0 r
.11962 .92081 m .10776 .91532 L .11662 .91882 L closepath p F P
0 g
s
.222 .022 .383 r
.75769 .8399 m .74944 .846 L .74474 .86095 L p F P
0 g
s
.665 .698 .87 r
.4432 .94778 m .47036 .93834 L .47783 .94861 L p F P
0 g
s
.668 .689 .86 r
.46792 .93442 m .47036 .93834 L .4432 .94778 L p F P
0 g
s
.668 .689 .86 r
.4432 .94778 m .4358 .93727 L .46792 .93442 L p F P
0 g
s
.8 .561 .576 r
.36566 .63335 m .34795 .62863 L .35047 .61527 L p F P
0 g
s
.856 .613 .572 r
.33658 .60928 m .35047 .61527 L .34795 .62863 L p F P
0 g
s
.572 .663 .899 r
.56759 .56545 m .59541 .56195 L p .6008 .57273 L F P
0 g
s
.571 .669 .905 r
.59541 .56195 m .56759 .56545 L .56042 .55523 L p F P
0 g
s
.897 .508 .281 r
.06893 .88085 m .06715 .87516 L .05764 .87183 L p F P
0 g
s
.49 .548 .843 r
.69394 .63381 m .69103 .63345 L .69257 .63106 L closepath p F P
0 g
s
.513 .571 .852 r
.68703 .62057 m .69257 .63106 L .69103 .63345 L p F P
0 g
s
.759 .539 .599 r
.38071 .65021 m .36144 .64732 L .36566 .63335 L p F P
0 g
s
.809 .583 .596 r
.34795 .62863 m .36566 .63335 L .36144 .64732 L p F P
0 g
s
.283 .171 .545 r
.77546 .79534 m .76316 .8064 L .7662 .81918 L p F P
0 g
s
.332 .246 .607 r
.77421 .78807 m .77103 .78184 L p .76316 .8064 L F P
0 g
s
.332 .246 .607 r
.76316 .8064 m .77546 .79534 L .77421 .78807 L p F P
0 g
s
.651 .715 .895 r
.47783 .94861 m .50514 .94043 L .51251 .9497 L p F P
0 g
s
.656 .682 .862 r
.50514 .94043 m .47783 .94861 L .47036 .93834 L p F P
0 g
s
.494 .324 .58 r
.44436 .63009 m .44373 .62204 L .45094 .62706 L closepath p F P
0 g
s
.615 .415 .587 r
.44436 .63009 m .44373 .62204 L .43632 .63162 L closepath p F P
0 g
s
.529 .608 .877 r
.64464 .59429 m .63744 .59432 L .6409 .58785 L closepath p F P
0 g
s
.546 .627 .883 r
.63766 .58257 m .6409 .58785 L .63744 .59432 L p F P
0 g
s
.374 .338 .689 r
.76582 .75067 m .76296 .74815 L .76469 .74636 L closepath p F P
0 g
s
.407 .387 .724 r
.76296 .74815 m .76469 .74636 L .75902 .72768 L p F P
0 g
s
0 .347 .715 r
.1466 .93256 m .1389 .92885 L .11962 .92081 L p F P
0 g
s
0 .392 .768 r
.10776 .91532 m .11962 .92081 L .1389 .92885 L p F P
0 g
s
0 0 0 r
.67879 .92146 m .68512 .91786 L .67986 .92066 L closepath p F P
0 g
s
0 0 0 r
.70652 .90425 m .68512 .91786 L .67986 .92066 L p F P
0 g
s
0 0 0 r
.70858 .90097 m .70652 .90425 L p .67986 .92066 L F P
0 g
s
.483 .541 .84 r
.69394 .63381 m .71959 .63792 L .71254 .64973 L p F P
0 g
s
.475 .54 .844 r
.71959 .63792 m .69394 .63381 L .69257 .63106 L p F P
0 g
s
.636 .749 .93 r
.51251 .9497 m .54 .94239 L .54724 .95013 L p F P
0 g
s
.642 .707 .894 r
.54 .94239 m .51251 .9497 L .50514 .94043 L p F P
0 g
s
.522 .904 .95 r
.64561 .93496 m .64447 .9349 L .61661 .94428 L p F P
0 g
s
.554 .891 .984 r
.64447 .9349 m .61661 .94428 L .60975 .94108 L p F P
0 g
s
.571 .871 .995 r
.58196 .94878 m .60975 .94108 L .61661 .94428 L p F P
0 g
s
.62 .432 .606 r
.43632 .63162 m .44436 .63009 L .44595 .64469 L p F P
0 g
s
.62 .432 .606 r
.44595 .64469 m .41822 .64997 L .43632 .63162 L p F P
0 g
s
.345 .718 .985 r
.16575 .93951 m .18397 .94067 L .17519 .93488 L p F P
0 g
s
.345 .718 .985 r
.17519 .93488 m .15157 .93442 L .16575 .93951 L p F P
0 g
s
.136 .618 .919 r
.14981 .93426 m .15157 .93442 L .16575 .93951 L p F P
0 g
s
.07 0 .062 r
.73389 .87895 m .73418 .87797 L p .70858 .90097 L F P
0 g
s
.07 0 .062 r
.70858 .90097 m .71705 .89577 L .73389 .87895 L p F P
0 g
s
0 0 0 r
.70652 .90425 m .71705 .89577 L .70858 .90097 L closepath p F P
0 g
s
.375 .366 .722 r
.76005 .72646 m .75902 .72768 L .76469 .74636 L p F P
0 g
s
.408 .413 .753 r
.75902 .72768 m .75829 .72554 L .76005 .72646 L closepath p F P
0 g
s
.408 .413 .753 r
.76005 .72646 m .75829 .72554 L .75212 .70757 L p F P
0 g
s
.945 .63 .406 r
.31689 .57217 m .32098 .57344 L p .32655 .58948 L F P
0 g
s
.905 .507 .238 r
.31689 .57217 m .31614 .56981 L .32098 .57344 L closepath p F P
0 g
s
.705 .514 .627 r
.38411 .65044 m .4162 .65037 L p .40816 .66585 L F P
0 g
s
.705 .514 .627 r
.38156 .65605 m .38411 .65044 L p .40816 .66585 L F P
0 g
s
.728 .527 .619 r
.38156 .65605 m .38411 .65044 L .38071 .65021 L closepath p F P
0 g
s
.916 .547 .314 r
.05539 .86216 m .05764 .87183 L .0482 .86699 L p F P
0 g
s
.916 .547 .314 r
.0482 .86699 m .04549 .85546 L .05539 .86216 L p F P
0 g
s
.928 .614 .428 r
.05539 .86216 m .04549 .85546 L .0446 .84267 L p F P
0 g
s
.618 .436 .613 r
.41635 .65164 m .41822 .64997 L .4162 .65037 L closepath p F P
0 g
s
.705 .514 .627 r
.4162 .65037 m .41635 .65164 L .40816 .66585 L p F P
0 g
s
.475 .54 .844 r
.69257 .63106 m .69761 .62165 L p .71959 .63792 L F P
0 g
s
.491 .566 .859 r
.69257 .63106 m .68703 .62057 L .69761 .62165 L closepath p F P
0 g
s
.737 .533 .617 r
.38071 .65021 m .36144 .64732 L p .3777 .66516 L F P
0 g
s
.737 .533 .617 r
.3777 .66516 m .38156 .65605 L .38071 .65021 L p F P
0 g
s
.553 .763 .975 r
.19271 .94601 m .21862 .94195 L .22715 .94835 L p F P
0 g
s
.592 .765 .962 r
.21862 .94195 m .19271 .94601 L .18397 .94067 L p F P
0 g
s
.936 .622 .419 r
.03513 .83575 m .0446 .84267 L .04549 .85546 L p F P
0 g
s
.936 .667 .505 r
.0446 .84267 m .03513 .83575 L .03606 .82249 L p F P
0 g
s
.357 .326 .687 r
.76469 .74636 m .7734 .73608 L p .77409 .75848 L F P
0 g
s
.357 .326 .687 r
.77409 .75848 m .76582 .75067 L .76469 .74636 L p F P
0 g
s
.375 .366 .722 r
.76469 .74636 m .7734 .73608 L .76005 .72646 L p F P
0 g
s
.628 .452 .624 r
.41823 .66552 m .41635 .65164 L .41822 .64997 L p F P
0 g
s
.689 .494 .618 r
.41823 .66552 m .41635 .65164 L .40816 .66585 L closepath p F P
0 g
s
.616 .803 .972 r
.54724 .95013 m .57489 .94305 L .58196 .94878 L p F P
0 g
s
.628 .752 .936 r
.57489 .94305 m .54724 .95013 L .54 .94239 L p F P
0 g
s
.628 .452 .624 r
.41822 .64997 m .44595 .64469 L p .41823 .66552 L F P
0 g
s
.612 .744 .939 r
.54036 .54822 m .52561 .55174 L .5183 .54362 L p F P
0 g
s
.262 .115 .485 r
.47808 .58284 m .4678 .59203 L .46805 .60506 L p F P
0 g
s
.136 0 .323 r
.4678 .59203 m .47808 .58284 L .48255 .56882 L p F P
0 g
s
.408 .413 .753 r
.75212 .70757 m .75354 .70574 L p .76005 .72646 L F P
0 g
s
.424 .446 .779 r
.75212 .70757 m .75104 .70472 L .75354 .70574 L closepath p F P
0 g
s
.559 .645 .891 r
.60249 .57258 m .6008 .57273 L .6016 .57119 L closepath p F P
0 g
s
.572 .663 .899 r
.59541 .56195 m .6016 .57119 L .6008 .57273 L p F P
0 g
s
.84 .381 .109 r
.08623 .89848 m .07536 .89223 L .06893 .88085 L p F P
0 g
s
.84 .375 .08 r
.05847 .8744 m .06893 .88085 L .07536 .89223 L p F P
0 g
s
.897 .508 .281 r
.05764 .87183 m .05847 .8744 L .06893 .88085 L p F P
0 g
s
.47 .512 .819 r
.71254 .64973 m .72994 .65367 L p .72993 .6673 L F P
0 g
s
.451 .508 .826 r
.71254 .64973 m .72994 .65367 L .72299 .63874 L p F P
0 g
s
.451 .508 .826 r
.72299 .63874 m .71959 .63792 L .71254 .64973 L p F P
0 g
s
.609 .819 .981 r
.60975 .94108 m .58196 .94878 L .57489 .94305 L p F P
0 g
s
.678 .695 .858 r
.43493 .93731 m .402 .93859 L .40092 .9371 L p F P
0 g
s
.688 .698 .854 r
.402 .93859 m .40092 .9371 L .39756 .93856 L closepath p F P
0 g
s
.702 .681 .827 r
.3662 .93873 m .36826 .93767 L .39756 .93856 L p F P
0 g
s
.682 .672 .834 r
.39324 .92505 m .36826 .93767 L .39756 .93856 L p F P
0 g
s
.682 .672 .834 r
.39756 .93856 m .40092 .9371 L .39324 .92505 L p F P
0 g
s
.355 .326 .688 r
.76927 .76378 m .76582 .75067 L .77409 .75848 L closepath p F P
0 g
s
.423 .447 .78 r
.75354 .70574 m .75104 .70472 L .74392 .68607 L p F P
0 g
s
.368 .373 .733 r
.76934 .71456 m .76005 .72646 L .7734 .73608 L p F P
0 g
s
.408 .413 .753 r
.75354 .70574 m .76934 .71456 L .76005 .72646 L p F P
0 g
s
.507 .35 .603 r
.45094 .62706 m .44436 .63009 L .44595 .64469 L p F P
0 g
s
.538 .632 .892 r
.60249 .57258 m .63066 .57138 L .63766 .58257 L p F P
0 g
s
.531 .631 .895 r
.62362 .56039 m .63066 .57138 L .60249 .57258 L p F P
0 g
s
.531 .631 .895 r
.60482 .56118 m .62362 .56039 L p .60249 .57258 L F P
0 g
s
.531 .631 .895 r
.60249 .57258 m .6016 .57119 L .60482 .56118 L p F P
0 g
s
.705 .692 .835 r
.3662 .93873 m .36826 .93767 L .36536 .93751 L closepath p F P
0 g
s
.708 .691 .832 r
.36536 .93751 m .3662 .93873 L p .33143 .94154 L F P
0 g
s
.148 0 .258 r
.73418 .87797 m .73528 .8772 L .74474 .86095 L p F P
0 g
s
.098 0 .205 r
.75712 .85185 m .74474 .86095 L .73528 .8772 L p F P
0 g
s
.222 .022 .383 r
.74474 .86095 m .75712 .85185 L .75769 .8399 L p F P
0 g
s
0 0 0 r
.68512 .91786 m .67879 .92146 L .67246 .9236 L p F P
0 g
s
.516 .916 .863 r
.67879 .92146 m .67246 .9236 L p .64561 .93496 L F P
0 g
s
.678 .695 .858 r
.40092 .9371 m .42804 .9247 L p .43493 .93731 L F P
0 g
s
.694 .651 .804 r
.42804 .9247 m .40092 .9371 L .39324 .92505 L p F P
0 g
s
.518 .598 .873 r
.64464 .59429 m .67317 .59513 L p .67078 .60693 L F P
0 g
s
.506 .596 .879 r
.66623 .58333 m .67317 .59513 L .64464 .59429 L p F P
0 g
s
.506 .596 .879 r
.64304 .58249 m .66623 .58333 L p .64464 .59429 L F P
0 g
s
.506 .596 .879 r
.64464 .59429 m .6409 .58785 L .64304 .58249 L p F P
0 g
s
.705 .514 .627 r
.40816 .66585 m .38304 .66572 L .38156 .65605 L p F P
0 g
s
.743 .54 .62 r
.38304 .66572 m .38156 .65605 L .3777 .66516 L closepath p F P
0 g
s
.705 .693 .837 r
.38555 .91176 m .39324 .92505 L .36826 .93767 L p F P
0 g
s
.705 .693 .837 r
.3584 .92745 m .38555 .91176 L p .36826 .93767 L F P
0 g
s
.705 .693 .837 r
.36826 .93767 m .36536 .93751 L .3584 .92745 L p F P
0 g
s
.708 .691 .832 r
.33143 .94154 m .34199 .93597 L .36536 .93751 L p F P
0 g
s
.716 .718 .851 r
.33143 .94154 m .34199 .93597 L .32516 .93356 L closepath p F P
0 g
s
.707 .713 .853 r
.32516 .93356 m .33143 .94154 L p .29663 .9448 L F P
0 g
s
.707 .694 .836 r
.36536 .93751 m .3584 .92745 L .34199 .93597 L closepath p F P
0 g
s
.551 .653 .902 r
.6016 .57119 m .59541 .56195 L .60482 .56118 L closepath p F P
0 g
s
.678 .694 .858 r
.4358 .93727 m .43563 .93703 L .43493 .93731 L closepath p F P
0 g
s
.678 .695 .858 r
.42804 .9247 m .43563 .93703 L .43493 .93731 L p F P
0 g
s
.677 .694 .859 r
.46285 .92638 m .46792 .93442 L .4358 .93727 L p F P
0 g
s
.677 .694 .859 r
.4358 .93727 m .43563 .93703 L .46285 .92638 L p F P
0 g
s
.317 .27 .647 r
.77409 .75848 m .76927 .76378 L .77285 .7801 L p F P
0 g
s
.356 .297 .653 r
.77103 .78184 m .77285 .7801 L .76927 .76378 L p F P
0 g
s
.653 .76 .928 r
.22715 .94835 m .25351 .9399 L .26184 .94747 L p F P
0 g
s
.677 .756 .911 r
.25351 .9399 m .22715 .94835 L .21862 .94195 L p F P
0 g
s
.453 .488 .806 r
.73691 .66942 m .72993 .6673 L p .74365 .68596 L F P
0 g
s
.44 .483 .807 r
.73691 .66942 m .72993 .6673 L .73366 .66176 L closepath p F P
0 g
s
.47 .512 .819 r
.72994 .65367 m .73366 .66176 L .72993 .6673 L p F P
0 g
s
.676 .647 .813 r
.46285 .92638 m .43563 .93703 L .42804 .9247 L p F P
0 g
s
0 0 0 r
.68512 .91786 m .70281 .90808 L .70652 .90425 L closepath p F P
0 g
s
0 0 0 r
.70281 .90808 m .68512 .91786 L p .67246 .9236 L F P
0 g
s
.707 .713 .853 r
.29663 .9448 m .32018 .93304 L .32516 .93356 L p F P
0 g
s
.724 .708 .835 r
.32018 .93304 m .29663 .9448 L .2885 .93597 L p F P
0 g
s
.694 .739 .886 r
.26184 .94747 m .2885 .93597 L .29663 .9448 L p F P
0 g
s
.809 .583 .596 r
.36144 .64732 m .34449 .64237 L .34795 .62863 L p F P
0 g
s
.859 .631 .592 r
.33432 .62257 m .34795 .62863 L .34449 .64237 L p F P
0 g
s
.856 .613 .572 r
.34795 .62863 m .33432 .62257 L .33658 .60928 L p F P
0 g
s
.387 .412 .764 r
.76195 .69394 m .75354 .70574 L .76934 .71456 L p F P
0 g
s
.423 .447 .78 r
.74392 .68607 m .76195 .69394 L .75354 .70574 L p F P
0 g
s
.711 .175 0 r
.10731 .91509 m .09615 .90899 L .08623 .89848 L p F P
0 g
s
.695 .155 0 r
.07536 .89223 m .08623 .89848 L .09615 .90899 L p F P
0 g
s
.901 .662 .568 r
.32554 .6023 m .33658 .60928 L .33432 .62257 L p F P
0 g
s
.904 .638 .524 r
.33658 .60928 m .32554 .6023 L .32655 .58948 L p F P
0 g
s
.711 .733 .868 r
.2885 .93597 m .26184 .94747 L .25351 .9399 L p F P
0 g
s
.424 .449 .781 r
.74392 .68607 m .74365 .68596 L .7438 .68576 L closepath p F P
0 g
s
.453 .488 .806 r
.74365 .68596 m .7438 .68576 L .73691 .66942 L p F P
0 g
s
.943 .68 .508 r
.31756 .58176 m .32655 .58948 L .32554 .6023 L p F P
0 g
s
.945 .63 .406 r
.32655 .58948 m .31756 .58176 L .31689 .57217 L p F P
0 g
s
.737 .533 .617 r
.36144 .64732 m .35656 .66157 L .3777 .66516 L p F P
0 g
s
.817 .601 .609 r
.34449 .64237 m .36144 .64732 L .35656 .66157 L p F P
0 g
s
.41 .44 .781 r
.76195 .69394 m .74392 .68607 L .7438 .68576 L p F P
0 g
s
.41 .44 .781 r
.7438 .68576 m .75126 .67425 L p .76195 .69394 L F P
0 g
s
.428 .474 .805 r
.7438 .68576 m .73691 .66942 L .75126 .67425 L closepath p F P
0 g
s
.571 .669 .905 r
.56042 .55523 m .58829 .55161 L .59541 .56195 L p F P
0 g
s
.572 .677 .91 r
.58829 .55161 m .56042 .55523 L .55321 .54531 L p F P
0 g
s
.161 0 .365 r
.76592 .83295 m .75769 .8399 L .75712 .85185 L p F P
0 g
s
.24 .093 .471 r
.75769 .8399 m .76592 .83295 L .7662 .81918 L p F P
0 g
s
.315 .234 .603 r
.77421 .78807 m .77103 .78184 L .77285 .7801 L closepath p F P
0 g
s
.715 .719 .852 r
.35059 .91521 m .3584 .92745 L .34199 .93597 L p F P
0 g
s
.715 .719 .852 r
.32348 .93143 m .35059 .91521 L p .34199 .93597 L F P
0 g
s
.715 .719 .852 r
.34199 .93597 m .32516 .93356 L .32348 .93143 L p F P
0 g
s
.689 .499 .624 r
.40816 .66585 m .41823 .66552 L .42048 .68094 L p F P
0 g
s
.689 .499 .624 r
.42048 .68094 m .39846 .68167 L .40816 .66585 L p F P
0 g
s
.706 .52 .634 r
.38304 .66572 m .40816 .66585 L .39846 .68167 L p F P
0 g
s
.656 .682 .862 r
.47036 .93834 m .49773 .92946 L .50514 .94043 L p F P
0 g
s
.654 .661 .845 r
.49765 .92933 m .49773 .92946 L .47036 .93834 L p F P
0 g
s
.654 .661 .845 r
.47036 .93834 m .46792 .93442 L .49765 .92933 L p F P
0 g
s
.045 0 .104 r
.73389 .87895 m .73528 .8772 L .73418 .87797 L closepath p F P
0 g
s
.706 .52 .634 r
.39846 .68167 m .38569 .6816 L .38304 .66572 L p F P
0 g
s
.744 .545 .626 r
.3777 .66516 m .38304 .66572 L .38569 .6816 L p F P
0 g
s
.509 .346 .596 r
.46909 .61901 m .45094 .62706 L .46887 .63425 L p F P
0 g
s
.501 .322 .57 r
.46805 .60506 m .46909 .61901 L .45094 .62706 L p F P
0 g
s
.507 .35 .603 r
.44595 .64469 m .46887 .63425 L .45094 .62706 L p F P
0 g
s
.623 .452 .63 r
.42048 .68094 m .41823 .66552 L .44781 .65963 L p F P
0 g
s
.628 .452 .624 r
.44595 .64469 m .44781 .65963 L .41823 .66552 L p F P
0 g
s
.489 .569 .863 r
.69761 .62165 m .68703 .62057 L .68011 .60768 L p F P
0 g
s
.744 .545 .626 r
.38569 .6816 m .37099 .68005 L .3777 .66516 L p F P
0 g
s
.778 .572 .621 r
.35656 .66157 m .3777 .66516 L .37099 .68005 L p F P
0 g
s
.527 .621 .889 r
.6409 .58785 m .63766 .58257 L .64304 .58249 L closepath p F P
0 g
s
.247 .672 .962 r
.15157 .93442 m .1466 .93256 L .14981 .93426 L closepath p F P
0 g
s
0 0 0 r
.73528 .8772 m .75351 .86386 L p .73067 .88711 L F P
0 g
s
0 0 0 r
.73067 .88711 m .73389 .87895 L .73528 .8772 L p F P
0 g
s
.098 0 .205 r
.75573 .86032 m .75712 .85185 L p .73528 .8772 L F P
0 g
s
.098 0 .205 r
.73528 .8772 m .75351 .86386 L .75573 .86032 L p F P
0 g
s
.496 .577 .867 r
.68011 .60768 m .67078 .60693 L .67495 .59822 L closepath p F P
0 g
s
.518 .598 .873 r
.67317 .59513 m .67495 .59822 L .67078 .60693 L p F P
0 g
s
.221 .079 .465 r
.77706 .80952 m .7662 .81918 L .76592 .83295 L p F P
0 g
s
.283 .171 .545 r
.7662 .81918 m .77706 .80952 L .77546 .79534 L p F P
0 g
s
.52 .913 .918 r
.64447 .9349 m .65251 .93175 L .64561 .93496 L closepath p F P
0 g
s
.516 .916 .863 r
.67246 .9236 m .65251 .93175 L .64561 .93496 L p F P
0 g
s
.031 0 .024 r
.71705 .89577 m .73067 .88711 L .73389 .87895 L closepath p F P
0 g
s
0 0 0 r
.70281 .90808 m .70652 .90425 L .71705 .89577 L p F P
0 g
s
0 .392 .768 r
.1074 .91516 m .10776 .91532 L p .1389 .92885 L F P
0 g
s
.59 .021 0 r
.1074 .91516 m .10731 .91509 L .10776 .91532 L closepath p F P
0 g
s
.293 .219 .599 r
.77285 .7801 m .78237 .76973 L p .77697 .7938 L F P
0 g
s
.293 .219 .599 r
.77697 .7938 m .77421 .78807 L .77285 .7801 L p F P
0 g
s
.317 .27 .647 r
.77285 .7801 m .78237 .76973 L .77409 .75848 L p F P
0 g
s
.662 .666 .844 r
.49027 .91669 m .49765 .92933 L .46792 .93442 L p F P
0 g
s
.662 .666 .844 r
.46792 .93442 m .46285 .92638 L .49027 .91669 L p F P
0 g
s
.298 .695 .976 r
.15157 .93442 m .17519 .93488 L p .14082 .92937 L F P
0 g
s
.298 .695 .976 r
.14082 .92937 m .1466 .93256 L .15157 .93442 L p F P
0 g
s
.546 0 0 r
.10731 .91509 m .1074 .91516 L .09819 .91053 L p F P
0 g
s
.546 0 0 r
.09819 .91053 m .09615 .90899 L .10731 .91509 L p F P
0 g
s
.612 .744 .939 r
.54595 .53577 m .54675 .5368 L .54036 .54822 L p F P
0 g
s
.612 .744 .939 r
.5183 .54362 m .54595 .53577 L p .54036 .54822 L F P
0 g
s
.612 .707 .913 r
.55321 .54531 m .54036 .54822 L .54675 .5368 L closepath p F P
0 g
s
0 0 0 r
.71705 .89577 m .73067 .88711 L p .70281 .90808 L F P
0 g
s
.512 .362 .614 r
.44781 .65963 m .44595 .64469 L .46887 .63425 L p F P
0 g
s
0 .392 .768 r
.1389 .92885 m .12731 .92291 L .1074 .91516 L p F P
0 g
s
0 .377 .742 r
.12731 .92291 m .1074 .91516 L .09819 .91053 L p F P
0 g
s
.642 .707 .894 r
.50514 .94043 m .53269 .93286 L .54 .94239 L p F P
0 g
s
.643 .675 .865 r
.53269 .93286 m .50514 .94043 L .49773 .92946 L p F P
0 g
s
.902 .506 .253 r
.05847 .8744 m .05764 .87183 L .0482 .86699 L p F P
0 g
s
.707 .801 .923 r
.51092 .53634 m .51014 .53683 L .5099 .54749 L p F P
0 g
s
.707 .801 .923 r
.5099 .54749 m .5183 .54362 L .51092 .53634 L p F P
0 g
s
.427 .475 .807 r
.75126 .67425 m .73691 .66942 L .73366 .66176 L p F P
0 g
s
.705 .716 .857 r
.32516 .93356 m .32348 .93143 L .32018 .93304 L closepath p F P
0 g
s
.307 .182 .542 r
.47917 .59517 m .46805 .60506 L .46909 .61901 L p F P
0 g
s
.262 .115 .485 r
.46805 .60506 m .47917 .59517 L .47808 .58284 L p F P
0 g
s
.694 .651 .804 r
.39324 .92505 m .42044 .91092 L .42804 .9247 L p F P
0 g
s
.7 .634 .779 r
.42044 .91092 m .39324 .92505 L .38555 .91176 L p F P
0 g
s
.535 .908 .954 r
.65251 .93175 m .64447 .9349 L .63775 .93258 L p F P
0 g
s
.554 .891 .984 r
.60975 .94108 m .63775 .93258 L .64447 .9349 L p F P
0 g
s
.717 .649 .781 r
.38555 .91176 m .3584 .92745 L .35059 .91521 L p F P
0 g
s
.724 .708 .835 r
.2885 .93597 m .29888 .92995 L .32018 .93304 L p F P
0 g
s
.701 .7 .846 r
.31551 .92054 m .29888 .92995 L .32018 .93304 L p F P
0 g
s
.701 .7 .846 r
.32018 .93304 m .32348 .93143 L .31551 .92054 L p F P
0 g
s
.715 .535 .645 r
.39846 .68167 m .42048 .68094 L p .38855 .69772 L F P
0 g
s
.715 .535 .645 r
.38855 .69772 m .38845 .69725 L .39846 .68167 L p F P
0 g
s
.706 .523 .639 r
.38845 .69725 m .39846 .68167 L .38569 .6816 L closepath p F P
0 g
s
.722 .534 .636 r
.38569 .6816 m .37099 .68005 L p .3882 .6977 L F P
0 g
s
.722 .534 .636 r
.3882 .6977 m .38845 .69725 L .38569 .6816 L p F P
0 g
s
.525 .626 .894 r
.64304 .58249 m .63766 .58257 L .63066 .57138 L p F P
0 g
s
.676 .647 .813 r
.42804 .9247 m .45532 .91277 L .46285 .92638 L p F P
0 g
s
.681 .627 .789 r
.45532 .91277 m .42804 .9247 L .42044 .91092 L p F P
0 g
s
.922 .551 .297 r
.04549 .85546 m .0482 .86699 L .03883 .86072 L p F P
0 g
s
.922 .551 .297 r
.03883 .86072 m .03599 .84857 L .04549 .85546 L p F P
0 g
s
.936 .622 .419 r
.04549 .85546 m .03599 .84857 L .03513 .83575 L p F P
0 g
s
.628 .752 .936 r
.54 .94239 m .56772 .93543 L .57489 .94305 L p F P
0 g
s
.63 .707 .902 r
.56772 .93543 m .54 .94239 L .53269 .93286 L p F P
0 g
s
.29 .218 .6 r
.77546 .79534 m .77421 .78807 L .77697 .7938 L closepath p F P
0 g
s
.549 .659 .908 r
.60482 .56118 m .59541 .56195 L .58829 .55161 L p F P
0 g
s
.011 .515 .866 r
.14082 .92937 m .1389 .92885 L .1466 .93256 L closepath p F P
0 g
s
.306 .271 .655 r
.78421 .74655 m .77409 .75848 L .78237 .76973 L p F P
0 g
s
.357 .326 .687 r
.7734 .73608 m .78421 .74655 L .77409 .75848 L p F P
0 g
s
.728 .671 .794 r
.35059 .91521 m .32348 .93143 L .31551 .92054 L p F P
0 g
s
.427 .475 .807 r
.73366 .66176 m .73726 .65553 L p .75126 .67425 L F P
0 g
s
.445 .506 .828 r
.73366 .66176 m .72994 .65367 L .73726 .65553 L closepath p F P
0 g
s
.84 .375 .08 r
.07536 .89223 m .0649 .88578 L .05847 .8744 L p F P
0 g
s
.838 .37 .049 r
.04845 .86775 m .05847 .8744 L .0649 .88578 L p F P
0 g
s
.902 .506 .253 r
.0482 .86699 m .04845 .86775 L .05847 .8744 L p F P
0 g
s
.817 .601 .609 r
.35656 .66157 m .34038 .65638 L .34449 .64237 L p F P
0 g
s
.854 .644 .618 r
.33122 .6362 m .34449 .64237 L .34038 .65638 L p F P
0 g
s
.859 .631 .592 r
.34449 .64237 m .33122 .6362 L .33432 .62257 L p F P
0 g
s
.619 .453 .636 r
.42048 .68094 m .44987 .67483 L p .42891 .6953 L F P
0 g
s
.619 .453 .636 r
.42891 .6953 m .42288 .69656 L .42048 .68094 L p F P
0 g
s
.623 .452 .63 r
.44781 .65963 m .44987 .67483 L .42048 .68094 L p F P
0 g
s
.715 .535 .645 r
.42048 .68094 m .42288 .69656 L .38855 .69772 L p F P
0 g
s
.778 .572 .621 r
.37099 .68005 m .35119 .67604 L .35656 .66157 L p F P
0 g
s
.818 .619 .634 r
.34038 .65638 m .35656 .66157 L .35119 .67604 L p F P
0 g
s
.659 .743 .912 r
.54595 .53577 m .5183 .54362 L .51092 .53634 L p F P
0 g
s
.895 .673 .595 r
.32345 .61564 m .33432 .62257 L .33122 .6362 L p F P
0 g
s
.901 .662 .568 r
.32339 .61539 m .32554 .6023 L p .33432 .62257 L F P
0 g
s
.901 .662 .568 r
.33432 .62257 m .32345 .61564 L .32339 .61539 L p F P
0 g
s
.592 .765 .962 r
.18397 .94067 m .21004 .93513 L .21862 .94195 L p F P
0 g
s
.621 .766 .949 r
.21004 .93513 m .18397 .94067 L .17519 .93488 L p F P
0 g
s
.535 .908 .954 r
.66933 .9234 m .65251 .93175 L p .63775 .93258 L F P
0 g
s
.536 .92 .919 r
.65251 .93175 m .66933 .9234 L .67246 .9236 L closepath p F P
0 g
s
.6 .846 .991 r
.63775 .93258 m .60975 .94108 L .60278 .93583 L p F P
0 g
s
.609 .819 .981 r
.57489 .94305 m .60278 .93583 L .60975 .94108 L p F P
0 g
s
.619 .765 .949 r
.60278 .93583 m .57489 .94305 L .56772 .93543 L p F P
0 g
s
.722 .534 .636 r
.37099 .68005 m .36396 .69509 L .3882 .6977 L p F P
0 g
s
.788 .601 .648 r
.35119 .67604 m .37099 .68005 L .36396 .69509 L p F P
0 g
s
.745 .724 .832 r
.29888 .92995 m .2885 .93597 L .28034 .92658 L p F P
0 g
s
.711 .733 .868 r
.25351 .9399 m .28034 .92658 L .2885 .93597 L p F P
0 g
s
.661 .629 .807 r
.49027 .91669 m .46285 .92638 L .45532 .91277 L p F P
0 g
s
.937 .701 .555 r
.32554 .6023 m .32339 .61539 L .31555 .60028 L p F P
0 g
s
.937 .701 .555 r
.31555 .60028 m .31649 .59461 L .32554 .6023 L p F P
0 g
s
.943 .68 .508 r
.32554 .6023 m .31649 .59461 L .31756 .58176 L p F P
0 g
s
.475 .54 .844 r
.69761 .62165 m .71607 .6248 L p .71959 .63792 L F P
0 g
s
.457 .538 .852 r
.69761 .62165 m .71607 .6248 L .70915 .61133 L p F P
0 g
s
.457 .538 .852 r
.70915 .61133 m .70275 .61017 L .69761 .62165 L p F P
0 g
s
.489 .569 .863 r
.68011 .60768 m .70275 .61017 L .69761 .62165 L p F P
0 g
s
.482 .569 .867 r
.70275 .61017 m .68011 .60768 L .67495 .59822 L p F P
0 g
s
.146 .037 .462 r
.48584 .57337 m .47808 .58284 L .47917 .59517 L p F P
0 g
s
0 0 .202 r
.47808 .58284 m .48584 .57337 L .48757 .56256 L p F P
0 g
s
.695 .155 0 r
.09615 .90899 m .08537 .9027 L .07536 .89223 L p F P
0 g
s
.677 .135 0 r
.0649 .88578 m .07536 .89223 L .08537 .9027 L p F P
0 g
s
.501 .602 .886 r
.64304 .58249 m .66623 .58333 L .65925 .57172 L p F P
0 g
s
.501 .602 .886 r
.65925 .57172 m .64647 .57121 L .64304 .58249 L p F P
0 g
s
.525 .626 .894 r
.63066 .57138 m .64647 .57121 L .64304 .58249 L p F P
0 g
s
.234 .137 .535 r
.77697 .7938 m .77546 .79534 L .77706 .80952 L p F P
0 g
s
.725 .724 .849 r
.28034 .92658 m .25351 .9399 L .24515 .93188 L p F P
0 g
s
.677 .756 .911 r
.21862 .94195 m .24515 .93188 L .25351 .9399 L p F P
0 g
s
.522 .375 .622 r
.44987 .67483 m .44781 .65963 L .47275 .64873 L p F P
0 g
s
.512 .362 .614 r
.47075 .63477 m .47275 .64873 L .44781 .65963 L p F P
0 g
s
.512 .362 .614 r
.46887 .63425 m .47075 .63477 L p .44781 .65963 L F P
0 g
s
.695 .754 .897 r
.24515 .93188 m .21862 .94195 L .21004 .93513 L p F P
0 g
s
.443 .508 .831 r
.73726 .65553 m .72994 .65367 L .72299 .63874 L p F P
0 g
s
.572 .677 .91 r
.55321 .54531 m .58114 .5415 L .58829 .55161 L p F P
0 g
s
.566 .687 .922 r
.57393 .53161 m .58114 .5415 L .55321 .54531 L p F P
0 g
s
.566 .687 .922 r
.54674 .53563 m .57393 .53161 L p .55321 .54531 L F P
0 g
s
.566 .687 .922 r
.55321 .54531 m .54675 .5368 L .54674 .53563 L p F P
0 g
s
.73 .545 .641 r
.38855 .69772 m .38845 .69725 L .3882 .6977 L closepath p F P
0 g
s
.691 .523 .654 r
.38855 .69772 m .42288 .69656 L p .41123 .71364 L F P
0 g
s
.691 .523 .654 r
.41123 .71364 m .3919 .71437 L .38855 .69772 L p F P
0 g
s
.731 .549 .645 r
.3882 .6977 m .38855 .69772 L .3919 .71437 L p F P
0 g
s
.731 .549 .645 r
.3919 .71437 m .37896 .71347 L .3882 .6977 L p F P
0 g
s
.758 .567 .639 r
.36396 .69509 m .3882 .6977 L .37896 .71347 L p F P
0 g
s
.745 .724 .832 r
.28034 .92658 m .28164 .92572 L .29888 .92995 L p F P
0 g
s
.717 .695 .829 r
.30752 .90904 m .28164 .92572 L .29888 .92995 L p F P
0 g
s
.717 .695 .829 r
.29888 .92995 m .31551 .92054 L .30752 .90904 L p F P
0 g
s
.161 0 .365 r
.75712 .85185 m .76198 .84778 L .76592 .83295 L p F P
0 g
s
.129 0 .342 r
.77764 .82261 m .76592 .83295 L .76198 .84778 L p F P
0 g
s
.221 .079 .465 r
.76592 .83295 m .77764 .82261 L .77706 .80952 L p F P
0 g
s
.329 .317 .695 r
.78201 .72501 m .7734 .73608 L .78421 .74655 L p F P
0 g
s
.368 .373 .733 r
.78153 .7235 m .76934 .71456 L p .7734 .73608 L F P
0 g
s
.368 .373 .733 r
.7734 .73608 m .78201 .72501 L .78153 .7235 L p F P
0 g
s
.7 .634 .779 r
.41967 .90934 m .42044 .91092 L p .38555 .91176 L F P
0 g
s
.7 .634 .779 r
.38555 .91176 m .38908 .90965 L .41967 .90934 L p F P
0 g
s
.705 .646 .788 r
.38555 .91176 m .38908 .90965 L .38442 .9096 L closepath p F P
0 g
s
.717 .649 .781 r
.38442 .9096 m .38555 .91176 L p .35059 .91521 L F P
0 g
s
.643 .675 .865 r
.52626 .92302 m .53269 .93286 L p .49773 .92946 L F P
0 g
s
.643 .675 .865 r
.49773 .92946 m .50039 .9287 L .52626 .92302 L p F P
0 g
s
.64 .642 .836 r
.49773 .92946 m .50039 .9287 L .49765 .92933 L closepath p F P
0 g
s
.234 .137 .535 r
.77706 .80952 m .77985 .80669 L .77697 .7938 L p F P
0 g
s
.213 .123 .531 r
.78804 .78182 m .77697 .7938 L .77985 .80669 L p F P
0 g
s
.293 .219 .599 r
.78237 .76973 m .78804 .78182 L .77697 .7938 L p F P
0 g
s
.64 .644 .838 r
.50039 .9287 m .49765 .92933 L .49027 .91669 L p F P
0 g
s
.057 0 .22 r
.75573 .86032 m .76198 .84778 L .75712 .85185 L closepath p F P
0 g
s
.532 .642 .903 r
.60482 .56118 m .62362 .56039 L .61654 .54961 L p F P
0 g
s
.532 .642 .903 r
.61654 .54961 m .60726 .55002 L .60482 .56118 L p F P
0 g
s
.549 .659 .908 r
.58829 .55161 m .60726 .55002 L .60482 .56118 L p F P
0 g
s
.681 .627 .789 r
.45246 .9069 m .45532 .91277 L p .42044 .91092 L F P
0 g
s
.681 .627 .789 r
.42044 .91092 m .42435 .90899 L .45246 .9069 L p F P
0 g
s
.68 .625 .787 r
.42044 .91092 m .42435 .90899 L .41967 .90934 L closepath p F P
0 g
s
.62 .458 .641 r
.42328 .69902 m .42891 .6953 L .42288 .69656 L closepath p F P
0 g
s
.691 .523 .654 r
.42288 .69656 m .42328 .69902 L .41123 .71364 L p F P
0 g
s
.7 .636 .782 r
.41967 .90934 m .41284 .89559 L .38908 .90965 L closepath p F P
0 g
s
.704 .647 .79 r
.40827 .88542 m .41284 .89559 L .38908 .90965 L p F P
0 g
s
.704 .647 .79 r
.39532 .88538 m .40827 .88542 L p .38908 .90965 L F P
0 g
s
.704 .647 .79 r
.37786 .89721 m .39532 .88538 L p .38908 .90965 L F P
0 g
s
.704 .647 .79 r
.38908 .90965 m .38442 .9096 L .37786 .89721 L p F P
0 g
s
.717 .649 .781 r
.35059 .91521 m .36075 .90843 L .38442 .9096 L p F P
0 g
s
.716 .652 .784 r
.38442 .9096 m .37786 .89721 L .36075 .90843 L closepath p F P
0 g
s
.328 .216 .57 r
.48295 .60675 m .46909 .61901 L .47059 .6335 L p F P
0 g
s
.307 .182 .542 r
.46909 .61901 m .48295 .60675 L .47917 .59517 L p F P
0 g
s
.509 .346 .596 r
.46887 .63425 m .47059 .6335 L .46909 .61901 L p F P
0 g
s
.727 .673 .797 r
.35059 .91521 m .36075 .90843 L .34567 .90691 L closepath p F P
0 g
s
.728 .671 .794 r
.34567 .90691 m .35059 .91521 L p .31551 .92054 L F P
0 g
s
.081 .554 .902 r
.1389 .92885 m .14082 .92937 L .13179 .92398 L p F P
0 g
s
.081 .554 .902 r
.13179 .92398 m .12731 .92291 L .1389 .92885 L p F P
0 g
s
.68 .627 .789 r
.42435 .90899 m .41967 .90934 L .41284 .89559 L p F P
0 g
s
.643 .674 .864 r
.52626 .92302 m .52532 .92159 L .50039 .9287 L closepath p F P
0 g
s
.64 .644 .838 r
.51789 .9085 m .52532 .92159 L .50039 .9287 L p F P
0 g
s
.64 .644 .838 r
.49027 .91669 m .51789 .9085 L p .50039 .9287 L F P
0 g
s
.445 .513 .834 r
.72299 .63874 m .71959 .63792 L .72118 .63489 L closepath p F P
0 g
s
.475 .54 .844 r
.71607 .6248 m .72118 .63489 L .71959 .63792 L p F P
0 g
s
.629 .474 .654 r
.42585 .71279 m .42328 .69902 L .42891 .6953 L p F P
0 g
s
.682 .51 .647 r
.42585 .71279 m .42328 .69902 L .41123 .71364 L closepath p F P
0 g
s
.502 0 0 r
.09615 .90899 m .09819 .91053 L .08894 .90531 L p F P
0 g
s
.502 0 0 r
.08894 .90531 m .08537 .9027 L .09615 .90899 L p F P
0 g
s
.681 .628 .79 r
.45246 .9069 m .44778 .89744 L .42435 .90899 L closepath p F P
0 g
s
.68 .627 .789 r
.44155 .88331 m .44778 .89744 L .42435 .90899 L p F P
0 g
s
.68 .627 .789 r
.43399 .8838 m .44155 .88331 L p .42435 .90899 L F P
0 g
s
.68 .627 .789 r
.41284 .89559 m .43399 .8838 L p .42435 .90899 L F P
0 g
s
.788 .601 .648 r
.34556 .69028 m .35119 .67604 L p .36396 .69509 L F P
0 g
s
.817 .623 .64 r
.34556 .69028 m .35119 .67604 L .34075 .67258 L closepath p F P
0 g
s
.818 .619 .634 r
.33826 .6629 m .34038 .65638 L p .35119 .67604 L F P
0 g
s
.818 .619 .634 r
.35119 .67604 m .34075 .67258 L .33826 .6629 L p F P
0 g
s
.629 .474 .654 r
.42891 .6953 m .45242 .69057 L p .42585 .71279 L F P
0 g
s
.624 .462 .643 r
.45242 .69057 m .45069 .68044 L .42891 .6953 L closepath p F P
0 g
s
.619 .453 .636 r
.44987 .67483 m .45069 .68044 L .42891 .6953 L p F P
0 g
s
.298 .695 .976 r
.17519 .93488 m .16636 .92872 L .14082 .92937 L p F P
0 g
s
.476 .737 .985 r
.16636 .92872 m .14082 .92937 L .13179 .92398 L p F P
0 g
s
0 0 0 r
.67246 .9236 m .7005 .90948 L .70281 .90808 L p F P
0 g
s
.619 .953 .922 r
.66933 .9234 m .67246 .9236 L .7005 .90948 L p F P
0 g
s
.726 .674 .799 r
.37171 .88464 m .37786 .89721 L .36075 .90843 L p F P
0 g
s
.726 .674 .799 r
.3664 .88428 m .37171 .88464 L p .36075 .90843 L F P
0 g
s
.726 .674 .799 r
.34276 .90205 m .3664 .88428 L p .36075 .90843 L F P
0 g
s
.726 .674 .799 r
.36075 .90843 m .34567 .90691 L .34276 .90205 L p F P
0 g
s
.35 .362 .732 r
.78153 .7235 m .76934 .71456 L .77575 .7055 L closepath p F P
0 g
s
.387 .412 .764 r
.7741 .70092 m .76195 .69394 L p .76934 .71456 L F P
0 g
s
.387 .412 .764 r
.76934 .71456 m .77575 .7055 L .7741 .70092 L p F P
0 g
s
.853 .649 .626 r
.33826 .6629 m .34038 .65638 L .33561 .65419 L closepath p F P
0 g
s
.854 .644 .618 r
.3309 .63739 m .33122 .6362 L p .34038 .65638 L F P
0 g
s
.854 .644 .618 r
.34038 .65638 m .33561 .65419 L .3309 .63739 L p F P
0 g
s
.482 .569 .867 r
.67495 .59822 m .67605 .5953 L p .70275 .61017 L F P
0 g
s
.499 .594 .88 r
.67495 .59822 m .67317 .59513 L .67605 .5953 L closepath p F P
0 g
s
.758 .567 .639 r
.37896 .71347 m .3566 .71028 L .36396 .69509 L p F P
0 g
s
.786 .604 .653 r
.34569 .69079 m .36396 .69509 L .3566 .71028 L p F P
0 g
s
.788 .601 .648 r
.36396 .69509 m .34569 .69079 L .34556 .69028 L p F P
0 g
s
.691 .524 .656 r
.3919 .71437 m .41123 .71364 L .39659 .73109 L p F P
0 g
s
.691 .524 .656 r
.39659 .73109 m .39535 .73114 L .3919 .71437 L p F P
0 g
s
.731 .55 .647 r
.37896 .71347 m .3919 .71437 L .39535 .73114 L p F P
0 g
s
.52 .629 .899 r
.64647 .57121 m .63066 .57138 L .62362 .56039 L p F P
0 g
s
.661 .629 .807 r
.45532 .91277 m .48278 .90219 L .49027 .91669 L p F P
0 g
s
.657 .615 .796 r
.48274 .90212 m .48278 .90219 L .45532 .91277 L p F P
0 g
s
.657 .615 .796 r
.45532 .91277 m .45246 .9069 L .48274 .90212 L p F P
0 g
s
.728 .671 .794 r
.31551 .92054 m .33684 .906 L .34567 .90691 L p F P
0 g
s
.743 .674 .783 r
.33684 .906 m .31551 .92054 L .30752 .90904 L p F P
0 g
s
0 0 0 r
.72842 .89043 m .71129 .9027 L .70281 .90808 L p F P
0 g
s
0 0 0 r
.73067 .88711 m .72842 .89043 L p .70281 .90808 L F P
0 g
s
.389 .807 .613 r
.7005 .90948 m .71129 .9027 L .70281 .90808 L closepath p F P
0 g
s
.63 .707 .902 r
.53269 .93286 m .56047 .92604 L .56772 .93543 L p F P
0 g
s
.627 .665 .867 r
.55315 .91492 m .56047 .92604 L .53269 .93286 L p F P
0 g
s
.627 .665 .867 r
.55044 .91557 m .55315 .91492 L p .53269 .93286 L F P
0 g
s
.627 .665 .867 r
.53269 .93286 m .52626 .92302 L .55044 .91557 L p F P
0 g
s
.892 .68 .609 r
.3309 .63739 m .33122 .6362 L .3302 .63556 L closepath p F P
0 g
s
.895 .673 .595 r
.33122 .6362 m .3302 .63556 L .32345 .61564 L p F P
0 g
s
.427 .475 .807 r
.73726 .65553 m .75778 .66274 L .75126 .67425 L p F P
0 g
s
.41 .479 .82 r
.743 .64412 m .73726 .65553 L .75778 .66274 L p F P
0 g
s
.443 .508 .831 r
.72299 .63874 m .743 .64412 L .73726 .65553 L p F P
0 g
s
.682 .511 .649 r
.41123 .71364 m .42585 .71279 L .42898 .72922 L p F P
0 g
s
.682 .511 .649 r
.42898 .72922 m .39659 .73109 L .41123 .71364 L p F P
0 g
s
.537 .391 .629 r
.44987 .67483 m .47513 .66425 L p .47241 .68214 L F P
0 g
s
.537 .391 .629 r
.47241 .68214 m .45069 .68044 L .44987 .67483 L p F P
0 g
s
.522 .375 .622 r
.47275 .64873 m .47513 .66425 L .44987 .67483 L p F P
0 g
s
.432 .505 .834 r
.743 .64412 m .72299 .63874 L .72118 .63489 L p F P
0 g
s
.547 .665 .914 r
.60726 .55002 m .58829 .55161 L .58114 .5415 L p F P
0 g
s
0 .377 .742 r
.09819 .91053 m .11607 .91682 L .12731 .92291 L p F P
0 g
s
0 .438 .811 r
.11607 .91682 m .09819 .91053 L .08894 .90531 L p F P
0 g
s
.762 .591 .665 r
.3566 .71028 m .37896 .71347 L .36956 .72934 L p F P
0 g
s
.731 .55 .647 r
.39535 .73114 m .36956 .72934 L .37896 .71347 L p F P
0 g
s
.369 .402 .764 r
.7741 .70092 m .76195 .69394 L .76808 .6843 L closepath p F P
0 g
s
.41 .44 .781 r
.76687 .68127 m .76808 .6843 L .76195 .69394 L p F P
0 g
s
.41 .44 .781 r
.75126 .67425 m .76687 .68127 L p .76195 .69394 L F P
0 g
s
.836 .635 .631 r
.33561 .65419 m .3309 .63739 L .32627 .65049 L closepath p F P
0 g
s
.866 .672 .638 r
.32627 .65049 m .3309 .63739 L .3302 .63556 L p F P
0 g
s
.866 .672 .638 r
.3302 .63556 m .31909 .6296 L p .32627 .65049 L F P
0 g
s
.871 .664 .62 r
.32335 .61558 m .32345 .61564 L .3302 .63556 L p F P
0 g
s
.871 .664 .62 r
.3302 .63556 m .31909 .6296 L .32335 .61558 L p F P
0 g
s
.496 .598 .885 r
.67605 .5953 m .67317 .59513 L .66623 .58333 L p F P
0 g
s
.382 .43 .787 r
.75126 .67425 m .76687 .68127 L .75977 .66368 L p F P
0 g
s
.382 .43 .787 r
.75977 .66368 m .75778 .66274 L .75126 .67425 L p F P
0 g
s
.906 .505 .226 r
.04845 .86775 m .0482 .86699 L .03883 .86072 L p F P
0 g
s
.727 .674 .798 r
.34567 .90691 m .34276 .90205 L .33684 .906 L closepath p F P
0 g
s
.666 .621 .795 r
.47526 .88579 m .48274 .90212 L .45246 .9069 L p F P
0 g
s
.666 .621 .795 r
.45246 .9069 m .44778 .89744 L .47526 .88579 L p F P
0 g
s
.62 .47 .657 r
.42585 .71279 m .45525 .70664 L p .45431 .72372 L F P
0 g
s
.62 .47 .657 r
.45431 .72372 m .42898 .72922 L .42585 .71279 L p F P
0 g
s
.629 .474 .654 r
.45242 .69057 m .45525 .70664 L .42585 .71279 L p F P
0 g
s
.874 .648 .593 r
.32345 .61564 m .32339 .61539 L .32335 .61558 L closepath p F P
0 g
s
.921 .703 .591 r
.32335 .61558 m .32339 .61539 L .31555 .60028 L p F P
0 g
s
.917 .718 .618 r
.3137 .6081 m .32335 .61558 L .31909 .6296 L p F P
0 g
s
.921 .703 .591 r
.31555 .60028 m .3137 .6081 L .32335 .61558 L p F P
0 g
s
.432 .505 .834 r
.72118 .63489 m .72486 .62652 L p .743 .64412 L F P
0 g
s
.452 .535 .852 r
.72118 .63489 m .71607 .6248 L .72486 .62652 L closepath p F P
0 g
s
.838 .37 .049 r
.0649 .88578 m .05488 .87913 L .04845 .86775 L p F P
0 g
s
.835 .363 .017 r
.03888 .86089 m .04845 .86775 L .05488 .87913 L p F P
0 g
s
.906 .505 .226 r
.03883 .86072 m .03888 .86089 L .04845 .86775 L p F P
0 g
s
.713 .638 .772 r
.37786 .89721 m .39532 .88538 L .37171 .88464 L closepath p F P
0 g
s
.164 .038 .45 r
.77985 .80669 m .77706 .80952 L .77764 .82261 L p F P
0 g
s
0 0 0 r
.72842 .89043 m .73786 .88186 L .73067 .88711 L closepath p F P
0 g
s
0 0 0 r
.75351 .86386 m .73786 .88186 L .73067 .88711 L p F P
0 g
s
.827 .636 .645 r
.33561 .65419 m .32627 .65049 L p .33505 .67085 L F P
0 g
s
.827 .636 .645 r
.33505 .67085 m .33826 .6629 L .33561 .65419 L p F P
0 g
s
.748 .733 .838 r
.28034 .92658 m .28164 .92572 L .27903 .92499 L closepath p F P
0 g
s
.725 .724 .849 r
.27903 .92499 m .28034 .92658 L p .24515 .93188 L F P
0 g
s
.685 .613 .769 r
.41284 .89559 m .43399 .8838 L .40827 .88542 L closepath p F P
0 g
s
.809 .615 .639 r
.34075 .67258 m .33826 .6629 L .33505 .67085 L closepath p F P
0 g
s
.748 .733 .838 r
.30127 .89968 m .30752 .90904 L .28164 .92572 L p F P
0 g
s
.748 .733 .838 r
.29686 .89889 m .30127 .89968 L p .28164 .92572 L F P
0 g
s
.748 .733 .838 r
.27215 .91671 m .29686 .89889 L p .28164 .92572 L F P
0 g
s
.748 .733 .838 r
.28164 .92572 m .27903 .92499 L .27215 .91671 L p F P
0 g
s
.537 .403 .645 r
.45242 .69057 m .45069 .68044 L .47241 .68214 L closepath p F P
0 g
s
.516 .363 .611 r
.47075 .63477 m .46887 .63425 L .47059 .6335 L closepath p F P
0 g
s
0 0 .131 r
.76198 .84778 m .77627 .83526 L p .75527 .86253 L F P
0 g
s
0 0 .131 r
.75527 .86253 m .75573 .86032 L .76198 .84778 L p F P
0 g
s
.129 0 .342 r
.77724 .83184 m .77764 .82261 L p .76198 .84778 L F P
0 g
s
.129 0 .342 r
.76198 .84778 m .77627 .83526 L .77724 .83184 L p F P
0 g
s
.619 .765 .949 r
.56772 .93543 m .5957 .92871 L .60278 .93583 L p F P
0 g
s
.619 .717 .917 r
.5957 .92871 m .56772 .93543 L .56047 .92604 L p F P
0 g
s
.743 .674 .783 r
.30752 .90904 m .31551 .90283 L .33684 .906 L p F P
0 g
s
.722 .662 .79 r
.33493 .88807 m .31551 .90283 L .33684 .906 L p F P
0 g
s
.722 .662 .79 r
.33684 .906 m .34276 .90205 L .33493 .88807 L p F P
0 g
s
.482 .569 .867 r
.67605 .5953 m .70222 .5984 L p .70275 .61017 L F P
0 g
s
.467 .569 .875 r
.67605 .5953 m .70222 .5984 L .69529 .58616 L p F P
0 g
s
.467 .569 .875 r
.69529 .58616 m .67935 .58416 L .67605 .5953 L p F P
0 g
s
.496 .598 .885 r
.66623 .58333 m .67935 .58416 L .67605 .5953 L p F P
0 g
s
.691 .527 .659 r
.39559 .73226 m .39659 .73109 L .39535 .73114 L closepath p F P
0 g
s
.743 .583 .677 r
.39535 .73114 m .39559 .73226 L .38431 .74787 L p F P
0 g
s
.743 .583 .677 r
.36956 .72934 m .39535 .73114 L p .38431 .74787 L F P
0 g
s
.681 .528 .672 r
.39659 .73109 m .42898 .72922 L p .42 .74706 L F P
0 g
s
.681 .528 .672 r
.39559 .73226 m .39659 .73109 L p .42 .74706 L F P
0 g
s
.22 .136 .542 r
.48629 .58663 m .47917 .59517 L .48295 .60675 L p F P
0 g
s
.146 .037 .462 r
.47917 .59517 m .48629 .58663 L .48584 .57337 L p F P
0 g
s
.903 .978 .696 r
.50991 .53544 m .51014 .53683 L .49229 .55517 L p F P
0 g
s
.765 .834 .905 r
.51014 .53683 m .50991 .53544 L .51092 .53634 L closepath p F P
0 g
s
.641 .618 .811 r
.51789 .9085 m .49027 .91669 L .48278 .90219 L p F P
0 g
s
.681 .528 .672 r
.42 .74706 m .39934 .74846 L .39559 .73226 L p F P
0 g
s
.72 .553 .662 r
.39934 .74846 m .39559 .73226 L .38431 .74787 L closepath p F P
0 g
s
.584 .702 .924 r
.54675 .5368 m .54595 .53577 L .54674 .53563 L closepath p F P
0 g
s
.254 .197 .598 r
.7909 .75977 m .78237 .76973 L .78804 .78182 L p F P
0 g
s
.306 .271 .655 r
.78953 .75389 m .78421 .74655 L p .78237 .76973 L F P
0 g
s
.306 .271 .655 r
.78237 .76973 m .7909 .75977 L .78953 .75389 L p F P
0 g
s
.659 .743 .912 r
.51092 .53634 m .53864 .5268 L .54595 .53577 L p F P
0 g
s
.654 .808 .957 r
.50991 .53544 m .51092 .53634 L .53864 .5268 L p F P
0 g
s
.797 .612 .651 r
.34075 .67258 m .33505 .67085 L p .34536 .69071 L F P
0 g
s
.797 .612 .651 r
.34536 .69071 m .34556 .69028 L .34075 .67258 L p F P
0 g
s
.535 .908 .954 r
.63775 .93258 m .66592 .92275 L .66933 .9234 L p F P
0 g
s
.589 .881 .992 r
.66592 .92275 m .63775 .93258 L .6309 .92817 L p F P
0 g
s
.6 .846 .991 r
.60278 .93583 m .6309 .92817 L .63775 .93258 L p F P
0 g
s
.725 .724 .849 r
.24515 .93188 m .26277 .92189 L .27903 .92499 L p F P
0 g
s
.723 .727 .854 r
.27903 .92499 m .27215 .91671 L .26277 .92189 L closepath p F P
0 g
s
.621 .766 .949 r
.17519 .93488 m .20142 .928 L .21004 .93513 L p F P
0 g
s
.643 .768 .939 r
.20142 .928 m .17519 .93488 L .16636 .92872 L p F P
0 g
s
.415 .29 .601 r
.47059 .6335 m .4883 .61794 L p .47876 .64409 L F P
0 g
s
.415 .29 .601 r
.47876 .64409 m .47075 .63477 L .47059 .6335 L p F P
0 g
s
.328 .216 .57 r
.47059 .6335 m .4883 .61794 L .48295 .60675 L p F P
0 g
s
.736 .639 .751 r
.3664 .88428 m .34276 .90205 L .33493 .88807 L p F P
0 g
s
.677 .135 0 r
.08537 .9027 m .07498 .89624 L .0649 .88578 L p F P
0 g
s
.657 .115 0 r
.05488 .87913 m .0649 .88578 L .07498 .89624 L p F P
0 g
s
.744 .737 .845 r
.26277 .92189 m .24515 .93188 L .23675 .92353 L p F P
0 g
s
.695 .754 .897 r
.21004 .93513 m .23675 .92353 L .24515 .93188 L p F P
0 g
s
.612 .789 .967 r
.6309 .92817 m .60278 .93583 L .5957 .92871 L p F P
0 g
s
.393 .286 .612 r
.47275 .64873 m .47075 .63477 L .47876 .64409 L closepath p F P
0 g
s
.581 .712 .932 r
.54674 .53563 m .54595 .53577 L .53864 .5268 L p F P
0 g
s
.662 .6 .774 r
.47251 .87902 m .47526 .88579 L .44778 .89744 L p F P
0 g
s
.662 .6 .774 r
.44778 .89744 m .44155 .88331 L .47251 .87902 L p F P
0 g
s
.903 .978 .696 r
.50349 .531 m .50991 .53544 L p .49229 .55517 L F P
0 g
s
.903 .978 .696 r
.49229 .55517 m .49513 .54362 L p .49733 .5443 L F P
0 g
s
0 0 0 r
.4922 .55724 m .49513 .54362 L p .49248 .55372 L F P
0 g
s
0 0 0 r
.48845 .56905 m .4922 .55724 L p .49248 .55372 L F P
0 g
s
0 0 .252 r
.49264 .56987 m .4922 .55724 L p .49145 .56349 L F P
0 g
s
0 0 .252 r
.48929 .58151 m .49264 .56987 L p .49145 .56349 L F P
0 g
s
.725 .503 0 r
.49264 .56987 m .49476 .58206 L p .49385 .5763 L F P
0 g
s
.807 .619 .061 r
.4922 .55724 m .49264 .56987 L p .49192 .5608 L F P
0 g
s
0 0 .252 r
.4922 .55724 m .48845 .56905 L .48929 .58151 L p F P
0 g
s
.807 .619 .061 r
.49122 .55964 m .49081 .54697 L p .49138 .55407 L F P
0 g
s
.807 .619 .061 r
.49264 .56987 m .49122 .55964 L p .49138 .55407 L F P
0 g
s
0 0 .36 r
.49264 .56987 m .48929 .58151 L .49214 .59343 L p F P
0 g
s
0 0 .36 r
.49214 .59343 m .49476 .58206 L .49264 .56987 L p F P
0 g
s
.921 .612 .137 r
.49122 .55964 m .49301 .57195 L p .49105 .56526 L F P
0 g
s
.921 .612 .137 r
.48668 .5503 m .49122 .55964 L p .49105 .56526 L F P
0 g
s
.725 .503 0 r
.49122 .55964 m .49264 .56987 L p .49385 .5763 L F P
0 g
s
.807 .619 .061 r
.49081 .54697 m .4922 .55724 L p .49192 .5608 L F P
0 g
s
.939 .802 .343 r
.49513 .54362 m .4922 .55724 L p .49268 .54285 L F P
0 g
s
.939 .802 .343 r
.493 .53356 m .49513 .54362 L p .49268 .54285 L F P
0 g
s
.903 .978 .696 r
.49513 .54362 m .50349 .531 L p .49733 .5443 L F P
0 g
s
.685 .614 .771 r
.43399 .8838 m .40827 .88542 L .40524 .87873 L p F P
0 g
s
.706 .624 .763 r
.40827 .88542 m .40524 .87873 L .39532 .88538 L closepath p F P
0 g
s
.713 .639 .773 r
.39883 .86315 m .40524 .87873 L .39532 .88538 L p F P
0 g
s
.713 .639 .773 r
.39404 .86306 m .39883 .86315 L p .39532 .88538 L F P
0 g
s
.713 .639 .773 r
.37017 .8815 m .39404 .86306 L p .39532 .88538 L F P
0 g
s
.713 .639 .773 r
.39532 .88538 m .37171 .88464 L .37017 .8815 L p F P
0 g
s
.581 .712 .932 r
.53864 .5268 m .54457 .52569 L .54674 .53563 L p F P
0 g
s
.579 .708 .931 r
.54674 .53563 m .57393 .53161 L .56668 .52197 L p F P
0 g
s
.579 .708 .931 r
.56668 .52197 m .54457 .52569 L .54674 .53563 L p F P
0 g
s
.654 .808 .957 r
.53128 .51808 m .51773 .52366 L .50991 .53544 L p F P
0 g
s
.654 .808 .957 r
.53864 .5268 m .53128 .51808 L p .50991 .53544 L F P
0 g
s
.727 .869 .948 r
.50349 .531 m .51773 .52366 L .50991 .53544 L closepath p F P
0 g
s
.762 .591 .665 r
.35287 .71772 m .3566 .71028 L p .36956 .72934 L F P
0 g
s
.786 .605 .656 r
.35287 .71772 m .3566 .71028 L .35047 .70887 L closepath p F P
0 g
s
.786 .604 .653 r
.3566 .71028 m .35047 .70887 L .34569 .69079 L p F P
0 g
s
.788 .601 .647 r
.34569 .69079 m .34556 .69028 L .34536 .69071 L closepath p F P
0 g
s
.711 .753 .886 r
.23675 .92353 m .21004 .93513 L .20142 .928 L p F P
0 g
s
.789 .605 .652 r
.34536 .69071 m .34569 .69079 L .35047 .70887 L p F P
0 g
s
.789 .605 .652 r
.35047 .70887 m .33804 .7059 L .34536 .69071 L p F P
0 g
s
.821 .634 .649 r
.32886 .68564 m .34536 .69071 L .33804 .7059 L p F P
0 g
s
.797 .612 .651 r
.33505 .67085 m .32886 .68564 L .34536 .69071 L p F P
0 g
s
.538 .407 .649 r
.45525 .70664 m .45242 .69057 L .47241 .68214 L p F P
0 g
s
.743 .583 .677 r
.36022 .74482 m .36956 .72934 L p .38431 .74787 L F P
0 g
s
.762 .592 .667 r
.36022 .74482 m .36956 .72934 L .35538 .72709 L closepath p F P
0 g
s
.762 .591 .665 r
.36956 .72934 m .35538 .72709 L .35287 .71772 L p F P
0 g
s
.621 .472 .659 r
.43048 .7369 m .45431 .72372 L .42898 .72922 L closepath p F P
0 g
s
.681 .528 .672 r
.42898 .72922 m .43048 .7369 L .42 .74706 L p F P
0 g
s
.849 .657 .643 r
.32094 .66496 m .33505 .67085 L .32886 .68564 L p F P
0 g
s
.827 .636 .645 r
.32627 .65049 m .32094 .66496 L .33505 .67085 L p F P
0 g
s
.724 .643 .768 r
.37171 .88464 m .37017 .8815 L .3664 .88428 L closepath p F P
0 g
s
.595 .932 .955 r
.66592 .92275 m .68373 .91532 L .66933 .9234 L closepath p F P
0 g
s
.619 .953 .922 r
.6942 .91071 m .68373 .91532 L .66933 .9234 L p F P
0 g
s
.619 .953 .922 r
.7005 .90948 m .6942 .91071 L p .66933 .9234 L F P
0 g
s
.681 .529 .673 r
.40286 .7635 m .42 .74706 L .39934 .74846 L closepath p F P
0 g
s
.701 .541 .668 r
.39934 .74846 m .38431 .74787 L p .40076 .76593 L F P
0 g
s
.701 .541 .668 r
.40076 .76593 m .40286 .7635 L .39934 .74846 L p F P
0 g
s
.357 .797 .634 r
.71129 .9027 m .7005 .90948 L .6942 .91071 L p F P
0 g
s
.164 .038 .45 r
.77764 .82261 m .77976 .82048 L .77985 .80669 L p F P
0 g
s
.137 .017 .441 r
.79095 .79477 m .77985 .80669 L .77976 .82048 L p F P
0 g
s
.213 .123 .531 r
.77985 .80669 m .79095 .79477 L .78804 .78182 L p F P
0 g
s
0 0 .399 r
.48845 .56905 m .48584 .57337 L .48629 .58663 L p F P
0 g
s
.685 .614 .771 r
.40524 .87873 m .43237 .86158 L p .43399 .8838 L F P
0 g
s
.691 .602 .752 r
.40524 .87873 m .43237 .86158 L .39883 .86315 L closepath p F P
0 g
s
.736 .639 .751 r
.33493 .88807 m .34212 .88189 L .3664 .88428 L p F P
0 g
s
.717 .629 .758 r
.36248 .86466 m .34212 .88189 L .3664 .88428 L p F P
0 g
s
.717 .629 .758 r
.3664 .88428 m .37017 .8815 L .36248 .86466 L p F P
0 g
s
.628 .667 .869 r
.52626 .92302 m .52532 .92159 L .55044 .91557 L closepath p F P
0 g
s
.136 .582 .926 r
.12731 .92291 m .13179 .92398 L .12272 .91822 L p F P
0 g
s
.136 .582 .926 r
.12272 .91822 m .11607 .91682 L .12731 .92291 L p F P
0 g
s
.449 .538 .856 r
.72486 .62652 m .71607 .6248 L .70915 .61133 L p F P
0 g
s
.722 .607 .729 r
.39404 .86306 m .37017 .8815 L .36248 .86466 L p F P
0 g
s
.701 .541 .668 r
.38431 .74787 m .37212 .76466 L .40076 .76593 L p F P
0 g
s
.743 .585 .679 r
.36038 .74541 m .38431 .74787 L .37212 .76466 L p F P
0 g
s
.743 .583 .677 r
.38431 .74787 m .36038 .74541 L .36022 .74482 L p F P
0 g
s
.068 0 .181 r
.75351 .86386 m .75527 .86253 L .75573 .86032 L closepath p F P
0 g
s
.774 .598 .662 r
.35047 .70887 m .33804 .7059 L p .34842 .72579 L F P
0 g
s
.774 .598 .662 r
.34842 .72579 m .35287 .71772 L .35047 .70887 L p F P
0 g
s
.755 .7 .799 r
.30752 .90904 m .31551 .90283 L .30127 .89968 L closepath p F P
0 g
s
.88 .687 .636 r
.31442 .64382 m .32627 .65049 L .32094 .66496 L p F P
0 g
s
.866 .672 .638 r
.31909 .6296 m .31442 .64382 L .32627 .65049 L p F P
0 g
s
.685 .612 .769 r
.44155 .88331 m .44023 .88035 L .43399 .8838 L closepath p F P
0 g
s
.685 .614 .771 r
.43275 .86155 m .44023 .88035 L .43399 .8838 L p F P
0 g
s
.685 .614 .771 r
.43237 .86158 m .43275 .86155 L p .43399 .8838 L F P
0 g
s
.626 .634 .838 r
.55044 .91557 m .52532 .92159 L .51789 .9085 L p F P
0 g
s
.629 .49 .674 r
.43252 .74608 m .43048 .7369 L .45431 .72372 L p F P
0 g
s
.676 .52 .667 r
.43252 .74608 m .43048 .7369 L .42 .74706 L closepath p F P
0 g
s
.755 .7 .8 r
.33067 .88009 m .33493 .88807 L .31551 .90283 L p F P
0 g
s
.755 .7 .8 r
.3209 .87862 m .33067 .88009 L p .31551 .90283 L F P
0 g
s
.755 .7 .8 r
.2995 .89703 m .3209 .87862 L p .31551 .90283 L F P
0 g
s
.755 .7 .8 r
.31551 .90283 m .30127 .89968 L .2995 .89703 L p F P
0 g
s
.772 .596 .661 r
.35538 .72709 m .35287 .71772 L .34842 .72579 L closepath p F P
0 g
s
.668 .604 .774 r
.46774 .86741 m .47251 .87902 L .44155 .88331 L p F P
0 g
s
.668 .604 .774 r
.44155 .88331 m .44023 .88035 L .46774 .86741 L p F P
0 g
s
0 0 0 r
.75527 .86253 m .75351 .86386 L .73786 .88186 L p F P
0 g
s
.46 0 0 r
.08537 .9027 m .08894 .90531 L .07967 .89956 L p F P
0 g
s
.46 0 0 r
.07967 .89956 m .07498 .89624 L .08537 .9027 L p F P
0 g
s
0 0 0 r
.71129 .9027 m .72473 .89388 L .72842 .89043 L closepath p F P
0 g
s
.357 .797 .634 r
.72473 .89388 m .71129 .9027 L p .6942 .91071 L F P
0 g
s
.52 .629 .899 r
.62362 .56039 m .64877 .56017 L .64647 .57121 L p F P
0 g
s
.515 .633 .905 r
.64877 .56017 m .62362 .56039 L .61654 .54961 L p F P
0 g
s
.691 .545 .683 r
.42 .74706 m .43252 .74608 L p .4035 .76597 L F P
0 g
s
.691 .545 .683 r
.4035 .76597 m .40286 .7635 L .42 .74706 L p F P
0 g
s
.744 .737 .845 r
.23675 .92353 m .24653 .91729 L .26277 .92189 L p F P
0 g
s
.721 .722 .85 r
.26392 .90655 m .24653 .91729 L .26277 .92189 L p F P
0 g
s
.721 .722 .85 r
.26277 .92189 m .27215 .91671 L .26392 .90655 L p F P
0 g
s
.712 .557 .678 r
.4035 .76597 m .40286 .7635 L .40076 .76593 L closepath p F P
0 g
s
.665 .584 .755 r
.46415 .85758 m .46774 .86741 L .44023 .88035 L p F P
0 g
s
.665 .584 .755 r
.44023 .88035 m .43275 .86155 L .46415 .85758 L p F P
0 g
s
.755 .588 .67 r
.35538 .72709 m .34842 .72579 L p .35988 .74534 L F P
0 g
s
.755 .588 .67 r
.35988 .74534 m .36022 .74482 L .35538 .72709 L p F P
0 g
s
.284 .256 .65 r
.78953 .75389 m .78421 .74655 L .787 .74302 L closepath p F P
0 g
s
.329 .317 .695 r
.78421 .74655 m .787 .74302 L .78201 .72501 L p F P
0 g
s
.674 .535 .688 r
.4035 .76597 m .43638 .76329 L p .4213 .78284 L F P
0 g
s
.674 .535 .688 r
.4213 .78284 m .40821 .78402 L .4035 .76597 L p F P
0 g
s
.691 .545 .683 r
.43252 .74608 m .43638 .76329 L .4035 .76597 L p F P
0 g
s
.712 .558 .679 r
.40076 .76593 m .4035 .76597 L .40821 .78402 L p F P
0 g
s
.712 .558 .679 r
.40821 .78402 m .38531 .78371 L .40076 .76593 L p F P
0 g
s
.727 .582 .692 r
.37212 .76466 m .40076 .76593 L .38531 .78371 L p F P
0 g
s
.641 .618 .811 r
.51151 .89574 m .51789 .9085 L p .48278 .90219 L F P
0 g
s
.641 .618 .811 r
.48278 .90219 m .48378 .90188 L .51151 .89574 L p F P
0 g
s
.636 .592 .788 r
.48278 .90219 m .48378 .90188 L .48274 .90212 L closepath p F P
0 g
s
.636 .594 .79 r
.48378 .90188 m .48274 .90212 L .47526 .88579 L p F P
0 g
s
.691 .603 .753 r
.43237 .86158 m .39883 .86315 L .39765 .8603 L p F P
0 g
s
.712 .613 .745 r
.39883 .86315 m .39765 .8603 L .39404 .86306 L closepath p F P
0 g
s
.452 .544 .86 r
.70915 .61133 m .70275 .61017 L .70513 .60365 L closepath p F P
0 g
s
.482 .569 .867 r
.70222 .5984 m .70513 .60365 L .70275 .61017 L p F P
0 g
s
.916 .725 .629 r
.30956 .62209 m .31909 .6296 L .31442 .64382 L p F P
0 g
s
.917 .718 .618 r
.31909 .6296 m .30956 .62209 L .3137 .6081 L p F P
0 g
s
.495 .607 .894 r
.64647 .57121 m .65925 .57172 L .65225 .56032 L p F P
0 g
s
.495 .607 .894 r
.65225 .56032 m .64877 .56017 L .64647 .57121 L p F P
0 g
s
.489 .6 .89 r
.67935 .58416 m .66623 .58333 L .65925 .57172 L p F P
0 g
s
.722 .607 .729 r
.36248 .86466 m .36574 .86176 L .39404 .86306 L p F P
0 g
s
.703 .596 .733 r
.38819 .84195 m .36574 .86176 L .39404 .86306 L p F P
0 g
s
.703 .596 .733 r
.39075 .84204 m .38819 .84195 L p .39404 .86306 L F P
0 g
s
.703 .596 .733 r
.39404 .86306 m .39765 .8603 L .39075 .84204 L p F P
0 g
s
.641 .618 .811 r
.51151 .89574 m .51043 .89361 L .48378 .90188 L closepath p F P
0 g
s
.636 .594 .79 r
.50293 .87679 m .51043 .89361 L .48378 .90188 L p F P
0 g
s
.636 .594 .79 r
.47526 .88579 m .50293 .87679 L p .48378 .90188 L F P
0 g
s
.622 .486 .676 r
.43252 .74608 m .46183 .73983 L p .46317 .75736 L F P
0 g
s
.622 .486 .676 r
.46317 .75736 m .43638 .76329 L .43252 .74608 L p F P
0 g
s
.629 .49 .674 r
.45822 .7229 m .46183 .73983 L .43252 .74608 L p F P
0 g
s
.629 .49 .674 r
.45431 .72372 m .45822 .7229 L p .43252 .74608 L F P
0 g
s
.4 .297 .621 r
.47876 .64409 m .47275 .64873 L .47513 .66425 L p F P
0 g
s
.691 .603 .753 r
.39765 .8603 m .42416 .84112 L p .43237 .86158 L F P
0 g
s
.697 .593 .735 r
.39765 .8603 m .42416 .84112 L .39075 .84204 L closepath p F P
0 g
s
.547 .665 .914 r
.58114 .5415 m .60867 .53907 L .60726 .55002 L p F P
0 g
s
.546 .672 .92 r
.60867 .53907 m .58114 .5415 L .57393 .53161 L p F P
0 g
s
.749 .664 .767 r
.33493 .88807 m .34212 .88189 L .33067 .88009 L closepath p F P
0 g
s
0 0 0 r
.76797 .85138 m .75527 .86253 L .75166 .87144 L p F P
0 g
s
0 0 .131 r
.77627 .83526 m .76797 .85138 L .75527 .86253 L p F P
0 g
s
0 0 0 r
.73786 .88186 m .75166 .87144 L .75527 .86253 L p F P
0 g
s
0 0 0 r
.72473 .89388 m .72842 .89043 L .73786 .88186 L p F P
0 g
s
.749 .665 .768 r
.36108 .86138 m .36248 .86466 L .34212 .88189 L p F P
0 g
s
.749 .665 .768 r
.34173 .85925 m .36108 .86138 L p .34212 .88189 L F P
0 g
s
.749 .665 .768 r
.32709 .87342 m .34173 .85925 L p .34212 .88189 L F P
0 g
s
.749 .665 .768 r
.34212 .88189 m .33067 .88009 L .32709 .87342 L p F P
0 g
s
0 0 0 r
.73786 .88186 m .75166 .87144 L p .72473 .89388 L F P
0 g
s
.553 .418 .652 r
.45525 .70664 m .48076 .69633 L p .4616 .72156 L F P
0 g
s
.553 .418 .652 r
.4616 .72156 m .45797 .72167 L .45525 .70664 L p F P
0 g
s
.538 .407 .649 r
.47809 .68246 m .48076 .69633 L .45525 .70664 L p F P
0 g
s
.538 .407 .649 r
.47241 .68214 m .47809 .68246 L p .45525 .70664 L F P
0 g
s
.62 .47 .657 r
.45525 .70664 m .45797 .72167 L .45431 .72372 L p F P
0 g
s
.758 .592 .672 r
.36038 .74541 m .36022 .74482 L .35988 .74534 L closepath p F P
0 g
s
.476 .737 .985 r
.13179 .92398 m .15747 .9223 L .16636 .92872 L p F P
0 g
s
.506 .745 .981 r
.15747 .9223 m .13179 .92398 L .12272 .91822 L p F P
0 g
s
.743 .585 .679 r
.37212 .76466 m .36566 .76401 L .36038 .74541 L p F P
0 g
s
.758 .594 .673 r
.35988 .74534 m .36038 .74541 L .36566 .76401 L p F P
0 g
s
.787 .617 .67 r
.33966 .74152 m .35988 .74534 L .34938 .76163 L p F P
0 g
s
.755 .588 .67 r
.34842 .72579 m .33966 .74152 L .35988 .74534 L p F P
0 g
s
.758 .594 .673 r
.36566 .76401 m .34938 .76163 L .35988 .74534 L p F P
0 g
s
.808 .631 .662 r
.33065 .72118 m .34842 .72579 L .33966 .74152 L p F P
0 g
s
.774 .598 .662 r
.33804 .7059 m .33065 .72118 L .34842 .72579 L p F P
0 g
s
.757 .696 .793 r
.29686 .89889 m .27215 .91671 L .26392 .90655 L p F P
0 g
s
.727 .582 .692 r
.36761 .7708 m .37212 .76466 L p .38531 .78371 L F P
0 g
s
.742 .586 .68 r
.36761 .7708 m .37212 .76466 L .36566 .76401 L closepath p F P
0 g
s
.674 .536 .689 r
.41023 .79169 m .4213 .78284 L .40821 .78402 L closepath p F P
0 g
s
.715 .583 .706 r
.40821 .78402 m .41023 .79169 L .399 .80262 L p F P
0 g
s
.715 .583 .706 r
.38531 .78371 m .40821 .78402 L p .399 .80262 L F P
0 g
s
.733 .627 .741 r
.36248 .86466 m .36574 .86176 L .36108 .86138 L closepath p F P
0 g
s
.732 .627 .741 r
.36123 .84025 m .38819 .84195 L .36574 .86176 L p F P
0 g
s
.732 .627 .741 r
.35481 .84679 m .36123 .84025 L p .36574 .86176 L F P
0 g
s
.732 .627 .741 r
.36574 .86176 m .36108 .86138 L .35481 .84679 L p F P
0 g
s
.831 .648 .655 r
.32252 .70055 m .33804 .7059 L .33065 .72118 L p F P
0 g
s
.821 .634 .649 r
.33804 .7059 m .32252 .70055 L .32886 .68564 L p F P
0 g
s
.531 .649 .909 r
.60726 .55002 m .61654 .54961 L .60943 .53903 L p F P
0 g
s
.531 .649 .909 r
.60943 .53903 m .60867 .53907 L .60726 .55002 L p F P
0 g
s
.715 .583 .706 r
.37505 .79549 m .38531 .78371 L p .399 .80262 L F P
0 g
s
.727 .582 .692 r
.37505 .79549 m .38531 .78371 L .37125 .78289 L closepath p F P
0 g
s
.727 .582 .692 r
.38531 .78371 m .37125 .78289 L .36761 .7708 L p F P
0 g
s
.689 .598 .749 r
.43275 .86155 m .43268 .86138 L .43237 .86158 L closepath p F P
0 g
s
.691 .603 .753 r
.4254 .84106 m .43268 .86138 L .43237 .86158 L p F P
0 g
s
.691 .603 .753 r
.42416 .84112 m .4254 .84106 L p .43237 .86158 L F P
0 g
s
.074 0 .335 r
.77724 .83184 m .77976 .82048 L .77764 .82261 L closepath p F P
0 g
s
.671 .589 .755 r
.46021 .84689 m .46415 .85758 L .43275 .86155 L p F P
0 g
s
.671 .589 .755 r
.43275 .86155 m .43268 .86138 L .46021 .84689 L p F P
0 g
s
.667 .57 .736 r
.45709 .83731 m .46021 .84689 L .43268 .86138 L p F P
0 g
s
.667 .57 .736 r
.43268 .86138 m .4254 .84106 L .45709 .83731 L p F P
0 g
s
.697 .594 .736 r
.42416 .84112 m .39075 .84204 L .39008 .84029 L p F P
0 g
s
.719 .605 .728 r
.39075 .84204 m .39008 .84029 L .38819 .84195 L closepath p F P
0 g
s
.71 .589 .718 r
.3797 .82155 m .36123 .84025 L .38819 .84195 L p F P
0 g
s
.71 .589 .718 r
.38363 .82178 m .3797 .82155 L p .38819 .84195 L F P
0 g
s
.71 .589 .718 r
.38819 .84195 m .39008 .84029 L .38363 .82178 L p F P
0 g
s
.741 .585 .681 r
.36566 .76401 m .34938 .76163 L p .35957 .78159 L F P
0 g
s
.741 .585 .681 r
.35957 .78159 m .36761 .7708 L .36566 .76401 L p F P
0 g
s
.697 .594 .736 r
.39008 .84029 m .41238 .82164 L p .42416 .84112 L F P
0 g
s
.705 .587 .72 r
.39008 .84029 m .41238 .82164 L .38363 .82178 L closepath p F P
0 g
s
.619 .717 .917 r
.56047 .92604 m .58853 .91983 L .5957 .92871 L p F P
0 g
s
.613 .677 .887 r
.58853 .91983 m .56047 .92604 L .55315 .91492 L p F P
0 g
s
.741 .631 .737 r
.36108 .86138 m .35481 .84679 L .34173 .85925 L closepath p F P
0 g
s
.291 .293 .689 r
.78252 .72426 m .78201 .72501 L .787 .74302 L p F P
0 g
s
.337 .353 .73 r
.78201 .72501 m .78153 .7235 L .78252 .72426 L closepath p F P
0 g
s
.337 .353 .73 r
.78252 .72426 m .78153 .7235 L .77575 .7055 L p F P
0 g
s
.668 .544 .704 r
.41023 .79169 m .4213 .78284 L p .44406 .79918 L F P
0 g
s
.668 .544 .704 r
.44406 .79918 m .41338 .80251 L .41023 .79169 L p F P
0 g
s
.704 .565 .695 r
.41338 .80251 m .41023 .79169 L .399 .80262 L closepath p F P
0 g
s
.337 .353 .73 r
.77575 .7055 m .77737 .70289 L p .78252 .72426 L F P
0 g
s
.359 .394 .762 r
.77575 .7055 m .7741 .70092 L .77737 .70289 L closepath p F P
0 g
s
0 0 .399 r
.48629 .58663 m .48929 .58151 L .48845 .56905 L p F P
0 g
s
.746 .592 .685 r
.37125 .78289 m .36761 .7708 L .35957 .78159 L closepath p F P
0 g
s
0 .438 .811 r
.08894 .90531 m .10521 .91054 L .11607 .91682 L p F P
0 g
s
0 .482 .859 r
.10521 .91054 m .08894 .90531 L .07967 .89956 L p F P
0 g
s
.705 .587 .72 r
.399 .80262 m .41338 .80251 L p .41238 .82164 L F P
0 g
s
.705 .587 .72 r
.38255 .81868 m .399 .80262 L p .41238 .82164 L F P
0 g
s
.715 .583 .706 r
.38255 .81868 m .399 .80262 L .37719 .80211 L closepath p F P
0 g
s
.715 .583 .706 r
.399 .80262 m .37719 .80211 L .37505 .79549 L p F P
0 g
s
.357 .394 .762 r
.77737 .70289 m .7741 .70092 L .76808 .6843 L p F P
0 g
s
.857 .67 .648 r
.31539 .67958 m .32886 .68564 L .32252 .70055 L p F P
0 g
s
.849 .657 .643 r
.32886 .68564 m .31539 .67958 L .32094 .66496 L p F P
0 g
s
.668 .544 .704 r
.41767 .81723 m .44406 .79918 L .41338 .80251 L closepath p F P
0 g
s
.705 .587 .72 r
.41338 .80251 m .41767 .81723 L .41238 .82164 L p F P
0 g
s
.835 .363 .017 r
.05488 .87913 m .04531 .87228 L .03888 .86089 L p F P
0 g
s
.729 .583 .692 r
.37125 .78289 m .35957 .78159 L p .36987 .80151 L F P
0 g
s
.729 .583 .692 r
.36987 .80151 m .37505 .79549 L .37125 .78289 L p F P
0 g
s
.668 .544 .704 r
.4213 .78284 m .44075 .78101 L p .44406 .79918 L F P
0 g
s
.672 .532 .686 r
.44075 .78101 m .43781 .76958 L .4213 .78284 L closepath p F P
0 g
s
.674 .535 .688 r
.43638 .76329 m .43781 .76958 L .4213 .78284 L p F P
0 g
s
.705 .587 .72 r
.41238 .82164 m .38363 .82178 L .38255 .81868 L p F P
0 g
s
.727 .598 .713 r
.38363 .82178 m .38255 .81868 L .3797 .82155 L closepath p F P
0 g
s
.622 .487 .677 r
.43781 .76958 m .46317 .75736 L .43638 .76329 L closepath p F P
0 g
s
.742 .697 .808 r
.30127 .89968 m .2995 .89703 L .29686 .89889 L closepath p F P
0 g
s
.291 .293 .689 r
.787 .74302 m .79254 .73499 L .78252 .72426 L p F P
0 g
s
.271 .285 .691 r
.78964 .71289 m .78252 .72426 L .79254 .73499 L p F P
0 g
s
.337 .353 .73 r
.77737 .70289 m .78964 .71289 L .78252 .72426 L p F P
0 g
s
.719 .585 .705 r
.3797 .82155 m .38255 .81868 L .37719 .80211 L p F P
0 g
s
.697 .594 .736 r
.41238 .82164 m .41904 .82147 L p .42416 .84112 L F P
0 g
s
.698 .574 .712 r
.41904 .82147 m .41767 .81723 L .41238 .82164 L closepath p F P
0 g
s
.693 .585 .73 r
.4254 .84106 m .42516 .8404 L .42416 .84112 L closepath p F P
0 g
s
.697 .594 .736 r
.41904 .82147 m .42516 .8404 L .42416 .84112 L p F P
0 g
s
.747 .664 .769 r
.33067 .88009 m .32709 .87342 L .3209 .87862 L closepath p F P
0 g
s
.719 .585 .705 r
.37719 .80211 m .36987 .80151 L p .3797 .82155 L F P
0 g
s
.736 .594 .698 r
.37719 .80211 m .37505 .79549 L .36987 .80151 L closepath p F P
0 g
s
.674 .575 .736 r
.4527 .82398 m .45709 .83731 L .4254 .84106 L p F P
0 g
s
.674 .575 .736 r
.4254 .84106 m .42516 .8404 L .4527 .82398 L p F P
0 g
s
.744 .626 .728 r
.35464 .81927 m .3797 .82155 L .36123 .84025 L p F P
0 g
s
.719 .585 .705 r
.36987 .80151 m .35464 .81927 L .3797 .82155 L p F P
0 g
s
.668 .556 .72 r
.45092 .81786 m .4527 .82398 L .42516 .8404 L p F P
0 g
s
.668 .556 .72 r
.42516 .8404 m .41904 .82147 L .45092 .81786 L p F P
0 g
s
.678 .563 .718 r
.44542 .79904 m .45092 .81786 L .41904 .82147 L p F P
0 g
s
.678 .563 .718 r
.44406 .79918 m .44542 .79904 L p .41904 .82147 L F P
0 g
s
.678 .563 .718 r
.41904 .82147 m .41767 .81723 L .44406 .79918 L p F P
0 g
s
.432 .505 .834 r
.72486 .62652 m .74577 .63237 L p .743 .64412 L F P
0 g
s
.409 .501 .841 r
.72486 .62652 m .74577 .63237 L .73883 .61831 L p F P
0 g
s
.409 .501 .841 r
.73883 .61831 m .72884 .61539 L .72486 .62652 L p F P
0 g
s
.449 .538 .856 r
.70915 .61133 m .72884 .61539 L .72486 .62652 L p F P
0 g
s
.573 .914 .969 r
.68373 .91532 m .66592 .92275 L .65922 .91952 L p F P
0 g
s
.589 .881 .992 r
.6309 .92817 m .65922 .91952 L .66592 .92275 L p F P
0 g
s
.634 .573 .768 r
.50123 .87249 m .50293 .87679 L .47526 .88579 L p F P
0 g
s
.634 .573 .768 r
.47526 .88579 m .47251 .87902 L .50123 .87249 L p F P
0 g
s
.625 .48 .665 r
.45822 .7229 m .45797 .72167 L .45431 .72372 L closepath p F P
0 g
s
.256 .183 .579 r
.48777 .60105 m .48295 .60675 L .4883 .61794 L p F P
0 g
s
.22 .136 .542 r
.48295 .60675 m .48777 .60105 L .48629 .58663 L p F P
0 g
s
.439 .537 .86 r
.72884 .61539 m .70915 .61133 L .70513 .60365 L p F P
0 g
s
.758 .628 .716 r
.34696 .79858 m .36987 .80151 L .35464 .81927 L p F P
0 g
s
.729 .583 .692 r
.35957 .78159 m .34696 .79858 L .36987 .80151 L p F P
0 g
s
.267 .244 .647 r
.787 .74302 m .79254 .73499 L p .79231 .7579 L F P
0 g
s
.267 .244 .647 r
.79231 .7579 m .78953 .75389 L .787 .74302 L p F P
0 g
s
.762 .749 .841 r
.24653 .91729 m .23675 .92353 L .22829 .91495 L p F P
0 g
s
.711 .753 .886 r
.20142 .928 m .22829 .91495 L .23675 .92353 L p F P
0 g
s
.63 .506 .693 r
.44075 .78101 m .43781 .76958 L .46317 .75736 L p F P
0 g
s
.885 .696 .642 r
.30945 .6582 m .32094 .66496 L .31539 .67958 L p F P
0 g
s
.88 .687 .636 r
.32094 .66496 m .30945 .6582 L .31442 .64382 L p F P
0 g
s
.757 .696 .793 r
.26392 .90655 m .27847 .89483 L .29686 .89889 L p F P
0 g
s
.739 .691 .805 r
.29146 .88466 m .27847 .89483 L .29686 .89889 L p F P
0 g
s
.739 .691 .805 r
.29686 .89889 m .2995 .89703 L .29146 .88466 L p F P
0 g
s
.193 .111 .529 r
.7937 .77529 m .78804 .78182 L .79095 .79477 L p F P
0 g
s
.254 .197 .598 r
.78804 .78182 m .7937 .77529 L .7909 .75977 L p F P
0 g
s
.357 .394 .762 r
.76808 .6843 m .76916 .68236 L p .77737 .70289 L F P
0 g
s
.38 .432 .79 r
.76808 .6843 m .76687 .68127 L .76916 .68236 L closepath p F P
0 g
s
.626 .634 .838 r
.51789 .9085 m .54577 .90201 L p .55044 .91557 L F P
0 g
s
.617 .604 .815 r
.53833 .88735 m .54577 .90201 L .51789 .9085 L p F P
0 g
s
.617 .604 .815 r
.53731 .88758 m .53833 .88735 L p .51789 .9085 L F P
0 g
s
.617 .604 .815 r
.51789 .9085 m .51151 .89574 L .53731 .88758 L p F P
0 g
s
.744 .626 .728 r
.35481 .84679 m .36123 .84025 L .35168 .83914 L closepath p F P
0 g
s
.744 .626 .728 r
.34714 .82804 m .35464 .81927 L p .36123 .84025 L F P
0 g
s
.744 .626 .728 r
.36123 .84025 m .35168 .83914 L .34714 .82804 L p F P
0 g
s
.764 .67 .758 r
.3209 .87862 m .2995 .89703 L .29146 .88466 L p F P
0 g
s
.657 .115 0 r
.07498 .89624 m .065 .88958 L .05488 .87913 L p F P
0 g
s
.636 .098 0 r
.04531 .87228 m .05488 .87913 L .065 .88958 L p F P
0 g
s
.056 .015 .49 r
.48929 .58151 m .48629 .58663 L .48777 .60105 L p F P
0 g
s
.554 .433 .67 r
.45822 .7229 m .45797 .72167 L .4616 .72156 L closepath p F P
0 g
s
.774 .633 .705 r
.33886 .77798 m .35957 .78159 L .34696 .79858 L p F P
0 g
s
.741 .585 .681 r
.34938 .76163 m .33886 .77798 L .35957 .78159 L p F P
0 g
s
.586 .723 .937 r
.54457 .52569 m .53864 .5268 L .53128 .51808 L p F P
0 g
s
.637 .576 .769 r
.49541 .85789 m .50123 .87249 L .47251 .87902 L p F P
0 g
s
.637 .576 .769 r
.47251 .87902 m .46774 .86741 L .49541 .85789 L p F P
0 g
s
0 0 .286 r
.77976 .82048 m .79088 .80861 L p .77707 .83452 L F P
0 g
s
0 0 .286 r
.77707 .83452 m .77724 .83184 L .77976 .82048 L p F P
0 g
s
.137 .017 .441 r
.77976 .82048 m .79088 .80861 L .79095 .79477 L p F P
0 g
s
.736 .622 .732 r
.34173 .85925 m .35481 .84679 L .35168 .83914 L p F P
0 g
s
.612 .789 .967 r
.5957 .92871 m .62393 .92187 L .6309 .92817 L p F P
0 g
s
.609 .738 .937 r
.62393 .92187 m .5957 .92871 L .58853 .91983 L p F P
0 g
s
.643 .768 .939 r
.16636 .92872 m .19274 .92065 L .20142 .928 L p F P
0 g
s
.66 .77 .931 r
.19274 .92065 m .16636 .92872 L .15747 .9223 L p F P
0 g
s
.555 .436 .672 r
.46183 .73983 m .45822 .7229 L .4616 .72156 L p F P
0 g
s
.377 .433 .792 r
.76916 .68236 m .76687 .68127 L .75977 .66368 L p F P
0 g
s
.405 .304 .627 r
.47767 .67999 m .47513 .66425 L .48834 .65415 L p F P
0 g
s
.4 .297 .621 r
.47513 .66425 m .48834 .65415 L .47876 .64409 L p F P
0 g
s
.537 .391 .629 r
.47513 .66425 m .47767 .67999 L .47241 .68214 L p F P
0 g
s
.764 .647 .733 r
.34173 .85925 m .32709 .87342 L .31923 .85827 L p F P
0 g
s
.764 .647 .733 r
.31923 .85827 m .32168 .85559 L .34173 .85925 L p F P
0 g
s
.736 .622 .732 r
.33847 .83733 m .32168 .85559 L .34173 .85925 L p F P
0 g
s
.736 .622 .732 r
.35168 .83914 m .33847 .83733 L p .34173 .85925 L F P
0 g
s
.793 .642 .694 r
.33081 .75733 m .34938 .76163 L .33886 .77798 L p F P
0 g
s
.787 .617 .67 r
.34938 .76163 m .33081 .75733 L .33966 .74152 L p F P
0 g
s
.743 .658 .765 r
.31923 .85827 m .30175 .87474 L .3209 .87862 L p F P
0 g
s
.743 .658 .765 r
.3209 .87862 m .32709 .87342 L .31923 .85827 L p F P
0 g
s
.764 .67 .758 r
.29146 .88466 m .30175 .87474 L .3209 .87862 L p F P
0 g
s
.626 .504 .694 r
.44523 .79838 m .44075 .78101 L .46991 .77463 L p F P
0 g
s
.63 .506 .693 r
.46551 .75686 m .46991 .77463 L .44075 .78101 L p F P
0 g
s
.63 .506 .693 r
.46317 .75736 m .46551 .75686 L p .44075 .78101 L F P
0 g
s
.668 .544 .704 r
.44075 .78101 m .44523 .79838 L .44406 .79918 L p F P
0 g
s
.297 .335 .732 r
.78368 .69161 m .77737 .70289 L .78964 .71289 L p F P
0 g
s
.357 .394 .762 r
.76916 .68236 m .78368 .69161 L .77737 .70289 L p F P
0 g
s
.723 .752 .875 r
.22829 .91495 m .20142 .928 L .19274 .92065 L p F P
0 g
s
.607 .827 .984 r
.65922 .91952 m .6309 .92817 L .62393 .92187 L p F P
0 g
s
.762 .749 .841 r
.22829 .91495 m .23239 .91207 L .24653 .91729 L p F P
0 g
s
.736 .724 .84 r
.25565 .89623 m .23239 .91207 L .24653 .91729 L p F P
0 g
s
.736 .724 .84 r
.24653 .91729 m .26392 .90655 L .25565 .89623 L p F P
0 g
s
.41 .479 .82 r
.75276 .64771 m .743 .64412 L p .75778 .66274 L F P
0 g
s
.393 .472 .822 r
.75276 .64771 m .743 .64412 L .74695 .63479 L closepath p F P
0 g
s
.432 .505 .834 r
.74577 .63237 m .74695 .63479 L .743 .64412 L p F P
0 g
s
.374 .293 .635 r
.49241 .63187 m .47876 .64409 L .48834 .65415 L p F P
0 g
s
.415 .29 .601 r
.49077 .62207 m .49241 .63187 L .47876 .64409 L p F P
0 g
s
.415 .29 .601 r
.4883 .61794 m .49077 .62207 L p .47876 .64409 L F P
0 g
s
.751 .629 .725 r
.35168 .83914 m .34714 .82804 L .33847 .83733 L closepath p F P
0 g
s
.814 .654 .684 r
.32311 .73656 m .33966 .74152 L .33081 .75733 L p F P
0 g
s
.808 .631 .662 r
.33966 .74152 m .32311 .73656 L .33065 .72118 L p F P
0 g
s
.787 .841 .893 r
.51773 .52366 m .50349 .531 L .49599 .52716 L p F P
0 g
s
.927 .877 .766 r
.49513 .54362 m .50349 .531 L .49599 .52716 L p F P
0 g
s
.916 .731 .637 r
.30499 .6363 m .31442 .64382 L .30945 .6582 L p F P
0 g
s
.916 .725 .629 r
.31442 .64382 m .30499 .6363 L .30956 .62209 L p F P
0 g
s
.758 .628 .716 r
.34714 .82804 m .35464 .81927 L .34296 .81745 L closepath p F P
0 g
s
.758 .628 .716 r
.33948 .80863 m .34696 .79858 L p .35464 .81927 L F P
0 g
s
.758 .628 .716 r
.35464 .81927 m .34296 .81745 L .33948 .80863 L p F P
0 g
s
.265 .244 .647 r
.7909 .75977 m .78953 .75389 L .79231 .7579 L closepath p F P
0 g
s
.18 .602 .942 r
.11607 .91682 m .12272 .91822 L .11359 .91212 L p F P
0 g
s
.18 .602 .942 r
.11359 .91212 m .10521 .91054 L .11607 .91682 L p F P
0 g
s
.555 .436 .672 r
.4616 .72156 m .48555 .72061 L p .46183 .73983 L F P
0 g
s
.555 .428 .663 r
.48555 .72061 m .4616 .72156 L .484 .71287 L closepath p F P
0 g
s
.553 .418 .652 r
.48076 .69633 m .484 .71287 L .4616 .72156 L p F P
0 g
s
.632 .554 .748 r
.493 .85108 m .49541 .85789 L .46774 .86741 L p F P
0 g
s
.632 .554 .748 r
.46774 .86741 m .46415 .85758 L .493 .85108 L p F P
0 g
s
.515 .633 .905 r
.61654 .54961 m .64522 .54943 L p .64877 .56017 L F P
0 g
s
.504 .639 .915 r
.64522 .54943 m .61654 .54961 L .60943 .53903 L p F P
0 g
s
.321 .38 .767 r
.7747 .67116 m .76916 .68236 L .78368 .69161 L p F P
0 g
s
.377 .433 .792 r
.75977 .66368 m .7747 .67116 L .76916 .68236 L p F P
0 g
s
.372 .433 .794 r
.75977 .66368 m .75778 .66274 L .75867 .66097 L closepath p F P
0 g
s
.41 .479 .82 r
.75778 .66274 m .75867 .66097 L .75276 .64771 L p F P
0 g
s
.54 .402 .643 r
.47809 .68246 m .47241 .68214 L .47767 .67999 L closepath p F P
0 g
s
.84 .663 .661 r
.31598 .71557 m .33065 .72118 L .32311 .73656 L p F P
0 g
s
.831 .648 .655 r
.33065 .72118 m .31598 .71557 L .32252 .70055 L p F P
0 g
s
.669 .544 .704 r
.44542 .79904 m .44523 .79838 L .44406 .79918 L closepath p F P
0 g
s
.489 .6 .89 r
.65925 .57172 m .68155 .57324 L .67935 .58416 L p F P
0 g
s
.482 .602 .895 r
.68155 .57324 m .65925 .57172 L .65225 .56032 L p F P
0 g
s
.632 .522 .711 r
.44542 .79904 m .44523 .79838 L .47284 .7864 L p F P
0 g
s
.626 .504 .694 r
.46991 .77463 m .47284 .7864 L .44523 .79838 L p F P
0 g
s
.63 .521 .712 r
.45092 .81786 m .44542 .79904 L .47462 .79271 L p F P
0 g
s
.632 .522 .711 r
.47284 .7864 m .47462 .79271 L .44542 .79904 L p F P
0 g
s
.635 .557 .749 r
.48788 .83674 m .493 .85108 L .46415 .85758 L p F P
0 g
s
.635 .557 .749 r
.46415 .85758 m .46021 .84689 L .48788 .83674 L p F P
0 g
s
.586 .723 .937 r
.53128 .51808 m .54111 .51606 L .54457 .52569 L p F P
0 g
s
.588 .719 .934 r
.54457 .52569 m .56668 .52197 L .55938 .51256 L p F P
0 g
s
.588 .719 .934 r
.55938 .51256 m .54111 .51606 L .54457 .52569 L p F P
0 g
s
.457 .572 .882 r
.67935 .58416 m .69529 .58616 L .68834 .57414 L p F P
0 g
s
.457 .572 .882 r
.68834 .57414 m .68155 .57324 L .67935 .58416 L p F P
0 g
s
.747 .623 .721 r
.33847 .83733 m .34714 .82804 L .34296 .81745 L p F P
0 g
s
.439 .537 .86 r
.70513 .60365 m .7065 .599 L p .72884 .61539 L F P
0 g
s
.461 .565 .874 r
.70513 .60365 m .70222 .5984 L .7065 .599 L closepath p F P
0 g
s
.206 .164 .587 r
.79231 .7579 m .7909 .75977 L .7937 .77529 L p F P
0 g
s
.423 0 0 r
.07498 .89624 m .07967 .89956 L .07035 .89332 L p F P
0 g
s
.423 0 0 r
.07035 .89332 m .065 .88958 L .07498 .89624 L p F P
0 g
s
.774 .633 .705 r
.33948 .80863 m .34696 .79858 L .33461 .79605 L closepath p F P
0 g
s
.774 .633 .705 r
.33182 .78883 m .33886 .77798 L p .34696 .79858 L F P
0 g
s
.774 .633 .705 r
.34696 .79858 m .33461 .79605 L .33182 .78883 L p F P
0 g
s
.565 .444 .673 r
.46183 .73983 m .48765 .72986 L p .46756 .75608 L F P
0 g
s
.565 .444 .673 r
.46756 .75608 m .46537 .75629 L .46183 .73983 L p F P
0 g
s
.555 .436 .672 r
.48555 .72061 m .48765 .72986 L .46183 .73983 L p F P
0 g
s
.622 .486 .676 r
.46183 .73983 m .46537 .75629 L .46317 .75736 L p F P
0 g
s
.626 .635 .84 r
.55315 .91492 m .55044 .91557 L .55308 .9148 L closepath p F P
0 g
s
.626 .634 .838 r
.54577 .90201 m .55308 .9148 L .55044 .91557 L p F P
0 g
s
.626 .519 .712 r
.4527 .82398 m .45092 .81786 L .47986 .81133 L p F P
0 g
s
.63 .521 .712 r
.47462 .79271 m .47986 .81133 L .45092 .81786 L p F P
0 g
s
.629 .536 .73 r
.486 .8308 m .48788 .83674 L .46021 .84689 L p F P
0 g
s
.629 .536 .73 r
.46021 .84689 m .45709 .83731 L .486 .8308 L p F P
0 g
s
.775 .667 .744 r
.31898 .83345 m .33847 .83733 L .32168 .85559 L p F P
0 g
s
.747 .623 .721 r
.33347 .81586 m .31898 .83345 L .33847 .83733 L p F P
0 g
s
.747 .623 .721 r
.34296 .81745 m .33347 .81586 L p .33847 .83733 L F P
0 g
s
.633 .539 .73 r
.48035 .81305 m .486 .8308 L .45709 .83731 L p F P
0 g
s
.633 .539 .73 r
.45709 .83731 m .4527 .82398 L .48035 .81305 L p F P
0 g
s
.863 .681 .654 r
.30962 .69432 m .32252 .70055 L .31598 .71557 L p F P
0 g
s
.857 .67 .648 r
.32252 .70055 m .30962 .69432 L .31539 .67958 L p F P
0 g
s
.36 .425 .793 r
.7747 .67116 m .75977 .66368 L .75867 .66097 L p F P
0 g
s
.573 .914 .969 r
.69208 .91037 m .68373 .91532 L p .65922 .91952 L F P
0 g
s
.598 .938 .945 r
.68373 .91532 m .69208 .91037 L .6942 .91071 L closepath p F P
0 g
s
.626 .519 .712 r
.47986 .81133 m .48035 .81305 L .4527 .82398 L p F P
0 g
s
.618 .606 .817 r
.51151 .89574 m .51043 .89361 L .53731 .88758 L closepath p F P
0 g
s
.762 .63 .714 r
.34296 .81745 m .33948 .80863 L .33347 .81586 L closepath p F P
0 g
s
.777 .713 .792 r
.27847 .89483 m .26392 .90655 L .25565 .89623 L p F P
0 g
s
.546 .672 .92 r
.57393 .53161 m .60228 .52904 L p .60867 .53907 L F P
0 g
s
.544 .678 .926 r
.60228 .52904 m .57393 .53161 L .56668 .52197 L p F P
0 g
s
.36 .425 .793 r
.75867 .66097 m .7627 .65158 L p .7747 .67116 L F P
0 g
s
.386 .464 .818 r
.75867 .66097 m .75276 .64771 L .7627 .65158 L closepath p F P
0 g
s
.613 .677 .887 r
.55315 .91492 m .58127 .90929 L .58853 .91983 L p F P
0 g
s
.611 .628 .844 r
.57888 .90527 m .58127 .90929 L .55315 .91492 L p F P
0 g
s
.611 .628 .844 r
.55315 .91492 m .55308 .9148 L .57888 .90527 L p F P
0 g
s
.927 .877 .766 r
.49599 .52716 m .493 .53356 L .49513 .54362 L p F P
0 g
s
.605 .628 .848 r
.57394 .89703 m .57888 .90527 L .55308 .9148 L p F P
0 g
s
.605 .628 .848 r
.55308 .9148 m .54577 .90201 L .57394 .89703 L p F P
0 g
s
.614 .579 .791 r
.53731 .88758 m .51043 .89361 L .50293 .87679 L p F P
0 g
s
.792 .642 .695 r
.33182 .78883 m .33886 .77798 L .32631 .77467 L closepath p F P
0 g
s
.793 .642 .694 r
.32415 .76908 m .33081 .75733 L p .33886 .77798 L F P
0 g
s
.793 .642 .694 r
.33886 .77798 m .32631 .77467 L .32415 .76908 L p F P
0 g
s
.686 .766 .912 r
.52387 .50954 m .51527 .51364 L .51773 .52366 L p F P
0 g
s
.686 .766 .912 r
.51773 .52366 m .53128 .51808 L .52387 .50954 L p F P
0 g
s
.787 .841 .893 r
.49599 .52716 m .51527 .51364 L .51773 .52366 L p F P
0 g
s
.459 .347 .639 r
.47767 .67999 m .49841 .66432 L p .49012 .68994 L F P
0 g
s
.459 .347 .639 r
.49012 .68994 m .47809 .68246 L .47767 .67999 L p F P
0 g
s
.405 .304 .627 r
.49831 .66383 m .49841 .66432 L .47767 .67999 L p F P
0 g
s
.405 .304 .627 r
.48834 .65415 m .49831 .66383 L p .47767 .67999 L F P
0 g
s
.101 0 .327 r
.77627 .83526 m .77707 .83452 L .77724 .83184 L closepath p F P
0 g
s
.777 .713 .792 r
.25565 .89623 m .26265 .89001 L .27847 .89483 L p F P
0 g
s
.753 .694 .795 r
.28337 .87213 m .26265 .89001 L .27847 .89483 L p F P
0 g
s
.753 .694 .795 r
.27847 .89483 m .29146 .88466 L .28337 .87213 L p F P
0 g
s
.76 .627 .713 r
.33347 .81586 m .33948 .80863 L .33461 .79605 L p F P
0 g
s
.206 .164 .587 r
.7937 .77529 m .7976 .77014 L .79231 .7579 L p F P
0 g
s
.181 .15 .585 r
.80021 .7465 m .79231 .7579 L .7976 .77014 L p F P
0 g
s
.267 .244 .647 r
.79254 .73499 m .80021 .7465 L .79231 .7579 L p F P
0 g
s
.775 .667 .743 r
.31923 .85827 m .32168 .85559 L .31737 .85459 L closepath p F P
0 g
s
.775 .667 .744 r
.31136 .84279 m .31898 .83345 L p .32168 .85559 L F P
0 g
s
.775 .667 .744 r
.32168 .85559 m .31737 .85459 L .31136 .84279 L p F P
0 g
s
.888 .705 .648 r
.30421 .67273 m .31539 .67958 L .30962 .69432 L p F P
0 g
s
.885 .696 .642 r
.31539 .67958 m .30421 .67273 L .30945 .6582 L p F P
0 g
s
.756 .659 .755 r
.30175 .87474 m .31923 .85827 L .31737 .85459 L p F P
0 g
s
.457 .569 .879 r
.7065 .599 m .70222 .5984 L .69529 .58616 L p F P
0 g
s
.446 .351 .654 r
.48076 .69633 m .47809 .68246 L .49012 .68994 L closepath p F P
0 g
s
.756 .659 .755 r
.30288 .85154 m .28532 .87006 L .30175 .87474 L p F P
0 g
s
.756 .659 .755 r
.31737 .85459 m .30288 .85154 L p .30175 .87474 L F P
0 g
s
.785 .689 .758 r
.30175 .87474 m .29146 .88466 L .28337 .87213 L p F P
0 g
s
.785 .689 .758 r
.28337 .87213 m .28532 .87006 L .30175 .87474 L p F P
0 g
s
.056 .015 .49 r
.48777 .60105 m .49214 .59343 L .48929 .58151 L p F P
0 g
s
.09 .063 .53 r
.49214 .59343 m .48777 .60105 L .48983 .61616 L p F P
0 g
s
.256 .183 .579 r
.4883 .61794 m .48983 .61616 L .48777 .60105 L p F P
0 g
s
.627 .498 .686 r
.46551 .75686 m .46537 .75629 L .46317 .75736 L closepath p F P
0 g
s
.814 .655 .686 r
.32415 .76908 m .33081 .75733 L .31762 .75291 L closepath p F P
0 g
s
.814 .654 .684 r
.31643 .74993 m .32311 .73656 L p .33081 .75733 L F P
0 g
s
.814 .654 .684 r
.33081 .75733 m .31762 .75291 L .31643 .74993 L p F P
0 g
s
.79 .672 .734 r
.31492 .81165 m .33347 .81586 L .31898 .83345 L p F P
0 g
s
.76 .627 .713 r
.32752 .79461 m .31492 .81165 L .33347 .81586 L p F P
0 g
s
.76 .627 .713 r
.33461 .79605 m .32752 .79461 L p .33347 .81586 L F P
0 g
s
.506 .745 .981 r
.12272 .91822 m .14852 .91566 L .15747 .9223 L p F P
0 g
s
.526 .75 .977 r
.14852 .91566 m .12272 .91822 L .11359 .91212 L p F P
0 g
s
0 0 .155 r
.77707 .83452 m .77627 .83526 L .76797 .85138 L p F P
0 g
s
0 0 0 r
.7505 .87312 m .73107 .88905 L .72473 .89388 L p F P
0 g
s
0 0 0 r
.75166 .87144 m .7505 .87312 L p .72473 .89388 L F P
0 g
s
.499 .877 .676 r
.72248 .89507 m .73107 .88905 L .72473 .89388 L closepath p F P
0 g
s
.357 .797 .634 r
.6942 .91071 m .72248 .89507 L .72473 .89388 L p F P
0 g
s
.774 .633 .705 r
.33461 .79605 m .33182 .78883 L .32752 .79461 L closepath p F P
0 g
s
.681 .964 .936 r
.69208 .91037 m .6942 .91071 L .72248 .89507 L p F P
0 g
s
.567 .46 .692 r
.46551 .75686 m .46537 .75629 L .46756 .75608 L closepath p F P
0 g
s
.568 .462 .693 r
.46991 .77463 m .46551 .75686 L .46756 .75608 L p F P
0 g
s
.768 .664 .748 r
.31737 .85459 m .31136 .84279 L .30288 .85154 L closepath p F P
0 g
s
.775 .634 .705 r
.32752 .79461 m .33182 .78883 L .32631 .77467 L p F P
0 g
s
0 0 .12 r
.78749 .82343 m .77707 .83452 L .77505 .84493 L p F P
0 g
s
0 0 .286 r
.79088 .80861 m .78749 .82343 L .77707 .83452 L p F P
0 g
s
0 0 .155 r
.76797 .85138 m .77505 .84493 L .77707 .83452 L p F P
0 g
s
.84 .664 .665 r
.32311 .73656 m .31643 .74993 L .30862 .73205 L p F P
0 g
s
.84 .664 .665 r
.30862 .73205 m .30923 .73073 L .32311 .73656 L p F P
0 g
s
.84 .663 .661 r
.32311 .73656 m .30923 .73073 L .31598 .71557 L p F P
0 g
s
.568 .462 .693 r
.46756 .75608 m .49308 .75354 L p .46991 .77463 L F P
0 g
s
.567 .452 .682 r
.49308 .75354 m .46756 .75608 L .49161 .7472 L closepath p F P
0 g
s
.565 .444 .673 r
.48765 .72986 m .49161 .7472 L .46756 .75608 L p F P
0 g
s
.916 .736 .643 r
.3001 .65068 m .30945 .6582 L .30421 .67273 L p F P
0 g
s
.916 .731 .637 r
.30945 .6582 m .3001 .65068 L .30499 .6363 L p F P
0 g
s
.766 .762 .849 r
.22829 .91495 m .23239 .91207 L .2202 .90671 L closepath p F P
0 g
s
.723 .752 .875 r
.2202 .90671 m .22829 .91495 L p .19274 .92065 L F P
0 g
s
.491 .613 .901 r
.65225 .56032 m .64877 .56017 L .6493 .55565 L closepath p F P
0 g
s
.515 .633 .905 r
.64522 .54943 m .6493 .55565 L .64877 .56017 L p F P
0 g
s
0 .482 .859 r
.07967 .89956 m .09475 .90409 L .10521 .91054 L p F P
0 g
s
.049 .512 .889 r
.09475 .90409 m .07967 .89956 L .07035 .89332 L p F P
0 g
s
.135 .07 .513 r
.7976 .77014 m .7937 .77529 L .79544 .78964 L p F P
0 g
s
.193 .111 .529 r
.79095 .79477 m .79544 .78964 L .7937 .77529 L p F P
0 g
s
.112 0 .432 r
.79544 .78964 m .79095 .79477 L .79088 .80861 L p F P
0 g
s
.382 .465 .821 r
.7627 .65158 m .75276 .64771 L .74695 .63479 L p F P
0 g
s
.439 .537 .86 r
.7065 .599 m .73184 .60444 L .72884 .61539 L p F P
0 g
s
.425 .544 .873 r
.70879 .58815 m .7065 .599 L .73184 .60444 L p F P
0 g
s
.457 .569 .879 r
.69529 .58616 m .70879 .58815 L .7065 .599 L p F P
0 g
s
.766 .762 .849 r
.24731 .88589 m .25565 .89623 L .23239 .91207 L p F P
0 g
s
.766 .762 .849 r
.21977 .90627 m .24731 .88589 L p .23239 .91207 L F P
0 g
s
.766 .762 .849 r
.23239 .91207 m .2202 .90671 L .21977 .90627 L p F P
0 g
s
.609 .738 .937 r
.58853 .91983 m .61685 .91386 L .62393 .92187 L p F P
0 g
s
.601 .695 .909 r
.61685 .91386 m .58853 .91983 L .58127 .90929 L p F P
0 g
s
.614 .579 .791 r
.50293 .87679 m .53085 .87077 L p .53731 .88758 L F P
0 g
s
.606 .553 .769 r
.5281 .86394 m .53085 .87077 L .50293 .87679 L p F P
0 g
s
.606 .553 .769 r
.50293 .87679 m .50123 .87249 L .5281 .86394 L p F P
0 g
s
.807 .666 .708 r
.31014 .78999 m .32752 .79461 L .31492 .81165 L p F P
0 g
s
.775 .634 .705 r
.32124 .77341 m .31014 .78999 L .32752 .79461 L p F P
0 g
s
.775 .634 .705 r
.32631 .77467 m .32124 .77341 L p .32752 .79461 L F P
0 g
s
.79 .672 .734 r
.31136 .84279 m .31898 .83345 L .30452 .82938 L closepath p F P
0 g
s
.79 .672 .734 r
.30345 .82728 m .31492 .81165 L p .31898 .83345 L F P
0 g
s
.79 .672 .734 r
.31898 .83345 m .30452 .82938 L .30345 .82728 L p F P
0 g
s
.788 .639 .697 r
.32631 .77467 m .32415 .76908 L .32124 .77341 L closepath p F P
0 g
s
.571 .464 .693 r
.47284 .7864 m .46991 .77463 L .49608 .76506 L p F P
0 g
s
.568 .462 .693 r
.49308 .75354 m .49608 .76506 L .46991 .77463 L p F P
0 g
s
.448 .355 .657 r
.49012 .68994 m .48076 .69633 L .484 .71287 L p F P
0 g
s
.604 .554 .771 r
.52333 .85222 m .5281 .86394 L .50123 .87249 L p F P
0 g
s
.604 .554 .771 r
.50123 .87249 m .49541 .85789 L .52333 .85222 L p F P
0 g
s
.278 .213 .602 r
.49077 .62207 m .4883 .61794 L .48983 .61616 L closepath p F P
0 g
s
.636 .098 0 r
.065 .88958 m .05543 .88273 L .04531 .87228 L p F P
0 g
s
.594 .732 .94 r
.54111 .51606 m .53128 .51808 L .52387 .50954 L p F P
0 g
s
.862 .692 .669 r
.3036 .70921 m .31598 .71557 L .30923 .73073 L p F P
0 g
s
.863 .681 .654 r
.31598 .71557 m .3036 .70921 L .30962 .69432 L p F P
0 g
s
.792 .646 .7 r
.32124 .77341 m .32415 .76908 L .31762 .75291 L p F P
0 g
s
.227 .229 .653 r
.7996 .72368 m .79254 .73499 L .80021 .7465 L p F P
0 g
s
.271 .285 .691 r
.79254 .73499 m .7996 .72368 L .78964 .71289 L p F P
0 g
s
.529 .655 .916 r
.60943 .53903 m .60867 .53907 L .6087 .53799 L closepath p F P
0 g
s
.546 .672 .92 r
.60228 .52904 m .6087 .53799 L .60867 .53907 L p F P
0 g
s
.66 .77 .931 r
.15747 .9223 m .184 .91317 L .19274 .92065 L p F P
0 g
s
.673 .773 .926 r
.184 .91317 m .15747 .9223 L .14852 .91566 L p F P
0 g
s
.482 .602 .895 r
.65225 .56032 m .68137 .56244 L p .68155 .57324 L F P
0 g
s
.466 .6 .902 r
.67438 .55144 m .68137 .56244 L .65225 .56032 L p F P
0 g
s
.466 .6 .902 r
.6495 .54952 m .67438 .55144 L p .65225 .56032 L F P
0 g
s
.466 .6 .902 r
.65225 .56032 m .6493 .55565 L .6495 .54952 L p F P
0 g
s
.723 .752 .875 r
.19274 .92065 m .21938 .90647 L .2202 .90671 L p F P
0 g
s
.736 .756 .869 r
.21938 .90647 m .19274 .92065 L .184 .91317 L p F P
0 g
s
.494 .637 .918 r
.63106 .52871 m .63816 .53895 L .60943 .53903 L p F P
0 g
s
.494 .637 .918 r
.60768 .52878 m .63106 .52871 L p .60943 .53903 L F P
0 g
s
.494 .637 .918 r
.60943 .53903 m .6087 .53799 L .60768 .52878 L p F P
0 g
s
.504 .639 .915 r
.60943 .53903 m .63816 .53895 L .64522 .54943 L p F P
0 g
s
.768 .665 .748 r
.30288 .85154 m .31136 .84279 L .30452 .82938 L p F P
0 g
s
0 0 0 r
.7505 .87312 m .75458 .86888 L .75166 .87144 L closepath p F P
0 g
s
0 0 0 r
.75166 .87144 m .75458 .86888 L .76797 .85138 L p F P
0 g
s
.573 .914 .969 r
.65922 .91952 m .6877 .90916 L .69208 .91037 L p F P
0 g
s
.603 .875 .992 r
.6877 .90916 m .65922 .91952 L .65239 .91438 L p F P
0 g
s
.607 .827 .984 r
.62393 .92187 m .65239 .91438 L .65922 .91952 L p F P
0 g
s
.579 .485 .713 r
.47462 .79271 m .47284 .7864 L .50064 .78257 L p F P
0 g
s
.571 .464 .693 r
.49608 .76506 m .50064 .78257 L .47284 .7864 L p F P
0 g
s
.214 .614 .951 r
.10521 .91054 m .11359 .91212 L .1044 .90575 L p F P
0 g
s
.214 .614 .951 r
.1044 .90575 m .09475 .90409 L .10521 .91054 L p F P
0 g
s
.595 .61 .836 r
.57394 .89703 m .54577 .90201 L .53833 .88735 L p F P
0 g
s
.819 .672 .7 r
.30515 .76834 m .32124 .77341 L .31014 .78999 L p F P
0 g
s
.792 .646 .7 r
.31507 .75214 m .30515 .76834 L .32124 .77341 L p F P
0 g
s
.792 .646 .7 r
.31762 .75291 m .31507 .75214 L p .32124 .77341 L F P
0 g
s
.605 .773 .961 r
.65239 .91438 m .62393 .92187 L .61685 .91386 L p F P
0 g
s
.641 .938 .964 r
.6877 .90916 m .70539 .90118 L .69208 .91037 L closepath p F P
0 g
s
.681 .964 .936 r
.71625 .89596 m .70539 .90118 L .69208 .91037 L p F P
0 g
s
.681 .964 .936 r
.72248 .89507 m .71625 .89596 L p .69208 .91037 L F P
0 g
s
.794 .706 .767 r
.28625 .84683 m .30288 .85154 L .28532 .87006 L p F P
0 g
s
.768 .665 .748 r
.30211 .82878 m .28625 .84683 L .30288 .85154 L p F P
0 g
s
.768 .665 .748 r
.30452 .82938 m .30211 .82878 L p .30288 .85154 L F P
0 g
s
.579 .485 .712 r
.47986 .81133 m .47462 .79271 L .50083 .78323 L p F P
0 g
s
.579 .485 .713 r
.50064 .78257 m .50083 .78323 L .47462 .79271 L p F P
0 g
s
.523 .661 .923 r
.6087 .53799 m .60228 .52904 L .60768 .52878 L closepath p F P
0 g
s
.599 .531 .749 r
.51973 .8423 m .52333 .85222 L .49541 .85789 L p F P
0 g
s
.599 .531 .749 r
.49541 .85789 m .493 .85108 L .51973 .8423 L p F P
0 g
s
0 0 0 r
.77505 .84493 m .76797 .85138 L .75458 .86888 L p F P
0 g
s
.239 .186 .594 r
.48983 .61616 m .49607 .60511 L p .49451 .62897 L F P
0 g
s
.239 .186 .594 r
.49451 .62897 m .49077 .62207 L .48983 .61616 L p F P
0 g
s
.09 .063 .53 r
.48983 .61616 m .49607 .60511 L .49214 .59343 L p F P
0 g
s
.939 .802 .343 r
.4922 .55724 m .49081 .54697 L .493 .53356 L p F P
0 g
s
.892 .713 .654 r
.29873 .6874 m .30962 .69432 L .3036 .70921 L p F P
0 g
s
.888 .705 .648 r
.30962 .69432 m .29873 .6874 L .30421 .67273 L p F P
0 g
s
.597 .531 .751 r
.51578 .8315 m .51973 .8423 L .493 .85108 L p F P
0 g
s
.597 .531 .751 r
.493 .85108 m .48788 .83674 L .51578 .8315 L p F P
0 g
s
.794 .727 .79 r
.26265 .89001 m .25565 .89623 L .24731 .88589 L p F P
0 g
s
.804 .65 .692 r
.31762 .75291 m .31643 .74993 L .31507 .75214 L closepath p F P
0 g
s
.807 .666 .708 r
.31492 .81165 m .30345 .82728 L .29549 .81201 L p F P
0 g
s
.807 .666 .708 r
.29549 .81201 m .2991 .80659 L .31492 .81165 L p F P
0 g
s
.807 .666 .708 r
.31492 .81165 m .2991 .80659 L .31014 .78999 L p F P
0 g
s
.794 .727 .79 r
.24731 .88589 m .2486 .88465 L .26265 .89001 L p F P
0 g
s
.766 .698 .787 r
.26908 .86526 m .2486 .88465 L .26265 .89001 L p F P
0 g
s
.766 .698 .787 r
.2811 .86863 m .26908 .86526 L p .26265 .89001 L F P
0 g
s
.766 .698 .787 r
.26265 .89001 m .28337 .87213 L .2811 .86863 L p F P
0 g
s
.813 .663 .697 r
.31507 .75214 m .31643 .74993 L .30862 .73205 L p F P
0 g
s
.394 .499 .848 r
.72884 .61539 m .73883 .61831 L .73188 .60446 L p F P
0 g
s
.394 .499 .848 r
.73188 .60446 m .73184 .60444 L .72884 .61539 L p F P
0 g
s
.438 .846 .666 r
.73107 .88905 m .72248 .89507 L .71625 .89596 L p F P
0 g
s
.584 .488 .712 r
.48035 .81305 m .47986 .81133 L .5064 .80222 L p F P
0 g
s
.579 .485 .712 r
.50083 .78323 m .5064 .80222 L .47986 .81133 L p F P
0 g
s
.794 .706 .767 r
.27524 .8596 m .28625 .84683 L p .28532 .87006 L F P
0 g
s
.794 .706 .767 r
.28532 .87006 m .2811 .86863 L .27524 .8596 L p F P
0 g
s
.795 .705 .766 r
.28337 .87213 m .28532 .87006 L .2811 .86863 L closepath p F P
0 g
s
.588 .508 .732 r
.486 .8308 m .48035 .81305 L .50821 .80839 L p F P
0 g
s
.584 .488 .712 r
.5064 .80222 m .50821 .80839 L .48035 .81305 L p F P
0 g
s
.382 .465 .821 r
.74695 .63479 m .74762 .63292 L p .7627 .65158 L F P
0 g
s
.408 .5 .842 r
.74695 .63479 m .74577 .63237 L .74762 .63292 L closepath p F P
0 g
s
.591 .509 .73 r
.48788 .83674 m .486 .8308 L .51262 .82184 L p F P
0 g
s
.588 .508 .732 r
.50821 .80839 m .51262 .82184 L .486 .8308 L p F P
0 g
s
0 .153 .594 r
.065 .88958 m .07035 .89332 L .06101 .8866 L p F P
0 g
s
0 .153 .594 r
.06101 .8866 m .05543 .88273 L .065 .88958 L p F P
0 g
s
.591 .509 .73 r
.51262 .82184 m .51578 .8315 L .48788 .83674 L p F P
0 g
s
.448 .57 .885 r
.70879 .58815 m .69529 .58616 L .68834 .57414 L p F P
0 g
s
.38 .302 .643 r
.49831 .66383 m .48834 .65415 L .49531 .64797 L closepath p F P
0 g
s
.374 .293 .635 r
.48834 .65415 m .49531 .64797 L .49241 .63187 L p F P
0 g
s
.834 .682 .694 r
.30037 .74658 m .31507 .75214 L .30515 .76834 L p F P
0 g
s
.813 .663 .697 r
.30862 .73205 m .30037 .74658 L .31507 .75214 L p F P
0 g
s
.256 .284 .698 r
.79586 .70166 m .78964 .71289 L .7996 .72368 L p F P
0 g
s
.297 .335 .732 r
.78964 .71289 m .79586 .70166 L .78368 .69161 L p F P
0 g
s
.488 .384 .662 r
.484 .71287 m .50489 .69878 L p .4961 .72463 L F P
0 g
s
.488 .384 .662 r
.4961 .72463 m .48555 .72061 L .484 .71287 L p F P
0 g
s
.448 .355 .657 r
.484 .71287 m .50489 .69878 L .49012 .68994 L p F P
0 g
s
.544 .678 .926 r
.56668 .52197 m .59509 .5193 L .60228 .52904 L p F P
0 g
s
.542 .685 .932 r
.59509 .5193 m .56668 .52197 L .55938 .51256 L p F P
0 g
s
.221 .178 .596 r
.49241 .63187 m .49077 .62207 L .49451 .62897 L closepath p F P
0 g
s
0 0 0 r
.73107 .88905 m .74546 .87777 L .7505 .87312 L closepath p F P
0 g
s
.438 .846 .666 r
.74546 .87777 m .73107 .88905 L p .71625 .89596 L F P
0 g
s
.496 .627 .909 r
.6493 .55565 m .64522 .54943 L .6495 .54952 L closepath p F P
0 g
s
.403 .503 .846 r
.74762 .63292 m .74577 .63237 L .73883 .61831 L p F P
0 g
s
.598 .728 .936 r
.54111 .51606 m .55938 .51256 L .55203 .50338 L p F P
0 g
s
.598 .728 .936 r
.55203 .50338 m .53654 .50669 L .54111 .51606 L p F P
0 g
s
.594 .732 .94 r
.52387 .50954 m .53654 .50669 L .54111 .51606 L p F P
0 g
s
.821 .825 .852 r
.51527 .51364 m .49599 .52716 L .4884 .52322 L p F P
0 g
s
.955 .841 .691 r
.493 .53356 m .49599 .52716 L .4884 .52322 L p F P
0 g
s
.563 .858 .542 r
.74546 .87777 m .7505 .87312 L .75458 .86888 L p F P
0 g
s
.563 .858 .542 r
.75458 .86888 m .76792 .85666 L p .74546 .87777 L F P
0 g
s
0 0 0 r
.77262 .85102 m .77505 .84493 L p .75458 .86888 L F P
0 g
s
0 0 0 r
.75458 .86888 m .76792 .85666 L .77262 .85102 L p F P
0 g
s
.916 .74 .649 r
.29494 .66521 m .30421 .67273 L .29873 .6874 L p F P
0 g
s
.916 .736 .643 r
.30421 .67273 m .29494 .66521 L .3001 .65068 L p F P
0 g
s
.775 .701 .781 r
.2811 .86863 m .27524 .8596 L .26908 .86526 L closepath p F P
0 g
s
.779 .669 .741 r
.30452 .82938 m .30345 .82728 L .30211 .82878 L closepath p F P
0 g
s
.824 .692 .718 r
.29527 .78458 m .31014 .78999 L .2991 .80659 L p F P
0 g
s
.819 .672 .7 r
.31014 .78999 m .29527 .78458 L .30515 .76834 L p F P
0 g
s
.48 .392 .68 r
.48765 .72986 m .48555 .72061 L .4961 .72463 L closepath p F P
0 g
s
.382 .465 .821 r
.74762 .63292 m .76655 .64062 L .7627 .65158 L p F P
0 g
s
.362 .469 .835 r
.75079 .62204 m .74762 .63292 L .76655 .64062 L p F P
0 g
s
.403 .503 .846 r
.73883 .61831 m .75079 .62204 L .74762 .63292 L p F P
0 g
s
.135 .07 .513 r
.79544 .78964 m .80036 .78318 L .7976 .77014 L p F P
0 g
s
.105 .051 .507 r
.80551 .75879 m .7976 .77014 L .80036 .78318 L p F P
0 g
s
.181 .15 .585 r
.7976 .77014 m .80551 .75879 L .80021 .7465 L p F P
0 g
s
.285 .336 .739 r
.78907 .68047 m .78368 .69161 L .79586 .70166 L p F P
0 g
s
.321 .38 .767 r
.78368 .69161 m .78907 .68047 L .7747 .67116 L p F P
0 g
s
0 0 .406 r
.49476 .58206 m .49214 .59343 L .49607 .60511 L p F P
0 g
s
.782 .672 .743 r
.30211 .82878 m .30345 .82728 L .29549 .81201 L p F P
0 g
s
.043 0 .41 r
.80036 .78318 m .79544 .78964 L .79606 .80276 L p F P
0 g
s
.112 0 .432 r
.79088 .80861 m .79606 .80276 L .79544 .78964 L p F P
0 g
s
.862 .693 .672 r
.30862 .73205 m .30923 .73073 L .3075 .72982 L closepath p F P
0 g
s
.862 .692 .669 r
.3007 .71618 m .3036 .70921 L p .30923 .73073 L F P
0 g
s
.862 .692 .669 r
.30923 .73073 m .3075 .72982 L .3007 .71618 L p F P
0 g
s
.809 .699 .744 r
.28577 .82391 m .30211 .82878 L .28625 .84683 L p F P
0 g
s
.782 .672 .743 r
.29549 .81201 m .28577 .82391 L .30211 .82878 L p F P
0 g
s
.615 .581 .793 r
.53833 .88735 m .53731 .88758 L .5383 .88727 L closepath p F P
0 g
s
.614 .579 .791 r
.53085 .87077 m .5383 .88727 L .53731 .88758 L p F P
0 g
s
.837 .687 .697 r
.30037 .74658 m .30862 .73205 L .3075 .72982 L p F P
0 g
s
.451 .578 .89 r
.68834 .57414 m .68155 .57324 L .68255 .56435 L closepath p F P
0 g
s
.482 .602 .895 r
.68137 .56244 m .68255 .56435 L .68155 .57324 L p F P
0 g
s
.595 .61 .836 r
.53833 .88735 m .56654 .88312 L .57394 .89703 L p F P
0 g
s
.591 .569 .798 r
.5637 .87713 m .56654 .88312 L .53833 .88735 L p F P
0 g
s
.591 .569 .798 r
.53833 .88735 m .5383 .88727 L .5637 .87713 L p F P
0 g
s
.585 .568 .801 r
.55908 .86746 m .5637 .87713 L .5383 .88727 L p F P
0 g
s
.585 .568 .801 r
.5383 .88727 m .53085 .87077 L .55908 .86746 L p F P
0 g
s
.36 .425 .793 r
.7627 .65158 m .7793 .66012 L .7747 .67116 L p F P
0 g
s
.338 .428 .808 r
.76655 .64062 m .7627 .65158 L .7793 .66012 L p F P
0 g
s
.601 .695 .909 r
.58127 .90929 m .60967 .90424 L .61685 .91386 L p F P
0 g
s
.591 .633 .862 r
.60258 .89332 m .60967 .90424 L .58127 .90929 L p F P
0 g
s
.591 .633 .862 r
.58127 .90929 m .57888 .90527 L .60258 .89332 L p F P
0 g
s
.001 0 .295 r
.79606 .80276 m .79088 .80861 L .78749 .82343 L p F P
0 g
s
.312 .384 .776 r
.7793 .66012 m .7747 .67116 L .78907 .68047 L p F P
0 g
s
.23 .193 .608 r
.49451 .62897 m .49241 .63187 L .49531 .64797 L p F P
0 g
s
.719 .754 .88 r
.2202 .90671 m .21977 .90627 L .21938 .90647 L closepath p F P
0 g
s
.999 .786 .454 r
.488 .52432 m .493 .53356 L .49081 .54697 L p F P
0 g
s
.955 .841 .691 r
.4884 .52322 m .488 .52432 L .493 .53356 L p F P
0 g
s
.481 .394 .681 r
.49161 .7472 m .48765 .72986 L .4961 .72463 L p F P
0 g
s
.837 .687 .697 r
.3075 .72982 m .29621 .72458 L p .30037 .74658 L F P
0 g
s
.844 .688 .689 r
.3075 .72982 m .3007 .71618 L .29621 .72458 L closepath p F P
0 g
s
.736 .756 .869 r
.184 .91317 m .2044 .90136 L .21938 .90647 L p F P
0 g
s
.719 .755 .881 r
.21119 .89756 m .2044 .90136 L .21938 .90647 L p F P
0 g
s
.719 .755 .881 r
.21938 .90647 m .21977 .90627 L .21119 .89756 L p F P
0 g
s
.526 .75 .977 r
.11359 .91212 m .1395 .90887 L .14852 .91566 L p F P
0 g
s
.539 .753 .975 r
.1395 .90887 m .11359 .91212 L .1044 .90575 L p F P
0 g
s
.771 .732 .817 r
.24731 .88589 m .21977 .90627 L .21119 .89756 L p F P
0 g
s
.709 .776 .904 r
.51639 .50105 m .5099 .50448 L .51527 .51364 L p F P
0 g
s
.709 .776 .904 r
.51527 .51364 m .52387 .50954 L .51639 .50105 L p F P
0 g
s
.821 .825 .852 r
.4884 .52322 m .5099 .50448 L .51527 .51364 L p F P
0 g
s
.439 .358 .668 r
.50198 .6812 m .49012 .68994 L .50489 .69878 L p F P
0 g
s
.459 .347 .639 r
.49841 .66432 m .50198 .6812 L .49012 .68994 L p F P
0 g
s
.844 .696 .699 r
.29136 .76253 m .30515 .76834 L .29527 .78458 L p F P
0 g
s
.834 .682 .694 r
.30515 .76834 m .29136 .76253 L .30037 .74658 L p F P
0 g
s
.81 .699 .743 r
.28625 .84683 m .27524 .8596 L .26705 .8473 L p F P
0 g
s
.81 .699 .743 r
.26705 .8473 m .27169 .84147 L .28625 .84683 L p F P
0 g
s
.809 .699 .744 r
.28625 .84683 m .27169 .84147 L .28577 .82391 L p F P
0 g
s
.89 .715 .658 r
.3036 .70921 m .3007 .71618 L .29258 .70322 L p F P
0 g
s
.89 .715 .658 r
.29258 .70322 m .29298 .70223 L .3036 .70921 L p F P
0 g
s
.892 .713 .654 r
.3036 .70921 m .29298 .70223 L .29873 .6874 L p F P
0 g
s
.492 .632 .915 r
.6495 .54952 m .64522 .54943 L .63816 .53895 L p F P
0 g
s
.591 .635 .864 r
.60241 .89306 m .60258 .89332 L .57888 .90527 L p F P
0 g
s
.591 .635 .864 r
.57888 .90527 m .57394 .89703 L .60241 .89306 L p F P
0 g
s
.049 .512 .889 r
.07035 .89332 m .08472 .89743 L .09475 .90409 L p F P
0 g
s
.093 .529 .908 r
.08472 .89743 m .07035 .89332 L .06101 .8866 L p F P
0 g
s
.824 .692 .718 r
.29549 .81201 m .2991 .80659 L .29067 .80321 L closepath p F P
0 g
s
.824 .692 .718 r
.28747 .79736 m .29527 .78458 L p .2991 .80659 L F P
0 g
s
.824 .692 .718 r
.2991 .80659 m .29067 .80321 L .28747 .79736 L p F P
0 g
s
.519 .667 .929 r
.60768 .52878 m .60228 .52904 L .59509 .5193 L p F P
0 g
s
.602 .739 .941 r
.53654 .50669 m .52387 .50954 L .51639 .50105 L p F P
0 g
s
.777 .705 .784 r
.26908 .86526 m .27524 .8596 L .26705 .8473 L p F P
0 g
s
.777 .705 .784 r
.26705 .8473 m .25422 .86003 L .26908 .86526 L p F P
0 g
s
.8 .74 .796 r
.25422 .86003 m .26908 .86526 L .2486 .88465 L p F P
0 g
s
.511 .416 .683 r
.49161 .7472 m .51419 .7336 L p .50983 .75726 L F P
0 g
s
.511 .416 .683 r
.50983 .75726 m .49308 .75354 L .49161 .7472 L p F P
0 g
s
.481 .394 .681 r
.51353 .73109 m .51419 .7336 L .49161 .7472 L p F P
0 g
s
.481 .394 .681 r
.4961 .72463 m .51353 .73109 L p .49161 .7472 L F P
0 g
s
.599 .922 .971 r
.70539 .90118 m .6877 .90916 L .68104 .90549 L p F P
0 g
s
.603 .875 .992 r
.65239 .91438 m .68104 .90549 L .6877 .90916 L p F P
0 g
s
.748 .768 .868 r
.2044 .90136 m .184 .91317 L .17519 .90563 L p F P
0 g
s
.673 .773 .926 r
.14852 .91566 m .17519 .90563 L .184 .91317 L p F P
0 g
s
.39 .5 .85 r
.75079 .62204 m .73883 .61831 L .73188 .60446 L p F P
0 g
s
.8 .74 .796 r
.24731 .88589 m .2486 .88465 L .24502 .88309 L closepath p F P
0 g
s
.8 .74 .796 r
.23891 .87566 m .25422 .86003 L p .2486 .88465 L F P
0 g
s
.8 .74 .796 r
.2486 .88465 m .24502 .88309 L .23891 .87566 L p F P
0 g
s
.771 .732 .817 r
.24502 .88309 m .24731 .88589 L p .21119 .89756 L F P
0 g
s
.23 .193 .608 r
.49531 .64797 m .50106 .64001 L .49451 .62897 L p F P
0 g
s
.041 .069 .563 r
.50069 .61667 m .49451 .62897 L .50106 .64001 L p F P
0 g
s
.239 .186 .594 r
.49607 .60511 m .50069 .61667 L .49451 .62897 L p F P
0 g
s
.682 .778 .923 r
.17519 .90563 m .14852 .91566 L .1395 .90887 L p F P
0 g
s
.605 .773 .961 r
.61685 .91386 m .64543 .90753 L .65239 .91438 L p F P
0 g
s
.594 .725 .935 r
.64543 .90753 m .61685 .91386 L .60967 .90424 L p F P
0 g
s
.238 .621 .957 r
.09475 .90409 m .1044 .90575 L .09516 .89912 L p F P
0 g
s
.238 .621 .957 r
.09516 .89912 m .08472 .89743 L .09475 .90409 L p F P
0 g
s
.574 .54 .779 r
.55288 .85304 m .55908 .86746 L .53085 .87077 L p F P
0 g
s
.574 .54 .779 r
.53085 .87077 m .5281 .86394 L .55288 .85304 L p F P
0 g
s
.798 .685 .739 r
.28577 .82391 m .29549 .81201 L .29067 .80321 L p F P
0 g
s
0 0 0 r
.77262 .85102 m .78033 .83933 L .77505 .84493 L closepath p F P
0 g
s
0 0 .12 r
.77505 .84493 m .78033 .83933 L .78749 .82343 L p F P
0 g
s
.448 .57 .885 r
.68834 .57414 m .7101 .5775 L .70879 .58815 L p F P
0 g
s
.438 .571 .89 r
.7101 .5775 m .68834 .57414 L .68255 .56435 L p F P
0 g
s
.859 .709 .695 r
.2878 .74032 m .30037 .74658 L .29136 .76253 L p F P
0 g
s
.837 .687 .697 r
.29621 .72458 m .2878 .74032 L .30037 .74658 L p F P
0 g
s
.157 .139 .585 r
.80684 .73597 m .80021 .7465 L .80551 .75879 L p F P
0 g
s
.227 .229 .653 r
.80629 .73377 m .7996 .72368 L p .80021 .7465 L F P
0 g
s
.227 .229 .653 r
.80021 .7465 m .80684 .73597 L .80629 .73377 L p F P
0 g
s
.915 .745 .657 r
.28951 .67989 m .29873 .6874 L .29298 .70223 L p F P
0 g
s
.916 .74 .649 r
.29873 .6874 m .28951 .67989 L .29494 .66521 L p F P
0 g
s
.506 .428 .702 r
.49608 .76506 m .49308 .75354 L .50983 .75726 L closepath p F P
0 g
s
.864 .717 .698 r
.29621 .72458 m .3007 .71618 L .29258 .70322 L p F P
0 g
s
.33 .268 .635 r
.49531 .64797 m .50106 .64001 L p .49856 .66414 L F P
0 g
s
.33 .268 .635 r
.49856 .66414 m .49831 .66383 L .49531 .64797 L p F P
0 g
s
.461 .608 .91 r
.6495 .54952 m .67438 .55144 L .66737 .54069 L p F P
0 g
s
.461 .608 .91 r
.66737 .54069 m .64879 .5392 L .6495 .54952 L p F P
0 g
s
.492 .632 .915 r
.63816 .53895 m .64879 .5392 L .6495 .54952 L p F P
0 g
s
.572 .541 .781 r
.55157 .85002 m .55288 .85304 L .5281 .86394 L p F P
0 g
s
.572 .541 .781 r
.5281 .86394 m .52333 .85222 L .55157 .85002 L p F P
0 g
s
.606 .821 .982 r
.68104 .90549 m .65239 .91438 L .64543 .90753 L p F P
0 g
s
.425 .544 .873 r
.72496 .59178 m .70879 .58815 L p .73184 .60444 L F P
0 g
s
.406 .535 .874 r
.70879 .58815 m .72496 .59178 L .71803 .57934 L p F P
0 g
s
.406 .535 .874 r
.71803 .57934 m .7101 .5775 L .70879 .58815 L p F P
0 g
s
.53 .443 .702 r
.49608 .76506 m .50983 .75726 L p .50182 .78271 L F P
0 g
s
.53 .443 .702 r
.50182 .78271 m .50064 .78257 L .49608 .76506 L p F P
0 g
s
.771 .732 .817 r
.21119 .89756 m .2341 .87935 L .24502 .88309 L p F P
0 g
s
.768 .735 .822 r
.24502 .88309 m .23891 .87566 L .2341 .87935 L closepath p F P
0 g
s
.495 .649 .926 r
.60768 .52878 m .63106 .52871 L .62393 .51871 L p F P
0 g
s
.495 .649 .926 r
.62393 .51871 m .6054 .51879 L .60768 .52878 L p F P
0 g
s
.519 .667 .929 r
.59509 .5193 m .6054 .51879 L .60768 .52878 L p F P
0 g
s
.843 .697 .7 r
.29527 .78458 m .28747 .79736 L .27935 .78371 L p F P
0 g
s
.843 .697 .7 r
.27935 .78371 m .2823 .77856 L .29527 .78458 L p F P
0 g
s
.844 .696 .699 r
.29527 .78458 m .2823 .77856 L .29136 .76253 L p F P
0 g
s
.823 .722 .753 r
.27152 .81837 m .28577 .82391 L .27169 .84147 L p F P
0 g
s
.798 .685 .739 r
.2846 .8011 m .27152 .81837 L .28577 .82391 L p F P
0 g
s
.798 .685 .739 r
.29067 .80321 m .2846 .8011 L p .28577 .82391 L F P
0 g
s
.542 .685 .932 r
.55938 .51256 m .58786 .50978 L .59509 .5193 L p F P
0 g
s
.54 .692 .938 r
.58786 .50978 m .55938 .51256 L .55203 .50338 L p F P
0 g
s
0 0 .06 r
.79543 .81456 m .78749 .82343 L .78033 .83933 L p F P
0 g
s
.001 0 .295 r
.78749 .82343 m .79543 .81456 L .79606 .80276 L p F P
0 g
s
.576 .62 .86 r
.60241 .89306 m .57394 .89703 L .56654 .88312 L p F P
0 g
s
.558 .512 .76 r
.54408 .83085 m .55157 .85002 L .52333 .85222 L p F P
0 g
s
.558 .512 .76 r
.52333 .85222 m .51973 .8423 L .54408 .83085 L p F P
0 g
s
.478 .398 .688 r
.51353 .73109 m .4961 .72463 L .50984 .71581 L closepath p F P
0 g
s
.488 .384 .662 r
.5059 .69937 m .50984 .71581 L .4961 .72463 L p F P
0 g
s
.488 .384 .662 r
.50489 .69878 m .5059 .69937 L p .4961 .72463 L F P
0 g
s
.876 .728 .695 r
.28504 .71779 m .29621 .72458 L .2878 .74032 L p F P
0 g
s
.864 .717 .698 r
.29258 .70322 m .28504 .71779 L .29621 .72458 L p F P
0 g
s
.806 .687 .733 r
.29067 .80321 m .28747 .79736 L .2846 .8011 L closepath p F P
0 g
s
.967 .696 .27 r
.48625 .53762 m .49081 .54697 L .49122 .55964 L p F P
0 g
s
.999 .786 .454 r
.49081 .54697 m .48625 .53762 L .488 .52432 L p F P
0 g
s
.526 .458 .722 r
.50083 .78323 m .50064 .78257 L .50182 .78271 L closepath p F P
0 g
s
.526 .458 .722 r
.5064 .80222 m .50083 .78323 L .50182 .78271 L p F P
0 g
s
.559 .514 .761 r
.54401 .83068 m .54408 .83085 L .51973 .8423 L p F P
0 g
s
.559 .514 .761 r
.51973 .8423 m .51578 .8315 L .54401 .83068 L p F P
0 g
s
.748 .768 .868 r
.17519 .90563 m .19132 .89566 L .2044 .90136 L p F P
0 g
s
.732 .761 .876 r
.20254 .88896 m .19132 .89566 L .2044 .90136 L p F P
0 g
s
.732 .761 .876 r
.2044 .90136 m .21119 .89756 L .20254 .88896 L p F P
0 g
s
.043 0 .41 r
.79606 .80276 m .80043 .79705 L .80036 .78318 L p F P
0 g
s
.006 0 .396 r
.80831 .77187 m .80036 .78318 L .80043 .79705 L p F P
0 g
s
.105 .051 .507 r
.80036 .78318 m .80831 .77187 L .80551 .75879 L p F P
0 g
s
0 0 .265 r
.80043 .79705 m .79606 .80276 L .79543 .81456 L p F P
0 g
s
.599 .922 .971 r
.71354 .89543 m .70539 .90118 L p .68104 .90549 L F P
0 g
s
.636 .949 .947 r
.70539 .90118 m .71354 .89543 L .71625 .89596 L closepath p F P
0 g
s
.197 .209 .646 r
.80629 .73377 m .7996 .72368 L .80248 .71857 L closepath p F P
0 g
s
.256 .284 .698 r
.79826 .70436 m .79586 .70166 L p .7996 .72368 L F P
0 g
s
.256 .284 .698 r
.7996 .72368 m .80248 .71857 L .79826 .70436 L p F P
0 g
s
.526 .458 .722 r
.50182 .78271 m .5288 .78572 L p .5064 .80222 L F P
0 g
s
.527 .458 .722 r
.5288 .78572 m .50182 .78271 L .5244 .77075 L closepath p F P
0 g
s
.53 .443 .702 r
.52116 .75974 m .5244 .77075 L .50182 .78271 L p F P
0 g
s
.53 .443 .702 r
.50983 .75726 m .52116 .75974 L p .50182 .78271 L F P
0 g
s
.309 .263 .642 r
.49841 .66432 m .49831 .66383 L .49856 .66414 L closepath p F P
0 g
s
.315 .272 .65 r
.49856 .66414 m .49841 .66432 L .50198 .6812 L p F P
0 g
s
.53 .46 .722 r
.50821 .80839 m .5064 .80222 L .5302 .79003 L p F P
0 g
s
.526 .458 .722 r
.5288 .78572 m .5302 .79003 L .5064 .80222 L p F P
0 g
s
.544 .485 .741 r
.53666 .80998 m .54401 .83068 L .51578 .8315 L p F P
0 g
s
.544 .485 .741 r
.51578 .8315 m .51262 .82184 L .53666 .80998 L p F P
0 g
s
.604 .735 .937 r
.53654 .50669 m .55203 .50338 L .54463 .49442 L p F P
0 g
s
.604 .735 .937 r
.54463 .49442 m .53087 .49758 L .53654 .50669 L p F P
0 g
s
.602 .739 .941 r
.51639 .50105 m .53087 .49758 L .53654 .50669 L p F P
0 g
s
.544 .487 .742 r
.53642 .8093 m .53666 .80998 L .51262 .82184 L p F P
0 g
s
.544 .487 .742 r
.51262 .82184 m .50821 .80839 L .53642 .8093 L p F P
0 g
s
0 0 .428 r
.49785 .59403 m .49607 .60511 L .50069 .61667 L p F P
0 g
s
0 0 .406 r
.49607 .60511 m .49785 .59403 L .49476 .58206 L p F P
0 g
s
.823 .722 .753 r
.26705 .8473 m .27169 .84147 L .25897 .83575 L closepath p F P
0 g
s
.823 .722 .753 r
.25878 .83547 m .27152 .81837 L p .27169 .84147 L F P
0 g
s
.823 .722 .753 r
.27169 .84147 m .25897 .83575 L .25878 .83547 L p F P
0 g
s
.315 .272 .65 r
.50198 .6812 m .50778 .67456 L .49856 .66414 L p F P
0 g
s
.198 .194 .628 r
.50798 .65106 m .49856 .66414 L .50778 .67456 L p F P
0 g
s
.33 .268 .635 r
.50106 .64001 m .50798 .65106 L .49856 .66414 L p F P
0 g
s
.53 .46 .722 r
.5302 .79003 m .53642 .8093 L .50821 .80839 L p F P
0 g
s
.862 .722 .707 r
.27936 .75612 m .29136 .76253 L .2823 .77856 L p F P
0 g
s
.859 .709 .695 r
.29136 .76253 m .27936 .75612 L .2878 .74032 L p F P
0 g
s
.785 .745 .817 r
.2341 .87935 m .21119 .89756 L .20254 .88896 L p F P
0 g
s
.815 .7 .739 r
.2846 .8011 m .28747 .79736 L .27935 .78371 L p F P
0 g
s
.386 .504 .855 r
.73188 .60446 m .73184 .60444 L .73185 .60439 L closepath p F P
0 g
s
.425 .544 .873 r
.73184 .60444 m .73185 .60439 L .72496 .59178 L p F P
0 g
s
.39 .5 .85 r
.73188 .60446 m .75303 .61133 L .75079 .62204 L p F P
0 g
s
.375 .497 .854 r
.75303 .61133 m .73188 .60446 L .73185 .60439 L p F P
0 g
s
.375 .497 .854 r
.73185 .60439 m .73344 .59381 L p .75303 .61133 L F P
0 g
s
.405 .532 .872 r
.73185 .60439 m .72496 .59178 L .73344 .59381 L closepath p F P
0 g
s
.792 .716 .781 r
.25422 .86003 m .26705 .8473 L .25897 .83575 L p F P
0 g
s
.835 .719 .737 r
.27099 .79529 m .2846 .8011 L .27152 .81837 L p F P
0 g
s
.815 .7 .739 r
.27935 .78371 m .27099 .79529 L .2846 .8011 L p F P
0 g
s
.438 .571 .89 r
.68255 .56435 m .68264 .56256 L p .7101 .5775 L F P
0 g
s
.463 .597 .9 r
.68255 .56435 m .68137 .56244 L .68264 .56256 L closepath p F P
0 g
s
.81 .73 .776 r
.25422 .86003 m .23891 .87566 L .23044 .8657 L p F P
0 g
s
.81 .73 .776 r
.23044 .8657 m .24096 .85428 L .25422 .86003 L p F P
0 g
s
.792 .716 .781 r
.25863 .83562 m .24096 .85428 L .25422 .86003 L p F P
0 g
s
.792 .716 .781 r
.25897 .83575 m .25863 .83562 L p .25422 .86003 L F P
0 g
s
.913 .747 .662 r
.29258 .70322 m .29298 .70223 L .28855 .6986 L closepath p F P
0 g
s
.915 .745 .657 r
.28424 .69363 m .28951 .67989 L p .29298 .70223 L F P
0 g
s
.915 .745 .657 r
.29298 .70223 m .28855 .6986 L .28424 .69363 L p F P
0 g
s
.485 .636 .921 r
.64879 .5392 m .63816 .53895 L .63106 .52871 L p F P
0 g
s
.827 .843 .86 r
.4845 .51987 m .4884 .52322 L .5099 .50448 L p F P
0 g
s
.951 .791 .648 r
.488 .52432 m .4845 .51987 L .4884 .52322 L closepath p F P
0 g
s
.539 .753 .975 r
.1044 .90575 m .13042 .90198 L .1395 .90887 L p F P
0 g
s
.547 .755 .974 r
.13042 .90198 m .1044 .90575 L .09516 .89912 L p F P
0 g
s
.438 .846 .666 r
.71625 .89596 m .74469 .87816 L .74546 .87777 L p F P
0 g
s
.728 .972 .929 r
.71354 .89543 m .71625 .89596 L .74469 .87816 L p F P
0 g
s
.893 .755 .702 r
.28504 .71779 m .29258 .70322 L .28855 .6986 L p F P
0 g
s
.785 .745 .817 r
.20254 .88896 m .2206 .87371 L .2341 .87935 L p F P
0 g
s
.771 .742 .826 r
.23044 .8657 m .2206 .87371 L .2341 .87935 L p F P
0 g
s
.771 .742 .826 r
.2341 .87935 m .23891 .87566 L .23044 .8657 L p F P
0 g
s
.982 .743 .497 r
.4845 .51987 m .488 .52432 L .48625 .53762 L p F P
0 g
s
.827 .843 .86 r
.5099 .50448 m .50297 .49573 L p .4845 .51987 L F P
0 g
s
.726 .781 .897 r
.50886 .4925 m .50297 .49573 L .5099 .50448 L p F P
0 g
s
.726 .781 .897 r
.5099 .50448 m .51639 .50105 L .50886 .4925 L p F P
0 g
s
.227 .265 .694 r
.79826 .70436 m .79586 .70166 L .79685 .69966 L closepath p F P
0 g
s
.285 .336 .739 r
.79077 .68194 m .78907 .68047 L p .79586 .70166 L F P
0 g
s
.285 .336 .739 r
.79586 .70166 m .79685 .69966 L .79077 .68194 L p F P
0 g
s
.459 .602 .906 r
.68264 .56256 m .68137 .56244 L .67438 .55144 L p F P
0 g
s
0 0 0 r
.78033 .83933 m .79077 .82766 L p .77123 .85351 L F P
0 g
s
0 0 0 r
.77123 .85351 m .77262 .85102 L .78033 .83933 L p F P
0 g
s
0 0 .06 r
.7944 .82005 m .79543 .81456 L p .78033 .83933 L F P
0 g
s
0 0 .06 r
.78033 .83933 m .79077 .82766 L .7944 .82005 L p F P
0 g
s
.515 .672 .935 r
.6054 .51879 m .59509 .5193 L .58786 .50978 L p F P
0 g
s
.594 .725 .935 r
.60967 .90424 m .63836 .89912 L .64543 .90753 L p F P
0 g
s
.585 .654 .884 r
.6312 .88925 m .63836 .89912 L .60967 .90424 L p F P
0 g
s
.585 .654 .884 r
.60316 .89296 m .6312 .88925 L p .60967 .90424 L F P
0 g
s
.585 .654 .884 r
.60967 .90424 m .60258 .89332 L .60316 .89296 L p F P
0 g
s
.093 .529 .908 r
.06101 .8866 m .07514 .89057 L .08472 .89743 L p F P
0 g
s
.362 .469 .835 r
.76934 .62975 m .75079 .62204 L p .76655 .64062 L F P
0 g
s
.337 .454 .832 r
.75079 .62204 m .76934 .62975 L .76237 .61535 L p F P
0 g
s
.337 .454 .832 r
.76237 .61535 m .75303 .61133 L .75079 .62204 L p F P
0 g
s
.317 .275 .653 r
.50778 .67456 m .50198 .6812 L .50565 .69823 L p F P
0 g
s
.439 .358 .668 r
.50489 .69878 m .50565 .69823 L .50198 .6812 L p F P
0 g
s
.88 .735 .697 r
.27697 .73346 m .2878 .74032 L .27936 .75612 L p F P
0 g
s
.876 .728 .695 r
.2878 .74032 m .27697 .73346 L .28504 .71779 L p F P
0 g
s
.576 .62 .86 r
.56654 .88312 m .59507 .88029 L .60241 .89306 L p F P
0 g
s
.562 .567 .816 r
.58766 .86604 m .59507 .88029 L .56654 .88312 L p F P
0 g
s
.562 .567 .816 r
.58354 .86623 m .58766 .86604 L p .56654 .88312 L F P
0 g
s
.562 .567 .816 r
.56654 .88312 m .5637 .87713 L .58354 .86623 L p F P
0 g
s
.438 .571 .89 r
.68264 .56256 m .71048 .56703 L .7101 .5775 L p F P
0 g
s
.427 .579 .902 r
.68231 .55221 m .68264 .56256 L .71048 .56703 L p F P
0 g
s
.459 .602 .906 r
.67438 .55144 m .68231 .55221 L .68264 .56256 L p F P
0 g
s
.725 .503 0 r
.49301 .57195 m .49122 .55964 L p .49202 .56476 L F P
0 g
s
.725 .503 0 r
.49476 .58206 m .49301 .57195 L p .49202 .56476 L F P
0 g
s
0 0 .153 r
.49301 .57195 m .49476 .58206 L .49785 .59403 L p F P
0 g
s
0 0 .153 r
.49568 .58408 m .49301 .57195 L p .49406 .57673 L F P
0 g
s
0 0 .153 r
.49785 .59403 m .49568 .58408 L p .49406 .57673 L F P
0 g
s
.827 .484 0 r
.49568 .58408 m .49525 .58322 L .49582 .58473 L p F P
0 g
s
0 0 .292 r
.49568 .58408 m .49785 .59403 L .50163 .60589 L p F P
0 g
s
.827 .484 0 r
.49582 .58473 m .49596 .58511 L .49568 .58408 L p F P
0 g
s
.866 .535 .021 r
.49301 .57195 m .49568 .58408 L p .494 .57919 L F P
0 g
s
.866 .535 .021 r
.48837 .56276 m .49301 .57195 L p .494 .57919 L F P
0 g
s
.759 .777 .868 r
.19132 .89566 m .17519 .90563 L .1663 .89812 L p F P
0 g
s
.682 .778 .923 r
.1395 .90887 m .1663 .89812 L .17519 .90563 L p F P
0 g
s
.608 .742 .94 r
.53087 .49758 m .51639 .50105 L .50886 .4925 L p F P
0 g
s
.257 .319 .736 r
.79077 .68194 m .78907 .68047 L .78973 .67893 L closepath p F P
0 g
s
.312 .384 .776 r
.78353 .66298 m .7793 .66012 L p .78907 .68047 L F P
0 g
s
.312 .384 .776 r
.78907 .68047 m .78973 .67893 L .78353 .66298 L p F P
0 g
s
.563 .858 .542 r
.76792 .85666 m .74712 .87622 L .74546 .87777 L p F P
0 g
s
.583 .918 .697 r
.74469 .87816 m .74712 .87622 L .74546 .87777 L closepath p F P
0 g
s
.253 .623 .959 r
.08472 .89743 m .09516 .89912 L .08585 .89225 L p F P
0 g
s
.253 .623 .959 r
.08585 .89225 m .07514 .89057 L .08472 .89743 L p F P
0 g
s
.835 .719 .736 r
.27152 .81837 m .25878 .83547 L .25041 .82429 L p F P
0 g
s
.835 .719 .736 r
.25041 .82429 m .25888 .81231 L .27152 .81837 L p F P
0 g
s
.835 .719 .737 r
.27152 .81837 m .25888 .81231 L .27099 .79529 L p F P
0 g
s
.338 .428 .808 r
.77641 .64586 m .76655 .64062 L p .7793 .66012 L F P
0 g
s
.314 .418 .808 r
.77641 .64586 m .76655 .64062 L .76946 .63001 L closepath p F P
0 g
s
.362 .469 .835 r
.76655 .64062 m .76946 .63001 L .76934 .62975 L p F P
0 g
s
.689 .783 .922 r
.1663 .89812 m .1395 .90887 L .13042 .90198 L p F P
0 g
s
.214 .257 .691 r
.79685 .69966 m .80065 .69073 L p .80539 .71261 L F P
0 g
s
.214 .257 .691 r
.80539 .71261 m .79826 .70436 L .79685 .69966 L p F P
0 g
s
.249 .313 .733 r
.79685 .69966 m .79077 .68194 L .80065 .69073 L closepath p F P
0 g
s
.286 .37 .775 r
.78353 .66298 m .7793 .66012 L .78076 .65594 L closepath p F P
0 g
s
.338 .428 .808 r
.7793 .66012 m .78076 .65594 L .77641 .64586 L p F P
0 g
s
.861 .723 .709 r
.27935 .78371 m .2823 .77856 L .27191 .77266 L closepath p F P
0 g
s
.862 .722 .707 r
.27111 .77146 m .27936 .75612 L p .2823 .77856 L F P
0 g
s
.862 .722 .707 r
.2823 .77856 m .27191 .77266 L .27111 .77146 L p F P
0 g
s
.076 .034 .501 r
.80992 .75188 m .80551 .75879 L .80831 .77187 L p F P
0 g
s
.157 .139 .585 r
.80551 .75879 m .80992 .75188 L .80684 .73597 L p F P
0 g
s
.217 .258 .69 r
.80248 .71857 m .79826 .70436 L .80539 .71261 L closepath p F P
0 g
s
.563 .57 .819 r
.5637 .87713 m .55908 .86746 L .58354 .86623 L closepath p F P
0 g
s
.059 .128 .622 r
.50584 .62818 m .50106 .64001 L .50798 .65106 L p F P
0 g
s
.041 .069 .563 r
.50106 .64001 m .50584 .62818 L .50069 .61667 L p F P
0 g
s
0 0 0 r
.76792 .85666 m .77123 .85351 L .77262 .85102 L closepath p F P
0 g
s
.246 .312 .734 r
.80065 .69073 m .79077 .68194 L .78973 .67893 L p F P
0 g
s
.182 .2 .643 r
.80248 .71857 m .80539 .71261 L p .80724 .73524 L F P
0 g
s
.182 .2 .643 r
.80724 .73524 m .80629 .73377 L .80248 .71857 L p F P
0 g
s
.441 .363 .672 r
.5059 .69937 m .50489 .69878 L .50565 .69823 L closepath p F P
0 g
s
.246 .312 .734 r
.78973 .67893 m .79309 .66962 L p .80065 .69073 L F P
0 g
s
.281 .364 .771 r
.78973 .67893 m .78353 .66298 L .79309 .66962 L closepath p F P
0 g
s
.599 .922 .971 r
.68104 .90549 m .70981 .89427 L .71354 .89543 L p F P
0 g
s
.613 .881 .99 r
.70981 .89427 m .68104 .90549 L .67424 .90008 L p F P
0 g
s
.606 .821 .982 r
.64543 .90753 m .67424 .90008 L .68104 .90549 L p F P
0 g
s
.596 .769 .962 r
.67424 .90008 m .64543 .90753 L .63836 .89912 L p F P
0 g
s
.589 .913 .672 r
.77123 .85351 m .76792 .85666 L .74712 .87622 L p F P
0 g
s
.893 .755 .702 r
.28855 .6986 m .28366 .69477 L p .28504 .71779 L F P
0 g
s
.895 .753 .698 r
.28855 .6986 m .28424 .69363 L .28366 .69477 L closepath p F P
0 g
s
.661 .971 .821 r
.74712 .87622 m .74469 .87816 L .73856 .87921 L p F P
0 g
s
.728 .972 .929 r
.74469 .87816 m .73856 .87921 L p .71354 .89543 L F P
0 g
s
.661 .971 .821 r
.73856 .87921 m .75932 .86427 L .74712 .87622 L p F P
0 g
s
.589 .913 .672 r
.76704 .85773 m .77123 .85351 L p .74712 .87622 L F P
0 g
s
.589 .913 .672 r
.74712 .87622 m .75932 .86427 L .76704 .85773 L p F P
0 g
s
.834 .721 .739 r
.27099 .79529 m .27935 .78371 L .27191 .77266 L p F P
0 g
s
0 0 .265 r
.79543 .81456 m .79755 .8118 L .80043 .79705 L p F P
0 g
s
0 0 .236 r
.80841 .78579 m .80043 .79705 L .79755 .8118 L p F P
0 g
s
.006 0 .396 r
.80043 .79705 m .80841 .78579 L .80831 .77187 L p F P
0 g
s
.54 .692 .938 r
.55203 .50338 m .58057 .50048 L .58786 .50978 L p F P
0 g
s
.538 .699 .944 r
.58057 .50048 m .55203 .50338 L .54463 .49442 L p F P
0 g
s
.391 .329 .667 r
.50565 .69823 m .51723 .68505 L p .51732 .70847 L F P
0 g
s
.391 .329 .667 r
.51732 .70847 m .5059 .69937 L .50565 .69823 L p F P
0 g
s
.317 .275 .653 r
.50565 .69823 m .51723 .68505 L .50778 .67456 L p F P
0 g
s
.374 .329 .679 r
.50984 .71581 m .5059 .69937 L .51732 .70847 L closepath p F P
0 g
s
.759 .777 .868 r
.1663 .89812 m .17949 .88954 L .19132 .89566 L p F P
0 g
s
.744 .769 .874 r
.1938 .88056 m .17949 .88954 L .19132 .89566 L p F P
0 g
s
.744 .769 .874 r
.19132 .89566 m .20254 .88896 L .1938 .88056 L p F P
0 g
s
.898 .759 .7 r
.27566 .71039 m .28504 .71779 L .27697 .73346 L p F P
0 g
s
.893 .755 .702 r
.28366 .69477 m .27566 .71039 L .28504 .71779 L p F P
0 g
s
.505 .431 .706 r
.52116 .75974 m .50983 .75726 L .51908 .75195 L closepath p F P
0 g
s
.511 .416 .683 r
.51419 .7336 m .51908 .75195 L .50983 .75726 L p F P
0 g
s
.967 .696 .27 r
.49122 .55964 m .48668 .5503 L .48625 .53762 L p F P
0 g
s
.677 .946 .959 r
.70981 .89427 m .72187 .88825 L .71354 .89543 L closepath p F P
0 g
s
.728 .972 .929 r
.73856 .87921 m .72187 .88825 L .71354 .89543 L p F P
0 g
s
.976 .81 .614 r
.48074 .51841 m .48168 .51543 L .4845 .51987 L closepath p F P
0 g
s
.827 .843 .86 r
.50297 .49573 m .48168 .51543 L .4845 .51987 L p F P
0 g
s
.982 .743 .497 r
.48074 .51841 m .4845 .51987 L p .48625 .53762 L F P
0 g
s
.4 .536 .877 r
.73344 .59381 m .72496 .59178 L .71803 .57934 L p F P
0 g
s
.798 .717 .776 r
.25897 .83575 m .25878 .83547 L .25863 .83562 L closepath p F P
0 g
s
.452 .612 .917 r
.64879 .5392 m .66737 .54069 L .66032 .53019 L p F P
0 g
s
.452 .612 .917 r
.66032 .53019 m .64705 .52911 L .64879 .5392 L p F P
0 g
s
.485 .636 .921 r
.63106 .52871 m .64705 .52911 L .64879 .5392 L p F P
0 g
s
.804 .729 .781 r
.25863 .83562 m .25878 .83547 L .25041 .82429 L p F P
0 g
s
.823 .747 .78 r
.2454 .82976 m .25863 .83562 L .24096 .85428 L p F P
0 g
s
.804 .729 .781 r
.25041 .82429 m .2454 .82976 L .25863 .83562 L p F P
0 g
s
.565 .549 .795 r
.58354 .86623 m .55908 .86746 L .55288 .85304 L p F P
0 g
s
.879 .736 .699 r
.27936 .75612 m .27111 .77146 L .26272 .76089 L p F P
0 g
s
.879 .736 .699 r
.26272 .76089 m .26883 .7492 L .27936 .75612 L p F P
0 g
s
.88 .735 .697 r
.27936 .75612 m .26883 .7492 L .27697 .73346 L p F P
0 g
s
.49 .656 .933 r
.6054 .51879 m .62393 .51871 L .61675 .50896 L p F P
0 g
s
.49 .656 .933 r
.61675 .50896 m .602 .50906 L .6054 .51879 L p F P
0 g
s
.515 .672 .935 r
.58786 .50978 m .602 .50906 L .6054 .51879 L p F P
0 g
s
.184 .2 .643 r
.80684 .73597 m .80629 .73377 L .80724 .73524 L closepath p F P
0 g
s
.276 .364 .773 r
.79309 .66962 m .78353 .66298 L .78076 .65594 L p F P
0 g
s
.104 .102 .57 r
.80724 .73524 m .80684 .73597 L .80992 .75188 L p F P
0 g
s
.852 .739 .738 r
.25901 .78893 m .27099 .79529 L .25888 .81231 L p F P
0 g
s
.834 .721 .739 r
.2707 .77205 m .25901 .78893 L .27099 .79529 L p F P
0 g
s
.834 .721 .739 r
.27191 .77266 m .2707 .77205 L p .27099 .79529 L F P
0 g
s
.797 .759 .818 r
.2206 .87371 m .20254 .88896 L .1938 .88056 L p F P
0 g
s
.392 .537 .881 r
.7101 .5775 m .71803 .57934 L .71107 .56717 L p F P
0 g
s
.392 .537 .881 r
.71107 .56717 m .71048 .56703 L .7101 .5775 L p F P
0 g
s
.432 .368 .686 r
.50984 .71581 m .51732 .70847 L p .51566 .73231 L F P
0 g
s
.432 .368 .686 r
.51566 .73231 m .51353 .73109 L .50984 .71581 L p F P
0 g
s
.824 .745 .777 r
.24096 .85428 m .23044 .8657 L .22187 .85615 L p F P
0 g
s
.824 .745 .777 r
.22187 .85615 m .22895 .8481 L .24096 .85428 L p F P
0 g
s
.823 .747 .78 r
.24096 .85428 m .22895 .8481 L .2454 .82976 L p F P
0 g
s
.979 .684 .367 r
.47949 .52889 m .48625 .53762 L .48668 .5503 L p F P
0 g
s
.982 .743 .497 r
.48625 .53762 m .47949 .52889 L .48074 .51841 L p F P
0 g
s
0 0 .079 r
.7944 .82005 m .79755 .8118 L .79543 .81456 L closepath p F P
0 g
s
0 0 .516 r
.50163 .60589 m .50069 .61667 L .50584 .62818 L p F P
0 g
s
0 0 .428 r
.50069 .61667 m .50163 .60589 L .49785 .59403 L p F P
0 g
s
.104 .102 .57 r
.80992 .75188 m .81226 .74765 L .80724 .73524 L p F P
0 g
s
.069 .082 .564 r
.81259 .72433 m .80724 .73524 L .81226 .74765 L p F P
0 g
s
.182 .2 .643 r
.80539 .71261 m .81259 .72433 L .80724 .73524 L p F P
0 g
s
.797 .759 .818 r
.1938 .88056 m .20843 .86763 L .2206 .87371 L p F P
0 g
s
.783 .752 .825 r
.22187 .85615 m .20843 .86763 L .2206 .87371 L p F P
0 g
s
.783 .752 .825 r
.2206 .87371 m .23044 .8657 L .22187 .85615 L p F P
0 g
s
.276 .364 .773 r
.78076 .65594 m .78272 .64931 L p .79309 .66962 L F P
0 g
s
.312 .412 .804 r
.78076 .65594 m .77641 .64586 L .78272 .64931 L closepath p F P
0 g
s
.606 .739 .939 r
.53087 .49758 m .54463 .49442 L .53717 .48565 L p F P
0 g
s
.606 .739 .939 r
.53717 .48565 m .524 .48878 L .53087 .49758 L p F P
0 g
s
.608 .742 .94 r
.50886 .4925 m .524 .48878 L .53087 .49758 L p F P
0 g
s
.586 .657 .886 r
.60258 .89332 m .60241 .89306 L .60316 .89296 L closepath p F P
0 g
s
.478 .641 .928 r
.64705 .52911 m .63106 .52871 L .62393 .51871 L p F P
0 g
s
.59 .627 .857 r
.60316 .89296 m .60241 .89306 L .59507 .88029 L p F P
0 g
s
0 0 0 r
.79077 .82766 m .77873 .84498 L .77123 .85351 L p F P
0 g
s
.557 .844 .513 r
.76704 .85773 m .77873 .84498 L .77123 .85351 L closepath p F P
0 g
s
.585 .655 .885 r
.6312 .88925 m .60316 .89296 L .62496 .87955 L closepath p F P
0 g
s
.59 .627 .857 r
.62395 .87798 m .62496 .87955 L .60316 .89296 L p F P
0 g
s
.59 .627 .857 r
.59507 .88029 m .62395 .87798 L p .60316 .89296 L F P
0 g
s
.45 .605 .912 r
.68231 .55221 m .67438 .55144 L .66737 .54069 L p F P
0 g
s
.565 .549 .795 r
.55288 .85304 m .55804 .85004 L p .58354 .86623 L F P
0 g
s
.547 .541 .799 r
.55288 .85304 m .55157 .85002 L .55804 .85004 L closepath p F P
0 g
s
.232 .255 .68 r
.51526 .66211 m .50778 .67456 L .51723 .68505 L p F P
0 g
s
.198 .194 .628 r
.50778 .67456 m .51526 .66211 L .50798 .65106 L p F P
0 g
s
.547 .755 .974 r
.09516 .89912 m .12126 .89502 L .13042 .90198 L p F P
0 g
s
.549 .756 .973 r
.12126 .89502 m .09516 .89912 L .08585 .89225 L p F P
0 g
s
.418 .373 .701 r
.51419 .7336 m .51353 .73109 L .51566 .73231 L closepath p F P
0 g
s
.55 .521 .776 r
.55804 .85004 m .55157 .85002 L .54408 .83085 L p F P
0 g
s
.419 .374 .702 r
.51566 .73231 m .51419 .7336 L .51908 .75195 L p F P
0 g
s
.511 .678 .941 r
.602 .50906 m .58786 .50978 L .58057 .50048 L p F P
0 g
s
.899 .762 .701 r
.26766 .72605 m .27697 .73346 L .26883 .7492 L p F P
0 g
s
.898 .759 .7 r
.27697 .73346 m .26766 .72605 L .27566 .71039 L p F P
0 g
s
.852 .739 .737 r
.25888 .81231 m .25041 .82429 L .24193 .81401 L p F P
0 g
s
.852 .739 .737 r
.24193 .81401 m .24752 .8058 L .25888 .81231 L p F P
0 g
s
.852 .739 .738 r
.25888 .81231 m .24752 .8058 L .25901 .78893 L p F P
0 g
s
.838 .72 .734 r
.27191 .77266 m .27111 .77146 L .2707 .77205 L closepath p F P
0 g
s
.306 .413 .807 r
.78272 .64931 m .77641 .64586 L .76946 .63001 L p F P
0 g
s
.766 .786 .869 r
.17949 .88954 m .1663 .89812 L .15734 .89068 L p F P
0 g
s
.689 .783 .922 r
.13042 .90198 m .15734 .89068 L .1663 .89812 L p F P
0 g
s
0 0 0 r
.79755 .8118 m .80548 .80062 L p .79325 .82473 L F P
0 g
s
0 0 0 r
.79325 .82473 m .7944 .82005 L .79755 .8118 L p F P
0 g
s
0 0 .236 r
.79755 .8118 m .80548 .80062 L .80841 .78579 L p F P
0 g
s
.853 .744 .743 r
.2707 .77205 m .27111 .77146 L .26272 .76089 L p F P
0 g
s
.375 .497 .854 r
.73344 .59381 m .7544 .60077 L .75303 .61133 L p F P
0 g
s
.357 .504 .868 r
.73412 .58335 m .73344 .59381 L .7544 .60077 L p F P
0 g
s
.4 .536 .877 r
.71803 .57934 m .73412 .58335 L .73344 .59381 L p F P
0 g
s
.118 .162 .633 r
.80997 .70177 m .80539 .71261 L .81259 .72433 L p F P
0 g
s
.214 .257 .691 r
.80065 .69073 m .80997 .70177 L .80539 .71261 L p F P
0 g
s
.861 .752 .74 r
.25973 .76529 m .2707 .77205 L .25901 .78893 L p F P
0 g
s
.853 .744 .743 r
.26272 .76089 m .25973 .76529 L .2707 .77205 L p F P
0 g
s
.419 .374 .702 r
.51908 .75195 m .53149 .74126 L .51566 .73231 L p F P
0 g
s
.396 .381 .725 r
.52976 .7183 m .51566 .73231 L .53149 .74126 L p F P
0 g
s
.432 .368 .686 r
.51732 .70847 m .52976 .7183 L .51566 .73231 L p F P
0 g
s
0 0 .383 r
.81183 .76645 m .80831 .77187 L .80841 .78579 L p F P
0 g
s
.076 .034 .501 r
.80831 .77187 m .81183 .76645 L .80992 .75188 L p F P
0 g
s
.465 .405 .705 r
.51908 .75195 m .53149 .74126 L p .5327 .76429 L F P
0 g
s
.465 .405 .705 r
.5327 .76429 m .52116 .75974 L .51908 .75195 L p F P
0 g
s
.011 0 .48 r
.81226 .74765 m .80992 .75188 L .81183 .76645 L p F P
0 g
s
.694 .788 .923 r
.15734 .89068 m .13042 .90198 L .12126 .89502 L p F P
0 g
s
.55 .521 .776 r
.54408 .83085 m .54433 .8307 L p .55804 .85004 L F P
0 g
s
.529 .511 .78 r
.54408 .83085 m .54401 .83068 L .54433 .8307 L closepath p F P
0 g
s
.533 .494 .758 r
.54433 .8307 m .54401 .83068 L .53666 .80998 L p F P
0 g
s
.627 .935 .963 r
.72187 .88825 m .70981 .89427 L .7032 .89058 L p F P
0 g
s
.613 .881 .99 r
.67424 .90008 m .7032 .89058 L .70981 .89427 L p F P
0 g
s
.55 .521 .776 r
.54433 .8307 m .57265 .83281 L p .55804 .85004 L F P
0 g
s
.527 .513 .784 r
.57265 .83281 m .54433 .8307 L .56624 .81677 L closepath p F P
0 g
s
.533 .494 .758 r
.56506 .81384 m .56624 .81677 L .54433 .8307 L p F P
0 g
s
.533 .494 .758 r
.53745 .80946 m .56506 .81384 L p .54433 .8307 L F P
0 g
s
.533 .494 .758 r
.53666 .80998 m .53745 .80946 L p .54433 .8307 L F P
0 g
s
.454 .413 .722 r
.5244 .77075 m .52116 .75974 L .5327 .76429 L closepath p F P
0 g
s
.387 .535 .882 r
.73412 .58335 m .71803 .57934 L .71107 .56717 L p F P
0 g
s
.596 .769 .962 r
.63836 .89912 m .66731 .89311 L .67424 .90008 L p F P
0 g
s
.58 .723 .941 r
.66731 .89311 m .63836 .89912 L .6312 .88925 L p F P
0 g
s
.491 .436 .723 r
.5244 .77075 m .5327 .76429 L p .53425 .78714 L F P
0 g
s
.491 .436 .723 r
.53425 .78714 m .5288 .78572 L .5244 .77075 L p F P
0 g
s
.565 .549 .795 r
.55804 .85004 m .58018 .8502 L p .58354 .86623 L F P
0 g
s
.546 .54 .8 r
.58018 .8502 m .55804 .85004 L .57566 .83972 L closepath p F P
0 g
s
.55 .521 .776 r
.57265 .83281 m .57566 .83972 L .55804 .85004 L p F P
0 g
s
.819 .746 .783 r
.2454 .82976 m .25041 .82429 L .24193 .81401 L p F P
0 g
s
.766 .786 .869 r
.15734 .89068 m .16859 .88309 L .17949 .88954 L p F P
0 g
s
.753 .778 .873 r
.18497 .87244 m .16859 .88309 L .17949 .88954 L p F P
0 g
s
.753 .778 .873 r
.17949 .88954 m .1938 .88056 L .18497 .87244 L p F P
0 g
s
.427 .579 .902 r
.70411 .55582 m .68231 .55221 L p .71048 .56703 L F P
0 g
s
.409 .574 .904 r
.68231 .55221 m .70411 .55582 L .69713 .5448 L p F P
0 g
s
.409 .574 .904 r
.69713 .5448 m .68101 .54206 L .68231 .55221 L p F P
0 g
s
.45 .605 .912 r
.66737 .54069 m .68101 .54206 L .68231 .55221 L p F P
0 g
s
.508 .48 .761 r
.53666 .80998 m .53642 .8093 L .53745 .80946 L closepath p F P
0 g
s
.921 .612 .137 r
.48831 .56251 m .48668 .5503 L p .49301 .57195 L F P
0 g
s
.921 .612 .137 r
.49301 .57195 m .48837 .56276 L .48831 .56251 L p F P
0 g
s
.514 .465 .74 r
.53745 .80946 m .53642 .8093 L .5302 .79003 L p F P
0 g
s
.835 .761 .781 r
.23362 .82341 m .2454 .82976 L .22895 .8481 L p F P
0 g
s
.819 .746 .783 r
.24193 .81401 m .23362 .82341 L .2454 .82976 L p F P
0 g
s
.514 .465 .74 r
.5302 .79003 m .53425 .78714 L p .53745 .80946 L F P
0 g
s
.483 .447 .742 r
.5302 .79003 m .5288 .78572 L .53425 .78714 L closepath p F P
0 g
s
.16 .232 .69 r
.80447 .67997 m .80065 .69073 L .80997 .70177 L p F P
0 g
s
.246 .312 .734 r
.79309 .66962 m .80447 .67997 L .80065 .69073 L p F P
0 g
s
.082 .151 .637 r
.51143 .63986 m .50798 .65106 L .51526 .66211 L p F P
0 g
s
.059 .128 .622 r
.51129 .63933 m .50584 .62818 L p .50798 .65106 L F P
0 g
s
.059 .128 .622 r
.50798 .65106 m .51143 .63986 L .51129 .63933 L p F P
0 g
s
.316 .45 .837 r
.75303 .61133 m .76237 .61535 L .75538 .60121 L p F P
0 g
s
.316 .45 .837 r
.75538 .60121 m .7544 .60077 L .75303 .61133 L p F P
0 g
s
.538 .699 .944 r
.54463 .49442 m .57324 .49141 L .58057 .50048 L p F P
0 g
s
.535 .706 .949 r
.57324 .49141 m .54463 .49442 L .53717 .48565 L p F P
0 g
s
0 0 .027 r
.79077 .82766 m .79325 .82473 L .7944 .82005 L closepath p F P
0 g
s
.504 .485 .769 r
.56506 .81384 m .53745 .80946 L .5581 .79505 L closepath p F P
0 g
s
.514 .465 .74 r
.55743 .79325 m .5581 .79505 L .53745 .80946 L p F P
0 g
s
.514 .465 .74 r
.53425 .78714 m .55743 .79325 L p .53745 .80946 L F P
0 g
s
.608 .829 .985 r
.7032 .89058 m .67424 .90008 L .66731 .89311 L p F P
0 g
s
.543 .609 .869 r
.62395 .87798 m .59507 .88029 L .58766 .86604 L p F P
0 g
s
.627 .935 .963 r
.73359 .87831 m .72187 .88825 L p .7032 .89058 L F P
0 g
s
.668 .962 .935 r
.72187 .88825 m .73359 .87831 L .73856 .87921 L closepath p F P
0 g
s
.867 .758 .741 r
.24842 .78209 m .25901 .78893 L .24752 .8058 L p F P
0 g
s
.861 .752 .74 r
.25901 .78893 m .24842 .78209 L .25973 .76529 L p F P
0 g
s
.898 .762 .703 r
.26883 .7492 m .26272 .76089 L .25414 .75229 L p F P
0 g
s
.898 .762 .703 r
.25414 .75229 m .25958 .74181 L .26883 .7492 L p F P
0 g
s
.899 .762 .701 r
.26883 .7492 m .25958 .74181 L .26766 .72605 L p F P
0 g
s
.306 .413 .807 r
.76946 .63001 m .76951 .62982 L p .78272 .64931 L F P
0 g
s
.341 .456 .832 r
.76946 .63001 m .76934 .62975 L .76951 .62982 L closepath p F P
0 g
s
.334 .458 .837 r
.76951 .62982 m .76934 .62975 L .76237 .61535 L p F P
0 g
s
.197 .294 .738 r
.79618 .65893 m .79309 .66962 L .80447 .67997 L p F P
0 g
s
.276 .364 .773 r
.78272 .64931 m .79618 .65893 L .79309 .66962 L p F P
0 g
s
.306 .413 .807 r
.76951 .62982 m .78511 .63869 L .78272 .64931 L p F P
0 g
s
.265 .399 .811 r
.77123 .61928 m .76951 .62982 L .78511 .63869 L p F P
0 g
s
.334 .458 .837 r
.76237 .61535 m .77123 .61928 L .76951 .62982 L p F P
0 g
s
.835 .761 .781 r
.22895 .8481 m .21795 .84157 L .23362 .82341 L p F P
0 g
s
.837 .76 .778 r
.22895 .8481 m .22187 .85615 L .2132 .84715 L p F P
0 g
s
.837 .76 .778 r
.2132 .84715 m .21795 .84157 L .22895 .8481 L p F P
0 g
s
.962 .63 .268 r
.48668 .5503 m .48831 .56251 L .48062 .54687 L p F P
0 g
s
.962 .63 .268 r
.48062 .54687 m .47992 .54159 L .48668 .5503 L p F P
0 g
s
.979 .684 .367 r
.48668 .5503 m .47992 .54159 L .47949 .52889 L p F P
0 g
s
.808 .772 .82 r
.20843 .86763 m .1938 .88056 L .18497 .87244 L p F P
0 g
s
.232 .349 .778 r
.78511 .63869 m .78272 .64931 L .79618 .65893 L p F P
0 g
s
.808 .772 .82 r
.18497 .87244 m .1973 .86118 L .20843 .86763 L p F P
0 g
s
.795 .765 .826 r
.2132 .84715 m .1973 .86118 L .20843 .86763 L p F P
0 g
s
.795 .765 .826 r
.20843 .86763 m .22187 .85615 L .2132 .84715 L p F P
0 g
s
0 0 0 r
.79325 .82473 m .79077 .82766 L .77873 .84498 L p F P
0 g
s
.332 .331 .708 r
.52685 .69584 m .51732 .70847 L .52976 .7183 L p F P
0 g
s
.391 .329 .667 r
.52668 .69523 m .52685 .69584 L .51732 .70847 L p F P
0 g
s
.391 .329 .667 r
.51723 .68505 m .52668 .69523 L p .51732 .70847 L F P
0 g
s
.478 .641 .928 r
.62393 .51871 m .64431 .51923 L .64705 .52911 L p F P
0 g
s
.472 .646 .934 r
.64431 .51923 m .62393 .51871 L .61675 .50896 L p F P
0 g
s
.441 .608 .918 r
.68101 .54206 m .66737 .54069 L .66032 .53019 L p F P
0 g
s
.011 0 .48 r
.81183 .76645 m .81495 .76081 L .81226 .74765 L p F P
0 g
s
0 0 .467 r
.81759 .73679 m .81226 .74765 L .81495 .76081 L p F P
0 g
s
.069 .082 .564 r
.81226 .74765 m .81759 .73679 L .81259 .72433 L p F P
0 g
s
.444 .618 .924 r
.64705 .52911 m .66032 .53019 L .65323 .51996 L p F P
0 g
s
.444 .618 .924 r
.65323 .51996 m .64431 .51923 L .64705 .52911 L p F P
0 g
s
.486 .662 .94 r
.602 .50906 m .61675 .50896 L .60952 .49948 L p F P
0 g
s
.486 .662 .94 r
.60952 .49948 m .5975 .49959 L .602 .50906 L p F P
0 g
s
.511 .678 .941 r
.58057 .50048 m .5975 .49959 L .602 .50906 L p F P
0 g
s
.476 .455 .754 r
.55743 .79325 m .53425 .78714 L .55087 .77422 L closepath p F P
0 g
s
.491 .436 .723 r
.54977 .77104 m .55087 .77422 L .53425 .78714 L p F P
0 g
s
.491 .436 .723 r
.5327 .76429 m .54977 .77104 L p .53425 .78714 L F P
0 g
s
0 0 .539 r
.51129 .63933 m .50584 .62818 L .50625 .62119 L closepath p F P
0 g
s
0 0 .516 r
.50362 .61128 m .50163 .60589 L p .50584 .62818 L F P
0 g
s
0 0 .516 r
.50584 .62818 m .50625 .62119 L .50362 .61128 L p F P
0 g
s
.562 .567 .816 r
.58766 .86604 m .58354 .86623 L .5869 .86441 L closepath p F P
0 g
s
.565 .549 .795 r
.58018 .8502 m .5869 .86441 L .58354 .86623 L p F P
0 g
s
.767 .982 .908 r
.73359 .87831 m .73856 .87921 L .75932 .86427 L p F P
0 g
s
0 0 .354 r
.81495 .76081 m .81183 .76645 L .81247 .77961 L p F P
0 g
s
0 0 .383 r
.80841 .78579 m .81247 .77961 L .81183 .76645 L p F P
0 g
s
.873 .773 .749 r
.25973 .76529 m .26272 .76089 L .25414 .75229 L p F P
0 g
s
.507 .684 .946 r
.5975 .49959 m .58057 .50048 L .57324 .49141 L p F P
0 g
s
.867 .758 .74 r
.24752 .8058 m .24193 .81401 L .23333 .8048 L p F P
0 g
s
.867 .758 .74 r
.23333 .8048 m .23725 .79889 L .24752 .8058 L p F P
0 g
s
.867 .758 .741 r
.24752 .8058 m .23725 .79889 L .24842 .78209 L p F P
0 g
s
.549 .756 .973 r
.08585 .89225 m .11202 .88801 L .12126 .89502 L p F P
0 g
s
0 0 .214 r
.81247 .77961 m .80841 .78579 L .80548 .80062 L p F P
0 g
s
.383 .541 .889 r
.71107 .56717 m .71048 .56703 L .71044 .5661 L closepath p F P
0 g
s
.427 .579 .902 r
.71048 .56703 m .71044 .5661 L .70411 .55582 L p F P
0 g
s
.387 .535 .882 r
.71107 .56717 m .73393 .57305 L .73412 .58335 L p F P
0 g
s
.372 .535 .888 r
.73393 .57305 m .71107 .56717 L .71044 .5661 L p F P
0 g
s
0 0 0 r
.78939 .83238 m .79325 .82473 L p .77873 .84498 L F P
0 g
s
0 0 0 r
.77873 .84498 m .78857 .83344 L .78939 .83238 L p F P
0 g
s
.74 .966 .69 r
.77873 .84498 m .78857 .83344 L p .76452 .85911 L F P
0 g
s
.74 .966 .69 r
.76452 .85911 m .76704 .85773 L .77873 .84498 L p F P
0 g
s
.543 .609 .869 r
.58766 .86604 m .61661 .86533 L .62395 .87798 L p F P
0 g
s
.528 .548 .82 r
.6092 .85142 m .61661 .86533 L .58766 .86604 L p F P
0 g
s
.528 .548 .82 r
.60541 .85124 m .6092 .85142 L p .58766 .86604 L F P
0 g
s
.528 .548 .82 r
.58766 .86604 m .5869 .86441 L .60541 .85124 L p F P
0 g
s
.877 .776 .746 r
.2503 .75798 m .25973 .76529 L .24842 .78209 L p F P
0 g
s
.873 .773 .749 r
.25414 .75229 m .2503 .75798 L .25973 .76529 L p F P
0 g
s
0 0 0 r
.78939 .83238 m .79911 .81644 L .79325 .82473 L closepath p F P
0 g
s
0 0 0 r
.80548 .80062 m .79911 .81644 L .79325 .82473 L p F P
0 g
s
.372 .535 .888 r
.71044 .5661 m .70967 .55682 L p .73393 .57305 L F P
0 g
s
.408 .569 .901 r
.71044 .5661 m .70411 .55582 L .70967 .55682 L closepath p F P
0 g
s
0 0 .338 r
.50362 .61128 m .50163 .60589 L .50088 .60234 L closepath p F P
0 g
s
0 0 .292 r
.49596 .58511 m .49568 .58408 L p .49602 .58535 L F P
0 g
s
0 0 .31 r
.49596 .58511 m .49525 .58322 L p .49588 .58477 L F P
0 g
s
0 0 .31 r
.50031 .5957 m .49596 .58511 L p .49588 .58477 L F P
0 g
s
0 0 .292 r
.50163 .60589 m .49596 .58511 L .49602 .58535 L F
.50163 .60589 m .50088 .60234 L .49596 .58511 L p F P
0 g
s
.772 .794 .871 r
.16859 .88309 m .15734 .89068 L .14828 .88335 L p F P
0 g
s
.694 .788 .923 r
.12126 .89502 m .14828 .88335 L .15734 .89068 L p F P
0 g
s
.53 .551 .822 r
.5869 .86441 m .58018 .8502 L .60541 .85124 L closepath p F P
0 g
s
.767 .982 .908 r
.75932 .86427 m .76452 .85911 L p .73359 .87831 L F P
0 g
s
.599 .92 .682 r
.75932 .86427 m .76452 .85911 L .76704 .85773 L closepath p F P
0 g
s
.58 .723 .941 r
.6312 .88925 m .66027 .88474 L .66731 .89311 L p F P
0 g
s
.571 .648 .888 r
.65313 .87509 m .66027 .88474 L .6312 .88925 L p F P
0 g
s
.571 .648 .888 r
.62757 .87761 m .65313 .87509 L p .6312 .88925 L F P
0 g
s
.571 .648 .888 r
.6312 .88925 m .62496 .87955 L .62757 .87761 L p F P
0 g
s
.237 .261 .684 r
.52668 .69523 m .51723 .68505 L .52161 .67706 L closepath p F P
0 g
s
.232 .255 .68 r
.51898 .66746 m .51526 .66211 L p .51723 .68505 L F P
0 g
s
.232 .255 .68 r
.51723 .68505 m .52161 .67706 L .51898 .66746 L p F P
0 g
s
.834 .765 .786 r
.23362 .82341 m .24193 .81401 L .23333 .8048 L p F P
0 g
s
.315 .452 .84 r
.77123 .61928 m .76237 .61535 L .75538 .60121 L p F P
0 g
s
.442 .421 .74 r
.54977 .77104 m .5327 .76429 L .54428 .75402 L closepath p F P
0 g
s
.465 .405 .705 r
.54209 .74722 m .54428 .75402 L .5327 .76429 L p F P
0 g
s
.465 .405 .705 r
.53149 .74126 m .54209 .74722 L p .5327 .76429 L F P
0 g
s
.033 .063 .559 r
.81716 .71354 m .81259 .72433 L .81759 .73679 L p F P
0 g
s
.118 .162 .633 r
.81259 .72433 m .81716 .71354 L .80997 .70177 L p F P
0 g
s
.695 .793 .926 r
.14828 .88335 m .12126 .89502 L .11202 .88801 L p F P
0 g
s
.846 .775 .783 r
.22308 .81662 m .23362 .82341 L .21795 .84157 L p F P
0 g
s
.834 .765 .786 r
.23333 .8048 m .22308 .81662 L .23362 .82341 L p F P
0 g
s
.772 .794 .871 r
.14828 .88335 m .15845 .87635 L .16859 .88309 L p F P
0 g
s
.761 .788 .875 r
.17604 .86467 m .15845 .87635 L .16859 .88309 L p F P
0 g
s
.761 .788 .875 r
.16859 .88309 m .18497 .87244 L .17604 .86467 L p F P
0 g
s
.866 .535 .021 r
.49568 .58408 m .49525 .58322 L .48837 .56276 L p F P
0 g
s
0 0 .437 r
.50088 .60234 m .49596 .58511 L .50031 .5957 L closepath p F P
0 g
s
.357 .504 .868 r
.74844 .58824 m .73412 .58335 L p .7544 .60077 L F P
0 g
s
.331 .492 .868 r
.73412 .58335 m .74844 .58824 L .74149 .5757 L p F P
0 g
s
.331 .492 .868 r
.74149 .5757 m .73393 .57305 L .73412 .58335 L p F P
0 g
s
.535 .706 .949 r
.53717 .48565 m .56585 .48256 L .57324 .49141 L p F P
0 g
s
.69 .38 0 r
.48835 .56268 m .48837 .56276 L .49525 .58322 L p F P
0 g
s
.69 .38 0 r
.49219 .57445 m .48835 .56268 L p .48927 .56544 L F P
0 g
s
.69 .38 0 r
.49525 .58322 m .49219 .57445 L p .48927 .56544 L F P
0 g
s
.866 .467 0 r
.49219 .57445 m .49648 .58619 L p .49516 .58365 L F P
0 g
s
.866 .467 0 r
.48582 .56564 m .49219 .57445 L p .49516 .58365 L F P
0 g
s
0 0 .31 r
.49525 .58322 m .49219 .57445 L p .50031 .5957 L F P
0 g
s
.627 .935 .963 r
.7032 .89058 m .73222 .8779 L .73359 .87831 L p F P
0 g
s
.627 .899 .986 r
.73222 .8779 m .7032 .89058 L .69645 .88528 L p F P
0 g
s
.608 .829 .985 r
.66731 .89311 m .69645 .88528 L .7032 .89058 L p F P
0 g
s
.879 .777 .745 r
.23907 .7748 m .24842 .78209 L .23725 .79889 L p F P
0 g
s
.877 .776 .746 r
.24842 .78209 m .23907 .7748 L .2503 .75798 L p F P
0 g
s
.592 .779 .969 r
.69645 .88528 m .66731 .89311 L .66027 .88474 L p F P
0 g
s
.78 .49 0 r
.48837 .56276 m .48831 .56251 L .48835 .56268 L closepath p F P
0 g
s
.926 .57 .138 r
.48835 .56268 m .48831 .56251 L .48062 .54687 L p F P
0 g
s
.885 .499 .039 r
.48216 .55379 m .48835 .56268 L .49219 .57445 L p F P
0 g
s
.926 .57 .138 r
.48062 .54687 m .48216 .55379 L .48835 .56268 L p F P
0 g
s
.846 .775 .783 r
.21795 .84157 m .20782 .83471 L .22308 .81662 L p F P
0 g
s
.847 .774 .781 r
.21795 .84157 m .2132 .84715 L .20441 .83879 L p F P
0 g
s
.847 .774 .781 r
.20441 .83879 m .20782 .83471 L .21795 .84157 L p F P
0 g
s
0 0 .524 r
.50088 .60234 m .50031 .5957 L p .50671 .61744 L F P
0 g
s
0 0 .524 r
.50671 .61744 m .50362 .61128 L .50088 .60234 L p F P
0 g
s
.091 .162 .645 r
.51898 .66746 m .51526 .66211 L .51646 .65838 L closepath p F P
0 g
s
.082 .151 .637 r
.51526 .66211 m .51646 .65838 L .51143 .63986 L p F P
0 g
s
.535 .534 .801 r
.60541 .85124 m .58018 .8502 L .57566 .83972 L p F P
0 g
s
0 .008 .557 r
.50625 .62119 m .50362 .61128 L .50671 .61744 L closepath p F P
0 g
s
.093 .156 .637 r
.81377 .69104 m .80997 .70177 L .81716 .71354 L p F P
0 g
s
.16 .232 .69 r
.80997 .70177 m .81377 .69104 L .80447 .67997 L p F P
0 g
s
.816 .784 .823 r
.1973 .86118 m .18497 .87244 L .17604 .86467 L p F P
0 g
s
.816 .784 .823 r
.17604 .86467 m .18706 .8544 L .1973 .86118 L p F P
0 g
s
.806 .779 .829 r
.20441 .83879 m .18706 .8544 L .1973 .86118 L p F P
0 g
s
.806 .779 .829 r
.1973 .86118 m .2132 .84715 L .20441 .83879 L p F P
0 g
s
.397 .577 .912 r
.68101 .54206 m .69713 .5448 L .69012 .53406 L p F P
0 g
s
.397 .577 .912 r
.69012 .53406 m .67878 .5321 L .68101 .54206 L p F P
0 g
s
.441 .608 .918 r
.66032 .53019 m .67878 .5321 L .68101 .54206 L p F P
0 g
s
.431 .611 .925 r
.67878 .5321 m .66032 .53019 L .65323 .51996 L p F P
0 g
s
.396 .382 .726 r
.54209 .74722 m .53149 .74126 L .53815 .73429 L closepath p F P
0 g
s
.396 .381 .725 r
.53439 .72188 m .52976 .7183 L p .53149 .74126 L F P
0 g
s
.396 .381 .725 r
.53149 .74126 m .53815 .73429 L .53439 .72188 L p F P
0 g
s
.472 .646 .934 r
.61675 .50896 m .64057 .50957 L .64431 .51923 L p F P
0 g
s
.464 .651 .94 r
.64057 .50957 m .61675 .50896 L .60952 .49948 L p F P
0 g
s
0 0 .354 r
.81247 .77961 m .81516 .77476 L .81495 .76081 L p F P
0 g
s
0 0 .33 r
.82029 .75 m .81495 .76081 L .81516 .77476 L p F P
0 g
s
0 0 .467 r
.81495 .76081 m .82029 .75 L .81759 .73679 L p F P
0 g
s
.01 .106 .618 r
.50625 .62119 m .50671 .61744 L p .51149 .63965 L F P
0 g
s
.01 .106 .618 r
.51149 .63965 m .51129 .63933 L .50625 .62119 L p F P
0 g
s
0 0 0 r
.81171 .79124 m .80548 .80062 L .79911 .81644 L p F P
0 g
s
0 0 .214 r
.80548 .80062 m .81171 .79124 L .81247 .77961 L p F P
0 g
s
.302 .452 .844 r
.75538 .60121 m .7544 .60077 L .75448 .59943 L closepath p F P
0 g
s
.357 .504 .868 r
.7544 .60077 m .75448 .59943 L .74844 .58824 L p F P
0 g
s
.508 .521 .805 r
.57566 .83972 m .57265 .83281 L .58312 .83399 L closepath p F P
0 g
s
.535 .534 .801 r
.57566 .83972 m .58312 .83399 L p .60541 .85124 L F P
0 g
s
.572 .651 .889 r
.62496 .87955 m .62395 .87798 L .62757 .87761 L closepath p F P
0 g
s
.138 .228 .695 r
.80751 .66932 m .80447 .67997 L .81377 .69104 L p F P
0 g
s
.197 .294 .738 r
.80447 .67997 m .80751 .66932 L .79618 .65893 L p F P
0 g
s
.315 .452 .84 r
.75538 .60121 m .77212 .60888 L .77123 .61928 L p F P
0 g
s
.294 .447 .843 r
.77212 .60888 m .75538 .60121 L .75448 .59943 L p F P
0 g
s
0 0 .178 r
.81516 .77476 m .81247 .77961 L .81171 .79124 L p F P
0 g
s
.054 .125 .62 r
.51143 .63986 m .51129 .63933 L .51149 .63965 L closepath p F P
0 g
s
.062 .138 .631 r
.51149 .63965 m .51143 .63986 L .51646 .65838 L p F P
0 g
s
.402 .573 .907 r
.70967 .55682 m .70411 .55582 L .69713 .5448 L p F P
0 g
s
.062 .138 .631 r
.51646 .65838 m .51873 .65075 L .51149 .63965 L p F P
0 g
s
0 0 .558 r
.51272 .62883 m .51149 .63965 L .51873 .65075 L p F P
0 g
s
.01 .106 .618 r
.50671 .61744 m .51272 .62883 L .51149 .63965 L p F P
0 g
s
.718 .985 .801 r
.76109 .8599 m .76969 .85268 L .76452 .85911 L closepath p F P
0 g
s
.74 .966 .69 r
.78857 .83344 m .76969 .85268 L .76452 .85911 L p F P
0 g
s
.767 .982 .908 r
.76452 .85911 m .76109 .8599 L p .73359 .87831 L F P
0 g
s
.294 .447 .843 r
.75448 .59943 m .75469 .59043 L p .77212 .60888 L F P
0 g
s
.337 .492 .865 r
.75448 .59943 m .74844 .58824 L .75469 .59043 L closepath p F P
0 g
s
.576 .626 .864 r
.62757 .87761 m .62395 .87798 L .61661 .86533 L p F P
0 g
s
.481 .669 .946 r
.5975 .49959 m .60952 .49948 L .60225 .49026 L p F P
0 g
s
.481 .669 .946 r
.60225 .49026 m .59186 .49039 L .5975 .49959 L p F P
0 g
s
.507 .684 .946 r
.57324 .49141 m .59186 .49039 L .5975 .49959 L p F P
0 g
s
.265 .399 .811 r
.78511 .63869 m .78667 .62821 L .77123 .61928 L p F P
0 g
s
.257 .408 .823 r
.77212 .60888 m .77123 .61928 L .78667 .62821 L p F P
0 g
s
.879 .777 .745 r
.23725 .79889 m .23333 .8048 L .22457 .79676 L p F P
0 g
s
.879 .777 .745 r
.22457 .79676 m .22796 .79162 L .23725 .79889 L p F P
0 g
s
.879 .777 .745 r
.23725 .79889 m .22796 .79162 L .23907 .7748 L p F P
0 g
s
.503 .691 .952 r
.59186 .49039 m .57324 .49141 L .56585 .48256 L p F P
0 g
s
.436 .623 .931 r
.64431 .51923 m .65323 .51996 L .64611 .51002 L p F P
0 g
s
.436 .623 .931 r
.64611 .51002 m .64057 .50957 L .64431 .51923 L p F P
0 g
s
.18 .294 .745 r
.79846 .64837 m .79618 .65893 L .80751 .66932 L p F P
0 g
s
.232 .349 .778 r
.79618 .65893 m .79846 .64837 L .78511 .63869 L p F P
0 g
s
.515 .506 .785 r
.58312 .83399 m .57265 .83281 L .56624 .81677 L p F P
0 g
s
.711 .959 .946 r
.73222 .8779 m .73585 .87583 L .73359 .87831 L closepath p F P
0 g
s
.767 .982 .908 r
.76109 .8599 m .73585 .87583 L .73359 .87831 L p F P
0 g
s
.22 .354 .787 r
.78667 .62821 m .78511 .63869 L .79846 .64837 L p F P
0 g
s
.334 .333 .709 r
.53439 .72188 m .52976 .7183 L .53236 .71491 L closepath p F P
0 g
s
.332 .331 .708 r
.52976 .7183 m .53236 .71491 L .52685 .69584 L p F P
0 g
s
.172 .217 .668 r
.51646 .65838 m .51873 .65075 L p .52346 .67301 L F P
0 g
s
.172 .217 .668 r
.52346 .67301 m .51898 .66746 L .51646 .65838 L p F P
0 g
s
.848 .786 .791 r
.22308 .81662 m .23333 .8048 L .22457 .79676 L p F P
0 g
s
.546 .612 .87 r
.62757 .87761 m .65313 .87509 L .64591 .86425 L p F P
0 g
s
.546 .612 .87 r
.64591 .86425 m .64366 .86432 L .62757 .87761 L p F P
0 g
s
.576 .626 .864 r
.61661 .86533 m .64366 .86432 L .62757 .87761 L p F P
0 g
s
.178 .219 .667 r
.52161 .67706 m .51898 .66746 L .52346 .67301 L closepath p F P
0 g
s
.775 .801 .874 r
.15845 .87635 m .14828 .88335 L .13913 .87617 L p F P
0 g
s
.695 .793 .926 r
.11202 .88801 m .13913 .87617 L .14828 .88335 L p F P
0 g
s
0 0 .423 r
.50535 .60729 m .50671 .61744 L .51272 .62883 L p F P
0 g
s
0 0 .524 r
.50031 .5957 m .50535 .60729 L .50671 .61744 L p F P
0 g
s
.271 .284 .691 r
.52161 .67706 m .52346 .67301 L p .52702 .69557 L F P
0 g
s
.271 .284 .691 r
.52702 .69557 m .52668 .69523 L .52161 .67706 L p F P
0 g
s
.515 .506 .785 r
.56624 .81677 m .56885 .81459 L p .58312 .83399 L F P
0 g
s
.484 .49 .788 r
.56624 .81677 m .56506 .81384 L .56885 .81459 L closepath p F P
0 g
s
0 0 .456 r
.8222 .72603 m .81759 .73679 L .82029 .75 L p F P
0 g
s
.033 .063 .559 r
.81759 .73679 m .8222 .72603 L .81716 .71354 L p F P
0 g
s
.854 .789 .787 r
.21366 .80943 m .22308 .81662 L .20782 .83471 L p F P
0 g
s
.848 .786 .791 r
.22457 .79676 m .21366 .80943 L .22308 .81662 L p F P
0 g
s
.372 .535 .888 r
.70967 .55682 m .7329 .5629 L .73393 .57305 L p F P
0 g
s
.358 .543 .899 r
.70795 .54679 m .70967 .55682 L .7329 .5629 L p F P
0 g
s
.402 .573 .907 r
.69713 .5448 m .70795 .54679 L .70967 .55682 L p F P
0 g
s
.689 .856 .446 r
.78908 .8328 m .78939 .83238 L .79911 .81644 L p F P
0 g
s
.689 .856 .446 r
.79911 .81644 m .80643 .80538 L p .78908 .8328 L F P
0 g
s
0 0 0 r
.81104 .79439 m .81171 .79124 L p .79911 .81644 L F P
0 g
s
0 0 0 r
.79911 .81644 m .80643 .80538 L .81104 .79439 L p F P
0 g
s
.492 .478 .77 r
.56885 .81459 m .56506 .81384 L .5581 .79505 L p F P
0 g
s
.775 .801 .874 r
.13913 .87617 m .14897 .86934 L .15845 .87635 L p F P
0 g
s
.767 .799 .879 r
.167 .85727 m .14897 .86934 L .15845 .87635 L p F P
0 g
s
.767 .799 .879 r
.15845 .87635 m .17604 .86467 L .167 .85727 L p F P
0 g
s
.706 .927 .965 r
.73585 .87583 m .73222 .8779 L .72569 .87453 L p F P
0 g
s
.627 .899 .986 r
.69645 .88528 m .72569 .87453 L .73222 .8779 L p F P
0 g
s
.706 .927 .965 r
.72569 .87453 m .74584 .86434 L .73585 .87583 L p F P
0 g
s
.695 .978 .904 r
.75488 .85934 m .74584 .86434 L .73585 .87583 L p F P
0 g
s
.695 .978 .904 r
.73585 .87583 m .76109 .8599 L .75488 .85934 L p F P
0 g
s
.263 .283 .693 r
.52685 .69584 m .52668 .69523 L .52702 .69557 L closepath p F P
0 g
s
.264 .286 .696 r
.52702 .69557 m .52685 .69584 L .53236 .71491 L p F P
0 g
s
0 0 .31 r
.49219 .57445 m .49648 .58619 L .50031 .5957 L p F P
0 g
s
.702 .35 0 r
.49648 .58619 m .50031 .5957 L .50535 .60729 L p F P
0 g
s
.264 .286 .696 r
.53236 .71491 m .53775 .70594 L .52702 .69557 L p F P
0 g
s
.123 .205 .678 r
.5323 .68384 m .52702 .69557 L .53775 .70594 L p F P
0 g
s
.271 .284 .691 r
.52346 .67301 m .5323 .68384 L .52702 .69557 L p F P
0 g
s
.592 .779 .969 r
.66027 .88474 m .68957 .87858 L .69645 .88528 L p F P
0 g
s
.572 .735 .952 r
.68957 .87858 m .66027 .88474 L .65313 .87509 L p F P
0 g
s
.492 .478 .77 r
.5581 .79505 m .55942 .79385 L p .56885 .81459 L F P
0 g
s
.455 .457 .771 r
.5581 .79505 m .55743 .79325 L .55942 .79385 L closepath p F P
0 g
s
.341 .338 .71 r
.53236 .71491 m .53775 .70594 L p .54267 .72813 L F P
0 g
s
.341 .338 .71 r
.54267 .72813 m .53439 .72188 L .53236 .71491 L p F P
0 g
s
.465 .447 .754 r
.55942 .79385 m .55743 .79325 L .55087 .77422 L p F P
0 g
s
0 0 .178 r
.81171 .79124 m .81266 .78952 L .81516 .77476 L p F P
0 g
s
0 0 .136 r
.8205 .764 m .81516 .77476 L .81266 .78952 L p F P
0 g
s
0 0 .33 r
.81516 .77476 m .8205 .764 L .82029 .75 L p F P
0 g
s
.855 .789 .785 r
.20782 .83471 m .20441 .83879 L .19551 .83112 L p F P
0 g
s
.855 .789 .785 r
.19551 .83112 m .19847 .82754 L .20782 .83471 L p F P
0 g
s
.854 .789 .787 r
.20782 .83471 m .19847 .82754 L .21366 .80943 L p F P
0 g
s
.329 .337 .717 r
.53815 .73429 m .53439 .72188 L .54267 .72813 L closepath p F P
0 g
s
.515 .506 .785 r
.56885 .81459 m .59418 .81981 L p .58312 .83399 L F P
0 g
s
.449 .454 .773 r
.56885 .81459 m .59418 .81981 L .58659 .80227 L p F P
0 g
s
.449 .454 .773 r
.58659 .80227 m .58312 .80117 L .56885 .81459 L p F P
0 g
s
.492 .478 .77 r
.55942 .79385 m .58312 .80117 L .56885 .81459 L p F P
0 g
s
.431 .611 .925 r
.65323 .51996 m .67564 .52232 L .67878 .5321 L p F P
0 g
s
.421 .615 .931 r
.67564 .52232 m .65323 .51996 L .64611 .51002 L p F P
0 g
s
.885 .499 .039 r
.49219 .57445 m .48582 .56564 L .48216 .55379 L p F P
0 g
s
.328 .494 .871 r
.75469 .59043 m .74844 .58824 L .74149 .5757 L p F P
0 g
s
.822 .797 .828 r
.18706 .8544 m .17604 .86467 L .167 .85727 L p F P
0 g
s
.822 .797 .828 r
.167 .85727 m .17763 .84732 L .18706 .8544 L p F P
0 g
s
.815 .795 .833 r
.19551 .83112 m .17763 .84732 L .18706 .8544 L p F P
0 g
s
.815 .795 .833 r
.18706 .8544 m .20441 .83879 L .19551 .83112 L p F P
0 g
s
.392 .379 .725 r
.53815 .73429 m .54267 .72813 L p .54747 .75031 L F P
0 g
s
.392 .379 .725 r
.54747 .75031 m .54209 .74722 L .53815 .73429 L p F P
0 g
s
.465 .447 .754 r
.55087 .77422 m .55274 .7723 L p .55942 .79385 L F P
0 g
s
.421 .421 .754 r
.55087 .77422 m .54977 .77104 L .55274 .7723 L closepath p F P
0 g
s
.432 .415 .74 r
.55274 .7723 m .54977 .77104 L .54428 .75402 L p F P
0 g
s
.432 .415 .74 r
.54428 .75402 m .54747 .75031 L p .55274 .7723 L F P
0 g
s
.38 .382 .736 r
.54428 .75402 m .54209 .74722 L .54747 .75031 L closepath p F P
0 g
s
.618 .85 .987 r
.72569 .87453 m .69645 .88528 L .68957 .87858 L p F P
0 g
s
.553 .594 .848 r
.64366 .86432 m .61661 .86533 L .6092 .85142 L p F P
0 g
s
.535 .534 .801 r
.58312 .83399 m .60172 .83621 L p .60541 .85124 L F P
0 g
s
.501 .53 .819 r
.60172 .83621 m .58312 .83399 L .59569 .82309 L closepath p F P
0 g
s
.515 .506 .785 r
.59418 .81981 m .59569 .82309 L .58312 .83399 L p F P
0 g
s
.436 .467 .794 r
.57215 .78068 m .55942 .79385 L .58312 .80117 L p F P
0 g
s
.465 .447 .754 r
.55274 .7723 m .57215 .78068 L .55942 .79385 L p F P
0 g
s
.464 .651 .94 r
.60952 .49948 m .63584 .50013 L .64057 .50957 L p F P
0 g
s
.457 .657 .947 r
.63584 .50013 m .60952 .49948 L .60225 .49026 L p F P
0 g
s
0 .045 .554 r
.81952 .70702 m .81716 .71354 L .8222 .72603 L p F P
0 g
s
.093 .156 .637 r
.81632 .69533 m .81377 .69104 L p .81716 .71354 L F P
0 g
s
.093 .156 .637 r
.81716 .71354 m .81952 .70702 L .81632 .69533 L p F P
0 g
s
0 0 0 r
.78857 .83344 m .78908 .8328 L .78939 .83238 L closepath p F P
0 g
s
.711 .975 .756 r
.78908 .8328 m .78857 .83344 L .76969 .85268 L p F P
0 g
s
.312 .491 .874 r
.73393 .57305 m .74149 .5757 L .73453 .56348 L p F P
0 g
s
.312 .491 .874 r
.73453 .56348 m .7329 .5629 L .73393 .57305 L p F P
0 g
s
.389 .575 .913 r
.70795 .54679 m .69713 .5448 L .69012 .53406 L p F P
0 g
s
0 .104 .631 r
.52608 .66194 m .52346 .67301 L .5323 .68384 L p F P
0 g
s
.172 .217 .668 r
.51873 .65075 m .52608 .66194 L .52346 .67301 L p F P
0 g
s
.74 .992 .866 r
.76969 .85268 m .76109 .8599 L .75488 .85934 L p F P
0 g
s
.689 .856 .446 r
.80643 .80538 m .79564 .82252 L .78908 .8328 L p F P
0 g
s
.717 .939 .626 r
.7837 .83667 m .79564 .82252 L .78908 .8328 L closepath p F P
0 g
s
.711 .975 .756 r
.7837 .83667 m .78908 .8328 L p .76969 .85268 L F P
0 g
s
.74 .992 .866 r
.75488 .85934 m .7785 .84138 L .76969 .85268 L p F P
0 g
s
.711 .975 .756 r
.76969 .85268 m .7785 .84138 L .7837 .83667 L p F P
0 g
s
.385 .581 .918 r
.67878 .5321 m .69012 .53406 L .68308 .52363 L p F P
0 g
s
.385 .581 .918 r
.68308 .52363 m .67564 .52232 L .67878 .5321 L p F P
0 g
s
.391 .431 .782 r
.56338 .75955 m .55274 .7723 L .57215 .78068 L p F P
0 g
s
.432 .415 .74 r
.54747 .75031 m .56338 .75955 L .55274 .7723 L p F P
0 g
s
.503 .691 .952 r
.56585 .48256 m .58508 .48146 L .59186 .49039 L p F P
0 g
s
.047 .127 .625 r
.81632 .69533 m .81377 .69104 L .81448 .68865 L closepath p F P
0 g
s
.138 .228 .695 r
.80856 .67062 m .80751 .66932 L p .81377 .69104 L F P
0 g
s
.138 .228 .695 r
.81377 .69104 m .81448 .68865 L .80856 .67062 L p F P
0 g
s
0 0 0 r
.81104 .79439 m .81266 .78952 L .81171 .79124 L closepath p F P
0 g
s
.525 .558 .832 r
.6092 .85142 m .60541 .85124 L .60809 .84916 L closepath p F P
0 g
s
.535 .534 .801 r
.60172 .83621 m .60809 .84916 L .60541 .85124 L p F P
0 g
s
.475 .676 .953 r
.59186 .49039 m .60225 .49026 L .59493 .48132 L p F P
0 g
s
.475 .676 .953 r
.59493 .48132 m .58508 .48146 L .59186 .49039 L p F P
0 g
s
0 0 .547 r
.51891 .64028 m .51873 .65075 L .52608 .66194 L p F P
0 g
s
0 0 .558 r
.51873 .65075 m .51891 .64028 L .51272 .62883 L p F P
0 g
s
.294 .447 .843 r
.75469 .59043 m .7722 .59861 L .77212 .60888 L p F P
0 g
s
.258 .44 .85 r
.75411 .58025 m .75469 .59043 L .7722 .59861 L p F P
0 g
s
.328 .494 .871 r
.74149 .5757 m .75411 .58025 L .75469 .59043 L p F P
0 g
s
.332 .387 .769 r
.55576 .73807 m .54747 .75031 L .56338 .75955 L p F P
0 g
s
.392 .379 .725 r
.54267 .72813 m .55576 .73807 L .54747 .75031 L p F P
0 g
s
.427 .629 .938 r
.64057 .50957 m .64611 .51002 L .63894 .50038 L p F P
0 g
s
.427 .629 .938 r
.63894 .50038 m .63584 .50013 L .64057 .50957 L p F P
0 g
s
0 0 .31 r
.82497 .73926 m .82029 .75 L .8205 .764 L p F P
0 g
s
0 0 .456 r
.82029 .75 m .82497 .73926 L .8222 .72603 L p F P
0 g
s
.094 .201 .685 r
.80856 .67062 m .80751 .66932 L .80776 .66822 L closepath p F P
0 g
s
.18 .294 .745 r
.8012 .65097 m .79846 .64837 L p .80751 .66932 L F P
0 g
s
.18 .294 .745 r
.80751 .66932 m .80776 .66822 L .8012 .65097 L p F P
0 g
s
.553 .594 .848 r
.6092 .85142 m .63859 .85224 L p .64366 .86432 L F P
0 g
s
.501 .545 .833 r
.6312 .83923 m .63859 .85224 L .6092 .85142 L p F P
0 g
s
.501 .545 .833 r
.62015 .83803 m .6312 .83923 L p .6092 .85142 L F P
0 g
s
.501 .545 .833 r
.6092 .85142 m .60809 .84916 L .62015 .83803 L p F P
0 g
s
0 0 0 r
.81266 .78952 m .81796 .77883 L p .80918 .80093 L F P
0 g
s
0 0 0 r
.80918 .80093 m .81104 .79439 L .81266 .78952 L p F P
0 g
s
0 0 .136 r
.81266 .78952 m .81796 .77883 L .8205 .764 L p F P
0 g
s
.257 .408 .823 r
.78687 .61752 m .77212 .60888 L p .78667 .62821 L F P
0 g
s
.219 .386 .817 r
.77212 .60888 m .78687 .61752 L .77986 .60322 L p F P
0 g
s
.219 .386 .817 r
.77986 .60322 m .7722 .59861 L .77212 .60888 L p F P
0 g
s
0 0 .408 r
.51065 .61892 m .51272 .62883 L .51891 .64028 L p F P
0 g
s
0 0 .408 r
.51619 .63058 m .51065 .61892 L p .5114 .62085 L F P
0 g
s
0 0 .408 r
.51891 .64028 m .51619 .63058 L p .5114 .62085 L F P
0 g
s
0 0 .395 r
.52201 .64228 m .51619 .63058 L p .51716 .63283 L F P
0 g
s
0 0 .395 r
.52533 .65177 m .52201 .64228 L p .51716 .63283 L F P
0 g
s
0 0 .459 r
.52484 .64772 m .52201 .64228 L p .52579 .65024 L F P
0 g
s
0 0 .459 r
.532 .66331 m .52484 .64772 L .52579 .65024 L F
.702 .304 0 r
.52201 .64228 m .52484 .64772 L .52444 .647 L p F P
0 g
s
0 0 .395 r
.51619 .63058 m .51891 .64028 L .52533 .65177 L p F P
0 g
s
0 0 .459 r
.52201 .64228 m .52533 .65177 L .532 .66331 L p F P
0 g
s
.702 .304 0 r
.52444 .647 m .51707 .63409 L p .52201 .64228 L F P
0 g
s
.721 .326 0 r
.51619 .63058 m .52201 .64228 L p .52103 .6404 L F P
0 g
s
.702 .304 0 r
.51707 .63409 m .51668 .63331 L .51728 .63431 L p F P
0 g
s
.702 .304 0 r
.51728 .63431 m .52201 .64228 L p .51707 .63409 L F P
0 g
s
.605 .149 0 r
.51707 .63409 m .51329 .62918 L p .51639 .63339 L F P
0 g
s
.721 .326 0 r
.52201 .64228 m .51668 .63331 L .5112 .62149 L p F P
0 g
s
0 0 .548 r
.52484 .64772 m .51707 .63409 L p .52368 .64462 L F P
0 g
s
.721 .326 0 r
.5112 .62149 m .51619 .63058 L p .52103 .6404 L F P
0 g
s
0 0 .548 r
.51707 .63409 m .52455 .64452 L .52934 .65364 L p F P
0 g
s
.605 .149 0 r
.52455 .64452 m .51707 .63409 L p .51639 .63339 L F P
0 g
s
0 0 .548 r
.52934 .65364 m .52484 .64772 L p .52368 .64462 L F P
0 g
s
.717 .335 0 r
.51065 .61892 m .51619 .63058 L p .51542 .62901 L F P
0 g
s
0 0 .423 r
.51272 .62883 m .51065 .61892 L p .50591 .60892 L F P
0 g
s
.717 .335 0 r
.50601 .6097 m .51065 .61892 L p .51542 .62901 L F P
0 g
s
0 0 .423 r
.51065 .61892 m .50535 .60729 L p .50591 .60892 L F P
0 g
s
.036 .119 .621 r
.81448 .68865 m .81643 .68054 L p .82076 .7029 L F P
0 g
s
.036 .119 .621 r
.82076 .7029 m .81632 .69533 L .81448 .68865 L p F P
0 g
s
.095 .198 .682 r
.81448 .68865 m .80856 .67062 L .81643 .68054 L closepath p F P
0 g
s
.31 .492 .875 r
.75411 .58025 m .74149 .5757 L .73453 .56348 L p F P
0 g
s
.502 .547 .835 r
.60809 .84916 m .60172 .83621 L .62015 .83803 L closepath p F P
0 g
s
.139 .271 .738 r
.8012 .65097 m .79846 .64837 L .79895 .64517 L closepath p F P
0 g
s
.22 .354 .787 r
.794 .63366 m .78667 .62821 L p .79846 .64837 L F P
0 g
s
.22 .354 .787 r
.79846 .64837 m .79895 .64517 L .794 .63366 L p F P
0 g
s
.572 .735 .952 r
.65313 .87509 m .68259 .87062 L .68957 .87858 L p F P
0 g
s
.548 .695 .936 r
.68259 .87062 m .65313 .87509 L .64591 .86425 L p F P
0 g
s
.183 .335 .784 r
.794 .63366 m .78667 .62821 L .7874 .61864 L closepath p F P
0 g
s
.257 .408 .823 r
.78667 .62821 m .7874 .61864 L .78687 .61752 L p F P
0 g
s
.085 .195 .683 r
.81643 .68054 m .80856 .67062 L .80776 .66822 L p F P
0 g
s
.085 .195 .683 r
.80776 .66822 m .80941 .65889 L p .81643 .68054 L F P
0 g
s
.143 .269 .735 r
.80776 .66822 m .8012 .65097 L .80941 .65889 L closepath p F P
0 g
s
.044 .122 .622 r
.81952 .70702 m .81632 .69533 L .82076 .7029 L closepath p F P
0 g
s
.253 .332 .752 r
.54856 .71642 m .54267 .72813 L .55576 .73807 L p F P
0 g
s
.341 .338 .71 r
.53775 .70594 m .54856 .71642 L .54267 .72813 L p F P
0 g
s
0 0 0 r
.80643 .80538 m .80918 .80093 L .81104 .79439 L closepath p F P
0 g
s
.711 .343 0 r
.5011 .59793 m .50535 .60729 L .51065 .61892 L p F P
0 g
s
.702 .35 0 r
.50535 .60729 m .5011 .59793 L .49648 .58619 L p F P
0 g
s
.334 .535 .901 r
.70795 .54679 m .72757 .55201 L .72059 .54104 L p F P
0 g
s
.334 .535 .901 r
.72059 .54104 m .70537 .53692 L .70795 .54679 L p F P
0 g
s
.389 .575 .913 r
.69012 .53406 m .70537 .53692 L .70795 .54679 L p F P
0 g
s
.358 .543 .899 r
.72757 .55201 m .70795 .54679 L p .7329 .5629 L F P
0 g
s
.421 .615 .931 r
.64611 .51002 m .6716 .51273 L .67564 .52232 L p F P
0 g
s
.411 .62 .937 r
.6716 .51273 m .64611 .51002 L .63894 .50038 L p F P
0 g
s
0 .002 .531 r
.82076 .7029 m .81952 .70702 L .82309 .72363 L p F P
0 g
s
0 .045 .554 r
.8222 .72603 m .82309 .72363 L .81952 .70702 L p F P
0 g
s
.656 .925 .975 r
.74584 .86434 m .72569 .87453 L .71902 .86968 L p F P
0 g
s
.618 .85 .987 r
.68957 .87858 m .71902 .86968 L .72569 .87453 L p F P
0 g
s
.853 .445 0 r
.48996 .57744 m .49648 .58619 L .5011 .59793 L p F P
0 g
s
.866 .467 0 r
.49648 .58619 m .48996 .57744 L .48582 .56564 L p F P
0 g
s
.376 .577 .919 r
.70537 .53692 m .69012 .53406 L .68308 .52363 L p F P
0 g
s
.133 .267 .736 r
.80941 .65889 m .8012 .65097 L .79895 .64517 L p F P
0 g
s
.457 .657 .947 r
.60225 .49026 m .6301 .49091 L .63584 .50013 L p F P
0 g
s
.45 .663 .953 r
.6301 .49091 m .60225 .49026 L .59493 .48132 L p F P
0 g
s
.599 .803 .978 r
.71902 .86968 m .68957 .87858 L .68259 .87062 L p F P
0 g
s
.141 .259 .726 r
.5413 .69476 m .53775 .70594 L .54856 .71642 L p F P
0 g
s
.123 .205 .678 r
.53775 .70594 m .5413 .69476 L .5323 .68384 L p F P
0 g
s
0 0 .443 r
.82309 .72363 m .8222 .72603 L .82497 .73926 L p F P
0 g
s
.133 .267 .736 r
.79895 .64517 m .79976 .63799 L p .80941 .65889 L F P
0 g
s
.19 .334 .78 r
.79895 .64517 m .794 .63366 L .79976 .63799 L closepath p F P
0 g
s
.509 .535 .818 r
.62015 .83803 m .60172 .83621 L .59569 .82309 L p F P
0 g
s
.658 .859 .469 r
.80918 .80093 m .80643 .80538 L .79564 .82252 L p F P
0 g
s
0 .158 .679 r
.53363 .67319 m .5323 .68384 L .5413 .69476 L p F P
0 g
s
0 .104 .631 r
.5323 .68384 m .53363 .67319 L .52608 .66194 L p F P
0 g
s
.298 .494 .881 r
.73453 .56348 m .7329 .5629 L .73234 .55977 L closepath p F P
0 g
s
.358 .543 .899 r
.7329 .5629 m .73234 .55977 L .72757 .55201 L p F P
0 g
s
0 0 .101 r
.82523 .75329 m .8205 .764 L .81796 .77883 L p F P
0 g
s
0 0 .31 r
.8205 .764 m .82523 .75329 L .82497 .73926 L p F P
0 g
s
0 0 .41 r
.82555 .7155 m .82309 .72363 L .82524 .73855 L p F P
0 g
s
0 .002 .531 r
.82309 .72363 m .82555 .7155 L .82076 .7029 L p F P
0 g
s
0 0 .443 r
.82497 .73926 m .82524 .73855 L .82309 .72363 L p F P
0 g
s
.372 .584 .925 r
.67564 .52232 m .68308 .52363 L .67601 .51351 L p F P
0 g
s
.372 .584 .925 r
.67601 .51351 m .6716 .51273 L .67564 .52232 L p F P
0 g
s
.656 .925 .975 r
.75155 .85816 m .74584 .86434 L p .71902 .86968 L F P
0 g
s
.709 .953 .952 r
.74584 .86434 m .75155 .85816 L .75488 .85934 L closepath p F P
0 g
s
.542 .623 .882 r
.64591 .86425 m .64366 .86432 L .64512 .86295 L closepath p F P
0 g
s
.553 .594 .848 r
.63859 .85224 m .64512 .86295 L .64366 .86432 L p F P
0 g
s
.179 .333 .783 r
.79976 .63799 m .794 .63366 L .7874 .61864 L p F P
0 g
s
0 0 .517 r
.82325 .69248 m .82076 .7029 L .82555 .7155 L p F P
0 g
s
.036 .119 .621 r
.81643 .68054 m .82325 .69248 L .82076 .7029 L p F P
0 g
s
.31 .492 .875 r
.73453 .56348 m .75274 .57021 L .75411 .58025 L p F P
0 g
s
.29 .489 .88 r
.75274 .57021 m .73453 .56348 L .73234 .55977 L p F P
0 g
s
.548 .695 .936 r
.64591 .86425 m .67549 .86155 L .68259 .87062 L p F P
0 g
s
.538 .621 .882 r
.66831 .85148 m .67549 .86155 L .64591 .86425 L p F P
0 g
s
.538 .621 .882 r
.65662 .85172 m .66831 .85148 L p .64591 .86425 L F P
0 g
s
.538 .621 .882 r
.64591 .86425 m .64512 .86295 L .65662 .85172 L p F P
0 g
s
.509 .535 .818 r
.59569 .82309 m .59821 .82052 L p .62015 .83803 L F P
0 g
s
.476 .518 .821 r
.59569 .82309 m .59418 .81981 L .59821 .82052 L closepath p F P
0 g
s
0 0 .535 r
.52533 .65177 m .52608 .66194 L .53363 .67319 L p F P
0 g
s
0 0 .547 r
.52608 .66194 m .52533 .65177 L .51891 .64028 L p F P
0 g
s
.802 .966 .911 r
.75155 .85816 m .75488 .85934 L .7785 .84138 L p F P
0 g
s
.539 .623 .883 r
.64512 .86295 m .63859 .85224 L .65662 .85172 L closepath p F P
0 g
s
.833 .993 .742 r
.79564 .82252 m .8023 .81159 L p .78157 .83733 L F P
0 g
s
.833 .993 .742 r
.78157 .83733 m .7837 .83667 L .79564 .82252 L p F P
0 g
s
.658 .859 .469 r
.80607 .8061 m .80918 .80093 L p .79564 .82252 L F P
0 g
s
.658 .859 .469 r
.79564 .82252 m .8023 .81159 L .80607 .8061 L p F P
0 g
s
.419 .635 .945 r
.63584 .50013 m .63894 .50038 L .63173 .49104 L p F P
0 g
s
.419 .635 .945 r
.63173 .49104 m .6301 .49091 L .63584 .50013 L p F P
0 g
s
.484 .507 .806 r
.59821 .82052 m .59418 .81981 L .58659 .80227 L p F P
0 g
s
.258 .44 .85 r
.7722 .59861 m .77151 .58847 L .75411 .58025 L p F P
0 g
s
.25 .449 .86 r
.75274 .57021 m .75411 .58025 L .77151 .58847 L p F P
0 g
s
.29 .489 .88 r
.73234 .55977 m .73095 .55294 L p .75274 .57021 L F P
0 g
s
.341 .533 .897 r
.73234 .55977 m .72757 .55201 L .73095 .55294 L closepath p F P
0 g
s
0 .074 .603 r
.81821 .67017 m .81643 .68054 L .82325 .69248 L p F P
0 g
s
.085 .195 .683 r
.80941 .65889 m .81821 .67017 L .81643 .68054 L p F P
0 g
s
.435 .465 .793 r
.58659 .80227 m .58312 .80117 L .58519 .79885 L closepath p F P
0 g
s
.436 .467 .794 r
.57895 .78366 m .57215 .78068 L p .58312 .80117 L F P
0 g
s
.436 .467 .794 r
.58312 .80117 m .58519 .79885 L .57895 .78366 L p F P
0 g
s
.802 .966 .911 r
.7785 .84138 m .78157 .83733 L p .75155 .85816 L F P
0 g
s
.722 .98 .767 r
.7785 .84138 m .78157 .83733 L .7837 .83667 L closepath p F P
0 g
s
0 0 0 r
.81796 .77883 m .81228 .7946 L .80918 .80093 L p F P
0 g
s
.673 .82 .381 r
.80607 .8061 m .81228 .7946 L .80918 .80093 L closepath p F P
0 g
s
.411 .62 .937 r
.63894 .50038 m .66666 .50332 L .6716 .51273 L p F P
0 g
s
.4 .624 .944 r
.66666 .50332 m .63894 .50038 L .63173 .49104 L p F P
0 g
s
.39 .43 .781 r
.57895 .78366 m .57215 .78068 L .57582 .7757 L closepath p F P
0 g
s
.391 .431 .782 r
.57127 .76416 m .56338 .75955 L p .57215 .78068 L F P
0 g
s
.391 .431 .782 r
.57215 .78068 m .57582 .7757 L .57127 .76416 L p F P
0 g
s
.711 .343 0 r
.51065 .61892 m .50601 .6097 L .5011 .59793 L p F P
0 g
s
.376 .577 .919 r
.68308 .52363 m .70194 .52722 L .70537 .53692 L p F P
0 g
s
.363 .579 .924 r
.70194 .52722 m .68308 .52363 L .67601 .51351 L p F P
0 g
s
.484 .507 .806 r
.58659 .80227 m .60844 .80824 L .59821 .82052 L p F P
0 g
s
.509 .535 .818 r
.59821 .82052 m .62374 .82527 L p .62015 .83803 L F P
0 g
s
.436 .481 .808 r
.59821 .82052 m .62374 .82527 L .61623 .81048 L p F P
0 g
s
.436 .481 .808 r
.61623 .81048 m .60844 .80824 L .59821 .82052 L p F P
0 g
s
.188 .377 .819 r
.7722 .59861 m .77986 .60322 L .77283 .58929 L p F P
0 g
s
.188 .377 .819 r
.77283 .58929 m .77151 .58847 L .7722 .59861 L p F P
0 g
s
.179 .333 .783 r
.7874 .61864 m .78744 .61786 L p .79976 .63799 L F P
0 g
s
.234 .393 .818 r
.7874 .61864 m .78687 .61752 L .78744 .61786 L closepath p F P
0 g
s
.015 .162 .674 r
.81051 .64859 m .80941 .65889 L .81821 .67017 L p F P
0 g
s
.133 .267 .736 r
.79976 .63799 m .81051 .64859 L .80941 .65889 L p F P
0 g
s
.332 .387 .769 r
.57127 .76416 m .56338 .75955 L .56707 .75315 L closepath p F P
0 g
s
.332 .387 .769 r
.56357 .74397 m .55576 .73807 L p .56338 .75955 L F P
0 g
s
.332 .387 .769 r
.56338 .75955 m .56707 .75315 L .56357 .74397 L p F P
0 g
s
.221 .393 .822 r
.78744 .61786 m .78687 .61752 L .77986 .60322 L p F P
0 g
s
0 0 .284 r
.82524 .73855 m .82497 .73926 L .82523 .75329 L p F P
0 g
s
.842 .426 0 r
.49443 .58924 m .5011 .59793 L .50601 .6097 L p F P
0 g
s
.853 .445 0 r
.5011 .59793 m .49443 .58924 L .48996 .57744 L p F P
0 g
s
.179 .333 .783 r
.78744 .61786 m .80019 .62775 L .79976 .63799 L p F P
0 g
s
.123 .309 .779 r
.78723 .60769 m .78744 .61786 L .80019 .62775 L p F P
0 g
s
.221 .393 .822 r
.77986 .60322 m .78723 .60769 L .78744 .61786 L p F P
0 g
s
.599 .803 .978 r
.68259 .87062 m .71222 .86353 L .71902 .86968 L p F P
0 g
s
.576 .761 .966 r
.71222 .86353 m .68259 .87062 L .67549 .86155 L p F P
0 g
s
.07 .24 .732 r
.80019 .62775 m .79976 .63799 L .81051 .64859 L p F P
0 g
s
.45 .663 .953 r
.59493 .48132 m .62334 .48193 L .6301 .49091 L p F P
0 g
s
.451 .475 .793 r
.60844 .80824 m .58659 .80227 L .58519 .79885 L p F P
0 g
s
.318 .537 .907 r
.70537 .53692 m .72059 .54104 L .7136 .5304 L p F P
0 g
s
.318 .537 .907 r
.7136 .5304 m .70194 .52722 L .70537 .53692 L p F P
0 g
s
0 0 .242 r
.82818 .72882 m .82524 .73855 L .82585 .7517 L p F P
0 g
s
0 0 .284 r
.82523 .75329 m .82585 .7517 L .82524 .73855 L p F P
0 g
s
0 0 .41 r
.82524 .73855 m .82818 .72882 L .82555 .7155 L p F P
0 g
s
0 0 0 r
.82269 .76819 m .81796 .77883 L .81228 .7946 L p F P
0 g
s
0 0 .101 r
.81796 .77883 m .82269 .76819 L .82523 .75329 L p F P
0 g
s
.656 .925 .975 r
.71902 .86968 m .74847 .85678 L .75155 .85816 L p F P
0 g
s
.642 .884 .985 r
.74847 .85678 m .71902 .86968 L .71222 .86353 L p F P
0 g
s
.451 .475 .793 r
.58519 .79885 m .5929 .78886 L p .60844 .80824 L F P
0 g
s
.408 .451 .793 r
.58519 .79885 m .57895 .78366 L .5929 .78886 L closepath p F P
0 g
s
.254 .333 .753 r
.56357 .74397 m .55576 .73807 L .55866 .7309 L closepath p F P
0 g
s
.253 .332 .752 r
.55584 .7234 m .54856 .71642 L p .55576 .73807 L F P
0 g
s
.253 .332 .752 r
.55576 .73807 m .55866 .7309 L .55584 .7234 L p F P
0 g
s
.544 .607 .867 r
.65662 .85172 m .63859 .85224 L .6312 .83923 L p F P
0 g
s
.488 .562 .857 r
.6312 .83923 m .62015 .83803 L .62651 .83043 L closepath p F P
0 g
s
.509 .535 .818 r
.62374 .82527 m .62651 .83043 L .62015 .83803 L p F P
0 g
s
.746 .946 .946 r
.74847 .85678 m .75477 .853 L .75155 .85816 L closepath p F P
0 g
s
.802 .966 .911 r
.77768 .83752 m .75477 .853 L .75155 .85816 L p F P
0 g
s
.802 .966 .911 r
.78157 .83733 m .77768 .83752 L p .75155 .85816 L F P
0 g
s
.331 .536 .903 r
.73095 .55294 m .72757 .55201 L .72059 .54104 L p F P
0 g
s
.144 .263 .728 r
.55584 .7234 m .54856 .71642 L .55029 .70868 L closepath p F P
0 g
s
.141 .259 .726 r
.5481 .70286 m .5413 .69476 L p .54856 .71642 L F P
0 g
s
.141 .259 .726 r
.54856 .71642 m .55029 .70868 L .5481 .70286 L p F P
0 g
s
.796 .999 .833 r
.77768 .83752 m .7854 .83048 L .78157 .83733 L closepath p F P
0 g
s
.833 .993 .742 r
.8023 .81159 m .7854 .83048 L .78157 .83733 L p F P
0 g
s
.417 .446 .783 r
.5929 .78886 m .57895 .78366 L .57582 .7757 L p F P
0 g
s
0 0 .385 r
.82803 .70512 m .82555 .7155 L .82818 .72882 L p F P
0 g
s
0 0 .517 r
.82555 .7155 m .82803 .70512 L .82325 .69248 L p F P
0 g
s
.417 .446 .783 r
.57582 .7757 m .58046 .76863 L p .5929 .78886 L F P
0 g
s
.367 .416 .78 r
.57582 .7757 m .57127 .76416 L .58046 .76863 L closepath p F P
0 g
s
0 .165 .684 r
.5481 .70286 m .5413 .69476 L .54155 .68604 L closepath p F P
0 g
s
0 .158 .679 r
.54036 .68294 m .53363 .67319 L p .5413 .69476 L F P
0 g
s
0 .158 .679 r
.5413 .69476 m .54155 .68604 L .54036 .68294 L p F P
0 g
s
.36 .588 .931 r
.6716 .51273 m .67601 .51351 L .6689 .50372 L p F P
0 g
s
.36 .588 .931 r
.6689 .50372 m .66666 .50332 L .6716 .51273 L p F P
0 g
s
.29 .489 .88 r
.73095 .55294 m .75059 .5603 L .75274 .57021 L p F P
0 g
s
.259 .485 .886 r
.72813 .54313 m .73095 .55294 L .75059 .5603 L p F P
0 g
s
.331 .536 .903 r
.72059 .54104 m .72813 .54313 L .73095 .55294 L p F P
0 g
s
.194 .383 .823 r
.78723 .60769 m .77986 .60322 L .77283 .58929 L p F P
0 g
s
.375 .413 .773 r
.58046 .76863 m .57127 .76416 L .56707 .75315 L p F P
0 g
s
0 0 0 r
.81228 .7946 m .81689 .78405 L .82269 .76819 L p F P
0 g
s
.813 .911 .513 r
.81228 .7946 m .81689 .78405 L p .8043 .80807 L F P
0 g
s
.813 .911 .513 r
.8043 .80807 m .80607 .8061 L .81228 .7946 L p F P
0 g
s
0 0 .548 r
.53363 .67319 m .54036 .68294 L .5326 .66431 L p F P
0 g
s
0 0 .548 r
.5326 .66431 m .532 .66331 L .53363 .67319 L p F P
0 g
s
0 0 .535 r
.53363 .67319 m .532 .66331 L .52533 .65177 L p F P
0 g
s
.409 .641 .951 r
.6301 .49091 m .63173 .49104 L .62448 .48202 L p F P
0 g
s
.409 .641 .951 r
.62448 .48202 m .62334 .48193 L .6301 .49091 L p F P
0 g
s
0 0 .064 r
.82585 .7517 m .82523 .75329 L .82269 .76819 L p F P
0 g
s
0 0 .502 r
.82503 .68215 m .82325 .69248 L .82803 .70512 L p F P
0 g
s
0 .074 .603 r
.82325 .69248 m .82503 .68215 L .81821 .67017 L p F P
0 g
s
.4 .624 .944 r
.63173 .49104 m .66082 .49411 L .66666 .50332 L p F P
0 g
s
.389 .629 .95 r
.66082 .49411 m .63173 .49104 L .62448 .48202 L p F P
0 g
s
.375 .413 .773 r
.56707 .75315 m .5699 .74785 L p .58046 .76863 L F P
0 g
s
.316 .377 .767 r
.56707 .75315 m .56357 .74397 L .5699 .74785 L closepath p F P
0 g
s
.363 .579 .924 r
.67601 .51351 m .69769 .51767 L .70194 .52722 L p F P
0 g
s
.349 .582 .93 r
.69769 .51767 m .67601 .51351 L .6689 .50372 L p F P
0 g
s
.729 .919 .957 r
.75477 .853 m .74847 .85678 L .7419 .85262 L p F P
0 g
s
.642 .884 .985 r
.71222 .86353 m .7419 .85262 L .74847 .85678 L p F P
0 g
s
.25 .449 .86 r
.76586 .57652 m .75274 .57021 L p .77151 .58847 L F P
0 g
s
.212 .431 .856 r
.75274 .57021 m .76586 .57652 L .75889 .56437 L p F P
0 g
s
.212 .431 .856 r
.75889 .56437 m .75059 .5603 L .75274 .57021 L p F P
0 g
s
.321 .377 .764 r
.5699 .74785 m .56357 .74397 L .55866 .7309 L p F P
0 g
s
.544 .607 .867 r
.6312 .83923 m .66105 .84052 L p .65662 .85172 L F P
0 g
s
.486 .561 .857 r
.6537 .82874 m .66105 .84052 L .6312 .83923 L p F P
0 g
s
.486 .561 .857 r
.63021 .82595 m .6537 .82874 L p .6312 .83923 L F P
0 g
s
.486 .561 .857 r
.6312 .83923 m .62651 .83043 L .63021 .82595 L p F P
0 g
s
.576 .761 .966 r
.67549 .86155 m .7053 .85626 L .71222 .86353 L p F P
0 g
s
.55 .722 .954 r
.7053 .85626 m .67549 .86155 L .66831 .85148 L p F P
0 g
s
.717 .335 0 r
.51619 .63058 m .5112 .62149 L .50601 .6097 L p F P
0 g
s
.729 .919 .957 r
.7419 .85262 m .76132 .84217 L .75477 .853 L p F P
0 g
s
.744 .98 .916 r
.77145 .83614 m .76132 .84217 L .75477 .853 L p F P
0 g
s
.744 .98 .916 r
.75477 .853 m .77768 .83752 L .77145 .83614 L p F P
0 g
s
0 0 .02 r
.82851 .74288 m .82585 .7517 L .82476 .76292 L p F P
0 g
s
0 0 .242 r
.82585 .7517 m .82851 .74288 L .82818 .72882 L p F P
0 g
s
0 0 .064 r
.82269 .76819 m .82476 .76292 L .82585 .7517 L p F P
0 g
s
.695 .885 .504 r
.8023 .81159 m .8043 .80807 L .80607 .8061 L closepath p F P
0 g
s
.831 .408 0 r
.49921 .60106 m .50601 .6097 L .5112 .62149 L p F P
0 g
s
.842 .426 0 r
.50601 .6097 m .49921 .60106 L .49443 .58924 L p F P
0 g
s
0 .052 .595 r
.81928 .6599 m .81821 .67017 L .82503 .68215 L p F P
0 g
s
.015 .162 .674 r
.81821 .67017 m .81928 .6599 L .81051 .64859 L p F P
0 g
s
.321 .377 .764 r
.55866 .7309 m .56033 .72678 L p .5699 .74785 L F P
0 g
s
.254 .333 .752 r
.55866 .7309 m .55584 .7234 L .56033 .72678 L closepath p F P
0 g
s
.802 .997 .784 r
.8043 .80807 m .8023 .81159 L .7854 .83048 L p F P
0 g
s
.166 .375 .824 r
.77283 .58929 m .77151 .58847 L .77118 .58611 L closepath p F P
0 g
s
.25 .449 .86 r
.77151 .58847 m .77118 .58611 L .76586 .57652 L p F P
0 g
s
.251 .333 .753 r
.56033 .72678 m .55584 .7234 L .55029 .70868 L p F P
0 g
s
.314 .537 .908 r
.72813 .54313 m .72059 .54104 L .7136 .5304 L p F P
0 g
s
.623 .841 .983 r
.7419 .85262 m .71222 .86353 L .7053 .85626 L p F P
0 g
s
.526 .641 .906 r
.66831 .85148 m .65662 .85172 L .66258 .84283 L closepath p F P
0 g
s
.544 .607 .867 r
.66105 .84052 m .66258 .84283 L .65662 .85172 L p F P
0 g
s
.301 .538 .913 r
.70194 .52722 m .7136 .5304 L .70657 .52012 L p F P
0 g
s
.301 .538 .913 r
.70657 .52012 m .69769 .51767 L .70194 .52722 L p F P
0 g
s
0 .145 .669 r
.81088 .63839 m .81051 .64859 L .81928 .6599 L p F P
0 g
s
.07 .24 .732 r
.81051 .64859 m .81088 .63839 L .80019 .62775 L p F P
0 g
s
.194 .383 .823 r
.77283 .58929 m .78626 .59764 L .78723 .60769 L p F P
0 g
s
.163 .373 .823 r
.78626 .59764 m .77283 .58929 L .77118 .58611 L p F P
0 g
s
.123 .309 .779 r
.80019 .62775 m .79988 .61763 L .78723 .60769 L p F P
0 g
s
.09 .299 .78 r
.78626 .59764 m .78723 .60769 L .79988 .61763 L p F P
0 g
s
.034 .227 .73 r
.79988 .61763 m .80019 .62775 L .81088 .63839 L p F P
0 g
s
.799 .993 .875 r
.7854 .83048 m .77768 .83752 L .77145 .83614 L p F P
0 g
s
.799 .993 .875 r
.77145 .83614 m .79099 .8198 L .7854 .83048 L p F P
0 g
s
.802 .997 .784 r
.80042 .81015 m .8043 .80807 L p .7854 .83048 L F P
0 g
s
.802 .997 .784 r
.7854 .83048 m .79099 .8198 L .80042 .81015 L p F P
0 g
s
.488 .563 .858 r
.62651 .83043 m .62374 .82527 L .63021 .82595 L closepath p F P
0 g
s
.251 .333 .753 r
.55029 .70868 m .55111 .70558 L p .56033 .72678 L F P
0 g
s
.174 .281 .735 r
.55029 .70868 m .5481 .70286 L .55111 .70558 L closepath p F P
0 g
s
0 0 .204 r
.83066 .71848 m .82818 .72882 L .82851 .74288 L p F P
0 g
s
0 0 .385 r
.82818 .72882 m .83066 .71848 L .82803 .70512 L p F P
0 g
s
.156 .278 .739 r
.55111 .70558 m .5481 .70286 L .54155 .68604 L p F P
0 g
s
.163 .373 .823 r
.77118 .58611 m .76995 .57849 L p .78626 .59764 L F P
0 g
s
.23 .436 .855 r
.77118 .58611 m .76586 .57652 L .76995 .57849 L closepath p F P
0 g
s
.417 .446 .783 r
.58046 .76863 m .59841 .77763 L .5929 .78886 L p F P
0 g
s
.304 .421 .815 r
.58524 .75745 m .58046 .76863 L .59841 .77763 L p F P
0 g
s
.375 .413 .773 r
.5699 .74785 m .58524 .75745 L .58046 .76863 L p F P
0 g
s
.451 .475 .793 r
.5929 .78886 m .60865 .79498 L p .60844 .80824 L F P
0 g
s
.333 .414 .796 r
.5929 .78886 m .60865 .79498 L .60104 .77897 L p F P
0 g
s
.333 .414 .796 r
.60104 .77897 m .59841 .77763 L .5929 .78886 L p F P
0 g
s
.659 .751 .262 r
.82476 .76292 m .82269 .76819 L .81689 .78405 L p F P
0 g
s
.225 .371 .801 r
.57356 .73685 m .5699 .74785 L .58524 .75745 L p F P
0 g
s
.321 .377 .764 r
.56033 .72678 m .57356 .73685 L .5699 .74785 L p F P
0 g
s
.494 .553 .845 r
.63021 .82595 m .62374 .82527 L .61623 .81048 L p F P
0 g
s
.414 .497 .836 r
.61623 .81048 m .60844 .80824 L .61211 .80204 L closepath p F P
0 g
s
.451 .475 .793 r
.60865 .79498 m .61211 .80204 L .60844 .80824 L p F P
0 g
s
.82 .973 .668 r
.80042 .81015 m .80726 .80101 L .8043 .80807 L closepath p F P
0 g
s
.813 .911 .513 r
.81689 .78405 m .80726 .80101 L .8043 .80807 L p F P
0 g
s
.086 .258 .743 r
.56264 .71602 m .56033 .72678 L .57356 .73685 L p F P
0 g
s
.251 .333 .753 r
.55111 .70558 m .56264 .71602 L .56033 .72678 L p F P
0 g
s
.347 .593 .937 r
.66666 .50332 m .6689 .50372 L .66176 .49427 L p F P
0 g
s
.347 .593 .937 r
.66176 .49427 m .66082 .49411 L .66666 .50332 L p F P
0 g
s
.156 .278 .739 r
.54155 .68604 m .54174 .6844 L p .55111 .70558 L F P
0 g
s
.071 .219 .711 r
.54155 .68604 m .54036 .68294 L .54174 .6844 L closepath p F P
0 g
s
.022 .204 .712 r
.54174 .6844 m .54036 .68294 L .5326 .66431 L p F P
0 g
s
.259 .485 .886 r
.75059 .5603 m .74768 .55052 L .72813 .54313 L p F P
0 g
s
.239 .485 .89 r
.72452 .53347 m .72813 .54313 L .74768 .55052 L p F P
0 g
s
.314 .537 .908 r
.7136 .5304 m .72452 .53347 L .72813 .54313 L p F P
0 g
s
0 .189 .708 r
.55193 .69512 m .55111 .70558 L .56264 .71602 L p F P
0 g
s
.156 .278 .739 r
.54174 .6844 m .55193 .69512 L .55111 .70558 L p F P
0 g
s
.349 .582 .93 r
.6689 .50372 m .69261 .50829 L .69769 .51767 L p F P
0 g
s
.334 .585 .936 r
.69261 .50829 m .6689 .50372 L .66176 .49427 L p F P
0 g
s
.55 .722 .954 r
.66831 .85148 m .69828 .84802 L .7053 .85626 L p F P
0 g
s
.544 .65 .904 r
.69116 .83894 m .69828 .84802 L .66831 .85148 L p F P
0 g
s
.544 .65 .904 r
.66472 .84029 m .69116 .83894 L p .66831 .85148 L F P
0 g
s
.544 .65 .904 r
.66831 .85148 m .66258 .84283 L .66472 .84029 L p F P
0 g
s
0 0 .362 r
.82982 .69482 m .82803 .70512 L .83066 .71848 L p F P
0 g
s
0 0 .502 r
.82803 .70512 m .82982 .69482 L .82503 .68215 L p F P
0 g
s
.389 .629 .95 r
.62448 .48202 m .65407 .48509 L .66082 .49411 L p F P
0 g
s
0 .11 .661 r
.54098 .67428 m .54174 .6844 L .55193 .69512 L p F P
0 g
s
.022 .204 .712 r
.5326 .66431 m .54098 .67428 L .54174 .6844 L p F P
0 g
s
0 0 .473 r
.5326 .66431 m .532 .66331 L .5315 .66198 L closepath p F P
0 g
s
0 0 .459 r
.532 .66331 m .5315 .66198 L .52484 .64772 L p F P
0 g
s
.442 .529 .851 r
.63021 .82595 m .6537 .82874 L .64629 .81633 L p F P
0 g
s
.442 .529 .851 r
.64629 .81633 m .63747 .81451 L .63021 .82595 L p F P
0 g
s
.494 .553 .845 r
.61623 .81048 m .63747 .81451 L .63021 .82595 L p F P
0 g
s
.215 .436 .86 r
.76995 .57849 m .76586 .57652 L .75889 .56437 L p F P
0 g
s
0 .106 .659 r
.54098 .67428 m .5326 .66431 L .5315 .66198 L p F P
0 g
s
.296 .537 .913 r
.72452 .53347 m .7136 .5304 L .70657 .52012 L p F P
0 g
s
.813 .381 0 r
.50428 .6129 m .5112 .62149 L .51668 .63331 L p F P
0 g
s
.831 .408 0 r
.5112 .62149 m .50428 .6129 L .49921 .60106 L p F P
0 g
s
.185 .426 .859 r
.75059 .5603 m .75889 .56437 L .75192 .55263 L p F P
0 g
s
.185 .426 .859 r
.75192 .55263 m .74768 .55052 L .75059 .5603 L p F P
0 g
s
.687 .923 .971 r
.76132 .84217 m .7419 .85262 L .7352 .84725 L p F P
0 g
s
.623 .841 .983 r
.7053 .85626 m .7352 .84725 L .7419 .85262 L p F P
0 g
s
0 .106 .659 r
.5315 .66198 m .52934 .65364 L p .54098 .67428 L F P
0 g
s
0 .046 .614 r
.5315 .66198 m .52484 .64772 L .52934 .65364 L closepath p F P
0 g
s
.659 .751 .262 r
.82242 .77007 m .82476 .76292 L p .81689 .78405 L F P
0 g
s
.798 .917 .529 r
.82106 .7735 m .81689 .78405 L .80726 .80101 L p F P
0 g
s
.659 .751 .262 r
.81689 .78405 m .82106 .7735 L .82242 .77007 L p F P
0 g
s
0 0 .494 r
.82612 .67191 m .82503 .68215 L .82982 .69482 L p F P
0 g
s
0 .052 .595 r
.82503 .68215 m .82612 .67191 L .81928 .6599 L p F P
0 g
s
.46 .523 .836 r
.63747 .81451 m .61623 .81048 L .61211 .80204 L p F P
0 g
s
0 0 .02 r
.82476 .76292 m .82631 .75773 L .82851 .74288 L p F P
0 g
s
0 0 0 r
.83098 .73258 m .82851 .74288 L .82631 .75773 L p F P
0 g
s
0 0 .204 r
.82851 .74288 m .83098 .73258 L .83066 .71848 L p F P
0 g
s
.599 .8 .977 r
.7352 .84725 m .7053 .85626 L .69828 .84802 L p F P
0 g
s
.692 .737 .227 r
.82242 .77007 m .82631 .75773 L .82476 .76292 L closepath p F P
0 g
s
.283 .54 .918 r
.69769 .51767 m .70657 .52012 L .69952 .51019 L p F P
0 g
s
.283 .54 .918 r
.69952 .51019 m .69261 .50829 L .69769 .51767 L p F P
0 g
s
.163 .373 .823 r
.76995 .57849 m .78456 .58771 L .78626 .59764 L p F P
0 g
s
.115 .358 .822 r
.76761 .56864 m .76995 .57849 L .78456 .58771 L p F P
0 g
s
.215 .436 .86 r
.75889 .56437 m .76761 .56864 L .76995 .57849 L p F P
0 g
s
0 .036 .589 r
.81966 .64973 m .81928 .6599 L .82612 .67191 L p F P
0 g
s
0 .145 .669 r
.81928 .6599 m .81966 .64973 L .81088 .63839 L p F P
0 g
s
.545 .652 .904 r
.66258 .84283 m .66105 .84052 L .66472 .84029 L closepath p F P
0 g
s
.46 .523 .836 r
.61211 .80204 m .61538 .79675 L p .63747 .81451 L F P
0 g
s
.422 .503 .837 r
.61211 .80204 m .60865 .79498 L .61538 .79675 L closepath p F P
0 g
s
.09 .299 .78 r
.79988 .61763 m .79885 .60762 L .78626 .59764 L p F P
0 g
s
.056 .289 .779 r
.78456 .58771 m .78626 .59764 L .79885 .60762 L p F P
0 g
s
0 .138 .67 r
.81055 .6283 m .81088 .63839 L .81966 .64973 L p F P
0 g
s
.034 .227 .73 r
.81088 .63839 m .81055 .6283 L .79988 .61763 L p F P
0 g
s
.687 .923 .971 r
.76682 .83407 m .76132 .84217 L p .7352 .84725 L F P
0 g
s
.74 .949 .947 r
.76132 .84217 m .76682 .83407 L .77145 .83614 L closepath p F P
0 g
s
.014 .229 .737 r
.79885 .60762 m .79988 .61763 L .81055 .6283 L p F P
0 g
s
.888 .989 .742 r
.80726 .80101 m .8111 .79062 L p .79557 .811 L F P
0 g
s
.888 .989 .742 r
.79557 .811 m .80042 .81015 L .80726 .80101 L p F P
0 g
s
.798 .917 .529 r
.80726 .80101 m .8111 .79062 L .82106 .7735 L p F P
0 g
s
.55 .637 .89 r
.66472 .84029 m .66105 .84052 L .6537 .82874 L p F P
0 g
s
.428 .499 .83 r
.61538 .79675 m .60865 .79498 L .60104 .77897 L p F P
0 g
s
.334 .597 .943 r
.66082 .49411 m .66176 .49427 L .65457 .48518 L p F P
0 g
s
.334 .597 .943 r
.65457 .48518 m .65407 .48509 L .66082 .49411 L p F P
0 g
s
0 0 .169 r
.8325 .70821 m .83066 .71848 L .83098 .73258 L p F P
0 g
s
0 0 .362 r
.83066 .71848 m .8325 .70821 L .82982 .69482 L p F P
0 g
s
.83 .956 .896 r
.76682 .83407 m .77145 .83614 L .79099 .8198 L p F P
0 g
s
.804 .998 .786 r
.79099 .8198 m .79557 .811 L .80042 .81015 L closepath p F P
0 g
s
.334 .585 .936 r
.66176 .49427 m .68671 .49907 L .69261 .50829 L p F P
0 g
s
.319 .589 .94 r
.68671 .49907 m .66176 .49427 L .65457 .48518 L p F P
0 g
s
.508 .618 .896 r
.66472 .84029 m .69116 .83894 L .68397 .82915 L p F P
0 g
s
.508 .618 .896 r
.68397 .82915 m .67228 .8289 L .66472 .84029 L p F P
0 g
s
.55 .637 .89 r
.6537 .82874 m .67228 .8289 L .66472 .84029 L p F P
0 g
s
.83 .956 .896 r
.79099 .8198 m .79557 .811 L p .76682 .83407 L F P
0 g
s
.188 .43 .861 r
.76761 .56864 m .75889 .56437 L .75192 .55263 L p F P
0 g
s
.239 .485 .89 r
.74768 .55052 m .74401 .54088 L .72452 .53347 L p F P
0 g
s
.232 .494 .897 r
.72013 .52396 m .72452 .53347 L .74401 .54088 L p F P
0 g
s
.296 .537 .913 r
.70657 .52012 m .72013 .52396 L .72452 .53347 L p F P
0 g
s
0 0 0 r
.82631 .75773 m .82874 .7475 L .83098 .73258 L p F P
0 g
s
.816 .818 .337 r
.82631 .75773 m .82874 .7475 L p .82163 .77183 L F P
0 g
s
.816 .818 .337 r
.82163 .77183 m .82242 .77007 L .82631 .75773 L p F P
0 g
s
.304 .421 .815 r
.59338 .76261 m .58524 .75745 L p .59841 .77763 L F P
0 g
s
.224 .371 .801 r
.59338 .76261 m .58524 .75745 L .58674 .74845 L closepath p F P
0 g
s
.225 .371 .801 r
.58569 .74622 m .57356 .73685 L p .58524 .75745 L F P
0 g
s
.225 .371 .801 r
.58524 .75745 m .58674 .74845 L .58569 .74622 L p F P
0 g
s
.088 .259 .744 r
.57356 .73685 m .58569 .74622 L .57798 .73008 L p F P
0 g
s
.088 .259 .744 r
.57798 .73008 m .57419 .72661 L .57356 .73685 L p F P
0 g
s
.086 .258 .743 r
.57356 .73685 m .57419 .72661 L .56264 .71602 L p F P
0 g
s
.303 .419 .815 r
.60104 .77897 m .59841 .77763 L .59922 .77508 L closepath p F P
0 g
s
.304 .421 .815 r
.59841 .77763 m .59922 .77508 L .59338 .76261 L p F P
0 g
s
.278 .537 .917 r
.72013 .52396 m .70657 .52012 L .69952 .51019 L p F P
0 g
s
0 .232 .743 r
.56214 .70598 m .56264 .71602 L .57419 .72661 L p F P
0 g
s
0 .189 .708 r
.56264 .71602 m .56214 .70598 L .55193 .69512 L p F P
0 g
s
0 .085 .644 r
.55016 .68533 m .55193 .69512 L .56214 .70598 L p F P
0 g
s
0 .11 .661 r
.55193 .69512 m .55016 .68533 L .54098 .67428 L p F P
0 g
s
0 0 .336 r
.8307 .68704 m .82982 .69482 L .8325 .70821 L p F P
0 g
s
0 0 .494 r
.82861 .67856 m .82612 .67191 L p .82982 .69482 L F P
0 g
s
0 0 .494 r
.82982 .69482 m .8307 .68704 L .82861 .67856 L p F P
0 g
s
0 0 .569 r
.53779 .66479 m .54098 .67428 L .55016 .68533 L p F P
0 g
s
0 .106 .659 r
.52934 .65364 m .53779 .66479 L .54098 .67428 L p F P
0 g
s
.813 .381 0 r
.50925 .62389 m .50428 .6129 L p .51668 .63331 L F P
0 g
s
.798 .361 0 r
.51707 .63409 m .51668 .63331 L .51329 .62918 L closepath p F P
0 g
s
.813 .381 0 r
.51668 .63331 m .51329 .62918 L .50925 .62389 L p F P
0 g
s
.46 .523 .836 r
.61538 .79675 m .63882 .80339 L p .63747 .81451 L F P
0 g
s
.361 .466 .832 r
.61538 .79675 m .63882 .80339 L .63129 .79006 L p F P
0 g
s
.361 .466 .832 r
.63129 .79006 m .62002 .78578 L .61538 .79675 L p F P
0 g
s
.428 .499 .83 r
.60104 .77897 m .62002 .78578 L .61538 .79675 L p F P
0 g
s
0 0 .474 r
.52455 .64452 m .52934 .65364 L .53779 .66479 L p F P
0 g
s
.599 .8 .977 r
.69828 .84802 m .72838 .84085 L .7352 .84725 L p F P
0 g
s
.572 .764 .969 r
.72838 .84085 m .69828 .84802 L .69116 .83894 L p F P
0 g
s
.383 .468 .823 r
.62002 .78578 m .60104 .77897 L .59922 .77508 L p F P
0 g
s
.687 .923 .971 r
.7352 .84725 m .76503 .83313 L .76682 .83407 L p F P
0 g
s
.666 .888 .979 r
.76503 .83313 m .7352 .84725 L .72838 .84085 L p F P
0 g
s
.157 .42 .86 r
.74768 .55052 m .75192 .55263 L .74492 .54134 L p F P
0 g
s
.157 .42 .86 r
.74492 .54134 m .74401 .54088 L .74768 .55052 L p F P
0 g
s
.383 .468 .823 r
.59922 .77508 m .60252 .76667 L p .62002 .78578 L F P
0 g
s
.336 .44 .82 r
.59922 .77508 m .59338 .76261 L .60252 .76667 L closepath p F P
0 g
s
.52 .611 .883 r
.67228 .8289 m .6537 .82874 L .64629 .81633 L p F P
0 g
s
.714 .79 .31 r
.82106 .7735 m .82163 .77183 L .82242 .77007 L closepath p F P
0 g
s
.265 .542 .922 r
.69261 .50829 m .69952 .51019 L .69243 .50065 L p F P
0 g
s
.265 .542 .922 r
.69243 .50065 m .68671 .49907 L .69261 .50829 L p F P
0 g
s
0 0 .461 r
.82861 .67856 m .82612 .67191 L .82624 .66916 L closepath p F P
0 g
s
0 .036 .589 r
.8205 .65127 m .81966 .64973 L p .82612 .67191 L F P
0 g
s
0 .036 .589 r
.82612 .67191 m .82624 .66916 L .8205 .65127 L p F P
0 g
s
.42 .547 .878 r
.64629 .81633 m .63747 .81451 L .64047 .80624 L closepath p F P
0 g
s
.46 .523 .836 r
.63882 .80339 m .64047 .80624 L .63747 .81451 L p F P
0 g
s
0 0 0 r
.83285 .72235 m .83098 .73258 L .82874 .7475 L p F P
0 g
s
0 0 .169 r
.83098 .73258 m .83285 .72235 L .8325 .70821 L p F P
0 g
s
.838 .955 .611 r
.82163 .77183 m .82106 .7735 L .8111 .79062 L p F P
0 g
s
.115 .358 .822 r
.78456 .58771 m .78215 .5779 L .76761 .56864 L p F P
0 g
s
.084 .351 .822 r
.76453 .55892 m .76761 .56864 L .78215 .5779 L p F P
0 g
s
.188 .43 .861 r
.75192 .55263 m .76453 .55892 L .76761 .56864 L p F P
0 g
s
.16 .424 .862 r
.76453 .55892 m .75192 .55263 L .74492 .54134 L p F P
0 g
s
.777 .941 .933 r
.76503 .83313 m .76788 .83123 L .76682 .83407 L closepath p F P
0 g
s
.83 .956 .896 r
.79445 .81093 m .76788 .83123 L .76682 .83407 L p F P
0 g
s
.83 .956 .896 r
.79557 .811 m .79445 .81093 L p .76682 .83407 L F P
0 g
s
0 0 .56 r
.8205 .65127 m .81966 .64973 L .81963 .64861 L closepath p F P
0 g
s
0 .138 .67 r
.81304 .63162 m .81055 .6283 L p .81966 .64973 L F P
0 g
s
0 .138 .67 r
.81966 .64973 m .81963 .64861 L .81304 .63162 L p F P
0 g
s
.605 .149 0 r
.51329 .62918 m .50982 .62471 L p .52455 .64452 L F P
0 g
s
.626 .172 0 r
.51329 .62918 m .50925 .62389 L .50982 .62471 L closepath p F P
0 g
s
.336 .44 .82 r
.60252 .76667 m .59338 .76261 L .58674 .74845 L p F P
0 g
s
.056 .289 .779 r
.79885 .60762 m .79712 .59771 L .78456 .58771 L p F P
0 g
s
.041 .295 .786 r
.78215 .5779 m .78456 .58771 L .79712 .59771 L p F P
0 g
s
.859 .921 .528 r
.81704 .77642 m .82359 .7633 L .82163 .77183 L closepath p F P
0 g
s
.816 .818 .337 r
.82874 .7475 m .82359 .7633 L .82163 .77183 L p F P
0 g
s
.838 .955 .611 r
.81704 .77642 m .82163 .77183 L p .8111 .79062 L F P
0 g
s
0 .097 .646 r
.81304 .63162 m .81055 .6283 L .81016 .62442 L closepath p F P
0 g
s
.014 .229 .737 r
.80577 .61466 m .79885 .60762 L p .81055 .6283 L F P
0 g
s
.014 .229 .737 r
.81055 .6283 m .81016 .62442 L .80577 .61466 L p F P
0 g
s
.319 .589 .94 r
.65457 .48518 m .67998 .49002 L .68671 .49907 L p F P
0 g
s
0 0 .456 r
.82624 .66916 m .82627 .66183 L p .83086 .68463 L F P
0 g
s
0 0 .456 r
.83086 .68463 m .82861 .67856 L .82624 .66916 L p F P
0 g
s
0 0 .564 r
.82624 .66916 m .8205 .65127 L .82627 .66183 L closepath p F P
0 g
s
0 0 .557 r
.82627 .66183 m .8205 .65127 L .81963 .64861 L p F P
0 g
s
0 0 .557 r
.81963 .64861 m .8191 .63973 L p .82627 .66183 L F P
0 g
s
0 .106 .65 r
.81963 .64861 m .81304 .63162 L .8191 .63973 L closepath p F P
0 g
s
0 .183 .711 r
.79885 .60762 m .80577 .61466 L .79861 .59926 L p F P
0 g
s
0 .183 .711 r
.79861 .59926 m .79712 .59771 L .79885 .60762 L p F P
0 g
s
.278 .537 .917 r
.69952 .51019 m .71497 .51459 L .72013 .52396 L p F P
0 g
s
.259 .538 .921 r
.71497 .51459 m .69952 .51019 L .69243 .50065 L p F P
0 g
s
0 0 .464 r
.8307 .68704 m .82861 .67856 L .83086 .68463 L closepath p F P
0 g
s
.888 .989 .742 r
.8111 .79062 m .7962 .80912 L .79557 .811 L p F P
0 g
s
.873 .994 .778 r
.81461 .78021 m .8111 .79062 L .7962 .80912 L p F P
0 g
s
.838 .955 .611 r
.8111 .79062 m .81461 .78021 L .81704 .77642 L p F P
0 g
s
.232 .494 .897 r
.73793 .53076 m .72013 .52396 L p .74401 .54088 L F P
0 g
s
.197 .482 .895 r
.72013 .52396 m .73793 .53076 L .73093 .52071 L p F P
0 g
s
.197 .482 .895 r
.73093 .52071 m .71497 .51459 L .72013 .52396 L p F P
0 g
s
.761 .915 .942 r
.76788 .83123 m .76503 .83313 L .75845 .82869 L p F P
0 g
s
.666 .888 .979 r
.72838 .84085 m .75845 .82869 L .76503 .83313 L p F P
0 g
s
.85 .996 .826 r
.79445 .81093 m .7962 .80912 L .79557 .811 L closepath p F P
0 g
s
0 0 .131 r
.83318 .70248 m .8325 .70821 L .83285 .72235 L p F P
0 g
s
0 0 .336 r
.8325 .70821 m .83318 .70248 L .8307 .68704 L p F P
0 g
s
.761 .915 .942 r
.75845 .82869 m .77098 .82109 L .76788 .83123 L p F P
0 g
s
.787 .983 .901 r
.78822 .80928 m .77098 .82109 L .76788 .83123 L p F P
0 g
s
.787 .983 .901 r
.76788 .83123 m .79445 .81093 L .78822 .80928 L p F P
0 g
s
0 .096 .646 r
.8191 .63973 m .81304 .63162 L .81016 .62442 L p F P
0 g
s
.52 .611 .883 r
.64629 .81633 m .67523 .81863 L .67228 .8289 L p F P
0 g
s
.488 .585 .878 r
.67523 .81863 m .64629 .81633 L .64047 .80624 L p F P
0 g
s
.572 .764 .969 r
.69116 .83894 m .72145 .83356 L .72838 .84085 L p F P
0 g
s
.544 .731 .962 r
.72145 .83356 m .69116 .83894 L .68397 .82915 L p F P
0 g
s
0 0 .298 r
.83086 .68463 m .8307 .68704 L .83318 .70248 L p F P
0 g
s
.336 .44 .82 r
.58674 .74845 m .58713 .74698 L p .60252 .76667 L F P
0 g
s
.284 .408 .813 r
.58674 .74845 m .58569 .74622 L .58713 .74698 L closepath p F P
0 g
s
.277 .409 .816 r
.58713 .74698 m .58569 .74622 L .57798 .73008 L p F P
0 g
s
.605 .149 0 r
.50982 .62471 m .51771 .63592 L .52455 .64452 L p F P
0 g
s
0 .096 .646 r
.81016 .62442 m .8094 .61834 L p .8191 .63973 L F P
0 g
s
0 .205 .723 r
.81016 .62442 m .80577 .61466 L .8094 .61834 L closepath p F P
0 g
s
.85 .984 .859 r
.7962 .80912 m .79445 .81093 L .78822 .80928 L p F P
0 g
s
.85 .984 .859 r
.78822 .80928 m .79894 .79899 L .7962 .80912 L p F P
0 g
s
.873 .994 .778 r
.7962 .80912 m .79894 .79899 L .81461 .78021 L p F P
0 g
s
0 0 0 r
.82874 .7475 m .83059 .73732 L .83285 .72235 L p F P
0 g
s
.819 .828 .353 r
.83059 .73732 m .82874 .7475 L .82359 .7633 L p F P
0 g
s
0 0 .454 r
.54076 .66718 m .5326 .6558 L p .53356 .65721 L F P
0 g
s
0 0 .454 r
.54633 .67604 m .54076 .66718 L p .53356 .65721 L F P
0 g
s
0 0 .465 r
.54693 .67563 m .54076 .66718 L .54633 .67604 L p F P
0 g
s
.632 .166 0 r
.54076 .66718 m .54693 .67563 L .5465 .67511 L p F P
0 g
s
0 0 .454 r
.5326 .6558 m .53779 .66479 L .54633 .67604 L p F P
0 g
s
.632 .166 0 r
.5465 .67511 m .5391 .66628 L p .54076 .66718 L F P
0 g
s
.642 .176 0 r
.5326 .6558 m .54076 .66718 L p .54043 .66674 L F P
0 g
s
0 0 .474 r
.53779 .66479 m .5326 .6558 L p .52485 .64496 L F P
0 g
s
.642 .176 0 r
.52562 .64726 m .5326 .6558 L p .54043 .66674 L F P
0 g
s
0 0 .474 r
.5326 .6558 m .52455 .64452 L p .52485 .64496 L F P
0 g
s
.638 .176 0 r
.51771 .63592 m .52455 .64452 L .5326 .6558 L p F P
0 g
s
0 .235 .745 r
.57798 .73008 m .57419 .72661 L .57333 .72076 L closepath p F P
0 g
s
0 .232 .743 r
.57025 .71456 m .56214 .70598 L p .57419 .72661 L F P
0 g
s
0 .232 .743 r
.57419 .72661 m .57333 .72076 L .57025 .71456 L p F P
0 g
s
0 .091 .65 r
.56214 .70598 m .57025 .71456 L .56249 .70006 L p F P
0 g
s
0 .091 .65 r
.56249 .70006 m .55946 .69647 L .56214 .70598 L p F P
0 g
s
0 .085 .644 r
.56214 .70598 m .55946 .69647 L .55016 .68533 L p F P
0 g
s
.336 .44 .82 r
.58713 .74698 m .60417 .75628 L .60252 .76667 L p F P
0 g
s
.141 .354 .813 r
.58834 .7366 m .58713 .74698 L .60417 .75628 L p F P
0 g
s
.277 .409 .816 r
.57798 .73008 m .58834 .7366 L .58713 .74698 L p F P
0 g
s
0 .028 .592 r
.54633 .67604 m .55016 .68533 L .55946 .69647 L p F P
0 g
s
0 0 .569 r
.55016 .68533 m .54633 .67604 L .53779 .66479 L p F P
0 g
s
.643 .851 .979 r
.75845 .82869 m .72838 .84085 L .72145 .83356 L p F P
0 g
s
.459 .605 .908 r
.67228 .8289 m .68397 .82915 L .67669 .81877 L p F P
0 g
s
.459 .605 .908 r
.67669 .81877 m .67523 .81863 L .67228 .8289 L p F P
0 g
s
.132 .419 .863 r
.74492 .54134 m .74401 .54088 L .74246 .53753 L closepath p F P
0 g
s
.232 .494 .897 r
.74401 .54088 m .74246 .53753 L .73793 .53076 L p F P
0 g
s
0 0 .298 r
.83318 .70248 m .83346 .69808 L .83086 .68463 L p F P
0 g
s
0 0 .257 r
.83088 .67463 m .83086 .68463 L .83346 .69808 L p F P
0 g
s
0 0 .456 r
.82627 .66183 m .83088 .67463 L .83086 .68463 L p F P
0 g
s
.383 .468 .823 r
.60252 .76667 m .62159 .77555 L .62002 .78578 L p F P
0 g
s
.248 .438 .852 r
.60417 .75628 m .60252 .76667 L .62159 .77555 L p F P
0 g
s
.16 .424 .862 r
.74492 .54134 m .76073 .54931 L .76453 .55892 L p F P
0 g
s
.13 .417 .862 r
.76073 .54931 m .74492 .54134 L .74246 .53753 L p F P
0 g
s
.248 .544 .926 r
.68671 .49907 m .69243 .50065 L .68531 .49148 L p F P
0 g
s
.248 .544 .926 r
.68531 .49148 m .67998 .49002 L .68671 .49907 L p F P
0 g
s
0 .196 .72 r
.8094 .61834 m .80577 .61466 L .79861 .59926 L p F P
0 g
s
.279 .434 .838 r
.62002 .78578 m .63129 .79006 L .62372 .77657 L p F P
0 g
s
.279 .434 .838 r
.62372 .77657 m .62159 .77555 L .62002 .78578 L p F P
0 g
s
.488 .585 .878 r
.64047 .80624 m .64174 .80377 L p .67523 .81863 L F P
0 g
s
.459 .57 .879 r
.64047 .80624 m .63882 .80339 L .64174 .80377 L closepath p F P
0 g
s
0 0 .4 r
.82564 .65188 m .82627 .66183 L .83088 .67463 L p F P
0 g
s
0 0 .557 r
.8191 .63973 m .82564 .65188 L .82627 .66183 L p F P
0 g
s
.084 .351 .822 r
.78215 .5779 m .77902 .56819 L .76453 .55892 L p F P
0 g
s
.052 .343 .82 r
.76073 .54931 m .76453 .55892 L .77902 .56819 L p F P
0 g
s
.194 .368 .809 r
.58834 .7366 m .57798 .73008 L .57333 .72076 L p F P
0 g
s
0 0 .09 r
.83346 .69808 m .83318 .70248 L .83369 .71557 L p F P
0 g
s
0 0 .131 r
.83285 .72235 m .83369 .71557 L .83318 .70248 L p F P
0 g
s
.463 .566 .874 r
.64174 .80377 m .63882 .80339 L .63129 .79006 L p F P
0 g
s
.13 .417 .862 r
.74246 .53753 m .73956 .53138 L p .76073 .54931 L F P
0 g
s
.217 .484 .894 r
.74246 .53753 m .73793 .53076 L .73956 .53138 L closepath p F P
0 g
s
.733 .686 .142 r
.83369 .71557 m .83285 .72235 L .83059 .73732 L p F P
0 g
s
.925 .946 .603 r
.82359 .7633 m .82533 .7532 L p .81544 .77732 L F P
0 g
s
.925 .946 .603 r
.81544 .77732 m .81704 .77642 L .82359 .7633 L p F P
0 g
s
.819 .828 .353 r
.82359 .7633 m .82533 .7532 L .83059 .73732 L p F P
0 g
s
0 0 .519 r
.81782 .62983 m .8191 .63973 L .82564 .65188 L p F P
0 g
s
0 .096 .646 r
.8094 .61834 m .81782 .62983 L .8191 .63973 L p F P
0 g
s
.041 .295 .786 r
.79154 .58548 m .78215 .5779 L p .79712 .59771 L F P
0 g
s
0 .258 .766 r
.78215 .5779 m .79154 .58548 L .78451 .57269 L p F P
0 g
s
0 .258 .766 r
.78451 .57269 m .77902 .56819 L .78215 .5779 L p F P
0 g
s
.259 .538 .921 r
.69243 .50065 m .70903 .50537 L .71497 .51459 L p F P
0 g
s
.24 .539 .924 r
.70903 .50537 m .69243 .50065 L .68531 .49148 L p F P
0 g
s
.488 .585 .878 r
.64174 .80377 m .66935 .80789 L p .67523 .81863 L F P
0 g
s
.409 .535 .872 r
.64174 .80377 m .66935 .80789 L .66194 .79669 L p F P
0 g
s
.409 .535 .872 r
.66194 .79669 m .64568 .79301 L .64174 .80377 L p F P
0 g
s
.463 .566 .874 r
.63129 .79006 m .64568 .79301 L .64174 .80377 L p F P
0 g
s
.544 .731 .962 r
.68397 .82915 m .71442 .82554 L .72145 .83356 L p F P
0 g
s
.515 .702 .955 r
.71442 .82554 m .68397 .82915 L .67669 .81877 L p F P
0 g
s
0 .051 .617 r
.80748 .60851 m .8094 .61834 L .81782 .62983 L p F P
0 g
s
0 .196 .72 r
.79861 .59926 m .80748 .60851 L .8094 .61834 L p F P
0 g
s
0 .169 .705 r
.79861 .59926 m .79712 .59771 L .79637 .59464 L closepath p F P
0 g
s
.041 .295 .786 r
.79712 .59771 m .79637 .59464 L .79154 .58548 L p F P
0 g
s
.194 .368 .809 r
.57333 .72076 m .57327 .71671 L p .58834 .7366 L F P
0 g
s
.137 .33 .793 r
.57333 .72076 m .57025 .71456 L .57327 .71671 L closepath p F P
0 g
s
.174 .481 .897 r
.71497 .51459 m .73093 .52071 L .7239 .51106 L p F P
0 g
s
.174 .481 .897 r
.7239 .51106 m .70903 .50537 L .71497 .51459 L p F P
0 g
s
0 .17 .705 r
.80748 .60851 m .79861 .59926 L .79637 .59464 L p F P
0 g
s
.74 .899 .95 r
.77098 .82109 m .75845 .82869 L .75175 .82326 L p F P
0 g
s
.643 .851 .979 r
.72145 .83356 m .75175 .82326 L .75845 .82869 L p F P
0 g
s
.098 .324 .798 r
.57327 .71671 m .57025 .71456 L .56249 .70006 L p F P
0 g
s
.863 .965 .637 r
.81461 .78021 m .81544 .77732 L .81704 .77642 L closepath p F P
0 g
s
0 0 .09 r
.83369 .71557 m .8339 .71224 L .83346 .69808 L p F P
0 g
s
0 0 .04 r
.83345 .68812 m .83346 .69808 L .8339 .71224 L p F P
0 g
s
0 0 .257 r
.83346 .69808 m .83345 .68812 L .83088 .67463 L p F P
0 g
s
.638 .176 0 r
.5326 .6558 m .52562 .64726 L .51771 .63592 L p F P
0 g
s
0 .17 .705 r
.79637 .59464 m .79461 .58794 L p .80748 .60851 L F P
0 g
s
.013 .276 .776 r
.79637 .59464 m .79154 .58548 L .79461 .58794 L closepath p F P
0 g
s
.618 .817 .977 r
.75175 .82326 m .72145 .83356 L .71442 .82554 L p F P
0 g
s
.872 .991 .814 r
.81544 .77732 m .81461 .78021 L .79894 .79899 L p F P
0 g
s
.199 .485 .897 r
.73956 .53138 m .73793 .53076 L .73093 .52071 L p F P
0 g
s
.74 .899 .95 r
.75175 .82326 m .77452 .81074 L .77098 .82109 L p F P
0 g
s
.779 .955 .929 r
.78183 .80626 m .77452 .81074 L .77098 .82109 L p F P
0 g
s
.779 .955 .929 r
.77098 .82109 m .78822 .80928 L .78183 .80626 L p F P
0 g
s
.423 .541 .872 r
.64568 .79301 m .63129 .79006 L .62372 .77657 L p F P
0 g
s
0 .028 .592 r
.55472 .68699 m .54633 .67604 L p .55946 .69647 L F P
0 g
s
0 0 .465 r
.54633 .67604 m .55472 .68699 L .54693 .67563 L p F P
0 g
s
.13 .417 .862 r
.73956 .53138 m .75621 .53983 L .76073 .54931 L p F P
0 g
s
.092 .408 .86 r
.73434 .52201 m .73956 .53138 L .75621 .53983 L p F P
0 g
s
.199 .485 .897 r
.73093 .52071 m .73434 .52201 L .73956 .53138 L p F P
0 g
s
0 .035 .599 r
.56249 .70006 m .55946 .69647 L .55548 .68827 L closepath p F P
0 g
s
0 .028 .592 r
.55946 .69647 m .55548 .68827 L .55472 .68699 L p F P
0 g
s
.194 .368 .809 r
.57327 .71671 m .58715 .72679 L .58834 .7366 L p F P
0 g
s
0 .252 .764 r
.57128 .70702 m .57327 .71671 L .58715 .72679 L p F P
0 g
s
.098 .324 .798 r
.56249 .70006 m .57128 .70702 L .57327 .71671 L p F P
0 g
s
.86 .853 .396 r
.83189 .72719 m .83059 .73732 L .82533 .7532 L p F P
0 g
s
.733 .686 .142 r
.83245 .72374 m .83369 .71557 L p .83059 .73732 L F P
0 g
s
.733 .686 .142 r
.83059 .73732 m .83189 .72719 L .83245 .72374 L p F P
0 g
s
.84 .972 .881 r
.79894 .79899 m .78822 .80928 L .78183 .80626 L p F P
0 g
s
.84 .972 .881 r
.78183 .80626 m .8014 .78883 L .79894 .79899 L p F P
0 g
s
.872 .991 .814 r
.81118 .77797 m .81544 .77732 L p .79894 .79899 L F P
0 g
s
.872 .991 .814 r
.79894 .79899 m .8014 .78883 L .81118 .77797 L p F P
0 g
s
.141 .354 .813 r
.60417 .75628 m .60345 .74647 L .58834 .7366 L p F P
0 g
s
.067 .337 .814 r
.58715 .72679 m .58834 .7366 L .60345 .74647 L p F P
0 g
s
0 0 .215 r
.83023 .66471 m .83088 .67463 L .83345 .68812 L p F P
0 g
s
0 0 .4 r
.83088 .67463 m .83023 .66471 L .82564 .65188 L p F P
0 g
s
.766 .687 .141 r
.83245 .72374 m .8339 .71224 L .83369 .71557 L closepath p F P
0 g
s
.908 .981 .721 r
.81118 .77797 m .81655 .77012 L .81544 .77732 L closepath p F P
0 g
s
.925 .946 .603 r
.82533 .7532 m .81655 .77012 L .81544 .77732 L p F P
0 g
s
.452 .611 .916 r
.67669 .81877 m .67523 .81863 L .67551 .81701 L closepath p F P
0 g
s
.488 .585 .878 r
.66935 .80789 m .67551 .81701 L .67523 .81863 L p F P
0 g
s
.248 .438 .852 r
.61611 .76306 m .60417 .75628 L p .62159 .77555 L F P
0 g
s
.136 .349 .81 r
.60417 .75628 m .61611 .76306 L .60846 .74979 L p F P
0 g
s
.136 .349 .81 r
.60846 .74979 m .60345 .74647 L .60417 .75628 L p F P
0 g
s
.515 .702 .955 r
.67669 .81877 m .70731 .81691 L .71442 .82554 L p F P
0 g
s
.513 .643 .914 r
.70012 .8078 m .70731 .81691 L .67669 .81877 L p F P
0 g
s
.513 .643 .914 r
.67998 .80775 m .70012 .8078 L p .67669 .81877 L F P
0 g
s
.513 .643 .914 r
.67669 .81877 m .67551 .81701 L .67998 .80775 L p F P
0 g
s
.052 .343 .82 r
.77902 .56819 m .7752 .5586 L .76073 .54931 L p F P
0 g
s
.041 .352 .827 r
.75621 .53983 m .76073 .54931 L .7752 .5586 L p F P
0 g
s
0 .269 .773 r
.79461 .58794 m .79154 .58548 L .78451 .57269 L p F P
0 g
s
0 .264 .771 r
.57128 .70702 m .56249 .70006 L .55548 .68827 L p F P
0 g
s
.24 .539 .924 r
.68531 .49148 m .70231 .49629 L .70903 .50537 L p F P
0 g
s
0 0 .367 r
.82434 .64202 m .82564 .65188 L .83023 .66471 L p F P
0 g
s
0 0 .519 r
.82564 .65188 m .82434 .64202 L .81782 .62983 L p F P
0 g
s
.513 .644 .914 r
.67551 .81701 m .66935 .80789 L .67998 .80775 L closepath p F P
0 g
s
.246 .437 .851 r
.62372 .77657 m .62159 .77555 L .6216 .77279 L closepath p F P
0 g
s
.248 .438 .852 r
.62159 .77555 m .6216 .77279 L .61611 .76306 L p F P
0 g
s
0 .24 .756 r
.77902 .56819 m .78451 .57269 L .77748 .5605 L p F P
0 g
s
0 .24 .756 r
.77748 .5605 m .7752 .5586 L .77902 .56819 L p F P
0 g
s
0 0 .493 r
.81587 .62003 m .81782 .62983 L .82434 .64202 L p F P
0 g
s
0 .051 .617 r
.81782 .62983 m .81587 .62003 L .80748 .60851 L p F P
0 g
s
.151 .48 .898 r
.70903 .50537 m .7239 .51106 L .71683 .50183 L p F P
0 g
s
.151 .48 .898 r
.71683 .50183 m .70231 .49629 L .70903 .50537 L p F P
0 g
s
0 0 .04 r
.8339 .71224 m .83386 .70233 L .83345 .68812 L p F P
0 g
s
.855 .741 .224 r
.8339 .71224 m .83386 .70233 L p .83197 .72603 L F P
0 g
s
.855 .741 .224 r
.83197 .72603 m .83245 .72374 L .8339 .71224 L p F P
0 g
s
.423 .541 .872 r
.62372 .77657 m .64666 .78295 L .64568 .79301 L p F P
0 g
s
.377 .516 .87 r
.64666 .78295 m .62372 .77657 L .6216 .77279 L p F P
0 g
s
0 .17 .705 r
.79461 .58794 m .80488 .59878 L .80748 .60851 L p F P
0 g
s
0 .136 .683 r
.79137 .57828 m .79461 .58794 L .80488 .59878 L p F P
0 g
s
0 .269 .773 r
.78451 .57269 m .79137 .57828 L .79461 .58794 L p F P
0 g
s
0 .024 .597 r
.80488 .59878 m .80748 .60851 L .81587 .62003 L p F P
0 g
s
.922 .954 .623 r
.82655 .74315 m .82533 .7532 L .81655 .77012 L p F P
0 g
s
.86 .853 .396 r
.82533 .7532 m .82655 .74315 L .83189 .72719 L p F P
0 g
s
.175 .483 .898 r
.73434 .52201 m .73093 .52071 L .7239 .51106 L p F P
0 g
s
.342 .496 .867 r
.6216 .77279 m .61611 .76306 L .62287 .76529 L closepath p F P
0 g
s
.377 .516 .87 r
.6216 .77279 m .62287 .76529 L p .64666 .78295 L F P
0 g
s
.71 .904 .965 r
.77452 .81074 m .75175 .82326 L .74493 .81698 L p F P
0 g
s
.618 .817 .977 r
.71442 .82554 m .74493 .81698 L .75175 .82326 L p F P
0 g
s
.593 .788 .973 r
.74493 .81698 m .71442 .82554 L .70731 .81691 L p F P
0 g
s
.345 .515 .882 r
.64568 .79301 m .66194 .79669 L .65448 .78532 L p F P
0 g
s
.345 .515 .882 r
.65448 .78532 m .64666 .78295 L .64568 .79301 L p F P
0 g
s
.642 .176 0 r
.54076 .66718 m .53366 .65868 L .52562 .64726 L p F P
0 g
s
0 .264 .771 r
.55548 .68827 m .55515 .68735 L p .57128 .70702 L F P
0 g
s
0 .23 .75 r
.55548 .68827 m .55472 .68699 L .55515 .68735 L closepath p F P
0 g
s
0 0 .215 r
.83345 .68812 m .8328 .67824 L .83023 .66471 L p F P
0 g
s
.744 .584 .01 r
.8328 .67824 m .83345 .68812 L .83386 .70233 L p F P
0 g
s
.632 .166 0 r
.5391 .66628 m .53366 .65868 L .54076 .66718 L p F P
0 g
s
.092 .408 .86 r
.75621 .53983 m .75097 .53047 L .73434 .52201 L p F P
0 g
s
.064 .403 .857 r
.72839 .51278 m .73434 .52201 L .75097 .53047 L p F P
0 g
s
.175 .483 .898 r
.7239 .51106 m .72839 .51278 L .73434 .52201 L p F P
0 g
s
0 .25 .763 r
.79137 .57828 m .78451 .57269 L .77748 .5605 L p F P
0 g
s
0 .198 .724 r
.55515 .68735 m .55472 .68699 L .54693 .67563 L p F P
0 g
s
.516 .639 .91 r
.67998 .80775 m .66935 .80789 L .66194 .79669 L p F P
0 g
s
0 .264 .771 r
.55515 .68735 m .56735 .69779 L .57128 .70702 L p F P
0 g
s
0 .148 .681 r
.55002 .67837 m .55515 .68735 L .56735 .69779 L p F P
0 g
s
0 .198 .724 r
.54693 .67563 m .55002 .67837 L .55515 .68735 L p F P
0 g
s
.914 .98 .761 r
.81655 .77012 m .81118 .77797 L .80507 .77721 L p F P
0 g
s
.914 .98 .761 r
.80507 .77721 m .81752 .7602 L .81655 .77012 L p F P
0 g
s
.922 .954 .623 r
.81655 .77012 m .81752 .7602 L .82655 .74315 L p F P
0 g
s
.791 .723 .191 r
.83189 .72719 m .83197 .72603 L .83245 .72374 L closepath p F P
0 g
s
0 .252 .764 r
.58715 .72679 m .58408 .71743 L .57128 .70702 L p F P
0 g
s
0 .185 .715 r
.56735 .69779 m .57128 .70702 L .58408 .71743 L p F P
0 g
s
.71 .904 .965 r
.77734 .80344 m .77452 .81074 L p .74493 .81698 L F P
0 g
s
.76 .925 .943 r
.77452 .81074 m .77734 .80344 L .78183 .80626 L closepath p F P
0 g
s
.336 .498 .872 r
.62287 .76529 m .61611 .76306 L .60846 .74979 L p F P
0 g
s
.873 .991 .815 r
.8014 .78883 m .81118 .77797 L .80507 .77721 L p F P
0 g
s
.904 .892 .473 r
.83197 .72603 m .83189 .72719 L .82655 .74315 L p F P
0 g
s
0 0 .172 r
.82893 .65488 m .83023 .66471 L .8328 .67824 L p F P
0 g
s
0 0 .367 r
.83023 .66471 m .82893 .65488 L .82434 .64202 L p F P
0 g
s
.067 .337 .814 r
.60078 .73699 m .58715 .72679 L p .60345 .74647 L F P
0 g
s
0 .246 .76 r
.58715 .72679 m .60078 .73699 L .59307 .72486 L p F P
0 g
s
0 .246 .76 r
.59307 .72486 m .58408 .71743 L .58715 .72679 L p F P
0 g
s
.847 .93 .883 r
.77734 .80344 m .78183 .80626 L .8014 .78883 L p F P
0 g
s
.041 .352 .827 r
.77047 .549 m .75621 .53983 L p .7752 .5586 L F P
0 g
s
0 .324 .811 r
.75621 .53983 m .77047 .549 L .76348 .53856 L p F P
0 g
s
0 .324 .811 r
.76348 .53856 m .75097 .53047 L .75621 .53983 L p F P
0 g
s
.847 .93 .883 r
.8014 .78883 m .80369 .77862 L p .77734 .80344 L F P
0 g
s
.873 .991 .815 r
.80507 .77721 m .80369 .77862 L .8014 .78883 L p F P
0 g
s
.918 .862 .425 r
.82733 .7329 m .8319 .71731 L .83197 .72603 L closepath p F P
0 g
s
.855 .741 .224 r
.83386 .70233 m .8319 .71731 L .83197 .72603 L p F P
0 g
s
.904 .892 .473 r
.82733 .7329 m .83197 .72603 L p .82655 .74315 L F P
0 g
s
.068 .338 .815 r
.60846 .74979 m .60345 .74647 L .60096 .7373 L closepath p F P
0 g
s
.067 .337 .814 r
.60345 .74647 m .60096 .7373 L .60078 .73699 L p F P
0 g
s
0 0 .331 r
.82237 .63224 m .82434 .64202 L .82893 .65488 L p F P
0 g
s
0 0 .493 r
.82434 .64202 m .82237 .63224 L .81587 .62003 L p F P
0 g
s
0 .228 .748 r
.77748 .5605 m .7752 .5586 L .77105 .54992 L closepath p F P
0 g
s
.041 .352 .827 r
.7752 .5586 m .77105 .54992 L .77047 .549 L p F P
0 g
s
.464 .624 .921 r
.67998 .80775 m .70012 .8078 L .69286 .79834 L p F P
0 g
s
.464 .624 .921 r
.69286 .79834 m .68166 .79761 L .67998 .80775 L p F P
0 g
s
.516 .639 .91 r
.66194 .79669 m .68166 .79761 L .67998 .80775 L p F P
0 g
s
0 0 .464 r
.81325 .61033 m .81587 .62003 L .82237 .63224 L p F P
0 g
s
0 .024 .597 r
.81587 .62003 m .81325 .61033 L .80488 .59878 L p F P
0 g
s
0 .136 .683 r
.80488 .59878 m .8016 .58915 L .79137 .57828 L p F P
0 g
s
0 .115 .666 r
.78744 .56873 m .79137 .57828 L .8016 .58915 L p F P
0 g
s
0 .25 .763 r
.77748 .5605 m .78744 .56873 L .79137 .57828 L p F P
0 g
s
.152 .48 .898 r
.72839 .51278 m .7239 .51106 L .71683 .50183 L p F P
0 g
s
.593 .788 .973 r
.70731 .81691 m .73801 .81 L .74493 .81698 L p F P
0 g
s
.567 .761 .97 r
.73801 .81 m .70731 .81691 L .70012 .8078 L p F P
0 g
s
.377 .516 .87 r
.62287 .76529 m .64553 .77338 L .64666 .78295 L p F P
0 g
s
.248 .49 .892 r
.62251 .75539 m .62287 .76529 L .64553 .77338 L p F P
0 g
s
.336 .498 .872 r
.60846 .74979 m .62251 .75539 L .62287 .76529 L p F P
0 g
s
0 0 .574 r
.8016 .58915 m .80488 .59878 L .81325 .61033 L p F P
0 g
s
.876 .757 .25 r
.8332 .69249 m .83386 .70233 L .8319 .71731 L p F P
0 g
s
.744 .584 .01 r
.83386 .70233 m .8332 .69249 L .8328 .67824 L p F P
0 g
s
0 .23 .75 r
.78744 .56873 m .77748 .5605 L .77105 .54992 L p F P
0 g
s
.71 .904 .965 r
.74493 .81698 m .77529 .80204 L .77734 .80344 L p F P
0 g
s
.688 .876 .969 r
.77529 .80204 m .74493 .81698 L .73801 .81 L p F P
0 g
s
0 .119 .64 r
.55002 .67837 m .54693 .67563 L .5391 .66628 L p F P
0 g
s
.483 .62 .91 r
.68166 .79761 m .66194 .79669 L .65448 .78532 L p F P
0 g
s
.936 .957 .649 r
.82725 .73313 m .82655 .74315 L .81752 .7602 L p F P
0 g
s
.904 .892 .473 r
.82655 .74315 m .82725 .73313 L .82733 .7329 L p F P
0 g
s
.273 .472 .871 r
.62251 .75539 m .60846 .74979 L .60096 .7373 L p F P
0 g
s
.064 .403 .857 r
.75097 .53047 m .74502 .52124 L .72839 .51278 L p F P
0 g
s
.035 .398 .854 r
.7217 .50369 m .72839 .51278 L .74502 .52124 L p F P
0 g
s
.152 .48 .898 r
.71683 .50183 m .7217 .50369 L .72839 .51278 L p F P
0 g
s
.272 .487 .883 r
.64666 .78295 m .65448 .78532 L .64697 .77392 L p F P
0 g
s
.272 .487 .883 r
.64697 .77392 m .64553 .77338 L .64666 .78295 L p F P
0 g
s
.8 .92 .918 r
.77529 .80204 m .77756 .8004 L .77734 .80344 L closepath p F P
0 g
s
.847 .93 .883 r
.80369 .77862 m .77756 .8004 L .77734 .80344 L p F P
0 g
s
0 .148 .681 r
.56735 .69779 m .56177 .68896 L .55002 .67837 L p F P
0 g
s
0 .092 .613 r
.54306 .66984 m .55002 .67837 L .56177 .68896 L p F P
0 g
s
0 .119 .64 r
.5391 .66628 m .54306 .66984 L .55002 .67837 L p F P
0 g
s
0 0 .172 r
.8328 .67824 m .83151 .66844 L .82893 .65488 L p F P
0 g
s
.799 .618 .058 r
.83151 .66844 m .8328 .67824 L .8332 .69249 L p F P
0 g
s
0 .185 .715 r
.58408 .71743 m .57944 .70843 L .56735 .69779 L p F P
0 g
s
0 .123 .656 r
.56177 .68896 m .56735 .69779 L .57944 .70843 L p F P
0 g
s
.926 .956 .783 r
.81752 .7602 m .81797 .7503 L p .80399 .77686 L F P
0 g
s
.926 .956 .783 r
.80399 .77686 m .80507 .77721 L .81752 .7602 L p F P
0 g
s
.936 .957 .649 r
.81752 .7602 m .81797 .7503 L .82725 .73313 L p F P
0 g
s
0 .313 .802 r
.75097 .53047 m .76348 .53856 L .75649 .52866 L p F P
0 g
s
0 .313 .802 r
.75649 .52866 m .74502 .52124 L .75097 .53047 L p F P
0 g
s
0 0 .331 r
.82893 .65488 m .82698 .64513 L .82237 .63224 L p F P
0 g
s
.701 .462 0 r
.82698 .64513 m .82893 .65488 L .83151 .66844 L p F P
0 g
s
0 .182 .713 r
.58408 .71743 m .59307 .72486 L .58534 .71365 L p F P
0 g
s
0 .182 .713 r
.58534 .71365 m .57944 .70843 L .58408 .71743 L p F P
0 g
s
.962 .878 .484 r
.8319 .71731 m .83119 .70753 L p .82725 .73298 L F P
0 g
s
.962 .878 .484 r
.82725 .73298 m .82733 .7329 L .8319 .71731 L p F P
0 g
s
.876 .757 .25 r
.8319 .71731 m .83119 .70753 L .8332 .69249 L p F P
0 g
s
.785 .901 .924 r
.77756 .8004 m .77529 .80204 L .76861 .79677 L p F P
0 g
s
.688 .876 .969 r
.73801 .81 m .76861 .79677 L .77529 .80204 L p F P
0 g
s
.785 .901 .924 r
.76861 .79677 m .77758 .79078 L .77756 .8004 L p F P
0 g
s
.816 .922 .907 r
.80399 .77686 m .80369 .77862 L .77756 .8004 L p F P
0 g
s
.816 .922 .907 r
.79873 .77448 m .80399 .77686 L p .77756 .8004 L F P
0 g
s
.816 .922 .907 r
.77756 .8004 m .77758 .79078 L .79873 .77448 L p F P
0 g
s
0 .23 .75 r
.77105 .54992 m .77067 .54913 L p .78744 .56873 L F P
0 g
s
.022 .339 .82 r
.77105 .54992 m .77047 .549 L .77067 .54913 L closepath p F P
0 g
s
.273 .472 .871 r
.60096 .7373 m .60094 .73706 L p .62251 .75539 L F P
0 g
s
.241 .451 .865 r
.60096 .7373 m .60078 .73699 L .60094 .73706 L closepath p F P
0 g
s
.567 .761 .97 r
.70012 .8078 m .731 .80245 L .73801 .81 L p F P
0 g
s
.541 .738 .967 r
.731 .80245 m .70012 .8078 L .69286 .79834 L p F P
0 g
s
0 .332 .816 r
.77067 .54913 m .77047 .549 L .76348 .53856 L p F P
0 g
s
.216 .453 .872 r
.60094 .73706 m .60078 .73699 L .59307 .72486 L p F P
0 g
s
.273 .472 .871 r
.60094 .73706 m .62023 .74592 L .62251 .75539 L p F P
0 g
s
.109 .407 .858 r
.5985 .72753 m .60094 .73706 L .62023 .74592 L p F P
0 g
s
.216 .453 .872 r
.59307 .72486 m .5985 .72753 L .60094 .73706 L p F P
0 g
s
0 .23 .75 r
.77067 .54913 m .78284 .55928 L .78744 .56873 L p F P
0 g
s
0 .205 .729 r
.7654 .53978 m .77067 .54913 L .78284 .55928 L p F P
0 g
s
0 .332 .816 r
.76348 .53856 m .7654 .53978 L .77067 .54913 L p F P
0 g
s
.483 .62 .91 r
.65448 .78532 m .68084 .78805 L .68166 .79761 L p F P
0 g
s
.447 .602 .911 r
.68084 .78805 m .65448 .78532 L .64697 .77392 L p F P
0 g
s
.867 .977 .851 r
.80369 .77862 m .80399 .77686 L .80507 .77721 L closepath p F P
0 g
s
0 0 .293 r
.81976 .62256 m .82237 .63224 L .82698 .64513 L p F P
0 g
s
0 0 .464 r
.82237 .63224 m .81976 .62256 L .81325 .61033 L p F P
0 g
s
0 .115 .666 r
.8016 .58915 m .79765 .57961 L .78744 .56873 L p F P
0 g
s
0 .093 .646 r
.78284 .55928 m .78744 .56873 L .79765 .57961 L p F P
0 g
s
0 0 .432 r
.80996 .60072 m .81325 .61033 L .81976 .62256 L p F P
0 g
s
0 0 .574 r
.81325 .61033 m .80996 .60072 L .8016 .58915 L p F P
0 g
s
0 0 .548 r
.79765 .57961 m .8016 .58915 L .80996 .60072 L p F P
0 g
s
.666 .849 .97 r
.76861 .79677 m .73801 .81 L .731 .80245 L p F P
0 g
s
.885 .958 .843 r
.79873 .77448 m .80396 .76884 L .80399 .77686 L closepath p F P
0 g
s
.926 .956 .783 r
.81797 .7503 m .80396 .76884 L .80399 .77686 L p F P
0 g
s
.416 .609 .928 r
.68166 .79761 m .69286 .79834 L .68553 .78863 L p F P
0 g
s
.416 .609 .928 r
.68553 .78863 m .68084 .78805 L .68166 .79761 L p F P
0 g
s
.248 .49 .892 r
.63941 .76261 m .62251 .75539 L p .64553 .77338 L F P
0 g
s
.178 .428 .862 r
.62251 .75539 m .63941 .76261 L .63181 .75158 L p F P
0 g
s
.178 .428 .862 r
.63181 .75158 m .62023 .74592 L .62251 .75539 L p F P
0 g
s
.913 .777 .293 r
.83191 .68273 m .8332 .69249 L .83119 .70753 L p F P
0 g
s
.799 .618 .058 r
.8332 .69249 m .83191 .68273 L .83151 .66844 L p F P
0 g
s
.035 .398 .854 r
.74502 .52124 m .73834 .51213 L .7217 .50369 L p F P
0 g
s
.933 .903 .507 r
.82725 .73313 m .82725 .73298 L .82733 .7329 L closepath p F P
0 g
s
.943 .962 .694 r
.82725 .73298 m .82725 .73313 L .81797 .7503 L p F P
0 g
s
.963 .934 .62 r
.82147 .73439 m .82646 .72342 L .82725 .73298 L closepath p F P
0 g
s
.962 .878 .484 r
.83119 .70753 m .82646 .72342 L .82725 .73298 L p F P
0 g
s
.943 .962 .694 r
.82147 .73439 m .82725 .73298 L p .81797 .7503 L F P
0 g
s
0 .092 .613 r
.56177 .68896 m .55466 .68047 L .54306 .66984 L p F P
0 g
s
.248 .49 .892 r
.64697 .77392 m .64553 .77338 L .6449 .77082 L closepath p F P
0 g
s
.248 .49 .892 r
.64553 .77338 m .6449 .77082 L .63941 .76261 L p F P
0 g
s
.846 .644 .103 r
.82958 .65872 m .83151 .66844 L .83191 .68273 L p F P
0 g
s
.701 .462 0 r
.83151 .66844 m .82958 .65872 L .82698 .64513 L p F P
0 g
s
.133 .422 .865 r
.5985 .72753 m .59307 .72486 L .58534 .71365 L p F P
0 g
s
0 .123 .656 r
.57944 .70843 m .57345 .69972 L .56177 .68896 L p F P
0 g
s
0 .076 .595 r
.55466 .68047 m .56177 .68896 L .57345 .69972 L p F P
0 g
s
0 .302 .792 r
.74502 .52124 m .75649 .52866 L .74947 .51933 L p F P
0 g
s
0 .302 .792 r
.74947 .51933 m .73834 .51213 L .74502 .52124 L p F P
0 g
s
.447 .602 .911 r
.64697 .77392 m .67814 .7788 L p .68084 .78805 L F P
0 g
s
.39 .575 .912 r
.6707 .76892 m .67814 .7788 L .64697 .77392 L p F P
0 g
s
.39 .575 .912 r
.64481 .76358 m .6707 .76892 L p .64697 .77392 L F P
0 g
s
.39 .575 .912 r
.64697 .77392 m .6449 .77082 L .64481 .76358 L p F P
0 g
s
.541 .738 .967 r
.69286 .79834 m .72391 .79446 L .731 .80245 L p F P
0 g
s
.516 .718 .964 r
.72391 .79446 m .69286 .79834 L .68553 .78863 L p F P
0 g
s
0 .32 .807 r
.7654 .53978 m .76348 .53856 L .75649 .52866 L p F P
0 g
s
0 .122 .655 r
.57944 .70843 m .58534 .71365 L .57757 .70352 L p F P
0 g
s
0 .122 .655 r
.57757 .70352 m .57345 .69972 L .57944 .70843 L p F P
0 g
s
.943 .962 .694 r
.81797 .7503 m .81794 .74044 L .82147 .73439 L p F P
0 g
s
.917 .959 .798 r
.81794 .74044 m .81797 .7503 L .80396 .76884 L p F P
0 g
s
0 0 .293 r
.82698 .64513 m .82438 .63547 L .81976 .62256 L p F P
0 g
s
.754 .493 0 r
.82438 .63547 m .82698 .64513 L .82958 .65872 L p F P
0 g
s
.391 .575 .912 r
.6449 .77082 m .63941 .76261 L .64481 .76358 L closepath p F P
0 g
s
.769 .888 .93 r
.77758 .79078 m .76861 .79677 L .76181 .79079 L p F P
0 g
s
.666 .849 .97 r
.731 .80245 m .76181 .79079 L .76861 .79677 L p F P
0 g
s
0 .205 .729 r
.78284 .55928 m .77755 .54994 L .7654 .53978 L p F P
0 g
s
0 .188 .713 r
.75943 .53054 m .7654 .53978 L .77755 .54994 L p F P
0 g
s
0 .32 .807 r
.75649 .52866 m .75943 .53054 L .7654 .53978 L p F P
0 g
s
.968 .882 .499 r
.82987 .69782 m .83119 .70753 L .82646 .72342 L p F P
0 g
s
.913 .777 .293 r
.83119 .70753 m .82987 .69782 L .83191 .68273 L p F P
0 g
s
.769 .888 .93 r
.76181 .79079 m .77737 .78111 L .77758 .79078 L p F P
0 g
s
.814 .942 .91 r
.79224 .77057 m .77737 .78111 L .77758 .79078 L p F P
0 g
s
.814 .942 .91 r
.77758 .79078 m .79873 .77448 L .79224 .77057 L p F P
0 g
s
.109 .407 .858 r
.62023 .74592 m .61642 .73679 L .5985 .72753 L p F P
0 g
s
.025 .372 .84 r
.5943 .71841 m .5985 .72753 L .61642 .73679 L p F P
0 g
s
.133 .422 .865 r
.58534 .71365 m .5943 .71841 L .5985 .72753 L p F P
0 g
s
0 0 .27 r
.81649 .61296 m .81976 .62256 L .82438 .63547 L p F P
0 g
s
0 0 .432 r
.81976 .62256 m .81649 .61296 L .80996 .60072 L p F P
0 g
s
0 .093 .646 r
.79765 .57961 m .79304 .57018 L .78284 .55928 L p F P
0 g
s
0 .071 .623 r
.77755 .54994 m .78284 .55928 L .79304 .57018 L p F P
0 g
s
.645 .826 .97 r
.76181 .79079 m .731 .80245 L .72391 .79446 L p F P
0 g
s
.876 .944 .856 r
.80396 .76884 m .79873 .77448 L .79224 .77057 L p F P
0 g
s
.876 .944 .856 r
.79224 .77057 m .80339 .75919 L .80396 .76884 L p F P
0 g
s
.917 .959 .798 r
.80396 .76884 m .80339 .75919 L .81794 .74044 L p F P
0 g
s
0 0 .397 r
.80601 .5912 m .80996 .60072 L .81649 .61296 L p F P
0 g
s
0 0 .548 r
.80996 .60072 m .80601 .5912 L .79765 .57961 L p F P
0 g
s
0 0 .519 r
.79304 .57018 m .79765 .57961 L .80601 .5912 L p F P
0 g
s
.401 .618 .939 r
.68553 .78863 m .68084 .78805 L .67852 .77929 L closepath p F P
0 g
s
.447 .602 .911 r
.67814 .7788 m .67852 .77929 L .68084 .78805 L p F P
0 g
s
.093 .394 .851 r
.62023 .74592 m .63181 .75158 L .62418 .74098 L p F P
0 g
s
.093 .394 .851 r
.62418 .74098 m .61642 .73679 L .62023 .74592 L p F P
0 g
s
.943 .791 .332 r
.82999 .67304 m .83191 .68273 L .82987 .69782 L p F P
0 g
s
.846 .644 .103 r
.83191 .68273 m .82999 .67304 L .82958 .65872 L p F P
0 g
s
.04 .389 .849 r
.5943 .71841 m .58534 .71365 L .57757 .70352 L p F P
0 g
s
.383 .579 .918 r
.64481 .76358 m .63941 .76261 L .63181 .75158 L p F P
0 g
s
.976 .922 .649 r
.82646 .72342 m .82506 .71378 L p .81756 .73412 L F P
0 g
s
.976 .922 .649 r
.81756 .73412 m .82147 .73439 L .82646 .72342 L p F P
0 g
s
.968 .882 .499 r
.82646 .72342 m .82506 .71378 L .82987 .69782 L p F P
0 g
s
.516 .718 .964 r
.68553 .78863 m .71674 .78611 L .72391 .79446 L p F P
0 g
s
.519 .68 .938 r
.7095 .77753 m .71674 .78611 L .68553 .78863 L p F P
0 g
s
.519 .68 .938 r
.67859 .77877 m .7095 .77753 L p .68553 .78863 L F P
0 g
s
.519 .68 .938 r
.68553 .78863 m .67852 .77929 L .67859 .77877 L p F P
0 g
s
0 .076 .595 r
.57345 .69972 m .56622 .69128 L .55466 .68047 L p F P
0 g
s
0 .308 .796 r
.75943 .53054 m .75649 .52866 L .74947 .51933 L p F P
0 g
s
.886 .665 .145 r
.82701 .64908 m .82958 .65872 L .82999 .67304 L p F P
0 g
s
.754 .493 0 r
.82958 .65872 m .82701 .64908 L .82438 .63547 L p F P
0 g
s
.327 .549 .913 r
.64481 .76358 m .6707 .76892 L .66321 .75916 L p F P
0 g
s
.327 .549 .913 r
.66321 .75916 m .64282 .75404 L .64481 .76358 L p F P
0 g
s
.383 .579 .918 r
.63181 .75158 m .64282 .75404 L .64481 .76358 L p F P
0 g
s
0 .075 .595 r
.57345 .69972 m .57757 .70352 L .56976 .69459 L p F P
0 g
s
0 .075 .595 r
.56976 .69459 m .56622 .69128 L .57345 .69972 L p F P
0 g
s
.95 .956 .706 r
.81794 .74044 m .81756 .73412 L .82147 .73439 L closepath p F P
0 g
s
0 .188 .713 r
.77755 .54994 m .77158 .54071 L .75943 .53054 L p F P
0 g
s
0 .171 .693 r
.75277 .52143 m .75943 .53054 L .77158 .54071 L p F P
0 g
s
0 .308 .796 r
.74947 .51933 m .75277 .52143 L .75943 .53054 L p F P
0 g
s
.754 .876 .935 r
.77737 .78111 m .76181 .79079 L .75492 .78421 L p F P
0 g
s
.645 .826 .97 r
.72391 .79446 m .75492 .78421 L .76181 .79079 L p F P
0 g
s
0 0 .27 r
.82053 .62428 m .81649 .61296 L p .8243 .63522 L F P
0 g
s
0 0 .27 r
.82438 .63547 m .8241 .63465 L .8243 .63522 L F
.8241 .63465 m .82053 .62428 L .8243 .63522 L F
.82438 .63547 m .82157 .62716 L .82053 .62428 L p F P
0 g
s
.802 .52 0 r
.82701 .64908 m .82556 .64479 L .82161 .62735 L p F P
0 g
s
.802 .52 0 r
.82161 .62735 m .82157 .62716 L p .82163 .62739 L F P
0 g
s
.802 .52 0 r
.82701 .64908 m .82161 .62735 L .82163 .62739 L F
.82157 .62716 m .82438 .63547 L .82701 .64908 L p F P
0 g
s
.911 .949 .811 r
.81756 .73412 m .81794 .74044 L .80339 .75919 L p F P
0 g
s
.625 .805 .969 r
.75492 .78421 m .72391 .79446 L .71674 .78611 L p F P
0 g
s
.982 .883 .526 r
.82793 .68818 m .82987 .69782 L .82506 .71378 L p F P
0 g
s
.943 .791 .332 r
.82987 .69782 m .82793 .68818 L .82999 .67304 L p F P
0 g
s
0 .071 .623 r
.79304 .57018 m .78775 .56085 L .77755 .54994 L p F P
0 g
s
0 .048 .596 r
.77158 .54071 m .77755 .54994 L .78775 .56085 L p F P
0 g
s
0 0 .397 r
.81649 .61296 m .81255 .60346 L .80601 .5912 L p F P
0 g
s
.718 .385 0 r
.81649 .61296 m .82053 .62428 L .81285 .60432 L p F P
0 g
s
.718 .385 0 r
.81285 .60432 m .81255 .60346 L .81649 .61296 L p F P
0 g
s
.025 .372 .84 r
.61642 .73679 m .61132 .72793 L .5943 .71841 L p F P
0 g
s
0 .341 .817 r
.58857 .70963 m .5943 .71841 L .61132 .72793 L p F P
0 g
s
.04 .389 .849 r
.57757 .70352 m .58857 .70963 L .5943 .71841 L p F P
0 g
s
0 0 .519 r
.80601 .5912 m .8014 .58178 L .79304 .57018 L p F P
0 g
s
0 0 .486 r
.78775 .56085 m .79304 .57018 L .8014 .58178 L p F P
0 g
s
.754 .876 .935 r
.75492 .78421 m .77705 .77137 L .77737 .78111 L p F P
0 g
s
.797 .918 .92 r
.78562 .76577 m .77705 .77137 L .77737 .78111 L p F P
0 g
s
.797 .918 .92 r
.77737 .78111 m .79224 .77057 L .78562 .76577 L p F P
0 g
s
0 0 .376 r
.8014 .58178 m .80601 .5912 L .81255 .60346 L p F P
0 g
s
.337 .565 .922 r
.64282 .75404 m .63181 .75158 L .62418 .74098 L p F P
0 g
s
0 .354 .821 r
.58857 .70963 m .57757 .70352 L .56976 .69459 L p F P
0 g
s
.865 .932 .866 r
.80339 .75919 m .79224 .77057 L .78562 .76577 L p F P
0 g
s
.865 .932 .866 r
.78562 .76577 m .80232 .74957 L .80339 .75919 L p F P
0 g
s
.911 .949 .811 r
.81534 .73343 m .81756 .73412 L p .80339 .75919 L F P
0 g
s
.911 .949 .811 r
.80339 .75919 m .80232 .74957 L .81534 .73343 L p F P
0 g
s
.519 .68 .938 r
.67852 .77929 m .67814 .7788 L .67859 .77877 L closepath p F P
0 g
s
.011 .361 .833 r
.61642 .73679 m .62418 .74098 L .61651 .73093 L p F P
0 g
s
.011 .361 .833 r
.61651 .73093 m .61132 .72793 L .61642 .73679 L p F P
0 g
s
.519 .68 .939 r
.67859 .77877 m .67814 .7788 L .6707 .76892 L p F P
0 g
s
.485 .66 .939 r
.67859 .77877 m .7095 .77753 L .70219 .7688 L p F P
0 g
s
.485 .66 .939 r
.70219 .7688 m .67852 .76879 L .67859 .77877 L p F P
0 g
s
.519 .68 .939 r
.6707 .76892 m .67852 .76879 L .67859 .77877 L p F P
0 g
s
.965 .799 .365 r
.82743 .66343 m .82999 .67304 L .82793 .68818 L p F P
0 g
s
.886 .665 .145 r
.82999 .67304 m .82743 .66343 L .82701 .64908 L p F P
0 g
s
.976 .922 .649 r
.82506 .71378 m .81701 .73072 L .81756 .73412 L p F P
0 g
s
.974 .923 .67 r
.82304 .7042 m .82506 .71378 L .81701 .73072 L p F P
0 g
s
.982 .883 .526 r
.82506 .71378 m .82304 .7042 L .82793 .68818 L p F P
0 g
s
.95 .944 .736 r
.81534 .73343 m .81701 .73072 L .81756 .73412 L closepath p F P
0 g
s
.918 .682 .187 r
.82556 .64479 m .82701 .64908 L .82743 .66343 L p F P
0 g
s
0 .171 .693 r
.77158 .54071 m .76493 .5316 L .75277 .52143 L p F P
0 g
s
.826 .538 0 r
.82111 .6259 m .82157 .62716 L .82556 .64479 L p F P
0 g
s
.669 .351 0 r
.82157 .62716 m .82053 .62428 L .82111 .6259 L closepath p F P
0 g
s
.275 .536 .917 r
.64282 .75404 m .66321 .75916 L .65567 .74959 L p F P
0 g
s
.275 .536 .917 r
.65567 .74959 m .63919 .74486 L .64282 .75404 L p F P
0 g
s
.337 .565 .922 r
.62418 .74098 m .63919 .74486 L .64282 .75404 L p F P
0 g
s
.708 .373 0 r
.82111 .6259 m .82053 .62428 L .81285 .60432 L p F P
0 g
s
.625 .805 .969 r
.71674 .78611 m .74794 .77714 L .75492 .78421 L p F P
0 g
s
.606 .788 .968 r
.74794 .77714 m .71674 .78611 L .7095 .77753 L p F P
0 g
s
.74 .866 .939 r
.77705 .77137 m .75492 .78421 L .74794 .77714 L p F P
0 g
s
.826 .538 0 r
.82556 .64479 m .82366 .63956 L .82111 .6259 L p F P
0 g
s
.864 .56 .036 r
.81704 .61646 m .82111 .6259 L .82366 .63956 L p F P
0 g
s
.708 .373 0 r
.81285 .60432 m .81704 .61646 L .82111 .6259 L p F P
0 g
s
.288 .553 .925 r
.63919 .74486 m .62418 .74098 L .61651 .73093 L p F P
0 g
s
0 .048 .596 r
.78775 .56085 m .78178 .55163 L .77158 .54071 L p F P
0 g
s
0 .025 .566 r
.76493 .5316 m .77158 .54071 L .78178 .55163 L p F P
0 g
s
0 .341 .817 r
.61132 .72793 m .60509 .7193 L .58857 .70963 L p F P
0 g
s
0 .319 .795 r
.58145 .70116 m .58857 .70963 L .60509 .7193 L p F P
0 g
s
0 .354 .821 r
.56976 .69459 m .58145 .70116 L .58857 .70963 L p F P
0 g
s
.945 .933 .754 r
.81701 .73072 m .81534 .73343 L .80897 .73038 L p F P
0 g
s
.945 .933 .754 r
.80897 .73038 m .81483 .72125 L .81701 .73072 L p F P
0 g
s
.974 .923 .67 r
.81701 .73072 m .81483 .72125 L .82304 .7042 L p F P
0 g
s
.764 .412 0 r
.81285 .60432 m .81255 .60346 L .8121 .60252 L closepath p F P
0 g
s
0 0 .376 r
.81255 .60346 m .80559 .58976 L .80169 .58235 L F
.81255 .60346 m .8121 .60252 L .80559 .58976 L p F P
0 g
s
0 0 .486 r
.8014 .58178 m .79612 .57247 L .78775 .56085 L p F P
0 g
s
0 0 .344 r
.8121 .60252 m .80559 .58976 L .80787 .59409 L closepath p F P
0 g
s
.652 .256 0 r
.80559 .58976 m .79843 .57693 L p .80773 .59384 L F P
0 g
s
.652 .256 0 r
.80787 .59409 m .80559 .58976 L p .80773 .59384 L F P
0 g
s
0 0 .376 r
.80559 .58976 m .8014 .58178 L p .80169 .58235 L F P
0 g
s
.99 .88 .548 r
.82537 .67861 m .82793 .68818 L .82304 .7042 L p F P
0 g
s
.965 .799 .365 r
.82793 .68818 m .82537 .67861 L .82743 .66343 L p F P
0 g
s
0 0 .449 r
.78178 .55163 m .78775 .56085 L .79612 .57247 L p F P
0 g
s
.911 .951 .81 r
.80232 .74957 m .81534 .73343 L .80897 .73038 L p F P
0 g
s
.659 .264 0 r
.8014 .58178 m .80559 .58976 L .79843 .57693 L p F P
0 g
s
.659 .264 0 r
.79843 .57693 m .79612 .57247 L .8014 .58178 L p F P
0 g
s
.765 .413 0 r
.81704 .61646 m .81285 .60432 L .8121 .60252 L p F P
0 g
s
.765 .413 0 r
.8121 .60252 m .80787 .59409 L p .81704 .61646 L F P
0 g
s
.93 .685 .201 r
.82366 .63956 m .82556 .64479 L .8253 .65708 L p F P
0 g
s
.918 .682 .187 r
.82743 .66343 m .8253 .65708 L .82556 .64479 L p F P
0 g
s
.492 .672 .944 r
.67852 .76879 m .6707 .76892 L .66321 .75916 L p F P
0 g
s
.74 .866 .939 r
.74794 .77714 m .77671 .76153 L .77705 .77137 L p F P
0 g
s
.78 .897 .926 r
.77888 .76022 m .77671 .76153 L .77705 .77137 L p F P
0 g
s
.78 .897 .926 r
.77705 .77137 m .78562 .76577 L .77888 .76022 L p F P
0 g
s
.855 .919 .874 r
.80232 .74957 m .78562 .76577 L .77888 .76022 L p F P
0 g
s
.855 .919 .874 r
.77888 .76022 m .80074 .73999 L .80232 .74957 L p F P
0 g
s
.911 .951 .81 r
.80897 .73038 m .80074 .73999 L .80232 .74957 L p F P
0 g
s
0 .331 .81 r
.61132 .72793 m .61651 .73093 L .60879 .72152 L p F P
0 g
s
0 .331 .81 r
.60879 .72152 m .60509 .7193 L .61132 .72793 L p F P
0 g
s
.983 .805 .402 r
.8253 .65708 m .82743 .66343 L .82537 .67861 L p F P
0 g
s
.453 .656 .947 r
.67852 .76879 m .70219 .7688 L .69483 .76 L p F P
0 g
s
.453 .656 .947 r
.69483 .76 m .67612 .75935 L .67852 .76879 L p F P
0 g
s
.492 .672 .944 r
.66321 .75916 m .67612 .75935 L .67852 .76879 L p F P
0 g
s
.974 .914 .682 r
.82041 .6947 m .82304 .7042 L .81483 .72125 L p F P
0 g
s
.99 .88 .548 r
.82304 .7042 m .82041 .6947 L .82537 .67861 L p F P
0 g
s
.93 .685 .201 r
.8253 .65708 m .82414 .65394 L .82366 .63956 L p F P
0 g
s
.952 .695 .24 r
.81956 .63016 m .82366 .63956 L .82414 .65394 L p F P
0 g
s
.864 .56 .036 r
.82366 .63956 m .81956 .63016 L .81704 .61646 L p F P
0 g
s
.606 .788 .968 r
.7095 .77753 m .74087 .76968 L .74794 .77714 L p F P
0 g
s
.589 .774 .968 r
.74087 .76968 m .7095 .77753 L .70219 .7688 L p F P
0 g
s
.288 .553 .925 r
.61651 .73093 m .63422 .73595 L .63919 .74486 L p F P
0 g
s
.238 .541 .925 r
.63422 .73595 m .61651 .73093 L .60879 .72152 L p F P
0 g
s
.724 .864 .948 r
.77671 .76153 m .74794 .77714 L .74087 .76968 L p F P
0 g
s
.225 .523 .916 r
.63919 .74486 m .65567 .74959 L .64808 .7403 L p F P
0 g
s
.225 .523 .916 r
.64808 .7403 m .63422 .73595 L .63919 .74486 L p F P
0 g
s
0 .025 .566 r
.78178 .55163 m .77514 .54252 L .76493 .5316 L p F P
0 g
s
.895 .577 .08 r
.81233 .60712 m .81704 .61646 L .81956 .63016 L p F P
0 g
s
.765 .413 0 r
.80787 .59409 m .81233 .60712 L .81704 .61646 L p F P
0 g
s
0 .319 .795 r
.60509 .7193 m .59782 .71088 L .58145 .70116 L p F P
0 g
s
.464 .665 .949 r
.67612 .75935 m .66321 .75916 L .65567 .74959 L p F P
0 g
s
0 0 .449 r
.79612 .57247 m .79016 .56325 L .78178 .55163 L p F P
0 g
s
.578 .133 0 r
.77514 .54252 m .78178 .55163 L .79016 .56325 L p F P
0 g
s
.813 .443 0 r
.80252 .58481 m .80787 .59409 L .81233 .60712 L p F P
0 g
s
.652 .256 0 r
.79843 .57693 m .80252 .58481 L .80787 .59409 L p F P
0 g
s
.707 .294 0 r
.79612 .57247 m .79843 .57693 L .79134 .56556 L p F P
0 g
s
.707 .294 0 r
.79134 .56556 m .79016 .56325 L .79612 .57247 L p F P
0 g
s
.939 .921 .767 r
.81483 .72125 m .80897 .73038 L .80244 .72624 L p F P
0 g
s
.939 .921 .767 r
.80244 .72624 m .81204 .71184 L .81483 .72125 L p F P
0 g
s
.974 .914 .682 r
.81483 .72125 m .81204 .71184 L .82041 .6947 L p F P
0 g
s
.994 .873 .566 r
.82216 .66913 m .82537 .67861 L .82041 .6947 L p F P
0 g
s
.983 .805 .402 r
.82351 .65964 m .8253 .65708 L p .82537 .67861 L F P
0 g
s
.983 .805 .402 r
.82537 .67861 m .82216 .66913 L .82351 .65964 L p F P
0 g
s
.982 .787 .379 r
.82351 .65964 m .82414 .65394 L .8253 .65708 L closepath p F P
0 g
s
.901 .933 .826 r
.80074 .73999 m .80897 .73038 L .80244 .72624 L p F P
0 g
s
0 .308 .787 r
.60509 .7193 m .60879 .72152 L .60104 .71283 L p F P
0 g
s
0 .308 .787 r
.60104 .71283 m .59782 .71088 L .60509 .7193 L p F P
0 g
s
.724 .864 .948 r
.77644 .75803 m .77671 .76153 L p .74087 .76968 L F P
0 g
s
.763 .878 .93 r
.77671 .76153 m .77644 .75803 L .77888 .76022 L closepath p F P
0 g
s
.849 .887 .866 r
.80074 .73999 m .79862 .73046 L p .77644 .75803 L F P
0 g
s
.849 .887 .866 r
.77644 .75803 m .77888 .76022 L .80074 .73999 L p F P
0 g
s
.901 .933 .826 r
.80244 .72624 m .79862 .73046 L .80074 .73999 L p F P
0 g
s
.702 .288 0 r
.80252 .58481 m .79843 .57693 L .79134 .56556 L p F P
0 g
s
.994 .785 .413 r
.82414 .65394 m .82001 .64458 L p .81941 .66243 L F P
0 g
s
.994 .785 .413 r
.81941 .66243 m .82351 .65964 L .82414 .65394 L p F P
0 g
s
.952 .695 .24 r
.82414 .65394 m .82001 .64458 L .81956 .63016 L p F P
0 g
s
.238 .541 .925 r
.60879 .72152 m .62809 .72729 L .63422 .73595 L p F P
0 g
s
.188 .532 .923 r
.62809 .72729 m .60879 .72152 L .60104 .71283 L p F P
0 g
s
.423 .651 .953 r
.67612 .75935 m .69483 .76 L .6874 .75121 L p F P
0 g
s
.423 .651 .953 r
.6874 .75121 m .67211 .75026 L .67612 .75935 L p F P
0 g
s
.464 .665 .949 r
.65567 .74959 m .67211 .75026 L .67612 .75935 L p F P
0 g
s
.589 .774 .968 r
.70219 .7688 m .73372 .76192 L .74087 .76968 L p F P
0 g
s
.574 .763 .968 r
.73372 .76192 m .70219 .7688 L .69483 .76 L p F P
0 g
s
.971 .903 .691 r
.81715 .68528 m .82041 .6947 L .81204 .71184 L p F P
0 g
s
.994 .873 .566 r
.82041 .6947 m .81715 .68528 L .82216 .66913 L p F P
0 g
s
.993 .804 .429 r
.82216 .66913 m .81941 .66243 L .82351 .65964 L closepath p F P
0 g
s
.967 .7 .274 r
.81483 .62085 m .81956 .63016 L .82001 .64458 L p F P
0 g
s
.895 .577 .08 r
.81956 .63016 m .81483 .62085 L .81233 .60712 L p F P
0 g
s
.812 .881 .895 r
.77202 .75396 m .7744 .75213 L .77644 .75803 L closepath p F P
0 g
s
.849 .887 .866 r
.79862 .73046 m .7744 .75213 L .77644 .75803 L p F P
0 g
s
.724 .864 .948 r
.74087 .76968 m .77202 .75396 L .77644 .75803 L p F P
0 g
s
.71 .849 .948 r
.77202 .75396 m .74087 .76968 L .73372 .76192 L p F P
0 g
s
.182 .513 .914 r
.63422 .73595 m .64808 .7403 L .64044 .73136 L p F P
0 g
s
.182 .513 .914 r
.64044 .73136 m .62809 .72729 L .63422 .73595 L p F P
0 g
s
.438 .661 .955 r
.67211 .75026 m .65567 .74959 L .64808 .7403 L p F P
0 g
s
.918 .589 .12 r
.80696 .59786 m .81233 .60712 L .81483 .62085 L p F P
0 g
s
.813 .443 0 r
.81233 .60712 m .80696 .59786 L .80252 .58481 L p F P
0 g
s
.578 .133 0 r
.79016 .56325 m .78352 .55415 L .77514 .54252 L p F P
0 g
s
.844 .461 0 r
.79652 .57562 m .80252 .58481 L .80696 .59786 L p F P
0 g
s
.702 .288 0 r
.79134 .56556 m .79652 .57562 L .80252 .58481 L p F P
0 g
s
.746 .318 0 r
.79016 .56325 m .79134 .56556 L .78432 .55572 L p F P
0 g
s
.746 .318 0 r
.78432 .55572 m .78352 .55415 L .79016 .56325 L p F P
0 g
s
.995 .865 .584 r
.81941 .66243 m .82216 .66913 L .81715 .68528 L p F P
0 g
s
.933 .899 .769 r
.81204 .71184 m .80863 .70251 L p .79602 .72136 L F P
0 g
s
.933 .899 .769 r
.79602 .72136 m .80244 .72624 L .81204 .71184 L p F P
0 g
s
.971 .903 .691 r
.81204 .71184 m .80863 .70251 L .81715 .68528 L p F P
0 g
s
.744 .315 0 r
.79652 .57562 m .79134 .56556 L .78432 .55572 L p F P
0 g
s
.803 .871 .897 r
.7744 .75213 m .77202 .75396 L .76506 .74716 L p F P
0 g
s
.71 .849 .948 r
.73372 .76192 m .76506 .74716 L .77202 .75396 L p F P
0 g
s
.889 .916 .837 r
.79862 .73046 m .79602 .72136 L .80244 .72624 L closepath p F P
0 g
s
.803 .871 .897 r
.76506 .74716 m .77064 .74303 L .7744 .75213 L p F P
0 g
s
.837 .884 .875 r
.79602 .72136 m .79862 .73046 L .7744 .75213 L p F P
0 g
s
.837 .884 .875 r
.79577 .72114 m .79602 .72136 L p .7744 .75213 L F P
0 g
s
.837 .884 .875 r
.7744 .75213 m .77064 .74303 L .79577 .72114 L p F P
0 g
s
.994 .785 .413 r
.82001 .64458 m .81821 .65975 L .81941 .66243 L p F P
0 g
s
.997 .786 .438 r
.81525 .6353 m .82001 .64458 L .81821 .65975 L p F P
0 g
s
.967 .7 .274 r
.82001 .64458 m .81525 .6353 L .81483 .62085 L p F P
0 g
s
.574 .763 .968 r
.69483 .76 m .7265 .75392 L .73372 .76192 L p F P
0 g
s
.562 .755 .968 r
.7265 .75392 m .69483 .76 L .6874 .75121 L p F P
0 g
s
.188 .532 .923 r
.60104 .71283 m .62087 .71884 L .62809 .72729 L p F P
0 g
s
.398 .647 .957 r
.67211 .75026 m .6874 .75121 L .67991 .74247 L p F P
0 g
s
.398 .647 .957 r
.67991 .74247 m .66688 .74141 L .67211 .75026 L p F P
0 g
s
.438 .661 .955 r
.64808 .7403 m .66688 .74141 L .67211 .75026 L p F P
0 g
s
.968 .891 .698 r
.81323 .67594 m .81715 .68528 L .80863 .70251 L p F P
0 g
s
.995 .865 .584 r
.81762 .66208 m .81941 .66243 L p .81715 .68528 L F P
0 g
s
.995 .865 .584 r
.81715 .68528 m .81323 .67594 L .81762 .66208 L p F P
0 g
s
.413 .659 .961 r
.66688 .74141 m .64808 .7403 L .64044 .73136 L p F P
0 g
s
.977 .702 .304 r
.80945 .61163 m .81483 .62085 L .81525 .6353 L p F P
0 g
s
.918 .589 .12 r
.81483 .62085 m .80945 .61163 L .80696 .59786 L p F P
0 g
s
.699 .835 .948 r
.76506 .74716 m .73372 .76192 L .7265 .75392 L p F P
0 g
s
.147 .508 .911 r
.62809 .72729 m .64044 .73136 L .63275 .7228 L p F P
0 g
s
.147 .508 .911 r
.63275 .7228 m .62087 .71884 L .62809 .72729 L p F P
0 g
s
.999 .843 .54 r
.81762 .66208 m .81821 .65975 L .81941 .66243 L closepath p F P
0 g
s
.934 .597 .157 r
.80095 .5887 m .80696 .59786 L .80945 .61163 L p F P
0 g
s
.844 .461 0 r
.80696 .59786 m .80095 .5887 L .79652 .57562 L p F P
0 g
s
.867 .475 .002 r
.78987 .56654 m .79652 .57562 L .80095 .5887 L p F P
0 g
s
.744 .315 0 r
.78432 .55572 m .78987 .56654 L .79652 .57562 L p F P
0 g
s
.997 .836 .56 r
.81821 .65975 m .81762 .66208 L .8112 .65896 L p F P
0 g
s
.997 .836 .56 r
.8112 .65896 m .81341 .65053 L .81821 .65975 L p F P
0 g
s
.997 .786 .438 r
.81821 .65975 m .81341 .65053 L .81525 .6353 L p F P
0 g
s
.933 .899 .769 r
.80863 .70251 m .79588 .721 L .79602 .72136 L p F P
0 g
s
.925 .893 .779 r
.80459 .69326 m .80863 .70251 L .79588 .721 L p F P
0 g
s
.968 .891 .698 r
.80863 .70251 m .80459 .69326 L .81323 .67594 L p F P
0 g
s
.993 .856 .594 r
.81323 .67594 m .81762 .66208 L .8112 .65896 L p F P
0 g
s
.562 .755 .968 r
.6874 .75121 m .71921 .74574 L .7265 .75392 L p F P
0 g
s
.553 .749 .968 r
.71921 .74574 m .6874 .75121 L .67991 .74247 L p F P
0 g
s
.795 .862 .899 r
.77064 .74303 m .76506 .74716 L .75802 .73994 L p F P
0 g
s
.699 .835 .948 r
.7265 .75392 m .75802 .73994 L .76506 .74716 L p F P
0 g
s
.795 .862 .899 r
.75802 .73994 m .76631 .73399 L .77064 .74303 L p F P
0 g
s
.839 .894 .879 r
.78895 .71499 m .76631 .73399 L .77064 .74303 L p F P
0 g
s
.839 .894 .879 r
.77064 .74303 m .79577 .72114 L .78895 .71499 L p F P
0 g
s
.998 .779 .457 r
.80985 .62612 m .81525 .6353 L .81341 .65053 L p F P
0 g
s
.977 .702 .304 r
.81525 .6353 m .80985 .62612 L .80945 .61163 L p F P
0 g
s
.901 .902 .816 r
.79577 .72114 m .79588 .721 L .79602 .72136 L closepath p F P
0 g
s
.894 .89 .82 r
.79588 .721 m .79577 .72114 L .78895 .71499 L p F P
0 g
s
.894 .89 .82 r
.78895 .71499 m .79159 .71187 L .79588 .721 L p F P
0 g
s
.925 .893 .779 r
.79588 .721 m .79159 .71187 L .80459 .69326 L p F P
0 g
s
.413 .659 .961 r
.64044 .73136 m .66062 .73276 L .66688 .74141 L p F P
0 g
s
.391 .66 .966 r
.66062 .73276 m .64044 .73136 L .63275 .7228 L p F P
0 g
s
.379 .645 .961 r
.66688 .74141 m .67991 .74247 L .67237 .73385 L p F P
0 g
s
.379 .645 .961 r
.67237 .73385 m .66062 .73276 L .66688 .74141 L p F P
0 g
s
.69 .824 .947 r
.75802 .73994 m .7265 .75392 L .71921 .74574 L p F P
0 g
s
.982 .7 .33 r
.80342 .60249 m .80945 .61163 L .80985 .62612 L p F P
0 g
s
.934 .597 .157 r
.80945 .61163 m .80342 .60249 L .80095 .5887 L p F P
0 g
s
.963 .878 .703 r
.80864 .66669 m .81323 .67594 L .80459 .69326 L p F P
0 g
s
.993 .856 .594 r
.8112 .65896 m .80864 .66669 L .81323 .67594 L p F P
0 g
s
.944 .601 .19 r
.79428 .57964 m .80095 .5887 L .80342 .60249 L p F P
0 g
s
.867 .475 .002 r
.80095 .5887 m .79428 .57964 L .78987 .56654 L p F P
0 g
s
.993 .826 .575 r
.81341 .65053 m .8112 .65896 L .80455 .65403 L p F P
0 g
s
.993 .826 .575 r
.80455 .65403 m .80797 .64138 L .81341 .65053 L p F P
0 g
s
.998 .779 .457 r
.81341 .65053 m .80797 .64138 L .80985 .62612 L p F P
0 g
s
.92 .881 .78 r
.79988 .68409 m .80459 .69326 L .79159 .71187 L p F P
0 g
s
.963 .878 .703 r
.80459 .69326 m .79988 .68409 L .80864 .66669 L p F P
0 g
s
.553 .749 .968 r
.67991 .74247 m .71185 .73745 L .71921 .74574 L p F P
0 g
s
.547 .746 .969 r
.71185 .73745 m .67991 .74247 L .67237 .73385 L p F P
0 g
s
.789 .854 .899 r
.76631 .73399 m .75802 .73994 L .75088 .73235 L p F P
0 g
s
.69 .824 .947 r
.71921 .74574 m .75088 .73235 L .75802 .73994 L p F P
0 g
s
.996 .77 .473 r
.8038 .61702 m .80985 .62612 L .80797 .64138 L p F P
0 g
s
.982 .7 .33 r
.80985 .62612 m .8038 .61702 L .80342 .60249 L p F P
0 g
s
.987 .844 .613 r
.80864 .66669 m .8112 .65896 L .80455 .65403 L p F P
0 g
s
.789 .854 .899 r
.75088 .73235 m .76137 .72502 L .76631 .73399 L p F P
0 g
s
.829 .879 .88 r
.78202 .7082 m .76137 .72502 L .76631 .73399 L p F P
0 g
s
.829 .879 .88 r
.76631 .73399 m .78895 .71499 L .78202 .7082 L p F P
0 g
s
.391 .66 .966 r
.63275 .7228 m .65341 .72428 L .66062 .73276 L p F P
0 g
s
.887 .879 .821 r
.79159 .71187 m .78895 .71499 L .78202 .7082 L p F P
0 g
s
.887 .879 .821 r
.78202 .7082 m .78667 .70282 L .79159 .71187 L p F P
0 g
s
.92 .881 .78 r
.79159 .71187 m .78667 .70282 L .79988 .68409 L p F P
0 g
s
.684 .815 .946 r
.75088 .73235 m .71921 .74574 L .71185 .73745 L p F P
0 g
s
.365 .647 .964 r
.66062 .73276 m .67237 .73385 L .66477 .72537 L p F P
0 g
s
.365 .647 .964 r
.66477 .72537 m .65341 .72428 L .66062 .73276 L p F P
0 g
s
.983 .695 .353 r
.79673 .59346 m .80342 .60249 L .8038 .61702 L p F P
0 g
s
.944 .601 .19 r
.80342 .60249 m .79673 .59346 L .79428 .57964 L p F P
0 g
s
.957 .864 .707 r
.80335 .65755 m .80864 .66669 L .79988 .68409 L p F P
0 g
s
.987 .844 .613 r
.80455 .65403 m .80335 .65755 L .80864 .66669 L p F P
0 g
s
.987 .815 .586 r
.80797 .64138 m .80455 .65403 L .79771 .64746 L p F P
0 g
s
.987 .815 .586 r
.79771 .64746 m .80188 .63233 L .80797 .64138 L p F P
0 g
s
.996 .77 .473 r
.80797 .64138 m .80188 .63233 L .8038 .61702 L p F P
0 g
s
.957 .864 .707 r
.79988 .68409 m .7945 .67502 L .80335 .65755 L p F P
0 g
s
.914 .869 .78 r
.7945 .67502 m .79988 .68409 L .78667 .70282 L p F P
0 g
s
.547 .746 .969 r
.67237 .73385 m .70442 .72906 L .71185 .73745 L p F P
0 g
s
.545 .745 .969 r
.70442 .72906 m .67237 .73385 L .66477 .72537 L p F P
0 g
s
.784 .846 .898 r
.76137 .72502 m .75088 .73235 L .74367 .72446 L p F P
0 g
s
.684 .815 .946 r
.71185 .73745 m .74367 .72446 L .75088 .73235 L p F P
0 g
s
.991 .76 .487 r
.79709 .60802 m .8038 .61702 L .80188 .63233 L p F P
0 g
s
.983 .695 .353 r
.8038 .61702 m .79709 .60802 L .79673 .59346 L p F P
0 g
s
.784 .846 .898 r
.74367 .72446 m .75578 .71613 L .76137 .72502 L p F P
0 g
s
.82 .865 .88 r
.77499 .70082 m .75578 .71613 L .76137 .72502 L p F P
0 g
s
.82 .865 .88 r
.76137 .72502 m .78202 .7082 L .77499 .70082 L p F P
0 g
s
.68 .808 .944 r
.74367 .72446 m .71185 .73745 L .70442 .72906 L p F P
0 g
s
.881 .868 .821 r
.78667 .70282 m .78202 .7082 L .77499 .70082 L p F P
0 g
s
.881 .868 .821 r
.77499 .70082 m .7811 .69386 L .78667 .70282 L p F P
0 g
s
.914 .869 .78 r
.78667 .70282 m .7811 .69386 L .7945 .67502 L p F P
0 g
s
.979 .831 .626 r
.80335 .65755 m .80455 .65403 L .79771 .64746 L p F P
0 g
s
.95 .85 .708 r
.79735 .64851 m .80335 .65755 L .7945 .67502 L p F P
0 g
s
.979 .831 .626 r
.79771 .64746 m .79735 .64851 L .80335 .65755 L p F P
0 g
s
.98 .802 .593 r
.80188 .63233 m .79771 .64746 L .79069 .63935 L p F P
0 g
s
.98 .802 .593 r
.79069 .63935 m .79514 .62337 L .80188 .63233 L p F P
0 g
s
.991 .76 .487 r
.80188 .63233 m .79514 .62337 L .79709 .60802 L p F P
0 g
s
.545 .745 .969 r
.66477 .72537 m .69693 .7206 L .70442 .72906 L p F P
0 g
s
.909 .857 .779 r
.78841 .66605 m .7945 .67502 L .7811 .69386 L p F P
0 g
s
.95 .85 .708 r
.7945 .67502 m .78841 .66605 L .79735 .64851 L p F P
0 g
s
.781 .84 .897 r
.75578 .71613 m .74367 .72446 L .73637 .71627 L p F P
0 g
s
.68 .808 .944 r
.70442 .72906 m .73637 .71627 L .74367 .72446 L p F P
0 g
s
.679 .803 .941 r
.73637 .71627 m .70442 .72906 L .69693 .7206 L p F P
0 g
s
.781 .84 .897 r
.73637 .71627 m .74951 .70734 L .75578 .71613 L p F P
0 g
s
.813 .852 .878 r
.76786 .6929 m .74951 .70734 L .75578 .71613 L p F P
0 g
s
.813 .852 .878 r
.75578 .71613 m .77499 .70082 L .76786 .6929 L p F P
0 g
s
.875 .857 .82 r
.7811 .69386 m .77499 .70082 L .76786 .6929 L p F P
0 g
s
.875 .857 .82 r
.76786 .6929 m .77487 .68498 L .7811 .69386 L p F P
0 g
s
.909 .857 .779 r
.7811 .69386 m .77487 .68498 L .78841 .66605 L p F P
0 g
s
.971 .817 .634 r
.79735 .64851 m .79771 .64746 L .79069 .63935 L p F P
0 g
s
.943 .836 .709 r
.79061 .63958 m .79735 .64851 L .78841 .66605 L p F P
0 g
s
.971 .817 .634 r
.79069 .63935 m .79061 .63958 L .79735 .64851 L p F P
0 g
s
.903 .845 .777 r
.7816 .65719 m .78841 .66605 L .77487 .68498 L p F P
0 g
s
.943 .836 .709 r
.78841 .66605 m .7816 .65719 L .79061 .63958 L p F P
0 g
s
.779 .833 .894 r
.74951 .70734 m .73637 .71627 L .729 .70782 L p F P
0 g
s
.679 .803 .941 r
.69693 .7206 m .729 .70782 L .73637 .71627 L p F P
0 g
s
.779 .833 .894 r
.729 .70782 m .74252 .69866 L .74951 .70734 L p F P
0 g
s
.808 .841 .875 r
.76063 .68447 m .74252 .69866 L .74951 .70734 L p F P
0 g
s
.808 .841 .875 r
.74951 .70734 m .76786 .6929 L .76063 .68447 L p F P
0 g
s
.871 .847 .817 r
.77487 .68498 m .76786 .6929 L .76063 .68447 L p F P
0 g
s
.871 .847 .817 r
.76063 .68447 m .76797 .6762 L .77487 .68498 L p F P
0 g
s
.903 .845 .777 r
.77487 .68498 m .76797 .6762 L .7816 .65719 L p F P
0 g
s
.25 Mabswid
.76523 0 m
.91897 .25049 L
s
.91897 .25049 m
1 .91594 L
s
1 .91594 m
.8234 .6978 L
s
.8234 .6978 m
.76523 0 L
s
.07962 .26911 m
0 .9318 L
s
0 .9318 m
.8234 .6978 L
s
.8234 .6978 m
.76523 0 L
s
.76523 0 m
.07962 .26911 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{897.938, 464.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000>10001d2000`400?l00000o`00003ooooonf[o
oookJ_oooo]ZQ?oonfX00?oooo]Zoooonf[ooookJXCooo]Z003ooookJ_oooo]ZoooonfZ4oookJP00
oooonf[ooookJ_oooo]ZQ?oonfX00?oooo]Zoooonf[ooookJXCooo]Z003ooookJ_oooo]ZoooonfZ4
oookJP00oooonf[ooookJ_oooo]ZQ?oonfX00?oooo]Zoooonf[ooookJXCooo]Z003ooookJ_oooo]Z
oooonfZ4oookJP00oooonf[ooookJ_oooo]ZQ?oonfX00?oooo]Zoooonf[ooookJXCooo]Z003ooook
JRKooo]Z0_l0003ooookJ^?ooo]Z0_l0001foookJP00oooonfXSoookJP?o000000?ooo]Zo`000?oo
nfX0oooonf[OoookJP?o000000?ooo]Zo`000?oonfX0MOoonfX00?oooo]Z8OoonfX2o`0000Cooo]Z
0_l0003ooookJ]gooo]Z0_l00004oookJP;o0000MOoonfX00?oooo]Z7ooonfX2o`0000Kooo]Z00?o
0000oookJ_l00000oooonf[IoookJP?o00001_oonfX00ol0003ooo]Zo`00001doookJP00oooonfXL
oookJP?o00002?oonfX00ol0003ooo]Zo`00003ooookJ]Oooo]Z0_l00009oookJP03o`000?oonf[o
000007Cooo]Z003ooookJQ[ooo]Z0_l0000;oookJP04o`000?oonf[ooo]Zo`000?oooo]ZdooonfX3
o`0000_ooo]Z00Co0000oookJ_oonf[o0000LooonfX00?oooo]Z6?oonfX2o`0000gooo]Z00Co0000
oookJ_oonf[o0000oooonf[@oookJP?o00003_oonfX01?l0003ooo]ZoookJ_l0001coookJP00oooo
nfXEoookJP?o00003ooonfX01Ol0003ooo]ZoookJ_oonf[o00000?oooo]ZcOoonfX2o`0001;ooo]Z
00Co0000oookJ_oonf[o0000L_oonfX00?oooo]Z4ooonfX2o`0001;ooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP3ooookJ/Oooo]Z0ol0000DoookJP05o`000?oonf[ooo]ZoookJ_l0
0000LOoonfX00?oooo]Z4?oonfX3o`0001Gooo]Z00Go0000oookJ_oonf[ooo]Zo`00003ooookJ/Oo
oo]Z0_l0000GoookJP05o`000?oonf[ooo]ZoookJ_l00000LOoonfX00?oooo]Z3_oonfX2o`0001So
oo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP3ooookJ/7ooo]Z0ol0000IoookJP03
o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0K_oonfX00?oooo]Z3?oonfX2o`0001[ooo]Z
00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP3ooookJ[oooo]Z0_l0000LoookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0K_oonfX00?oooo]Z2OoonfX3o`0001cooo]Z00?o
0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP3ooookJ[_ooo]Z0ol0000NoookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0KOoonfX00?oooo]Z1ooonfX2o`0001oooo]Z00?o0000
oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP3ooookJ[Sooo]Z0_l0000QoookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX0K?oonfX00?oooo]Z1OoonfX2o`00027ooo]Z00?o0000oook
J_oonfX01?oonfX00ol0003ooo]ZoookJP3ooookJ[Gooo]Z0ol0000SoookJP03o`000?oonf[ooo]Z
00Cooo]Z00?o0000oookJ_oonfX0K?oonfX00?oooo]Z0_oonfX3o`0002?ooo]Z00?o0000oookJ_oo
nfX01OoonfX00ol0003ooo]ZoookJP3ooookJ[;ooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z00Go
oo]Z00?o0000oookJ_oonfX0JooonfX00?oooo]Z0_l0000VoookJP03o`000?oonf[ooo]Z00Kooo]Z
00?o0000oookJ_oonfX0oooonfZ^oookJP?o0000:?oonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z06_ooo]Z003moookJP;o0000:?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oo
nf[ooo]Z0?oooo]ZZooonfX3o`0002_ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]Zoook
JP1ZoookJP00n_oonfX3o`0002[ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP3o
oookJZSooo]Z0_l0000^oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0JOoonfX0
0?Sooo]Z0_l0000]oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0oooonfZUoook
JP?o0000<OoonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z06Wooo]Z003eoookJP?o
0000;ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z0?oooo]ZX_oonfX2o`0003Co
oo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP1XoookJP00looonfX2o`0003;ooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP3ooookJYkooo]Z0ol0000foookJP03o`00
0?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0J?oonfX00?7ooo]Z0_l0000doookJP03o`000?oo
nf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0oooonfZLoookJP;o00005ooonfXAo`00017ooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP1WoookJP00k_oonfX3o`0003Kooo]Z00?o0000
oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP3ooookJYSooo]Z0ol0000EoookJPCo00000_nR]^H0
0ol0003oQjS[ohNXj`02ohNXj`03o`000?mkX^_oNj;[00?oNj;[00Co0000oe:9j?l0003o;W;O0_l0
000?oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0I_oonfX00>cooo]Z0_l0000i
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0oooonfZFoookJP;o00005OoonfX3
o`0000OoX[KV00?o0000ohNXjon7Z>/00_n7Z>/00ol0003oNj;[og^Rj`03og^Rj`03o`000?mBRNSo
000000;o;W;O0_l0000=oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0I_oonfX0
0>[ooo]Z0_l0000koookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0oooonfZBoook
JP?o00005?oonfX3o`0000[oX[KV00Co0000ohNXjon7Z>_oQjS[1_l000001OmkX^_o0000oe:9j?mB
RNSo000000?o;W;O00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oo
nf[ooo]Z06Gooo]Z003WoookJP?o0000?_oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[o
oo]Z0?oooo]ZSooonfX2o`0001Gooo]Z0_l000000onf_^3o0000oj:fiP0;oj:fiP?o00000_n7YnX0
1?l0003oNioYog^OjOmkWnT6o`0000;o;W;O0_l0000;oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000oookJ_oonfX0IOoonfX00>Gooo]Z0_l00011oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000
oookJ_oonfX0oooonfZ<oookJP?o00005?oonfX3o`0000Co][kP00?o0000oj:fi_nR]^H00onR]^H4
o`0000;oX[CU00?o0000ohNWj_n7YnX00on7YnX00ol0003oNioYog^Oj@02og^Oj@05o`000?mDR>Ko
E8SVo`000?lbL]l01?l0000:oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0I?oo
nfX00>;ooo]Z0ol00013oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0oooonfZ8
oookJP?o00005OoonfX2o`0000Oo][kP00?o0000oj:fi_nR]^H00ol00007oj:di@03o`000?n7Yn[o
QjOZ00;oQjOZ00?o0000og^OjOmkWnT00omkWnT01?l0003oE8SVoeB8i_l00002oc9bg`03o`000?l0
?/;o000000Wooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP1SoookJP00h?oonfX2
o`0004Kooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP3ooookJXGooo]Z0_l0000F
oookJP;o00002_nf_^02o`0000_oX[CU00?o0000ohNWj_n7YnX01ol000001?mkWnWo0000oeB8i_l0
0003oc9bg`03o`000?l006Ko000000Sooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zoook
JP1SoookJP00g_oonfX2o`0004Sooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP3o
oookJX;ooo]Z0ol0000GoookJP03o`000?nf_^3o][kP00Oo][kP0_l000000onf_^3o0000oj:di@0<
oj:di@;o00000_n7Y^T00ol0003oNigXog^Mj002og^Mj0Go00000_lbL]l01?l0003o0474o`00I_l0
0007oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0H_oonfX00=_ooo]Z0ol0001:
oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0oooonfYooookJP;o00006OoonfX2
o`0000Oo][kP0_l00004okJnh003o`000?nR]>GoX[CU00CoX[CU1?l00002oj6ci@03o`000?n7Y^Wo
QjKY00;oQjKY00?o0000og^Mj?mkWNP00omkWNP01?l0003oEHOUo`000?lfLMd3o`000003o`11a?l0
06Ko000000Oooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP1RoookJP00fOoonfX2
o`0004gooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP3ooookJWcooo]Z0ol0000J
oookJP04o`000?o4`mWoa<?Io`0000Co][kP0_l00007okJnh003o`000?nR]>GoX[CU00?o00001onQ
/nD01Ol0003oQjKYohNVjOn7Y^Wo000000KoNigX00?o0000oeF7iOl000000_lfLMd01?l0003o0474
o`11a?l00007oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0HOoonfX00=Oooo]Z
0_l0001?oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0oooonfYioookJP;o0000
6ooonfX2o`0000Coa<?I00Co0000okJnh?l0003o00002_nf_^02o`0000[oXK?U00?o0000ohNVjOn7
Y^T01ol000001?mkWNSo0000oeF7iOl00003ocIag@Co00001_oonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z063ooo]Z003DoookJP?o0000DOoonfX00ol0003ooo]ZoookJP0@oookJP03
o`000?oonf[ooo]Z0?oooo]ZMOoonfX3o`0001cooo]Z00?o0000ol?3f_l000001?o4`mT2o`0000Wo
][kP0_l00002okFmh003o`000?nQ/nGoXK?U00WoXK?U0_l00002ohJTj003o`000?miV^KoNI[V00;o
NI[V1Ol00002ocIag@04o`000?l0@lGo0000o`0000Kooo]Z00?o0000oookJ_oonfX03_oonfX00ol0
003ooo]ZoookJP1PoookJP00d_oonfX2o`0005Cooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003o
oo]ZoookJP3ooookJW?ooo]Z0_l0000MoookJP;o00000oo3`mX01_l0003oa<?IolC3fOl0003oaLGJ
o`0000Oo][kP0_l00005okFmh004o`000?nQ/nGoXK?Uoj6ci@Go00000_nP/^@00ol0003oQZCXohJT
j002ohJTj003o`000?miV^KoNI[V00?oNI[V00Co0000oeJ5hol0003o>G3L0ol000000ol0@lGo0000
o`000005oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0GooonfX00<oooo]Z0ol0
001FoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0oooonfY_oookJP?o00007_oo
nfX00ol0003o`l?Jol?3fP03ol?3fP03o`000?o4`mWo000000?oaLGJ00?o0000okJnh?nf_^000_nf
_^02o`0000So]KgP0ol00008oj2bi005o`000?n6Y>SoQZCXohJTj?l000001_miV^H00ol0003oEXGS
o`000002ocU`g004o`000?l0@lGo0000o`0000Gooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP1OoookJP00cOoonfX2o`0005Wooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP3ooookJVgooo]Z0_l0000PoookJP03o`000?o3`m[o`l?J00Go`l?J00?o0000olG5f_o5aMX0
0oo5aMX01?l0003o][kPo`000?l00007okFmh0;o000000?o];gQo`000?nP/^@02_nP/^@00ol0003o
QZCXohJTj006o`0000;oNI[V0_l00003ocU`g0Co00001?oonfX00ol0003ooo]ZoookJP0@oookJP03
o`000?oonf[ooo]Z05kooo]Z003;oookJP;o0000FooonfX00ol0003ooo]ZoookJP0BoookJP03o`00
0?oonf[ooo]Z0?oooo]ZJOoonfX3o`00023ooo]Z0_l00006ol?3fP03o`000?o3aM_o000000GoaLGJ
0_l00006okFmh0?o00001?nd_N400ol0003oX;;Toj2bi006oj2bi003o`000?nP/^CoX;;T00;o0000
00?oQJ;Wo`000?mgU^@00omgU^@5o`0000;o>G3L00Co0000o`15aOl0003o00001?oonfX00ol0003o
oo]ZoookJP0AoookJP03o`000?oonf[ooo]Z05gooo]Z0038oookJP?o0000GOoonfX00ol0003ooo]Z
oookJP0CoookJP03o`000?oonf[ooo]Z0?oooo]ZIOoonfX3o`0002;ooo]Z00Co0000om36dOo@a]7o
00000oo3`mX2o`0000?o`lGK00?o0000olG5f_o5aMX00_l000000oo5a]_o0000okFmh003okFmh0;o
00001ond_N401?l0003oX;;Toj2bi?nP/^@5o`0000?oWZoT00Co0000ohFRion5X^Oo00001omgU^@0
0omEP^7o0000oc]_fP06o`0000?ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP1M
oookJP00a_oonfX2o`00063ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP3ooook
JV?ooo]Z0_l0000ToookJP03o`000?o@a]7od<KA00;od<KA00?o0000ol?3f_l000001Oo3aM/00ol0
003oaLGJo`000004olG6f`04o`000?ne_N3o0000o`0000[o];gQ0ol00009oij_i004o`000?n5X^Oo
QJ;Wo`0000OoMiKT00Co0000oc]_f_lkKm[o>foJ1?l00003oookJP03o`000?oonf[ooo]Z01;ooo]Z
00?o0000oookJ_oonfX0G?oonfX00<Cooo]Z0_l0001RoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX0oooonfYOoookJP?o00009OoonfX00ol0003od<KAom36d@04om36d@03o`000?o3
aM_o`lGK00Go`lGK00?o0000olG6foo5a]/00oo5a]/2o`0000Wo];gQ0_l000000onb_>7o0000oij_
i00:oij_i004o`000?n5X^OoQJ;Wo`0000OoMiKT00?oEH;Qo`000?lkKmX00_lkKmX4o`0000;ooo]Z
00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP1LoookJP00`OoonfX3o`0006Cooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP3ooookJUcooo]Z0_l0000WoookJP;o00001Oo@
a]42o`0000Go`lGK00?o0000ol?7gOl000001?o5a]/00ol0003oa<OMo`000007okBmh@;o00001?nb
_>400ol0003oWZoToij_i006oij_i003o`000?nN[nCoWZoT00co00000olkKmX4o`0000;ooo]Z00?o
0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP1KoookJP00_ooonfX2o`0006Sooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP3ooookJUWooo]Z0ol0000XoookJP04o`000?o>a]?o
c/KCo`0000?od<KA00Co0000om79dooAbM?o00000_o3aM/2o`0000?o`lOM00Co0000olG6foo5a]_o
00000oo4amd00ol0003o];gQokBmh@02okBmh@;o00001_nb_>401?l0003oWZoToij_i?nN[n@5o`00
00?oW:gS0_n3X>H00ol0003oMYOUogJGi@06ogJGi@03o`000?lgJmSo000000;o000000Koo;MXo`00
0?oaWc3o0000oookJ_l0000FoookJP03o`000?oonf[ooo]Z05[ooo]Z002moookJP;o0000J_oonfX0
0ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z0?oooo]ZE_oonfX2o`0002[ooo]Z00?o0000
olk6doo>a]<00_o>a]<00ol0003od<KAo`000003om79d`03o`000?o3aM_o000000Go`lOM00?o0000
olG6fol000001Oo4amd01?l0003o];gQo`000?l00009ok:lh@?o00002OnL[N<00on3X>Ko0000ogJG
i@07ogJGi@09o`000?lgJmSo=f_HocM[f?l0003oo;MXo`000?oaWc3o000000;ooo]Z00?o0000oook
J_oonfX04ooonfX00ol0003ooo]ZoookJP1JoookJP00^_oonfX3o`0006cooo]Z00?o0000oookJ_oo
nfX05OoonfX00ol0003ooo]ZoookJP3ooookJU?ooo]Z0ol0000[oookJP03o`000?o>a]?oc/KC00Co
c/KC00?o0000om79dooAbM<00ooAbM<00ol0003o`lOMol?7g@05ol?7g@03o`000?o4amgoa<OM00Co
a<OM0_l00007ok:lh@?o000000?o/;[Qo`000?nL[N<02onL[N<00on3X>Ko0000ogJGi@06ogJGi@;o
00000_lgJmP00ol0003oo;MXo`000003o`000003oookJ_l0003ooo]Z01Gooo]Z00?o0000oookJ_oo
nfX0FOoonfX00;Sooo]Z0_l0001_oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
oooonfY@oookJP;o0000;OoonfX00ol0003oc/KColk6d`03olk6d`03o`000?o?b]Go000000CodLWC
00?o0000om7<eOl000000oo3amd2o`000003ol;8gol0003oa<OM00?oa<OM0_l000000oo3bMoo0000
ok:lh@04ok:lh@;o00001On`^^400ol0003oW:gSoib]h`07oib]h`03o`000?nL[N?oW:gS00Ko0000
0omfUnD2o`000003ocM[f?l0003o000000Co000000?ooo]Zo`000?oonfX05OoonfX00ol0003ooo]Z
oookJP1IoookJP00]OoonfX3o`00077ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Zoook
JP3ooookJTcooo]Z0ol0000^oookJP03o`000?o>a]?oc/KC00?oc/KC00Go0000olo:eOo?b]Gocl[E
o`000002om79d`07o`000?oAc=GodLcEom7<eOl0003o`lOMo`000003ol;8g`05o`000?o4amgoa<OM
olC7gOl000001?o3bMl00ol0003o/[cQo`000002o`0000So/;[Q00Co0000oib]honL[N?oW:gS1Ol0
0003oiVZhP03o`000?maU>GoLICU00?oLICU1_l000001_ok`hOo0000o`000?om^FCo0000onjM9`;o
00005ooonfX00ol0003ooo]ZoookJP1HoookJP00/ooonfX2o`0007Cooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP3ooookJT[ooo]Z0_l0000aoookJP03o`000?o>a]?oc/KC00;oc/KC
00?o0000olo:eOo?b]D00_o?b]D00ol0003odLWCo`000004om7<e@;o00001Oo2b=l3o`0000Go`lWO
0_l0000<ok2jh@?o00002OnIZ^800ol0003oLICUog6Di@05og6Di@03o`000?mOP=co000000;onl>7
00Co0000oofiI?l0003okYdW0_l0000HoookJP03o`000?oonf[ooo]Z05Oooo]Z002aoookJP;o0000
M_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z0?oooo]ZA_oonfX3o`0003;ooo]Z
00?o0000omW8bOl000000_o>a]<00ol0003ocl[Eolo:e@04olo:e@03o`000?oAc=GodLcE00;odLcE
00?o0000om7?eol000001Oo2b=l00ol0003o`lWOol?9g`04ol?9g`03o`000?o1bn;o000000So/;[Q
0ol000000on]^>7o0000oiVZhP0:oiVZhP03o`000?maU>GoLICU00GoLICU00?o0000oen0g?l00000
0_ok`hL00ol0003ooKUTo`000003o`0001Sooo]Z00?o0000oookJ_oonfX0EooonfX00:kooo]Z0ol0
001hoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0oooonfY3oookJP?o0000=?oo
nfX2o`000004omW8bOl0003oc/KCo`0000Gocl[E00?o0000olo=f?l000000ooAc=D01Ol0003odLoG
om7?eooAcmOo000000;o`/SO00?o0000ol39h_l000001?o3bMl2o`0000?o`L_R00?o0000ok2jhOn`
^^400on`^^42o`0000Go[KSQ00?o0000oiVZh_nIZ^800onIZ^83o`0000;oVJ[R1_l00003og6Di@04
o`000?ogbIco0000oo_3Q`Ko00006OoonfX00ol0003ooo]ZoookJP1FoookJP00[?oonfX2o`0007_o
oo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP3ooookJT3ooo]Z0_l0000foookJP06
o`000?oIb<WofLS9o`000?oIb<Wo00001Oo?b]D01?l0003oclgHolo=f?l00002om7<e@03o`000?oA
cmOodLoG00;odLoG00?o0000ol;8gol000000_o0bN801Ol0003o`lWOol?9goo3bMoo000000Ko`L_R
00?o0000ok2jhOl000000_l00008ojfhh@Go00001OnFZ><2o`0000CoM93P1?l000001?ogbIco0000
o`000?omaXD2o`000003oofkG_l0003o000001[ooo]Z00?o0000oookJ_oonfX0EOoonfX00:[ooo]Z
0_l0001moookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0oooonfXloookJP?o0000
=ooonfX00ol0003ofLS9omW8b@02omW8b@03o`000?oKc<[o000000?ocl[E00?o0000olo=f?o?cMP0
0_o?cMP2o`0000GodLoG0_l00004ol39hP03o`000?o3bMoo`L_R00Oo`L_R0_l00007ojfhh@?o0000
00?oZ[GQo`000?nFZ><02?nFZ><00ol0003oS:3Qo`000006ogB@h004o`000?ogbIcomlVLo`0000;o
oLJ500Co0000oofkG_l0003o00006_oonfX00ol0003ooo]ZoookJP1EoookJP00YooonfX3o`0007oo
oo]Z00?o0000oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP3ooookJS[ooo]Z0_l0000ioookJP03
o`000?oIb<WofLS900?ofLS900Ko0000om_<b_oKc<[o0000olo:eOl00005olo=f003o`000?oAcmOo
dLoG00?odLoG00Co0000om7Bf_oAd][o00000oo0bN800ol0003o`L_Rol7;hP05ol7;hP;o000000?o
_LWTo`000?n]^>401?n]^>42o`0000GoZ[GQ00?o0000oiJXhonFZ><01_nFZ><01?l0003oS:3QohbP
hOl00004ogB@h005o`000?ogbIcomlVLooO9W?l000000_omaXD00ol0003ooK]No`000002o`0001[o
oo]Z00?o0000oookJ_oonfX0E?oonfX00:Gooo]Z0_l00022oookJP03o`000?oonf[ooo]Z01_ooo]Z
00?o0000oookJ_oonfX0oooonfXfoookJP?o0000>_oonfX00ol0003ofLS9omW8b@03omW8b@03o`00
0?oJc<_o000000;oflc:00?o0000olo=f?o?cMP00_o?cMP00ol0003ocm3Ko`000004om7?e`03o`00
0?oAd][odM;J00;odM;J00Co0000ol39h_l0003o00001Oo1bn82o`0000Co_LWT00?o0000ojfhhOl0
00000_l00008ojZeh@03o`000?nFZ>?oUZSS00;oUZSS0_l000000onFZ>?o0000o`000007o`0000?o
mlVL0_l000000oomaXGo0000o`000003o`0001[ooo]Z00?o0000oookJ_oonfX0E?oonfX00:;ooo]Z
0ol00024oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0oooonfXcoookJP;o0000
??oonfX00ol0003ofLS9omW8b@03omW8b@05o`000?oJc<_of/c;o`000?oKc<X00_l00003olo=f005
o`000?o?d=_ocm3Kolo@fol000000_oAcmL00ol0003odM;Jom7BfP03om7BfP;o000000?o_LWTo`00
0?o1bn800oo1bn800ol0003o_LWTokg9i004okg9i0;o00003?nZ]N44o`0000?oTZKS00Go0000ohRK
gon8VmooR9_Oo`000003og6=gP;o000000?omlVLo`000?oic9`00_l000000oonbH;o0000o`000003
o`0001[ooo]Z00?o0000oookJ_oonfX0DooonfX00:3ooo]Z0_l00027oookJP03o`000?oonf[ooo]Z
01cooo]Z00?o0000oookJ_oonfX0oooonfX`oookJP?o0000?OoonfX2o`0000CofLS900?o0000om[<
booJc</00_oJc</01_l0003og=3=omc@cOl0003oclgHo`0000Cocm3K00?o0000om7?eol000001OoA
d]X01Ol0003oc]COokg9i?nmbNCo000000;o`L_R0_l00005okg9i0;o000000?o^/7Po`000?nZ]N40
1onZ]N43o`000003ojNbh?l0003oTZKS00GoTZKS00?o0000ohRKgon8Vml00_n8Vml00ol0003oLHgN
o`000002oo7<[0;o00000_oic9`01Ol0003oo/V2ook9P_l0003oo;]H00;o00006ooonfX00ol0003o
oo]ZoookJP1BoookJP00W_oonfX2o`0008Wooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Z
oookJP3ooookJRgooo]Z0_l0000ooookJP04o`000?oHbL_of<W;o`0000?ofLS900?o0000om[<booJ
c</00_oJc</01Ol0003og=3=omc@cOoLd<go000000Kocm3K00?o0000om7Bf_oAd]X00ooAd]X02?l0
003oc]COolkDgoo>e=oo_LWTo`000?o1bn;o00001_nmbN@00ol0003o^/7Pok[1h002ok[1h003o`00
0?nZ]N7oZ[GQ00;oZ[GQ0ol00005ojNbh003o`000?nBY^?oTZKS00CoTZKS00Oo0000ohRKgon8Vmoo
R9_Oo`000?maSMko000000?olLb/00Co0000ooW<W?oic9co00000_onbH801?l0003oo;]Ho`000?l0
000KoookJP03o`000?oonf[ooo]Z05;ooo]Z002KoookJP?o0000RooonfX00ol0003ooo]ZoookJP0M
oookJP03o`000?oonf[ooo]Z0?oooo]Z:_oonfX3o`00043ooo]Z00?o0000omS9booHbL/00_oHbL/0
0ol0003ofLS9o`000004om[<b`03o`000?oKclgo000000;og=3=0_l00003olo@f`03o`000?o=dmko
000000?odM;J0_l00004olkDg`;o00001_nmbN@2o`0000Go^/7P00?o0000ojZehOl000000_l00008
ojNbh003o`000?nBY^?oTZKS00CoTZKS00Oo0000ohRKgon8VmooR9_Oo`000?maSMko000000?olLb/
00?o0000ooW<W?oic9`00_l000000oonbH;o0000o`000003o`0001_ooo]Z00?o0000oookJ_oonfX0
DOoonfX009Wooo]Z0_l0002>oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0oooo
nfXVoookJP?o0000@_oonfX00ol0003of<W;omS9b`04omS9b`03o`000?oJc<_of/c;00;of/c;00Ko
0000om_?cOoKclgo0000omc@cOl00002omcDd003o`000?o?d=_o000000;ocM?N00Co0000om7Bf_oA
d][o00001Oo>e=l01?l0003obMGSo`000?l00004okg9i003o`000?nj`N3o^/7P00Ko^/7P00?o0000
ojNbh?nW/^002_nW/^0<o`0000?olLb/00Go0000oo??Zol0003o0000oo[@V`02o`000003ooo<O_l0
003o000000;o00006ooonfX00ol0003ooo]ZoookJP1AoookJP00UooonfX2o`00097ooo]Z00?o0000
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP3ooookJR?ooo]Z0_l00015oookJP03o`000?oHbL_o
f<W;00?of<W;0_l00003om[<b`03o`000?oKclgoflo=00;oflo=00?o0000omcDd?oLe=000_oLe=00
1ol0003ocM?NolgCg_o=dmko0000om7Bf_l000001Oo>e=l01_l0003obMGSolWEhol0003ob<cMo`00
00;o_LWT1onj`N02o`0000;o]koP00?o0000ojNbh?nW/^001?nW/^03o`0000;oXjkO00?o0000ohnS
h_n?Xn800on?Xn800ol0003oQ9KMohBFg@02ohBFg@06o`000?oac:colLb/oo7<[?l0003olln[0ol0
00001?ojd9_o0000ooo<O_ooc7h3o`0001cooo]Z00?o0000oookJ_oonfX0D?oonfX009Cooo]Z0ol0
002CoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0oooonfXPoookJP?o0000A_oo
nfX00ol0003oh/W0o`000003omS9b`04o`000?oJc/kof/k>o`0000;of/c;00?o0000om_?cOoKcld0
0_oKcld01ol0003og=C@omcDd?oLe=3o0000omcIdol000000_o=dmh2o`0000Goc]CO00?o0000olWE
hoo9eN<00_o9eN<3o`0000Ko^/7P0_l00005okNoh003o`000?nW/^3oYk;P00?o00001_nS[]l00ol0
003oSj?RohnShP02ohnShP09o`000?n4U]goQ9KMohBFgOl0003ojlffo`000?oac:co000000?olln[
00Co0000oo[@V_l0003o00000_ooc7h3o`0001gooo]Z00?o0000oookJ_oonfX0CooonfX009;ooo]Z
0_l0002FoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0oooonfXMoookJP;o0000
BOoonfX01_l0003oh/W0on;9`?l0003of<W;o`0000?of/k>00?o0000om[<bol000001?oKcld2o`00
00;og=C@00Oo0000omcIdooLfM?og=WCo`000?o=dmko000000Coc]CO0_l00005olWEh`03o`000?o9
d=oo000000Co^/7P0_l00008okNoh0;o00002_nS[]l01Ol0003oSj?RohnSh_n?Xn;o000000?oQ9KM
00Go0000on_=]_l0003olLb/o`000003oo??Z`03o`000?ojd9[on]2J00;o000000?oolano`000?l0
00000_l0000LoookJP03o`000?oonf[ooo]Z04oooo]Z002@oookJP;o0000D_oonfXBo`0003Cooo]Z
00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0001:oookJP03o`00
0?oRbL3o000000;oh/W000?o0000om[>c_oJc/h00ooJc/h00ol0003oflo=om_?c@02om_?c@03o`00
0?oKdm3ofm?@00;o00001OoLfM<2o`0000?oc]CO00?o0000olWEhoo9eN<01?o9eN<01_o6e>Go0000
olW@goo9d=oo0000ok[1h0;o00001ong_n02o`000003ok>lh?l0003oXjkO00_oXjkO1ol00003on_=
]P08o`000?occj_olln[oo??Zol0003omM>[o`000?ojd9X7o`0001gooo]Z00?o0000oookJ_oonfX0
C_oonfX008gooo]Z0ol00018oookJQ3o00000_mV00001?l0003oP000oh000?n0000Ao`0002_ooo]Z
00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP3ooookJQOooo]Z0_l0001<oookJP06o`00
0?oRbL3oh/W0on;9`?l0003oh/W00_l00003om[>cP;o00000ooKcld01Ol0003ofm?@om_Cd?oKdm3o
000000Gog=WC0ol00003olkDg`GobMGS00Co0000olKDiOo6e>Go00000_o9d=l2o`0000Oo]koP0_l0
0004ok>lh003o`000?nS[]ooXjkO00?oXjkO1?l00002oijYgP?oRioQ00Co0000oh>Hgon3V=oo0000
0oo[cKH01_l0003olln[oo??Zooccj_o0000ooGCZ`;o00000_oke9`3o`000003ooFlBOl0003ooo]Z
01cooo]Z00?o0000oookJ_oonfX0C_oonfX008_ooo]Z0_l00014oookJR[o00000oma000:o`0002;o
oo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP3ooookJQ?ooo]Z0ol0001>oookJP03
o`000?oRbL3oh/W000;oh/W000So0000onC?`_oTcl;o0000om[>c_l0003ofmCAo`0000;oflo=00?o
0000om_Cd?oKdm000_oKdm000ol0003og=WComcId`02omcId`04o`000?oGeMOoemGGo`0000;oc]CO
1?o9eN<2o`0000Coa]CU0_l00002olKAh`03o`000?ng_n3o]koP00;o]koP0_l00006ok>lh003o`00
0?nS[]ooXjkO00?o00001onNZMh2oh^Oh@03o`000?n3V=oo000000?ojlff00Go0000ong@]_l0003o
lln[o`000003ooGCZ`03o`000?oke9conmBL00?o000000?omKa9o`000?oonfX07OoonfX00ol0003o
oo]ZoookJP1=oookJP00R?oonfX3o`0003oooo]Z3ol00005ohXP=003o`000?nA:C_o000000SoTR@^
00Co0000oi/a>onK<C_o00001onH:2h00ol0003oY3Xmo`000003ojLg<@_o00000_n=0006o`0001go
oo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP3ooookJQ7ooo]Z0_l0001@oookJP03
o`000?oRbL3oh/W000?oh/W000Go0000onC?`_oTcl;oi<o2o`000003om_Dd@;o00001?oKdm02o`00
00?og=WC00?o0000omOEeooGeML00_oGeML2o`0000?obMGS00?o0000olKDiOo6e>D01?o6e>D00ol0
003oa]7SolKAh`02olKAh`04o`000?ng_n3o0000o`0000Wo/kcP0_l0000:oijYgP05o`000?n;Wn7o
0000oh>Hgol000000_o[cKH01_l0003okM2fong@]_l0003olln[o`0000?omM>[00?o0000oo_DW?l0
00001?l000000oo_^Coo0000oookJP0MoookJP03o`000?oonf[ooo]Z04cooo]Z0026oookJP;o0000
?_oonfX;o`0000;oNQ0/00?o0000ohXP=?n:83@01on:83@00ol0003oTBTko`00000Mo`0000;oYcLa
00?o0000ojDe<_l000000_n]?SH8o`000003og400?l0003o000000Co00005ooonfX00ol0003ooo]Z
oookJP0RoookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX3o`00057ooo]Z00?o0000on;9`?oRbL00
0ooRbL000ol0003oi<o2o`000002onC?`P05o`000?oKe=7ofmCAom_DdOl000001?oKdm001_l0003o
f]gHom[Mf?l0003og=WCo`0000CoemGG00Koe^;Po`000?oHfMSo0000olWEhol00005olKDi@03o`00
0?o2dnOo000000Coa]7S0_l00007ok>lh0?o000000?o[kSPo`000?nNZMh02_nNZMh02?l0003oRioQ
o`000?l0003oi/fmo`000?o[cKKo00000oo]d;H01?l0003omM>[ooGCZooedj/2o`000008oo_DW?l0
003ooMNHo`000?oodW_o0000onni?ol0000NoookJP03o`000?oonf[ooo]Z04cooo]Z0024oookJP;o
0000??oonfX:o`0000GoNa<b0ol00005ohXP=0Ko00000_nPBV800ol0003oXDYQoj5:H@04oj5:H@03
o`000?nXDF;oZ55R00;oZ55R00?o0000ojUAHOnYDF401?nYDF401?l0003o[eMRojmGH_l00005ok1F
GPSo000000?o[Chfo`000?n[>2/00_n[>2/<o`0001Cooo]Z00?o0000oookJ_oonfX08ooonfX00ol0
003ooo]ZoookJP3ooookJP[ooo]Z0_l0001DoookJP;o00000ooRbL002Ol0003oi<o2onC?`_l0003o
i<o2o`000?oVe<Co0000om_Dd@02o`0000?ofm?@00Co0000om[Mf?oJgMSof]gH0_l00003omOEe`05
o`000?oFh^3oe^;Po`000?oHfMP00_l00004olKDi@;o00000_o2dnL00ol0003oa]7SolKAh`02o`00
0003ol7Biol0003o/kcP00Co/kcP0_l00005ojnhh003o`000?nNZMkoWZWN00WoWZWN0_l00003onK=
_@03o`000?o]d;KokM2f00;okM2f00Ko0000ooGCZooedj_omM>[o`000?ogeZ/2o`000006oogGV?l0
003o0000o`000?o_^Coo00007ooonfX00ol0003ooo]ZoookJP1;oookJP00POoonfX3o`0003_ooo]Z
2?l00002og8;;P04o`000?mk4c;oNa<bog/C<Pco00001?nH@f000ol0003oX4YRoj1:HP02oj1:HP03
o`000?nQBV7oXDYQ00;oXDYQ00?o0000ojQAH_nXDF801?nXDF800ol0003oZE5QojUAH@02ojUAH@03
o`000?n_Ef;o[eMR00;o[eMR00?o0000ok1FG_n`EUh01On`EUh00ol0003o^emNok]OGP02ok]OGPKo
00000on[>2/01?l0003o^TL_okY7;onjAbl7o`00017ooo]Z00?o0000oookJ_oonfX08ooonfX00ol0
003ooo]ZoookJP3ooookJPOooo]Z0ol0001EoookJP06o`000?oRb/3oh/[0o`000?oRbL3o00001?oT
cl801?l0003oi]C4onKDa?oVe<@3o`0000;ofm?@00?o0000om[Mf?oJgMP00_oJgMP01Ol0003oemGG
omOEeooGeMOo000000?oe^;P0_l000000ooFgMgo0000olKDi@02olKDi@05o`000?o2dnOo`]?Wol;C
iol000000_o6dN<00ol0003o`M;Wol7Bi`02ol7Bi`03o`000?nc_>3o000000;o00002?n_^>001?l0
003oWZWNoijYg_nNZMh5o`0000?oVZCL00Go0000onK=_OoVcKgoi/fmo`000003ong@]P05o`000?o_
dkKo0000ooGCZol000000_ogeZ/00ol0003ooMNHoogGV003o`000003onni?ol0003ooo]Z01kooo]Z
00?o0000oookJ_oonfX0BooonfX007oooo]Z0_l0000ioookJPSo00001?mb2bh7o`0000GoScaO00Co
0000oiQ3H_nH@f;o00000onH@f0To`0000?o/5IN00?o0000ok]OG_nkGeh01?nkGeh01?l0003o^UiN
okYNG_njGUh4o`0000Co^TL_00?o0000okDo9one?bL01_l0000>oookJP03o`000?oonf[ooo]Z02Co
oo]Z00?o0000oookJ_oonfX0oooonfX3oookJP?o0000EooonfX00ol0003oh/[0on;:`002on;:`003
o`000?oTcl;oi<o200?oi<o200Ko0000onKDa?oVe<Coi]C4o`000?oXflL3o`0000Cof]gH0_l00002
omOEe`03o`000?oFh^3oe^;P00;oe^;P00Oo0000omKMgOoFgMgoe]gMo`000?o6e>Go000000Co`]?W
0ol00005ol7Bi`;o00003?n_^>03o`0000OoVZCL00Oo0000onK=_OoVcKgoi/fmo`000?oXd;ko0000
00;okM2f00Go0000onoC]_l0003omM>[o`000002ooOFZ`03o`000?omeiSooMNH00?o000000?okkTo
o`000?oonfX07ooonfX00ol0003ooo]ZoookJP1:oookJP00OOoonfX2o`0003Sooo]Z1ol000000omN
01ko0000og8;;P05o`0000;oQS=L00?o0000ohllGon??5l01_n??5l00ol0003oV4=RoiQ3HP05o`00
00?oXEYj00?o0000ojMON_nWGgX01?nWGgX01Ol0003oZ61jojQPN_nXH7[o000000Oo[VAj00Go0000
ojmUN_n_IG[o[fEjo`000004okAZNP03o`000?nfJg[o]V]j00;o]V]j2Ol00002ok]OGP03o`000?nj
GUko^UiN00;o^UiN00?o0000okmSGol000000ol000000onjAboo0000okDo9`03okDo9`Oo00002_oo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z0?oooo]Z0OoonfX2o`0005[ooo]Z00?o
0000on;:`?oRb/000_oRb/000ol0003oi<o2onC?`P02onC?`P;o00000_oVe<@01?l0003oj=_7onSK
aooXflL2o`0000?of]gH00Go0000omSPgOl0003oemGGo`000004omKRh0;o00000ooFgMd2o`0000Go
`]?W00?o0000ol7Bioo1d^L00oo1d^L2o`000003ok_4hOl0003o[kSP00Go[kSP1?l00002ojZcg`03
o`000?nJY=coVZCL00KoVZCL00?o0000onK=_OoVcKd00_oVcKd01_l0003oj=2nonS@__l0003okM2f
o`0000;okm>f00Oo0000ooOFZoogeZ_o0000ooSJZ_l0003ooMNH00Go00008OoonfX00ol0003ooo]Z
oookJP19oookJP00N_oonfX3o`0003Oooo]Z1ol000000omN01ko0000o`000003o`0000KoQS=L00?o
0000ohllGon??5l00_n??5l8o`0000;oX5Uj00?o0000oj5JN_nQFWX00onQFWX00ol0003oYemjojMO
NP05ojMONP04o`000?nXH7[oZ61jo`0000Oo[VAj00Go0000ojmUN_n_IG[o[fEjo`000004okAZNP03
o`000?nfJg[o]V]j00Go]V]j0_l00004oke`N@Ko000000Co^UiNo`000?noHeoo00000oo1I5d6o`00
0003okDo9ol0003o]ShS00?o000000?oV`T0o`000?l000002?oonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z0?cooo]Z0ol0001KoookJP03o`000?oRb/3oh/[000;oh/[000?o0000onG@
`ol000000_oTcl800ol0003oi]C4onKDa002o`0000Coj=_700Go0000on?KcOl0003of]gHo`000002
omSPg@;o00001?oFh^000ol0003od^?To`000002omKMg@09o`000?oCh^?odn;Som?Rhol0003o`]?W
o`000?o1d^Oo000000Co`M;W00?o0000ok_4hOnka>400_nka>400ol0003o[kSPojnhh003o`0000Oo
Z[?O00?o0000oiZTg?nJY=`00_nJY=`3o`000005on7=aOl0003oi/fmonK=_Ol000001?oXd;h01Ol0
003okm>fonoC]_o_dkKo000000;ommJ[00Go0000ooSJZ_l0003o0000ookJUP04o`00027ooo]Z00?o
0000oookJ_oonfX0BOoonfX007Sooo]Z0_l0000goookJP_o000000?oI@8_o`000?l000000_n6=5h3
o`0000;oQS=L1_l00005oiUCN@03o`000?nPFG[oX5Uj00?oX5Uj00?o0000oj5JN_nQFWX00_nQFWX0
1?l0003oYemjojMON_nWGgXGo`0000;o]6Yj00?o0000okI[N_nfJgX00onfJgX00ol0003o^fmjo`00
0007oke`N@03o`000?nnLWWo_W9i00Go00001?o1I5d01?l0003o`fEKol=UFoo3IE/3o`0000?o`dl[
1Ol00006oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0nOoonfX2o`0005gooo]Z
00?o0000on;:`?oRb/000_oRb/001_l0003oiM33onG@`ol0003oi<o2o`0000?oi]C400?o0000onSK
aooXflL00_oXflL2o`0000;ohm_=00Go0000omSPgOoHh=gof>3Mo`000004omKRh006o`000?oBhnCo
d^?To`000?oFgMgo00001?oCh^<2o`0000;o`M;W00?o0000ol7Bioo1d^L00_l00006ok_4h@;o0000
2onZ/ml4o`0000;oUJ?O00Ko0000on7=aOoQcLGo0000onK=_Ol00004onS@_P09o`000?o_dkKokm>f
o`000?oaekOo0000ooOFZol0003on=ZZ00;o000000?oo]ZFo`000?l000000_l0000RoookJP03o`00
0?oonf[ooo]Z04Sooo]Z001eoookJP?o0000=ooonfX9o`0000;oI@8_0ol000000oml:e_o0000ohHd
GP02ohHdGPCo000000?oTTeho`000?nIDgT02?nIDgT00ol0003oX5Ujoj1INP0<o`0000CoZff;00Co
0000oja^Ron/KX_o00001onaLX/01Ol0003o/g>;ok=cRoncLh_o000000?o]gN;2ol00007oke`N@05
o`000?nnLWWo_W9iokibNOl000000_o3MGT5o`000003ol5TGOl0003o`fEK00?o`fEK1?l000000oo3
Cb_o0000okm78P05o`0000?ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP3foook
JP?o0000G_oonfX00ol0003ohL_1o`000003on;:`005o`000?oUd<?oiM33onG@`ol000001?oVe<@0
1Ol0003oj=_7onSKaooXflOo000000;ohm_=0_l000000ooVi<oo0000omSPg@02o`0000?oe^;P00Co
0000om;Si?oBhnCod^?T0_l00004om?Rh`03o`000?o9h>WobN3Y00;o00000_o1d^L00ol0003o^lCQ
ok_4h@04ok_4h@03o`000?ng`>7o000000SoZ[?O0ol000000onU[]ko0000oiFSg`03oiFSg`03o`00
0?oQcLCo000000;ohLg500?o0000onS@__oXd;h00_oXd;h01_l0003ojM>oo`000?o_dkKo0000oo7G
]`;o00000oohfZX00ol0003oo]ZFo`000003o`0002;ooo]Z00?o0000oookJ_oonfX0B?oonfX007?o
oo]Z0_l0000hoookJPOo00000_mD02H4o`0000?oO2]K00?o0000ohHdG_l000000_l00002oi5=N004
o`000?nBCGSoTTeho`0000OoVE=i1Ol00003ojEXR`03o`000?nVJH_oYVV;00;oYVV;00?o0000oj]]
Ron[KH/01On[KH/01?l0003o[6j;oja^Rol00007ok5bR`05o`000?ncLh_o/g>;ok=cRol000001Ong
Mh/00ol0003o^GR;okUhR`03okUhR`03o`000?nmNh[o000000Co00000onmL7T01Ol0003o_W9iokib
NOnnLWWo000000;o`gEi00?o0000olEgN?o5MgP00_o5MgP6o`000004olMYG?l0003obVYIolYZF@?o
00000onoAb84o`000003oookJ_l0003ooo]Z02Sooo]Z00?o0000oookJ_oonfX0looonfX2o`00067o
oo]Z00Ko0000on7;`OoQbl7o0000on;:`?l00004onG@``04o`000?oVe<Coi]C4onKDa0;o00000_oX
flL01Ol0003ohm_=on?KcOoSflgo000000?oi^C?0ol00002omKRh003o`000?oBhnCod^?T00;od^?T
00Co0000om?RhooCh^?odn;S0_l00004olWPj@03o`000?o1d^Oo^lCQ00Co^lCQ0_l00004okO0h@03
o`000?nZ/mooZ[?O00?oZ[?O0_l00005ojF^gP04o`000?nEXmooUJ?Oo`0000?ohLg400?o0000on7=
aOl000000ooXd;h01_l0003ojM>oonWC_ol0003okm>fo`0000;olMNg00Ko0000ooSJZ_ohfZ[on=ZZ
o`000?onfYH5o`0002;ooo]Z00?o0000oookJ_oonfX0AooonfX0077ooo]Z0_l0000goookJPGo0000
1OmD02H3o`0000GoO2]K0ol00005oi5=N004o`000?nBCGSoTTeho`0000;oVE=i1Ol00002oimSR`03
o`000?nUJ8_oYFR;00;oYFR;00?o0000ojIYRonVJH/00onVJH/00ol0003oZff;oj]]R`04oj]]R`03
o`000?n/KX_o[6j;00;o[6j;00?o0000ok5bRonaLX/00onaLX/00ol0003o/g>;ok=cR`02ok=cR`03
o`000?ngMh_o]gN;00?o]gN;00?o0000okUhRoniN8/00oniN8/00ol0003o_G^:o`000004okimR`[o
000000?o`gEio`000?o5MgP01?o5MgP00ol0003oagQholMhN004o`0000CobVYI0_l000001?noAb;o
0000ok`n4_nl?Q84o`0002Sooo]Z00?o0000oookJ_oonfX0l?oonfX3o`0006;ooo]Z00?o0000onW9
]Ol000000_oQbl400ol0003oiM33onG@``02onG@``;o00000_oVe<@00ol0003oj=_8onSKb002o`00
00Cohm_=00Co0000onKTcooVi<oo00000_oNhML00ol0003oe^;Po`000003om;Si003o`000?o=h^Oo
000000;odn;S00?o0000olWPjOo9h>T00oo9h>T2o`0000Co^lCQ0_l00007okO0h@03o`000?nZ/moo
000000;o00001onU[]h01?l0003oUJ?OoiFSgol00004on7=a003o`000?oRd<Ko000000;oj=2n00Go
0000onWC_ooYdkoojM>oo`000003oo7G]`03o`000?ohfZ[on=ZZ00;o000000?oo]ZFo`000?ongI80
0ol0000SoookJP03o`000?oonf[ooo]Z04Kooo]Z001^oookJP?o0000=ooonfX4o`000003odD08Ol0
003oE00V00;oE00V0ol000000om`8EOo0000og`[F`02og`[F`?o000000?oRDIgo`000?nACGP00onA
CGP8o`0000OoWf>;00?o0000ojEXRonUJ8/00_nUJ8/00ol0003oYVV;ojIYR`03ojIYR`04o`000?n[
KH_oZff;oj]]RaOo000000?o]gN;o`000?niN8/01_niN8/2o`0000Oo_Wf;00Go0000ol1nRoo0OX_o
`7j;o`000002olB1RPCo00000oo5MgP01?l0003oagQholMhN?l00002ol]kM`?o00000_o:JUT00ol0
003oc6]Go`000002o`0000Co_3hB1?l0000VoookJP03o`000?oonf[ooo]Z0>gooo]Z0_l0001Uoook
JP06o`000?oYbKGojLVeo`000?oQbl7o00000ooUd<<00ol0003oim_8onOKb002o`0000?oj=_800?o
0000on?KcOoSfld00_oSfld2o`000003onKTcol0003og^7G00;og^7G0_l00003om;Si003o`000?o=
h^Oo000000;odn;S00?o0000olWPjOo9h>T00oo9h>T01Oo4g>_o0000olSFi?l0003o^lCQ00;o0000
2_ng`>400ol0003oYJkNojF^gP09ojF^gP;o00001OoQcL@01Ol0003oh]36o`000?oXd;ko000000Co
jM>o00Wo0000oo7G]ooaekOo0000oo;J]ol0003on=ZZo`000?ojgJT00_l000001?ongI;o0000o`00
0?l0000SoookJP03o`000?oonf[ooo]Z04Kooo]Z001/oookJP;o0000>?oonfX4o`0000;oA@0Q00?o
0000oe@09_l000000_l00003og0QE`03o`000?ml:e_o000000;o00001?n9AWL00ol0003oTDeho`00
0002o`0000;oV5j:0onIGXX00ol0003oWf>;oimSR`07oimSR`03o`000?nUJ8_oYFR;00;oYFR;00?o
0000ojIYRonVJH/01ol00003ojigU`03o`000?n_N9Oo[gRG00;o[gRG00?o0000ok=kUoncNiL00onc
NiL00ol0003o]7fGokAmU`02okAmU`04o`000?nhP9Oo^82GokR0U`go00001OnnOH/01Ol0003o`7j;
ol1nRoo0OX_o000000?oa86:00?o0000olJ3R_o6PhX01?l00002olMhN004o`000?o;NgOobg]go`00
00;ocGef1?l00003ola[E`?o000000?o_3hBo`000?o:D1P00ol0000VoookJP03o`000?oonf[ooo]Z
0>Wooo]Z0ol0001VoookJP03o`000?oYbKGojLVe00;ojLVe00?o0000onGCaOl000000_oUd<<01?l0
003oim_8onOKb?l00004onSKb006o`000?oSflgohm_=on?KcOl0003oi^??0_l00004omkQe`05o`00
0?oPimSo0000om;Si?l000000_o=h^L00ol0003odn;So`000004olWPj@04o`000?o4g>_oa=c[o`00
00;ob=KT00?o0000okO0hOng`>401_ng`>43o`000003ok:khOl0003oYJkN00GoYJkN0ol00002oj2X
f`03oi6Og_l0003ohLg400?ohLg400Go0000on;@aOl0003oh]36o`000004onWC_`;o000000SolMNg
o`000?obf[Ool]Zgo`000?ohfZ[o0000oo[MZ@;o000000Coo]fBo`000?l0003o00009?oonfX00ol0
003ooo]ZoookJP15oookJP00J_oonfX2o`0003Wooo]Z0ol00003odD08@?o00001Om`8EL3o`0000Ko
RDIg0ol00004oiQNRP05o`000?nIGX[oVEj:oiUNR_l000001onOHh/:o`0000?oZGBG00?o0000ojig
Uon^MiL00on^MiL00ol0003o[gRGojmhU`03ojmhU`03o`000?ncNiOo/g^G00;o/g^G00?o0000okAm
UondOIL00ondOIL00ol0003o^82GokR0U`02okR0U`03o`000?njPYSo^X:H00Go^X:H0_l00002okf4
U`Co000000?o_Wf;o`000?o0OX/00_o0OX/01Ol0003oa86:olB1R_o4PH[o000000GoaX>:1_l00000
0oo;NgOo0000olemMP03olemMP;o00000_o<JeL00ol0003ocVaEoli/E@03o`0000;obU0H0ol0000T
oookJP03o`000?oonf[ooo]Z0>Oooo]Z0_l0001YoookJP03o`000?oYbKGojLVe00;ojLVe0ol00000
0ooUd<?o0000onOKb002onOKb004o`000?oXflSoj=_8onSKb0;o00000_oSfld01?l0003oi^??onKS
col00004omkQe`;o000000?oh>OHo`000?l000000oo=h^L00ol0003obN3YolWPj@02olWPj@03o`00
0?o4g>_oa=c[00;oa=c[00Go0000olSFi?l0003oa=WYo`000005okO0h@;o00001Onb^n400ol0003o
YJkNojF^gP03o`0000GoX:SK00?o0000omc=b_l000000_oQcL@01?l0003oh]35on;@aOoRd<D2o`00
00?ojM>o00?o0000on_G`?o[el000_l00003oo;J]`03o`000?ojgJWon]fY00Co000000?omM5Ro`00
0?oonfX08ooonfX00ol0003ooo]ZoookJP15oookJP00IooonfX3o`0003Wooo]Z1?l00002odD08@;o
000000?oI1ICo`000?m`8EL00_m`8EL3o`000003oh0nMOl0003oRDIg00?oRDIg0ol000000onAF8Wo
0000oiQNRP04oiQNRP05o`000?nIGX[oVEj:oiUNR_l000000_nOHh/5o`0000;oXfnG1?nXLYL00ol0
003oZGBGojUdU`04ojUdU`03o`000?n^MiOo[WNG00?o[WNG00?o0000ojmhUon_N9L00on_N9L00ol0
003o/g^Gok=kU`02ok=kU`03o`000?ndOIOo]7fG00Co]7fG00Co0000okR0UonhP9Oo00002?njPYP0
0ol0003o_HBGokf4U`05okf4U`Wo00001_o6PhX01?l0003oahF:olN5R_l00002ol^7R@?o00000oo=
OGH00ol0003ocgmfo`000003o`000003oli/EOl0003o000000;o000000?obU0Ho`000?o7C1801?l0
000RoookJP03o`000?oonf[ooo]Z0>?ooo]Z0ol0001ZoookJP03o`000?oZbKCo000000;ojLVe00?o
0000onkA]_o^dKH00_l00003onOKb0;o00000_oXflP00ol0003oi^WAonKYd@02o`0000?oi^??00Ko
0000omkQeooNhMOog^7Go`000?oKlml2o`0000?og>oN0_l00003olWPj@;o00001Oo4g>/2o`0000?o
a=WY00?o0000okO0hOl000000_l00008ok:kh@;o00001onPZ=/01_l0003og<g:omc=b_l0003ohLg4
o`0000Coh]350ol00002onWC_`04o`000?o[el3ojmO0o`0000Col]Zg00Go0000oo[MZOl0003o0000
ookMTP02o`000003ooGAH_l0003ooo]Z02Cooo]Z00?o0000oookJ_oonfX0A?oonfX006Gooo]Z0_l0
000joookJPCo00000_m50242o`0000;oI1IC00?o0000og0QEol000000_l00004oh0nM@03o`000?n9
AWOo000000;o00001?nAF8T00ol0003oV5j:oiQNRP03oiQNRP03o`000?nIGX[o000000Co00001onS
KiL01?l0003oZ7:GojQbUol00008ojUdU`03o`000?n^MiOo[WNG00;o[WNG00?o0000ojmhUon_N9L0
0on_N9L00ol0003o/g^Gok=kU`02ok=kU`03o`000?ndOIOo]7fG00Co]7fG00Co0000okR0UonhP9Oo
00002?njPYP00ol0003o_HBGokf4U`06okf4U`05o`000?o1QiOo`HNGol67Uol000000_o4RIH3o`00
00CoaX>:00Co0000olN5R_o7QH[o00000oo;QhT00ol0003ocHV9o`000003o`0000Cocgmf1Ol00000
1?oDLE7o0000o`000?l00003olM<4P?o00008OoonfX00ol0003ooo]ZoookJP3OoookJP?o0000K?oo
nfX01ol0003oj/Vdon[9]?oZbKCo0000onW9]Ol000000_o^dKH3o`000007onOKb?l0003oin?=onOS
cOl0003oj=_8o`000002onKYd@04o`000?oVhlooi^??onKSc`;o00000_oNhML01?l0003ofo?Oo`00
0?l00004omc_gP?o000000?obN3Yo`000?o4g>/01_o4g>/00ol0003oa=WYolCIj@02olCIj@;o0000
1onb^n43o`000003ojffgol0003oX:SK00KoX:SK00?o0000omc=b_oLcLX00_oLcLX00ol0003oh]35
on;@a@02on;@a@06o`000?oTdlKoi=?6o`000?oYdkoo00000oo[el001?l0003ol]Zgoo;J]oobf[L2
o`000003oo[MZOl0003onn6X00?o000000?omM5Ro`000?oonfX09OoonfX00ol0003ooo]ZoookJP13
oookJP00H_oonfX3o`0003_ooo]Z0ol000001?lf01ko0000o`000?l00003of@FD`?o00001_n0?WD3
o`0000OoTER900?o0000oiQNR_nHGXX01Ol00002oiaYUP03o`000?nSKiOoXfnG00SoXfnG0_nXLYL0
1?l0003oZGBGojUdUonYM9LTo`0000Co^X:H00?o0000okf4UonmQ9L01OnmQ9L00ol0003o`HNGol67
U`02ol67U`04o`000?o4RIKoa8VFo`0000;oaX^G0ol000000oo6Ph[o0000olN5RP02olN5RP04o`00
0?o;QhWobhN9o`0000CocHV90ol00002olmoMP;o000000CoeH=co`000?l0003o00000ooDLE42o`00
0003olM<4_l0003oadT:00;o00008?oonfX00ol0003ooo]ZoookJP3MoookJP;o0000KooonfX00ol0
003oj/Vdon[9]002on[9]007o`000?o^dKKok]6fo`000?o^ek_o0000onkG_002o`0000;oin?=0_l0
0002onKYd@;o00000_oVhll01Ol0003oh?7Ko`000?oNhMOo000000;ofo?O00?o0000omc_g_oLkmh0
0_oLkmh01Ol0003od?3Xo`000?oAh>?o000000Coa=c[0ol000001?nnf>go0000olCIjOo4fNT2o`00
0003okkCj_l0003o/[_Q00Co/[_Q0_l00005ojffg`03o`000?nPZ=_oX:SK00?oX:SK00?o0000omc=
b_oLcLX00ooLcLX01Ol0003oh]35on;@aOoRd<Go000000Coi=?600Oo0000on_G`?o[el3ojmO0o`00
0?o/f/7o000000;ol]Zg00Go0000ooCN]ol0003o0000oo_QZ003o`000003ooGAH_l0003ooo]Z02Go
oo]Z00?o0000oookJ_oonfX0@ooonfX0063ooo]Z0_l0000loookJPCo000000?o=P0No`000?l00000
0omT5U<2o`000003ogHfLol0003oP3ie00?oP3ie0ol000000on:DXSo0000oi5HR@06oi5HR@Co0000
0_nMJYL00ol0003oW6VFoiaYUP02oiaYUP03o`000?nSKiOoXfnG00GoXfnG2Ol00005ojUkX004o`00
0?n_Oj3o[gnPo`0000Oo[gjP00Go0000okB3X?ndPj3o]8>Po`000007okF5X@03o`000?niQj3o0000
00Go^8NP2Ol00003okf4U`03o`000?o1QiOo`HNG00?o`HNG00?o0000olB9U_l000001Oo6RiL4o`00
0004olN5R_l0003obhN9o`0000GocHV900?o0000oln;ROo?RhT01?l000001?oEPg?o0000omF3LooE
Pg<2o`000003omAaDOl0003oeg9>00?o000000?oadT:o`000?l000008?oonfX00ol0003ooo]Zoook
JP3IoookJP?o0000L?oonfX00ol0003oj/Vdon[9]003on[9]004o`000?o^dKKok]6fo`0000;ok]Nk
0_l000001?obhKco0000onOScOl00002onKYd@05o`000?oTk]Ko0000onKScol000000_oPlM/2o`00
00;ofo?O0_l00003omc_gP03o`000?o@l>Sod?3X00;o000000?od^[Vo`000?o4g>/00_l00003okkH
k@04o`000?o4fNWo0000o`0000Co_]?Z00?o0000ok:khOl000000_l00008ojffg`05o`000?nPZ=_o
X:SKoj2Xfol000001OoLcLX00ol0003ogLo;o`000002on;@a@03o`000?oTdlKoi=?600;oi=?600Co
0000on_G`?o[el3o00000_o/f/400ol0003ol]Zgo`000002ooCN]`03o`000?okhJSonn6X00?o0000
00?omM5Ro`000?oonfX09_oonfX00ol0003ooo]ZoookJP12oookJP00G_oonfX2o`0003cooo]Z1?l0
00001_lf01ko0000o`000?mE2Dko0000of@FD`;o00000omf=W<00ol0003oP3ieo`000002o`0000Co
RU:800?o0000oi5HROnAF8T00_nAF8T3o`000003oiMUU_l0003oWFZG00;oWFZG00?o0000oiaYU_nL
JIH00onLJIH00ol0003oXfnGoj=_U`05o`0000?oYGRP00?o0000ojUkX?nYNj002?nYNj000ol0003o
[gnPo`000008ojmnX004o`000?ndPj3o]8>Po`0000Wo]HFQ00?o0000okR7X?nhQj001onhQj000ol0
003o^hZQo`000003okn<X0Oo00000_o1QiL2o`0000OoaX^G00?o0000olN=Uoo7SIL01_l00003olf9
R@03o`000?o?RhWoch^900?och^90ol00002omF3L`03o`000?oGQG;o000000;o00000ooGLTh5o`00
01kooo]Z00?o0000oookJ_oonfX0eooonfX2o`0007?ooo]Z00?o0000on[9]?oZbK@00_oZbK@01Ol0
003ok]6fo`000?o^dKKo000000;ok]Nk00Co0000oo;Q_?obhKcol^6l0_l000001_oVjM7o0000onC^
e_l0003oi^??o`0000?oh?7K00Oo0000om_cgooKlmoo0000omKbi?l0003og>oN00;o00000oo@l>P0
0ol0003od^[Vom;ZiP02o`0000Co_]S]00?o0000olCIjOl000001_nndnX2o`0000co[KKO0ol00005
omc=bP06o`000?oMcl_ogLo;o`000?oRd<Go00001?oTdlH3o`000007on_G`?l0003ok=[1oncJ`Ol0
003ol]Zgo`000002ooCN]`03o`000?okhJSo000000;o000000?oo>6:o`000?l000009ooonfX00ol0
003ooo]ZoookJP12oookJP00FooonfX3o`0003cooo]Z0_l000000olA007o0000ocH07P02o`0000;o
E@U>0ol00004ogHfL`?o00001on:DXP00ol0003oTER9o`000002o`0000CoUfFF00Co0000oieZUonM
JYOo00001?nLJIH5o`0000OoYGRP0_l0000:ojUkX0;o00002_n_OZ02o`0000[o]HFQ00?o0000okR7
X?nhQj001_nhQj001?l0003o^hZQok^:XOl00005okn<X003o`000?o1Sj;o`HnR00;o`HnR1_l00005
olJ;U`07o`000?o7SIOoahfGolN=Uol0003obXnFo`000002olbAUPCo00001Oo?RhT00ol0003oe8n7
o`000003o`0000?oehEb0_l00002omMbCP03o`000?oHLDSo000000Co00007OoonfX00ol0003ooo]Z
oookJP3CoookJP?o0000M?oonfX00ol0003ojlZdo`000002on[9]003o`000?o^dKKok]6f00;o0000
0oo^ek/01?l0003ol^6loo;Q_?obhK`7o`0000?oh?7K0_l000001_oKlmoo0000omKbi?l0003og>oN
o`0000Cod?3X00Co0000om;Zi_oBj^Ko00000_o;j>/01?l0003o_]S]okkHkOnnf>d2o`0000Go_]?Z
0_l00002okO3h`03o`000?n]]]oo[KKO00Co[KKO0ol00002ojR_g@04o`000?oGc<ooelc?o`0000?o
g<g:00?o0000omg?booMcl/00_oMcl/00ol0003oi=?6onCCaP02onCCaP03o`000?oTe/Soi=K800;o
00001?o/f/400ol0003om=jgooCN]`02o`000005oo_QZ?l0003onnBVo`000?olhHX00_l0000Xoook
JP03o`000?oonf[ooo]Z047ooo]Z001IoookJP;o0000?OoonfX3o`000004oa400Ol0003o0000o`00
00?oE@U>0_l00004ogHfL`;o000000?oPTb7o`000?n:DXP01_n:DXP3o`0000SoUfFF1ol00002oj1d
X@03o`000?nUN:3oYGRP00KoYGRP00?o0000ojIhXOl000002_nYNj000ol0003o[gjPojmnX009ojmn
X0;o00002_neQJ400ol0003o^8NPokR7X006okR7X005o`000?nkRZ7o^hZQok^:XOl000000onoS:00
0ol0003o`HnRol6?XP05ol6?XP;o00000_o3T:03o`000003olJ;Uol0003oahfG00?oahfG00?o0000
olZ?U_l000001Oo<TIH3o`0000?och^900?o0000omB?Qol000000_oDShL2o`0000;oehEb00?o0000
omZ7LOl000000ol00002omQaB004o`000?o0>`3o0000o`0001gooo]Z00?o0000oookJ_oonfX0d?oo
nfX2o`0007Oooo]Z00Ko0000on_:]?o[b[Co0000on[9]?l00003onkA]P03o`000?o^ek_ok]Nk00;o
00000_obhK`01?l0003ok^G5o`000?l00002oo3_a0?o000000Goh?7Ko`000?l0003ofo?Oo`000002
omKbi003o`000?oLkmkod?3X00?od?3X00Cobnc/o`000?oBj^Ko00001?o;j>/00ol0003o_]S]o`00
0005okkCjP;o00001Ong`n<00ol0003o[KKOojffg`03o`0000GoZ:oM00Oo0000omO<cooGc<ooelc?
o`000?oLcL[o000000GogLo;00Go0000onCCa_oTdlKoi=?6o`000004onCFb0;o00000oo/f/401Ol0
003om=jgooCN]ol0003omN>g00;o000000?onnBVo`000?olhHX00_l0000YoookJP03o`000?oonf[o
oo]Z043ooo]Z001GoookJP;o0000?_oonfX2o`000004oa400Ol0003o0000o`0000?oE@U>0_l00000
0om[;G3o0000ogHfL`03o`0000?oPTb700?o0000ohYBR?n:DXP00_n:DXP3o`000003oi1QU_l0003o
UfFF00SoUfFF0_l00007oj1dX@03o`000?nUN:3oYGRP00GoYGRP00Go0000ojIhXOnVN:7oYWRQo`00
0004ojUkX2Wo000000?o^hZQo`000?noS:000_noS:000ol0003o`HnRol6?XP05ol6?XP03o`000?o3
T:3o`i2P00Co`i2P1Ol00002olN=U`03o`000?o<TIKoc96F00Coc96F00?o0000oljCU_o>TiH01_l0
0002omB?Q`03o`000?oGTHOo000000;o00001?oJQg42o`000006omQaB?l0003o0000o`000?o=C`3o
00007?oonfX00ol0003ooo]ZoookJP3=oookJP?o0000NOoonfX01Ol0003ojlZdon_:]?o[b[Co0000
00Cok]6f00Go0000onkG^oo^ek_o0000oo;Q^`02o`0000;ok^G500Go0000oo3_a?o`klCol>o4o`00
0002onO^d@04o`000?oPlM_o0000o`0000?oe_;T00?o0000om3`j?o@l>P00_o@l>P01?o;k>co0000
om;Zi_l00005ol_Xj`;o00001?nndnX2o`0000So]l?S0_l00007ojR_g@03o`000?oGc<ko000000?o
elc?00?o0000omg?booMcl/00ooMcl/00ol0003og];<o`000002onCCaP03o`000?oTe/Soi=K800;o
i=K800Co0000ongK`?l0003ok=[10_l000001Oodg[Oo0000ooGS]ooehkOo000000;onnBV1?l0000Y
oookJP03o`000?oonf[ooo]Z043ooo]Z001DoookJP?o0000?ooonfX4o`000004od40A?l0003o0000
oeD9CP;o00000_m[;G03o`0000KoPTb700?o0000ohYBR?l000000_l00004oi1QUP03o`000?nGIIKo
UfFF00CoUfFF1?l00009oj1dX@03o`000?nUN:3oYGRP00?oYGRP00?o0000ojIhXOl000001ol00004
ojb2Z003o`000?n]Q:So000000Wo/HJX0_l00009okB9Z003o`000?ngS:So000000Oo^XjW1?nkT:T7
o`0000Ko`HnR00?o0000ol>@X?o3T:001Oo3T:001?l0003oaiBRolNDX_o7U:85o`0000Coc96F00?o
0000oljCU_o>TiH00oo>TiH3o`0000;oe8n700Co0000omNAQooGTHOoei670_l00003omZ7L@04o`00
0?oLRG3o0000o`0000;oh7Y600Co0000ole?0?l0003o00006ooonfX00ol0003ooo]ZoookJP3:oook
JP;o0000NooonfX00ol0003ojlZdon_:]002on_:]004o`000?o^dKKok]6fonkA]P;o000000Gok]Nk
o`000?obhK_ol^6ko`000003onkUa@03o`000?o`klCol>o400;o000000?oinkAo`000?oRl=P00_l0
0003omKbi0;o00000_o@l>P3ol_/k0;o00001?o;j>/2o`000003ol3Ql?l0003o000000;o_]?Z00?o
0000okO3hong`n<01Ong`n<2o`000003ok:lhOl0003oZ:oM00KoZ:oM00Ko0000omO<c_oGc<koelc>
o`000?oGc<l2o`0000CogLo;00Ko0000omkBc?oNd/co0000onCCa_l00004onCFb0;o00000_o]fl00
0ol0003okMk2ongN`P02o`0000;omN>g00?o0000oo_TY_l000001?l0000ZoookJP03o`000?oonf[o
oo]Z03oooo]Z001BoookJP;o0000@OoonfX3o`0000;o@@141?l00003of/]L0;o00001on2C8L3o`00
00OoT66F00?o0000oiMUU_l000001Ol00002oiY_X003o`000?nPM:7oX7BQ00OoX7BQ00?o0000ojEh
X?nUN:001Ol00003ojMnZ0So[8:X00Co0000ojf4Z?n]Q:So00002?naQZP00ol0003o/XRXo`000008
okB9Z004o`000?ngS:So]hbXo`0000Ko^XjW00?o0000ok^@ZOnkT:T00onkT:T01?l0003o_Y6XokjA
Z?l00002okjAZ0Co000000Co`HnRo`000?o2Sj7o00001Oo3T:000ol0003oaiBRolNDXP04olNDXP03
o`000?o9UZ7obIJQ00Co00001_o>TiH6o`0000Coei670_l00002omZ7L@03o`000?oLRG3og8U`00;o
00000_oPNTH5o`0001Wooo]Z00?o0000oookJ_oonfX0aooonfX3o`0007gooo]Z00Wo0000on_:]?o[
b[CojlZdo`000?o_dkKo0000onkA]_l000000_obfkP2o`0000;ol^6k00?o0000onkUaOo^iLD00_l0
00000oo`klCo0000onO^d@02o`0000;oh_3H00?o0000on7he_oQn=H00ol000000oo@l>So0000ol_/
k003ol_/k003o`000?o;j>_obnS[00;obnS[00Go0000ol3Ql?o0hO3o`>7`ol3Dj@02o`0000Ko]l?S
0_l00005ok:lh@04o`000?nX[mgoZ:oMojR_g@?o00001OoGc<h01?l0003of<k@omS>d?l00002omg?
b`03o`000?oNd/cog];<00;og];<00?o0000onCFb?oTe/P00_oTe/P00ol0003oi]W8onKIb002o`00
0004onkN`Ol0003okMk2o`0000;omN>g0_l000000ooki:Ko0000o`000003o`0002[ooo]Z00?o0000
oookJ_oonfX0?ooonfX0053ooo]Z0_l00011oookJPCo00000_m104@3o`0000?oJbe`0_l000000omh
AHKo0000oh9<Q`04oh9<Q`;o000000?oRE^Fo`000?n@HIH01_n@HIH3o`0000?oVg2Q0_l00003oiY_
X003o`000?nPM:7oX7BQ00GoX7BQ1Ol000000onWOjSo0000ojMnZ005ojMnZ003o`000?n/PZSo[8:X
00Co[8:X00?o0000ojf4Z?n]Q:P00_n]Q:P00ol0003o/HJXok66Z004ok66Z005o`000?nbR:So/XRX
ok:8Z?l000001_ndRJP00ol0003o]hbXokN<Z002okN<Z003o`000?njSZOo^XjW00;o^XjW00?o0000
ok^@ZOnkT:T01?nkT:T00ol0003o_Y6Xo`000007okjAZ0Oo00000_o3T:000ol0003oaiBRolNDXP04
olNDXP03o`000?o9UZ7obIJQ00?obIJQ0ol00004oljCUP?o00000_oCUiD2o`0000?oei6700?o0000
omVDQ_l000000_l00002omb9L0?o000000?oh7Y6o`000?oPND801?l0000IoookJP03o`000?oonf[o
oo]Z0<Cooo]Z0_l00020oookJP09o`000?o[b[CojlZdon_:]?l0003okm>fo`000?o^dKKo000000;o
l]^h00?o0000oo;Q^oobhK/00_l000002?o^iLGo0000oo3_a?l0003ol>o4o`000?oWk]7o00000_oR
l=P2o`000004on7he_l0003oc_kOolkng`;o00001?o;k>`01?l0003obnS[ol_Xjoo;j>/2o`0000?o
`>7`0_l00003ol7Lk@03o`000?ng`n?o000000;o00002?nb_>43o`000003oj>Xf_l0003oelc>00Co
elc>00Oo0000omS>d?l0003of<k@o`000?oMcl_o000000Gog];<00Go0000onCFb?oTe/Soi=K8o`00
0003onKIb004o`000?o^g/7ok]k1onkN`@;o000000ComN>go`000?oei[SomNJh0ol000000oohhh?o
0000o`00000[oookJP03o`000?oonf[ooo]Z03kooo]Z001=oookJP?o0000@_oonfX3o`0000?o@@14
0_l000001OmN8fco0000of/]L?m[;G3o000000?oN4F600?o0000oh9<Qon2C8L00ol00003ohUKUP03
o`000?n@HIKoT66F00;oT66F0ol000001?nEK:7o0000oi]`XOnKL:42o`0000GoVVnP00?o0000oj1d
XOnPM:401Ol00002oj=kZ004o`000?nWOjSoYgnXo`0000SoYgjX00?o0000ojb2Z?n/PZP00_n/PZP0
0ol0003o[HBXojf4Z003ojf4Z003o`000?naQZSo/HJX00?o/HJX00?o0000ok:8Z?nbR:P00_nbR:P0
0ol0003o]8VXokB9Z003okB9Z003o`000?ngS:So]hbX00?o]hbX00?o0000okZ>YonjSZL00_njSZL0
0ol0003o^i2Yok^@Z@05ok^@Z@;o00002?nnTJP00ol0003o`IFYo`000003olBGZ0Co00001?o7U:82
o`0000GobIJQ00?o0000olfIX?o=VJ001?l00002om2FU`05o`000?oCUiGodiNEo`000?oEVID01?l0
0003omVDQPGo000000CohXi/o`000?l0003o00000_oPND83o`0001Wooo]Z00?o0000oookJ_oonfX0
`?oonfX3o`00087ooo]Z00Go0000on_<]Ol0003ojlZdo`000003onoC]P05o`000?obfkSol]^hoo;K
^?l000000_obhK/2o`000003onkUaOl0003ol>o400;o00000_oWk]401_l0003oh_3Ho`000?l0003o
hOSFo`0000;oc_kO00Co0000omCjh_oDn^;oe?[R0ol00003ol_Xj`03o`000?o0hO3o`>7`00?o`>7`
1Oo1g>d2o`0000Oo/[cQ0ol000001On]]Moo0000oj>Xf_nSZ=[o000000Goelc>00Oo0000omS>d?oH
c]3of<k@o`000?oHc]3o000000Gog];<00?o0000on3EcOl000000_oTe/P01Ol0003oi]W8onKIb?oV
fLSo000000?ok]k11?l00002ooGV^004o`000?okj:Co0000ooSSP`;o0000;?oonfX00ol0003ooo]Z
oookJP0moookJP00BooonfX2o`0004Cooo]Z0_l000001Ol^03co0000od40A?m104Co000000?oGR=/
0ol00004ogQ5QP?o00001_n9FiH00ol0003oT66Fo`000002o`0000GoUFbQ0_l00006oiY_X0Co0000
2?nSNjP2o`0000WoYgjX00Go0000ojb2Z?n/PZSo[8:Xo`000002ojf4Z1ko000000?o^XjWo`000?nk
T:T01onkT:T00ol0003o_Y6XokjAZ006okjAZ004o`000?o1UJWo`IFYo`0000Coa9NX00?o0000olJH
Z?o6V:P00ol000001?o7U:;o0000olRFXOl00003olVFX@03o`000?o=VJ3ocIVP00CocIVP1?l00002
om>GU@03o`000?oEVIGoeIVE00;oeIVE0_l00002omVDQP03o`000?oKUXKofiJ600?o00000_oRSV`2
o`000005on1i@_l0003o0000olQ80?l000006?oonfX00ol0003ooo]ZoookJP2moookJP?o0000Pooo
nfX01_l0003ojlbeon_<]Ol0003ojlZdo`0000?okm>f00?o0000oo;K^?obfkP00_l000000oobhK_o
0000oo;[_`02o`0000;ol>o400Oo0000onO^dOoWk]7o0000on;`f?l0003odooG00;o00000_o>o]l0
1_l0003oe?[RomCjh_oDn^;o0000olKfk@;o00000_o;j>/4ol3Ql003o`000?o0fngo000000?o`Mc]
0_l000000onjb>Go0000ok:lh@04ok:lh@;o00001On]]Ml2o`000003om?;d_l0003oelc>00;oelc>
00?o0000omS>d?oHc]000ooHc]02o`0000Cog];<00Ko0000on3EcOoPeLgo0000onCFb?l00003onKI
b0;o00000_o^g/400ol0003okN74ongQa003o`000003ooGV^?l0003onnRT00Co0000;?oonfX00ol0
003ooo]ZoookJP0moookJP00B?oonfX3o`0004Gooo]Z0_l000000ol^03co0000od40A002o`0000?o
GR=/0_l00005ogQ5QP;o00001on9FiH3o`0000OoUFbQ0_l00004oiY_X0?o000000?oWWRXo`000?nS
NjP02?nSNjP2o`0000OoYgjX2_l00004ojf8[P03o`000?naS:ko/Hb^00;o/Hb^00?o0000ok6;[_na
Rjh00onaRjh00ol0003o]Xn^okJ?[P02okJ?[P03o`000?nfSjko]Xn^00Co]Xn^00?o0000okZC[_nj
Tjh02ol00007okjAZ005o`000?o1UJWo`IFYol6EZOl000000oo4UjP00ol0003oaYRXolJHZ004olJH
Z0Co00000oo9UZ400ol0003ocIVPolfIX004olfIX003o`000?o?W:;ocibR00?o00001OoEVID01Ol0
003oeibEo`000?oIU8Ko000000;ofiJ600Oo0000omjHQOl0003o0000on:>K?l0003oi91Z00;o0000
00CohWXmo`000?o8B03o00006?oonfX00ol0003ooo]ZoookJP2joookJP;o0000Q_oonfX01Ol0003o
jlbeon_<]Oo[c;Go000000?okm>f0_l000001?obfkSo0000ooCV^oodi[/2o`000003oo;[_ol0003o
l>o400;ol>o400?o0000onO^dOl000000_l00002om?oe`05o`000?o>o]ooc_kOolkngol000000_oD
n^800ol0003oa_K]olKfk@03o`0000?o`>7`0_l000000oo0fngo0000ol7Lk@02ol7Lk@03o`000?nj
b>Go^/SU00;o^/SU00?o0000ok:lhOl000000_l00007ojfeg`07o`000?oCbm;odl_Bom?;d_l0003o
elc>o`000005omS>d0;o000000GofM7Ao`000?oNd/cog];<o`000004on3Ec@05o`000?oVfLSoi]W8
onKIb?l000000_oWg<T2o`0000?okN7400?o0000ooKV]_ofi[H00ol000001?ojjZ;o0000o`000?l0
000]oookJP03o`000?oonf[ooo]Z03cooo]Z0016oookJP;o0000AooonfX00ol0003o;P0lobh0?003
o`000007oe`QK?l0003oGR=/oehSK?l0003oKSf4o`000003ogQ5QP;o000000?oPEFEo`000?n9FiH0
1?n9FiH2o`000003ohmWXOl0003oUFbQ00GoUFbQ0_l000000onDJj3o0000oiY_X003o`0000CoWWRX
00?o0000oj=kZ?nSNjP01OnSNjP2o`000004oj=lZ?l0003oYgjXojMnZ0Go00000onYQJh2o`0000Wo
[HR^00Go0000ok6<[_naS:ko/Hb^o`000007ok6;[P04o`000?nfSjko]Xn^o`0000So]Xn^0_l00009
okZB[PKo00000onnTJP00ol0003o`IFYol6EZ@02ol6EZ@03o`000?o4UjSo000000OoaYRX00?o0000
olNKZOo7VjT00ol000000oo9UZ7o0000olfIX004olfIX004o`000?o?W:;ocibRolnLXPCo00001?oE
VID00ol0003oeibEomNLU@02o`0000;ofiJ600Co0000omjHQOl0003ohIZ40_l00002onB@JP;o0000
00?ohWXmo`000?l000000_l0000GoookJP03o`000?oonf[ooo]Z0;Kooo]Z0ol00027oookJP03o`00
0?o[c;Gojlbe00;ojlbe00Co0000onoC]_o_dkKo00000_oci;/2o`0000;om>Jk00Co0000oo;[_oob
jkoo00000_o`kl@3o`000005omWod?l0003odooGom?oeol000000oo>o]l01?l0003oe?[Ro`000?l0
0002olKfk@;o00000_o9lNd00ol0003o`>7`o`000002ol3Kk@03o`000?o1g>go`Mc]00;o00001_nj
b>D00ol0003o[KGOojfeg`07ojfeg`03o`000?oCbm;odl_B00?odl_B00?o0000omS>d?oHc]000ooH
c]000ol0003ofM7AomWAd@02o`000003omkBc?l0003oh=G=00Coh=G=00Co0000onKIb?oVfLSo0000
0ooWg<T2o`0000?okN7400?o0000ooKV]_ofi[H01ol0000]oookJP03o`000?oonf[ooo]Z03cooo]Z
0014oookJP;o0000B?oonfX01_l0003o;P0lobh0??l0003oCAAWo`0000;oG25/0ol00002ofhmQ004
o`000?mhAHKo0000o`0000?oPEFE00Co0000ohUKU_n9FiKoRE^F0_l00003ohmWX@03o`000?nEK:7o
UFbQ00;oUFbQ0_l00002oiA[X0?o00002?nNN:P00ol0003oXg^Xoj=kZ003oj=kZ003o`000?nSO:So
000000Co00001onYQJh2o`0000_o[HR^00?o0000ok6<[_l000002?naRjh00ol0003o]Xn^o`000009
okJ?[P03o`000?njTZko^Y:^00Oo^Y:^00?o0000okbF[ol000001?noUjh6o`0000;o`IFY00?o0000
olBGZ?l000001_o6V:P01Ol0003oai^YolNKZOo7VjWo000000;obIbX0ol00004olfIX004o`000?o?
W:;ocibRolnLXP?o000000?odIfQo`000?l000000_l00004omNLU@?o000000?ofiJ6o`000?l00000
0_oQVX@2o`0000;oi91Z0ol000001?oSNSOo0000olA40?l0000FoookJP03o`000?oonf[ooo]Z0;Co
oo]Z0_l0002:oookJP09o`000?o[c;Gojlbeon_<]Ol0003ol=Rho`000?o_dkKo000000;olnBk00Ko
0000ooCV^oodi[_om>Jko`000?objkl2o`000004oo3_a?l0003o0000onO^d@;o00000ooComL01?l0
003oc_kOolkngoo9n^L2o`0000Coa_K]1?o9lNd4o`000004ol3KkOl0003o`Mc]o`0000Ko^/SU00?o
0000okC1i?l000001_n]]Ml3o`0000Godl_B0_l00004omS>d007o`000?oIdM7ofM7AomWAdOl0003o
fM7Ao`000005on3Ec@;o00000_oVfLP01Ol0003oimc9onOLbOoWg<Wo000000?okN740_l000000oof
i[Ko0000ooGY^@02o`000004ooW/YOl0003o0000o`0002kooo]Z00?o0000oookJ_oonfX0>ooonfX0
047ooo]Z0ol00019oookJP04o`000?l^03co;P0lo`0000;oCAAW00Co0000oe`QK?l0003o00000om^
?H@3o`0000KoPEFE0ol00006ohmWX@05o`000?nEK:7oUFbQo`000?nDJj000ol000000onHM:Wo0000
oiihZ008oiihZ003o`000?nSNjSoXg^X00Go00000_nTPZl00ol0003oZHF^ojV5[P06ojV5[P03o`00
0?nZQZoo000000_o[HR^0_l0000:ok6;[P03o`000?nfSjko]Xn^00Oo]Xn^0_l00008okZB[P05o`00
0?nlUZoo_9J_okbF[ol000001OnoUjh01?l0003o`IZ`ol6J/?o1V[06o`0000GoaYRX00Go0000olNK
ZOo7VjWoai^Yo`000002olVLZ003o`000?o:W:SobYbX00?o000000?ocIVPo`000?o?W:800oo?W:80
0ol0003odIfQom6MX@03om6MX@;o00000ooGW9D00ol0003ofIjFomVNUP03o`0000?ohIZ40_l00000
0ooTT6[o0000onNBI`02o`000004on=j=ol0003oa4@0o`0001Kooo]Z00?o0000oookJ_oonfX0/?oo
nfX3o`0008cooo]Z00ColLRWo`000?o[c;Go00000oo`f;P01Ol0003olnBkoo?T^ooci;_o000000;o
m>Jk0ol000000ooXnlGo0000oo3_a003o`000005omWod?l0003odooGom?oeol000000_o>o]l00oo9
n^Oo0000omCjhP03olKfk@03olW`kOl0003obO7]00;obO7]00?o0000okkXl_nnj?800_nnj?800ol0
003o`Mc]ok[8i@04ok[8i@;o00001?nd`N@00ol0003o[KGOojfeg`03o`000003ojR^g?l0003odl_B
00Codl_B00Co0000omC>dooDc]?o00000_oHc]000ol0003ofM7AomWAd@03omWAd@;o00001?oPeLd0
0ol0003ohMS>on7HcP02o`0000Coimc900Co0000ongQa?o]hLCo00000_o_iL<2o`000004ooGY^Ol0
003onNbUooW/Y@?o0000;ooonfX00ol0003ooo]ZoookJP0joookJP00?ooonfX2o`0004_ooo]Z0_l0
00000ol^03co0000oddDI`02oddDI`?o00000om^?H@2o`0000OoPEFE0_l00008ohmWX@Go00001?nH
M:T00ol0003oWWRXoiihZ006oiihZ0Go00001onTPZl00ol0003oZHF^ojV5[P04ojV5[P04o`000?nZ
QZooZXJ_o`0000[o[HR^0_l0000:ok6;[P;o00002?nfSjh01?l0003o^96_okRA[ol00006okZB[P03
o`000?nlUZoo_9J_00;o_9J_00?o0000oknG[_noUjh00_noUjh00ol0003o`IZ`ol6J/005ol6J/003
o`000?o3Vjoo`i^_00?o00000_o6V:P00ol0003oai^YolNKZ@02olNKZ@;o00001_o:W:P2o`0000Co
cibR00?o0000om6MXOoAWJ400ooAWJ400ol0003oeJ6Po`000002omNLU@04o`000?oIWYKofIjFomVN
UP?o00000_oQVX@00ol0003ohib3o`000002o`0000;oii9W00?o0000on=j=ol000000_l0000Eoook
JP03o`000?oonf[ooo]Z0:kooo]Z0_l0002>oookJP05o`000?oab:Oo0000on_<]Ol000000oo`f;P0
0ol0003olnBkoo?T^`02o`000006ooCV^ol0003o0000oo;[_ol0003oj?_50_l000000ooPo/[o0000
omWod002o`000004om?oeol0003o0000olkng`;obO[W00Ko0000olKfkOo6m^go0000olW`kOl00002
olWak@;o00001?nnj?82o`0000Co^/SU0_l00007okC1i0;o00000onX[]`2o`0000Codl_B00Oo0000
omC>dooDc]?oe<kCo`000?oHc]3o000000GofM7A00Co0000omWCd_l0003o00000_oPeLd01Ol0003o
hMS>on7Hc_oQf<ko000000Coimc90_l00002ongQa004o`000?o_iL?oknG3o`0000;omNVi00?o0000
ooW/YOl000000_l0000`oookJP03o`000?oonf[ooo]Z03[ooo]Z000moookJP;o0000BooonfX5o`00
00?oCAAW0_l00002ofdlQ005o`000?m^?HCo0000ogU?U?l000001On1EID2o`000003ohQSXOl0003o
SfNQ00GoSfNQ1?l00008oiQdZ@03o`000?nNN:SoWWRX00;oWWRX0ol000001?nPOjoo0000ojF3[ol0
0008ojB2[`03o`000?nYQJkoZHF^00?oZHF^00?o0000ojZ6[onZQZl00_nZQZl00ol0003o[HR^ojf8
[P02ojf8[R;o00000_njTZh00ol0003o_9J_okbF[`03okbF[`05o`000?noUjko_iN^oknG[_l00000
1oo1V[000ol0003o`Y^`o`000004ol>K[`Go00000_o7VjT00ol0003obYbXolZLZ005olZLZ003o`00
0?o=X:Wo000000;o000000?ocibRo`000?oAWJ400ooAWJ401?l0003oeJ6PomFQX?oEXJ02o`0000Co
fIjF0_l000001?oLXIGo0000o`000?l00003on>LP`03o`000?oWTVOoii9W00?o000000?oiGX`o`00
0?l000005OoonfX00ol0003ooo]ZoookJP2ZoookJP?o0000T?oonfX00ol0003olLRWoo78Y`03o`00
0008oo3H^?l0003o0000oo?T^ol0003olnnno`000?odi[/3o`0000;oj?_500?o0000on3nb_l00000
0ol000001?oComOo0000omOmfol00002olWji`06o`000?o6m^goa_K]o`000?o9l>go00000_o9lNd0
0ol0003o_^SbokkXlP03okkXlP05okWOlol0003o`=o_o`000?njb>D00_l00006okC1i0;o000000Co
[kWQo`000?nX[]coZ:kL0_l00002om;;d`04o`000?oCbm;odl_Bo`0000Goe<kC00?o0000omWAdOoI
dM400ooIdM401ol0003ofM?BomWCd_oIdm;o0000on3EcOl000001?oQf<h01Ol0003oimc9onOLbOoW
g<Wo000000;oj>3:0_l00003onoU``03o`000?oejKWo000000;o000000?on>fOo`000?l00000<Ooo
nfX00ol0003ooo]ZoookJP0ioookJP00>_oonfX3o`0004cooo]Z0ol000000olH03?o0000oddDI`02
oddDI`03o`000?mQ<h;o000000;oKCb40ol000000omiCiCo0000oh5EU@02oh5EU@;o00000on8Hj40
0ol0003oSfNQo`000005o`000003oi=aZOl0003oV7BY00SoV7BY00?o0000oiihZ?l000000_l00004
oj1o[`;o00002OnTPZl00ol0003oZHF^ojV5[P02ojV5[P03o`000?nZQZooZXJ_00So00000_n^S[@0
1?l0003o[Xfcojj=/on^SK<8ok:A/`05o`000?ncT[Co/i:dok>B]?l000001_ngU;<00ol0003o^9Je
okRF]@02okRF]@04o`000?nkV;Co^iRdok^H]0Ko00000onlUZl00ol0003o_iN^o`000007ol6J/004
o`000?o2Vk3o`Y^`o`0000Go`i^_00Co0000olJN[oo6WZooaYj_0ol00006olZLZ003o`000?o=X:Wo
cJ2Y00?ocJ2Y0ol00003om6MX@03o`000?oEXJ3oeJ6P00;oeJ6P0_l00003omVNUP03o`000?oLXIGo
g:6E00;og:6E00Co0000on>LPooSW8?ohib30_l000000ooWTVOo0000onVDI@02o`000003onEj<?l0
003o000001Gooo]Z00?o0000oookJ_oonfX0YooonfX2o`0001Gooo]Z3Ol0001`oookJP05o`000?oa
b:OolLRWoo78Yol000000_ofdZP5o`000005oo?___l0003o0000onkf`Ol000000_oXnlD:o`000006
olWjiol0003o0000o`000?o6m^go00000_o9l>d00ol0003obO7]o`000003okkXlP04o`000?nigo?o
^Moco`0000;o`=o_0_l00005okC1i0?o00001?n_^N42o`000007olk:e_l0003od/_Com;;dol0003o
dl_Bo`000005omC>d`;o00001?oIdM400ol0003ofM?BomWCdP02omWCdP;o00001?oQf<h00ol0003o
hM_@o`000002onOLb@04o`000?oXh<[oj>3:o`0000?oknG30ol000001?ofkKKo0000o`000?ohkIl2
o`00037ooo]Z00?o0000oookJ_oonfX0>OoonfX003Wooo]Z00?o0000oookJ_oonfX0C?oonfX2o`00
0005oa00;Ol0003o0000o`000?m=56L00_l00002of4cPP03o`000?m]?8Co000000?oN4nE1Ol00000
0on8Hj7o0000o`000004o`000004ohiWX?l0003o0000o`0000?oTg6Y00?o0000oiQdZOnHM:T01_nH
M:T3o`0000GoX7n_0_l000000onPOjoo0000ojB2[`09ojB2[`03o`000?nYQJko000000Co00000onZ
Rk@00ol0003o[Xjdojj>]003ojj>]003o`000?n^SK?o[Xfc00?o[Xfc1_nbTK<00ol0003o/i:dok>B
]003ok>B]003o`000?ngU;?o]iBc00;o]iBc00?o0000okRF]OnhU[D01?nhU[D01Ol0003o^iRdok^H
]?nkV;Co000000Co^YRd2Ol00003ol6J/005o`000?o2Vk3o`Y^`ol:K/?l000001?o3Vjl00ol0003o
aYj_olJN[`04olJN[`Go00000_o:W:P00ol0003ocJ2YolfPZ@03olfPZ@;o000000GodJ>Yo`000?l0
003odIfQo`000004omFQX003o`000?oGY:7o000000?o00001?oLXID2o`0000;ohib300Co0000onJO
P_l0003o00000_oYU6D5o`0001Cooo]Z00?o0000oookJ_oonfX0Y?oonfX3o`0001Cooo]Z0ol00000
1OnN]^Wo0000ogjZl?mnZ_3o000000KoPZc`00?o0000odfCkol000000ol0001/oookJP08o`000?oa
b:OolLRWo`000?ogdJKo0000ooKBZ?l00002ooSM[@[o000000Goio_4o`000?l0003of?kEo`000002
om;mgP04o`000?o6om?o0000okOlh@Co000000?obO3]o`000?o9lNd00onnj?801_l0003o^MocokWO
lonigo?o0000ol3Ok`;o00000onjenh01?l0003o]<7To`000?l00007ojnih@05o`000?o>b]Koc/[F
olk:e_l000000_oBbm<00ol0003oe<kComC>d`03omC>d`04o`000?oDd=Goe=3Eo`0000;ofM7A00?o
0000omWCd_oIdm800ooIdm82o`0000?ohMS>00Ko0000on7Kd?oQfm3o0000onOLbOl00003onSPbP05
o`000?o_iL?oknG3o`000?o`j<<00_l000001?ofkKKo0000ooS]WoohkIl2o`0003;ooo]Z00?o0000
oookJ_oonfX0>?oonfX003Wooo]Z00?o0000oookJ_oonfX0C?oonfX01Ol0003o400]oa00;Ol0003o
?0MQ00;o00001?mQ<h82o`0000GoN4nE1Ol00004ohQSX@?o00001onCLJT00ol0003oV7BYoiQdZ@02
oiQdZ@?o000000?oVgb`o`000?nPOjl00onPOjl2o`0000?oX7n_00?o0000ojB2[onTPZl01_nTPZl4
o`0000WoZX^d00Go0000ojj>]?n^S[Co[Xjdo`000006ojj=/`Go/Y6c00?o0000ok>B]?ncT[@01?nc
T[@01Ol0003o]iBcokND/ongU;?o000000Oo^9Je00Co0000ok^H]?nkV;Co00002?njV;@00ol0003o
_Y^dokjK]003okjK]0Ko00000_o2Vk001?l0003o`i^_ol>K[ol00006olJN[`03o`000?o7X;3o0000
00?obJ6_0ol00004olfPZ@04o`000?o?XZ[o0000o`0000;odJ>Y0_l00004omFQX003o`000?oGY:7o
ejBQ00;oejBQ0_l00003ombQU@04o`000?oQY9?o0000o`0000?oiYn20_l000000ooYU6Go0000onbF
HP04o`0001Cooo]Z00?o0000oookJ_oonfX0XOoonfX2o`0001Cooo]Z0ol00005oijfj@04o`000?mn
Z_3oOZ[`o`0000KoPZc`00?o0000odfCkol000000_mEV?05o`0006Kooo]Z00Ko0000oo;8Y?l0003o
lLRWo`000?ogdJH2o`0000?on=f]00Go0000oo[WZ_ojij[o0000ooG`]`02o`000003onog_Ol0003o
000000;o000000Gof?kEo`000?oBoMko0000ok?kdP02o`0000;o]ocQ00Co0000okWik?ninNco^OW/
0ol000000onnj?;o0000o`000003okWOl`?o00001Onjenh2o`0000So[kWQ00?o0000olk:e_o>b]H0
0_o>b]H01Ol0003od/_Co`000?oCc]Co000000?oe<kC00Oo0000omC@eOoDd=Goe=3Eo`000?oIdM7o
000000GofM?B00Ko0000om_Fdol0003o0000on7Hc_l00004on7Kd004o`000?oXh<[oj>3:onSPbP;o
00000_o_iL<00ol0003ol>S3o`000002ooK]]P03o`000?ohkIoo000000;o0000<_oonfX2o`0003Wo
oo]Z000ioookJP;o0000C?oonfX01Ol0003o400]o`000?l0003o?0MQ00;o00001?mQ<h82o`0000Go
N4nE00?o0000oh1MXOn8Hj401_n8Hj42o`0000WoTg6Y00?o0000oiQdZOl000000_l00004oi]l/005
o`000?nPOjooX7n_oj1o[ol000001_nPOjl00ol0003oY8:_ojB2[`05o`000003ojJ8]?l0003o0000
00[oZX^d00Co0000ojj>]?n^S[Co00001on^SK<01Ol0003o/Y6cok:A/onbTK?o000000Oo/i:d00Co
0000okND/ongU;?o00002?nhU[D00ol0003o^iRdo`000008okZH]0;o00001onnVk@01?l0003o`Inf
ol6O]_o1WkH3o`000003ol>K[ol0003oaYj_00GoaYj_00Go0000olNP/?o7X;3oaj2`o`000003olVQ
[`03o`000?o:XZoo000000;o000000?ocJ2Yo`000?o?XZX00_l00002om6SZ@03o`000?oAY:Wo0000
00?o00001OoGY:45o`0000?ohJBC0_l00002onJOPP03o`000?oYXX7o000000;o000000?ok9IRo`00
0?oUNBL00_l0000CoookJP03o`000?oonf[ooo]Z09kooo]Z0ol0000CoookJP?o00002OnN]^T01?l0
003oOZ[`ogjZl?l00003oh:/l0Ko00001?mEV?04o`0006Cooo]Z00Go0000oo;8Y?l0003olLRWo`00
0002ooOAYP06o`000?ohgJgon=f]ooSM[Ol0003on^NZ0ol000000oo_mkgo0000o`000003o`0000;o
f?kE0_l000000oncnm;o0000o`000002okOlh@05o`000?ninNco^OW/okWik?l000000_o1m>l2o`00
00Co^Moc0_l00005ok[GkP;o000000?o]<CVo`000?n_^N401On_^N42o`0000Koc/[F00Oo0000om?>
e?oCc]CodlkDo`000?oDc]?o000000Goe=3E00?o0000omWCd_oIdm800ooIdm801Ol0003ofmKCom_F
dol0003ohMW>00;o00000ooQfm02o`0000;oj>3:00?o0000onWTbooYi</00_l00002oo3X``05o`00
0?ofkKKo0000o`000?ohkIl00_l0000`oookJP?o000000?ooo]Zo`000?oonfX0>?oonfX003Wooo]Z
00?o0000oookJ_l00000B_oonfX3o`000004ocP3Gol0003o?0MQo`0000CoHC>200?o0000ofi8Tol0
00000omhCiD2o`0000;oP5fQ1On8Hj42o`000003ohe]ZOl0003oTg6Y00OoTg6Y0ol00008oi]l/0?o
00001OnPOjl5o`0000GoYXRd00?o0000ojJ8]?l000002_nZRk@00ol0003o[Xjdo`000009ojj=/`;o
/Y6c00?o0000ok>B]?ncT[@01oncT[@2o`0000[o^9Je00?o0000okZH]?njV;@01_njV;@01?l0003o
_I^eokfK]Ol00005okjK]003o`000?o1WkKo`Inf00Co`Inf1Ol00003olJN[`03o`000?o7X;3oaj2`
00;oaj2`00Co0000olVQ[oo9XJoo00001Oo:XZl2o`000005olnRZ_l0003o0000om6SZOl000001OoA
Y:T2o`0000?oejBQ00?o0000omVVX_l000000_oKYj02o`0000;ohJBC00?o0000on>WTol000000_l0
0003onVRP@03o`000?o/UV;o000000?o00005?oonfX00ol0003ooo]ZoookJP2JoookJP?o00005?oo
nfX2o`0000;o];cO00?o0000oijfjOnN]^T02?nN]^T6o`0000CoPjoa00?o0000odZDlOl000000ol0
00001?mEV?3o0000o`000?l6Im/2o`0006;ooo]Z00Co0000oo;8Y?obb:Co00000oogdJH00ol0003o
n=f]ooSM[@03o`00000:ooG`]_l0003o0000onog_Ol0003oio_4o`000?oOo/co0000omSne@;o0000
00?o/o_Bo`000?ngo>400_ngo>44okWik004o`000?o1m>oo0000o`0000;o`>3_00Co0000okWOloni
go?o00001Onjenh2o`0000Co]<CV00?o0000ojnihOn_^N401?l00006olk:eP03olo=eol0003odlkD
00?odlkD00?o0000omC@eOoDd=D00ooDd=D2o`0000CofM?B00?o0000om_FdooKe]<00_oKe]<02_l0
003oh]c?on;Lcol0003ohM_@o`000?oRg]7o0000onSPb_l00003onWTb`03o`000?o`j<?ol>S300;o
000000?om^ffo`000?l000000ol0000]oookJP?o00001?oonfX00ol0003ooo]ZoookJP0goookJP00
>?oonfX01Ol0003ooo]ZoookJ_oonf[o000004Sooo]Z0ol00002ocP3G`?o00000_mQ<h82o`0000;o
KTRC00Co0000ogQ?UOl0003o00001?n0GJ43ohQSX@;o00000on=KJT00ol0003oTg6Yoi=aZ@04oi=a
Z@;o000000?oUWV`o`000?nKO;001onKO;02o`0000CoX7n_0ol00002oj:5]@03o`000?nVR;CoYXRd
00?oYXRd0_l00003ojJ8]003o`000?nZRkCoZX^d00OoZX^d0_l00005ojj=/aOo00001OnhU[D2o`00
00Oo^YRd00Go0000okfK]OnmVkGo_I^eo`000004okjK]003o`000?o1WkKo`Inf00Go`Inf00?o0000
ol>P]Oo3X;D00_o3X;D5o`0000?oaj2`00?o0000olVQ[ol000001_o:XZl00ol0003ocJF`o`000004
o`0000GodJBY00Ko0000omFXZOl0003o0000omNTXOl00002omVVXP07o`000?oKYj3o0000ombXX?l0
003ohJBCo`000003on>WT`04o`000?oYXX7ojJ:1onVRP@?o000000CokiQNo`000?l0003o00005?oo
nfX00ol0003ooo]ZoookJP2GoookJP;o00005?oonfX3o`0000Go];cO00?o0000oijfjOnN]^T01Ol0
0003oinhjP05o`000?mn[?7oOZcaogj/lOl000001On3[o401Ol0003oBYCaodZDlOl0003oDi_c00So
0000GooonfX01Ol0003ol/RToo;8Y?obb:Co000000;omm6V0_l000000oohgJgo0000oo_WZ002o`00
0006ooG`]_l0003okoNmonog_Ol0003oio_40_l000001OoHo]Go0000o`000?ncnm;o000000?o]ocQ
0oninN`2o`000003ol7dkol0003o`>3_00Co`>3_0_l00004ok[GkP;o00001onda>H2o`0000;oZ[7M
00?o0000olk:e_o>b]H00oo>b]H01Ol0003oclgGolo=eoo?cMOo000000;odlkD0_l00004omC@e@04
o`000?oEd]KoeM;Fo`0000;ofM?B00?o0000om_FdooKe]<00_oKe]<2o`0000?oh]c?00?o0000on;N
dOoRg]400_l00004onWTb`04o`000?o`j<?o0000oo7/``;o000000?om_2do`000?l000000ol0000Y
oookJP?o00001ooonfX00ol0003ooo]ZoookJP0goookJP00>?oonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z04Cooo]Z0ol00002ocP3G`;o000000CoDbQno`000?mQ<h;o00001?m^B9<2
o`0000KoP5fQ00?oR6>Qo`000?l000001_n=KJT00ol0003oTg6Yoi=aZ@03o`0000?oUWV`00?o0000
oi]l/?nKO;001?nKO;02o`000003oi]k[ol0003oX7n_00?o00001OnRQKD00ol0003oYXRdojJ8]002
ojJ8]003o`000?nVR;CoYXRd00?oYXRd00?o0000ojZ;]?nZRk@01_nZRk@8o`0000Go[i>i00?o0000
ok:E^OnbUKT01onbUKT00ol0003o]9Njo`000005okJH^@[o00000onjV;@00ol0003o_I^eokfK]@02
okfK]@05o`000?nnVkCo_Y^dokjK]?l000002?o1WkH00ol0003o`j2eol>P]@04ol>P]@03o`000?o6
XkGoaZ>e00?o000000?oaj2`o`000?o:XZl01Oo:XZl01_l0003ocJF`olfU/?o=YK3o0000olfU/0?o
00000ooAY:T00ol0003oeJRYomFXZ@02omFXZ@;o00000_oIYZ800ol0003ofjNPo`000002ombXX0;o
00000ooSYi<2o`0000;ojJ:100?o0000on^UOol000000ol000000ooXP2Ko0000o`00000BoookJP03
o`000?oonf[ooo]Z09Cooo]Z0ol0000DoookJP;o00002Ond_=l2o`0000WoWkSZ00Go0000ogj/lOmn
[?7oOZcao`000003oh>_l@Co000000?oBYCao`000?mCVo<00_mCVo<01_l0003o06OIo`000?l0003o
3VoOo`0005kooo]Z00Co0000oo;8Y?obb:Col/RT0_l000000oogdJKo0000oo_MY@02o`000008oo_W
Z?l0003omO2fooG`]_l0003okoNmo`000?oWnl@5o`000005ok?kd_l0003o]ocQokOlhOl000000_ni
nN`00ol0003o`OC`o`000002o`0000Go`>3_00Co0000okOFl?nge_3o00000_njenh00ol0003o]<CV
okC4iP04okC4iP;o000000Go/;_Ro`000?nZ/MgoZ[7Mo`000005olk:eP03o`000?o?cMOoclgG00;o
clgG00?o0000om?>e?l000000_oDd=D01?l0003oe=3EomC@eOl00003omGBeP03o`000?oIdm;o0000
00CofmKC00?o0000omcIe?l000000_oRg<l2o`0000;oh]kA00?o0000onWTbooYi</00_oYi</2o`00
0003oo3X`ol0003olNc300;o000000?om_2do`000?oekY/00ol0000VoookJP?o00002_oonfX00ol0
003ooo]ZoookJP0goookJP00>?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z04;o
oo]Z1?l000000olh0eoo0000o`000002oe<XOP;o00001?m^B9<2o`0000KoP5fQ0_l00008ohe]Z@?o
00001onFNK000ol0003oVgb`oi]l/003o`0000;oVg^_0ol00009oj:5]@04o`000?nVR;Co0000o`00
00KoYXRd00?o0000ojZ;]?nZRk@00_nZRk@5o`000003oj^@^Ol0003o[i>i00Oo[i>i00?o0000ok2C
^?l000002?nbUKT01?l0003o]9NjokBG^_l00007okJH^@05o`000?nhVk[o^9^jokRK^_l000000onk
W;T7o`0000;o_I^e00?o0000okjK]?l000002?o1WkH00ol0003o`Z2eo`000004ol>P]@03o`000?o6
XkGoaZ>e00CoaZ>e0ol00004olZR[`03o`000?o=YK3ocJF`00;ocJF`00Go0000olfU/?l0003o0000
om2X/002o`000003om6TZOl0003oeJRY00?oeJRY00?o0000omNZZ_l000000ol00004ombXX0;o0000
0_oSYi<01?l0003oiZZCo`000?l00003on^UO`Oo00004_oonfX00ol0003ooo]ZoookJP2AoookJP;o
00005OoonfX2o`0000So];cO0_l00002okBlg`03o`000?nO^>[oWkSZ00SoWkSZ1ol00003ohFbl`03
o`000?m9V?;o000000Go00000_l0ImT00ol0003o3VoOo`00001LoookJP0;o`000?ocb:;o0000oo;8
Y?l0003on=>So`000?ogdJKo0000oo_MYOl000000_okijP00ol0003omO2fo`000008o`000003ok?k
d_l0003o]ocQ00;o000000Co^OW/o`000?o1m?3o`OC`0_l00004ol3Pk`03o`000?nfh?Go000000?o
]mK`0_l00005okC4iP;o00001?n`^n83o`0000Goc/[F00?o0000olo=eoo?cML01?o?cML01ol0003o
e=3EomC@eOoDd=Go0000omC@eOl000001OoEd]H00ol0003ofmKCom_Fd`02om_Fd`04o`000?oLfMCo
g=WDomcIe0;o00000_oSgm400ol0003oh]kAo`000003onWTb`04o`000?oYilgo0000o`0000;olNc3
00?o0000ooK`]?ofl;@01Ol0000SoookJP?o00003_oonfX00ol0003ooo]ZoookJP0foookJP00>?oo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z047ooo]Z1Ol000001OmA9gko0000oe<X
O_mC:7ko000000CoKTRC00?o0000ogMHXOl000001On0GJ400ol0003oQFV[o`000007ohe]Z@;o0000
2OnFNK03o`0000;oVg^_0ol000000onMPkKo0000oj:5]@09oj:5]@;o00001onVR;@6o`000003ojb@
^Ol0003oZi2i00CoZi2i00?o0000ojnC^On_TkT00on_TkT2o`0000?o/9>h00?o0000ok:E^OnbUKT0
1?nbUKT00ol0003o]9NjokBG^P02okBG^P03o`000?nfV;Wo]YRi00?o]YRi00?o0000okRK^_nhVkX0
0onhVkX01Ol0003o^ibiok^L^OnkW;Wo000000Go^ibi2?l00004ol6O]P04o`000?o2X;Go`Z2eo`00
00?o`j2e00?o0000olJS]Oo6XkD01Oo6XkD2o`000006olVV]Ol0003o0000o`000?o:XZoo00001?o=
YK02o`0000;ocjRa00?o0000om2X/?o@Z;000_l00003omFXZ@03o`000?oGZZ[oejZZ00;oejZZ0_l0
0004ombXX004o`000?oP[:3o0000o`0000?oiZZC0_l00002on^UO`?o000000?olY]Io`000?l00000
0_l0000BoookJP03o`000?oonf[ooo]Z08gooo]Z0ol0000FoookJP04o`000?o3_]Go`kkEo`0000Co
];cO0ol00005okBlg`03o`000?nO^>[oWkSZ00Go00000onP^NX01Ol0003oOjkbogn^l_mo[_;o0000
00GoQK;c00Ko0000odVHl_m9V?;oBISbo`000?mEXOD2o`0000;o06OI0ol0001KoookJP03o`000?oc
b:;ollRR00;o00000_ohdj<01Ol0003onmfUoo_MYOl0003onnNX00;o000000?omO2fo`000?o_mkd0
0ol000001?n^lZgo0000o`000?ncnm87o`000003ol7dl?l0003o`>3_00?o`>3_00Go0000okKPmOnf
h?Go0000okOFl003o`0000;o]mK`00?o0000okC4i_l000000_l00005ok2khP04o`000?o9bMWo0000
o`0000Coc/[F00?o0000olo=eoo?cML01?o?cML00oo@cmSo0000omC@e@03omC@e@03o`000?oEd]Ko
eM;F00?oeM;F0_l00003om_Fd`03o`000?oLfMCog=WD00;og=WD00?o0000on?OdOoSgm400_oSgm43
o`000005onWTbol0003ojNO=onWWcOl000000ooak<<00ol0003om_2do`000005o`00023ooo]Z0ol0
000AoookJP03o`000?oonf[ooo]Z03Kooo]Z000hoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000
oookJ_oonfX0?ooonfX01Ol0003o000Jo`000?lT05So000000?oDBMn0ol00002ofi8T`;o00000_mg
F:401?l0003oP5fQoh1MXOn0GJ42o`0000;oQFV[00?o0000ohe]ZOn=KJT00on=KJT2o`000003oi5f
/Ol0003oUWV`00OoUWV`0_l000001?nKNjoo0000o`000?l00005oif3]P03o`000?nRQKGoXXFe00Ko
XXFe0_l00003ojJ8]0Go00000_nXSKT00ol0003o[92iojb@^@02o`0000KoZi2i00?o0000ojnC^On_
TkT00_n_TkT00ol0003o/9>hok2C^003ok2C^003o`000?nbUKWo/YFi00?o/YFi00?o0000okBG^_nd
UkX00ondUkX00ol0003o]YRiokJH^@02okJH^@03o`000?nhVk[o^9^j00Co^9^j00Co0000ok^L^Onk
W;Wo00002?nkW;T2o`0000Co_j2i2?l00003ol>P]@03o`000?o6XkGoaZ>e00CoaZ>e00Co0000olNU
]_o7YKKo00000oo9Y[D2o`0000CocJF`00Go0000olnX/Oo?Z;7ocjRao`000002om2X/003o`000?oA
ZK3o000000;oeJRY00?o0000omNZZ_oGZZX00ooGZZX2o`0000;og:RP00Co0000on2/X?oP[:3oh:bP
0_l00002onJZT`04o`000?oX[I?o0000on^UO`Co000000ColY]Io`000?l0003o00004_oonfX00ol0
003ooo]ZoookJP2<oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000ol>neOo3_]D00_o3_]D01?l0
003o];cOo`000?l00009okBlg`;o00002OnP^NX01Ol0003oOjkbogn^l_mo[_;o000000?oQK;c1Ol0
00001?m9V?;o0000oeFQmOmEXOD2o`000004o`1WfOl0003o1G7No`0005[ooo]Z00Go0000oo?8X_oc
b:;ollRRo`000002ooSCX`05o`000?okgJGo0000o`000?okijP01ol000001On^lZgo0000ojkjd_l0
003o/O_R00Co00000_nZm^d2o`000003ol3Pkol0003o`>3_00;o00000_nfh?D00onge_3o0000o`00
0005okOFl0;o00001on`^n801?l0003obLWIolW9fOo9bMT2o`0000;oc/[F00?o0000olo=eoo?cML0
0oo?cML01Ol0003od<oHom3?f?o@cmSo000000;oe=3E00?o0000omGCe_l000000ooEd]H00ol0003o
e]GGo`000002om_Fd`03o`000?oLfMCog=WD00;og=WD0_l00004on?Od@04o`000?oRhM?o0000o`00
00?ojNO=00?o0000oo7/`ooak<<00ol000000oocm;;o0000o`000003o`0001gooo]Z0ol0000Doook
JP03o`000?oonf[ooo]Z03Kooo]Z000hoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oo
nfX0?OoonfX3o`0000;o901H00?o0000oe4WO_mA9gh00_l000001?mS@97o0000ofi8Tol00005ogMH
X@03o`000?n0GJ7o000000GoQFV[00?o0000ohe]ZOn=KJT00_l00003oi5f/@03o`000?nFNK3oUWV`
00?oUWV`1_l00008oif3]P03o`000?nRQKGoXXFe00?oXXFe2?l00008ojR=^@;o00002?n[T;T00ol0
003o[i>iojnC^@02o`0000Oo/9>h00Go0000ok:E^OnbUKWo/YFio`000006okBG^P05o`000?nfV;Wo
]YRiokJH^Ol000001onhVkX00ol0003o^ibio`000008ok^L^@03o`000?nnW[Wo000000Ko_j2i00?o
0000ol2Q^Oo0XKT00_o0XKT2o`000003ol>P]Ol0003oaZ>e00GoaZ>e00Go0000olNU]_o7YKKoajFf
o`000003olVV]@03o`000?o:YkKo000000;o000000?ocJF`o`000?o?Z;400_o?Z;400ol0003od:R`
o`000003om6Y/003o`000?oEZ:Wo000000GoejZZ00Go0000omZ]Z_l0003og:RPo`000003on2/X005
o`000?oR[j3o0000onJZTol000000_oX[I<3o`000003onnXO?l0003olY]I00;o000000?oi7/Bo`00
0?oonfX04OoonfX00ol0003ooo]ZoookJP2;oookJP03o`000?oonf[ooo]Z01Cooo]Z0_l00005ol>n
e@;o00002?nd_=l2o`0000;o]KcO00?o0000oj2ij_nP^NX02?nP^NX7o`0000?oR;Kc00?o0000od^M
m?m;WO@02?l000000ol5LMko0000o`00001GoookJP03o`000?ocb:;ollRR00;ollRR00Oo0000ooSC
Xol0003o0000oo_MYOl0003on^ZR00oo00000onZm^d4okKcl`;o00000onfh?D2o`0000Go]mK`0_l0
0002ok?4i`03o`000?n`^n;o/;_R00;o/;_R0_l00005olW9f@03o`000?o>b]Ko000000GoclgG00?o
0000om3?f?o@cmP00_o@cmP00ol0003oe=3Eo`000003omGCeP03o`000?oEd]Ko000000?oe]GG0_l0
0004omcIe003o`000?oMgMKo000000?ohmoA00?o0000on;QdooRhM<00ol000001_oYilgo0000o`00
0?oak<?o0000oo3aa0;o000000?oloBbo`000?o/ki800ol0000JoookJP?o00005ooonfX00ol0003o
oo]ZoookJP0foookJP00=ooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z03_ooo]Z
1?l000001OlT05So0000o`000?mA9gko000000;oHSnB0ol00006ogMHX@;o00001_n5JJ/3o`0000Ko
TGJa00?o0000oiIi/?l000000_l000001OnFN;3o0000o`000?nIOkKo000000WoWH>f00Co0000oj:5
]OnRQKGoXXFe1?l00003oj>;^P03o`000?nXSKWoZ8fi00SoZ8fi00?o0000oj^@^On[T;T02?n[T;T2
o`0000Wo/9>h00Co0000ok:E^OnbUKWo00002?ndUkX00ol0003o]YRio`000009okRK^P03o`000?nk
W;Wo^ibi00Ko^ibi00Go0000okjN^OnnW[Wo_Yjio`000004oknP^@03o`000?o0XKWo`:6i00Go`:6i
1?l00003olJS]@03o`000?o7YKKoajFf00;oajFf00Co0000olVV]Oo9Y[Go00001Oo:YkH2o`0000Co
cjRa0_l00004om6Y/0;o00001?oGZZX01?l0003ofJf[o`000?oJ[JX2o`0000?oh:bP00?o0000on:_
X?oR[j000_l00003onR]T`03o`000?o^Ygko000000Go000000?oi7/Bo`000?oonfX04?oonfX00ol0
003ooo]ZoookJP2;oookJP;o00005?oonfX01?l0003oakkBolNnd_l00003ol>ne@03o`000?o3_MGo
000000Ko];cO0_l00005okFlg`03o`000?nP^N[oX;WZ00Go00000onR^^X00ol0003oPK7coh6al`02
oh6al`;o00000on8]_<00ol0003oBigdod^Mm002od^Mm0Co000000?o06WIo`000?l000000_l0001F
oookJP04o`000?ocb:;ollRRoo?8XP;o000000?on=>So`000?olh:400_l000001OojjZ;o0000oo?a
X_l0003oj?JS00?o000000KoNm^Qo`000?n?k<?o0000oiofgOl00003oj[fk@04o`000?nflo?o]_?c
okKcl`;o00000onihO<00onfh?Go0000okOFl003okOFl0?o00001Onca>L00ol0003o/;_Ro`000002
o`0000OobLWI00?o0000olo=eoo?cML00oo?cML00ol0003od<oHom3?f004om3?f003o`000?oEdmKo
eM?F00?oeM?F00?o0000omKEeooFeML00_oFeML00ol0003og=WDomcIe002omcIe007o`000?oMgMKo
gMgFomgMe_l0003ohmoAo`000003on;Qd`0:o`000?oZj<coj^S<o`000?oYj/ko0000oo7/`ol0003o
l?74o`0000;oloBb0ol000000ooonf[o0000oookJP0FoookJP?o00006_oonfX00ol0003ooo]Zoook
JP0foookJP00=ooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z03Wooo]Z00Co0000
o`003?l0003o7P1E0_l000000om16gWo0000o`000004of8oTP03o`000?mgF:7oMeRQ00CoMeRQ0_l0
0006ohEYZ`;o00001_nAM[44o`0000;oUWR`0_l00004oiUo]P03o`000?nMPkKoWH>f00OoWH>f0ol0
0008oj>;^P03o`000?nXSKWoZ8fi00CoZ8fi0_l000000onXSKWo0000oj^@^@09oj^@^@03o`000?n`
TkSo/9>h00Wo/9>h4_l00004okRK^P;o00001onkW;T00ol0003o_YjiokjN^@02okjN^@05o`000?no
X;Wo_j2ioknP^Ol000001oo0XKT2o`0000?o`jFj1Ol00004olNU]P;o00001_o:YkH00ol0003ocJZf
o`000002o`000003olnX/Ol0003odJV`00CodJV`00Ko0000omB]/Ol0003o0000omNZZ_l00002omV]
Z`07o`000?oJ[J[o0000om^_Z_l0003oh:bPo`000004on:_X004o`000?oX[I?oj:fConR]T`Co0000
00KolZ]jo`000?ocWE?o0000onAk4_l0000BoookJP03o`000?oonf[ooo]Z08[ooo]Z00?o0000oook
J_l000004_oonfX00ol0003oakkBolNndP02olNndP03o`000?o3_]Go000000?o`kgE00?o0000okBl
gond_=l00_nd_=l00ol0003o]KcOokFlg`06okFlg`;o00002OnR^^X01_l0003oPK7coh6alon1/O?o
0000oh6al`So000000CoBigdo`000?mIYoSoFJOh0_l000000ol0JMWo0000o`000002o`0005Cooo]Z
0_l00002oo?8XP06o`000?ojeJ7o0000o`000?olh:7o00000_ojjZ800ol0003olo6Ro`000003o`00
0005og_KXOl0003oSnc3o`000?nOm]d00_nZm^d2o`0000?o]_?c0_l00004okWQl`?o]]kd00Co0000
okOFl?nge_3o00002Onca>L2o`0000OobLWI00Co0000ol[;fol0003o00000oo?cML00ol0003od<oH
om3?f003om3?f003o`000?o@dM[o000000CoeM?F00?o0000omKFf?l000000ooFeML01Ol0003og=WD
omcIe?oLfMCo000000CogMgF0_l00003on;Qd`;o00000_oZj<`4o`0000;ol?7400?o0000oo?d/_l0
00000ol000000ooonf[o0000oookJP0CoookJP?o00007OoonfX00ol0003ooo]ZoookJP0foookJP00
=ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z03Oooo]Z1_l00002od4KN@03o`00
0?mR?i;oHSnB00;oHSnB00?o0000ofiBX?l000000_l00002ogMHX@03o`000?moI:[o000000GoQFV[
00?o0000oh]b/_l000000_nAM[44o`0000;oT7Fa00Co0000oiIh/?l0003o00001_nIOkH00ol0003o
WH>foif3]P06oif3]P?o00002OnSRkX00ol0003oZ8fiojR=^@02ojR=^@;o00000onXSKT00ol0003o
Zi2ioj^@^@05oj^@^@Wo00001_n`Ukd00ol0003o/iZmok>J_@06ok>J_@03o`000?neVkgo000000Ko
]ifm2_l00002ok^L^@03o`000?nnW[Wo_Yji00?o_Yji00Co0000oknP^OnoX;Wo00001oo0XKT01?l0
003o`jBiol>T^Ol00004ol>U^P03o`000?o5Y[[oaJJj00?o000000?oajFfo`000?o:YkH01Oo:YkH0
1?l0003ocJZfolfZ]_l00002olfZ]P;o00001?oAZK000ol0003oe:faomB]/@02omB]/@;o00000_oI
[J/2o`0000?ofjnZ0_l00004on:_X0;o00000_oX[I<01Ol0003ojk2Do`000?l0003olZ]j00Ko0000
4_oonfX00ol0003ooo]ZoookJP29oookJP04o`000?oonf[ooo]Zo`00013ooo]Z00?o0000olNnd_o7
_]801?o7_]800ol0003o`kgEol>me@03ol>me@04o`000?nd_=oo0000o`0000Ko]KcO0_l000000onf
_=ko0000oj:jjP0:oj:jjP?o00001?n5]O@2o`000004ohfim?l0003oCZCgodjTm`So000000Co0WGN
o`000?l0003o0000DooonfX01ol0003om<RPo`000?ocb:;o0000oo[EXOl000000_olh:400ol0003o
n^ZRo`000005o`000005og_KXOl0003oSnc3oiofgOl000000_nZm^d2o`0000;o]_?c0_l00003okWQ
l`03o`000?nfgOCo]]kd00?o]]kd0_l00007ok?4i`?o000000?o[[_So`000?o9bMT01_o9bMT01?l0
003ob/_Kol[;foo:bm/2o`000003olo=eol0003od<oH00Cod<oH00Go0000om3Af_o@dM[od=7Jo`00
0002omGCeP06o`000?oFe]Soe]KHomKFf?l0003oe]GG0_l00002omcIe003o`000?oMgMKogMgF00?o
gMgF00Wo0000on;QdooRhM?oh^7Co`000?oSiM?o0000on[Xc?l000000_oZk<d2o`000003oo3aa?l0
003o000000;o000000Gok>nBo`000?oonf[ooo]Zo`00000BoookJP;o00008?oonfX00ol0003ooo]Z
oookJP0foookJP00=ooonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z03Kooo]Z1Ol0
0002od4KN@;o00000omR?i801?l0003oKU:PofiBX?l00002ogMHX@oo00001_n@MK42o`0000SoVGnf
00?o0000oif3]_nMPkH00onMPkH3o`000003oin8^ol0003oXh^j00WoXh^j00Go0000ojR=^OnXSKWo
Z8fio`000006ojR=^@03o`000?n[T;Wo000000Go00000_n/U;d00ol0003o/9Nmok2G_@07ok2G_@03
o`000?naV;go000000Oo/iZm00Go0000okFK_OneVkgo]I^mo`000006okNM_@03o`000?nhWKgo^9fm
00;o^9fm00Co0000ok^Q_OnkXKgo^j6m1_l00003okjN^@;o00001oo0XKT01Ol0003o`jBiol>T^Oo3
Y;Wo000000?o`jFj00?o0000olFV^_o5Y[X01?o5Y[X2o`0000GobZNf00Go0000olfZ]_o=Z[KocJZf
o`000002olfZ]P?o00000ooAZK000ol0003oe:faomB]/@02omB]/@03o`000?oF[k7o000000;ofJf[
00?o0000om^_Z_oK[jX00_oK[jX2o`0000;ohZnP00?o0000onFbX?oU/Z000_l00003on^`U004o`00
0?obZg[o0000ooB]M`Go00004OoonfX00ol0003ooo]ZoookJP28oookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000oookJ_oonfX03?oonfX00ol0003oakkBolNndP04olNndP03o`000?o7_M3o000000Co
`kgE0_l00006okFlg`;o00001?nf_=h00ol0003oX[[Zoj:jjP04oj:jjP?o00000_nT^nX00ol0003o
QKGdohFem005ohFem003o`000?n=^OCo000000GoCZCg00Co0000of2^n_l0003o07;G1Ol0001Aoook
JP05o`000?odb:3om<RPooC8X?l000000_ojeJ401Ol0003oo>2Qo`000?l0003on^ZR00Go000000?o
Nm^Qoho/`on?k<<01_l00002okKcl`03o`000?nihO?o^N7c00;o00000_nfgO@2okKNm0?o000000?o
/lc/o`000?nca>L01?nca>L2o`0000?o[[_S00?o0000olW9fOo9bMT01?o9bMT2o`0000Cob/_K00?o
0000olk<f?l000001Oo@cmP00ol0003od=7Jom3AfP02om3AfP03o`000?oEdmKo000000Coe]KH0_l0
0002omKGf@;o00001OoMgMH2o`0000;oh^7C00?o0000on?UdooSiM<00_l00003on[/c@03o`000?o_
lLCo000000Ko00000_oonfX00ol0003ooo]ZoookJP0=oookJP?o00008_oonfX00ol0003ooo]Zoook
JP0foookJP00=ooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z03Cooo]Z0_l00000
2?l604_o0000ochHNOl0003o@A]io`000?mD=Xoo00000_mR?i801ol0003oKU:PofiBX?m^DZ3o0000
ogMHXOl000001OmnI:/00ol0003oQFRZo`000005oh]b/P03o`000?n@MK7oT7Fa00?oT7Fa0_l00000
0onCOKOo0000oiUo]P08oiUo]P03o`000?nMPkKo000000;o00000_nOR;/00ol0003oWhRko`00000;
oj>;^P?o00001onXSKT2o`0000?o[IFn0_l00004ojbD_@03o`000?n`Ukgo/9Nm00Co/9Nm0_l00003
ok6H_@03o`000?ncV[go/iZm00;o/iZm0_l00004okFK_@03o`000?ngWKgo]ifm00?o]ifm00?o0000
okRM_OnhWKd01?nhWKd01?l0003o^j6mok^Q_Ol00005ok^Q_PSo00000oo0XKT00ol0003o`jBiol>T
^@02ol>T^@04o`000?o3YK[o`jFjo`0000OoaJJj00?o0000olNZ_?l000000_l000000oo:YkKo0000
olfZ]P03olfZ]P06o`000?o=Z[Ko0000olj]^?l0003od:fg0_l000000ooAZK3o0000omB]/@02omB]
/@07o`000?oF[k7oeZnaomJ_/Ol0003ofJf[o`000004om^_ZP05o`000?oO/Z[o0000on:_X?l00000
0ooU/Z02o`0000;ojk2D0ol00002ooB]M`04o`000?oeWTko0000o`0001;ooo]Z00?o0000oookJ_oo
nfX0QooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000olNnd_o7
_]801?o7_]801_l0003oakg@olNmd?o7_M3o0000ol>me@;o00000_o3_=@00ol0003o]KcOokFlg`02
okFlg`03o`000?nf_=ko][cN00Go][cN00?o0000oj:jj_nR^^X00ol00006ojBkjP03o`000?n5]OCo
QKGd00;oQKGd0_l000000on5]OCo0000o`000006o`000003odjTmol0003o000000;o07;G1?l0001@
oookJP06o`000?odb:3om<RPooC8X?l0003on]FQ0_l000000oolh:7o0000o`000005o`000005og_K
XOn?k<?o0000o`000?nFl^800ol000000onQl_;o0000o`000002okWQl`;o00000_nfgO@2okKNm0;o
00001Oncc>`00ol0003o/lCWo`000002o`0000Co[[_S00?o0000olW9fOo9bMT01?o9bMT00ol0003o
b/_Kol[;f`05ol[;f`03o`000?o?cmWo000000?od<oH00?o0000om3Af_o@dMX01?o@dMX00ol0003o
e]KHomKFf002omKFf006o`000?oGf=WoemSIo`000?oFemWo00001OoMgMH01Ol0003ogN3Ho`000?oR
hM?o000000?ohnGC00Co0000on[/cOoZk<goj^c=0_l000002?o_lLCo0000onkda_l0003ol?Nco`00
0?oVki7o00000_oonfX00ol0003ooo]ZoookJP0:oookJP?o00009_oonfX00ol0003ooo]ZoookJP0e
oookJP00=ooonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z03;ooo]Z0_l00002o`H0
B`04o`000?ln67Wo0000o`0000;oE3J?00?o0000of8oT_l000001?m^DZ02o`0000KoOVB[0_l00006
oh]b/P04o`000?n@MK7oT7Faoi1e/@;o00001?nCOKL00ol0003oVGnfoiUo]P05oiUo]PKo00001OnO
R;/00ol0003oXh^joj>;^P08oj>;^P03o`000?nXSKWoZ8fi00;oZ8fi0ol00002ojVB_P03o`000?n]
UKko[IFn00;o00001_n/U;d00ol0003o/9Nmok2G_@03ok2G_@03o`000?naV;go/IRm00?o/IRm00Go
0000ok>J_OncV[go/iZmo`000007okFK_@05o`000?ngWKgo]ifmokNM_Ol000001onhWKd00ol0003o
^j6mo`000007ok^Q_P03o`000?nmY;oo000000Co`:Fn1Ol00004ol>T^@;o00001oo5Y[X01?l0003o
ajZlolNZ_?l00002olVZ^`;o00001?o=Z[H2o`0000?ocZfh00?o0000om2]]oo@[KL00_l00003omB]
/@03o`000?oF[k7oeZna00;oeZna0ol00002om^_ZP04o`000?oO/Z[ogk:ZomnbZP;o00000ooU/Z00
1Ol0003oikFPo`000?l0003ok[:@00;o00000_od[GL00ol0003omIi>o`000002o`00017ooo]Z00?o
0000oookJ_oonfX0QooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Sooo]Z00Co
0000om6nb?oA_/So00000oo7_]800ol0003oakg@olNmd003olNmd0;o00001?o3_=@01?l0003o]KcO
o`000?l00009okJlgP;o00002_nT^nX4o`0000GoRKWf00?o0000oi:llol000001_mE[?T3o`000003
o`1beol0003o000000;o0000C_oonfX00ol0003om<RPooC8X002o`000003oo[EXOl0003ooN>L00So
000000?oPNO5o`000?nIln@00_l000001?nVlo?o0000o`000?l00003ok7Wn0;o00000_nfgO@00onf
g_Co0000o`000008ok?<k003o`000?n^^n?o[[_S00?o[[_S0ol00004olW9f@;o00001_o:bm/00ol0
003oblkLo`000002olo?f@03o`000?o@cmSo000000God=7J00?o0000om7Dfol000000ooFe]P00ol0
003oemSIomOHf@02omOHf@;o00001?oMgMH00ol0003ogN3HomgPf002o`0000CohnGC00Go0000on[/
cOoZk<go0000onS]d002o`0000;ok_C61?l00003oookJP03o`000?oonf[ooo]Z00Oooo]Z0ol0000Y
oookJP03o`000?oonf[ooo]Z03Gooo]Z000goookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oook
J_oonfX0<?oonfX3o`000005o`H0Bol0003o0000ochHNOl000000omD=Xl2o`0000CoKU:P0_l00006
ogiTZ`;o00002?n;L[83o`0000KoTgfg00?o0000oiUo]_nIOkH00onIOkH2o`0000;oVhJl00?o0000
oin8^onOR;/01_nOR;/00ol0003oXh^joj>;^P05oj>;^PKo00002?nYT[h2o`0000Wo[9Bm00?o0000
ok2G_On`Ukd00_l00006ok6H_@04o`000?ncV[go/iZmo`0000So]I^m00Co0000okNM_OngWKgo0000
2?nhWKd2o`0000Oo^j6n00Go0000okfT_onmY;oo_JBoo`000004ol2U_P04o`000?o0YKko`:Fnol2U
_P?o000000?o`jBio`000?o5Y[X01_o5Y[X00ol0003oajZlolNZ_002olNZ_004o`000?o9Z[_o0000
olV[^`?o000000?ocJZfo`000?o>[KP00oo>[KP00ol0003od:fgo`000002om2^]`;o000000?oe:fa
o`000?oF[k400ooF[k401_l0003of;:co`000?l0003ofjnZo`0000?ogk:Z00?o0000on6eZ_l00000
0_oU/Z001Ol0003oikFPonNeX?l0003ok[:@00?o000000Gom:ego`000?l0003o0000ooFOA`02o`00
017ooo]Z00?o0000oookJ_oonfX0Q_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z
00Kooo]Z00?o0000om6nb?oA_/P00_oA_/P00ol0003oakkBo`000005olNmd004o`000?o7^looak_?
o`0000?o`kcD0_l00008okJlgP;o00000_ng_=d00ol0003oY;_ZojBkjP04ojBkjP?o00000_nV_>T0
0ol0003oRKWfohVimP07ohVimP03oi:llol0003o000000;o00001?mE[?T00ol0003o9i3^o`000004
o`0004gooo]Z00Go0000ooC8X?odb:3o0000oocGW@02o`000005oogSW?l0003omnbIo`000?oFkXd0
1?l000001?nIlnCo0000o`000?nVlo<2o`0000Co/NOh00?o0000ok3Rn?n`h_P00ol00007ok?<k0?o
000000?o/<;Wo`000?n^^n<00on^^n<01Ol0003oaLSLo`000?o8bM[o000000;obLWI00?o0000ol[;
foo:bm/01Oo:bm/01Ol0003oblkLol_>g?o;c]co000000;ocloI00?o0000om3Af_o@dMX00_o@dMX2
o`0000;odMCK00Co0000omKFf?oFe]So00001?oGf=T01?l0003oe][Ko`000?l00002omgMeP05o`00
0?oMh=SogN3HomgPf?l000001?oSiM<2o`000005on[/cOl0003oj>g@onS]d?l000000oo^m<H4o`00
00?ooo]Z00?o0000oookJ_oonfX01?oonfX3o`0002cooo]Z00?o0000oookJ_oonfX0=OoonfX003Ko
oo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0_oookJPCo000000Co:`Yco`000?l0
003o00000omD=Xl00ol0003oKU:PofiBX002ofiBX003o`000?mfGZ[o000000GoOVB[00?o0000oh=^
/ol000001on;L[82o`0000SoTgfg00Co0000oiUo]_nIOkKoVGnf0_l00004oi^6_003o`000?nOR;_o
WhRk00KoWhRk00?o0000oj>;^_nSRkX01_l00002ojF@_`03o`000?nYT[koZI:n00SoZI:n00?o0000
ojbD_On/U;d02?n/U;d00ol0003o/9Nmo`000009ok6H_@;o00002OneVkd00ol0003o]ifmo`000008
okRM_@03o`000?njX;ko000000Ko^j6n00?o0000okfT_onmY;l00_nmY;l01Ol0003o`:Fnol2U__o0
YKko000000Oo`:Fn0ol00005olFV^P03o`000?o7Z[coajZl00CoajZl00?o0000olV[^oo9Zk/00oo9
Zk/2o`0000GocZfh00?o0000om2^]oo@[[L00oo@[[L2o`0000?oeZna00Go0000omRb/ooH/[?o0000
omVc/P02o`0000?ogk:Z00?o0000on6eZ_oQ]JX00_l00003onNeX0Co000000KolKJ?o`000?l0003o
mk1do`000?oeWdL2o`0001;ooo]Z00?o0000oookJ_oonfX0QOoonfX00ol0003ooo]ZoookJP06oook
JP03o`000?oonf[ooo]Z00Gooo]Z0_l00003om6nb0;o00001Oo7_M000ol0003oak_?olNkc`02olNk
c`03o`000?o3_=Co000000;o`k_C00?o0000okJlg_nf_=h00_nf_=h3o`0000Go]kcM00?o0000ojBk
j_nT^nX00ol00006ojJlj@03o`000?n9^OKoRKWf00?oRKWf0_l00002ohVimP;o00001?md/?L2o`00
0003oeF/nOl0003o000000Ko0000B_oonfX01ol0003om/VMo`000?odb:3o0000oocGWOl000000_om
hi`00ol0003omnbIo`000003o`000004oiWci?nFl^;o0000ojKcl`;o00000_naioP3o`0000;o/>;h
0ol000000onad_7o0000ok?<k004ok?<k0;o00001On``^L01?l0003o[[_So`000?l00003olG8g0;o
000000?obLWIo`000?o:bm/01_o:bm/00ol0003oblkLol_>g002ol_>g004o`000?o?cmWo0000o`00
00?od=7J00?o0000om7DfooAe=/00ooAe=/2o`0000CoemSI00Oo0000omKJfooFf]_oe][Ko`000?oM
gMKo000000?ogN3H0_l00003on?Ud`04o`000?oTj]Go0000o`0000?oj>g@00?o0000onkda_o^m<H0
1Ol00004oookJP03o`000?oonf[ooo]Z00?o0000;ooonfX00ol0003ooo]ZoookJP0eoookJP00=_oo
nfX00ol0003ooo]ZoookJP0AoookJP03o`000?oonf[ooo]Z02gooo]Z0_l000001Ol004Oo0000o`00
0?l[2W?o000000;oDSF@00Co0000oe@fSol0003o00000om^DZ001?l0003oMUjZogINZ_l00003ogiT
Z`;o00000_n3K[<00ol0003oRg:boh]b/P03oh]b/P;o000000?oSWZio`000?nCOKL02?nCOKL3o`00
00KoVhJl00?o0000oin8^onOR;/01onOR;/2o`0000;oYI2o0_l00005ojF@_`03o`000?nYT[koZI:n
00CoZI:n0_l000000onYT[ko0000ojbD_@09ojbD_@;o00002_naV;d00ol0003o]I^mokFK_@09okFK
_@03o`000?nhWKgo^9fm00Ko^9fm00Co0000okZP__njX;ko00001OnkXKh00ol0003o_JBookfT_`03
okfT_`04o`000?o0YKko`:Fno`0000Oo`:Fn00Co0000ol:X`?l0003oa:Vo0ol000000oo5Y[[o0000
olNZ_006olNZ_003o`000?o9Zk_obJ^k00?obJ^k1?l00003olj]^003o`000?o@[[Ood:jg00?od:jg
00Ko0000om>a]ol0003o0000omJ_/Ol00003omRb/`;o000000Cof[Bbo`000?oO/Z[o00001?oQ]JX2
o`0000;oikFP00Co0000onVhX?l0003o00000_oa]Xl01?l0003omk1do`000?oeWdL3o`00017ooo]Z
00?o0000oookJ_oonfX0QOoonfX00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z00?ooo]Z
00Ko0000omJn`ooF_/?o0000om6nb?l00002om2mb005o`000?o7_M3oakg@olNmd?l000001_o7^ll0
0ol0003o`k_Col>kd`02ol>kd`04o`000?nf_=ko0000o`0000Wo]kcM0_l0000:ojJlj@Go00001_n@
_?@2o`0000OoM;3g1ol00019oookJP04o`000?ofbIgom/VMo`0000;oo=NM00?o0000oogSW?l00000
2ol000000onaioSo0000o`000002ok3Rn0?o00001Onad_400ol0003o/lc/o`000002o`0000So/<;W
00?o0000olG8g?o5b=`01?o5b=`2o`0000Kob/_K0_l00006ol_>g006o`000?o@dM[od=7Jo`000?o@
dM[o00001_oAe=/00ol0003oemSIomOHf@02omOHf@03o`000?oFf]_oe][K00;oe][K0_l00003omgP
f003o`000?oMhmWo000000;ohnGC00Co0000onCZeOoTj]Go00000ooXkM02o`000003onkda_l0003o
000000Co00001?oonfX3o`0003;ooo]Z00?o0000oookJ_oonfX0=OoonfX003Kooo]Z00?o0000oook
J_oonfX04_oonfX00ol0003ooo]ZoookJP0/oookJP;o000000Go0017o`000?l[2W?o:`Yco`000003
oe8eT0?o00000_m^DZ000ol0003oMUjZogINZP02ogINZP03o`000?mnI:_o000000GoPfjc00?o0000
oh]b/_n;L[800_l00003ohij^@03o`000?nCOKOoTgfg00GoTgfg0ol00009oi^6_003o`000?nOR;_o
WhRk00;oWhRk0ol000000onQS/3o0000ojF@_`02o`0000OoYI2o00?o0000ojVB__nYT[h00_nYT[h2
o`0000?oZI:n00?o0000ojbD_On/U;d01on/U;d9o`0000Co/IRm6?l000000onjX;ko0000ok^Q_P02
ok^Q_P03o`000?nmY;oo_JBo00Go_JBo0_l00007ol2U_P05o`000?o2Z<3o`ZS0ol:X`?l000000oo4
ZKl3o`0000GoajZl00?o0000olV[_?l000000oo9Zk/00ol0003oc:jlo`000002olb^_005o`000?o>
[KSo0000om2^]ol000000oo@[[L00ol0003odk6gom>a]`02om>a]`;o00000ooH/[<01?l0003of[Bb
omZd/_oJ];82o`0000CohKFZ00Co0000on>hZol0003o00000ooY^:001Ol0003olKJ?oo6fSol0003o
mk1d00?o000000?omIm0o`000?oonfX04OoonfX00ol0003ooo]ZoookJP24oookJP03o`000?oonf[o
oo]Z00Sooo]Z00Go0000oookJ_oonf[ooo]Zo`000004omJn``;o00000oo@_LP00ol0003oakg@o`00
0006olNkc`03o`000?o7^Lgo000000?o`k_C0_l00008okNlg@;o00000_ni_=`00ol0003oY[cYojJl
j@04ojJlj@?o00000_nY_>L00ol0003oT;cdoi2lm008oi2lm0go000000?o]2`0o`000?l000000_l0
0016oookJP05o`000?ofbIgom/VMo`000?oleid00_l000000oomhico0000o`000004o`0000;oS^ca
0onPj_X3o`0000;o/>;h0_l00008ok7Bl@03o`000?n``^Oo/<;W00Go/<;W1?l00008olG8g003o`00
0?o:bm_ob/_K00?ob/_K00?o0000ol_>g?o;c]`01Oo;c]`00oo;d=go0000om3AfP02om3AfP03o`00
0?oAe=_odMCK00?odMCK00?o0000om7Fg?l000000ooGf=T00ol0003oe][KomKJf`03omKJf`05o`00
0?oMhMSo0000omgPf?l000000ooMhmT2o`0000?oi>[E00?o0000onS]d?oXkM000_l000001Oo^m<Ko
0000onkg`_l0003ok?N]00;o00000_oonfX4o`0003Cooo]Z00?o0000oookJ_oonfX0=OoonfX003Ko
oo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0ZoookJPGo000000?o:`Yco`000?l0
00000_mB=I000ol0003oHDZPof5:X003o`0000GoMUjZ0_l00006oh=^/`?o00001_n>N[T01?l0003o
Tgfgoi=m]onCOKL3o`0000;oUX>m00?o0000oi^6_?nKQ[`01onKQ[`00ol0003oWhRko`000002o`00
00GoXHk000?o0000ojF@_onUT;l01onUT;l01Ol0003oZI:nojVB__nYT[ko000000KoZI:n00Co0000
ojbD_On/U;go[9Bm1_l000000on]VL;o0000ok6L`P06ok6L`P;o000000?o/I_2o`000?ndW/801_nd
W/801Ol0003o]Ik2okFN`_neW/;o000000Go^:7200?o0000okRR`_nhX/800onhX/87o`0000Ko_JBo
00?o0000ol2U__o0YKh01Oo0YKh00ol0003o`ZS0ol:X`002ol:X`004o`000?o4ZKooa:Voo`0000?o
a:Zo0ol000001Oo7Z[co0000olV[_?o9Zkco000000;obJ^k00Co0000olb^_?o<[[co00000oo<[[`2
o`000005om2^]ol0003od:jgom2^]ol000001OoC/KL00ol0003oeKBho`000002omRb/`03o`000?oJ
];;of[Bb00;of[Bb0_l00002on6eZP05o`000?oS^:_ohkR[on>hZol000000ooY^:000ol0003olKJ?
oo6fS`03o`000003ooVbLOl0003omIm000;o00004_oonfX00ol0003ooo]ZoookJP23oookJP03o`00
0?oonf[ooo]Z00Wooo]Z00Co0000oookJ_oonf[o00001?oF_/<00ol0003oeKc2o`000003om2mb003
o`000?o7^looak_?00Coak_?00Wo0000olNicOo7^LgoakW=o`000?o3^m?o0000ol>jd_l000001_ng
_=d2o`0000Go^KcL00?o0000ojJljOnV_>T00ol00006ojVli`03o`000?n@_?CoT;cd00Go00000onF
_O801?l0003oLK?io`000?l00006og^no0?o000000?o]2`0o`000?l000000ol00013oookJP03o`00
0?ofbIgom/VM00;o000000?oo=NMo`000?oijYL01Ol000001?n>k?7o0000oj3Zn_nPj_X3o`0000?o
Yn7k0_l00006ok7Bl@?o00000on_an/00ol0003o/<;Wok32i`03o`000003ojfhh_l0003o000000Oo
aLSL00Co0000olG:g_l0003o00000oo:bm/00ol0003oblkLol_>g004ol_>g005o`000?o;d=gobm3M
ol_@gOl000000_o@dMX2o`0000?odMCK00Co0000om7Fg?oAe]co00000_oGf=T00ol0003oe][KomKJ
f`03omKJf`05omONg?l0003ogN7HomgQf?l000000ooMhmT2o`0000?oi>[E0_l000000ooXkM3o0000
on[acP02o`0000;ok_O21_l00003oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0
=OoonfX003Kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0YoookJP?o000000Oo
9PIbo`000?l0003o@bV<o`000?mB=I3o000000CoHDZP1?l00002ogINZP;o00001on3K[<00ol0003o
SWZiohij^@06ohij^@Co00001_nFPkd00ol0003oVhJloi^6_006oi^6_0;o00001OnQS/02o`000003
oj6=_ol0003oYI2o00WoYI2o0ol00007ojVB_PCo00000_n]VL800ol0003o[IW2ojfI`P03ojfI`P03
o`000?naW<;o/Ic200;o/Ic20_l00004ok6K`P03o`000?ndW/;o]9k200;o]9k20_l00005okFN`P05
o`000?nhXL;o^:72okRQ`_l000001onhX/800ol0003o^jC2o`000003okbU`P?o00000_nmY;l00ol0
003o_jFoo`000005ol2U_P03o`000?o2Z<3o`ZS000?o`ZS000?o0000olBY_ol000001oo4Z[l2o`00
00;obJ^l00Co0000olV[^oo9Zk_o00000_o<[[`01_l0003oc:jlolb^_?o<[[co0000olfa_P;o0000
00?od:jgo`000?oC/KL01?oC/KL01?l0003oeKBhomFd^?oE];P2o`000003omZd/_l0003of[Bb00;o
f[Bb00Go0000ombg/_l0003ohKFZo`000003on>hZ`05o`000?oY^:3ojKRPo`000?o/_:400_l00002
ooBiS@04o`000?oi/W7o0000ooFO@0;o00004_oonfX00ol0003ooo]ZoookJP22oookJP03o`000?oo
nf[ooo]Z00_ooo]Z0_l00004omJn``06o`000?oE_<;oeKc2omFl`_l0003od;g80_l00005olNkc`03
o`000?o7^LgoakW=00?oakW=0_l00002ol>jdP03o`000?ng_=go]kcM00;o]kcM00?o0000okVlg?ni
_=`01_ni_=`2o`0000[oZKcW0_l00009oiJmlP04o`000?ma/oWoLK?io`0000?oNkkl3Ol00011oook
JP05o`000?ofbIgom/VMo`000?omg9/00_l000000ooijYOo0000o`000003o`0000;oX>[j0_l00005
ojOQn`04o`000?n/e_Ko[=Kfo`0000;o/M;a0ol00007ojo7j`;o00000on]^>800ol0003oaLSLolG8
g005olG8g0;o00000oo5b]h2o`000003ol[;fol0003oblkL00CoblkL0_l00004ol_@g@03o`000?o@
dM[o000000;od=CL00?o0000om7Dfol000001?oAe]`2o`0000Coe][K00co0000omONg?oGg]co0000
omgQf?l0003ogNCIo`000?oMhmWo0000omkUf_l00002onCZe@04o`000?oSk=Ko0000o`0000;oj_7>
00?o0000onkg`_o^ml801Ol00005oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0
=OoonfX003Kooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0WoookJPCo000000Co
9PIbo`000?m3:Hco@bV<0_l00004of5:X003o`000?meGj_oMEn[00;oMEn[1?l00006oh=^/`;o0000
1?n>N[T5o`000003oi=l]ol0003oUX>m00KoUX>m00?o0000oi^6_?nKQ[`00onKQ[`2o`000003oif<
`Ol0003oXHk000;oXHk00ol00004oj6=_`03o`000?nUT;ooYI2o00KoYI2o0_l00004ojVB_P?o0000
0_nZUl801?l0003o[IW2ojfI`_n]VL82o`0000Ko[IW200Go0000ok6L`_naW<;o/Ic2o`000007ok6K
`P04o`000?ndW/;o]9k2o`0000Oo]Ik200Co0000okRQ`_nhXL;o00002?nhX/82o`0000Oo_:G22?l0
00000oo0YKko0000ol:X`006ol:X`003o`000?o4Z[ooa:Zo00Goa:Zo00?o0000olN^`Oo7[/401Ol0
0003olb^_004o`000?o<[[coc:jlo`0000CocK6n0_l00004om>a]`03o`000?oE];SoeKBh00?oeKBh
0ol00002omZd/P05o`000?oL]k;og;Nbombg/_l000000ooS^:/01_l0003oiK^[o`000?oY^:3o0000
onblX@;o00000_od^Hd00ol0003onK9ao`000002o`000003ooBO>?l0003ooo]Z017ooo]Z00?o0000
oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oF_/?oe[k300;oe[k300?o0000
omFl`_oE_<800ooE_<801?l0003ock_7olnkaol00003olNkc`03o`000?o7^LgoakW=00?oakW=00Co
0000olNgboo7]l_o00000_o3^]801?l0003o]kcMo`000?l00006okVlg0;o00000_nl]m@00ol0003o
ZKcWojVli`04ojVli`?o00000_n]_>D00ol0003oU[gboiJmlP08oiJmlPKo00000on7`_/2o`000004
ol=20?l0003o0000okdg00;o000000CoW`l0o`000?l0003o0000?ooonfX2o`000004ooK9WOl0003o
oMbKo`0000;onNZG1?l000000onPj_[o0000o`000004ojOQn`;o00001?n/e_H3o`0000Ko[lO[0ol0
00001?n]_NGo0000ojfhh_n]^>82o`0000KoaLSL0_l00006olG:gP;o00001Oo;c]`00ol0003obm3M
ol_@g@05ol_@g@03o`000?o@e=cod=CL00;od=CL00?o0000om7Fg?oAe]`00ooAe]`00ol0003oe][K
omKJf`02omKJf`04o`000?oGg]coemkLomONg0;o00000ooMi=T01_l0003og^GJomkUf_l0003oi>[E
o`0000;ohncF00Ko0000on[ac_oZlLkoj_7>o`000?o^ml85o`0000Kooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP0doookJP00=OoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oo
nf[ooo]Z02Kooo]Z1?l000001OlV1W;o0000od<YS?m3:Hco000000CoHDZP00?o0000ofYI[?meGj/0
0omeGj/01?l0003oO6^doga[]?mlJk@<o`0000CoSWZh0_l00008oiJ3_@04o`000?nKQ[coVhJloi^6
_0;o00001?nMS<43o`0000OoXHfo00?o0000ojF@_onUT;l00onUT;l7o`0000SoZYO200?o0000ojfI
`_l000002?n]VL801?l0003o/Ic2o`000?l00008ok6K`P03o`000?ndW/;o000000So]Ik200?o0000
okRQ`_l000002?nhX/800ol0003o^Z?2o`000006okbU`P03o`000?nmY/;o_JK200?o_JK200?o0000
oknX`onoZ<<00ol00005ol:X`0;o00001_o4Z[l00ol0003oajk1olN^`@04olN^`@;o00000oo<[[`0
0ol0003oc:jlo`000005olfa_P03o`000?o?/kgo000000;o000000?odk6go`000?oE];P01?oE];P0
1Ol0003oekJio`000?oJ];;o000000Cog;Nb0_l00002on>hZ`04o`000?oU^j_oiK^[o`0000?ok;bQ
0_l000002?od^Hgo0000o`000?l0003onkE]o`000?odWcSo00004_oonfX00ol0003ooo]ZoookJP21
oookJP03o`000?oonf[ooo]Z00_ooo]Z0_l00003omJn``03o`000?oE_<;oeKc200?oeKc20_l00002
olnka`03o`000?o7^loo000000GoakW=00?o0000olNgboo7]l/00_o7]l/01?l0003o`k[Bo`000?l0
0006okVlg0;o00001Onl]m@00ol0003oZKcWojVli`03o`0000Ko[KcU00?o0000oiJml_nF_O801Ol0
0004oibnl003o`000?mk^_[oNk[j00?o00000_n7`_/2o`000003ol=20?l0003o000000;o_CL02Ol0
000hoookJP;o00000_ohb9T01?l0003ooMbKoogLVol00002ooWZU`Co00000onWhO/3o`0000Co[=Kf
0ol000000on]b^oo0000ojo7j`04ojo7j`;o00001On]_ND2o`000003ol;7g_l0003oaLSL00CoaLSL
00?o0000olG:g_o5b]h01?o5b]h01Ol0003oa/cOo`000?o9cMgo000000?oblkL00?o0000ol_@gOo;
d=d01?o;d=d00ol0003oc=;No`000003om3Dg0;o00000ooAe]`00ol0003odMSNo`000003omKJf`03
o`000?oGg]coemkL00;oemkL00?o0000omgTfOoMi=T00_oMi=T3o`000003onCZeOl0003ohncF00;o
hncF00?o0000on[ac_oZlLh00_l000000oo^ml;o0000o`000003o`0000Kooo]Z00?o0000oookJ_oo
nfX0<ooonfX00ol0003ooo]ZoookJP0doookJP00=OoonfX00ol0003ooo]ZoookJP0HoookJP03o`00
0?oonf[ooo]Z02Cooo]Z0ol000001ol?06Wo0000o`000?m0:8go0000od<YS?l000000omQBZ001?l0
003oJUV/ofYI[?mZFJ`2ogEOZ`03o`000?mlJkCoO6^d00;oO6^d00Co0000oh=^/_l0003o00001?n8
MkT00ol0003oSWZhohij^003ohij^0;o000000?oTH6no`000?nFPkd02?nFPkd3o`0000KoWHc100?o
0000oj6=_onQSKl01onQSKl00ol0003oYI2oojF@_`04o`0000?oYYC300?o0000ojZG`_nZUl802OnZ
Ul800ol0003o[IW2ojfI`P07ojfI`P;o00002_naVl82o`0000Wo]Ik20_l00008okRR`P05o`000?nj
Xl;o^Z?2okZS`_l000001?nlYL800ol0003o_JK2okfV`P05okfV`P;o00000oo0ZL<3o`000005ol:X
`?l0003oa:[0olBZ`?l000001?o4Z[l00ol0003oajk1olN^`@04olN^`@;o000000?obJo1o`000?l0
00000ol00005olfa_P03o`000?o?/[go000000?ock>m00?o0000omFd^?oE];P00ooE];P01Ol0003o
ekJiomNf^OoG][Wo000000Cog;Nb00Ko0000omnj/ooO^[?o0000on>hZol00002onFkZ`;o00000_o/
_:402Ol0003okknOo`000?l0003omkf;o`000?ok]Fgo0000ooBO>002o`0001;ooo]Z00?o0000oook
J_oonfX0P?oonfX00ol0003ooo]ZoookJP0:oookJP06o`000?oL_KWog;fio`000?oF_/?o00001OoE
_<801Ol0003oe;_1omBk`Ol0003ock_700;o00001Oo7^Ld00ol0003oakO;olNgb`04olNgb`;o0000
00?oa;W@o`000?ni_=`00oni_=`00ol0003o_;ODokbge006okbge0;o00002_n]_>D2o`0000[oW;k`
1?l000001Omk^_[o0000o`000?l0003o]cL000Go000000?o_CL0o`000?l000002_l0000aoookJP?o
000000Go1P00o`000?ohb9Won<RIo`000002oogLV`Ko00000_nRg_`2o`0000Go[=Kf0_l00005ojg:
k`03o`000?n_an_o000000;o00001on]_ND01Ol0003o`/ONol;7g_o2amko000000;oaLSL0_l00005
olG:gP;o00000oo6c=l01Ol0003obLgMo`000?o;c]co000000Gobm3M0_l00002olcBgP04o`000?o@
e=cod=CLo`0000;odMOM00?o0000om7Fg?l000000_oAf=h01?l0003oe][KomKJfol00004omONg003
omOQg_l0003ogNCI00;ogNCI00?o0000omcUfooLiM/00_l00003on?/eP;o000000?oj_7>o`000?oX
m/l00_l000000ooYnl3o0000on;gY002o`0000Kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003o
oo]ZoookJP0doookJP00=OoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z02?ooo]Z
00Go0000o`00=Ol0003o3`1Yo`000003od0XS@;o00000_mQBZ000ol0003oJUV/ofYI[002ofYI[003
ogEOZol0003oO6^d00CoO6^d0_l00006ohQg^@04o`000?n>N[SoSWZhohij^0;o00001?nAPKh00ol0
003oUX>moiJ3_@05oiJ3_@;o00001?nMS<43o`000003oif;`?l0003oXHfo00WoXHfo0_l000000onV
U<?o0000ojJD``05ojJD``03o`000?nZUl;oZYO200GoZYO20_l000000onZUl;o0000ojfI`P07ojfI
`P03o`000?n^V/;o000000Wo/I_200?o0000ok:M`_l000002?neW/800ol0003o]Z73o`000007okRR
`P03o`000?njXl;o^Z?200;o^Z?200Go0000okbU`_nlYL;o_:G2o`000007okfV`P;o00001_o0ZL<6
o`0000?oa:Zo00?o0000olN^`Oo7[/401?o7[/401?l0003ob:k0olR^`?l00003olV_`@;o00001?o=
/Kh01Ol0003ock:molnb_Oo?/[go000000;ock>m0_l00003omFd^003o`000?oG][WoekJi00;oekJi
0_l00002ombg/P03o`000?oO^[?ogkZc00;ogkZc00Ko0000onFkZooU^j_oiK^[o`000?oX_Z/2o`00
0007onnnW_l0003okknOo`000?og_H_o0000oo^eK@04o`0001?ooo]Z00?o0000oookJ_oonfX0Oooo
nfX00ol0003ooo]ZoookJP09oookJP03o`000?oL_KWog;fi00;og;fi00?o0000omFl`_oE_<800ooE
_<800ol0003oe;_1omBk`@02omBk`@;o000000?ock[6o`000?o7^Ld00_o7^Ld00ol0003oakO;olNg
b`04olNgb`07o`000?o7^LcoakW<o`000?o4^M3o0000okVlg002o`0000Oo_;OD00?o0000ok^geOl0
00002?n]_>D2o`0000;o/;cR00?o0000oibnl?nL__001?nL__03o`000003oj:okOl0003oQL7k00Ko
QL7k0_l000000oo1?@3o0000okhi0004o`000004okH_0?l0003oZAd0ojTM00[o0000:?oonfX5o`00
0003o`H00?l0003o000000;o00000_ohb9T3o`000003oo[USOl0003o000000Go00000_nWe?L00ol0
003o[=KfojcFmP02o`0000So[L[_00?o0000ojfmiOn]_ND01On]_ND3o`0000Co`/ON00?o0000olG8
g?l000001_o5b]h00ol0003oa/cOolK<g`03olK<g`04o`000?o9cMgo0000o`0000Gobm3M00?o0000
olcBg_o<d]h00oo<d]h2o`0000CodMOM00?o0000om7Hg_oAf=h00_oAf=h2o`0000CoemkL0_oGhMh0
1?l0003ogNCIomgTfOl00003omcUf`04o`000?oTkMKo0000on?/eP;o000000Goj_7>o`000?oXm/oo
j?K?o`000002onWk`0?o00001ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z03Co
oo]Z000eoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX08OoonfX4o`000006o`l0
JOl0003o@2R=od0XSOl0003oDd6O0ol00005ofYI[003o`000?mlJkCoO6^d00CoO6^d00?o0000ohQg
^On8MkT01_n8MkT3o`0000KoTH6n00?o0000oiJ3_OnFPkd00onFPkd2o`000003oiV9`_l0003oWHc1
00?o00001OnMRl000ol0003oXHfooj6=_`03oj6=_`?o000000CoXi;4o`000?l0003o00002?nVU<<0
1?l0003oZYO2ojZG`_nZUl83o`0000CoZYO200?o0000ojfI`_n]VL800on]VL82o`0000?o[Y[200?o
0000ok6K`_naVl801OnaVl801Ol0003o/Yg2ok:M`_nbWL;o000000Ko]Ik200Go0000okJQ`onfXL?o
]Z73o`000005okRR`P03o`000?njXl;o^Z?200?o^Z?200Co0000okbU`_nlYL;o00001onmY/800ol0
003o_jS3o`000005ol2Y``03o`000?o1Z/?o`J[300?o`J[30_l000000oo4Z[oo0000olN^`@05olN^
`@05o`000?o8[/3ob:k0olR^`?l000000_o9[l42o`000005olZa`Ol0003o0000olfa__l000001?o?
/[d00ol0003ock>mo`000002om6d_P03o`000?oE];So000000CoekJi00Ko0000omRi^_l0003o0000
ombg/_l00004omnj/`;o000000?oiK^[o`000?oX_Z/00_oX_Z/01_l0003okkjNo`000?o__ioo0000
ooNmR`?o000000Coo;MXo`000?l0003o00004_oonfX00ol0003ooo]ZoookJP1ooookJP03o`000?oo
nf[ooo]Z00Sooo]Z00?o0000ombm^OoL_KT00ooL_KT2o`0000?oeKc200?o0000omBk`OoD^l400ooD
^l401ol0003odkW0o`000?o?^/Ko0000olNicOl000001_o7]l/00ol0003oakW<olNic002olNic003
o`000?o4^M3o000000Oo_;OD0_l00003ok^ge@03o`000?n]_>Go[KcU00;o[KcU0ol00005ok2lhP03
o`000?nL__3oW;k`00?o00001OnR_nd00ol0003oQL7kohG1n`05o`000006omi^3Ol0003o`Cd0o`00
0?nn>@3o00000_no?005o`000003ojTM0?l0003o000000co00007OoonfX;o`000007obh00?l0003o
0000o`000?ohb9Wo0000oooIT@04o`000003oo;WQ_l0003o000000KoYmCg00?o0000ojg:kon]b^l0
1On]b^l3o`0000?o[KoX00?o0000ojfmiOn]_ND01?l000000onoa]oo0000ol;7gP03ol;7gP;o0000
1_o5b]h00ol0003oa/cOolK<g`05olK<g`03o`000?o:d=ko000000?obm3M0_l00006olcBgP03o`00
0?oAemgodMOM00;odMOM00?o0000om7Ig_l000000ooAf=h00ol0003oemkLomONg002omONg0Coen7N
0_l00003omcUf`;o00000_oTkMH4o`0000?oj?K?00?o0000onWk`?l000000ol00007oookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0=?oonfX003Gooo]Z00?o0000oookJ_oonfX06ooo
nfX00ol0003ooo]ZoookJP0PoookJPKo000000?o@2R=o`000?mC@Il00_mC@Il2o`0000CoJUV/0_l0
0006oga[]003o`000?n8MkWoR7Ni00GoR7Ni0_l00008oi61_P04o`000?nFPkgoUX>moiJ3_@;o0000
00?oVHW2o`000?l000000_l00008oif;`003o`000?nQSKooXHfo00?o00001?nST/@00ol0003oYYC3
ojJD``08ojJD``04o`000?nZUl;o0000o`0000OoZYO200?o0000ojfI`_n]VL800_n]VL800ol0003o
[Y[2ojjJ`P0No`000003okRR`_l0003o^Z?200Ko^Z?20_l00007okfV`P05o`000?noZ<?o_jS3oknX
`ol000000oo0ZL<00ol0003o`J[3ol6Z``05ol6Z``?o00001Oo7[/400ol0003ob:k0olR^`002olR^
`005o`000?o9[l7o0000olZa`Ol000000oo:/L42o`0000Gock:m00?o0000om6d__oA];h00_oA];h2
o`0000?oekJi00Co0000omRi^_oH^K[of;Vj0_l00004omnj/`03o`000?oQ_K?ohKfc00;o00000ooX
_Z/01Ol0003okkjNonnnW_l0003olL:N00;o000000?onL29o`000?ol]fP00ol0000CoookJP03o`00
0?oonf[ooo]Z07kooo]Z00?o0000oookJ_oonfX01ooonfX2o`0000Cog;fi00Ko0000om^j^?oK^[So
0000omFl`_l00005omBk`@07o`000?oC^L3odkW0om>i`?l0003ock[6o`000006olNgb`03o`000?o7
^LcoakW<00CoakW<0_l00006okbge003o`000?nk]mGo^kOE00Co^kOE00Co0000ojfliOl0003o0000
2On`_>82o`0000WoX[o]0_l00005oi;2m`04o`000?oNKPgo0000ol4m00Co000000?o_c`0o`000?l0
00001Ol00002ohd000Co000000?oM`00o`000?l000003Ol00008oookJQ?o000000?o;P00o`000?l0
00000ol000000ookaXko0000o`000002oooIT@05o`000?ongXWo0000oo;WQ_l000000onWe?L3o`00
00?oZ/[a00?o0000ojg:kon]b^l00ol00007ojfoj0;o000000?oZk?No`000?noa]l00onoa]l01?l0
003o`/ONo`000?l00002ol?9g`04o`000?o5b]koaL[NolG:gP;o00001_o6c=l00ol0003oa/kPo`00
0002ol[@gP03o`000?o;d=go000000Koc=;N00?o0000olcDh?l000000ooAemd01_l0003odMWNom7I
g_oAfMko0000om7HgP;o00000ooGg]`5omOQgP09o`000?oLiM_og>GKomcUfol0003ogN_Lo`000?oT
kMKo000000;oho7G0ol000000ooXm/oo0000onWk`004o`0000Sooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0doookJP00=OoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[o
oo]Z01oooo]Z0_l000000ol806So0000obhKQ`02o`0000CoDd6O00So0000ofYI[?l0003o0000ofYI
[?l0003oM6Fco`0000GoO6^d00?o0000oh5c^_l000001On8MkT00ol0003oS7jno`000009oi61_PKo
00000_nIRL800ol0003oWH_0oif;`008oif;`0;o00000onST/@3o`000003oj>Ba?l0003oYYC300Wo
YYC30_l0000:ojZG`POo00000on^WLH01?l0003o/Io6ok6Oa_naWlH2o`0000Ko/Z3600?o0000okFR
a_neX/H00_l00007okFSaP04o`000?nhYLKo0000o`0000So^Z?200?o0000okfV`_nmY/801OnmY/80
0ol0003o_jS3oknX``02oknX``04o`000?o0ZL?o`:W3o`0000Oo`J[300Co0000ol>]`ol0003oa:k4
0ol000000oo7[/7o0000olR^`005olR^`005o`000?o:/L7ob[71olZa`Ol000000_o:/L400ol0003o
c;?1o`000003olnb_@;o00001?oA];h01_l0003odkNno`000?l0003oekJio`0000Cof;Vj0_l00002
omnj/`03o`000?oQ_K?ohKfc00;ohKfc00So0000onRnZooX_Z_o0000on[2Zol0003okkjNo`0000;o
lL:N00?o0000ooW0ROl000001Ol0000BoookJP03o`000?oonf[ooo]Z07kooo]Z00?o0000oookJ_oo
nfX01ooonfX3o`0000;og;fi00?o0000om^j^?oK^[P00_oK^[P2o`0000Coe;_100?o0000om>i`?oC
^L000ooC^L02o`0000GoakO;00?o0000olNic?o7^L`01?o7^L`01?l0003oakO;olNgbol00003okbg
e0;o00001onk]mD2o`0000So/;cR0_l000000onc^moo0000oj:ok@05oj:ok@?o00000_nX_^T00ol0
003oT/;goi;2m`04oi;2m`03o`000?oNKPgo000000Oo000000?o[2@0o`000?l000000_nN4`0:o`00
00?oI`006ol000000oln003o0000o`000003o`000003obh00?l0003o000000Wo000000CoomVAooo?
R?l0003oo]j90_l000001?nWe?Oo0000o`000?l00007oj[:l@;o00001_n]_nP3o`000004oj^fh?l0
003o0000o`0000Ko_lKO00?o0000ol?9goo3bMl00oo3bMl00ol0003oaL[No`000006olK<g`;o0000
0_o6c^000ol0003ob]3Nol[@gP02o`0000Goc=;N0_l00002olcDh004o`000?oAemgodMOMo`0000Co
dMWN0_l000001?oBfmoo0000omONg?oGg]`5omOQgP05omOSgol0003og>GKomcUfol000000_oMjm`2
o`0000?oho7G00?o0000onOfd?l000001ol00008oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX0=?oonfX003Cooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0Moook
JP?o000000Co201Xo`000?l^6hOo00001?mC@Il2o`0000?oJUV/0ol000000omdIK?o0000oga[]002
oga[]004o`000?n1Lk[oPG>jo`0000CoR7Ni00Go0000ohan__n<O[koS7jno`000004oi61_P?o0000
00?oTH6no`000?l000001onIRL800ol0003oWH_0oif;`004oif;`0;o000000?oWi75o`000?nST/@0
0ol00005oj>Ba003o`000?nVU<?oYYC300GoYYC30_l000001?nVU<?o0000ojZG`_nZUl85o`0000?o
Zi_60_l00009ojjMaP03o`000?naWlKo000000Wo/Z360_l0000:okFSaP03o`000?nhY/Ko^:K600Co
^:K62Ol00002okfV`P03o`000?noZ<?o_jS300?o_jS300?o0000ol2Y`ol000001oo1Z/<01Ol0003o
`jg3ol>]`oo3[L?o000000?oa:k40_l00005olR^`0;o00000oo:/L400ol0003ob[71o`000003olbc
`@03o`000?o?/[go000000;odKBm00Co0000om6d__oA];ko00001?oC]kh00ol0003of;VjomRi^P03
omRi^P05o`000?oJ_;[o0000omnj/ol000001?oQ_K<2o`000008onRnZol0003oj/:[on[2Zol0003o
l/:No`000?oa`Yh3o`000003oo_3Qol0003ooKUR00;o00004ooonfX00ol0003ooo]ZoookJP1moook
JP03o`000?oonf[ooo]Z00Kooo]Z00?o0000onBjZooT^Z/00_l000000ooL_KWo0000om^j^003om^j
^003o`000?oI^;So000000?oe;_100?o0000om>i`?oC^L000ooC^L03o`0000?oakO;00?o0000olNi
c?o7^L`01?o7^L`00ol0003oakO;olNgb`02olNgb`03o`000?nl]mCo000000Oo^kOE0_l00002okbf
d`03o`000?n`_>;o/;cR00;o/;cR0ol00004ok>kg`03o`000?nR_ngoX[o]00?o00001_nX_^T00ol0
003oT/;goi;2m`0;o`0000;o]c4000?o0000oj`T0?n/90001Ol00002oihD00;o00000_n6000Do`00
00Go<00000?o0000och00?l000001?l00002odX000Wo000000?o7000o`000?l000000_oj_X<01Ol0
003ooln8ooo?R?l0003oo]j900?o00001_nZb_43o`000003oj_0jOl0003o[KoX00Co[KoX0_l00003
oj^fh0;o00001_noa]l00ol0003o`<SQo`000005ol?9g`;o00001_o6c=l00ol0003oa/kPolK>h003
olK>h0;o00000_o;d]l01Ol0003oc=;NolcBg_o<d]ko000000Goc=CP0_l00004om7IgP03o`000?o@
f^3od=[P00;o000000?oemkLomOQg_oGhMh00_oGhMh01_l0003oen?OomOSgol0003og>GKo`0000?o
gN_L00Co0000on?aeooSlMOoho7G0ol00002onGhdP05o`000?oUo<;o0000om_gY?l000002_oonfX0
0ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03Cooo]Z000doookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX07?oonfX4o`000003ob/JROl^6hOo000000?oDd6O00Ko0000of=D
ZomSE:_o0000ofYI[?l00003og=V]@?o000000?oO6^do`000?n1LkX00_n1LkX01_l0003oR7NiohQg
^On8MkWo0000ohan_PSo00000_nAP;h00ol0003oThO3oiV9`P08oiV9`P04o`000?nMRl3oWH_0oif;
`0?o00000onOTLD2o`0000SoXi;400?o0000ojJD`onVU<<00onVU<<2o`0000?oYYC30ol00008oj^K
aP03o`000?n^WLKo[Yg600Wo[Yg600?o0000ok:Pa_nbX<H01onbX<H2o`0000Wo]J?600?o0000okNT
aOl000001onhY/H01Ol0003o^JK6okVVa_niY/Ko000000?o_:W60_l00007oknX``03o`000?o1Z/?o
`J[300Go`J[300?o0000ol>]`oo3[L<00_o3[L<01?l0003oa:k4olB^a?l00002olF_a0?o000000Go
b:k0o`000?o:/<7ob[31o`000002olZa`@;o00001Oo</l42o`0000;odKBm00?o0000om6d__l00000
1OoC]kh2o`0000?of;Vj00Co0000om^k^_l0003of[bj0_l00003on6m/`04o`000?oS`;Cohl2do`00
00?oj/:[1?l00002ooC5W@04o`000?ok`hOo0000oofiHP?o00004ooonfX00ol0003ooo]ZoookJP1k
oookJP03o`000?oonf[ooo]Z00Oooo]Z00Co0000onBjZooT^Z_oi;Z[0_l00004om^j^007o`000?oI
^;SofKRhomVh^?l0003oe;_1o`000005om>i`003o`000?oB]kood[No00;o000000?oakO;o`000?o7
^L`01Oo7^L`00ol0003oakO;olNgb`03olNgb`?o00001_nk]mD00ol0003o_;KCokbfd`03okbfd`04
o`000?n`_>;o0000o`0000So/k_O0_l0000:ojRnj@;o00000onK`_<00ol0003ohgDIo`000003o`00
0003omEO6_l0003o000000Co000000Co_d4>o`000?na;P;o/Bh20_l00003oihD00So000000?oOP00
o`000?l000007ol000001_m?003o0000o`000?l0003o>`0Co`0000;on[j300Co0000ooo?R?l0003o
o=Ic0ol000001?nXb?7o0000oj[:lOnZb_43o`0000GoZl3Y00?o0000ojfoj?l000000_l00003oj^f
h0;o000000?o_<GRo`000?noa]l00onoa]l2o`0000?o`<SQ00Go0000ol?9goo3bMoo`lWOo`000002
olC<h004o`000?o6c=ooa/cOolK<g`;o00001_o6c^000ol0003obm;Ool_Bg`02ol_Bg`03o`000?o<
d]ko000000Koc=CP00?o0000om7Ig_oAfMh00_oAfMh00ol0003od=[Pom3Jh002om3Jh003o`000?oG
hMkoen7N00;oen7N00Ko0000omOSgooGhmoo0000omcUfol00003omg[g0;o00000_oSlML3o`0000;o
iOSB00Go0000onGl`_l0003ofoNTo`00000;oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX0<ooonfX003Cooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0KoookJP?o
00000_l[6XT3o`0000;oDd6O00?o0000of=DZomSE:/00_l00005og=V]@go00000on<O[l00ol0003o
TH2noi60_P02oi60_P;o00000_nCQl<00ol0003oVHW2oiV9`P06oiV9`P04o`000?nMRl3o0000o`00
00CoWi7500?o0000oij@a?l000002_nST/@01Ol0003oYYC3ojJD`onVU<?o000000CoYYC300?oYiW7
o`000?n[VlH01_n[VlH2o`000003oj^Ka_l0003o[Yg600Oo[Yg60_l000000on_W/Ko0000ok:PaP07
ok:PaP03o`000?ncXLGo000000Oo]J?60_l00003okNTa@03o`000?nhY/Ko^:K600;o^:K60_l00005
okVVaP04o`000?nlZLKo_:W6o`0000Go_:W61?l00006ol6Z``03o`000?o3[L?o`jg300?o`jg300?o
0000olB^a?l000001_o5[l@2o`0000;ob[3100Co0000olZa`Oo:/L7o00001Oo</l400ol0003oc[K2
oljf`P02o`000003om6d_Ol0003odkNn00CodkNn00Ko0000omFj_ooE^[oo0000omRi^_l00002om^k
^P07o`000?oJ_;[o0000ombn^ol0003ohKfco`000003on?0]0;o00000_oZ`Z/01?l0003ok<F/o`00
0?l00002ooC5W@03o`000?ok`hOo000000Co00004ooonfX00ol0003ooo]ZoookJP1koookJP03o`00
0?oonf[ooo]Z00Oooo]Z00Co0000onBjZooT^Z_oi;Z[0ol00002om^j^003o`000?oI^;SofKRh00?o
fKRh00?o0000om>i`?oC^L000ooC^L000ol0003od[Noom:g_`02om:g_`?o00001Oo7^L`00ol0003o
akO;olNgb`04olNgb`03olNdb?l0003o_kG@00?o000000?o^kOEo`000?l000001_nl]]<2o`0000Oo
/k_O0_l00002okJjg003o`000?nX_^WoZ;kY00CoZ;kY0ol00002ojfmi@03o`000?nK`_?oVl;c00;o
Vl;c00?o0000on=e6Ol000000ol000000ooEGa[o0000om9Q;`02o`000004ol134Ol0003o0000o`00
00?o/Bh21ol000000onB50co0000o`00000Go`0000CoF`001?l00004odl000;o00000olk01<00ol0
003on[j3ooZnP`03o`000003oocFLol0003o000000?oZ<Sa0_l00009oj_0j@03o`000?n[]^3oZkKP
00;oZkKP0_l00004okc5hP04o`000?noa]oo_lKOo`0000Ko`<SQ00?o0000ol?9gol000001?o4c>00
0ol0003oa/cOo`000006olK>h003o`000?o6d>;o000000Cobm;O0_l00005olcDh003o`000?o<en7o
000000;odMWN0_l00004om3Jh006om7Oh_l0003oen;No`000?oGhMko00000ooGhml2o`0000?ogN_L
00Oo0000omc]g_l0003oho7Go`000?oQlM[o000000?oiOSB00?o0000onGl`_l000000_l0000;oook
JP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<ooonfX003Cooo]Z00?o0000oookJ_oo
nfX08OoonfX00ol0003ooo]ZoookJP0IoookJP;o000000Co001Mo`000?l[6XWo:aZ90_m6=i`00ol0
003oDd6Oo`000003of=DZ`03o`000?mcI[GoLfJe00CoLfJe00?o0000oh5c^on1Lk/01On1Lk/00ol0
003oS7joohan_`05ohan_`03o`000?nAP;koTH2n00;o00001OnCQl<00ol0003oVHW2oiV9`P05oiV9
`P;o000000CoWi75o`000?l0003o00001OnNT<@00ol0003oXi;4oj>Ba007oj>Ba004o`000?nVU<?o
0000o`0000;oYYC31OnWVLL01?l0003oZi_6oj^Ka_n[VlH3o`0000CoZi_600?o0000ojjMa_n^WLH0
0on^WLH2o`0000Co[ik600?o0000ok:Pa_nbX<H00onbX<H2o`0000?o/j7500?o0000okFSa_neXlH0
0oneXlH00ol0003o]jC5okNTa@03okNTa@03o`000?nhY/Ko^:K600;o00001oniY/H00ol0003o_:W6
o`000006okbYaP04o`000?nmZlOo_J_7okf[a`?o00000_o1Z/<00ol0003o`jg3ol>]``05ol>]``03
o`000?o5[lCoaJo400CoaJo400?o0000olNaaOo7/LD00ol000000oo:/L7o0000o`000004olbc`@03
o`000?o>]/;oc[K200?oc[K20_l00004om>g_P03o`000?oE^[ooeKZo00;oeKZo0_l00003om^k^P05
o`000?oL_[_og;jkombn^ol000000ooS`;@00ol0003oiL>donG3]002o`0000?ok<F/00?o0000ooC5
WOodaId00ol000001?omaXCo0000o`000?l0000DoookJP03o`000?oonf[ooo]Z07[ooo]Z00?o0000
oookJ_oonfX01_oonfX2o`0000?oi;Z[00Ko0000on:gZ_l0003o0000om^j^?l00005omVh^0;o0000
0ooC^L000ol0003od[Noom:g_`03om:g_`;o000000?obkG4o`000?o7^L`00_o7^L`00ol0003oakO;
olNgb`04olNgb`?oakC800Co0000okned?no]M3o_kG@0_l00005okbfd`;o000000?o_[GBo`000?nc
^ml01?nc^ml2o`0000Go][[L00?o0000ojRnjOnX_^T00ol00006ojfmi@03o`000?nK`_?oVl;c00Co
000000?ohG@]o`000?oJK3400ol00002om9Q;`04o`000?o0@a7o`4<Aol134@?o00000_na;P800ol0
003oXBXQoj4Z8@06o`0000;oTQ@<0ol00009ogX000Co00001?mK0005o`0000;oC`001_l000000olk
01?o0000o`000004o`0000;oolUi00?o0000oocFLol000000_l00002oj^oj003o`000?n[`>WoZl3Y
00CoZl3Y0ol00002oj^gh@04o`000?n[]^3oZkKPo`0000Ko_<GR00?o0000oko6gol000002?o0b>40
0ol0003oa<cPolC<h003olC<h0;o00001Oo6c^02o`0000;oa]3R00?o0000ol_Bgoo;d]l00_l00002
ol_Eh@05o`000?o<e>3oc=CPolcDh?l000000_o<en400ol0003odMWNo`000004om3Jh004o`000?oA
gn;odMoRo`0000;oen;N00?o0000omOSgooGhml00_oGhml02Ol0003ogN_Lomg[g?oMjmco0000omc]
g_l0003oho7Go`000002on7afP03o`000?oUn=;oiOSB00Go00003?oonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z03?ooo]Z000doookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oook
J_oonfX06?oonfX01_l0003o001Io`000?l0003o:aZ9o`0000;oASNL0ol00003of=DZ`03o`000?mc
I[GoLfJe00?oLfJe0_l00006oh5c^`;o00002?n<O[l2o`0000OoThO300?o0000oiV9`_nIRL800onI
RL85o`0000SoWY3400?o0000oj>Ba?nST/@02?nST/@00ol0003oYYC3ojNIa`07ojNIa`04o`000?n[
VlKo0000o`0000SoZi_600Go0000ojjMa_n^WLKo[Yg6o`000006ojnNaP03o`000?nbX<Ko/Z3600;o
/Z3600?o0000ok>QaOncXLD01?ncXLD00ol0003o]J?6okFSaP02o`0000Ko]jC500?o0000okRVa_l0
00002OniY/H2o`0000Ko_:W600?o0000okf[aonmZlL00_nmZlL00ol0003o`:g7ol2]a`04o`0000Go
`jg30_l00005olF_a003o`000?o7/LGoak7500Coak750ol00003olbc`@03o`000?o>]/;oc[K200Co
c[K21?l000000ooC]kko0000omFj_`04omFj_`04o`000?oG_;oo0000om^k^P;o00000ooL_[/2o`00
00;ohl2d00Go0000onG3]?oU`kCoiL>do`000003onc5[0?o00000_ogbI`00ol0003ooLJ4o`000003
o`0001Cooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP06oookJP05o`000?oY]Yko
0000onBjZol000000ooR]jX3o`0000CofKRh00Ko0000omRf]ooH][Oo0000om>i`?l00005om:g_`08
o`000?oA]KkodKFno`000?o;]LCo0000olNic?l00006olNgb`GoakC800?o0000okned?l000000_o0
/ld3o`000003okbfdol0003o_[GB00?o_[GB00Go0000ok>kgonc^moo/k_Oo`000008okJjg0;o0000
2_n]_ND2o`000003oj?0k_l0003oiGXQ00;o000000GohG@]o`000?oJK37ofV`ao`000003om9Q;`?o
000000?o`4<Ao`000?nlBBl01?l00005oj4Z8@03o`000?nQ9a[o000001ko00000_mO01d7o`000007
oo^gKol0003oolUiooo9NOl0003oo=Ico`000005oj^oj003o`000?n[`>WoZl3Y00?o00001_n[]n42
o`0000So_<GR00?o0000ol38hOo0b>401?o0b>42o`000003ol3:h_l0003oa<cP00?oa<cP00Co0000
olC>h_o4c^;o00000oo6c^000ol0003oa]3RolK@hP03olK@hP;o00001Oo;eN400ol0003oc=CPo`00
0003olcGh@;o00001?o@f^003Ol0003odMoRom7Oh_oAgn;o0000omORg_l0003oenCPo`000?oGhmoo
0000omSUh?l000000_oMjm`00ol0003og>gNomc]gP02o`0000;ohO7J0_l000000ooUn=;o0000o`00
0002o`000003om7bVOl0003ooo]Z00_ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Zoook
JP0coookJP00=?oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000
o`00FOlH38800_l00003odHgW005o`000?mMDJcoGE6/o`000?mSE:/00_l00004og=V]@04o`000?mi
K[_oNFjko`0000CoPG>k00Co0000ohEl`On5O<7o00001_n<O[l2o`0000SoThO300Co0000oiV9`_nI
RL;oVHW21?l00002oiZ?aP03o`000?nNT<CoWY3400OoWY3400?o0000oj>Ba?nST/@00onST/@3o`00
0003ojBGb?l0003oYiW700WoYiW700?o0000oj^Ka_n[VlH02?n[VlH01?l0003o[Yg6o`000?l00007
ojnNaP03o`000?nbX<Ko/Z3600;o00001oncXLD00ol0003o]J?6o`000009okNTa@03o`000?niY/Ko
^JK600Oo^JK600?o0000ok^Xa_l000001OnlZLH00ol0003o_J_7okf[a`04okf[a`03o`000?o0[LOo
000000?o`Jk70ol000001Oo3[L?o0000olF_a?o5[lCo000000?oaJo400?o0000olNaaOo7/LD01?o7
/LD00ol0003ob;C6o`000002o`000003olbc`Ol0003oc[K200Goc[K200?o0000olnha?l000000_o@
^L<00ol0003oeKZoomFj_`03omFj_`05o`000?oG_;ooekboomNl_ol000000_oM_[X00ol0003og;jk
o`000002omk1^`03o`000?oS`;Co000000?oiL>d00Go0000onc5[?o/aJco0000onk8[002o`0000;o
mlVL00?o0000oog6Q?l000000ol0000DoookJP03o`000?oonf[ooo]Z07Wooo]Z00?o0000oookJ_oo
nfX01_oonfX00ol0003ojKJNonVfWP02o`0000Coh[NZ00?o0000omje[_l000000_oI^;P00ol0003o
f;JgomRf]`02omRf]`;o00001?oB]kl01_l0003odKFnom6e__oA]Kko0000ol^ea0?o00001Oo7]l/6
olNdb0;o00001_o0/ld2o`0000Co_[GB00Co0000ok>kgol0003o00001_nf^]`2o`000003okZad?l0
003o[KgU00Oo[KgU0_l00002ok6jh@06o`000?nS`>koXl3^o`000?oUNR7o00000_oQM2d2o`000005
omY/<Ol0003o0000om9Q;ol000000_o7EcH3o`0000?o_4T_1Ol00002oj4Z8@;o00001onA4``3o`00
00;oTb0U00?o0000og@04?md01000_md0108o`0000GoG`0M0ol000002?ld017o0000o`000?l0003o
C00ao`000?ok]foo00000_oobGT3o`0000KoZkoX0_l00007oj^gh@;o00001onlaN82o`0000;o_<OS
00?o0000ol38hOo0b>400_o0b>401Ol0003o`<[Rol3:h_o0b^;o000000;oa<cP0_l00004olC>hP03
o`000?o6c^3o000000Koa]3R00?o0000ol_EhOo;eN401?o;eN42o`0000Coc=OQ00Co0000om3Jh?o@
f^3od=[P0_l00004om7OhP;o00000ooGi>02o`000004omSUh?l0003ogN_Lo`0000;og>gN0_l00002
on7afP;o000000?oiOSBo`000?oQoLd01?l0000=oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000
oookJ_oonfX0<ooonfX003Cooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0Eoook
JP?o000000?o60b2o`000?l000000om6=i`01?l0003oGE6/oeeA[?mMDJ`2o`000005ofYP]?l0003o
LfJeog=V]Ol000000omiK[/01Ol0003oPG>koh5c^on1Lk_o000000?oQGc100?o0000ohan_on<O[l0
0on<O[l00ol0003oShC4o`000009oi>7``Co00001_nJSlH00ol0003oWY34oij@a006oij@a003o`00
0?nST/CoXi;400?o00001OnTUlP00ol0003oYiW7ojNIa`04ojNIa`;o000000?oZ9W7o`000?n[VlH0
2_n[VlH00ol0003o[ik6ojnNaP08ojnNaP;o00002_ncXLD00ol0003o]jC5okNTa@07okNTa@;o0000
1oniY/H2o`0000?o^jS600Go0000okbYa_nlZLKo_:W6o`000007okf[a`;o00001_o1[/L3o`0000;o
aJo400Co0000olF_a?o5[lCo00001_o7/LD01_l0003ob;C6olRda_o8]<Ko0000olZeaP;o00001Oo>
]/801_l0003ockS4olnha?o?^<Co0000om2i``;o00000ooE^[l00ol0003oekboomNl_`02omNl_`;o
000000CogKjjo`000?oL_[_o00000ooN`K/02Ol0003oiL>donG3]?oU`kCo0000onO6]Ol0003ok<F/
o`000002onk8[003o`000?ogbIcomlVL00;o000000Coo/V1o`000?ok^eGo00005OoonfX00ol0003o
oo]ZoookJP1hoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000onVfW_oY]Yh00_oY]Yh00ol0003o
h[NZon:gZP02on:gZP06o`000?oN]Jkog[F^o`000?oI^;So00001?oH][L01_l0003oekBfo`000?l0
003od[Noo`0000GodKFn00Co0000ol^c`_o;/l;obk?20_l00002olNgb`KoakC800?o0000olNca_l0
00001?o0/ld01?l0003o`K3:ol6`b_o1/<X2o`0000?o_[GB00?o0000okJjg?nf^]`01?nf^]`2o`00
00Co^[7@00?o0000ojfmiOn]_ND00_n]_ND3o`0000Go/K[Q00?o0000oj?0k_l000000_oUNR43o`00
0004omY_>ol0003o0000om5T>`?o00001?o7EcH5o`000003oka9;ol0003o[S/]01Go00001_n43a/0
0ol0003oG`0Moel07@04o`0000;oIP0R0_l00003od`0<@;o000000?onkM_o`000?l000001?l00002
oj^oj0?o00000_n[]^000ol0003oZkOQoj^gh@03oj^gh@;o00002?nlaN800ol0003o_<OSokc7h`03
okc7h`04o`000?o0b>7o0000o`0000Go`<[R0_l00006olC>hP;o00001Oo6d>800ol0003oam;So`00
0005ol_Eh@08o`000?o<en;oc=ORo`000?o<en7o0000olcIhol00002om3Jh003o`000?oAgn;odMoR
00CodMoR00Go0000omOTh?oGi>3oenCPo`000002omGUhP?o00000_oLkMh01_l0003ofnoOo`000?oQ
lM[o0000omogf@;o00000_oQoLd4o`0000gooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Z
oookJP0coookJP00<ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0
00000olH38;o0000odHgW002odHgW0;o00000omMDJ`2ofUQ]P;o000000?oLfJeo`000?miK[/00omi
K[/01?l0003oPG>koh5c^ol00004ohEl`@04o`000?n<O[ooS7joohan_`;o00000on?Q<@00ol0003o
ThO3oi>7``02oi>7``?o000000?oThO3o`000?nJSlH02?nJSlH00ol0003oWY34oij@a006oij@a0?o
00002?nTUlP01?l0003oYiW7ojNIaonWVLL3o`0000CoZ9W700?o0000oj^Ka_n[VlH01On[VlH2o`00
0003ojbLaol0003o[ik600Co[ik600?o0000ojnNa_n_W/H00_n_W/H00ol0003o/j75ok>Qa@08ok>Q
a@ko00001OniY/H00ol0003o^jS6ok^XaP03ok^XaP04o`000?nlZLKo_:W6o`0000Oo_J_700?o0000
ol2]aol000001Oo1[/L01?l0003o`Zo8ol:_b?o2[lP3o`000003olF_a?l0003oak7500Goak7500?o
0000olRda_o8]<H00_o8]<H01?l0003ob[G6o`000?o;]/H2o`0000?oc[K200?o0000olnha?o?^<@0
0_o?^<@01_l0003odK_4om6ka?l0003oeKZoo`0000Coekbo00Ko0000omVo`?oI_l3o0000omfn^_l0
0004omk1^`04o`000?oU`kCoiL>do`0000?oilJe00Co0000onk8[?o^b:cok/R/0ol000001_oicI_o
0000ook9POl0003onk]Eo`0001Gooo]Z00?o0000oookJ_oonfX0N?oonfX00ol0003ooo]ZoookJP05
oookJP03o`000?oY]YkojKJN00;ojKJN0_l00002on:gZP03o`000?oQ]JWo000000;og[F^00?o0000
omRf]ooH][L00_oH][L00ol0003oekBfomNd]P02omNd]P;o00001OoA]Kh00ol0003obk?2ol^c`P03
ol^c`P;o00001Oo7]<P01Ol0003oak?6olNca_o7/lKo000000;o`;?=00?o0000ol6`b_o1/<X01?o1
/<X01Ol0003o_[GBo`000?no]<oo000000Co][[L00?o0000okZad?nj/M001Onj/M001?l0003o[KgU
o`000?l00009ok6jh@?o000000?oiGXQo`000?oRN3L00_l00002omY_>`04o`000?oAI3_odF@kom5T
>`?o00000_o7EcH01?l0003o[Sdbojhm<_n^?C84o`0000GoXbdT00?o0000oi@X=?nD:3@01_nD:3@4
o`0000OoQ0lK1?l00005ofH08P04o`000?m<037oC00aod`0<@;o000000?oAP0ao`000?l000002?l0
0006oj^fh003o`000?n[]n7oZkOQ00;o000000?o/L;Vo`000?nlaN801OnlaN82o`0000Oo_<OS00?o
0000ol3:h_o0b^801Oo0b^800ol0003oa<kRolC>hP04olC>hP03o`000?o5d>?o000000?oa]3R0_l0
0002olOBh`04o`000?o;eN7obmGQol_Eh@;o00000oo<en82o`0000;oc=WS00?o0000om3Jh?l00000
1_oAgn801OoAhN?o0000omOTh?oGi>3o000000CoeNGR0_l000001?oLkMko0000om__gooKkml2o`00
00;ogoOI00?o0000on7mcOoQoLd01?l0000>oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oook
J_oonfX0<ooonfX003?ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0CoookJP;o
00000_lH38801?ll<igo0000odHgW?l00002oe59ZP;oGE6/00Co0000ofUQ]_mYHKKoJF6f1_l00002
ogU^^`03oh5c^ol0003oQGc100GoQGc100?o0000ohan_ol000000_n?Q<@8o`0000;oThK300?o0000
oiJ=b?l000002OnJSlH00ol0003oWY34oij@a003oij@a0?o000000?oX9G9o`000?nTUlP02?nTUlP0
1?l0003oYiW7o`000?l00007ojRIa`03o`000?n[VlKoZi_600CoZi_600?o0000ojbLaol000001ol0
0002ojnQbP;o000000?o[j;:o`000?nbY<T01onbY<T01?l0003o/jC:ok>Tb_l00005okJWb@;o0000
1?nfYlX6o`0000Ko^jS600?o0000okbYa_l000001onmZlL01Ol0003o`:g7ol2]aoo0[LOo000000?o
`Jk700?o0000ol:_b?o2[lP01?o2[lP3o`0000Goak7500?o0000olRda_o8]<H00oo8]<H2o`0000Co
bkK600?o0000oljf`_l000001?o?^<@2o`0000?odK_40_l00004omNl_`04o`000?oI_l3ofKo0omVo
`0;o00000ooN`K/01Ol0003ohLBko`000?oU`kCo000000?oilJe00Go0000onk8[?o^b:co0000oo7<
[002o`000005ooW=Vol0003oo/V1o`000?ok^eD00_l0000EoookJP03o`000?oonf[ooo]Z07Oooo]Z
00?o0000oookJ_oonfX01OoonfX2o`0000;ojKJN00Ko0000onNcW_oW/iko0000on:gZ_l00002on6e
Z@04o`000?oN]Jko0000o`0000;of;Jg00?o0000omNd]_oG];H00ooG];H00ol0003oe[:eo`000003
om6e_P03o`000?oA/kco000000?obk?200Co0000ol^`_oo;/;oo00000oo7]<P00ol0003oak?6olNc
aP02olNcaP03o`000?o0/lgo000000So`K3:0_l00002okndc`04o`000?nf^]co0000o`0000Wo^[7@
00?o0000ok6jhOna^^401_na^^42o`0000;o];SK1?l00002on9h=`04o`000?oJKc_ofVlkomY_>`;o
000000CodF@ko`000?niC3co^D`l1?l00004ojhm<PKo00000_nS;B@00ol0003oU2Pdoi@X=004oi@X
=003o`000?n66BcoQQT/00[o00000_mV0286o`0000;oC00a0_l00002odH0<@Co000000Coo;iLo`00
0?l0003o00002_n[]^02o`0000Co/L;V00Co0000okc5h_nlaN;o_<GR0_l00007okc7h`04o`000?nm
bNCo_LWTo`0000?o`<[R0_l000000oo1c>?o0000olC>hP03olC>hP;o00000oo5d><00ol0003oa]3R
o`000005olOBh`03o`000?o;eN7o000000Coc=OR00Go0000olcJi?o<f^Co0000olcIh`02o`0000Go
dMoR00Ko0000om7QhooAhN?o0000omOTh?l00004omGUhP04omK[hol0003og>kNo`0000;ofnoO0_l0
0003omogf@03o`000?oQoLgo000000Co00003_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oo
nf[ooo]Z03?ooo]Z000coookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX04OoonfX3
o`000005oaP<P_l0003o?3>Moc`cWOl000000omABJX00omMDJco0000ofUQ]P04ofUQ]PGoNG2l0ol0
0007ohEl`@Go00001?n?QL@01?l0003oThK3oi>6`onCQ/<2o`0000?oUXg800?o0000oiZ?a_nJSlH0
1onJSlH00ol0003oWY34o`000002o`0000GoX9G900?o0000ojBGb?nTUlP01_nTUlP2o`0000WoZ9W7
00Co0000oj^Ka_n[VlKoZi_61Ol00002ojbObP03o`000?n_XL[o[j7:00?o[j7:0_l00004ojnRbP03
o`000?nbY<Wo/ZC900?o/ZC90_l00004ok>TbP05o`000?nfYlWo]ZO9okJWbOl000001onfYlX00ol0
003o^JW:o`000006okVZbP?o^jS600?o0000okf[aonmZlL01OnmZlL00ol0003o`:g7ol2]a`02ol2]
a`04o`000?o1[/Oo`Jk7o`0000Ko`Zo800Co0000ol>bbOl0003oaK?90ol000000oo7/LGo0000olRd
aP05olRdaP;o00001?o;]/H3o`0000?ockS400Co0000om6j`ooA^/?o00000_oA^l@00ol0003odkg4
o`000002omNl_`03o`000?oI_l3ofKo000;ofKo00ol000000ooN`K_o0000on74^`02on74^`0<o`00
0?oWa[GoilJeonO6]Ol0003ojLVeo`000?o^b:co0000oo7<[?l0003onLfK1ol0000FoookJP03o`00
0?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX01_oonfX01Ol0003okK2>o`000?oY]Yko000000?o
ik>N00?o0000on6eZOoQ]JT00_oQ]JT01_l0003ogK:/omfb[?l0003of;Jgo`0000CoekBf00Oo0000
omJb]OoF/[Goe[:eo`000?oA]Kko000000?odK>l00?o0000ol^c`_l000001?o;/;l00ol0003oakC8
o`000006olNcaP03o`000?o1/<[o`K3:00Go`K3:00Co0000ol:cc?o2/lco`[?<1?l00008okZad0;o
00000_nj/]800ol0003o/K[Qok6jh@02ok6jh@?o00001Ond^=/01?l0003oighZo`000?l00002on9h
=`;o000000?ofVlko`000?o?ID@00ol00004okU<?0?o000000Co[Sdbo`000?nc@cKo00001?nU<2L<
o`0000OoQaX]2?l00002og0@>P03o`000?m<037o000000?oAP0a0ol000000oofXTGo0000oobnG002
o`0000OoZkKP1Ol00006ok72iP03o`000?nlaN;o000000Ko_<OS0_l00005okg9i003o`000?o0b^;o
000000Co`LcS00Co0000olC>h_o4c^;o00001Oo5d><2o`0000Koam;S0_l00004olcGhP03o`000?o<
f^Coc=[T00;oc=[T0_l00004om7OhP;o00000ooAhN<2o`0000?oeNGR00Go0000omK[hooFjn?o0000
omc^gP02o`000003om__gol0003ogoOI00;ogoOI0ol000000ooNo/ko0000o`000002o`0000kooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0boookJP00<ooonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z013ooo]Z0_l000001ol50Gko60b2o`000?l[9YSo?3>Modm9[?l0
00000_mABJX00ol0003oJF6fofUQ]P04ofUQ]POoNG2l00?o0000ohEk`On5Nl401_n5Nl48ohn5a004
o`000?nCQ/?oThK3o`0000GoUXg800?o0000oiZ?a_nJSlH01_nJSlH3o`0000SoX9G900?o0000ojBG
b?nTUlP01?nTUlP2o`000003ojBGb?l0003oZ9W700WoZ9W71?l00007ojbObP05o`000?n_XL[o[j7:
ojnQb_l000001on_X/X00ol0003o/ZC9ok:Tb@02o`0000Ko/jC:00Co0000okJWbOl0003o00002?nf
YlX2o`0000Oo^J[:00Co0000okZ[b_njZl[o^Z_:1?l00002okf[a`03o`000?o0[LOo`:g700?o`:g7
00?o0000ol6^aol000001_o2[lP01Ol0003o`k;9ol>bbOo3//Wo000000?oaK?90_l00005olRdaP;o
000000Gob[K6o`000?o;]/KobkK6o`000003olbha`03o`000?o?^<Co000000?odK[300?o0000om6k
a?l000000ooC_L@00ol0003oekboo`000003omVo`006o`000?oI`/;ofL;2o`000?oN`K_o00000ooQ
a;/2o`0000;oilJe00Co0000onW9]OoYbKGo00000_oac:`01ol0003onLfKooW=Vol0003onm2Jo`00
0?ooc7`00_l0000FoookJP03o`000?oonf[ooo]Z07Gooo]Z00?o0000oookJ_oonfX01OoonfX01?l0
003okK2>onf`S_o]/8h2o`0000?oik>N0_l00003on6eZ@04o`000?oM/ZcogK:/omfb[0;o00001?oG
];H00ol0003oe[:eomJb]@02omJb]@;o00001?oA/k`00ol0003obk2ool^`_`04ol^`_`;o00001Oo7
/lH2o`0000Go`K3:0_l00007ol:cc003o`000?nj/M3o^[7@00Go^[7@00?o0000okZbd_nj/]800onj
/]801?l0003o/K[Qo`000?l00009okBhf`07o`000?oWOR[o0000o`000?oRN3Oo0000omU`A003o`00
00?ocfE40_l00003okU<?003o`000?niCCgo000000Co00002?nU<2L2o`000003oj4g?Ol0003oQaX]
00WoQaX]00?o0000ofh==_l000000_l00004og0@>P?o00000_m60342o`000003oeP7B?l0003o0000
00Ko00001?n[]^05o`000003ok71i_l0003o/L;V00Go/L;V0_l00006okc7h`03o`000?nmbNCo_LWT
00Ko_LWT00?o0000ol7<hoo1c><00oo1c><00ol0003oa<kRo`000005olG@h`04o`000?o6dnCoa]?T
o`0000Goam;S00Co0000olcGh_o<en;oc=OR0_l00005olcJi0;o00000ooAgn800ol0003odN7Som7Q
h`03om7Qh`05o`000?oEiN;oeNGRomGUh_l000000_oFjn<01?l0003og>kNo`000?oKlMl4o`000005
omogfOl0003o0000o`000?oNo/h01?l0000?oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oook
J_oonfX0<_oonfX003?ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0?oookJP;o
000000Go1@5no`000?l[9YSo:bJHo`000002odm9[003o`000?mABJ[o000000GoJF6f00?o0000og1Z
_?miL;`01?miL;`2o`0000KoQG_100?o0000ohR3a_l000002?n?QL@2o`0000OoUXg800?o0000oiZ?
a_nJSlH00_nJSlH3o`000003oibCb_l0003oX9G900SoX9G900Co0000ojBGb?nTUlSoY9O80ol00004
ojBGb003o`000?nXVLOoZ9W700Go00000onXWL/00ol0003o[9o:ojbObP07ojbObP04o`000?n_XL[o
0000o`0000So[j;:00?o0000ok:TbOl000002?ncY<X2o`0000Wo]ZO:00?o0000okRXb_l000001_ni
Z/X00ol0003o^Z_:okZ[bP02okZ[bP04o`000?nm[L[o_Jg:okf]bP;o00001oo0[LL00ol0003o`Zo8
ol:_b004ol:_b003o`000?o3//Wo`k;900?o`k;900?o0000olFcbOl000000_o6]<T3o`000008olRd
a_l0003ob[K6o`000?o:]/Ko0000ol^fa_l00005olbha`;o00001?oA^/<00ol0003odkg4om>ma003
om>ma0;o00000_oI_l000ol0003ofL;2omW2`P02omW2`P05o`000?oQa;_ohLBkon74^ol000000_oS
ak`00ol0003oilJeo`000002onW9]@03o`000?oac:colLb/00;o000000GonLfKo`000?okd9[o0000
ooo<O003o`0001Kooo]Z00?o0000oookJ_oonfX0M?oonfX00ol0003ooo]ZoookJP05oookJP;o0000
0_o]/8h00ol0003ojjj>o`000002onNcWP07o`000?oU/Iko0000on6eZOl0003ogk:Xo`000002omfb
[003o`000?oK/:co000000;oekBf00?o0000omJb]OoF/[D00ooF/[D00ol0003oeK2do`000003om6c
_003o`000?o;/;oobk2o00Cobk2o00?o0000ol^`_ol000000_l000001Oo7/lKo0000olNaa?o7/LCo
000000?o`K3:00?o0000ol:cc?o2/l`01_o2/l`2ol>ab0?o00000_nj/M02o`0000Ko^[;B0_l00008
okBhf`;o000000Go^:k?o`000?l0003o0000on9j?`02o`0000?ofG1400Ko0000olmUA?o?IDCocfE4
o`000?o2FDH3o`000003okU<??l0003o/dDi00?o/dDi6Ol00004og0@>PCo00000_m60342o`0000?o
F0M80ol00004ofBBj@Oo00001Ona`NH00ol0003o/L;Vok72iP03o`000003ok;3i_l0003o_<OS00?o
_<OS0_l00007okg9i004o`000?nmbnGo_L_Uo`0000Go`LcS00?o0000olG@hoo5d><00oo5d><00ol0
003oa]?TolKCi002olKCi006o`000?o7d^?o0000o`000?o7e>Co00000_o<en800ol0003oc=[TolcJ
i004olcJi006o`000?o;g>Ko0000o`000?oAgn;o00001?oAhN<00ol0003odN?Uo`000002omGUhP04
o`000?oFjn?oe^_SomK[h`;o000000Cofo7Oo`000?oImN7ofOGQ1ol000000ooCo;Oo0000o`00000@
oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<_oonfX003?ooo]Z00?o0000oook
J_oonfX0:ooonfX00ol0003ooo]ZoookJP0>oookJP;o000000Go1@5no`000?l[9YSo:bJHo`000003
odm9[0?o00000omYHKH00ol0003oL6Zlog1Z_004ogU`_004o`000?moN/?oOg[3o`0000CoQG_100Go
0000ohR3a_n8PlKoR8?6o`000006ohn5a0;o00002?nFSLP00ol0003oVXo6o`000004o`0000?oW9?:
00?o0000oj2EbOnPULT01onPULT3o`0000OoY9O80ol00005ojRMb`;o000000?oZIk;o`000?n/WlX0
2?n/WlX2o`0000[o[j;:0_l00008ok>TbP03o`000?ndYL[o000000Oo]ZO:0_l00003okRXbP04o`00
0?niZ/[o^J[:okVZbP;o00001_njZlX00ol0003o_Jg:o`000004okf^b`?o000000?o`:g7o`000?l0
00001Oo2[lP00ol0003o`k;9ol>bb@04ol>bb@;o00001Oo6]<T3o`000005olZfa_l0003ob[K6olZf
a_l000001Oo<^<L00ol0003ocK[7olfja`02o`000003om6j`ol0003o000000Codkg400Ko0000omBo
aOoD_lGo0000omVo`?l00004omW2`P04o`000?oQa;_ohLBko`0000CohlNl00Go0000onW9]OoYbKGo
0000on_=]P02o`0000;olln[00?o0000oo_@VOl000000_l000000ooocg[o0000o`00000FoookJP03
o`000?oonf[ooo]Z07Cooo]Z00?o0000oookJ_oonfX01OoonfX01Ol0003ol:Qio`000?o]/8ko0000
00;ojjj>0_l00003onFaWP;o000000Cogk:Xo`000?oM/Zco00000ooK/:`00ol0003oekBfo`000004
omJb]@09o`000?oE/;CoeK2domF`]?l0003odK>lo`000?o@/K_o000000Cobk2o00?o0000ol^`_oo;
/;l00oo;/;l2o`0000?oak7400?o0000ol6`b_l000002?o2/l`4ol>ab003o`000?nk/<ko000000?o
00001Onj/]800ol0003o_;7?o`000006okBhf`;o00000onh[/l01Ol0003ojH<co`000?l0003ohWXo
00;o00000ooIL4@3o`000003olmUA?l0003o`UU600;o`UU61Ol00003ok=5>@03o`000?n/BDko[4U>
00Go[4U>00?o0000oiHa@onF<D<00_l00007oiDdBP03o`000?m`43[o000000Co00000omh63l01?l0
003oAP0ao`000?l00003oeP7B0;o000000?o2@0Vo`000?mTT^T01_mTT^T00ol0003oTKG_o`000007
ok71iP;o00001Onb`nH01?l0003o_<OSo`000?l00006okg9i0;o00001OnmbnD01_l0003o`LcSo`00
0?l0003o`LkTo`0000?oaM3S0_l00005olKCi0;o00000oo7e>@00ol0003oc=ORolcGhP05olcJi0;o
00000_o;g>H00ol0003od=oSo`000004om7Qh`06o`000?oAhnGodN?Uo`000?oEiN;o00001?oFjn<0
0ol0003ofo7Oo`000002omWeh@;o00000_oLnM`00ol0003og?o;omcob`04o`00017ooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0boookJP00<_oonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[ooo]Z00cooo]Z0ol000001Ol50Gko9bNJo`000?l[9YSo000000?oCdV/0_mOF[D2
o`000003ofUQ]_l0003oL6Zl00;oL6Zl0omiL;`01Ol0003oOg[3ogmj`omoN/?o000000?oQG_100?o
0000ohR3a_n8PlH00_n8PlH00ol0003oShG4ohn5a002ohn5a0;o000000?oTH[8o`000?nFSLP02?nF
SLP01?l0003oVXk6o`000?l00005oibCbP03o`000?nPULWoX9G900OoX9G900?o0000ojBGb?nTUlP0
0onTUlP3o`000003ojFKc?l0003oZ9g;00?oZ9g;0ol00004ojVNb`03o`000?n/Wl[o[9o:00Co[9o:
0_l000000on]X<[o0000ojnRbP07ojnRbP;o000000?o/:;:o`000?ncY<X01OncY<X2o`0000?o]:G:
00?o0000okJWb_nfYlX00onfYlX00ol0003o^:S:okRXbP03okRXbP04o`000?niZ/[o^J[:o`0000So
^Z_:0_l00007okf^b`Go00000oo2[lP00ol0003o`k;9ol>bb@04ol>bb@03o`000?o5/lWo000000Co
a[C900Co0000olNfb_o7]/[oakK:0_l000000oo:]/Ko0000o`000004olbha`03o`000?o=^/OocK[7
00?ocK[700Co0000om>la?oC_<Co00000_oC_L@00ol0003oe;o5omBoa@02omBoa@03o`000?oI`/;o
fL;200;ofL;200Go0000omc4`_l0003ohLBko`000004on?7_004o`000?oYbKGojLVeo`0000;ojlff
00Oo0000oo??Zooccj_o0000oo_@VOl0003oo=BK00Co00005ooonfX00ol0003ooo]ZoookJP1coook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oo2XNOo`Z7T00_l00003on^^SP06o`000?oU/IkoiK6N
onFaW_l0003ohjjN0_l000000ooM/Zco0000om^`[003om^`[0;o00000ooF/[D00ol0003oeK2domF`
]003omF`]0;o00000_o@/K/01?l0003obk2ool^`_ol00006ol^`_`04o`000?o;[kko0000o`0000;o
ak7400?o0000ol:cc?o2/l`01Oo2/l`00ol0003o`k78ol>ab004ol>ab003o`000?nm[L[o_Jg:00;o
_Jg:0ol000000onj/];o0000okbac`02okbac`03o`000?nd^=_o];SK00;o];SK00?o0000okR^conh
[/l00onh[/l01?l0003ojH<conV3<ol00002on9j?`?o000000CofG14o`000?o5G4KoaEa60ol00002
ol9IAP;o`EQ500?o0000okUHEOniF5D01Ol00005oja9CP03o`000?nF<D?oUS5300?oUS5300Co0000
oiDdB_nE=4[oUCA:1Ol00007ogPH?`Co00000omH1dP2o`000004o`T09_l0003o:P12o`0000OoI9;Y
00?o0000oi6ekol000000ona`NH2o`000003ok;2i_l0003o//?V00Go//?V0_l00007okg9i003o`00
0?nmbnGo_L_U00Ko_L_U00Go0000ol7>i?o1c^Co`LkTo`000002olG@h`03o`000?o6dnCoa]?T00Co
a]?T00Co0000olGDiOo5e>Go00000_o7e>@00ol0003oc=ORolcJi003olcJi0;o00001?o;g>H2o`00
00;od>;T00?o0000om7Qhol000000_oAhnD00ol0003oeNGRo`000004omK[h`03omC/iOl0003o0000
00?ofOGQ00?o0000omcig?oLnM`00_l000000ooLol_o0000o`000002o`0001;ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP0boookJP00<_oonfX00ol0003ooo]ZoookJP0^oookJP03
o`000?oonf[ooo]Z00_ooo]Z00Co0000o`00?_l007Co00000_lW9iX2o`0000;oCdV/00Go0000oemJ
]OmOF[Go0000ofEN]P04o`0000;oL6Zl00?oNG2lo`000?moN/<00omoN/<01?l0003oQG_1ohEk`Ol0
0005ohR3aP05o`000?n?QLCoShG4ohn5a?l000001?nAR/P00ol0003oUXg8o`000004o`0000;oUXc7
0_l00008oibCbP03o`000?nPULWoX9G900;oX9G90ol000001?nPULWo0000ojBGb?nTUlP3o`0000Go
YI_<00Co0000ojRMbol0003o00001onYW//01?l0003o[9o:ojbOb_n/WlX3o`0000Co[J3:00?o0000
ojnRb_n_X/X00on_X/X2o`0000Co/:;:00Co0000ok>Tb_ncY<[o/jC:0_l00006okBUbP03o`000?nf
Yl[o]ZO:00;o00001_nhZ<X00ol0003o^J[:o`000008okZ[bP03o`000?nl[L_o000000Ko_Jk;00?o
0000okj_bonn[l/00_nn[l/5o`0000Go`k;900Go0000olFcbOo5/lWoaK?9o`000002olJdb@03o`00
0?o7]/[oakK:00?oakK:0ol000001Oo<^<Oo0000olbhaoo<^<Oo000000GocK[700Oo0000olnmb?l0
003odkc4o`000?oC_LCo000000Coe;o50_l00003omW2`P04o`000?oLa<;og<C2omc4`P;o00000ooS
ak`01Ol0003oi<Zmo`000?oYbKGo000000;ojlff00Co0000oo??Zol0003omM>[0_l000000oole9_o
0000ooo>M`02o`0001Sooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]ZoookJP05oookJP05
o`000?o`Z7Wol:Qioo2XNOl000000oo[[Xh2o`0000;oiK6N00?o0000on>^W_oS[Yh00_l00005om^`
[006o`000?oJ[Z_o0000o`000?oF/[Go00001OoE/;@00ol0003odjjco`000002o`000003ol^`_ol0
003obk2o00Gobk2o00?o0000ol^___o;[kh00_o;[kh01?l0003oak74o`000?l00005ol:cc0Oo`k78
0_l00007okf]bP?o00000onl/Ll01?l0003o];SKo`000?l00007okR^c`03o`000?oYPc?ojH<c00?o
00000_oAJDL3o`0000CoaEa60ol00002ol5HA@03o`000?niF5Go^EQE00?o^EQE4?l00002oiHfC@03
o`000?mh63ooN1Po00GoN1Po1?l00003oeP7B0;o000000KoE@Q<o`000?l0003o:P12o`000?lD04@5
o`0000;oI9;Y00Ko0000oi6ekonA]Noo0000ok71i_l00004ok;2iP04o`000?nb`nKo//?Vok;3iP;o
00000_nca>H00ol0003o_LWTokg9i002okg9i0;o00001onmbnD01?l0003o_/gVokk=i_l00003ol7>
i003o`000?o5d>?oa]?T00Coa]?T0_l00004olGDi@03o`000?o7e>Co000000Coc=[T00?o0000ol_L
i_o;g>H01?o;g>H01?l0003od>;Tom3Ri?o@h^@2o`0000?odN?U0_l00003omK[h`04o`000?oDk>Go
0000o`0000?ofOGQ00?o0000omcig?oLnM`00_l000000ooLol_o0000o`000002o`0001?ooo]Z00?o
0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0boookJP00<_oonfX00ol0003ooo]ZoookJP0_
oookJP03o`000?oonf[ooo]Z00[ooo]Z00Co0000o`00?_l007Co00000_lW9iX01?m2@:Wo0000odm9
[?l00004oemJ]@03o`000?m`K;koL6bn00;oL6bn1ol00002ogmj``;o00001on8PlH:o`0000OoUXc7
00?o0000oibCb_nLTlX01onLTlX00ol0003oX9G9o`000002o`0000GoX9G90_l00009ojFKc003o`00
0?nYW/_oZIk;00OoZIk;00Co0000ojbOb_l0003o00002?n]X<X01Ol0003o[j;:ojnRb_n_X/[o0000
00Ko/:;:00Co0000ok>Tb_ncY<[o00002?ndYLX00ol0003o]ZO:o`000009okRXbP03o`000?njZl[o
^Z_:00Ko^Z_:00Go0000okb]bonl[L_o_:g;o`000003okf^b`;o00001Onn[l/2o`0000?o`K?<0ol0
00000oo3//Wo0000olFcb@03olFcb@03o`000?o6]<Wo000000KoakK:00?o0000olRhboo8^</00_l0
00000oo<^<Oo0000olfja`04olfja`07o`000?o?_LSockg8olnmb?l0003odkc4o`000004omBoa@06
o`000?oF`/Koe/;6o`000?oI`/;o00001?oLa<801Ol0003ogLO3o`000?oSakco000000?oi<Zm00Go
0000on_=]_o[cKKo0000ong@]P02o`0000;omM>[00Co0000oocDVol0003oolig0_l0000HoookJP03
o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX01OoonfX2o`0000;ol:Qi0_l00002on^^SP04
o`000?oYZhoo0000o`0000CohjjN0ol00002om^`[003o`000?oJ[Z_ofZj[00;ofZj[0_l00004omF`
]003o`000?oC[[?odjjc00?odjjc00?o0000ol^`_oo;/;l01?o;/;l00ol0003objnnol^__P04ol^_
_PCo00000_o2/l`00ol0003o`k78ol>ab005ol>ab004o`000?o2[LGo`Zg5o`0000Co_Jg:00?o0000
okfZa_nmZ/H00_nmZ/H3o`000003okbacol0003o^:k?00Ko^:k?1?l000000ooYPc?o0000omigA002
o`0000CodFU70_l000000oo5G4Ko0000o`000002ol=LBPCo00001_niF5D01Ol0003o[4]@oja;D?n/
Be3o000000SoUc=50ol00003ogPH?`Go00000_ml8DX00ol0003oF0M8o`000002o`0000;oE@Q<1?l0
00000olD04Co0000o`000004of2Ek0Oo00001Onb`^H01?l0003o//?Vok;3i_l00005ok?4iP04o`00
0?nmbNCo0000o`0000Oo_L_U0_l00004okk=iP04o`000?o1c^Co0000o`0000Coa]?T0_l00007olGD
i@;o00000oo<f^@00ol0003obmcVol_LiP03ol_LiP03o`000?o;g^Oo000000;od>;T00Co0000om3U
i_o@iNKo00000_oAhnD01Ol0003oe^_SomK[hooFjn?o000000;oe>cU00Wo0000omWehOoImN7ofOGQ
omOfh_l0003og?WLo`000?oHoMT00ol000000oo>o;Oo0000o`00000CoookJP03o`000?oonf[ooo]Z
03?ooo]Z00?o0000oookJ_oonfX0<_oonfX003;ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003o
oo]ZoookJP09oookJP03o`00>?l0003o000000;o9bNJ00Go0000od90ZOm2@:WoCdV/o`000004oemJ
]@03o`000?m`K;koL6bn00CoL6bn00?o0000ogeh`ommN<<00_mmN<<3o`0000SoR8?60_l00006oi6;
b@03o`000?nFS<OoUXc700?oUXc70_l000000onHT/co0000oibCbP09oibCbP03o`000?nPULWoX9G9
00;oX9G90ol000000onQV/go0000ojFKc005ojFKc0?o000000?oYIc<o`000?nYW//02?nYW//2o`00
00[o[J3:00Co0000ojnRb_l0003o00002?n`X/X2o`0000[o]:G:00?o0000okRXb_nhZ<X01_nhZ<X0
0ol0003o^:[;o`000006okZ[bP;o00001?nl[L/01?l0003o_Jk;okf^bol00006okj_b`03o`000?o0
/Lco000000Ko`K?<00?o0000olFcbOo5/lT01?o5/lT00ol0003oakK:olNfbP04olNfbP03o`000?o8
^<_o000000;ob;S;0_l00005olfja`03o`000?o?_LSockg800?ockg80_l00003omBoa@03o`000?oF
`/Koe/;600;oe/;600?o0000omc4`_oLa<800_oLa<801Ol0003ogLO3o`000?oMal?o000000Coi<Zm
00?o0000on_=]_l000000_o]d;H01?l0003omM>[ooGCZooedj/2o`000004ookHU_l0003o0000o`00
01Wooo]Z00?o0000oookJ_oonfX0LOoonfX00ol0003ooo]ZoookJP05oookJP06o`000?o`Veoo0000
oo2XNOl0003okZEk0_l00003onV[S`;o00000ooS[Yh2o`000004on2/Wol0003ofk2/o`0000CofZj[
00?o0000omV/Z_l000000_oE/;@00ol0003odjjcom>^/`04om>^/`?o00000oo;/;l00ol0003objnn
ol^__P04ol^__P04o`000?o;[Kcobjflol^]_0?o00001oo3/LP00ol0003o`Zg5ol:]a@02ol:]a@04
o`000?nm[L[o_Jg:o`0000So_J[61Ol00002okR^c`;o00000_nh[m001?l0003ojhPoo`000?l00002
omigA003o`000?oAJDOodFU700;odFU700Ko0000olaXD?l0003o0000oliYC_l00004ol=LBPKo0000
0_niF5D00ol0003o[4]@oja;D005oiLcAA?o00001?mE24`4o`0000;o50140ol00006of2Ek005o`00
0?nH^>koV;S^oiRhk_l000001Onb`^H00ol0003o/lCVok?4iP05ok?4iP;o00001onmbnD2o`0000Oo
_/gV00?o0000ol;@iOl000000oo6dn@00ol0003oaMCUolGDi@05olGDi@04o`000?o5enOoaMOWo`00
00;oc=[T1_o;g>H00ol0003obmkWol_Ni`03o`0000?od>GV0_l000001OoAiNGo0000omK[hooFjn?o
000000;oe>cU00So0000omWehOoImN7ofOGQomOfh_l0003og?WLo`0000;of?gI00?o0000om;ob?l0
00000_l0000DoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0<_oonfX003;ooo]Z
00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP08oookJP06o`00>?l0003o5AZDo`000?lW
9i[o00000_m2@:T2o`0000CoGeZe00?o0000og1/__m`K;h00om`K;h2o`0000KoOGS300?oPh78o`00
0?n7P<D01_n7P<D00ol0003oTH_9oi6;b@06oi6;b@05o`000?nFS<OoUXc7oiJ<aol000001?nHT/`0
0ol0003oW9?:oibCbP05o`0000;oW9?:00?o0000oj2EbOl000000_l00005oj6Jc@03o`000?nUVlco
YI_<00?o00001OnUW<`00ol0003oZIk;ojVNb`04ojVNb`;o000000?oZIk;o`000?n]X<X02On]X<X2
o`0000Go/:;:1On`Y/h00ol0003o/jS>ok>XcP04ok>XcQ;o00001?njZlX00ol0003o_:g;okb]b`04
okb]b`03o`000?nm[/_o000000Ko_Zo;00Go0000ol2ac?o0/Lco`;7<o`000004ol6cc004o`000?o2
]<go`[C=o`0000?oaK?90_l00005olNfbP04o`000?o8^<_ob;S;o`0000;ob;S;0_l00004olfja`03
o`000?o?_LSockg800Cockg80ol000000ooD_lGo0000omK2aP04omK2aP;o00000_oLa<801?l0003o
gLO3omg7`ooMal<2o`0000?oi<Zm00?o0000onK=_Ol000000oo]d;H01ol0003omM>[ooGCZol0003o
mmNZo`000?onf9H00ol0000JoookJP03o`000?oonf[ooo]Z06oooo]Z00?o0000oookJ_oonfX01_oo
nfX00ol0003ol9]Ooo2KG`02o`0000;okZEk0_l00002onV[S`03o`000?oWZHoo000000;ohjjN00Co
0000on6/WOl0003oh:bO0_l00003omZ^Z`07o`000?oI[:[ofJbZomV/Z_l0003oeK2do`000005om>^
/`07o`000?oB[;;o0000oln/]_l0003obk2oo`000006ol^__P03o`000?o;[Kcobjfl00?objfl0ol0
0005ol>ab003o`000?o2[LGo`Zg500?o`Zg500?o0000okf]b_l000001onmZ/H01?l0003o_jg8okn]
b?l00003okV/c0Co00000_nh[m000ol0003ojhPoon^8?`02o`0000;ogWM40ol000000ooAJDOo0000
o`000002olm]D`;o00001Oo3G4X00ol0003oZdiHoj]>F002oj]>F0[o00001_nVAE000ol0003oORI@
oghVD005oghVD0?o00001?mE24`2o`000003oeH<DOl0003o000000?o50141?l00006of2Ek006o`00
0?nH^>koV;S^oiRhk_l0003o//;V0_l000000onc`nGo0000ok?4iP04ok?4iP;o000000?o]LKWo`00
0?nmbnD01OnmbnD00ol0003o_/gVokk=iP05okk=iP05o`000?nncnOo0000ol;@iOl000000_o6dn@0
0ol0003oaMCUolGDi@04olGDi@;o00000oo5enL2o`0000GobmcV0_l00002ol_Ni`;o00001?o@iNH0
0ol0003ocnOXoloWj002o`000004omK[hol0003oe>cUomC/i@;o00000_oImN42omOfhP;o00000_oH
oMT00ol0003od_o8o`000002o`0001Gooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]Zoook
JP0aoookJP00<_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z00Sooo]Z00Ko000h
o`00L?lE6YCo0000obLWV_l00002od90Z@;oFEVg0_l000000omOF[Go0000o`000004og1/_P04o`00
0?mhML?oN7G3o`0000CoOGS300Co0000oh>1b?n3PLSo00001On7P<D2o`0000SoTH_900Co0000oiJ<
aol0003o00001_nHT/`2o`0000SoW9?:00?o0000oj6JcOnQV/d01onQV/d2o`0000SoYIc<00Co0000
ojVNbonYW/_oZIk;0ol00004ojVNb`03o`000?n]X<[o[J3:00Ko00000_n]Y<h00ol0003o/:K>ok2V
cP05ok2VcP;o000000?o/JO>o`000?ncZ<h01oncZ<h01?l0003o/jW>ok>Yc_l00005okN[cP03o`00
0?ng[<ko]jc>00?o]jc>0ol000000onjZl[o0000okb]b`07okb]b`03o`000?nn[l_o_Zo;00Co_Zo;
00?o0000ol2ac?o0/L`00oo0/L`01?l0003o`K?<ol6cc?l00004ol:dc@03o`000?o5/lWo000000;o
a[K:00Go0000olNfb_o7]/[oakK:o`000003olRhb`03o`000?o8^<_o000000;obK_<0_l000000oo=
^/Oo0000olnmb005olnmb003o`000?oA_lWodKo900;o00001OoF`/H01_l0003of<G7omS5aol0003o
g<C2o`0000?ogLO300Go0000omo:a?l0003oi<Zmo`000002onK=_@0;o`000?o]d;KokM2fo`000?o_
e;Ko0000ooGCZol0003ommNZo`000?onf9H01?l0000IoookJP03o`000?oonf[ooo]Z06oooo]Z00?o
0000oookJ_oonfX01ooonfX01?l0003ol9]Ooo2KGol00002onjUN`05o`000?o/Xgco0000onV[Sol0
00000_oWZHl2o`0000;ohJbM00Go0000on2/Wol0003ogZVOo`000002omZ^Z`03o`000?oI[:[ofJbZ
00;ofJbZ0_l00004om>^/`06o`000?oB[;;odZbbom://_l0003ocjbf0_l00005ol^__P03o`000?o;
[Kcobjfl00Cobjfl00?o0000olFZ_oo5Z[l00ol000000oo3/LSo0000ol:]a@05ol:]a@;o00001_nm
Z/H2o`0000Co_jg800?o0000okV/c?l000001?njZLL4o`0000;ojhPo0_l000001?oNMdCo0000omIc
D_oFLe83o`0000CocfeC1Ol000000oo3G4[o0000oj]>F006oj]>F0;o00002_nVAE001?l0003oORI@
oghVD?mn9U04o`0000;oPReF00?o0000oeD8C?mE24`00_l00002oeH<D@;o00000olD04@5o`0000Ko
H9G/00?o0000oiRhk_nH^>h00ol00004ok?3i@05o`000?nca>Ko/lCVok?4i_l000001?nea^L01?l0
003o_L_Uokg;iOnmbnD2o`0000Go_/gV0_l00004okk?i`;o000000?oa]?TolGDiOo5e>D01?o5e>D2
o`0000GoaMOW00?o0000olWLiol000000oo;g>H00ol0003obmkWol_Ni`02ol_Ni`03o`000?o@iNKo
d>GV00;od>GV00Co0000oloWj?o?inSocnOX1?l000001OoDk>Go0000omC^iOl0003ofOGQ00?oeoKR
00?o0000omSmfOoHoMT01Ol0000FoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0
<OoonfX0037ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP07oookJP;o00000_lE
6Y@01Ol0003o@T2Yod90ZOl0003oCE6e00?oFEVg1?l00003og1/_P04o`000?mhML?oN7G3o`0000?o
OGS300Go0000oh>1b?n3PLSoPh78o`000004ohN0a@04o`000?n<R<[oS8S:o`0000SoTH_900?o0000
oiRBc?nHT/`00_nHT/`2o`0000;oUi7;00?o0000oibCb_nLTlX01OnLTlX00ol0003oWIS>o`000005
oj6Jc@?o000000?oXI[=o`000?nUW<`02?nUW<`01?l0003oZIk;o`000?l00007ojVNb`?o00000_n]
Xlh2o`0000Go[JC>00?o0000ok2Vc_n`Y/h00_n`Y/h2o`0000Co/JO>00?o0000ok>Xc_ncZ<h00onc
Z<h2o`0000Co/jW>00?o0000okN[c_ngZlh00_l00007okN/cP?o00001onl[L/00ol0003o_Jo<o`00
0005okj_b`03o`000?o0/Lco`;7<00Co`;7<00?o0000ol6cc?l000001Oo2]<d2o`0000?oa[K:00Co
0000olNfb_o7]/[o00001?o8^</2o`0000?obK_<00Co0000ol^kc?l0003o00001Oo?_LP00ol0003o
dKo9om6ob@02om6ob@03o`000?oF`/Koe/;600;oe/;600?o0000omS5aooHaLL00_oHaLL02Ol0003o
gLO3omg7`ooMal?o0000omo:a?l0003ogl[4o`000002onK=_@05o`000?oXd;ko0000ong@]_l00000
0_o_e;H01Ol0003ommNZooOGZ_l0003oo]RF00Co00006_oonfX00ol0003ooo]ZoookJP1^oookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oo2KGoo`Vel00_l000001?o^YG_o0000onbSO?o/Xg`2o`00
00?oijV?0_l000000ooQ[9go0000o`000003omjYW`03o`000?oJ[Z_o000000CofJbZ00?o0000omNZ
ZOl000000_l000000ooC[[?o0000om://P02om://P04o`000?o?[;Ko0000olj[]P?o000000?objnn
o`000?o;[K`01Oo;[K`00ol0003obJ^ko`000004olFZ_`;o00001Oo2[LD00ol0003o`jc2o`000005
okfZaP03o`000?no[LSo_jg800Go_jg800?o0000okZYaonjZLL01_njZLL2o`000003on^8?ol0003o
hH5C00Co00000_oLOET3o`0000;ocfeC00?o0000ol=XH_o3J6800_o3J686o`0000;oZdiH00Co0000
ojA6EOnTAUGo00002?nVAE000ol0003oORI@o`000002o`0000KoPReF00?o0000oeD8C?l000001?mF
35401?l0003o5014oa@0A?lD04@?o`0000;oWkc]00?o0000ok?3iOnc`nD00_nc`nD01?l0003o/lCV
o`000?l00006okG6i`03o`000?nmbnGo000000Ko_/gV00?o0000okk?ionncnL01OnncnL00ol0003o
aMCUolGDi@04olGDi@03o`000?o5enOoaMOW00CoaMOW00OoaMWXo`000?o9g>OobMcWo`000?o;g>Ko
000000?obmkW00?o0000ol[Pj?l000000_o@iNH2o`0000?ocnOX0_l00002omC^i@Co000000GofOGQ
omOfh_oGm^;oeoKRo`000002omSmf@Ko00005_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oo
nf[ooo]Z037ooo]Z000aoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX01OoonfX0
0oo9^33o0000o`000002oaDJU005ocLlZol0003o@T2Yo`000?m=DKD00omIFKL3ofIX`@;o000000?o
L6bno`000?mhML<00_mhML<01?l0003oOGS3ogeh`ol00004oh>1b005o`000?n7P<GoQh35ohN0aOl0
00000on<R<X00ol0003oTH_9oi6;b@05oi6;b@Co00001onGTL/00ol0003oW9?:oibCbP02oibCbP;o
00000onMV<h00ol0003oXI[=o`000002o`0000GoXI[=00?o0000ojFLc?nUW<`01_nUW<`2o`0000Co
ZIk;0ol00003ojVRc`04o`000?n]Xlko0000o`0000Oo[JC>00Go0000ok2Vc_n`Y/ko/:K>o`000007
ok6WcP03o`000?ncZ<ko/jS>00;o00001_ncZLh00ol0003o]j_>o`000008okN/cP;o00001_nj[lh7
o`0000?o_Zo;00?o0000ol2ac?o0/L`01_o0/L`00ol0003o`[C=ol:dc@03ol:dc@04o`000?o3]/go
`kK=ol>fc@;oa[K:00?o0000olNfb_l000001Oo8^</00ol0003obK_<olVkc003olVkc004o`000?o<
_Lgoc;g=o`0000?ockg800?o0000om6obOoA_lT00_oA_lT01_l0003odL;;o`000?l0003oe/;6o`00
00Cof<G70_l00002omg7``04o`000?oOb/Cogl[4omo:a0;o00000_oVcKd01?l0003oj=2nonS@__l0
0003onoD]P06o`000?ogej[o0000ooWJZOl0003oo]^C0ol0000JoookJP03o`000?oonf[ooo]Z06ko
oo]Z00?o0000oookJ_oonfX01ooonfX2o`000003oo2KGol0003okYUR00;o00000oo/Xg`02Ol0003o
ijV?onNYSooWZHoo0000onBVT?l0003ohJbMo`000004omjYW`;o00000ooI[:X00ol0003oejZYomNZ
Z@03omNZZ@;o00001?oB[;800ol0003ocZ^folj[]P03olj[]P;o00001Oo;[K`01Ol0003obJ^kolV[
^oo9Zk_o000000;oaJZo00?o0000olFZ__o5Z[h00ol000000oo2[LGo0000ol>/`P02ol>/`P03o`00
0?nmZ/Ko_J[600;o00001ono[LP2o`0000Oo^ZW70_l000000oo^TeCo0000o`000003on61D`05o`00
0?oLOEWog7eIomamFOl000000_o@N6H4o`0000Go`fQR00Co0000okIKH?nfFf3o]U]P4?l00008oh8]
EP?o00001?mF3542o`0000;o501400Ko0000ob80E?l0003o001;o`000?l007H2o`0000KoOZ7Y00?o
0000oinlkOnO_>d00_nO_>d01?l0003o/l?Uok?3iOnc`nD2o`0000So]LKW0_l00005okk=iP;o0000
1_nncnL01?l0003o_m7Xo`000?l00003olGDi@;o00001?o5enL2o`0000;oaMWX00?o0000olWLioo9
g>L00_l00003ol_Ni`06o`000?o:h>Sob^3Xo`000?o@iNKo00001?o?inP01Oo>jNWo0000omC^iOoD
k^Go000000?odO7W00Co0000omOfh_oGm^;oeoKR0_l000000ooHoMWo0000o`000005o`0001Kooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0aoookJP00<OoonfX00ol0003ooo]Zoook
JP0eoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00002oaDJU0;o=cb[0_l000001?m=DKGoFEVgoeUI
]ol00003ofIX`@03o`000?m/JKko000000?o00000_mhML<2o`0000KoPh7800?o0000ohN0aOl00000
1?n<R<X01?l0003oTH_9oi6;bOnARlT5o`000003oiBAc_l0003oUi7;00OoUi7;00?o0000oibCb_nL
TlX00_l00005oifHcP;o00002?nQV/d00ol0003oYIc<ojFLc004ojFLc0;o00000_nUW<`2o`0000Wo
ZJ;?00?o0000ojfTc_n]Y<h01on]Y<h01?l0003o/:K>o`000?l00008ok6WcP03o`000?ncZ<ko0000
00So/jW>0_l00007okN/cP;o000000?o^:g>o`000?nj[lh01Onj[lh00ol0003o^k3?ok^`c`03ok^`
c`;o000000?o_Zo;o`000?o0/L`01_o0/L`00ol0003o`K?=o`000004ol:dc@03o`000?o3]/go`kK=
00Co`kK=0ol00004olRhb`;o00001?o9^l`2o`0000?oc;g=00?o0000olnmb?l000001?oA_lT01_l0
003odL;;om72bol0003od/;;o`0000Cof<G700Ko0000omW7b?oIalSo0000omg7`ol00003omo:a005
o`000?oQcLGo0000onK=_Ol000000_oXd;h01Ol0003okmBfonoD]_l0003olMRf00;o000000?onMZY
o`000?onfi<00ol0000KoookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX02?oonfX3
o`0000;okYUR00Co0000onbSO?o/Xgcok:=l0_l00002onNYS`03o`000?oTYY3oi:J@00;o00001?oN
ZIl00ol0003og:NNo`000002omV/ZP03o`000?oGZZWoejZY00?oejZY00?o0000omJXZOl000000ooB
[;800ol0003ocZ^folj[]P03olj[]P03o`000?o=Z;?o000000;o00000_o;[K`4olV[^`03o`000?o5
Z[oo000000KoaJZn0ol00002ol>/`P03o`000?nmZ/Ko000000So_jg800Co0000oknYa?noZLCo0000
1?njZLL2o`0000;o^j_91?l000001?oQPE?oj8iMo`000?l00002omamF@03o`000?o@N6Kod7QV00?o
d7QV0ol00004ol=XHP05o`000?nfFf3o]U]PokIKH?l000001OnUBET00ol0003oXD]Qoj5;H@04oj5;
H@03o`000?n2;EKoPReF00CoPReF1?l00004oeH<D@Co000000?o5014o`000?lR05@01?l00002o`00
MP;o00001OmnXNT00ol0003oWkc]oinlk@02oinlk@06o`000?nc`nGo0000o`000?neaNKo00001_ne
a^L2o`0000?o]lSW00Co0000okk=i_l0003o00001_nncnL02Ol0003o_m7XokoAj?nodNSo0000ol;D
j?l0003oaMCUo`000005olGGi`06o`000?o5fNSoaMWXolGIj?l0003obMcW0_l00002olWOj003o`00
0?o;g^Oo000000;ob^3X00?o0000om3Ui_o@iNH00oo?inP01_l0003oc^WYolkYjOl0003oe>kUo`00
00?odO7W00?o0000omKhh_oFn>800ol000000ooHoMWo0000omOmf@05o`0001Oooo]Z00?o0000oook
J_oonfX0=?oonfX00ol0003ooo]ZoookJP0aoookJP00<OoonfX00ol0003ooo]ZoookJP0foookJP03
o`000?oonf[ooo]Z00?ooo]Z00?o0000o`00K_l44Y<00_l00002ocLlZ`;oC5>i00Co0000odeA]OmI
FKOo00001?mVJ<400ol0003oMGK5ogEfa@02ogEfaAOo00001OnDTLh00ol0003oUi7;oiNAb`05oiNA
b`03o`000?nLTl[o000000GoWIS>00?o0000oifHc_l000002_nQV/d01?l0003oYIc<ojFLc?nUW<`2
o`0000?oYIc<00?oYZ3@o`000?nYX/l01_nYX/l2o`000003ojZScol0003o[JC>00So[JC>0_l0000:
ok6WcP;o00001oncZLh2o`000003okFZc_l0003o]jc>00Co]jc>0_l00004okR]cP04o`000?nj[lko
^Zo>okZ_cP;o00001_nk/<l3o`0000Oo`;7<00Go0000ol6ccOo1/lgo`K?=o`000002ol:dc@03o`00
0?o3]/go`kK=00Co`kK=00Co0000olFicol0003oa[W>0_l000001?o8^<_o0000olVkc?l00003olVk
c004o`000?o;_Lcobkg<o`0000;oc;g=0ol00003om6ob@03o`000?oA`/_odL;;00;odL;;0_l00003
omS5a`03o`000?oIalSofLO800;ofLO800Wo0000omo:a?oOb/Cogl[4o`000?oQcLCo0000on7=aOl0
00000_oXd;h01ol0003oj]Boo`000?o_e;Ko0000oo7H]_l000000_oifZT00ol0003oo]^Co`000002
o`0001cooo]Z00?o0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?o[R3_o
000000;okYUR0_l00002onbSO004o`000?oYXGko0000o`0000Coi:J@0_l00003omjYW`06o`000?oL
Yikog:NNo`000?oI[:[o00001?oGZZT02Ol0003oeZRYomJXZOoFZ:Wo0000om://_l0003odJZao`00
0004olj[]PGocJRc0_l00005olV[^`03o`000?o5Z[koaJZn00GoaJZn00?o0000olJX_?o6Z;`01?l0
0008okn]b003o`000?noZLCo_jW400;o_jW400Co0000okZYaonjZLOo00001?nkZlT00ol0003olYmS
oo:OH`02o`000003onR>GOl0003ogHMY00Co00001?o@N6H00ol0003o]EiVokENIP05o`0000;o]U]P
00?o0000ojE9FOnUBET01OnUBET00ol0003oXD]Qoj5;H@02oj5;H@03o`000?n2;EKoPReF00Go0000
0on8=5`00ol0003oEPaAo`000002o`000003oe/DF?l0003oHA]N00;o00000_lR05@4o`0000;o001f
0ol00005ogjQj@03o`000?nO_>goWkc]00?o00001?neaNH01?l0003o]LKWokG6ionea^L2o`0000Go
]lSW0_l00006okk?i`;o00000onodNP00ol0003o`]CXol;Dj002o`0000CoaMOW0_l00004olGIj0;o
00001?o9gnP2o`0000?ob^3X00?o0000om3Ui_o?inP00_o?inP01_l0003oc^WYolkYjOl0003oe>kU
o`0000?odO7W00Cod??Xo`000?oFn>;o00000_oAnn<4o`000004olSm`_l0003o0000o`0001Sooo]Z
00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0aoookJP00<OoonfX00ol0003ooo]Zoook
JP0goookJP03o`000?oonf[ooo]Z00;ooo]Z00Co000Jo`000?l44Y?o11:C0_l000001?lg?:_oC5>i
odaC^Om<DkT2o`0000GoIVS100?o0000ogEfaOmeM/D01?meM/D00ol0003oP7g7oh1ma`05oh1ma`03
o`000?n<RL_oS8W;00GoS8W;00?o0000oi2:bOl000001onDTLh00ol0003oUi7;oiNAb`05oiNAb`;o
000000CoWIS>o`000?l0003o00001OnMV<h00ol0003oXI[=oj6Jc@07oj6Jc@04o`000?nUW<co0000
o`0000;oYIc<1OnVX=001?l0003oZJ;?ojVRconYX/l3o`0000CoZZ??00?o0000ojfTc_n]Y<h01?n]
Y<h2o`000003ojfTc_l0003o/JO>00Oo/JO>0_l000000onaYlko0000ok>YcP04ok>YcP;o00001?ne
Z/h01Ol0003o]jc>okN/c_ng[<ko000000Oo^:g>00?o0000okZ_c_l000001onk/<l00ol0003o_;7?
o`000003okfcc`?o000000?o`;7<o`000?o1/ld00oo1/ld00ol0003o`[C=o`000006ol>fc@06o`00
0?o5^LooaKW?olFicol0003oa[W>0ol000001Oo9^lco0000olVkc?o9^lco000000?obkg<00?o0000
olbmcOl000000oo=_ld00ol0003odKo9o`000004om72b`;o000000CodlC<o`000?oHaLOo00001OoI
alP2o`000003omo:a?l0003ohLg400;ohLg40_l000000ooXd;ko0000on[D_`02on[D_`09o`000?oa
f;KolMRfo`000?oifZWo0000oo[NZ?l0003oo]f?00;o00007?oonfX00ol0003ooo]ZoookJP1/oook
JP03o`000?oonf[ooo]Z00Sooo]Z1?l000000oo^VF;o0000onbGI@02o`0000?ojJ5n0_l00003onBV
T0Go00001?oLYih2o`0000CoejZY00?o0000omJXZOoFZ:T00_oFZ:T2o`0000;odJZa00?o0000olj[
]_o>ZkH01_o=Z;<01?l0003ocJNbo`000?l00003olV[^`03o`000?o5Z[koaJZn00CoaJZn00?o0000
olJX_?o6Z;`01?o6Z;`3o`0000Go_jg800?o0000oknYa?noZL@00onoZL@00ol0003o^ZW7o`000005
ok^[b@05o`000?obWf?olYmSo`000?oYUV/00_l00004omf7J@?o00000oo@N6H00ol0003o]EiVokEN
IP03okENIQ?o00001on8=5`3o`0000?oFaAH00Co0000of4KG_l0003o00000_lR05@2o`000005o`d0
Fol0003o0000o`00M_l000000_lnDKd01?l0003oOZ7YogjQjOmnXNT5o`0000?oY[?R00Go0000okG5
i_neaNKo]LGVo`000002okG6i`03o`000?ngb>Oo]lSW00?o]lSW0_l00002ok_=j004o`000?nncnOo
_/oWokk?i`;o00001OnodNP3o`0000?o`]OY00?o0000olGGiol000001_o5fNP00ol0003obMoXolWO
j002olWOj007o`000?o9h^[obN;ZolWRj_l0003ob^3Xo`000003oloWj006o`000?o>jNWoc^WYolkY
jOl0003oe>kU0ooAlNL01?o@lnSo0000omKhh_l00002om7kh`;o000000?od_kLol[oeol000000ol0
000IoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0<OoonfX0037ooo]Z00?o0000
oookJ_oonfX0>?oonfX01?l0003ooo]ZoookJ_oonfX2o`0000;o11:C00?o0000obLaY_l000001?m<
DkT2o`0000?oIVS100?o0000ofe`aOl000001?meM/D00ol0003oOGg9o`000006oh1ma`03o`000?n<
RL_oS8W;00KoS8W;00?o0000oiBAc_nDTLh01_nDTLh00ol0003oUi7;oiNAb`04oiNAb`Co00002?nM
V<h00ol0003oXI[=oj6Jc@07oj6Jc@;o000000?oYIc<ojJPd?nVX=001_nVX=001?l0003oZJ;?o`00
0?l00007ojZSc`04o`000?n]Y<ko[JC>ojfTcP?o00001?n]Y<h00ol0003o/JO>ok6WcP02ok6WcP?o
00001?naYlh01Ol0003o/jW>ok>Yc_ncZLko000000Ko]J[>00Co0000okN/c_l0003o00002Onh[Lh0
0ol0003o^k3?ok^`c`04ok^`c`;o00000onl/Ll00ol0003o_K??okfcc`02okfcc`;o00001_o1/ld0
0ol0003o`kK=ol>fc@03ol>fc@;o00001Oo5^Ll01?l0003oak_?olNkcoo7^ll2o`000003olVkc?l0
003obkg<00Cobkg<00?o0000olfocOo=_ld00oo=_ld00ol0003odL;;om72b`02om72b`06o`000?oC
a<_odlC;o`000?oCa<co00001OoIalP01?l0003ofl[9om_:bOl00004on7=a004o`000?oRd<Ko0000
o`0000?oj]Bo00Co0000oo7H]_l0003olm^f0_l000000oojgZSo0000ookMS`02o`0001gooo]Z00?o
0000oookJ_oonfX0JooonfX00ol0003ooo]ZoookJP08oookJPKo00000_o/UfD2o`0000;ojJ5n00?o
0000onNNOol000000_oTYY02o`0000;ohJ>@0_l00003ombWWP03o`000?oJYIko000000;o000000?o
ejZYo`000?oFZ:T00ooFZ:T00ol0003oe:JXo`000002o`000003olj[]_l0003ocJRc00CocJRc00?o
0000olfW/_o=Yk800_o=Yk801Ol0003obJ^ko`000?o9Z;So000000CoaJZn00?o0000olJX_?o6Z;`0
1Oo6Z;`2o`000006ol6U__l0003o0000o`000?no[LSo00001_noZL@2o`0000Ko^j_90_l000001?ob
Wf?o0000onVFJooYUV/2o`0000?ogHMY00?o0000olijKoo>NVl01?l00006okENIP03o`000?ngGVCo
000000WoYdiN00Co0000oj=>I?nSCVCo00001on8=5`3o`0000CoFaAH0ol000001om/;6go0000ob80
E?l0003o=P]/o`000?l=05/00_l000000ol007Ko0000ociA_@02ociA_@?o00000_nFYN000ol0003o
Y[?RojJchP04ojJchP03o`000?neaNKo]LGV00;o00001Ongb>L2o`0000Go^lgX00?o0000okk?iol0
00001onodNP00ol0003o`]OYol;Gj@03ol;Gj@;o00001Oo5fNP00ol0003oaM_Zo`000003olWOj003
o`000?o9h^[obN;Z00;obN;Z0_l00003oloWj003o`000?o>jNWoc^WY00;oc^WY00Co0000om7aiooA
lNOodO7W0_o@lnP2o`0000?odO_S0_l000000oo:omOo0000o`000002o`0001_ooo]Z00?o0000oook
J_oonfX0<ooonfX00ol0003ooo]ZoookJP0aoookJP00<OoonfX00ol0003ooo]ZoookJP0ioookJP03
o`000?oonf[ooo]Z00?o000000Co11:Coah]Y_l0003o00001?m<DkT02?l0003oHFG0o`000?l0003o
IVS1o`000?m]L<Go00000omeM/D01?l0003oOGg9ogembOl00005oh1ma`03o`000?n6Q/co000000Oo
S8W;00?o0000oiBAc_nDTLh01onDTLh00ol0003oUi7;oiNAb`04o`0000;oVYO@00?o0000oifHc_nM
V<h01onMV<h00ol0003oXI[=oj6Jc@03oj6Jc@?o000000?oXikAo`000?nVX=002OnVX=000ol0003o
ZZ??ojZSc`07ojZSc`04o`000?n]Y<ko0000o`0000So[JC>00Co0000ok6Wc_l0003o00001onaYlh0
1?l0003o/jW>ok>Yc_l00008okFZcP03o`000?nh[Lko^:g>00Oo^:g>00?o0000okV_col000001Onk
/<l00ol0003o_;7?okbac`04okbac`04o`000?nm/loo0000o`0000Go_[C@1?l00004ol>fc@03o`00
0?o5^LooaKW?00CoaKW?0_l00004olNkc`;o00001Oo;_L`00ol0003ocKo=o`000003olfoc@;o0000
0ooA`//00ol0003odlC;om?4b`02om?4b`03o`000?oDalgo000000?ofLO800Go0000om_:bOoKb/Wo
fl[9o`000003on7=a004o`000?oRd<Go0000o`0000?oj]Bo00Ko0000on_H`?l0003o0000oo?K]_l0
0002oo[NZ0Co00007OoonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[ooo]Z00Wooo]Z0ol0
00002OoZQT3o0000o`000?o/UfGo0000onVEIol0003ojJ5no`000002onNNO`;o000000OohZB@o`00
0?oQXi3ohJ>@o`000?oOXI7o000000;og:NN00?o0000omZUW_oJYIh00_oJYIh2o`0000?oeZRY00?o
0000omBVZ?oDYZP00ooDYZP2o`0000GocJRc00?o0000olfW/_o=Yk800oo=Yk84o`0000?oaJZn00?o
0000olJX_?o6Z;`01Oo6Z;`01?l0003oaJJjolFV^_l00003ol6U_PCo00000onoZL@00ol0003o_jO1
o`000006ok^[b@04o`000?obZ7Ko0000o`0000?ojII[0_l00002omf7J@03o`000?o>NVoocWY_00?o
cWY_1_l00002okENIP03o`000?nWCUkoYdiN00WoYdiN0_l00003ohPdG0Go00000_n<?VL01?l0003o
FaAHoe/DF?mK55P2o`0000?oK2a]0_l00002ocH;K004o`000?l=05_o0000ob<HRP;o00000olnDKd0
1Ol0003oUZGPoiJUh?nFYN3o000000SoY[?R0_l000000onganOo0000okO8i`03okO8i`03o`000?nk
cNSo^lgX00Go^lgX0_l00005okoAj0;o000000?o_m?Yo`000?o2enT00oo2enT00ol0003o`m[Zo`00
0003olGIj0;o00000_o5fnX01?l0003obMoXo`000?l00004olWRjP06o`000?o8i>co0000o`000?o?
inSo00000oo>jNT01?l0003oc^_Yo`000?oAlNL4om3cj007o`000?oAnn?odO_Som7khoo?nnCo0000
ol[oe`04o`0001cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0`oookJP00<?oo
nfX00ol0003ooo]ZoookJP0koookJP04o`000?oonf[o0000o`03R`;o00000_lN;JH2o`0000;oC5>i
00?o0000oeaR`?l000000_mQIL04o`0000;oMGK500Go0000ogembOmmOLWoOGg9o`000004oh1ma`05
o`000?n6Q/coQXK<ohJ6c?l000001On<RL/00ol0003oSXk>o`000004oiBAcPSo00001_nJUm000ol0
003oWIS>oifHcP06oifHcP03o`000?nQV/goXI[=00?o00001OnSW]400ol0003oYZ3@ojJPd004ojJP
d0;o000000?oYZ7@o`000?nZXll02?nZXll2o`0000_o[JC>00?o0000ok6Wc_naYlh02?naYlh00ol0
003o]J[>okFZcP07okFZcP;o00001onh[Lh2o`0000?o^Jo?00?o0000ok^`conk/<l00_l00008okba
c`03o`000?nn]=3o_[C@00Co_[C@00Co0000oknfd?no]]3o_kK@0_l00002ol>fc@03o`000?o5^Loo
aKW?00CoaKW?00Co0000olJjcoo6^/oo00000_o7^ll2o`000003olRmd?l0003obkg<00;obkg<00Oo
0000olfocOo=_lgocKo=o`000?o=_lgo000000;oc/;>00?o0000om72bol000001OoCa</01_l0003o
e<O=omC7cOl0003ofLO8o`0000?ofl[900Go0000omc=b_l0003ohLg4o`000003on;@a@04o`000?oZ
e;ooj]Boo`0000;ojmS000Go0000oo?K]_ocfkKo0000oo[NZ005o`0001kooo]Z00?o0000oookJ_oo
nfX0JOoonfX00ol0003ooo]ZoookJP0:oookJPGo000000?oj8E3o`000?l000000_oYUFL2o`0000?o
iiio0ol00002on6ST003o`000?oOXI7ogj6A00;o00001OoJYIh00ol0003ofJ>No`000002omJXZ@03
o`000?oDYZSoe:JX00?oe:JX00Co0000om2TZol0003o00000_o=Z;<00ol0003ocJNbolfW/P04olfW
/P03o`000?o<YK7oc:Fa00;o000000?oaJZno`000?o6Z;`01_o6Z;`01Ol0003oaJJjolFV^_o5Y[[o
000000;o`JFn00?o0000ol6U_Oo1YKd00_o1YKd7o`0000Go^j_900?o0000oo:XM_obZ7H00_l00002
onVFJ`03o`000?oLS7Co000000?o00001Oo>NVl00ol0003o_Va`oki/L002oki/L0?o00003?nWCUh4
o`0000OoS3iW00?o0000oe/DF?mK55P00_l00003of`/K@;o00000_lf2f`01_l0003o3@1Ko`000?l0
003o8aR:o`0000Go?U6m00?o0000oiJUh?l000001onV/n83ojK2k@;o]lOW00?o0000okO8iongb>L0
0_l00006ok_=j0;o000000?o^]3[o`000?nodNP00onodNP01Ol0003o_m?YokoCjOnodnWo000000;o
`]OY0_l00003ol?JjP03o`000?o5fNSo000000?oaM_Z00?o0000olWOj?o9gnP01?o9h^X2o`0000;o
b>C/0ol000001oo>jNWo0000olkYjOl0003oc^_Yo`000?oAlNL01?o@lnP01_l0003odO_Som7khooA
nn?oco_To`0000;ob_oG0ol0000MoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0
<?oonfX0033ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003o001Ao`03R`02o`0000;o7RfV00Oo
0000odE?^?l0003oC5>io`000?mLH/3o000000;oHFG00om/LlP6o`0000;oOGg900Co0000oh1maon0
OLOo00001?n6Q/`00ol0003oS8W;ohb9b`02ohb9b`03o`000?n>S/ko000000Go00001?nBSld2o`00
00SoVYO@00?o0000oifHc_nMV<h01OnMV<h4o`0000SoXikA00Co0000ojJPd?nVX=3oYZ3@0ol00004
ojJQd003o`000?nZXlooZZ??00CoZZ??0_l000000onZXloo0000ojfTcP07ojfTcP;o000000?o[ZK?
o`000?naYlh00onaYlh01?l0003o/JO>ok6Wc_naYlh8o`0000?o]J[>00Co0000okJ/conf[<oo0000
1Onh[Lh00ol0003o^Jo?okV_c`03okV_c`03o`000?nk/<oo000000So_;7?00?o0000okfcd?l00000
1?nn]=02o`0000Ko_kK@0_l00006olFic`09o`000?o6^/ooa[[?olJjcol0003oak_?o`000?o8_M3o
000000;ob;g@00?o0000ol^mc?l000001?o=_ld2o`0000Coc/;>00?o0000om?4booCa</00ooCa</0
1?l0003oe<O<o`000?oDald2o`0000?ofl[900Go0000omc=b_oLcL[og<g:o`000004on;@a@;o0000
00Soj]Boo`000?o[f<3ojmS0o`000?ocfkKo0000ooCO]P?o000000?ooMn:o`000?l000007ooonfX0
0ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000ol530?l000000ol00000
0ooXQD?o0000o`000002onVEI`;o00000_oWWWl01Ol0003oi9aoo`000?oQXi3o000000Cogj6A0_l0
0003omZUWP07o`000?oIXikofJ>NomVSW_l0003oeZRYo`000005omBVZ007o`000?o@Y:_od:B[om2T
Zol0003ocJRco`000005olfW/P03o`000?o<YK7oc:Fa00;oc:Fa1?l00005olJX_003o`000?o5Y[[o
aJJj00;oaJJj00?o0000ol6U__l000001oo1YKd01?l0003o`J>kol6S^oo1Xk/3o`0000;o^j_900Ko
^jK4o`000?obZ7KolZQfo`000?oXWW`3o`0000Cog8ad0ol00003olijK`03o`000?nnK73o_Va`00Co
_Va`3_l00003oha0J`?o00000on<?VL01?l0003oFaAHo`000?l00004of`/K@;o00000olf2f`2o`00
00;o?BV?0_l00002ohem_@?o?U6m00?o0000oiJUh?l000000onV/n800ol0003oY/;]ojK2k@05ojK2
k@04okO7iol0003o]lSWo`0000Ko^lgX0_l00004ok[@j`04o`000?nodNSo0000o`0000?o_m?Y00Co
0000ol;GjOl0003o00001Oo3f^X2o`0000CoaM_Z00?o0000olWOj?o9h^X00_o9h^X2o`0000Cob>C/
00Co0000olc[joo<jn_oc>_[0ol000000oo>jnWo0000om3cj002om3cj007o`000?o?m>So0000om7k
hol0003oco_To`000002ol[oe`?o00007_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o
oo]Z033ooo]Z000`oookJP03o`000?oonf[ooo]Z03gooo]Z00Co001Ao`03Rol0003o00000_lN;JH0
0oloBkOo0000odE?^002o`000004oeaR`?l0003oHFG0o`0000CoK7?800?o0000ogYnbomjO//00_mj
O//Ao`0000;oSXo@00?o0000oi:?cOnBSld01?nBSld00ol0003oUIGAo`000008oiZGd003o`000?nM
V<koWIS>00Ko000000?oWigBo`000?nSW]402?nSW]401?l0003oYZ3@o`000?l00007ojJQd004o`00
0?nZXlooZZ??ojZSc`?o00001?nZXll01?l0003o[JC>ojfTc_n]Y<h2o`000003ojfTc_l0003o0000
00Oo000000?o/J[Ao`000?l000001?naZm800ol0003o]:gAokB]d@02okB]d@[o000000?o^:g>o`00
0?ni[ll01_ni[ll00ol0003o_;7?okbac`05okbac`;o00000onm/m001?l0003o_[C@okjdd?l00007
oknfd0?o00001Oo5^Ll00ol0003oa[[?olJjc`03olJjc`04o`000?o8_M3ob;g@o`0000?ob;g@0_l0
0003olfoc@03o`000?o>`Lko000000Coc/;>0_l00003om?4b`07o`000?oDalcoe<O<omC7c?l0003o
e/W=o`000003om_:b@05o`000?oLcL[og<g:omc=b_l000000ooRd<D01?l0003oi=?6onCCa_l00002
on_H`0;o000000Oolm^fo`000?odgkKo0000oo_RY_l0003ooMn:00;o00007ooonfX00ol0003ooo]Z
oookJP1XoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000ol530?l000000ol000002_oXQD?o0000
onVEIooYUFOo0000onNBJ?l0003oiiioo`000?oTW7l3o`0000Cogj6A00?o0000omfOTOl000000_oJ
YIh00ol0003ofJ>NomVSWP02omVSWP;o00001?oDYZP00ol0003odjBWo`000003om2TZ`;o00001?o=
Yk800ol0003oc:FaolbU/@03olbU/@04o`000?o7XkCoaj>dolNS]0?o000000?oaZRlo`000?o5Y[X0
1Oo5Y[X00ol0003o`JFmol6U_@05ol6U_@03o`000?o1Xk_o`J>k00?o`J>k1_l00002oo:XMP04o`00
0?oXWWcoj9ilonRNO0;o00000ooLS7@00ol0003oc7iholanN003o`000003olijKol0003o_Va`00Co
_Va`0_l0000;oj]MLP03o`000?n<@6_oS41[00;oS41[2?l00003of`/K@;o000000?oLSYlo`000?lf
2f`00_lf2f`01Ol0003o?BV?ocdYSolm:Hoo000000KoSGfm00Co?U6mo`000?nV/n;o00002onV`^d0
0ol0003o^lgXok_=j005ok_=j003o`000?njd>_o^]3[00Go^]3[00?o0000okoCjOnodnT00onodnT0
0ol0003o`]OYol?JjP04ol?JjP;o00000oo3f^/01?l0003oaM_ZolGKj_l00003olWRjP03o`000?o8
i>cob>C/00?ob>C/00Go0000olc[joo<jn_oc>_[o`000003ol[]k@08o`000?o@lnSo0000om3cj?l0
003ocoCXo`000?oAnn<2oloki004o`000?o:omOob_oGolWoeP;o00007ooonfX00ol0003ooo]Zoook
JP0doookJP03o`000?oonf[ooo]Z033ooo]Z000`oookJP03o`000?oonf[ooo]Z03gooo]Z0ol00000
1_lJ;JOo0000o`000?loBkOo0000odE?^0;oEV;31?l00004ofacb003o`000?mjO/_oNWk;00GoNWk;
00?o0000ohF7c_n5Qlh01On5Qlh00ol0003oRXS<o`000006ohj?d003o`000?nBSlgoTXo=00;oTXo=
00Go0000oiFEdOnEUM7oUIGAo`000006oiZGd0Co00000onMV<l2o`0000?oWigB00?o0000oj>NdOnS
W]401onSW]400ol0003oYZ7@ojJQd007ojJQd004o`000?nZXloo0000o`0000SoZZ??1Ol00005ojjX
dP03o`000?naZ]7o/J[A00;o/J[A00?o0000ok6[d_naZm801?naZm801?l0003o]:gAokB]dOnd[M42
o`0000Ko]:kB00Co0000okN_dOl0003o00001oni[ll2o`0000Go_;7?0_l00005okfcd003o`000?nn
]=3o000000Oo_kK@00Co0000ol6hdOl0003o`[WA0ol000000oo5^Loo0000olJjc`04olJjc`;o0000
0_o8_M001?l0003ob;g@olRmd?l00002olVod@03o`000?o=_lgo000000?oc/7>00Co0000olk2c_o>
`/ko00000_o?a<l00ol0003odlC;o`000003omC7c0;o00000_oFbLd00ol0003ofl[9o`000003omc=
bP05o`000?oMcl_o0000on;@aOl000000ooTdlH00ol0003ojmS0o`000002ongK`@;o000000?om=nf
o`000?okhZH01?l0000PoookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oookJ_oonfX03?oonfX0
0ol0003o`D<0o`000005o`000004onVEIol0003oii9XonNBJ0;o000000?oi9aoonBKOooTVgl00_l0
0003omnQT@06o`000?oMWi7ogInAo`000?oJYIko00001?oIXih00ol0003oej6No`000002o`000004
omBVZ?l0003odjBWo`0000?od:B[00?o0000olnRZOl000000_l000000oo=Yk;o0000olbU/@04olbU
/@03o`000?o7XkCoaj>d00Coaj>d1?l00003olFV^P;o00001_o1YKd00ol0003o`J>kol6S^`04ol6S
^`03o`000?nmX[ko_J:n00;o_J:n0_l000000oobZ7Ko0000onRNO003onRNO0;o00000_oLS7@00ol0
003oc7iholanN003olanN0Go000000Go_Va`o`000?ncH6co/f1/o`000009oj]MLP03o`000?n<@6_o
000000?o00001?n?B7@3o`0000;oK2a]0_l00003og8jO003o`000?lf2fco=P]/00;o00000olm:Hl0
0ol0003oSGfmohem_@05ohem_@;o00002?nV`^d3o`000003ok31i_l0003o000000Co^lgX0_l00006
ok[@j`04o`000?nkd^co^m;/o`0000Co_m?Y00?o0000ol?Jj_o3f^X00oo3f^X00ol0003o`m[[ol?J
j`04ol?Jj`03o`000?o5gN_o000000;obN;Z00?o0000olSTk?o8i>`00_o8i>`01?l0003oanG]o`00
0?o<jn/2o`0000?ob^g]00?o0000olkdjOo>m>T00_l000000oo?m>So0000o`000002oloki004o`00
0?o:omOob_oGolWoeP;o00008?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033o
oo]Z000`oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000o`00P?l000000_lJ;JL01?l0003o?d^g
o`000?m5CkP4oeIR``03o`000?m/LlSoK7?800?oK7?800?o0000ogYnbomjO//01OmjO//00ol0003o
QHO>ohF7cP06ohF7cP03o`000?n>Sm3oSXo@00GoSXo@00Go0000oi:?cOnBSlgoTXo=o`000004oiFE
d@03o`000?nJUm3oVYO@00Co00000_nIU/l00ol0003oWIS?oifHc`02o`0000GoWigB00?o0000oj>N
dOnSW]401Ol00002oj:Nd@03o`000?nVXM3oYZ7@00OoYZ7@0_l00005ojZSc`?o00000_nZY]800ol0
003o[JSBo`000008ojjXdP04o`000?naZ]7o0000o`0000So/J_B0ol00008okB^dP;o00001_ng/=86
o`0000?o_;7?00?o0000okfcd?nm/m001_nm/m000ol0003o_kK@oknfd004oknfd0;o00000oo1^=40
0ol0003o`[WAol:id@02o`0000Goa[[?00So0000olNld?o7_=3o0000olRmd?l0003ob;g@o`0000Co
bKoA00?o0000olk1c_o>`Lh00_o>`Lh00ol0003oc/;>o`000004olo4c`05o`000?oDalcoe<O<omC7
c?l000000_oFbLd01?l0003oe/W=o`000?l00003omc=bP05o`000?oMcl_ogLo;omg?bol000000ooT
dlH00ol0003oi=K8o`000003ongK`@06o`000?odgkKo0000ooKT]_l0003oo>FT0ol0000QoookJP03
o`000?oonf[ooo]Z06Kooo]Z00?o0000oookJ_oonfX03OoonfX3o`000003omi/6_l0003o000000;o
000000?ojIEWo`000?oWTVP00ol00002onBKO`03o`000?oQVH3o000000;o00001?oMWi42o`0000Co
fJ>N00?o0000omNQW_oGXIh00_oGXIh2o`000003om>TYol0003od:B[00;od:B[1Oo?XZT2o`0000Co
c:Fa00?o0000ol^S/?l000001Oo7Xk@01?l0003oaj6bolNQ/_o7XK84o`000003olFS^?l0003o`JFm
00?o`JFm00?o0000ol6S^oo1Xk/01Oo1Xk/01Ol0003o_J:nokfR__nmX[ko000000;okk:=0_l00004
onRNO003o`000?oJTX;o000000?o00001Oo<OWP01?l0003o_g5hokmaN?noLGP@o`0000WoSdQd00Co
0000of`/KOm/;6go00001Omb>W`00ol0003o=P]/o`000002oe<dSP04o`000?lm:Hoo?BV?o`0000Oo
SGfm00?o0000oiZcjOl000001?nV`^d3o`0000?o/<7V00Co0000ok;:k?nbb^co00000_nkcNP00ol0
003o^]3[ok[@j`04ok[@j`03o`000?nkd^co^m;/00?o^m;/00Go0000okoCjOl0003o_mK[o`000003
ol?JjP;o00001Oo3f^/01?l0003o`]k]ol;NkOl00002olWRjPCob>C/0_l000001?o7iNgo0000olc[
jol00004ol[]k@04olS^kOl0003oc_CYo`0000;obOO[0_l00002oloki0?o000000?obOoFo`000?l0
00008OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z033ooo]Z000`oookJP03o`00
0?oonf[ooo]Z03gooo]Z00Wo001;o`00P?l0003o0000oaX]Yol`@kKo0000ocm;]ol000001?mFH/<4
o`000004ofacb?l0003oLg[;o`0000GoNWk;00?o0000ogn4c_l000001_n5Qlh2o`0000OoSXo@00Co
0000oi:?cOnBSlgo00000_nEUM46o`0000OoVIK?0_l00008oinMdP;o00002?nRW]400ol0003oYZ7@
ojJQd003ojJQd0?o00000_nVXM03o`0000SoZZKB00?o0000ojjXd_n^Z=801on^Z=82o`0000Wo/J_B
0_l00008okB^dP;o000000?o][3Co`000?ng/=801?ng/=82o`0000Co^;7C1?l00007okfcd003o`00
0?nn]M7o000000Go_kK@00?o0000ol6hdOo1^=400oo1^=400ol0003o`[WAo`000003ol>kdP;o0000
00?oa[[?o`000?o7_=000oo7_=03o`0000CobKoA00?o0000ol[1dOl000000oo>`Lh2o`0000CoclC?
00Go0000om36d?l0003oe<O<o`000004omK9c@03o`000?oGc<oo000000?og<g:00?o0000omg?booM
cl/00_l00002onCCaP03o`000?oTe/Soi=K800;o000000SokM_1o`000?l0003om=nfo`000?ofi;Ko
0000oocUY0?o00008OoonfX00ol0003ooo]ZoookJP1VoookJP03o`000?oonf[ooo]Z00gooo]Z1?l0
00001?oNK1[o0000onJ1@ooVPD<3o`000006onNCJOl0003oi8mXo`000?oTVgoo00000ooQVH02o`00
00?ogInA00?o0000om^MTOl000000ol00005omNQWP03o`000?oEWigo000000;o000000?od:B[olnR
ZOo?XZT01?o?XZT00ol0003ocZ2Xo`000002o`000005olbU/Ol0003obj>`ol^S/?l000000oo7Xk@0
0ol0003oaj6bolNQ/P04olNQ/P04o`000?o6Wk7o0000o`0000?o`JFm00?o0000ol6S^oo1Xk/01Oo1
Xk/00ol0003o`J2ho`000002okfR_P04o`000?o_/Xgokk:=onnbS@;o00000ooXWW`00ol0003ofY:2
omZBPP02omZBPP?o00000oo<OWP00ol0003o_g5hokmaN002okmaN005o`000?neIgGo]FMeokEWMOl0
00002?n]HgT00ol0003oSdQdohm8M008ohm8M0?o00001_mb>W`2o`0000?oDcB>00Co0000ocdYSol0
003o00001on=OKd01?l0003oV[?Yo`000?nV`^d3o`0000Ko/<7V00?o0000ok;:k?nbb^`00_l00006
ok[@j`;o00001onkd^`01?l0003o_mK[okoFjol00002ol?JjP03o`000?o3f^_o`m[[00;o`m[[0_l0
0004ol;Nk@;o00001?o8i>`01_l0003oanG]olOUkOl0003oc>_[o`0000?ob^g]00?o0000olS^kOl0
00000_l00003olWgj`03o`000?o;oN?o000000Ko00008_oonfX00ol0003ooo]ZoookJP0doookJP03
o`000?oonf[ooo]Z033ooo]Z000_oookJP03o`000?oonf[ooo]Z03kooo]Z0_l000000ol68:7o0000
oaX]Y`02oc13]P;o00000omFH/<2o`0000?oIVg61?l00004ogYnb`04o`000?moQ<koOhC>o`0000Go
QHO>00Co0000ohV<d?n9S=3o00001on>Sm05o`0000CoUIKB00?o0000oiVFconIU/l01OnIU/l2o`00
00GoWigB0ol000000onNWM;o0000oj:Nd@09oj:Nd@03o`000?nVXM3o000000;o00000onVXM000ol0
003oYjGCo`000006ojZVdP?o000000?oZjOCo`000?n^Z=801_n^Z=82o`000003ojjZdol0003o/J_B
00Ko/J_B0_l000000onb[M?o0000okB^dP05okB^dP;o00001?nf/=<01Ol0003o]k3BokN`d_ng/=;o
000000Oo^;7C0_l00003ok^dd`?o000000?o_K?@o`000?nn]M400_nn]M400ol0003o_kK@oknfd002
o`0000Oo`KSA00?o0000ol>kd_o3^m800oo3^m82o`0000Koakc@00?o0000olVodOo9_m400_o9_m40
2Ol0003ob/7Aol[1dOo:`M7o0000olk1c_l0003oclC?o`000003olo4c`05o`000?o@a]3od<K@om36
d?l000001OoFbLd01_l0003oelc?omO<col0003og<g:o`0000;ogLo;00?o0000omoBc?oOd/`00_l0
0003onCFb003o`000?o]g<3o000000;ok]o20_l000000oofi;Ko0000o`000003o`0002;ooo]Z00?o
0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0>oookJP;o000000?oaTL0o`000?l000000_l0
00000ooVPD?o0000onB2B`02o`0000;oi8mX0_l00003on6IP006o`000?oOUh7o0000o`000?oMWi7o
00001?oKWI42o`0000?oej6N00?o0000omFOWOoEWid00_oEWid3o`0000Cocj:Y00?o0000oljPZ?o>
X:P00oo>X:P5o`0000;oaj>d00?o0000olNQ/_o7XK801?o7XK800ol0003oaYnaolJO/@02olJO/@Go
00001Oo1Xk/01Ol0003o`J2hol6P^?l0003o_J:n00;o00000oo_/Xd00ol0003oiJRAo`000003o`00
00CofY:200?o0000olZ4QOo:Q8D00ol000000oo<OWSo0000okmaN002okmaN005o`000?neIgGo]FMe
okEWMOl000002?n]HgT00ol0003oSdQdohm8M005ohm8M0Co00001omb>W`2o`0000GoDcB>1?l00006
ohem_@;oV[?Y0_l00009ok31iP?o00000_nbb>/01?l0003o^]3[ok[@jonjd>/2o`0000Oo^m;/00?o
0000ok_DkOnke>d00_l00002ol?JjPGo`m[[00?o0000ol;NkOo2g^d00oo2g^d2o`0000;oaNC]00?o
0000olSTk?l000000oo7iNd01?l0003ob^g]ol[]kOo:kNd2o`000003olS^kOl0003o000000CobOO[
00Gob?O[o`000?l0003oa?gSo`000002okWld@;o00008ooonfX00ol0003ooo]ZoookJP0doookJP03
o`000?oonf[ooo]Z033ooo]Z000_oookJP03o`000?oonf[ooo]Z03kooo]Z00Go000ho`000?l68:7o
1R2Qo`000003oc13]P;o00000_mFH/<00ol0003oI6k7o`000003ofI]aP?oLg[;6Ol00009oiFFdP03
o`000?nIU/ooVIK?00?oVIK?00Go0000oi^KdonKVm?o0000oinMdP03o`0000GoWYgB00?o0000oj:N
dOnRW]401onRW]42o`000004ojJQd?l0003o0000o`0000GoYjGC00?o0000ojZVd_nZY]800ol00005
oj^Wd`04o`000?n^Z=;o[ZSBojjXdP?o00001?n^Z]<01?l0003o/J_Bok6[d_naZm83o`0000Co/ZgC
00?o0000okB^d_nd[]800_nd[]800ol0003o][3CokJ`d`04okJ`d`04o`000?ng/=;o0000o`0000Oo
^;7C00?o0000okVde?l000001Onk]=<2o`0000Co_[GA00?o0000oknfd?l000001oo1^=401?l0003o
`[[Bol:jd_l00003ol>kdP06o`000?o4_=?oa;cColBldol0003oakc@0_l000000oo8_]7o0000o`00
0002olVod@03o`000?o:`M7ob/7A00;ob/7A0_l00003olo4c`03o`000?o?a<oo000000Cod<K@0_l0
0003omK9c@04o`000?oGc<oo0000omO<c`;o00000_oMcl/01Ol0003ogm;<omoBc?oOd/co000000?o
i=K800?o0000onOJb?l000000_l000000oo^gl;o0000ooKT]P06o`0002;ooo]Z00?o0000oookJ_oo
nfX0IOoonfX00ol0003ooo]ZoookJP0?oookJP?o000000?obDX0o`000?oMK2400_l00002onB2B`;o
00000_oTSfP2o`0000;ohIV000Co0000omnGPOoOUh7ogiN10_l00004om^MT@06o`000?oIVi7o0000
o`000?oGXIko00001?oEWid00ol0003odIbOom6LW`03o`000003olnRZOl0003ocZ2X00CocZ2X00Co
0000olfNYoo=WZOocIjW0ol00006olNQ/P03o`000?o6Wk7oaYna00?oaYna00?o0000ol>N/ol00000
0_o2WK<3o`0000;o`J>k00Go0000ol6P^?o1X;So`J2ho`000002olg0c`04o`000?o_/Xgokk:=o`00
00CoiJRA0_l00003omZBPP03o`000?o:Q8GobXB500?obXB51Ol00005okEWM@03o`000?n]HgWo[F=i
00Go[F=i00?o0000ohm8M?n?B7@01Ol00003oiEFP@03o`000?mb>WcoLSYl00?oLSYl0_l000000on5
EI;o0000oe<dSP03oe<dSP04o`000?n?M[;oSgJbohmf/PWo00000_nTZm`00ol0003o/<7Vok31iP05
ok31iP03o`000?nbb>_o//S[00Co//S[00?o0000ok[@jol000001Onkd^`3o`0000Go^mC]0_l00004
ol?Jj`;o00001_o2g^d01?l0003oaNC]olGTkOo5i>d2o`0000?oanG]00Go0000ol[]kOo:kNgob^g]
o`000003olS^k@03o`000?o9mn_obOO[00;obOO[00?ob?O[o`000?l000000_o4oN<2okWld@;o0000
9?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02oooo]Z000_oookJP03o`000?oo
nf[ooo]Z03kooo]Z00Go0000o`00Ool0003o1R2Qo`000003oc13]P05o`000?m@G/;o0000oeIR`ol0
00000_mTK/L00ol0003oIVg6o`000003og=jb`04o`000?mhOL_oN7g;o`0000CoOhK@00Go0000ohB7
c_n4QlkoQ8O>o`000003ohV>dP03o`000?n<SLooS8g?00CoS8g?0_l00009oiFFdP04o`000?nIU/oo
VIK?oiVFc`;o00000_nKVm<3o`0000WoWYgB00?o0000oj:NdOnRW]400onRW]43o`000003oj>OdOl0
003o000000WoYjGC0_l00008oj^Wd`04o`000?n^Z=;o0000o`0000Oo[Z[C00Co0000ok6[d_naZm;o
00002?nb[M<01?l0003o]:kBo`000?l00007okJ`d`;o00001onh/M<2o`0000?o^KCD00?o0000ok^d
donk]=<00_l00003okbfe0;o00000_nn]M400ol0003o`KSAol6hd@04ol6hd@;o00001?o2^]800ol0
003o`k_Bo`000005olBld`03o`000?o8_]7ob;kA00;ob;kA00?o0000olVodOl000001?o:`M401?l0
003obl?Bol_3d_l00003olo4c`03o`000?o@a]3od<K@00;od<K@00Ko0000om;8dOoBb=7o0000omK9
cOl00003omO<c`05o`000?oHcm3o0000omg?bol000001?oOd/`01?l0003oi=K8onCFb?l00002onOJ
b003o`000?o^gl7ok]o100;o000000Com^Bfo`000?l0003on^VQ0ol0000SoookJP03o`000?oonf[o
oo]Z06?ooo]Z00?o0000oookJ_oonfX04_oonfX2o`000003olU:0?l0003ogF`Q00;o00000_oTPT/2
o`000003onB?J?l0003ohXi/00?o00001?oOUh42o`0000?ofifA00Co0000omVKTOoIVi7ofI^A0_l0
0004omFOW@03o`000?oAW9oodIbO00?odIbO0_l00004oljPZ003o`000?o=WZOocIjW00?ocIjW0ol0
0005olNQ/P03o`000?o6Wk7oaYna00CoaYna00?o0000ol:M/oo2WK<01?o2WK<6o`0000CocL3?0ol0
0004onFXT@06o`000?oIW9Go0000o`000?oJTX;o00001_o:Q8D00ol0003o`7Z4ol1jQ00Ao`0000So
UEJ100?o0000og8jO?mb>W`00ol00003ohEETP05o`000?mC=8koDcB>oe<dS_l000001?n?M[800ol0
003oS97DohbAe004ohbAe003o`000?nTZmcoY:_L00;oY:_L00?o0000ok31i_n``NH00ol000000onc
anWo0000ok;8j`05ok;8j`;o00001?nkd^`2o`0000Ko^mC]00Ko0000ok_Gk_l0003o_]_^o`000?o3
f^/2o`0000Go`]k]0_l000001Oo1gnko0000olGTkOo5i>go000000;oaNO_0_l000001Oo7ingo0000
ol[]kOo:kNgo000000?ob>k]00Ko0000olWgjoo9mn_obOO[o`000?o8mn/2o`0000;oa?gS0_nio=42
o`0002Gooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0_oookJP00;ooonfX00ol0
003ooo]ZoookJP0noookJP06o`00;?l007oo0000o`HPXOl/@kSo00000_l`@kH2o`000003oe1N`_l0
003o000000?o000000?oIVg6o`000?mcN//00omcN//2o`0000KoOhK@00?o0000ohB7c_l000001On9
S]800ol0003oS8g?ohb=c`02ohb=c`04o`000?n@Tm?oT9?Co`0000SoUIKB00?o0000oiVFconIU/l0
1Ol00002oi^Le003o`000?nNWM;oWYgB00OoWYgB00?o0000oj:NdOnRW]400ol00002oj>Od@03o`00
0?nTXmGo000000OoYjGC0_l000000onWYMCo0000oj^Wd`08oj^Wd`;o00002On^Z]<2o`0000[o/ZgC
0_l00007okJ`d`;o000000?o][3Co`000?nh/M<01Onh/M<00ol0003o^KCDokVde003okVde003o`00
0?nk]=?o000000Oo_;KD0ol00005ol6hd@03o`000?o2^];o`[[B00Go`[[B00?o0000olBldoo4_=<0
0oo4_=<01?l0003oaKkDolFne?l00002olRnd@;o00001?o:`M400ol0003obl?Bol_3dP02ol_3dP04
o`000?o?a<oo0000o`0000?od<K@00?o0000om;8dOoBb=400_oBb=402Ol0003oelc?omO<cooGc<oo
0000omS?d?l0003of<o@o`000004omoBc004o`000?oPe/go0000o`0000?oim[800?o0000onkO`Oo^
gl400ol000000oofj;Oo0000o`000003o`0002Cooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003o
oo]ZoookJP0CoookJP03o`000?o9BP3obDX000Co000000?oi89;o`000?oRPDl00_l00003on:>K0;o
00000ooOUh400ol0003ogIF2o`000002o`0000CofI^A00Co0000omNITOl0003o00000_oEWid00ol0
003odIbOom6LW`03om6LW`03o`000?o@VYko000000;o000000?ocZ2Xo`000?o=WZL01?o=WZL00ol0
003ob9bYolRLZ@03o`000003olNQ/_l0003oaYna00GoaYna0_l00007ol:M/`04o`000?o2Vk3o`Y^`
o`0000GocL3?00Co0000onRmZOl0003o00000ooUZ9401?l0003ofIbEomVLUOoIW9D2o`0000KobXB5
00Co0000ol1jQ?o0NXCo00001OngLX<00ol0003o[fb4ojm/Q005ojm/Q003o`000?nEEX7oUEJ100So
UEJ10ol00007ohEETP03o`000?mC=8ko000000KoSgJb00?o0000ohbAe?n<TM@00_n<TM@00ol0003o
Y:_LojB[g004ojB[g0;o00001?ncanT00ol0003o//S[ok;8j`02ok;8j`;o00000_nfc^`01?l0003o
^m;/o`000?l00006ok_Dk@04o`000?nkenko^mO^o`0000;o_]_^0_l00005ol;Nk@;o00000_o1gnh0
1?l0003oaNC]o`000?l00002olGWk`03o`000?o3j?3o`nS`00;o000000?ob^g]o`000?o8k^d00_o8
k^d01?o8l>ko0000olWgjoo9mn/2olSgj`06o`000?o4oN?oa?gSolCmhol0003o^OcA0_l0000Voook
JP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0;ooonfX002oooo]Z00?o0000oookJ_oo
nfX0?_oonfX01?l002co0000o`000?l68:42oba3^0;o000000?oBe_1o`000?m@G/801?mOK//4o`00
00CoLg[;00?o0000ogn6d?moQ]001?moQ]000ol0003oQ8O>o`000006ohV>dP04o`000?n<SLooS8g?
o`0000CoT9?C00?o0000oiFFd_nEU]800_nEU]87o`0000OoVicD00?o0000oijMd_nNWM801_nNWM86
o`0000GoY:?E00Co0000ojNUdonWYM?oYjGC0ol00004ojNUe003o`000?n[Ym?oZjOC00CoZjOC0_l0
00000on[Ym?o0000ojjZd`06ojjZd`;o000000?o[j_Co`000?nb[M<01onb[M<2o`000003ok:]dol0
003o][3C00Co][3C0_l00004okJ`d`04o`000?nh/M?o^;7CokRad`;o00001_ni]=@2o`0000Oo_;KD
00Co0000okbge?nl]mCo_;OD0ol000000oo1^=7o0000ol:jdP05ol:jdP03o`000?o3_=?o000000Co
a;cC00?o0000olFne?o5_]@00_o5_]@01?l0003ob;kAo`000?l00003ol[1d@03o`000?o;`m;obl?B
00?obl?B0_l00002om36d003o`000?o@a]3o000000Cod/SA0_l00002omO<c`04o`000?oHcm3of<o@
omS?d0;o00000ooOd/`01?l0003oh=K=on3FcOl00003onOJb007o`000?oXgLWo0000o`000?o^hlCo
0000ooOX]006o`0002Cooo]Z00?o0000oookJ_oonfX0H_oonfX00ol0003ooo]ZoookJP0DoookJP?o
000000?obd`0o`000?oMK2L00ol000000ooRPDoo0000o`000002on:>K006o`000?oOS6ko0000o`00
0?oOUh7o00000ooMUH82o`0000?ofI^A00Co0000omNITOoGVI7oeiVA0_l000000ooCWIgo0000om6L
W`02om6LW`03o`000?o@VYkod9ZN00?od9ZN0_l00005olfNY`03o`000?o8W:Wob9bY00?ob9bY1?l0
0003olJO/@03o`000?o5WJoo000000Ko`Yfc00Co0000ol:K/?o2Vk3o00001_o=`<l2o`0000;og[N`
00?o0000onFXTOl000001OoIW9D3o`0000CobXB500Co0000ol1jQ?o0NXCo00001OngLX<00ol0003o
[fb4ojm/Q005ojm/Q003o`000?nEEX7oUEJ100KoUEJ10ol00009ohEETP;o00002?n?M[801?l0003o
S97DohbAe?l00005ojB[g004o`000?nU`^koYL;^o`0000?o/lOY00?o0000ok;8jonbb>/00ol00004
okK>k0;o00001_nke>d2o`0000?o^mO^00?o0000okkKk_l000000onog^l01?l0003o`]k]o`000?l0
0003ol7OkP?o00000_o5inl2o`0000?o`nS`0ol00002olS^k@03o`000?o8l>ko000000;obOO[0_o8
mn/01_l0003oa?gSolCmhoo4oN?o0000okWld@;o0000:?oonfX00ol0003ooo]ZoookJP0doookJP03
o`000?oonf[ooo]Z02oooo]Z000_oookJP03o`000?oonf[ooo]Z03oooo]Z00Co0000o`0CW?l0003o
00000_l/@kP4o`0000GoGfk;0om_Nlh2o`0000;oLg[;00?o0000ogn6d?moQ]001OmoQ]000ol0003o
RHkBohV>dP05ohV>dP03o`000?n<SLoo000000;oT9?C2?l00003oiBFdP;o00002OnKW=@00ol0003o
WYgBoijMdP03oijMdP?o000000?oWYkCo`000?l000002?nTXmD01?l0003oYjGCo`000?l00007ojNU
e004o`000?n[Ym?oZjOCoj^Wd`?o00001?n[Ym<00ol0003o[Z[CojjZd`02ojjZd`;o00001?n_Zm<0
0ol0003o/ZgCok:]d`02ok:]d`?o00001?nb[M<01Ol0003o][3CokJ`donf/=?o000000Oo][3C00?o
0000okRadol000001oni]=@00ol0003o^[GDo`000005okbfe0;o00001?nl]m@01?l0003o_kWDo`00
0?l00005ol:jdP;o00000oo3_=<01?l0003oa;cColBldol00005olFne0?o000000CobL7Bo`000?o:
`M7o00001Oo;`m801Ol0003oc<GColc5dol0003od<K@00;o00001?oBb=400ol0003odl_Bom?;dP02
o`0000Cof<o@00Go0000omWAdOl0003ogm;<o`000003on3Fc@04o`000?oWf/Soim[8o`0000;oj=g9
00Go0000onkSa?o^hlCo0000ooOX]006o`0002Gooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003o
oo]ZoookJP0EoookJP?o000000Cobd`0o`000?oMK2OogF`W0_l000001OoRPDoo0000o`000?oRSVco
000000?ogha^0_l00003omfEPP06o`000?oJTh?o0000o`000?oIVi7o00001?oGVI44o`0000;odIbO
00?o0000om2JW_o@VYh00oo@VYh00ol0003ocYRMo`000002o`000003olfNYol0003o000000Gob9bY
00Co0000olRJYoo8VZOob9ZW1Ol000000oo5WJoo0000ol:M/`03ol:M/`04o`000?o2Vk3o`Y^`o`00
00KocL3?00?o0000ol_0d?l000000ooN]k02o`0000GofIbE00?o0000olV?Uoo9SiL00ol000001Oo:
Q8Go0000ol1jQ?o0NXCo000000Ko]g:300?o0000ojm/Q?n_K8@01?n_K8@00ol0003oUEJ1oiEFP@02
oiEFP@Co00000_nKJIL00ol0003oQEFBohEETP06ohEETP;o00002On?M[800ol0003oS97Do`000003
ojB[g003o`000?nU`^koYL;^00CoYL;^00Ko0000ok?7jOncanWo0000ok;8jol00005okK>k0;o0000
0_ngdnl01?l0003o^mC]ok_DkOnke>d2o`0000Co^mO^0ol00004okoNk`;o00001Oo1gnh01Ol0003o
aNO_olGWkoo5inoo000000Co`nS`0_l00002olK`k`?o000000?ob?3^o`000?l000000_o8mn/01?l0
003oa?gSo`000?o4oN<4o`0002Wooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0_
oookJP00;_oonfX00ol0003ooo]ZoookJP10oookJP04o`00L?l0003o01>Lo`0000;o;4>h0_lnEL82
o`0000GoGfk;00?o0000ofmkc_m_Nlh00om_Nlh6o`0000?oOhK@00?o0000ohV>d_n9S]800_n9S]88
o`0000CoT9GD00?o0000oiBFd_nDU]800onDU]801?l0003oUi_FoiNKe_l00008oi^Le003o`000?nN
WM;oWYgB00?o00000_nNW]<00ol0003oX:;Fo`00000:ojBSe@03o`000?nWYMCoYjGD00OoYjGD00Co
0000oj^Wdol0003o00002?n[Ym<01?l0003o[Z[Co`000?l00007ojn[d`04o`000?nb[M?o0000o`00
00Oo/ZgC00Co0000okJ`dol0003o00002Onf/=<00ol0003o^KCDokVde004okVde0;o00000onj]M@0
0ol0003o_;KDokbfe002o`0000Ko_;OD0_l00003oknje@;o000000?o`[[Bo`000?o3_=<01?o3_=<0
0ol0003oa;cCo`000005olFne003o`000?o6`=Goa/3E00;o000000?obL7Bo`000?o;`m801?o;`m80
0ol0003oc<GColc5d`02olc5d`03o`000?oAb=7o000000?od/SA00Go0000om?;d_oCbm;odl_Bo`00
0004omS?d005o`000?oJd]7o0000omWAdOl000000ooPe/d01?l0003ohMW?o`000?l00003onSMb@08
o`000?o^hlCo0000oo3V`_l0003om^^ho`000?oikJ42o`0002Kooo]Z00?o0000oookJ_oonfX0HOoo
nfX00ol0003ooo]ZoookJP0FoookJP03o`000?l0BlCo000000;o000000?ogF`Wo`000?oLK2d00_l0
00001?oPP5?o0000o`000?l00003omn<KP;o00000_oMUH801?l0003ofY>3omZCPooJTh<2o`0000Co
eiVA00Oo0000omFGTOl0003odiFBo`000?oAW9oo000000God9ZN00?o0000oljHWOo>V9d00_o>V9d4
o`0000?ob9bY00?o0000olRJYoo8VZL01?o8VZL00ol0003oaiRWolNHY`04o`000005ol:M/ol0003o
`Y^`ol:K/?l000001_o=`<l01Ol0003obl3@ol_0d?o;`=3o000000?og[N`0_l00004omVLU@03o`00
0?o9SiOobHnG00?obHnG2Ol00002okMbP`03o`000?n_K8Co[fb400Co[fb400?o0000oiEFPOl00000
0_l00006oi]YU`03o`000?n5EI;oQEFB00CoQEFB0_l000000onAMk;o0000ohmf/P09ohmf/P04o`00
0?nTZmco0000o`0000WoYL;^0ol00005okK>k0;o00001Ongdnl00ol0003o^mC]o`000006ok_GkP03
o`000?nog^oo_mk_00;o_mk_0_l00002okkOl005o`000?o1gnko`Mo^ol7Ok_l000000oo5inl00ol0
003o`nS`ol?Xl002ol?Xl003o`000?o6l>ooa_3_00;o00000oo2lO02o`0000;ob?O[0ol000001?o4
oN?o0000o`000?l0000[oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0;ooonfX0
02kooo]Z00?o0000oookJ_oonfX0@?oonfX01?l0073o0000o`0CW?lK>K<2oba3^003o`000?lnEL;o
?UG200?o00000omOK//2o`0000CoKg_>0_mhPm401?l0003oNh?@og^3d?mkPm08o`0000CoQXcA00?o
0000oi2Ee?n@UM@01_n@UM@01Ol0003oU9KBoiBFd_nDU];o000000CoUi_F00?o0000oi^Le?nKW=@0
1?nKW=@01?l0003oVicDo`000?l00003oijNd`03o`000?nPX]KoX:;F00;oX:;F00?o0000ojBSeOnT
XmD00onTXmD3o`000003ojBTeOl0003oYjGD00SoYjGD0_l0000;oj^Wd`03o`000?n_Zm?o[j_C00So
[j_C00?o0000ok:]donb[M<02?nb[M<00ol0003o][3CokJ`d`06okJ`d`;o000000?o][;Do`000?ni
]=@01?ni]=@00ol0003o^[GDokZee003okZee003o`000?nl]]Co000000Oo_;OD00?o0000okjje_l0
00001Ono^]D00ol0003o`kcCol>ld`05ol>ld`03o`000?o5_]CoaKkD00;oaKkD0_l00003olK0e@Co
00001?o;`m800ol0003oc<GColc5d`02olc5d`;o00000_oAb=400ol0003od/SAo`000004om?;dP05
o`000?oHcm3of<o@omS?d?l000000ooJd]42o`0000;oh=K=00Co0000on7IcooQfLoo00000ooXgLT3
o`0000;ol>K200?o0000ooK[^?l000000ol0000WoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000
oookJ_oonfX05ooonfX2o`000004o`1;a?l0003o0000o`0000;og6`]0_l00002on20D`;o00000_oO
S6h00ol0003ogH]`o`000002o`0000CofY>30_l00003omNIT@03o`000?oEUi7o000000;odiFB0ol0
0003om2JWP03o`000?o>V9gocYRM00?ocYRM00?o0000olfGWOo=Uid00ol000000oo8W:Wo0000olRJ
Y`04olRJY`03o`000?o7V:OoaiRW00;oaiRW00?o0000olBFZ?o4UZP01?l00006olg0c`03o`000?o;
`=3obl3@00?obl3@00Go0000omjg/?oN]k3o0000omFf^P02o`000003omVLUOl0003obHnG00KobHnG
00Co0000ol28VOo0R9Wo00001?njPiP;o`0000WoVfVG00Co0000ohEET_n5EI;oQEFB0ol00003oi5g
/P03o`000?n?M[;oSgJb00;oSgJb1ol00008ojG2kP?o00000_n_a>T00ol0003o]/k/okK>k002okK>
k0;o00002?ngdnl00ol0003o^mO^ok_GkP04ok_GkP04o`000?nog^oo_mk_okoNk`;o00001Onngo03
o`0000?oaNO_00?o0000ol?Xl?o3j?000_o3j?001?o2jO3o0000olK`kol00004ol;al003o`000?o3
nN_o`oW[00Oo000000?oXOC8oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oo
nf[ooo]Z02oooo]Z000^oookJP03o`000?oonf[ooo]Z043ooo]Z0_l000001?l04ico0000oa/i/ol0
0003ociE`P08oeEYb_l0003oEVS9o`000?mOK/_o0000ofMfc_l00003ofmkcP05o`000?mhPm7oN8?A
ogR3dOl000001?mkPm000on3Rm?o0000ohJ<d@07ohJ<d@03o`000?n@UMCoT9GD00KoT9GD00Co0000
oiBFd_nDU];o00001OnGVmH00ol0003oVicDoi^Le004o`0000?oVY_D00Co0000oijNdol0003o0000
1OnPX]H00ol0003oY:?EojBSe@03o`0000GoY:CE00?o0000ojNUe?nWYM@00onWYM@3o`000003ojNV
eOl0003oZjOC00KoZjOC2_l00004ojn[da7o00000_nf/=<2o`0000Co][;D00?o0000okVde?ni]=@0
0_l00007okZee003o`000?nl]mCo_;OD00Co_;OD0_l00003okjjeP05o`000?no^]Go_k[EoknjeOl0
00000_o0_=H01ol0003o`kcCol>ldoo3_=?o0000olBne?l000000oo5_]@00ol0003oa/3EolK0e@03
olK0e@05o`000?o7`]Ko0000ol_3dol000000_o;`m800ol0003oc<GColc5d`02olc5d`05o`000?o=
b=GocLSEo`000?oAb=400_l00004om?;dP05o`000?oDc]Co0000omS?d?l000001?oJd]401?l0003o
f]CCo`000?l00003on7Ic`05o`000?oXgLWoj=g9o`000?oYhLX00_l00002oo3V`PKo00009_oonfX3
o`00067ooo]Z00?o0000oookJ_oonfX06OoonfX5o`0000;og6`]0_l000001_oPP5?o0000ominE_l0
003ogha^o`0000?ogH]`0_l00003omZCP`03o`000?oHTH?o000000?o000000GoeINAo`000?oCUI;o
diFBo`000002om6CTPCo00001Oo>V9d01?l0003ocINMolfGWOl00002olZDWP?o00001?o8VZL00ol0
003oaiRWolNHY`02olNHY`05o`000?o4UZSoa9JXo`000?o3UJP00_l00005olg0c`03o`000?o;`=3o
bl3@00Cobl3@00?o0000omjg/?l000001?oE][X2o`0000KobHnG00Go0000ol28VOo0R9Wo`8RIo`00
0006okZ3V003o`000?nbNYKo/WZF00Co/WZF00?o0000oi]YUonKJIL02?nKJIL01?l0003oQEFBo`00
0?l00002oi5g/PWo00000on?S/h01Ol0003oY:SJojBXf_nTZ=[o000000GoYL;^0_l00005ojo4j@;o
00000_nfc^`00ol0003o]m?_okOCk`05okOCk`;o00000onge_001_l0003o^mO^o`000?l0003o^mW_
o`0000;o_mk_00?o0000okkOl?nngo000onngo000ol0003o_N;bokgRlP02o`0000;oaNO_0oo3j?00
0ol0003o`^W`ol;Yl003o`0000Co`_7`00Ko0000ol?ijol0003o0000okkik?l00002okKlh@;o0000
00?oXOC8oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02oooo]Z
000^oookJP03o`000?oonf[ooo]Z043ooo]Z00Go001No`000?l0003o0000oa/i/`02o`0000;o?UG2
00?o0000oeEYb_l000000_mFJ<T3o`0000?oKg_>00Go0000ogR3dOmhPm7oN8?Ao`000003og^3d004
o`000?n3Rm?oPh_Co`0000KoQXcA00?o0000oh^BeOl000001on@UM@00ol0003oU9KBo`000007oiNK
eP;o00001onJVm@2o`0000SoX:;F0_l00009ojBTe@03o`000?nWYMCo000000;o00001OnWY]D01_l0
003oZjOCoj^Wdon[Ym?o0000oj^Wd`?o00000_n[[=P00ol0003o[ZgGojj]e`03ojj]e`?o00000_n_
[mP00ol0003o/K3Fok6`eP02ok6`eP?o00001?nb/ML01?l0003o]K;FokFbe_ne/]H2o`0000Ko][;D
00?o0000okVde?l000001onj]M@00ol0003o^kOFo`000005okbge003o`000?nn^]Ko_[[F00Co_[[F
00?o0000oknjeOl000001?o0_=H00ol0003o`kcCo`000003olBne003o`000?o5_]Co000000Goa/3E
0_l00002olO2eP;o000000?obl?Bo`000?o<aM<00oo<aM<01?l0003ocLSEolg8eOo=b=D2o`000003
om;;dol0003odl_B00;odl_B00Go0000omC>e?oDc]Coe<kDo`000004om[Bd@04o`000?oJe=?of]CC
o`0000?ohMW?00Co0000on;Ld?l0003o00000_oYhLX00ol0003ol>K2oo3V`P04o`000003ooK]V_l0
003o000002?ooo]Z0ol00002oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX06_oo
nfX01?l0003o04Noo`000?l7K]h3o`000003omY/<_l0003o000000;ogWiF0_l00003omf;L006o`00
0?oKRG7o0000o`000?oJTh?o00001?oHTH<3o`0000;odiFB00?o0000om6CT_oATi800ooATi82o`00
00?ocYRM00Go0000olfGWOo=UigocINMo`000002olZDWP03o`000?o9TigobI>M00?o000000?ob9ZW
o`000?o7V:L01?o7V:L4o`0000;o^/?Q00?o0000olg0coo=`<l00_o=`<l7ol_0d0;o00001_oE][X3
o`0000CobHnG00Go0000ol28VOo0R9Wo`8RIo`000005okZ3V003o`000?nbNYKo/WZF00Go/WZF00?o
0000oi]YUonKJIL02?nKJIL6o`0000CoWH^o00?o0000ohn>c_n?S/h01?n?S/h00ol0003oY:SJojBX
fP03ojBXfP03o`000?nU`^ko000000;o00001_n_a>T01?l0003o/<g_o`000?l00007okOCk`;o0000
1_nge_02o`000003ok_Ikol0003o_mk_00;o00001?nngo000ol0003o_N;bokgRlP02okgRlP?o0000
0_o3j?02o`0000;o`^W`0_l00004ol;al0;o000000?o`oW[o`000?nnnN`00_nnnN`2okKlh@;o0000
00?oXOC8oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z02oooo]Z
000^oookJP03o`000?oonf[ooo]Z043ooo]Z00Go^GX0o`000?l049co0000oa/i/`02oc]Ga005o`00
0?lnEL;o0000oeEYb_l000000_mFJ<T3ofMgc`Ko000000GoN8?Ao`000?mkPm3oNh?@o`000004oh>;
d`03o`000?n6S=7oQXcA00;oQXcA00Co0000oh^BeOn;T]Go00001?n@UM@5o`0000CoUi_F1?nFV]H0
0ol0003oVY_DoiZKe005oiZKe003o`000?nLX=Oo000000;oX:;F1?l00002oj2ReP03o`000?nTY=Go
Y:CE00SoY:CE0_l00009ojNVe@Co00001on[[=P00ol0003o[ZgGo`000002o`0000Ko[joH00Co0000
ok6`e_l0003o00002?nb/ML00ol0003o]K;Fo`000006okFde`?o][;D00?o0000okZee?nj]M@01?nj
]M@2o`0000?o^kOF00?o0000okbge?nl]m@00_l00007okjjeP;o00001Oo0_=H2o`0000Goa;kD00?o
0000olK0eOo6`=D00_o6`=D2o`000004olO2e_l0003oal;FolO2eP?o00001?o<aM<01ol0003ocLSE
olg8eOo=b=Go0000olk:e_l000000_oBbm<00ol0003odl_Bo`000003omC>e0;o00000ooJd]401?l0
003of]CCom[DdooJe=<2o`000005on7Icol0003oh]c@on;Ld?l000000ooYhLX01_l0003ol>K2o`00
0?oaj/;o0000ooK_/`?o00008OoonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0003o
oo]ZoookJP0LoookJPGo000000?o;8G[o`000?l000000_l00002ominEP;o00000_oMRg001?l0003o
fhUaom^9LOoKRG42o`0000Cof96300?o0000omJ?Q?l000000ol00005om6CTP03o`000?o@TY;o0000
00?o00000oo=Uid01?l0003obYBNolZDW_l00005olVCW@So00000onN^nd01?l0003o^/?Qok[3hOl0
0002olg0c`Oobl3@00?o0000ol6ke?l000001_oE][X00ol0003oaj6aolNQ/@03o`000003olV?Uol0
003o`8RI00;o`8RI00?o0000okZ3V?njPiP00onjPiP00ol0003o/WZFok9jUP05ok9jUP03o`000?nK
JIOoVfVG00GoVfVG1?l0000:oif;_`03o`000?n?S/koShk>00;oShk>00?o0000ojBXf_nTZ=X01OnT
Z=X00ol0003o[lCYojo4j@06ojo4j@?o00000_nacNl00ol0003o]m?_okOCk`02okOCk`;o00001_ng
e_001ol0003o]mSaokOHlOngf?7o0000okoNkol000001?nngo02o`0000Co_N;b0_l00002okoYlPCo
000000?o`^W`o`000?o2lO000_o2lO02o`000004ol;bl?l0003o0000o`0000?o__W/0_nfo>42o`00
0003oj7db?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0^oook
JP00;_oonfX00ol0003ooo]ZoookJP11oookJP03o`000?l049co232a00;o00000olkEl@3o`0000;o
EVS900Go0000ofMgcomWMloo0000ofaic`04ogF4e0So000000?oPh_Co`000?n6S=400_n6S=400ol0
003oRi;Eo`000006o`0000CoSY?D00?o0000oiJJe_nFV]H01onFV]H00ol0003oVY_DoiZKe003oiZK
e003o`000?nLX=OoW:3G00?o00001onPX]H00ol0003oY:CEojBTe@04ojBTe@?o000000?oY:CFo`00
0?nWY]D01?nWY]D3o`0000;oZ:WH00?o0000oj^/f?n[[=P02?n[[=P00ol0003o[joHojn_f007ojn_
f0;o00002_nb/ML2o`0000Oo]KCG00Go0000okJef?nf]MSo0000okRfe`03o`000003okZee?l0003o
^kOF00Co^kOF00?o0000okbge?nl]m@01onn^]H2o`000003oknke_l0003o`;cF00;o`;cF0_l00003
ol6ne`05o`000?o4_]Co0000olG0e_l000000oo6`=D01ol0003oal;FolO2e_o7`]Ko0000olO2e_l0
00000_o8aML01Ol0003oc<GColc5doo<aM?o000000?ocLSE00Ko0000olk:e_o>b]Koc/[Fo`000?oB
bm<2o`0000?oe<kD00Ko0000omC@eOoDd=Go0000om[BdOl00003om[Dd`;o000000?ohMW>o`000?oR
g=000_oRg=001Ol0003ojN7:onWQb_l0003oj^K;00;o000000?olN[2o`000?l000000ol0000Noook
JP?o00002?oonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z01gooo]Z1Ol00003obb5
j`Wo00000ooKRG42o`0000?of96300?o0000omJ?Q?l000000_oDSH<2o`0000CodI>B00?o0000om2B
T_o@TY800_o@TY82o`0000?ocINM0_l00004olVCW@Go00000onN^nd00ol0003oW[_]oijkk@03oijk
k@03o`000?nj`n7o000000;o00001Oo;`=02o`0000?o`K_D00?o0000omFf^_oE][X00_oE][X00ol0
003oaj6aolNQ/@04olNQ/@Wo00000_njPiP00ol0003o/WZFok9jUP05ok9jUP03o`000?nKJIOoVfVG
00Ko00000onWR[H00ol0003oWH^ooif;_`08oif;_`04o`000?n?S/koShk>o`0000KoY:SJ00?o0000
ojG0kOl000001on_a>T2o`0000Go/Lg_00Co0000okOCkol0003o00001?nge_03o`0000Co]mSa0_l0
0004okkOl0;o00001Onmh_800ol0003o_nWbokoYlP02o`0000Co_N_c00?o0000ol;al?o2lO000_l0
0002ol;bl0;o00001?nnnN`00onfo>7o0000o`000002oj7db33ooo]Z00?o0000oookJ_oonfX0=Ooo
nfX00ol0003ooo]ZoookJP0^oookJP00;_oonfX00ol0003ooo]ZoookJP11oookJP?o000000?o232a
o`000?lkEl@00_lkEl@2odmVbP03oeEYb_l0003o000000CoIgO?00?o0000ogF4e?meQ=@01OmeQ=@0
0ol0003oPHgFoh6=eP02oh6=ePOo00000on;U=L00ol0003oSY?DohjCe004ohjCe003o`000?nCVMOo
000000SoUY[F00?o0000oiZKe?nJVm@00_nJVm@4o`000003oibQf?l0003oX:;F00SoX:;F00?o0000
ojBTeOnTY=D00ol00005ojBTeP03o`000?nWY]Go000000;o00000onXZMP00ol0003oZ:_Io`000007
oj^/f0;o000000?o[:gIo`000?n_[mP01_n_[mP2o`000003ojn`fOl0003o/[7G00Oo/[7G0_l00000
0onb/mWo0000okFde`04okFde`;o00001?nf]MP00ol0003o^;KGokRfe`02o`0000Oo^kOF00?o0000
okjje_nn^]H01?nn^]H2o`0000Co_k_F00?o0000ol2le_l000001Oo1_]L2o`0000?oaL3F00?o0000
olK0eOo6`=D01?o7`]H2o`0000Cob<GG00?o0000olc5dol000000oo=b=D00ol0003oc/[Folk:eP03
olk:eP06o`000?oCc]CodlkDo`000?oDc]Co00001?oDd=D01Ol0003of]CCom[DdooJe=?o000000;o
fmOC0ol000001OoRg=3o0000o`000?oYhL[o000000;oj^K;00?o0000oo7Z`_l000000ol000000ooa
kI?o0000oookJP0JoookJP?o00002ooonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z
01kooo]Z00Co0000o`14^Ol0003o06cK1Ol00003odVFl@go000000KoeXn4omB=PooDSH?oe8f3o`00
0?oBRh@4o`0000God9:B00?o0000olj@T_l000002?l00002ohbelP03o`000?nN^ngoW[_]00CoW[_]
00Co0000oijkkOnN^ngoW[_]0ol00003okK2h`05o`000?o;`=3obl3@ol_0d?l000001_o1^m@01?l0
003oeKJjomFf^_l00007olNQ/@03o`000?nmW[Wo_Iji00;o_Iji00Co0000okZG/onjUk?o^YNc3Ol0
0002oj>2/0;o00001OnWR[H00ol0003oWH^ooif;_`08oif;_`03o`000?n?S/ko000000?oY:SJ0_l0
0005ojG0k@05o`000?n_a>Wo[lCYojo4jOl000000_n_a>T7ok7=k`;o00001?nge_02o`0000Ko]mSa
00Oo0000ok[Plonjh??o^^3co`000?nngo3o000000Go_N;b00Go0000okcSl_l0003o_nWbo`000005
okg[l`03o`000?nnl_;o000000?o000000?o`_;`o`000?nnnN`00_nnnN`2o`0000;o]_cQ00?o0000
oj7db?nQm<P0<OoonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02kooo]Z000]oook
JP03o`000?oonf[ooo]Z04;ooo]Z00Ko0000o`00TOl0003o232aobe>`_l00002oc]Ga003o`000?m?
I/[oCfK:00Go000000?oIgO?o`000?meQ=@01_meQ=@00ol0003oPHgFoh6=eP04oh6=eP03o`000?n6
SM?o000000KoRiCG00?o0000ohjCe?n>Tm@00_n>Tm@01Ol0003oTiWGoi>IeonCVMOo000000KoUY[F
1ol00005oibQf003o`000?nPX]KoX:;F00KoX:;F0ol00008ojBTeP;o000000CoZ:WHo`000?l0003o
00001OnXZmT01?l0003oZjcHoj^/f?n[[=P3o`0000Co[:gI00Co0000ojn_f?n_[mSo[joH0ol00004
ojn`f@03o`000?nb/MOo/[7G00;o/[7G0ol00004ok:cf@03o`000?ne]=Oo]KCG00;o00001_nf]MP3
o`0000Co^KSH0ol000001?nk]mKo0000ok^heol00004okjjeP03o`000?no^mKo_k_F00Go_k_F00?o
0000ol6neoo1_]L00oo1_]L01Ol0003o`[oHol:of?o2_mSo000000;oaL3F00?o0000olO2e_o7`]H0
0_o7`]H2o`0000Gob<GG0_l00003olg8e@03o`000?o>b]Koc/[F00?oc/[F00?oclgGo`000?oCc]@0
0_oCc]@00ol0003oe=3EomC@e@02omC@e@;o00000_oJe=<01Ol0003ofmOCom_GdooKem?o000000;o
h]g@00?o0000on;OdOoRgm400_l000001OoZi/_o0000o`000?l0003olNk200Go00006?oonfX3o`00
00oooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0OoookJPGo00000_lVQNX2o`00
00KoBIKa00?o0000of6Rm?mQX_@00_mQX_@Io`0000SoS;Gb00?o0000oijkkOnN^nd01?nN^nd3o`00
00?oWK_]00Oo0000okK2honf`^?o]/;So`000?o;`=3o000000Oo`K_D00?o0000omFf^_l000001oo7
XK400ol0003o_IjiokfN^@04okfN^@04o`000?njUk?o^YNco`0000Wo]8f^00Go0000oj>2/?nSP[3o
Xh:`o`000007ojN:]P03o`000?nMRkooWH^o00SoWH^o0_l000000onTZ=[o0000o`000009ojG0k@?o
000000?o[l[^o`000?nacNl01?nacNl3o`0000;o/]Cb00Co0000okOFl?l0003o00001Ongf?42o`00
0003okOJl_l0003o^^3c00;o^^3c0_l000000onmh_;o0000okgRlP02o`0000;o_>?b0ol00005okg[
l`03o`000?nnl_;o000000Co^_?b00Go0000okkik?nnnNco0000okkik002o`000004okKlhOl0003o
XOC8oj7db3;ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0^oookJP00;OoonfX0
0ol0003ooo]ZoookJP13oookJP;o000000Go232ao`000?l]C/;o>eO4o`000004odmVbPCoHgSB0ol0
0005ogF4e003o`000?mkRMKo000000KoPHgF00?o0000oh^Deon;U=L01_n;U=L01?l0003oSY?DohjC
e?l00004oi>Ie`03o`000?nFV]KoUY[F00Co00000onEV]H00ol0003oW:7HoibQf006oibQf003o`00
0?nPX]KoX:;F00?oX:;F0ol000000onPX]Oo0000ojBTeP04ojBTeP?o00000_nUZ=T2o`0000SoZ:_I
00Co0000oj^/f?l0003o00001on/[MT01?l0003o[joHojn_f?l00008ojn`f@04o`000?nb/MOo0000
o`0000Oo/[?I00?o0000okFdeol000001_nf]MP2o`000003okJgf_l0003o^KSH00Ko^KSH0_l00003
ok^he`04o`000?nn^]Ko0000o`0000Ko_k_F00?o0000oknmf?l000000oo1_]L2o`0000Co`[oH0_l0
00000oo6`]Oo0000olO2eP02olO2eP03o`000?o8aMOo000000Cob<GG00Ko0000olW7f?l0003o0000
olg8eOl00004olk:eP06o`000?o?cMOoclgGolo=eol0003odlkD0_l00003omC@e@03o`000?oFdmKo
e]?F00;o00000ooKem<2o`0000;oh]g@0_l000001OoRgm7o0000on[Vbol0003oj^W<00;o000000?o
lNk2o`000?l000000ol0000EoookJP?o00004_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oo
nf[ooo]Z027ooo]Z1?l00003obJ5jPGo00000_m9U_400ol0003oHJ;dof6Rm005of6Rm0;o00002?md
Zo@3og^^m003o`000?n3/_?oPk;c00?oPk;c00?o0000ohbel_n<]O802?n<]O800ol0003oW[_]o`00
0002o`0000?oWKc^00?o0000oifkkOnM^nd00_nM^nd00ol0003o]/;SokK2h`03o`0000Oo`K_D0_l0
0007olNQ/@03o`000?nmW[Wo_Iji00Go_Iji00?o0000okZG/ol000002ondSJh3o`0000WoYhZf00?o
0000oif;_onMRkl01?nMRkl5o`0000SoYL3]0ol00002ojg5k003o`000?n_b^ko000000?o/Lg_0ol0
0006ok;DlP03o`000?ngf?7o]mSa00?o]mSa0_l00002okOJlP03o`000?njh??o^^3c00;o00001?ni
hO<01?l0003o_>?bokcSl_nlho82o`0000Co_N_c00?o0000ok_[m?l000000_l00004ok[clP03o`00
0?ngnNco000000Ko000000?oXOC8oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0eoookJP03o`00
0?oonf[ooo]Z02kooo]Z000]oookJP03o`000?oonf[ooo]Z04?ooo]Z1?l000001?l]C/;o0000o`00
0?l00003odmVbP03o`000?mSN=;oHgSB00;oHgSB0_m^PMD3o`0000;oMHCD00?o0000og^9e_l00000
1_n1SMH2o`0000OoRiCG00?o0000ohjCe?l000000_nCVML6o`0000KoUI[F0_l00008oibQf003o`00
0?nPX]KoX:;F00?o00001OnPX]L00ol0003oY:CFo`000002o`0000?oYJSI00?o0000ojFYf_l00000
2OnXZmT2o`0000Wo[:gI0_l0000:ojn`f@;o00002Onb/mT2o`0000Go][GH0_l00004okJgfP03o`00
0?ni^=So^KSH00;o^KSH0_l00004okVif@03o`000?nk^=Oo000000Ko_k_F0_l00003oknmf003o`00
0?o1_]Oo000000Go`[oH00Ko0000ol?2fOo3`]Wo0000olK2eol00002olO2eP;ob<GG00?o0000olS5
eoo8aML00_l00003olW7f0;o00001?o>b]H00ol0003oclgGolo=e`03olo=e`06o`000?oDd=Goe=3E
o`000?oDd=Go00000ooFdmH01Ol0003ofmOCom_GdooKem?o000000;og=[D0_l00002on?Pd@?o0000
0_oZjL`00ol0003olNk2oo7^`P05o`0001;ooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z05gooo]Z
00?o0000oookJ_oonfX08ooonfX00ol0003o06_Io`000005o`0000;oAIOb2Ol00002of6Rm0;o0000
2?mdZo@01?l0003oNjkdog^^m?l00005oh>bl`03o`000?n<]O;oS;Gb00?oS;Gb0ol00002ohbelP03
o`000?nM_>koWKc^00GoWKc^00?o0000oifkkOnM^nd01?l00003ok72iP?o000000Co`K_Do`000?l0
003o00000_nd/]H00ol0003oaj6aolNQ/@03olNQ/@03o`000?nmW[Wo_Iji00Ko_Iji0_l0000;okB=
[P;o00002onWR[H00ol0003oWH^ooif;_`02oif;_`Co00000onX]N800ol0003oYL3]ojG0k@03ojG0
k@;o00001On]aN`2o`0000;o/Lg_0_l00006ok;DlP;o00000onbeo<01?l0003o]mSao`000?l00003
okOJlP04o`000?njh??o0000o`0000Co^N7c00Ko0000okOSmOnghoGo0000okcSl_l00004okg[l`03
o`000?nkjoCo^n_d00;o00001Onjlo801?ngnNco0000o`000?nbn>`2o`000003ojCgg?n>jkgo0000
03Kooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0^oookJP00;OoonfX00ol0003o
oo]ZoookJP13oookJP03o`000?l0097o0Rnc00;o000000So;Dk2odUWc_m9Ilko0000odmVb_l0003o
FW?Ao`0000?oHgSB00?o0000ofj1eOl000000_m`PM<Io`0000CoTY_I00?o0000oiFJe_nEV]H01?nE
V]H01?l0003oV9oIoiROfOl00006oibQf0Co00002?nPX]L2o`000004ojFXfOl0003o0000o`0000Go
YJWJ00?o0000ojR[fOnXZmT00onXZmT3o`000003ojR/f_l0003o[:gI00Ko[:gI0_l000000on/[m[o
0000ojn`f@07ojn`f@;o000000?o[k7Jo`000?nb/mT01_nb/mT2o`000003ok:df_l0003o][GH00?o
][GH00?o0000okJgf_nf]mX01Onf]mX01?l0003o^KSHo`000?l00005okVif@03o`000?nj^m[o^[_J
00;o00001?no^mH00ol0003o_kgHoknmf004oknmf003o`000?o2_mSo`[oH00;o`[oH0_l00004ol?2
f@03o`000?o6`]Oo000000?ob<GG00?o0000olS5eol000001Oo9amP2o`0000?oc/[F00?o0000olo=
eoo?cML00oo?cML01?o@cmWo0000omC@eOoDd=D2o`0000?oe]?F0_l00002om_Gd`05o`000?oLf]Co
g=[DomcJe?l000000_oSh=401Ol0003oh^;Co`000?l0003oj^W<00;o000000?olNk2o`000?l00000
0ol0000@oookJP?o00006?oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z02Gooo]Z
00Co0000o`1[fOl0003o8HGZ0ol00005odFGlP;o00000omNY?DKo`0000KoRkOc00?o0000oiflk_nM
_>h01OnM_>h2o`0000?oVk_^00?o0000ok72i_na`^H01?na`^H5o`0000;o];;F00Go0000olNQ/Oo7
XK7oaj6ao`000008okfN^@03o`000?nfY/So000000Wo]8f^0_l000000onbWlGo0000ojN:]P0:ojN:
]P03o`000?nMRkoo000000;o00002?nX]N800ol0003oYL3]o`000002o`0000Go[LG/0_l000000on]
c?3o0000o`000006ok;DlP;o00001onbeo<2o`0000?o]m[b0ol00003okWQl`;o00001?nghoD2o`00
0003okg[lol0003o_N_c00;o00000_nkjo@2o`0000?o^_?b0_l000000ongnNco0000ok;hk002ok;h
k004ojCgg?l0003oS^^mo`0003Oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0^
oookJP00;OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?l008Go000000;o74O100?o;Dk2o`00
0?m9Ilh00_m9Ilh3o`0000;oHgSB00Go0000ofj1eOm^PMGoKX7Eo`000002og21d`05o`000?mkR]Oo
Nh[Gog^:eol000001?mmR]H01?l0003oQI;HohFBf?l00007ohRBe`03o`000?nBVmWoTY_I00KoTY_I
00?o0000oiFJe_nEV]H00_nEV]H01Ol0003oV9oIoiROfOnHWmWo000000;oW:7H1?l00002oibQf003
o`000?nPX]OoX:;G00KoX:;G1?l00009ojFYfP03o`000?nXZmWo000000;o00001OnX[=X00ol0003o
[:gIojb]f@02ojb]f@;o00001?n/[mX00ol0003o[k3Iojn`f@02ojn`f@?o00001?n_/MX01?l0003o
/[?Iok:cfOnb/mT3o`0000Co/[CJ00Co0000okJef?nf]MSo00002?nf]mX2o`0000Go^KWI0_l00003
okZkfP06o`000?nl_=Wo0000o`000?no^mKo00001Ono_MP00ol0003o`;oIo`000003ol:of003o`00
0?o3`]Wo`l;I00Co`l;I0ol00003olS5e`;o00001Oo9amP01_l0003obLWIolW9fOl0003oc/[Fo`00
00CoclgG00Co0000om3?fOo@cmWod<oI0_l00002omGCe`03o`000?oFdmKo000000;oe]KH0_l00003
omcJe004omgNeol0003ohn3Ao`0000;oh^;C00?o0000on_Zc?l000000ol000000oo`ll;o0000oo7e
[@02o`0000gooo]Z0ol0000KoookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX09_oo
nfX3o`0000;o8HGZ1_l000000om5Uo;o0000o`000006oejTm@;o00002?mb[OH01Ol0003oNK3fogV`
m_mi/?Ko000000CoP[?d00?o0000oh^glon;]o<02?n;]o<00ol0003oWKc^oiflkP03o`0000?oVkc_
00Ko0000oi^kk_nK^nkoVk_^o`000?na`^H3o`0000Ko[kSP1?l000000oo7XK7o0000okfN^@06okfN
^@;o00000onfY/P00ol0003o]8f^okB=[P04okB=[P;o00001?nbWlD00ol0003oYhZfojN:]P08ojN:
]P?o00002onX]N800ol0003o[LG/ojg5k005ojg5k0Co00000on]d?800ol0003o/]Cbo`000002o`00
00Ko/]Oc0_l00003ok;Im004o`000?ngf_;o0000o`0000Co^N7c00?o0000okOSmOnghoD00onghoD0
1?l0003o^>_fokS[m_nhjoH2o`0000?o^n_d00Ko0000ok[cl_njlo;o^_?bo`000?nilo83o`0000?o
/_S/00CoY?OLo`000?n>jkgo0000>OoonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z
02kooo]Z000]oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0025o`000?l2;k<00_lLAl42o`0000;o
BFO>00?o0000oeYcd_mJLm801?l00002ofj1e@04o`000?m`PM?oL87Co`0000CoNh[G00Co0000ogf:
e_mmR]Ko00001?n5T]P00ol0003oR9;GohRBe`03ohRBe`03o`000?n=V=[o000000OoTY_I00Go0000
oiFJe_nEV]KoUI[Fo`000002oiROf@Go00001onLXMP00ol0003oX:;Goj2Re`04oj2Re`;o000000?o
XJSKo`000?nUZMX02OnUZMX2o`0000WoZ:cJ00Co0000ojb]fOl0003o00001on/[mX01?l0003o[k3I
o`000?l00007ojnafP04o`000?nb/mWo0000o`0000Oo/[CJ0_l00008okJgfP;o000000?o][SKo`00
0?ni^MT00_ni^MT2o`0000Ko^[_J00Co0000okblfOl0003o00001?no_MP2o`0000?o`;oI00?o0000
ol:of?l000001_o3`]T00ol0003o`lCJol?4fP02o`0000;ob<GG00?obLOHo`000?o9amP00_o9amP2
o`0000CobLWI00?o0000olo=eoo?cML00_o?cML00ol0003od<oIom3?f@02om3?f@04o`000?oEdmOo
eM?GomGCe`;o00000ooFe]P01?l0003og=[DomcJe?l00002omgNe`;o00000ooRh]<01_l0003ojn[<
o`000?o[k/co0000oo3c`PGo00002_oonfX3o`0001kooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0
003ooo]ZoookJP0XoookJPKo000000Co8hK[o`000?m2V??o@YSc2?l00002oejTm@;o00002?mb[OH0
1Ol0003oNK3fogV`m_mi/?Ko000000CoP[?d00?o0000oh^glon;]o<00on;]o<3o`0000;oRkOc0_l0
0007oi^lk`03o`000?nK^nkoVk_^00;o00002on_^>05o`0000Go_Iji00?o0000okJVb?nfY/P00onf
Y/P00ol0003o]8f^okB=[P02okB=[P;o00001_nbWlD00ol0003oYhZfojN:]P05ojN:]PGo00002?nX
]N83o`0000;oZ<C]00?o0000ojg5k?n]aN`00on]aN`2o`0000Ko[M3b0_l00007ok;Gl`;o00001Onb
fO@2o`0000Co^N7c0_l00004okOSm@04o`000?nhjoKo^>_fokS[mP;o00000ongjoH2o`0000;o^_?b
0_l000000onilo;o0000o`000003ok;hk005ojCgg?l0003o0000o`000?n<j[h0>_oonfX00ol0003o
oo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02gooo]Z000/oookJP03o`000?oonf[ooo]Z04Gooo]Z
1?l000001_lLAl7o?F7=oceQcOl0003oBFO>o`0000;oFW?B00Co0000oeeed_mZP]SoJX;H0ol00000
0om`PM?o0000og^:e`04og^:e`04o`000?mmR]KoOH[Fo`0000CoQI;H00?o0000ohRBeon8T]L00_n8
T]L01?l0003oSISJohfHf_l00004oi:Kf@?o000000?oTY_Io`000?l000001?l00003oiRQfP03o`00
0?nLXMSoW:7H00OoW:7H00?o0000oj2ReonPX]L00ol00004oj6Xf`03o`000?nUZM[oYJWJ00CoYJWJ
0ol000000onUZm_o0000ojR/fP08ojR/fP;o00002On/[mX2o`0000Wo[k7J0_l00007ok:dfP;o0000
00?o/kSMo`000?nf]mX01Onf]mX2o`0000Co][SK00?o0000okVifOni^MT02?nj^mX2o`0000?o_KgJ
00?o0000oknmf?l000001_o0_mT00ol0003o`l;Iol?2f@03ol?2f@;o00001?o3a=X2o`0000;obLOH
00Co0000olW7f?o9amSo00001Oo9bMT00oo:c=_o0000olo=e`02olo=e`03o`000?o@cmWod<oI00;o
d<oI00God=;Jo`000?oEdmOoeM?Go`000002omKFf006o`000?oFe]So0000o`000?oLf]Co00000ooM
g]L01?l0003oh^;Con;RdooRh]<3o`0000;ojnk<1ol00007oookJP?o00008OoonfX00ol0003ooo]Z
oookJP1LoookJP03o`000?oonf[ooo]Z02[ooo]Z1ol00004od:Hl`03o`000?m6V_?o000000;oG:Gg
6ol00006ohZhm003o`000?nK_>ooVkc_00KoVkc_0_l000000onH^o3o0000ojnhh008ojnhh0;o0000
0_nZ^N@00ol0003o];cPokBlh003o`000003okfN^Ol0003o]ZK800Go]ZK800?o0000okB=[_ndSJh0
0_l00008ok:Oa@04o`000?nWR[KoYhZfojN:]PKo00000onZ]>000ol0003oZ;GRojRehP03ojRehP;o
00001_nXa>d01?l0003o[LG/o`000?l00006ojg@lP?o00000_n]e_D00ol0003o/]Ocok;Gl`02ok;G
l`;o00001OnbfO@01_l0003o/n7gok?QmonchOOo0000okWQl`;o00000onghoD3o`0000;o^>_f0_l0
0004okO[mPKo000000Co^O?bo`000?nbn>co/_S/0ol000000onUmmgo0000o`00000loookJP03o`00
0?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0;OoonfX002cooo]Z00?o0000oookJ_oonfX0AOoo
nfX2o`000007o`0R[?lIBLCo74O1o`000?lmHLgo0000od1RcP02o`0000;oFW?B0_l00004ofZ2f0Ko
000000GoNh[Go`000?mmR]KoOH[Fo`000004ohFBf003o`000?n8T]OoR9;G00;oR9;G00?o0000ohfH
f_l000001Ol00005oi2Jf@03o`000?nHXM[oV:7J00KoV:7J00?o0000oibQf?nLXMP01OnLXMP5o`00
00OoXJSK00?o0000ojFYf_nUZMX00ol00005ojF[f`03o`000?nX[=[oZ:cJ00?oZ:cJ0ol000000onY
[]_o0000ojb_fP06ojb_fP;o000000?o[;;Mo`000?n_/MX01_n_/MX2o`000003ojnfg_l0003o/[CJ
00?o/[CJ0ol00004ok>hg@03o`000?nf]m[o][OJ00;o][OJ00?o0000okJhfonf^=/01?nf^=/2o`00
00Oo^[_J0_l000000onj_=_o0000okfmfP02okfmfP;o00001Oo0_mT00ol0003o`L7Jo`000003ol?2
f@;o00001_o3a=X2o`0000;obLOH00?o0000olW7f?l000001?o9bMT01ol0003ob/cKol[<foo:c=_o
0000olo=eol000000oo@cmT01?l0003od=;Jom3Bf_o@d]X2o`0000?oe]KH0_l000000ooGf=Wo0000
o`000003omgNe`;o00000_oRh]<00ol0003oi>KCo`000002on_^c0Co000000?okON]o`000?l00000
1OoonfX3o`0002Gooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0/oookJP05o`00
0?l0Im;o0000o`000?lMQ^T01?l000001?m2V??o0000odJJlol00005oebUm`03o`000?mRZ?Oo0000
00OoL:og00?o0000ogRbmomh/_L00_mh/_L00ol0003oPKGfoh6emP02oh6emP03o`000?n:^?CoR[Sd
00OoR[Sd00?o0000oi^lkonK_>l00ol00004oiRll@03o`000?nH^o3o000000Ko[kSP00?o0000ojZi
i?nZ^N@01?nZ^N@01Ol0003o];cPokBlh?l0003o];cP01_o00002?nZ]>000ol0003oZ;GRo`000002
o`0000WoZ<C]0_l00005ojg@lP;o00001_n]e_D01?l0003o/]Oco`000?l00003ok;Im0;o000000?o
/]_eo`000?nchOL00onchOL2o`000003okOSmOl0003o]n?e00;o000000Go]nCfo`000?nhjoKo^>_f
o`000003okO[mP04o`000?nekOKo0000ok?cm0;o00000on_lo@9o`0003gooo]Z00?o0000oookJ_oo
nfX0=OoonfX00ol0003ooo]ZoookJP0]oookJP00;?oonfX00ol0003ooo]ZoookJP16oookJP08o`00
0?l08Zco0000oaU9a?lLAl7o0000oceQcOl00002oeAdePCo00001OmZP]P00ol0003oN8cJogR<fP02
ogR<fQ3o00000_n=V]/00ol0003oT9[Ioi2Jf@06oi2Jf@03o`000?nHXM[oV:7J00KoV:7J00?o0000
oibQf?nLXMP01Ol000000onKX]Wo0000o`00000:oj6Xf`;o00002?nUZm/00ol0003oZ:cJojR/fP03
o`0000GoZJkK00Co0000ojb_f_n/[m[o[:oJ0ol00004ojbbg@04o`000?n_/M[o[k7JojnafP?o0000
1?n_]]h01?l0003o/[CJo`000?l00008ok>hg@04o`000?nf]m[o0000o`0000Go][SK0_l000000ong
^mgo0000okZkfP04okZkfP;o00001?nj_=/00ol0003o_KgJo`000003okfof`;o000000?o`;oIo`00
0?o1`MX00_o1`MX00ol0003o`l;Iol?2f@07ol?4fP06o`000?o4a]_oa<KKo`000?o9amSo00001?o9
bMT2o`0000Gob/cK00Go0000om3?fOo@cmWod<oIo`000004om3BfP05o`000?oFe]Soe]KHomKFf?l0
00000_oGfMT2o`0000?ogMkG00?o0000omgRf?oMh]P00_l00002onCVd`06o`000?o[k/co0000onW`
col0003ok_K41?l00002oookJP?o0000:?oonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[o
oo]Z02gooo]Z0_l000000ol0Im;o0000o`00000<o`000004oebUmol0003oHZSgo`0000OoL:og00?o
0000ogRbmomh/_L00_mh/_L00ol0003oPKGfoh6emP02oh6emP03o`000?n:^?CoR[Sd00?oR[Sd0_l0
0002ohZhm0;o00002?nH_?400ol0003oV;_`o`000003ojnhh003o`000?nZ^NCoZ[WT00OoZ[WT0_l0
000;ok:bf0;o00002_n`[MD3o`0000[oZ[CP0ol00008ojS4k@Oo00000_n]d?82o`0000Wo[MKe00?o
0000ok;Im?nbfO@00ol000000onbfoGo0000o`000002ok?Qm`?o00001?nbh_L2o`000003okOTm_l0
003o^>_f00;o00000_ngjoH2o`000004okG]m_l0003o/o?do`0000Co[o?d00?oZ?O[o`000?l00000
0_l000000on@kmKo0000ofoI/00ooookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0
;OoonfX002cooo]Z00?o0000oookJ_oonfX0A_oonfX3o`0000;o6DW400Co0000oceQcOl0003o0000
1?mDM=H2o`0000CoJX;H00?o0000ogR<f_mhS=X01OmhS=X00ol0003oQ9?KohBCf`05ohBCf`03o`00
0?n8U=Wo000000GoSI[K00?o0000oi2JfOn@V]T01?n@V]T00ol0003oU9oKo`000004oiRQfPKo0000
1OnKX]T00ol0003oWZKLo`000006oj6Xf`?o000000?oXZWLo`000?nUZm/02?nUZm/3o`0000SoZJkK
00Co0000ojb_f_l0003o00001on//]d01?l0003o[k7Jo`000?l00008ojnfgP03o`000?nc^=go/kSM
00Wo/kSM00?o0000okJhfonf^=/00onf^=/2o`0000Co]k_M00Go0000okZkf_nj^m[o^[_Jo`000006
okZlf`;o00001Onm_m/2o`0000Go`L7J00?o0000ol?4f_o3a=X01?o3a=X2o`0000?oa<KK0ol00003
olW9f@03o`000?o:c=_ob/cK00Cob/cK00GoblkLo`000?l0003od<oIo`000003om3BfP03o`000?oA
e=_o000000;oe]KH00Co0000omOIfOoGfMWoemWI0_l00002omgNe`05o`000?oMh]SogN;HomgRf?l0
00000_oTi]<3o`0000;ojO3?2?l0000[oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oo
nfX0;ooonfX2o`000003oaR6j?l0003o5hKX00?o000000Go?YWco`000?m2VoCo@Y_do`000002oeVW
n1_o00001_n8^_H00ol0003oV;caoiRll@06oiRll@?o00002?nZ^N@3o`000003oio3lOl0003o/[;H
00So/[;H0ol000000on/^N?o0000ok2]e@06ok2]e@?o00000_n[^^@00ol0003oZ[CPojZdh004ojZd
h0Co00000onX`^`00ol0003oZ<C]ojS4k@03ojS4k@;o000000?oZL_ao`000?l000000onYcO<2o`00
00So[MKe0ol00003ojgHmP05o`000?nbfoGo/]_eok;KmOl000000_nchOL2o`0000Go/^;g00?o0000
ok3Tn?n`i?P00_l000001?nhjoKo0000okO[m_ngjoH2o`0000;o]Ngf0ol00002ojocm0Co000000Ko
Y?G[o`000?n@kmKoT>oFofoI/?l00010oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oo
nfX0;OoonfX002cooo]Z00?o0000oookJ_oonfX0AooonfX01?l05:?o0000o`000?lIBL@2obiKc@;o
00001?mDM=H02?l0003oI7kGo`000?l0003oJX;Ho`000?mbR=[o00001_mhS=X2o`0000OoQ9?K00?o
0000ohfJfon=V]/01On=V]/00ol0003oT9[Ioi2Jf@02oi2Jf@03o`000?nDWm_o000000Go00001?nG
X=/00ol0003oVj;Ioi^Rf@03oi^Rf@05o`000?nNY]coWZKLoijVg?l000000_nQZ=/3o`0000GoXZWL
00?o0000ojF[fonUZm/00onUZm/3o`000003ojJ]gOl0003oZJkK00SoZJkK0_l0000:ojbbg@03o`00
0?n_]]ko[kKN00Go[kKN0_l000000on^]]oo0000ok>hg@06ok>hg@?o000000?o/;_Ro`000?nf^=/0
0onf^=/00ol0003o]k_MokNkg@04okNkg@04o`000?nj^m[o^[_Jo`0000Go^[cK0_l000000onj_]go
0000okfof`02okfof`;o00000_nn`M`01ol0003o`L7Jol71f_o1`M[o0000ol73fol000000oo3a=X2
o`0000Coa<KK00Co0000olG8gOl0003o00000_o9bMT00ol0003ob/cKol[<f`03ol[<f`04o`000?o;
c]coblkLol_>g0;o00000oo@d]X01?l0003odMCKom7DfooAe=/2o`0000?oemWI00?o0000omKKfooF
fm/00_l00003omgRf0;o000000Coi>KCo`000?oTk=Go00000ooYl<l00ol0003okOVoo`000002o`00
02kooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP0aoookJP?o00000olGQ^P3o`00
00;o@Y_d00?o0000oeVWn?mIYoP00omIYoP2oenZn003o`000?m_/?SoKk3h00CoKk3h00?o0000ogJc
n?mf/oP00omf/oP01Ol0003oOkOgogngmomo]oOo000000[oR;[f1?l00006oiFml`;o00001OnZ^N@2
o`0000GoWl?a00?o0000ok:bf?nb/]P00onb/]P3o`0000Go[;WS00?o0000ok2]eOn`[MD00_n`[MD0
0ol0003oZk[Toj^ji005oj^ji003o`000?nZ]>3oZ[CP00?o00002?nX`^`00ol0003oZ<C]o`000002
o`000003ojW;lOl0003o000000;oZLgc0ol000000onXdoKo0000ojgFm@04ojgFm@?o00001?n]f?H0
1ol0003o[M[gojgJmol0003o/]_eo`000?nchOL00_l00004ok;Rm`;o00000on`i?P5o`000003okO[
m_l0003o]Ngf00;o]Ngf00Co/o?do`000?n_loCo[o?d1?l00002ojCej`04o`000?n@kmKoKmV`o`00
04;ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0]oookJP00;?oonfX00ol0003o
oo]ZoookJP17oookJP05o`000?l8?koo23nooaU9a?l000000_l^Fld2o`0000?oE7CF0_l00003ofAn
e`Oo000000CoN8cJo`000?mnTM_o00001on4Tm/00ol0003oSI[KohfJf`02ohfJf`[o00000_nDX=d0
0ol0003oUj3KoiNPf`06oiNPf`05o`000?nKX]WoVj;Ioi^RfOl000000onNY]`4o`0000SoXZWL00?o
0000ojF[fonUZm/00ol00005ojJ]g@03o`000?nY[]_oZJkK00?oZJkK0ol00002ojVbg`03o`000?n/
/]go[;;M00?o[;;M3ol000000on^]]oo0000ok>hg@02ok>hg@?o00001On`^n801?l0003o][SKo`00
0?l00008okNkg@03o`000?nj_=_o^[cK00?o^[cK0_l00004okZng@03o`000?nm_m_o000000Go_/7L
00?o0000ol71f_l000000oo1`m/00ol0003o`lCJol?4fP05olC6f`07o`000?o5b=goaLSMolG8gOl0
003obLWIo`000004ol[<f`;o00001?o;c]`01Ol0003od=;Ko`000?o@d][o000000CodMCK00Go0000
omOIfOoGfMWoemWIo`000003omKKf`06o`000?oMh]SogN;HomgRf?l0003ogNCI0_l00002onC/e@03
o`000?oYl<oojO3?00;o000000?okOVoo`000?l00000;ooonfX00ol0003ooo]ZoookJP1KoookJP03
o`000?oonf[ooo]Z03;ooo]Z1Ol000000olGQ^So0000oc^Jl`08o`000004oeVWn?l0003oGj[ho`00
00KoKk3h00?o0000ogJcn?mf/oP00omf/oP01Ol0003oOkOgogngmomo]oOo000000;oR;[f1Ol00003
ohNkn003o`000?nE_O?oUKgc00SoUKgc00?o0000ojZii?l000000_l00008oio3l@03o`000?nb/]So
000000;o00002On/^N<2o`0000_oZk[T0_l0000<ojS2k004o`000?nYbo7oZL_aojW;l@;oZLgc0ol0
0005ojSCmP03o`000?n]e_Go000000;o00001?n]f?H2o`0000Co[M[g0ol00005ok;Rm`;o00001?n`
i?P2o`0000?o[^ch0ol00002okG]mP05ok?cm?n_loCo[o?do`000?n_lo@00ol00002ojCej`03oi3_
e_l0003o000004Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0]oookJP00:ooo
nfX00ol0003ooo]ZoookJP18oookJP03o`000?l05:?o23no00?o000000?o;U_=o`000?m;Km@00_l0
00001?mDM=Ko0000of=ofOl00002ofAne`04o`000?maRM_oLHWKo`0000?oM8WJ4?l00004oh^Ig004
o`000?n@Vm[oT9_Jo`0000GoU:3M00?o0000oiNPfonGX=/01_nGX=/00ol0003oVj;Io`000004o`00
00;oWZSM00?o0000oj:Yg?nRZM`01onRZM`3o`0000SoYZgM00?o0000ojV^fonY[]/00ol00006ojVb
g`Oo00001?n/^^@01?l0003o[[SPo`000?l00005ojjmi@Go00002On`^n800ol0003o]k_MokNkg@05
okNkg@;o000000?o][kPo`000?nj_=/00onj_=/00ol0003o^[kMokZng@04okZng@;o00001_nn`M`2
o`0000Go`L?K00?o0000olC6foo4a]/00_o4a]/2o`0000CoaLSM0ol00003ol[<f`03o`000?o;c]co
blkL00?oblkL00Goc=3Mo`000?o@d]_od=;Ko`000004om7Df`;o00000_oGfMT01Ol0003oe]_KomKK
fooFfm_of>3M00;o000000GogN;Ho`000?oMi=WogNCIo`000002onC/e@;o000000CojO3?o`000?l0
003okOVo0ol0000_oookJP03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX0=?oonfX01?mJ
003o0000oa:5i_lBQNH4o`0000?o?Ycd00?o0000oeNXn?mGZ?P05ol00009ohNkn003o`000?nE_O?o
UKgc00?oUKgc0ol00002oiFml`Ko00001OnO`o43o`0000So[;WS0ol00002oj36l`03o`000?n[^^Co
Zk[T00CoZk[T0ol00003oj?7lP03o`000?nX`^coZ<;/00CoZ<;/1?l000001?nVbo?o0000o`000?l0
0002ojW=l`;o00002OnXdoH00ol0003o[MSfojgHmP03ojgHmP;o00001?n]f_L3o`0000?oZn;j00Co
0000ok;Rmol0003o00001?n`i?P01?l0003o[^chojk/n?n^k?P3o`0000;o[>ci1_l000000on_loCo
0000o`000002ojCej`04oi3_e_l0003o0000o`0004Gooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0
003ooo]ZoookJP0]oookJP00:ooonfX00ol0003ooo]ZoookJP19oookJP03o`0>Wol0003o23no00;o
;Ek@00?o0000obiKcOl000000om;Km@3o`0000;oI7kG00Go0000og69fomaRM_oLHWKo`000003ogB9
fP04o`000?mmTMcoOI7Lo`0000GoP9;K00?o0000ohNIgOl000002?n;VM`2o`0000KoU:3M00?o0000
oiNPfonGX=/00onGX=/6o`0000OoWZSM00?o0000oj:Yg?nRZM`00onRZM`3o`000003oj:/g_l0003o
YZgM00SoYZgM0ol00005ojVbg`?o00000_nY]>42o`0000Wo[;[T00?o0000ojjmiOn^_ND02?n^_ND0
1?l0003o/[gRok:mh_nb_N83o`000005ok2kh_l0003o0000ok2ih?l000001Ong^md2o`0000Co][kP
00Co0000okZlfol0003o00001_nj_]d01?l0003o^l3Nok_0g_l00003okk1g0;o00000_nn`md01_l0
003o`L?Ko`000?l0003o`/GMo`0000Coa<KK1Oo5b=d3o`000004olW;g?l0003ob/cKo`0000CoblkL
00Co0000olc@gOo<d=goc=3M0ol00003om7Df`03o`000?oAemgodMOM00;o00000_oFfm/01Ol0003o
f>3MomSPgOl0003og^;H00;o000000KogNCIo`000?l0003oi>cEo`000?oTkmH2o`000003on[dcOl0
003o000000?o0000;ooonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z03Gooo]Z0ol0
0003oa:5iP06o`000?lhVo?o0000o`000?lnW?Co00001OmGZ?P00ol0003oG:_io`000002o`0000?o
KK;j00?o0000og>en_mc]OX01?mc]OX2o`0000;oO[Sh00?o0000ohNkn?n7^oP01on7^oP5o`0000Oo
TKof00Co0000oic4lonLa??oWl?a1Ol00003oibol@03o`000?n/^N?o[;WS00?o[;WS0_l00006oj36
l`03o`000?n[^^CoZk[T00?o00001onSao800ol0003oZ<;/ojS2k003o`0000;oY/_c0ol000001?nU
c_Go0000o`000?l00007ojSCmP?o00001?nXeoP01?l0003o[MSfo`000?l00006ojgJm`KoZn;j0_l0
0002ok3Tn0Co00000_n^k?P2o`0000?o[>ci00?o0000ojKamOnVlOD00_l00002ojCam@;o000000?o
Y?G[o`000?l000000ol00017oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0;?oo
nfX002_ooo]Z00?o0000oookJ_oonfX0BOoonfX01?l0003o03Bjo`0d^_l00003obeNd0;o00000_m;
Km@00ol0003oGWgJoeimfP07o`0000?oM8WJ00Go0000ogfAg?mmTMcoOI7Lo`000004oh2Bf`04o`00
0?n7VMgoQiWMo`0000OoRiWL00?o0000oiBPgOnDX=d00_nDX=d9o`0000CoUj;L00?o0000oijXgOnN
Z=d01onNZ=d00ol0003oXZWLo`000002o`0000GoXZcN00?o0000ojJ]gOnV[Md00onV[Md3o`0000;o
Y[3O00?o0000ojVbgonY/]l00ol00003ojVdh@03o`000?nX^NGo000000Ko[;[T0ol000000onU^^So
0000ojjmi@05ojjmi@?o000000?oYKWWo`000?nb_N801?nb_N85o`000004ok2ih?l0003o]k_MokNk
g@;o00001onf_^000ol0003o^[kMokZng@04okZng@;o00001?nk`=h00ol0003o_/7Lo`000004okk3
g@;o00001?o2aMd00ol0003oa<KKolC6f`05olG8g@07o`000?o5b]ko0000olG:g_l0003obL_Lo`00
0004ol_>g003o`000?o<d=goc=3M00;oc=3M00Ko0000om7Dg?oAe=co0000om7Dfol00003om7Gg@04
o`000?oFfm_oe]_Ko`0000?of>3M0_l00002omkUf@;o000000?oi>cEo`000?oTkmH00_l000001?oZ
m<go0000o`000?oVo;/2o`00037ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP0h
oookJP06oi@10?l0003o0000o`000?lBQNKo00000olhVo<00oljWOCo0000o`000007o`000003oeb[
nOl0003o000000?o00001?mc]OX2o`0000;oLkGj1ol00006ohNnn@03o`000?nA_oKoTKof00SoTKof
0ol00005oig1lP?o000000?oW;oao`000?n/^N<00ol00008oj36l`?o00002OnSao84o`0000?oY/_c
00Co0000ojG>mOnUc_GoYLke0_l00004oj?Bn003o`000?nXdoKoZ=?f00?o00002?nXeoP01?l0003o
[M[gojgJmon]f_L3o`0000GoZn;j0ol00003oj_SnP03o`000?n`iOSo000000;o[^ch0_l000000on/
k?Wo0000o`000002o`0000;oY_7e00?o0000ojCamOnTlOD00_l000001?nGlNWo0000o`000?mmi]02
o`0004Wooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0/oookJP00:ooonfX00ol0
003ooo]ZoookJP19oookJP05o`00J?l03Yoo03Bjo`0d^_l000000_l]G]02odA^eP?o00000_mNOMX0
0ol0003oH7gIo`000003ofn8g0Co00001?mmTM`01Ol0003oP9;Koh2Bfon0T]_o000000?oQiWM00?o
0000oh^Ig?n;VM`01On;VM`5o`0000CoTZ3M00?o0000oiNRg?nGX]`01OnGX]`00ol0003oVZKNo`00
0009oijXg@03o`000?nR[=koXZcN00OoXZcN00?o0000ojJ]gOl000000_l00006ojJ`g`;o000000Co
ZKCQo`000?l0003o00001OnX^ND00ol0003o[;[Tojbji003o`0000GoYK[X00?o0000ojjmiOn^_ND0
0ol00005ojFii`03o`000?nb_N;o000000;o00001On``NH4o`0000Go][kP0ol00002okBohP04o`00
0?nj_]go^[kMokZng@;o00001_nk`=h2o`0000Co_/?M00Co0000oko5g_noaMko00001?o2aMd00ol0
003oaLSMolG8g@02olG8g@;o00000_o5b]h00ol0003oaL[NolG:gP02o`0000?oblkL00?o0000olc@
gOo<d=d00_o<d=d01?o<dmoo0000om7Dg?oAe=`2o`0000?odMOM0_l000000ooFfm_o0000omSPg@03
omSPg@05o`000?oNiMWog^GIo`000?oLim`00_l000000ooTkmKo0000on?ae`03o`0000;oi_bk0_l0
000aoookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX0>ooonfX2o`000003oaN;j?l0
003o000000Oo00000_mEZ_T00ol0003oFJgjoeV]nP02oeV]nPOo00001_ma]o/2o`0000[oQkki00?o
0000oi6om_nA_oH01Ol00003ohg2n@03o`000?nM`O;oWL7b00OoWL7b2?l00004oj36l`;o00000_nP
a_<00ol0003oXlOboj?7lP05oj?7lPOo00000onUc_D2o`0000SoXm;h0_l00006ojSGn0?o00001OnW
fOT2o`0000GoZn;j0_l00004oj_SnP03o`000?nYi?[o000000?o00000_n/k?T2o`000005ojc/nOl0
003oY_7eojKamOl000000onTlOD2oiOaj@;o000000?oUO7Yo`000?l00000BooonfX00ol0003ooo]Z
oookJP0foookJP03o`000?oonf[ooo]Z02cooo]Z000[oookJP03o`000?oonf[ooo]Z04[ooo]Z00Co
00jOo`000?l0=;[o00000_l]G]001?l0003oA6kFo`000?m4KMH2o`0000;oGWgJ0_l00004ofn8g003
o`000?mbRmco000001Co000000?oSioOo`000?nBX=d01onBX=d00ol0003oUj;LoiNRg003oiNRg004
o`000?nJY]koVZKNo`0000;oWZSM1Ol00002oijYgP03o`000?nR[=koXZcN00KoXZcN0ol00005ojJ`
g`?o00000_nW/n42o`0000SoZ;WU0ol00008ojFjj0?o00001onU^NL3o`0000Ko/<7V0ol00002ojJi
i`04o`000?ne_^7o0000okJnh0;o00001_nd_n800ol0003o^[kMo`000006ok_0gP;o000000?o^l;O
o`000?nn`md00_nn`md00ol0003o_lGNoko5gP02oko5gP05o`000?o2aMgo0000ol;7g_l000000oo5
b=d00ol0003oaL[NolG:gP02olG:gP;o000000Koa/cOo`000?o9c]go0000ol_>g?l00003olc@g@04
o`000?o<dmooc=?OolcCg`;o00000_oAemd01?l0003odMOMo`000?oBfMh2o`0000Cof>3M00Cof>?N
o`000?oNiMWo00000_oLim`00ol0003oi?3Fo`000003o`000003onOicOl0003oi_bk00;o0000<_oo
nfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z03gooo]Z1Ol00002ocFLl`;o=Ygc1Ol0
0005oeV]nP04o`000?m/]?_oK;Cko`0000WoLKOk00?o0000ohNnnOn7__T00on7__T7o`0000WoSL;i
00?o0000oig1l_nM`O801Ol00005oiO4mP04o`000?nNaoGoW/Oeoik7m@oo00002?nPcOL2o`0000Ko
Xm;h0ol00004oj;EnP03o`000?nXeoSoZ=Oh00?o00001OnWfOT6o`0000;oZn;j0_l00002oj_SnP;o
00000_nYi?X4o`0000?oYN[j0_l000001?n/k?Wo0000ojKamOl00002ojCam@03o`000?nGlNWoUo7Y
00;o000000?oUO7YoggVd?l00000C_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z
02cooo]Z000[oookJP03o`000?oonf[ooo]Z04[ooo]Z00Oo002Ao`0^]ol0=;[o0000oaeDcOl]G]3o
000000;oA6kF0_l000000omJOM_o0000o`000002o`0000GoKhSL0_l00005og^Cg`04o`000?moTmgo
Oi?Mo`0000CoQY[O00?o0000ohVJgOn9V]d00on9V]d01?l0003oSioOohnOgol00008oi:Pg@06o`00
0?nGX]coUj;LoiNRg?l0003oVZKN1Ol00008oijYgP03o`000?nR[=koXZcN00Go00000onS[n000ol0
003oY[3Oo`000002o`0000?oYk?Q00?o0000ojRkiol000001_nX^ND3o`000003ojS9lOl0003oYK[X
00GoYK[X0ol00002oioGn`03o`000?nU^NOoYKWW00Go00000onQdoT00ol0003o/<7Vok31iP03o`00
00KoY[WW00?o0000okFnhOl000002Ond_n800ol0003o^l3Nok_0gP03ok_0gP;o00001?nk`]l00ol0
003o_/?Mo`000005oko5gP;o00000oo2amh00ol0003oaLSMo`000004olG:gP;o00000oo6c=l3o`00
00?oc=3M00?o0000olcCgoo<dml00_o<dml01?l0003odMOMom7GgOoAemd2o`0000;od]WN00?o0000
omSPgOoHh=d00_oHh=d2omSSgP;o00000_oLim`2o`000003onC`e_l0003oho?G00Oo0000<_oonfX0
0ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z03oooo]Z0_l000000ol9Q^7o0000o`000002
o`0000?o=Ygc4ol00002og6gn`Go00001on3_oX00ol0003oSL;iohg2n@07ohg2n@;o00002onGa?H3
o`0000[oW/Oe0_l00006oj3=m`?o00001?nMd?X00ol0003oXm;hoj?Bn003o`0000SoX]Gj0_l00005
ojOIn@;o000000?oY]_jo`000?l000000_nSh?`3o`0000;oZn?j0ol00002ojWTnP?o00001?nUj_X0
0ol0003oXn[joj?ZnP03o`000004ojCamOl0003oXo7do`0000;oUo7Y00Co0000oiGajOl0003o0000
D?oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02cooo]Z000ZoookJP03o`000?oo
nf[ooo]Z04cooo]Z00Go00jOo`0^]ol0=;[o0000oaeDc@02o`000003odA^e_l0003o000000CoFWgK
1Ol00002ofn8g003o`000?mkTmooNi?O00CoNi?O0_l00006ohJJg`03o`000?n9V]goRI[M00;oRI[M
00Go0000ohnOgon?WmooSioOo`000004oi:Pg@Wo00001?nJYml00ol0003oWZWNoijYgP05oijYgPCo
00002?nS[n02o`000004ojNchOl0003o0000o`0000GoZ;_W00?o0000ojRiiOnX^ND00ol00005ojS9
l@03o`000?nU^^SoYK[X00?o00001_nOeo/2o`0000WoXM?i0_l00009ojJii`;o00000_nd`><00ol0
003o];oRokBohP02okBohP;o000000?o/l3To`000?nk`=h00onk`=h00ol0003o^l;Ook_2g`04ok_2
g`;o00001OnoaMh00ol0003o_lKOo`000003ol;7gP;o00000oo5b]h2o`000003olK<gol0003oa/cO
00;oa/cO00Ko0000ol[@g_o:d=ko0000olc@gOl00003olcCg`04o`000?o<eN3o0000om7Gg@;o0000
0_oBf]l00ol0003od]WNo`000003omSPg@?of>?N00Go0000omcWg?oLimco0000omg]g@02o`000004
on?ceol0003o0000onKicP?o000000?oco6Fo`000?oonfX0<OoonfX00ol0003ooo]ZoookJP1Ioook
JP03o`000?oonf[ooo]Z043ooo]Z2Ol000001OlfWO?o0000oe>/nOmC[?Wo000000GoEZkj0_l00000
0omZ]__o0000ofjio008ofjio0Co00001?n3_oX8o`0000KoRlCj00Co0000oiO4m_nGa?KoUlCf1Ol0
0004oi;8nP04o`000?nNaoGoW/Oeoik7m@Go00001?nHc?T00ol0003oX<ggoj3=m`03o`0000SoWM3j
0_l00006oj;EnP?o00001?nQeo/00ol0003oYmWio`000002o`000003ojKKn_l0003o000000Co0000
1?nRhO`2o`0000;oZNCj00?o0000ojGZn_l000000_nUj_X2o`0000?oXn[j0ol00002oi[^mP03oiO^
m?l0003o000000Go0000D_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02cooo]Z
000ZoookJP03o`000?oonf[ooo]Z04cooo]Z00Oo002Ao`000?l0;[Oo0000oaeDcOl0003o?FcG00?o
00001?mJOM/00ol0003oJh_Oof^;g`02of^;g`So00000_mkTml00ol0003oQY[OohJJg`05ohJJg`04
o`000?n9V]goRI[Mo`0000;oSioO1ol00005oi:Qg`03o`000?nJYmooVZOO00KoVZOO00?o0000oijY
g_nNZMh01?l00002oij/h@03o`000?nS[n3oXjoP00KoXjoP1?l00008ojRki`?o00001onXbO44o`00
00CoWmOk1ol00004oj7Cn@Co00000_nH__800ol0003oY[WWojJii`04ojJii`?o000000?oYLWbo`00
0?nd`><00_nd`><01?l0003o];oRo`000?l00004ok?0i004o`000?nk`=ko0000o`0000Go^l;O0_l0
00000onka>3o0000oko5gP02oko5gP;o00000onoa]l00ol0003o`/ONo`000002ol?9g`03o`000?o5
b]ko000000?oa/cO00Go0000olK<gol0003oa/oQo`000002ol[@gP;o00000oo<dml00ol0003oc=GP
olcEh002o`0000Cod][O1?l000001?oHh=gof>?NomSSg_oHhmh2o`000008omcWg?l0003ogNgMomg]
gOl0003oho?Go`000?oQm=T3o`000003on7m^ol0003o000003?ooo]Z00?o0000oookJ_oonfX0FOoo
nfX00ol0003ooo]ZoookJP12oookJPGo000000Co>j;do`000?lkX_Co>j;d2Ol00002oeJ^nPWo0000
0_m^^O`7o`0000CoP/3k00?o0000oh_4n_n;a?X02?n;a?X3o`0000[oT/Sj0ol0000:oiS<n@;o0000
1_nMd?X3o`0000CoVm?k00?o0000oj;En_nReOX00ol00008oj7Gn`05o`000?nVfo[oY]_jojKKn_nS
h?`00_l00005oj;Qo0;o00000_nQh_`3o`0000;oYN[j0ol00002oj?ZnP?o00000_nJk_HHo`0004Go
oo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0/oookJP00:_oonfX00ol0003ooo]Z
oookJP1=oookJP03o`0Y/ol0;[Oo55?=00?o00000_lmK=L4o`0000;oFWgK00?o0000of^;gom[Rml0
0om[Rml00omeTN7o0000ogRAg`03ogRAga3o00000on>XN400ol0003oTZ7Ooi:Qg`06oi:Qg`03o`00
0?nJYmooVZOO00GoVZOO00Co0000oiZWgol0003o00001onN[>400ol0003oXjoPoj>_h003oj>_h0?o
00000_nT]>@00ol0003oZ;_WojRki`03ojRki`?o00000_n[bo400ol0003oZ<WaojS9l@03ojS9lAKo
000000CoP1<Xod/00?m;003oB`000_nH__800ol0003oY[WWojJii`03o`0000GoYLWb00?o0000okC0
hond`><00_l00007ok?0i003o`000?nk`]oo^l;O00?o^l;O0_l00004ok_4h003o`000?noaMko0000
00Ko_lKO00Co0000ol?9goo3bMoo`lWO0_l00004olK<g`;o00000oo6cn42o`0000;obm?P00?o0000
olcCgol000000oo<eN000ol0003od][Oom;Jg`02om;Jg`05o`000?oAg>7odMcQom7LhOl000000ooH
hmh01?l0003oenGPo`000?l00002omg]g@?o000000CohOCIo`000?l0003oi?_?0ol0000doookJP03
o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX0AOoonfX4o`000003oc^Rm?l0003o000000Go
00001omC[oX00ol0003oLK_log6ko008og6ko004o`000?mg__goMkkmogNno@?o00000on2`?/00ol0
003oRlCjoh_4nP05o`0000CoR/Kl00Co0000oi;8n_nBb?[oT/Sj1Ol00004oi3:o004o`000?nHc?Wo
V<cioiS<n@Go00001?nFc_/00ol0003oWM3joig@nP03o`0000SoVm?k0_l00006oj7Gn`Wo00001OnR
hO`2o`0000?oXN;l0ol00003oi[Wn`co00001?n0/?<01?l0003oNJgcogV]lol0000;og>Yl`04o`00
0?mSXO?oHj7cof>Ql`Ko0000?ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z02co
oo]Z000ZoookJP03o`000?oonf[ooo]Z04gooo]Z00Go0000o`0Y/ol0;[Oo0000oa9@b`02o`000003
oce/eomEO]ko000000;oEGkN1?l00004of^;g`03o`000?meTN7o000000GoN97O00?oPIWQo`000?n3
VN001_n3VN000ol0003oRI_Oo`000006ohjQh@03o`000?nBXMooTZ7O00CoTZ7O00Co0000oiFUhOl0
003oVZOO1Ol00002oiZYh@03o`000?nN[>7oWZcQ00OoWZcQ00?o0000oj>_h?l000000_l00006ojBd
i003o`000?nX^nOo000000;o00001_n[bo400ol0003oZ<Wao`000004o`000003ojHf<?l0003o0000
00KoVB8O0_l00002oiX]=@04o`000?mo42GoOa0Uogl@9@Ko00000_m]2C82od/000;o00002OnUbO82
o`0000?o/l7T00?o0000ok?0i?l000000_l000000onb`>Go0000ok_2g`03ok_2g`03o`000?nka>3o
^lCP00Co^lCP0_l00004oko6g`;o000000Oo`<SQo`000?o3bMoo`lWOo`000?o4c>7o000000?oa/cO
0_l00004olK?h@04o`000?o;dn3obm?Pol_Ch0;o00000oo<eN02o`0000?od][O00?o0000om7LhOoA
g>400_oAg>42o`000005omSSg_l0003oenGPomOUh?l000000_oMkMd3o`0000;ohOCI00?o0000onCk
col000000ol0000eoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0B?oonfX5o`00
0003oc6QlOl0003o000000Oo00000_mC[oX@o`000003ogNnoOl0003o000000Co00002?n:a_`5o`00
00[oT<[l0ol0000:oiK>n`;o00001_nKdo/3o`0000CoV]Gl00?o0000oj7GnonQeo/01_l00002oi_M
o@06o`000?nIg_koVMknoiWNo_l0003oX^7l0ol00002oj7Ro0_o00001on8]?800ol0003oP;3coh2`
l`05oh2`l`04o`000?mi[O?oNJgco`0000_oLjWc00?o0000of>QlomSXO<01_mSXO<6o`0003Wooo]Z
00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0[oookJP00:_oonfX00ol0003ooo]Zoook
JP1>oookJP03o`000?l0:K?o000000;o000000Go<FSHo`000?lmK=OoEGkNo`000003oeEngP;oI8SQ
0ol000001?m[Rmoo0000ogFAhOl00005ogRAg`03o`000?n1VN7o000000OoPiWP00?o0000ohjQhOn>
XN401On>XN400ol0003oTZ7Ooi:Qg`04oi:Qg`Co00002?nJZN400ol0003oWZcQoij/h@05oij/h@?o
000000?oXk;So`000?nT]>@01_nT]>@2o`0000OoZl_a1_l000000onnD3[o0000ok54>P0Ao`0000Co
SAl^00?o0000ofd9<_m]2C800ol000000on^:P?o0000ohO9o@02ohO9o@Co00000_nO^^`00ol0003o
/l7Tok?1i002ok?1i0;o00001Onb`>D01?l0003o^l;Oo`000?l00005ok_4h0;o00000_nlaN801?l0
003o_lKOo`000?l00004ol38h@;o00000oo4c>400ol0003oa/cOo`000002olK?h@05o`000?o6cn7o
0000olKAh_l000000_o;dn002?l0003obmKQol_FhOl0003oc=GPo`000?o<en;o00000_oBf]l00ol0
003odMcQom7Lh@02om7Lh@0<om7Phol0003o0000o`000?oGiN3o0000omSWh?l0003ogNgMo`000?oL
l=ko00000_oQm=T6o`0003Kooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003ooo]ZoookJP1<oook
JPOo000000Co<J7aoeRcnol0003o00001_mH/o/00ol0003oFKKloeVfo003o`0000CoKKgm00?o0000
ogC0o_md`?h01Omd`?h3o`0000;oR/Kl1Ol00004ohO7o@04o`000?n@b_coT<[loi3:o0Go00001?n>
c?d01?l0003oU/kkoiK>nonFc_/5o`0000CoU=3m00?o0000oi_CnonKdo/00ol00006oi[Eo0Go0000
1OnKgOd7oiWNoP?o00000_nQh_`4o`0000?oVkg`00?o0000ohRdl_n8]?802_n8]?800ol0003oP;3c
oh2`l`04oh2`l`05o`000?mi[O?oNJgcogV]lol000002omcZO<00ol0003oHj7cof>Ql`08of>Ql`03
o`000?mAU_3oDIK`00Go0000=?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02_o
oo]Z000ZoookJP03o`000?oonf[ooo]Z04kooo]Z00Co0000o`0Y/ol8C/_o24k;0_l00002oc5Xf0;o
00000omEO]h00ol0003oI8SQo`000002ofF8h0So000000CoN97Oo`000?n1VN7o00001on3VN000ol0
003oSZ7QohjQh@02ohjQh@_o00000_nEYn800ol0003oVZWQoiZYh@06oiZYh@03o`000?nN[>7oWZcQ
00Go00000onQ/N@00ol0003oY;CTojBdi003ojBdi0?o000000?o[<G/o`000?n[bo401?n[bo44o`00
0004olQL@?l0003o/DHook56?`Oo000000?oZ3Pco`000?nJ=4801?nJ=484o`0000GoSAl^1?l00003
og<@=PGo00001?m//OX01Ol0003oWk[/oinjk?l0003o/l7T00;o00000_nb`^H00ol0003o//3Uok;0
i@03ok;0i@03o`000?nka>3o^lCP00;o^lCP0ol00005okc5hP03o`000?o0b>7o`<SQ00Co`<SQ00?o
0000olC<hOo4c>400_o4c>42o`0000?oa/oQ0_l00003olKAhP;o00000oo;e^42o`0000?oc=OR0_l0
0003om7Lh@04o`000?oAh>?o0000o`0000;oenKP00?o0000omSWh?oHin000_l00002omc`gP03o`00
0?oQm=Wo000000;o000000CogOk9o`000?l0003o0000=_oonfX00ol0003ooo]ZoookJP1GoookJP03
o`000?oonf[ooo]Z04oooo]Z4ol000000omI]_co0000o`00000;o`0000;oM<3n1Ol00005ohO7o@Go
00002?n>c?d5o`0000SoU=3m1?l00007oi[Eo0;o00000on@f_l01Ol0003oVmgmoi_MoOnKgOgo0000
00KoVMkn00Co0000oiWOo_nIgokoVMon1?l000000onK_O3o0000oi^ml005oi^ml003o`000?n8]?;o
R;Cb00CoR;Cb0ol00003ohRdlPKo000000?oP;3co`000?l000003Ol000000omcZO?o0000o`000005
o`0000CoHj7c00?o0000oe6Fl?mAU_001?mAU_07o`0002gooo]Z00?o0000oookJ_oonfX0=_oonfX0
0ol0003ooo]ZoookJP0[oookJP00:_oonfX00ol0003ooo]ZoookJP1?oookJP04o`000?l0:K?o24k;
o`Q>b`;o000000?o<FSHo`000?m<Nml00_l000001OmEO]ko0000ofB8hOmTR>7o000000;oIHSP00Co
0000og:Ah_mbTN;o00000omeT^4@o`0000CoS:3Q00?o0000oi6ShOnAXn400_nAXn400ol0003oUJOR
oiFWhP02oiFWhP03o`000?nJZN7oVZWQ00;oVZWQ1_l00007oj6ai0;o00000_nT]>@3o`0000Go[<G/
00?o0000oj_;lOl000001Ol000001?nkDdKo0000o`000?l00003ok56?`;o00000onY>SHAo`0000;o
La0f1Ol00002oe`7A0_o00001Onb`^H01?l0003o//3Uo`000?l00002ok71iP04o`000?nka>3o0000
o`0000Go_<GR0_l000000onlan?o0000ol38h@02ol38h@;o000000Co`<[Ro`000?o4c>7oa<cQ0_l0
0002olC>hP04o`000?o6cn7o0000o`0000Coa]7R00Oo0000ol_FhOo;e^7obmKQo`000?o<f>?o0000
00?oc=OR00?o0000om7LhOoAg>400_l00002om7Ph`05o`000?oGi^3oenKPo`000?oFin800ol00002
omc`gP?o000000?ogo[Ho`000?oMo/T00ol0000goookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000
oookJ_oonfX0D_oonfX6o`0000;o<JGa0ol00003oe:dn`;o00001?mF]o/2o`0000;oK;kn00?o0000
og72o_ma`_h01oma`_h00ol0003oO<Onogc7oP07o`000003ohG9o_l0003oS/cm00CoS/cm1?l00004
ohc>oPCoU=3m3_l00008oi3Jo`03o`000?nIg_koVMkn00;oVMkn0ol00002oiWOoPGo00001OnK_O00
0ol0003oVkg`oi^ml003oi^ml0Oo00001_n9/_400ol0003oPJoboh6_lP04oh6_lP03o`000?mkZo;o
Nj_b00;oNj_b00?o0000ogBXl_mdZ?802?mdZ?800ol0003oIYoaofJOl@04ofJOl@Wo00001?mAU_00
0ol0003o?h_]o`000002ocf9k0?o0000:_oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[o
oo]Z02_ooo]Z000YoookJP03o`000?oonf[ooo]Z057ooo]Z0_l000001Ol8C/_o;f_Jobm[f_l0003o
<FSH00;o00000_m<N]h4o`0000;oIHSP00Go0000og:Ah_mbTN;oLY7Ro`000003ogFBh@04o`000?mo
VN?oOiWSo`0000KoPY[R00?o0000ohVPhol000001on<X>401?l0003oTJ?Qoi6ShOl00004oiFWhPKo
00001OnJZn<00ol0003oXK7Toj6ai004oj6ai0Go00002?n/aN`5o`000004olmYC?l0003o0000o`00
00?o^e=61_l00006ojTj=P03o`000?nU@DWo000000SoSbTm1Ol00003ogXPB@?o00000omG14@3o`00
00;oCI_c00Co0000oiRhk_nH^>ko00000onb`^H3o`0000Go/L7V00?o0000okc5h_nlaN800onlaN82
o`0000Co_<OS00?o0000ol38hOl000001?o0b^82o`0000Coa<kR0_l000000oo6dN;o0000olKAhP02
o`000003olOChol0003obmKQ00;o00000_o<f><3o`000004olcJhol0003odMcQo`0000?odN3S00Co
dN?To`000?oGi^3o00000ooFin82o`000005omc`g_l0003o0000o`000?oOn]P01_l0000goookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0EOoonfX4o`000004objSl?l0003o;ZG_oc6U
l@[o00000_mF]o/:o`0000;oLL;n0ol00006ogW8oa7o000000?oU=3mo`000?l000000ol00006ohWE
o`03o`000?n@f_ooT=[o00?oT=[o1?l00005oi3Ko`;o00000onIgoh4o`0000;o^LOU00?o0000oi^m
l?nK_O001?nK_O000ol0003oVkg`o`000002o`000003oiZlkol0003oRK;a00_oRK;a00?o0000oh6_
l_n1[o801?n1[o800ol0003oNj_bog^[lP02og^[lP03o`000?mdZ?;oM:Sb00SoM:Sb00?o0000ofJO
lOmVWo402?mVWo401?l0003oEIG_oeFEkomEUNl3o`0000;oDIK`00?o0000ocn;kOl000001?lmRN`3
o`0002Oooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0[oookJP00:OoonfX00ol0
003ooo]ZoookJP1AoookJP05o`0NZOl0003o04K7o`Q>bol000000_l_JmX3o`000004odajg_l0003o
GhSRoen8hPOo000000GoLY7Ro`000?meT^7oMI;Qo`000003ognIh`03o`000?n2V^;oPY[R00?oPY[R
00Co0000ohVPhon9X>?o00001on<X>400ol0003oTJ?Qo`000004o`0000;oUJWS00?o0000oiZ[honJ
Zn<01onJZn<00ol0003oXK7Toj6ai004o`0000?oX[?U00?o0000ojc5k?n/aN`00on/aN`4o`000003
okShk_l0003o000000;o00000oo?JD`3o`000003ok]CA_l0003o]Te400;o]Te45?l00004ogXPB@?o
00000omG14@9o`000003oiRhk_l0003o000000;o00000ona`NH01_l0003o/L7Vo`000?l0003o/L;V
o`0000Co_<GR00?o0000okc7honlan<01Onlan<00ol0003o`<[Rol3:hP03ol3:hP03o`000?o4c^;o
a<kR00;oa<kR00?o0000olGAhoo5dN<00ol00003olOCh`03o`000?o;e^7oc=SS00;oc=SS00Go0000
olcKi?o<fnCo0000olcJh`02o`0000;odN3S00?o0000om7Si?oAhn@00_l00003omKWhP03omK]i?l0
003o000000?o000000?ogo[Ho`000?l000001?l0000hoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o
0000oookJ_oonfX0EooonfX8o`000006objUkol0003o0000o`000?mA]O[o00001omC^?/3o`0000Go
M<Cn2Ol00006ogO:o`04o`000?n1coooPLoooh7?o`Go00001?mnd?l01?l0003oRMGoohWEoon9eOl5
o`0000CoQmKo0ol00004oi3Ko`Co000000?oT=coo`000?l000000ol000001On@hogoS^?lo`000?oC
emco000000?o^LOU00Co0000oi^ml?nK_O3oVkg`0_l000000onK_O3o0000oiZlk`04oiZlk`03o`00
0?n9/_7oRK;a00[oRK;a00Co0000oh6_l_n1[o;oPJob3ol00003ogBXlP;o00002_mVWo400ol0003o
EIG_oeFEk`05oeFEk`?o00001?lmRN`00ol0003o9W[UobIji@03o`0002Cooo]Z00?o0000oookJ_oo
nfX0=_oonfX00ol0003ooo]ZoookJP0[oookJP00:OoonfX00ol0003ooo]ZoookJP1BoookJP;o0000
00Go04K7obm[f_l0003o;f_Jo`000002odIjg`?o00000omOR>82o`0000?oL9;S2?l000000omoVN?o
0000oh:JhP02oh:JhP03o`000?n9X>?oRJ3S00co00001onEZN<00ol0003oVZ_SoiZ[h`05oiZ[h`Co
000000?oXK7To`000?nR/nD01OnR/nD00ol0003o[<G/o`000002o`0000;o]Mcd1Ol00002omUcBP;o
000000CocfU<o`000?o3GToo`ei?0_l00004okI=A003o`000?n^DESo[U5H00Co[U5H00Co0000oi/l
ConK?4oo00001_nJ?eH6o`0000;oPBM>00Co0000oeL4A?l0003o00000_mU6EL3o`0000?oAIcd0_l0
00000onA]Noo0000ok71iP04ok71iP;o00001?na`^H01?l0003o_<GRo`000?l00005okc7h`;o0000
0_nmbN@01_l0003o`<[Ro`000?l0003o`LcSo`0000;oa<kR0_l00003olGAh`;o00001?o7dn<01Ol0
003oc=SSolcHhoo<f>?o000000?oc=_T0ol00002om7Ph`05o`000?oAhnCodN?Tom7Si?l000000_oF
in801?l0003oe^gTo`000?l00002om_dg`So0000>OoonfX00ol0003ooo]ZoookJP1GoookJP03o`00
0?oonf[ooo]Z05Oooo]Z00Co0000oookJ_oonf[ooo]Z1Ol000000olgZo;o0000o`000009o`0000;o
DkSk1ol00004og76o`03o`000?mgb_ooMl[o00SoMl[o0ol0000:ogk@o`?o00000on7e_l4o`0000Co
R=Oo1?l00003oi3Lo`?o000000?oQ=gmo`000?n2g_`00on2g_`01Ol0003odmOLom?Gg?oCemco0000
00;o^LOU1?l00003oiZml003o`000?nJ_>ooV[c_00CoV[c_00?o0000ohVblOn9/_401?n9/_45o`00
0004ohVblOl0003o0000o`0000?oPZg`00?o0000ogbYl?mlZO000_mlZO000ol0003oMZK`ogJVl004
ogJVl0?o000000?oM:Sbo`000?l000001_l00003ofJOl@;o00001omEUNl00ol0003o@h[/o`000002
o`0000;o?HW/00?o0000obIjiOlVN^D00_lVN^D2o`0002;ooo]Z00?o0000oookJ_oonfX0=_oonfX0
0ol0003ooo]ZoookJP0[oookJP00:OoonfX00ol0003ooo]ZoookJP1CoookJPGo000000Go;f_Jo`00
0?m6N]oo0000odIig`04o`000003oen8h_l0003oL9;S00CoL9;S00?o0000ogBDhol000000ommVnD8
o`0000;oQj7T00?o0000oh^Rhon;X^<01On;X^<00ol0003oUJWSoiFYh`06oiFYh`03o`000?nJZn?o
VZ_S00Go00000_nK/>D00ol0003oXK7To`000006oj:ci@03o`000?nR/nGo000000Co]Mcd1?l00002
on9lA0?o000000OoaV5>o`000?l0003o0000ol=NCol0003o`Ue>00Co000000?o]Te4o`000?n^DEP0
0on^DEP00ol0003oVca?oi/lC`02oi/lC`03o`000?nJ?eKoVSmF00Co00001_n19dh4o`0000;oIAUG
0_l000000olS03go0000o`000003o`0000;oAIcd00CoTKG_o`000?na`NKo/L7V0_l000000ona`NKo
0000ok72iP03ok72iP;o00001Onlan<2o`0000Go_LWT00?o0000ol7<hoo1c><00_o1c><00ol0003o
a<kRolGAh`03olGAh`08o`000?o6e>Co0000o`000?o7dn?o0000olOEiOl00002olcHh`05o`000?o<
fnCoc=_TolcKi?l000000_o;g^H00ol0003odN3So`000003om7Si004om7UiOl0003oe^ORo`0000;o
e^gT00Go0000om_dgooKm=oo0000omShh@04o`000003olWm__l0003ooo]Z03Wooo]Z00?o0000oook
J_oonfX0EooonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z00Cooo]Z0ol00002ocN[
lPWo000000?oFKclo`000?l000001Ol000000omK_oco0000o`000008o`0000GoN/_o2?l00004oh7A
o`Ko00001_n8eol6o`000004oi3Lool0003oQ=gmo`0000CoP]kl1Ol00005om?Gg0;o00000_nea^L0
0ol0003oV[g`oiZml003oiZml004o`000?nJ_>ooV[c_oiZlk`Wo00001on:/O000ol0003oPZg`oh:]
l003oh:]l003o`000?mlZO3oO:W`00;oO:W`00?o0000ogJVl?mfY_001omfY_02o`0000KoJIk_2Ol0
0004oeFEk`;o00000_m2RN/4o`0000?o9W[U00Co0000obIjiOl0003o00008OoonfX00ol0003ooo]Z
oookJP0eoookJP03o`000?oonf[ooo]Z02_ooo]Z000YoookJP03o`000?oonf[ooo]Z05?ooo]Z00?o
01BPo`000?l0@/@00_l000001?lPI=So0000o`000?m6N]l2o`0000?oFhOS0ol00005og2Bh`;o0000
1OmmVnD01?l0003oP9_Soh2Khol00005ohNQi003o`000?n;X^?oRj;S00CoRj;S0_l00004oiFYh`?o
000000?oUJWSo`000?l000002?nK/>D00ol0003oX[?Uoj:ci@05o`0000?o[<K]00?o0000okGLm?ne
g?@01?l000001OoYPcGo0000on9lA?l0003odFe>00;o00000oo6HDh5o`0000;o^UeM3ol000000onK
@ESo0000oh4WCP03oh4WCPGo00000_mU6EL2o`000003of<JF_l0003o000000;o?P1C00Co0000ofJC
j?mVTnSoIY?X1?l00005ok71iP06o`000?na`^Ko0000o`000?nb`nKo00001?nlan<00ol0003o_LWT
okg9i003okg9i003o`000?nmc>Go000000Co`LcS00Co0000olGAhoo5dN?oaM7S0_l00002olKDi0?o
00000_o7eND00ol0003oc=SSolcHh`03olcKi003o`000?o;g^KobmkV00?o00000_oAhn@00ol0003o
dNGUom7Ui@02o`0000;oe^gT0_l000001?oKm=oo0000omShhOoHn>43o`0000;obOfn00?o0000oook
J_oonfX0>OoonfX00ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oook
J_oonfX02?oonfX00ol0K;;o0000o`000007o`0000;o<:g]0ol00002oeBmnP03o`000?mH`O_oF<7k
00GoF<7k2ol00002ogK<o`03o`000?n1dOooPM7o00;oPM7o2ol00003ohSGo`Ko00000omifO`5o`00
00?oPmkl0_l00005om?Gg0;o00001?nea^L01_l0003oV[g`oiZml?nJ_O3o0000oiZml0?o00000onI
^^l00ol0003oR[7`ohZal00;ohZal003o`000?n2[O3oPZg`00;oPZg`00?o0000ogbYl?mlZO000oml
ZO000ol0003oMZK`ogJVl007ogJVl0;o00002OmYW^l2o`0000?oFIC^1?l000000omEUNoo0000o`00
0004od:9j`Co000000Co9W[Uo`000?l0003o26GJ0ol0000NoookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000oookJ_oonfX0:_oonfX002Wooo]Z00?o0000oookJ_oonfX0E?oonfX2o`000005o`12a?l0
003o0000o`000?loN>401?l00004oe^7h`Go00000_m`T^<00ol0003oOI_UogfKi@04ogfKi@03o`00
0?n0Vn?o000000GoQj7T00Co0000oh^Rhon;X^?oRj;S2Ol00005oiFZi@03o`000?nK/>GoVk3U00Ko
Vk3U0ol00008ojc6k@Oo000000CojH<eo`000?l0003o00000ooAKDh01?l0003oaV5>o`000?l00003
ol=QD`Ko000000Co^UeMo`000?n_DU[o00002?nL?E46o`0000?oQ2mG00Co0000ofDIEol0003o0000
0_mS6UX3o`000003och0Dol0003o000000GoIY?X00?o0000oi6ekol000001Ona`NH00ol0003o//?V
ok;3iP02ok;3iP04o`000?nlan?o0000o`0000Co_LWT0_l00003okg<i@05o`000?o1c>?o0000ol7>
i?l000000_o5dN<00ol0003oa]CTolKDi002olKDi007o`000?o5eNKoaMGVo`000?o7eNGo0000olcH
h`02olcKi0;o00000oo;g^H01Ol0003od>CUom3TiOo@i>Go000000;odNGU0_l00002omK]i004o`00
0?oDknGo0000o`0000;of?SQ0ol000000oo9oKko0000o`00000loookJP03o`000?oonf[ooo]Z05Go
oo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0=oookJP04ocP00?l0003o0000o`bF
f@?o00000_lk/o49o`0000KoGlCl00?o0000of78nomQb?/01?mQb?/5o`0000GoJ]3l1?l00005of[A
n`?o00001?mifO`8o`000003oh?No?l0003oKm_b00;o00001OoCem`01?l0003od]?Jom;Cf_l00003
okG6i`Co00000_nH^o000ol0003oVK[_oiVjk`04oiVjk`03o`000?n:/O3oR[7`00_oR[7`5?l00000
0omfY_3o0000o`000009ofVNk`;o00001omIU>h3o`0000Go@XW[00?o0000obakiOl000000ol00003
o`QUfP;o00007?oonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02[ooo]Z000Xoook
JP03o`000?oonf[ooo]Z05Kooo]Z00Co0000o`0m`Ol0003o66;H0_l00003ocmhh@?o00000_mKQn<0
0ol0003oKICVoffDiP02offDiQGo00000on;Y>D01?l0003oSjSVohnXi_l00008oiFZi@03o`000?nK
/>GoVk3U00;oVk3U1?l000000onM]^Wo0000ojc6k@04ojc6k@?o000000?o]mK`o`000?o4lNl01_l0
00000ooNNDWo0000o`000002om5]CPGo00000oo3HE<00ol0003o[EEQojeEH@02ojeEH@go00001On5
<e`5o`0000?oHaYJ0ol000000oln05?o0000o`000005o`0000;oIY?X00Co0000oi6ekol0003o/L7V
0_l000000onb`^Ko0000ok;3iP03ok;3iP;o00001?nmbN@2o`0000Ko_LcU00Ko0000ol7>i?o1c^Co
`LkTo`000?o5dN<3olKDi0?o00000oo5eNH2o`0000?oc=_T1?o;g^H02Oo;h>So0000om3TiOo@i>Go
0000om3Wiol0003odNGUo`000002omK]i004o`000?oDknGo0000om_dg`;of?SQ00Coe_WQo`000?l0
003obOfn0_l0000moookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0
003ooo]ZoookJP0AoookJPCo00000olk/o46o`000003oeo4o?l0003o000000[o00001?mWbo`6o`00
00CoJ]7k2Ol00002ogWIo0So000000?oH]Cao`000?l000000ol00005om?Gg003o`000?oBdm[od]?J
00;od]?J00Go0000okG6iol0003o[lCYo`000005oiRkl003o`000?nI^^ooVK[_00CoVK[_00Co0000
ohZal?n:/O3oR[7`1_l00003ohZ_kP03o`000?n3[>ooPjc_00;oPjc_00?o0000ogfWk_mmYnh00omm
Ynh00ol0003oN:G_ogRUk`07ogRUk`03o`000?m_Wnko000000Go00000omYW^l00ol0003oG9K^o`00
0007oeVDkP03o`000?m8R^_o000000Co000000?o@XW[o`000?l/NnD00_l/NnD2o`0000Co26GJ0_l0
000JoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0:_oonfX002Sooo]Z00?o0000
oookJ_oonfX0EooonfX01Ol0003o03g1o`000?l0003o5f7G00;o000000Co?gSQo`000?mGRNKoEhWV
0_l000000omKQn?o0000offDiP04offDiP;o00001_mjV^H2o`0000OoQj?V00?o0000oh^TiOn;Y>D0
0_n;Y>D01Ol0003oSjSVohnXi_n?Z>Ko000000CoUJ[U2?l00003oinej005o`000?nM]^WoWKKYo`00
0?n/a^d00ol00003okOFl005o`000?o4lNoo0000o`000?oDoll00_l000001?o[RD7o0000o`000?oN
NDT4o`0000?ocg1J1?l000000oo3HE?o0000ojeEH@04ojeEH@;o00002?nXCEX00ol0003oQC=LohDc
G003ohDcG0?o00000omS6UX2o`000008of<MG_l0003o0000o`000?l[05Ko0000o`00=ol00004of6E
k0Go00001?nb`^H01?l0003o//?Vo`000?l00003ok?4i`03o`000?nmbNCo000000Ko_LcU00Co0000
okk>i_nnc^Ko00000_o1c^@01Ol0003oa]CTolKDi?o6e>Co000000;oaMGV00?o0000olGEi_o5eNH0
0_o5f>P00ol0003oc=_TolcKi003ol_NiP06o`000?o;h>Sobn3Xo`000?o@i>Go00000_o@inL3o`00
0005omK]i?l0003oe>oUomC_iOl000000_oHn>400ooFnN7o0000omCoeP04o`0003gooo]Z00?o0000
oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01Oooo]Z3Ol00002
ocJdjPGo000000?oIl_lo`000?l000003_l00004oeC:l003oeK<l?l0003o000000Co00000_mRe?40
1?l0003o=[c>ocJlc_lf_<h2o`000003oookJ_l0003odmOL00CodmOL00?o0000om;Cf_oBdmX01?oB
dmX01Ol0003o[lCYojo4jOn_a>Wo000000CoV;_`00?o0000oiVjkonI^^l00_nI^^l6o`0000[oRZo^
00?o0000oh>/kon3[>l00_n3[>l00ol0003oOJO^ogfWkP03ogfWkP03o`000?mhYNooN:G_00KoN:G_
00?o0000ofnOk_l000001Om[WNh9o`0000GoFIC^0_l00004odN9jP?o00000_l/NnD01?l0003o;7_U
o`000?l00002o`QUfP03o`000?l0CL[o000001Wooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003o
oo]ZoookJP0ZoookJP00:?oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?l0?L7o000000;o0000
00Co=7KQo`000?l0003o00001?mGRNH5o`0000;oKICV0_l00006ogZJiP;o00001on7XnH01?l0003o
RjCUoh^TiOl00002ohnXiPOo00001?nE[NL00ol0003oWkGXoinej003oinej003o`000?nM]^WoWKKY
00?o00001Onge_03o`000003omCocol0003o000000?o000000GojhU1o`000?l0003o0000omEfF004
o`000003olm`F_l0003o`faX00;o`faX1Ol000001On]EF7o0000ojM>GonWCUoo000000KoZ4eJ00?o
0000ohDcG?l000001?l00002ohThH@04o`000?mS6U[oHaYJo`0000?oHaeN0_l000000ol[05Ko0000
o`P0BP03o`0000GoHIG/00Co0000oiRhk_nH^>ko00001?nb`^H00ol0003o/lCWok?4i`03ok?4i`;o
00001?nmc>D2o`0000Go_/kV00?o0000ol;@i_l000000_o6e>@01?l0003oaMGVolGEi_o5eNH2o`00
00?oaMSX0_l00003ol_NiP04o`000?o;h>Sobn3Xol_Pj0;o00000_o@inL00ol0003oc^[YolkZj@02
o`000004omC_iOl0003oe?7Uo`0000;oe_WQ00?o0000omCoe_l000000ol0000noookJP03o`000?oo
nf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0OoookJP03oc800?l0
003o000000Co000000?o@[_`o`000?l000002?l00002od_3l0Ko00000_mDb_03oeK<l0Go00001?lb
^M@2o`0000Kooo]Z00?o0000om?Gg?oCem`00ooCem`00ol0003od]?Jom;CfP04om;CfP03olWGi?l0
003o[lCY00?o[lCY00?o0000oiRkl?nH^o001_l00004oiJhk`03o`000?n:[nkoRZo^00[oRZo^00Go
0000oh>/kon3[>ooPjc_o`000006ogfWkP03o`000?mhYNooN:G_00KoN:G_00?o0000ofnOk_l00000
2?m[WNh00ol0003oGiG/o`000002oebDk0Co000000CoFIC^o`000?m8R^_o00001Om7RNX00ol0003o
<W_Uo`000003o`000007oa1Wfol0003o0000o`QUf_l0003o04g:o`00000HoookJP03o`000?oonf[o
oo]Z03Kooo]Z00?o0000oookJ_oonfX0:_oonfX002Sooo]Z00?o0000oookJ_oonfX0F?oonfX01?l0
003o0432o`000?l>GmH2o`0000;o=7KQ0ol00002oeN9iP03o`000?mVT^So000000;oJ9;W4ol00000
0on7XnKo0000o`000003o`0000?oSjWW00?o0000oiF]ionE[NL01_nE[NL00ol0003oWkGXoinej005
o`0000;oXKGW00?o0000okOFl?nge_000onge_000ol0003oe?o?omCoc`08o`000003on62Eol0003o
000000;ofgmN00?o0000om1jJol000000_l00004ol=/J003o`000?ngHFOo]f5W00go00001on9>643
o`0000;oHaeN0ol000001?l[05Ko0000o`000?l804X3o`0000KoHIG/00?o0000oiRhk_l000000_l0
0002ok?3iP04o`000?nca>Oo/lCWok?4i`;o00000_nea^L01?l0003o_LcUo`000?l00005okk>iP03
o`000?nnd>Oo_]3W00;o000000?oa]CTolGEi_o5eNH00_o5eNH2o`0000CoaMSX00Go0000olWNj?l0
003obmkVo`000004ol_Pj004o`000?o@inOo0000o`0000;oc^[Y00?o0000om?ai_l000000ol00002
omKih@Ko0000?ooonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000
oookJ_oonfX0<OoonfX6o`0001Sooo]Z0_l00003om?Gg003o`000?oBdm[od]?J00;od]?J0_l00002
olWGi003o`000?n_a>Wo[lCY00;o[lCY0ol00002oiJik`03o`000?nF^>ooU[S_00KoU[S_00?o0000
ohZ_k_n:[nh01?n:[nh3o`0000?oRZo^5ol00008of^MkP03o`000?mOUNco000000KoG9C/1?l00005
odN9jP03o`000?lbNnGo<W_U00?o00000ol@Im/2o`000003o`1=b_l0003o000001Kooo]Z00?o0000
oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0ZoookJP00:?oonfX00ol0003ooo]ZoookJP1Ioook
JP03o`000?l0@<;o000000?o000000?o=7KQo`000?m?QnL00ol000001?mGRNKo0000ofJBj?l00003
ofRBi`03o`000?mdVnSo000000KoMi_X00?oP:;Xo`000?n4X^L01_n4X^L00ol0003oRjGVo`000006
ohnYi`03o`000?nE[NOoUJgW00CoUJgW1?l00002oinciP03o`000?nQ]NOoXKGW00?oXKGW00?o0000
okOFl?nge_000_l00002omCoc`03o`000?o/nKco000000Co000000CokYAGo`000?l0003ohH9G0_l0
00000ooKOeko0000om1jJ`03om1jJ`Co000000Go`faXo`000?ngHFOo]f5Wo`000004ojQAHP03o`00
0?nTDVWoY59Y00;oY59Y00?o0000ohThHOn9>6400_n9>645o`000006of<MG_l0003o0000o`000?mW
8fGoK2UY0_l000000olf1F?o0000o`000002o`000003o`00POl0003o000000Ko000000?oWkc]o`00
0?nc`nH00onc`nH3o`0000Co]LKW0_l00005okk>iP;o00001?nnd>L01?l0003oaMGVolGEi_o5eNH2
o`000008olGHj?l0003oaMSXolGHj?l0003oaM[Yo`000?o9g^P2o`0000;obn3X0_l000000oo:h^Wo
0000o`000003olkZj@03olg/j_l0003odo7V00;od?CX00?o0000omCkhOl000001_l00010oookJP03
o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP1?oookJP05
o`000?ok_Woo0000om?Gg?l000000ooBdmX2o`0000GobMOT1?l00002ojO>m004o`000?nF^NooU[W_
o`0000OoU[S_2?l00006oh^]k@05o`000?n4Z^goQ:[]ohBZkOl000001_mnY^d00ol0003oNZC]ogZT
k@05ogZTk@03o`000?maW^coLIk/00go00001_mLU>`00ol0003oCHWYodf9j@04o`000003odN9j_l0
003o<W_U00?o<W_U0ol00003oa1Wf`03o`000?l0C/_o04k;00;o00005?oonfX00ol0003ooo]Zoook
JP0foookJP03o`000?oonf[ooo]Z02[ooo]Z000XoookJP03o`000?oonf[ooo]Z05[ooo]Z0_l00000
0ol3FmCo0000obifhP03o`000004odn7iol0003oD8OVoe27iPKo000000CoJ9;Wo`000?mdVnSo0000
1OmgVnP00ol0003oP:;Xo`000007ohBRi`;o00001_n?ZNL00ol0003oUJgWoiF]i`04o`0000?oU[3Y
00Co0000oinci_nO/nKo00001?nQ]NL02?l0003oXKGWo`000?l0003o]/SXo`000?oDoloo00000_o/
nK`3o`000003ooVaJol0003o000000Co000000CogHQ]o`000?l0003o00000oo@NV/01?l0003o]V=]
okISKOnfHfd8o`0000;oZ55R00?o0000ojABJOnTDVT01_l00004ohhoIP;o00000omW8fD3o`000004
ocH5Hol0003o0000ob80J@;o000000?o0021o`000?moXNP01?moXNP01Ol0003oWkc]oinlkOnO_>go
000000;o/l?V0_l00004okG6i`;o000000?o]lSWo`000?nnc^H00_nnc^H2o`0000Co_]3W00Ko0000
okkBjOl0003o0000olGEi_l00003olGHj0?o000000CoaM[Yo`000?l0003o00000_o9hNT2o`0000;o
b^;Y00So0000olkZjOo>j^Woc^[Yo`000?o=k>[o0000om?aiP;od?CX00?oc_KXo`000?l000000_o>
oN43o`000003oj_a[Ooonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]Zoook
JP1HoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oo^nOook_Wl00ol000000ooBdm[o0000olWG
i006olWGi003o`000?nWc_CoYlkd00CoYlkd00Go0000oiJikonF^Noo0000oiJhk`05o`0000;oU;G^
00?o0000oh^]kOn;[Nd02_n;[Nd01?l0003oQ:[]ohBZkOl00007ogjVk@03o`000?mjY>goNZC]00Co
NZC]00Go0000og6Nk?maW^coLIk/o`000008ofjLk003o`000?mRU>_oHYC[00Go00000_mLU>`00ol0
003oCHWYo`000003od^9j@?o00000olbNnD00olbO>Go0000oaMXg002o`000004oa1Wfol0003o053=
o`1>b`;o02^a00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[o
oo]Z02[ooo]Z000WoookJP03o`000?oonf[ooo]Z05cooo]Z0_l000000ol3FmCo0000obifhP02obif
hPGo00000_mRT^T00ol0003oII?YofFCj@08o`000004ogNKj?l0003oP:;Xo`0000CoQ:;W3_l00008
oiJ`j@;o000000?oXKGWo`000?l000000_l00004oj_5k@?o00000oo/nK`4o`000005ooVaJol0003o
lImTo`000?oXUfh00_l00002omf8K@Co000000?od7Y[o`000?nfHfd00onfHfd2o`0000CoZEAW1Ol0
00000onUE6co0000ohhoIP04ohhoIP?o00001?mW8fD3o`0000;o=PES00Co0000ob80JOlR06Wo0000
0_l00842o`0000GoOj7X00?o0000oinlkOl000000ol000000oneaNKo0000okG6i`02okG6i`03o`00
0?ngb>Oo]lSW00;o]lSW00?o0000okk>i_l000001?nnd>L2o`0000;o_];Y0ol00003olGHj0;o0000
0oo5f^T01Ol0003obN7YolWQjOo9hNWo000000;obNC[0_l00002olkZj@05o`000?o=k>[ocNcZolg/
j_l000000_o@m>P00oo>m^So0000o`000002olkmh@?o000000?oZo6]oookJ_oonfX0@OoonfX00ol0
003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0C_oonfX01Ol0
003onkiooo^nOook_Woo000000;om=N`00?o0000olWGi?o9en@00oo9en@2o`000003ok[Nl_l0003o
Ylkd00KoYlkd1?l00008oiBekP03o`000?n;[NgoRjg]00WoRjg]00Go0000ohBZkOn4Z^goQ:[]o`00
0007ogjVk@03o`000?mjY>goNZC]00CoNZC]00Go0000og6Nk?maW^coLIk/o`000007ofjLk004o`00
0?mRU>_oHYC[o`0000CoH9?[1?l000000om=RNWo0000od^9j@03od^9j@03o`000?lkO^Go000000;o
000000Wo<WcUo`000?lGJ=co5fSLo`000?l@Im_o0000o`1@cOl0C//00_l0:k400ol0003ooo]Zoook
JP0@oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0:OoonfX002Oooo]Z00?o0000
oookJ_oonfX0GOoonfX5o`000005obifh_l0003oBHOXo`000?m;QnP00_l00002of:Bj@04o`000?mU
TnWoII?Yo`0000?oLY_Z00?o0000ogFLj_meW>X02?l00004oh>Tj@03o`000?n@ZnSoT:_X00KoT:_X
00?o0000oiJ`jOnF/>T01OnF/>T4o`0000SoZlG]0_l00003onci_0;o00000_onbH400ol0003onK5[
o`000002o`0000;oj9M^0_l000000ooMR6go0000olilL`02olilL`Go00000_nfHfd00ol0003oZEAW
ojUDI`06ojUDI`;o00000_n>?fH4o`0000;oTDM`00Co0000ofLSIOmW8fGoIb=U0_l000000omd=gKo
0000ocH5H`02o`0000;o8P1Y00?o0000o`00POl008400_l00003ognQj0Co00000onV/n801_l0003o
]LGVokG5i_l0003o]LKWo`0000Go]lSW0_l00003okk@i`;o00001?nnd^T03?l0003o`]SYol;HjOl0
003oaMSXo`000?o5f^Wo0000olGJjOl0003oaMc[o`0000;obN7Y00Co0000olWTjoo9i>_obNC[0_l0
00000oo>j^Wo0000olg/jP02olg/jP03o`000?o@m>Sod?CX00;oc_KX00Co0000olkmhOo>oN7obogQ
1?l00013oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]Z
oookJP1>oookJP04o`000?ok_Woonkiooo^nO`;o000000Gom=N`o`000?o]h<Co0000olWGi002o`00
00;o^]kb00?o0000ojO>m?nWc_@01OnWc_@01?nX_^WoU;K^oiBfk_l0000:oiBekP03o`000?n;[Ngo
Rjg]00CoRjg]1?l000000on;[Ngo0000o`00000Do`000003og6Nk?l0003oKYc/00KoKYc/00Co0000
of:DjomRU>_o00001OmPTn/00ol0003oDHWXo`000002o`0000?oBhWY00?o0000oc]niOlkO^D00_lk
O^D2o`0000?o5fSL0_l00002o`1@c@04o`000?l0:k7o02^ao`00017ooo]Z00?o0000oookJ_oonfX0
=ooonfX00ol0003ooo]ZoookJP0YoookJP009ooonfX00ol0003ooo]ZoookJP1NoookJP03o`000?l0
E]7o;7ST00Co000000?oBHOXo`000?m;QnP02?l00003og:KjP04o`000?meW>[oMIcZo`0000?oOj?Z
00?o0000oh>TjOn3Y>T01?n3Y>T2o`0000SoT:_X00?o0000oiJ`jOnF/>T01?l00002oiNcj`03o`00
0?n[aNgoZlG]00CoZlG]0ol000001onab^co0000o`000?o/nKco0000onWIa?l000000_onbH401Ol0
003onK5[o`000?oaZ7Ko000000;oj9M^00?o0000om^<Mol000000_l00003olilL`04o`000?nnKgKo
_Vmfoki_MPoo00001_nAAg001?l0003oIb=UofLSIOl00003og@gMP;o000000?oAQ]go`000?lR06T0
1?l00002odIF_`?o00000_nGYMl00ol0003oY[?RojJchP03ojJchP?o00001Ongb>L2o`0000;o^/gX
00?o0000okk@iol000001?nnd^T00ol0003o_mCZo`000002ol;Hj@;o00000_o5f^T2o`0000;oaMc[
00?o0000olWQjOo9i>/00_o9i>/2o`000003olOVkOl0003o000000;ocNcZ00Co0000olg]j_l0003o
d?CX0_o>m^P01?l0003oc_gQolkmhOo;oN44o`0004Cooo]Z00?o0000oookJ_oonfX0DooonfX00ol0
003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z04kooo]Z00Co0000oo^nOook_Woonkio0ol00003
ongPa005o`000?njg_;o^]kbok[Nl_l000001OnWc_@5ojRnj@03oiBfk_l0003oU;G^00OoU;G^2Ol0
0005oh^/j`04o`000?n5ZNcoQJW/o`0000SoOZ?[00?o0000ogbRjomlX^/00omlX^/01?l0003oLicZ
og>Lj_mcW>X>o`0000GoH9?[00Co0000oe69j?mARNSoDHWX0ol000000om;RNWo0000oc]ni@04oc]n
i@;o00000olGJ=`4o`0000;o02^a00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0goook
JP03o`000?oonf[ooo]Z02Wooo]Z000WoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000o`1FdOl0
00000ol/N>@2o`0000;oBhOX00Ko0000oejCjomNTn_oGY?[o`000?mQU>/9o`0000?oOj?Z00?o0000
oh>TjOn3Y>T01?n3Y>T2o`0000CoT:_X0ol000000on@ZnSo0000o`000006oiNcj`;o00000_n[aNd3
o`0000?o/L[/00?o0000okcIk_l000000_l000001?oYfLCo0000ook9POonbH43o`000005oo6XM_l0
003o0000onRGK_l000000ooKS7L2o`0000;ocWac00?o0000oki_M_nnKgH00onnKgH2o`0000So[F9h
00?o0000oi59L_nABG800ol00003oi57L0?o00000omd=gH2o`0000;oAQ]g0_l000001?m:=9Go0000
oc<UTOl00002odIF_`05o`000?nGYMooUjGOoiNUgol000001OnV/n801?nV`^ko]lOWokO7iol00002
okO8i`?o00001?njcNP2o`0000?o_];Y0_l00002okoDjP?o00000_o3fn/2o`000005olGLjol0003o
aMc[o`000?o9hNT00_o9i>/2o`0000?oanK]00?o0000olc]jol000000ol000000oo@m>Soc_KXolkf
j002o`0000;obogQ1?l00015oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0FOoo
nfX00ol0003ooo]ZoookJP1>oookJP;o000000Gonkioo`000?oobGCoolUdo`000003ongPa0;o0000
00?o^]kbo`000?nWc_@00_nWc_@9ojRnj@04oiBfk_l0003oU;G^oiBekPGo00000on@[n`00ol0003o
Rjc[oh^/j`09oh^/j`03o`000?n5ZNco000000WoOZ?[00?o0000ogbRjomlX^/00_mlX^/00ol0003o
LicZog>LjP03og>LjP03o`000?m`Vn_oL9_[00CoL9_[00Co0000ofFCjOmUTnWoII?Y1Ol000000omP
Tn_o0000oe69j002oe69j003o`000?m@RNSoD8WX00?o00001?lkO^D00ol0003o8F[Lo`000003o`00
0006o`1Bcol0003o0000o`0`]_l0:k7o00004OoonfX00ol0003ooo]ZoookJP0foookJP03o`000?oo
nf[ooo]Z02Wooo]Z000WoookJP03o`000?oonf[ooo]Z063ooo]Z1_l000000om4Q^Wo0000o`000004
o`000003oejCjol0003o000000CoKic/00?o0000og>Nk?mcW^`04Ol00004ohj]j`03o`000?nG/n_o
Uk?[00KoUk?[0ol00006ok7:k0;o00000oo8dN04o`0000;on;b800Co0000oo6XM_l0003oiiin0_l0
0003om^<M`03o`000?o;Ogco000000?o00000onnKgH01?l0003o]6AbokATL_l00007ojeRN003o`00
0?nABG;oTDUb00Oo00000omd=gH2o`000005ogY3P_l0003oAQ]godHKMol000000_m:=9D2o`0000;o
T7nl0_m6E[l00ol0003oUjGOo`000003ojJchPGoY/;^00Co]lOWo`000?ngb>Oo00001OnjcNP2o`00
00;o^]7[00?o0000okkBjOl000000onoe>X2o`0000?o`m_[00?o0000ol;Lk?o2g>`00_l000001Oo5
g>_o0000olWTjoo9i>_o000000CoanK]00?o0000olc]jol000000oo9l>d2o`000003olkfj?l0003o
000000;obogQ1?l00016oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0F?oonfX0
0ol0003ooo]ZoookJP1?oookJP04o`000?oj[ego0000o`0000;oolUd00Co0000ongPa?o]h<Co0000
0_oWn[800ol0003oYlkdojRnj@0<ojRnj@?o00002On@[n`00ol0003oRjc[oh^/j`09oh^/j`;o0000
2_mnXn/00ol0003oO:;[ogbRj`02ogbRj`03o`000?mcW>[oLicZ00?oLicZ00?o0000og2Kjom`Vn/0
0om`Vn/00ol0003oII?YofFCj@02ofFCj@04o`000?mSTnWoHi?Yof>Cj@Go000000KoDHWXo`000?m@
RNSoD8WXo`000?lmO><3o`0000;o>gkU00Co0000ob5Zg?lQJ]co8F[L0_l00002o`1Bc`04o`000?l0
<;Ko02^ao`00013ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0YoookJP009ooo
nfX00ol0003ooo]ZoookJP1QoookJP[o00000omKTn`3o`0000CoKic/00?o0000og>Nk?l000001?mm
Y>`00ol0003oPZK[oh:Vj`03oh:Vj`04o`000?n8Z^_oR:[[o`0000OoSZg[00?o0000oiNcjonG/n/0
0_nG/n/4o`000003oiVgkOl0003o/L[/00?o/L[/0_l00003olSAh003o`000?o?c=OoclcG00;oclcG
00?o0000ooRlR?oh_8P00ol00002onNNOP;o00000_oKS7L00ol0003obgmlol]oO002ol]oO1;o0000
1OnDD7X00ol0003oM3Mfog@gMP02o`0000?oNT>200Co0000odHKMol0003o00000_m:=9D00ol0003o
T7nloi1o_004oi1o_003o`000?nV/n;oY/;^00SoY/;^00?o0000ok[=j?njcNP00_njcNP3o`0000Go
^]7[00?o0000okoDj_noe>X00_noe>X00ol0003o`m_[ol?Kj`02o`0000Co`]c/00Go0000olGNk?l0
003obNC[o`000003olOVk@04o`000?o6inko0000o`0000?obO3]00?o0000olcgjOl000000_l00000
0oo;oN7o0000o`000003o`0004Oooo]Z00?o0000oookJ_oonfX0DooonfX00ol0003ooo]ZoookJP1H
oookJP03o`000?oonf[ooo]Z04oooo]Z00Co0000ooZ_GOoj[ego00000_oobG@00ol0003okN34o`00
0003onOj/P03o`000?ndcNco000000KoZ;kY1?l00002oibnl003o`000?n@[ncoT:o/00[oT:o/00?o
0000oh^/jon;[>/01?n;[>/4o`000003oh^/jol0003o000001?o000000?oLicZo`000?m`Vn/01Om`
Vn/00ol0003oII?YofFCj@02ofFCj@03o`000?mSTnWoHi?Y00;oHi?Y00?o0000oeF8i_mER>H00ol0
0002oe29j004o`000?lmO>?o?GcSocelh`;o000000?o>gkUo`000?lQJ]`00olQJ]`01Ol0003o05;?
o`1Bcol0003o032f00;o00003ooonfX00ol0003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z02Wo
oo]Z000WoookJP03o`000?oonf[ooo]Z06;ooo]Z00?o0000o`1BcOl000000_l00002ocj6jP?o0000
0omKTn`00ol0003oGYG]o`000007o`0000CoOJC/00?o0000oh:Vjon2Y^/00on2Y^/00ol0003oR:[[
o`00000<o`0000?oV[K/00Go0000oiVgkOnI]ngo0000ok7:k002o`000005ok70iOl0003ob=7PolSA
h?l000001?o?c=L2om;<e0;o00000_o_/Xh2o`000003onNNO_l0003ofI:400?o00001?o;Og`Eo`00
00;oU51j0ol00005ogY3PP;o00000_mN?Y<3o`0000KoT7nl00?oV[?Yo`000?nV`^h01?nV`^h3o`00
0003ok31i_l0003o000000;o^/gX00?o0000ok[AjonjdN/00onjdN/2o`0000;o^m?/00Oo0000okoD
j_l0003o_mO[o`000?o3fn_o000000Co`]c/00?o0000ol7Ok_l000000_l00003olOVk@;o000000?o
a^O^o`000?l000000oo9l>d01?o7lNko0000o`000?o7nNX2o`000003okgmg_l0003o[?O500;o0000
BOoonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0
CooonfX01Ol0003onZmMooZ_GOl0003oolUd00?o000000Gooo]ZonOj/_oWn[;oioZbo`000002okC=
k003o`000?nX_^WoZ;kY00?o00001OnL__000ol0003oW;CYo`000009oi2_k0Wo00001On<Z^T00ol0
003oPJ?Zoh6SjP09oh6SjP05o`000?mmXN[oOJ7ZogfQj_l000001?mfVnP<o`000003ofFCjOl0003o
Hi?Y00?oHi?Y00?o0000oeF8i_mER>H00omER>H3o`0000Ko?GcS0_l00003ob5Zg006o`000?l:F]?o
0000o`1Dd?l0=;[o032f0_l0000>oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0
:OoonfX002Kooo]Z00?o0000oookJ_oonfX0I?oonfX01Ol0003o04o9o`000?lHLN7o000000;o?XKZ
00?o0000od27j_l000000_l000000omKTnco0000o`000005offMkP03o`000?maWngo000000_o0000
0_n7Znd00ol0003oSZk/ohj^k005ohj^k003o`000?nJ]^coV[K/00?oV[K/1Ol00004ok70i@;o0000
0oo?c=L01?l0003od/cDom;<e?oBc=@2o`000003onnbS_l0003o000002_o00000omN?Y<4o`0000Go
T7nl0_nJ/nT00ol0003oY/;^o`000002o`0000?o/<7V00Co0000ok;;kOl0003o00001?njdN/3o`00
00Go^m?/0ol000000oo3fn_o`]c/ol;Lk002ol;Lk0;o00000_o1gnh2o`000004olGWk_l0003oanK]
o`0000?oa^O^00Go0000olW`kOo9l>go0000olOakP02o`000003olOij_o4nN[o000000;o_OgN00?o
[?O5o`000?l00000B_oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z05Sooo]Z00?o
0000oookJ_oonfX0CooonfX00ol0003onZmMooZ_G@04o`0000CoioZb0_l00002okC=k0?o00002?nL
__001?l0003oW;CYoibdjOl00003oi2_k0Go00000onB[NP00ol0003oS:[YohbZj@08ohbZj@;o0000
2on1XnX01?l0003oOJ7ZogfQj_l00006ogJKj003o`000?mcV^WoLi[Y00?oLi[Y00Co0000ofRBiomX
T^OoJ9;W1_l000000omSTnWo0000oeF8iP03oeF8iP?oE8WW0_l00004ocelh`;o000000co:6cLo`00
0?lQJ]co8F[Lo`000?l:F]?o0000o`1Dd?l0=;[o00bHo`06T?l0000=oookJP03o`000?oonf[ooo]Z
03Kooo]Z00?o0000oookJ_oonfX0:OoonfX002Kooo]Z00?o0000oookJ_oonfX0IOoonfX01?l0003o
04o9o`000?lHLN45o`0000?oEYC^1_l00002offMkP;o00001OmkYNh01Ol0003oPJO]oh6WkOn1Yngo
000000CoQj_]00?o0000ohj^k?n>[^`01On>[^`00ol0003oV[K/o`000002o`000003oibhk?l0003o
VkW]00;oVkW]00?o0000ok70iOna`>D00_l00003olo<e`So00000olQ000jo`0000Ko/<7V0_l00002
ok;8j`04o`000?njdN_o0000o`0000Go^m?/0_l00003ok_Fk@04o`000?o2g>co`]c/ol;Lk0;o0000
1?o1gnh00ol0003oaNO^olGWkP02o`0000?oa^O^00?o0000olW`kOl000000_o7lNh01Ol0003oaoWZ
olOij_o4nN[o000000;o_OgN00?o[?O5o`000?l00000BooonfX00ol0003ooo]ZoookJP1BoookJP03
o`000?oonf[ooo]Z05Sooo]Z00?o0000oookJ_oonfX0D?oonfX01?l0003onZmMo`000?og/TD2o`00
0003oookJ_oWn[;oioZb00;o000000?o]<g/o`000?l000000_nUf_X00ol0003oW;k`oibnl006oibn
l003o`000?nL]>Wo000000Co00002OnB[NP00ol0003oS:[YohbZj@06ohbZj@04o`000?n7Y^SoQjKX
o`0000_oPJ?Z00?o0000ogfQj_l000001omfVnP00ol0003oLi[Yog>Jj@02og>Jj@03o`000?mXT^Oo
J9;W00?oJ9;W00Co0000ofJBj?mVT^SoIY;X1?l00003oeF8iP;oE8WW00?o0000od9lh_l000000_l0
0002ocelh`;o00000_lXK=`00olQJ]co0000o`YJd`02o`YJd`04o`000?l0=;[o00bHo`0000gooo]Z
00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0XoookJP009_oonfX00ol0003ooo]Zoook
JP1VoookJPGo000000Co>8K[o`000?l0003o00001?mFU>h00ol0003oJYk_ofZNk`02ofZNk`Oo0000
0_mkYNh01Ol0003oPJO]oh6WkOn1Yngo000000;oQj_]2ol00005oibhk003o`000?nK^Ngo000003So
000000?oH`00o`000?l000000ol000000om`003o0000o`00000;o`000003ojF[fol0003o/<7V00?o
/<7V00?o0000ok;8jonbb>/00_nbb>/2o`0000Co^m?/0ol00004ok_Fk@05o`000?nngNoo0000ol;L
k?l000001?o1gnh01Ol0003o`N7_o`000?o5inko000000;oa>W_0ol000001_o9l>go0000olOak_o7
lNko0000olOijP;oa?WZ00Co0000okgmg_l0003oZ?K50_l0001<oookJP03o`000?oonf[ooo]Z05;o
oo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP1@oookJP?o000000?omk95o`000?l0
00000_oWn[84o`0000GoYM[j00Co0000oibnl?nL__3oW;k`0_l000001?nL__3o0000o`000?l00002
oibgj`03o`000?nB[NSoTZgX00[oTZgX00?o0000ohbZjOn<Z^T01On<Z^T00ol0003oQjKXo`00000<
o`000003oh6Sj_l0003o000000Go00000omfVnP01Ol0003oLi[Yog>JjOmcV^Wo000000KoJ9;W00Go
0000ofJBj?mVT^SoIY;Xo`000002oe^;iPCo000000?oE8WWo`000?m2O>800om2O>84o`0000Co:6cL
0_l00002o`YJd`04o`000?l0=;[o00bHo`0000cooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003o
oo]ZoookJP0XoookJP009_oonfX00ol0003ooo]ZoookJP1WoookJP03o`0NV?l0003o000000;o0000
0_lhQ^/5o`000003oeJDk_l0003oJYk_00CoJYk_0_l00004ogVVk`So00000_n6[Nh00ol0003oS[3^
ohj`kP06ohj`kP03o`000?nL^>coW;S/01co00001OmY00000ol0003oM@00ogD00002ogD000Co0000
1?mc00001?l0003oO`00ogl00?mo0003o`0000OoO0006Ol00002ok?7j@03o`000?nbb>_o000000;o
00000_nfcnd01?l0003o^m?/o`000?l00005ok_Fk@04o`000?nkf>oo0000okkMk`;o00000_o1gnh2
o`0000;o`N7_0ol00002olCYk`03o`000?o2jo7o`^_a00;o000000Coao7^o`000?o7l^ko00000_o4
nNX01?l0003o_OgNo`000?nXm/D2o`0004gooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]Z
oookJP1IoookJP03o`000?oonf[ooo]Z053ooo]Z0ol000001?og/TGo0000oookJ_oWn[83o`000003
okofkol0003oYM[j00GoYM[j0ol00003oiZhk@03o`000?nL]n_oW;O[00?oW;O[00?o0000oi:]j?nB
[NP01onB[NP00ol0003oTZgXoi:]j009o`0000;oR:CW00?o0000oh>Rion3X^L02On3X^L2o`0000Go
MiWV2_l00005ofRBi`04o`000?mVT^SoIY;Xo`0000KoFh_V00?o0000oeB9iol000001_m2O>800ol0
003o:6cLobQ/g002obQ/g0;o3EOA00Oo0000o`YJdol0>[oo03Zoo`0d^_l039So000000_ooo]Z00?o
0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0XoookJP009_oonfX00ol0003ooo]ZoookJP1X
oookJPKo000000?o>8K[ocZ7jol000000_mBU>l7o`000003ofZNkol0003o000000KoNJK_00Co0000
ognYkomoZNoo00001?n6[Nh00ol0003oS[3^ohj`kP02ohj`kP[o000000?o4@00o`000?l000002_l0
0004oeX000Ko00001?mY000Ko`0000;oO00000Co0000ohL00?l0003o00001_n70@02o`000003ohP0
0?l0003o000000Co000000?oM000o`000?l000002?l00004okK?k@;o00001?nke^d2o`0000;o^mS_
0ol00002okkPl0;o00001?o1hNl2o`000003olCYkol0003o000000;o`^_a00?o0000olCckol00000
0_o0m?001?l0003oa?WZo`000?o4n^T2o`000003ojSfaOl0003ooo]Z04kooo]Z00?o0000oookJ_oo
nfX0DOoonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z053ooo]Z0ol000000oog/TGo
0000onOj/P03o`000003okofkol0003oYM[j00GoYM[j00?oZ[kXo`000?nJ^>d00onJ^>d00ol0003o
W;O[oibgj`05oibgj`04o`000?nB[NSoTZgXoi:]j0Go00000onBZnL00ol0003oS:SXohbXj004ohbX
j003o`000?n8Y>OoR:CW00;oR:CW00?o0000oh>Rion3X^L02On3X^L00ol0003oMiWVogNIiP07ogNI
iP?oMI[W00?o0000offDi_m]U>H01_l00002ofJBj003o`000?mKRnKoFh_V00GoFh_V0ol00005od9l
hP?o00000_lXK=`00ol0003o3EOAo`eGd@02o`0000;o03Zo00?o01:Oo`000?l000002_oonfX00ol0
003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Sooo]Z000VoookJP03o`000?oonf[ooo]Z06Wo
oo]Z00Ko01ZCo`000?l0003o1fkMo`000?lbQN/4o`0000;oDYC_00?o0000ofNOlOmWWo400_mWWo4F
o`0000?oSK;_2_l000000olb003o0000o`000003o`0000?oFP004_l0000;ohD?6P;o00002On>5aX>
o`0000;oQ`4000?o0000ohP00?l000000on=0`0@o`0000;o]]C`00Co0000ok_FkOl0003o00001?nk
f>l00ol0003o_^3`okkPl002o`0000;o_^7a00Go0000ol7Qkoo1hNoo0000olCYk`02o`0000?o`^_a
0ol00002ol3dl0;o000000?o^O[Zo`000?l000000ol0001@oookJP03o`000?oonf[ooo]Z057ooo]Z
00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP1@oookJP03o`000?o]TB?o000000Co0000
0_nom^l00ol0003oYM[jojGJnP02ojGJnPGoZ[kX00Go0000oiZhkOnJ^>goV[S]o`000003oibgj`So
00002OnBZnL00ol0003oS:SXohbXj003ohbXj003o`000?n8Y>OoR:CW00?oR:CW00?o0000oh>Rion3
X^L02?n3X^L00ol0003oMiWVogNIiP08ogNIiP;oMI[W00?o0000offDi_m]U>H01Om]U>H6o`0000Ko
Fh_V00?o0000odYmhOl000000_l00002od9lhP;o000000Go<6kLo`000?l0003o:6cLo`000003o`eG
d@05o`000?l0>[oo03Zoo`0BWol000002_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[o
oo]Z02Sooo]Z000UoookJP03o`000?oonf[ooo]Z06_ooo]Z00Co01ZCo`000?l0003o1fkM0_l00000
1olbQN_o0000odfEl?m=UO3o0000oe:Dkol000001_mWWo400ol0003oN:SaogRXl@04ogRXl@04o`00
0?mnZo3oOZ_`o`0000CoQJk`00?o0000ohfbkon=/^l02?l000000olb003o0000o`00000=o`0000?o
L00A00?o0000ogT55_mi1AH02?mi1AH00ol0003oQ@hHohD>6003o`0000OoQ@lJ00?o0000ohhF6?n>
5QP00_l00009ohhG6P;o00001_nF71L2o`0000;oVA`@2Ol000001?n=0`3o0000o`000?n<000?o`00
00Go^mS_00Co0000okkPl?l0003o00001OnnhO42o`0000;oa>W_00?o0000ol;[lOo2jo400ol00003
ol3dl0;o00000_nin^X3o`0005?ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1I
oookJP03o`000?oonf[ooo]Z057ooo]Z1_l000001?nom^oo0000ojGJn_nUf_X9ojZnj003o`000?nJ
^>go000000Co00001OnH/>P00ol0003oTZ_Woi:[i`0:oi:[i`05o`000?n<Z>SoS:SXohbXj?l00000
1_n8Y>L00ol0003oPj;Woh>Ri`08oh>Ri`03o`000?mgVNKoMiWV00WoMiWV0_meV^L00ol0003oKICV
offDiP05offDiP03o`000?mXTNKo000000;oGhSS0ol00003oe^;iP03o`000?m:ON7oBWgQ00;oBWgQ
0_l000000om2O>;o0000o`000003oc1^g0;o00000ol=Em400ol0003o03Zoo`0j_`02o`0000Wooo]Z
00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0XoookJP009OoonfX00ol0003ooo]Zoook
JP1]oookJPOo00001?m=UO05o`0000;oIioa00?o0000ogRXlOmhZ?401?mhZ?401?l0003oOZ_`ogj[
l?l00002ohF^l0Ko00000_lM0007o`000003odd00?l0003o000000?o00001om`01<5o`0000CoN@DF
:?l00002oiHL5`;o00000_nI71001Ol0003oXBDEoj4U5OnQ9AGo000000;oWQd85_l000001?nkf_3o
0000okkPl?l00005okkQl@03o`000?nlho?o000000;o000000Co`^_ao`000?l0003o`Nca0_l00003
ol3dl0;o00000_nin^X00on/nMWo0000o`00001DoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000
oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP1AoookJPCo00000_lO00000ol0003oZ[kXojZnj00;
ojZnj0;o00002_nH/>P00ol0003oTZ_Woi:[i`07oi:[i`03o`000?nBZnOoTZ_W01go00001?mgVNH0
0ol0003oMI[Wo`000008offDiP;o00001OmOR><4o`0000OoBWgQ0ol00002oc1^g0;o5EWB00?o0000
o`eGdOl=Em400_l000001?l0>[oo0000o`000?l00008oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o
0000oookJ_oonfX0:?oonfX002Gooo]Z00?o0000oookJ_oonfX0K_oonfX00ol0003o06cKo`1[f`07
o`000003odfEl?mBV?7o000000;oI:7b4Ol000000olM003o0000o`000003o`000003oc`00?l0003o
C@0000Go00000omR00h00ol0003oL00Cog004`04og004`_o00001?n87S800ol0003oTRPgoi8X=`06
oi8X=`;o00000_nB9S<00ol0003oV2`foiP/=P05oiP/=P;o00001?nL;S<01Ol0003oXcHgoj<f=onS
=SOo000000CoY3@a2_l000000onQ9AGo0000oihM2005oihM2003o`000?nR8P[o000000?o00001?nD
1`04o`000003og`00?l0003o000000?o00000_nnhO43o`0000?o_>?c00?o0000okk/lol000000_l0
00001oo1k?7o0000ol3dl?o0m?3o0000okodl?l000000_nin^X01?l0003oZoWIo`000?l0001Eoook
JP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP03oook
JPKo0000B?oonfX01Ol0003ohWl9o`000?l0003o7`0000;oXmgl00?o0000ojZnj?nZ_^P01?nZ_^P4
o`0000;oWk_]0_l0000;oiR`j004o`000?nBZnOoTZ_Woi:[i`Go00000onBZNH01?l0003oSJOVohfW
i_l00007ohNQi@03o`000?n5XNKoQJ7V00OoQJ7V0_l00006og^Ji@go00000om]U>H2o`0000OoGhSS
0ol00005odYmh@03o`000?lfK]_o=VkK00;o000000Ko<6kLoaEId_lEFM;o0000o`eGdOl00002o`0o
``04o`0j_ol04Yoo0000o`0000Sooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0X
oookJP009OoonfX00ol0003ooo]ZoookJP1_oookJP;o000000Oo06_Ko`000?lUQN[o0000obj6jol0
003oBIKa00Ko00000omTXO800ol0003oMZWcogJYl`02ogJYl`Wo00000oll0005o`0000OoHP0>00?o
0000og004ol000001Ol00003ogdF<`03o`000?n883KoR20f00CoR20f0ol000000on87S;o0000oi8X
=`0:oi8X=`;o00002_nH;3H01?l0003oW2hcoi`^<ol00005oj<f=`03o`000?nT=37oY3@a00KoY3@a
00?o0000ojXk=OnZ>cD00_nZ>cD7o`0000;oWQd800?o0000oj8R2_l000000_nU9@`5o`000003oi@7
0?l0003oV0T000Wo00001?nlho<00onnk??o0000o`000002ok_]m0Go000000?o_oC`o`000?nin^X0
0_l000000on[nMWo0000o`00001FoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0
FOoonfX01?l0003ooo]ZoookJ_oonfX2o`000003ok34jOl0003oR[Od00;oR[Od00?o6hGYo`000?l0
00000_l00014oookJP?o000000?o^H00o`000?nSgO`00_nSgO`00ol0003oZ[kXojZnj003o`0000Ko
Wk_]00?oW[?Wo`000?nH/>P02?nH/>P6o`0000WoTZWV00?o0000ohfWi_l000002?n7XND00ol0003o
QJ7VohFQiP06ohFQiP03o`000?mnVnCo000000_oNi[U00?o0000og2Bhom`T^<01?m`T^<5o`0000So
GhSS00?o0000odmmgol000000_l00002odYmh@03o`000?lfK]_o=VkK00;o=foL0_l00003oaEIdP07
o`eGdOl0003o03o3o`0o`ol0003o_U00o`000008oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000
oookJ_oonfX09ooonfX002Gooo]Z00?o0000oookJ_oonfX0LOoonfX3o`000003obF5j_l0003o0000
00Go00001?mQX_@00ol0003oI:7bo`000007o`000003obT00?l0003o?00000Go00000_mF00X00ol0
003oHP0>of803P03of803PKo00002?mm5S<00ol0003oR20fohPP=P03ohPP=RKo00000_nS=SL00ol0
003oY3@aoj@d<@04oj@d<@03o`000?nZ>cCo000000KoZS/e00Co0000ojhk;_n^>bko[S/^1_l00003
ojDU3003o`000?nZ:@WoZRT9017o00000onkkO@3o`0000;o]_Gb2?l0001GoookJP03o`000?oonf[o
oo]Z053ooo]Z00?o0000oookJ_oonfX0FOoonfX01?l0003ooo]Zo`000?l00004ok34j@05o`000?n:
]oCoR[OdohZgm?l000000olKQNT2o`00047ooo]Z00?o0000o`00<ol000000ol00004oj?Mo0;o0000
2?nO^nd3oijci`03o`000?nH/>SoV;3X00Ko00000onH[>D00ol0003oTZWVoi:YiP09oi:YiP;o0000
2_n7XND00ol0003oQJ7VohFQiP04ohFQiP05o`000?mnVnCoOY_TogjKi?l000002_mkV^D2o`0000Wo
L9;S00?o0000of>8hOmSR>401_mOR><2o`0000?oCggO00Co0000odYmhOm:ON7o00000_lfK]/3ocM_
g004o`000?lEFM;o5EWBoaEIdP;o00000_l0?l<3o`0000Oooo]Z00?o0000oookJ_oonfX0=ooonfX0
0ol0003ooo]ZoookJP0WoookJP009OoonfX00ol0003ooo]ZoookJP1boookJPGo00000_lWQ^/01?l0
003oA9Obo`000?l00004of6Rm0Ko000000?o:@00o`000?l000000ol000000omF00[o0000o`00000@
o`0000GoOAHc2Ol00006oi0cCP03o`000?nJ?57oVSaA00[oVSaA0_l0000;oj=1CP03o`000?nYB53o
ZDQ@00?oZDQ@3ol00004ojXk=@03o`000?n^>bko[S/^00?o[S/^0_l000000one@Rko0000o`000003
o`0000CoZRT900?o0000ojTU0?l000000_l000000onC0P3o0000o`000008o`000003okW^mOl0003o
000000;o]_Gb00Co0000ojoij?l0003oZ_SW0_nElM000ol0003ooo]ZoookJP1GoookJP03o`000?oo
nf[ooo]Z04oooo]Z00?o0000oookJ_oonfX0F_oonfX3o`0000Ko/<CY00?o0000ohZgm?n:]o@00_l0
0003oa^5j@;o0000?ooonfX2o`000003o`00<ol0003o000000;o00000onSgO`2ojVoj@03o`000?nO
^ngoWk_]00GoWk_]00?oW[?Wo`000?l000001?l0000:oiR/i@03o`000?nBZNKoTZWV00WoTZWV00?o
0000ohNQiOn7XND00on7XNDGo`0000?oNi[U00?o0000og>Chol000002Om`T^<2o`0000CoHhSQ0omO
R><00ol0003oCggOo`000005odmmg`;o00000_lfK]/2ocM_g0;o7E_B0_lEFM82o`0000;o03o300?o
01fZo`000?l000001ooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Oooo]Z000T
oookJP03o`000?oonf[ooo]Z07Gooo]Z2?l000000om4Uo;o0000o`000005o`000003obT00?l0003o
000000Oo00000_mD00H5o`0000SoL`d_00?o0000ogdE<Ol000001Ol00003ohT/C003o`000?n@<dko
T3=>00WoT3=>0_l0000:oiXlD@04o`000?nR@U7oXT9Ao`0000[oXd5>00?o0000ojU8D?nYB5001onY
B5001Ol0003o[DU=oje9COn]BDgo000000?o/dm?00?o0000okA>BOndCTT01_l00003ojhk;P04o`00
0?nc@S7o/d8ao`0000Co]D8^1?l00002ojXY2@04o`000?nY9@3oZBD0ojTU00Go00000_nJ2P05o`00
00;o]_Gb1?l000000onZn>OoUO7@o`00001KoookJP03o`000?oonf[ooo]Z04oooo]Z00?o0000oook
J_oonfX0EooonfX3o`0000?o/<CX00?o0000ok34jOn`a>T00on`a>T3o`0000?oT[[c0ol000000ooa
XFOo0000oookJP0loookJP04o`000?lR05;o0000o`00<`Co00001_nY_nT01?l0003oWk_]oinkkOl0
0002oinkk@;o00000onN/^H00ol0003oV:cUoiR/i@0:oiR/i@03o`000?nBZNKoTZWV00CoTZWV1?l0
00000onBZNKo0000o`000004o`0000KoRJ7T00?o0000ohJPi?n6X>@00on6X>@00ol0003oP9[Roh2J
hP02oh2JhP03o`000?mmVN?oOIWS00?oOIWS2Ol00006og2Bh`03o`000?mTRN7o000000KoHhSQ0ol0
0005odmmg`03o`000?loL]co000000;o000000_o=foLo`000?lMFm;o7E_BoaEId_l0003o04;4o`00
0?l0?l?o0000o`0MZP02o`0000Kooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP0W
oookJP009?oonfX00ol0003ooo]ZoookJP1foookJQ;o00000_m300000ol0003oE006o`000004o`00
00;oI`4Z00?o0000og<=;omc3Bl01?mc3Bl6o`0000GoRBe=1?l0000;oi0cCP04o`000?nJ>e3oVS]@
o`0000GoVSaA5?l00009ojU8D003o`000?n]BDgo000000Go/dm?00?o0000okA>BOndCTT01?ndCTT7
o`000003ok=2<Ol0003o]D8^00?o]D8^00?o0000okI09onf@2L01?l00002ojTU0003o`000?n_;@Co
000000?o00000onJ2P07o`000004oj[hionElM3o0000o`0005gooo]Z00?o0000oookJ_oonfX0C_oo
nfX00ol0003ooo]ZoookJP1EoookJP;o00001on`a>P00ol0003o/<CYo`000002o`0000;o/LCX00?o
0000oi:jlonB^_<00_nB^_<2o`0000;olJ5W0_l0000joookJP05o`000?lR05;o8P1Bo`000?l003<0
1?l00007ojVoj@;o000000?oWkGXo`000?nN/^H01_nN/^H00ol0003oV:cUoiR/i@07oiR/i@03o`00
0?nH[>GoV:cU00Ko00001OnBYn@00ol0003oRJ7TohVQi00:ohVQi003o`000?n6X>CoQZ3T00;oQZ3T
00?o0000oh2Jh_n0V^800on0V^800ol0003oOIWSogfIh`05ogfIh`04o`000?mdT^7oM9;Qo`0000;o
LY7R1?l00002og2Bh`03o`000?mTRN7o000000KoHhSQ00?o0000oeAmg_mDOMh00_l00003odmmg`03
o`000?loL]co?g;L00;o?g;L00?o0000ocM_g?l000000_lMFm801OlEFM;o0000o`14aOl0A<Go03o3
00Co00001OoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Oooo]Z000ToookJP03
o`000?oonf[ooo]Z07Sooo]Z00?o03RUo`000?l000001?l000000olB003o0000o`000003o`0000;o
@`001Ol00006ofL1:P03o`000?mc3BooL`d_00Go00000omo94X00ol0003oRBe=ohT]C@08ohT]C@03
o`000?n@<dkoT3=>00?oT3=>3ol00004oj9=I005o`000?nXDfGoZ5=UojQCIOl000002?nZDf@00ol0
003o/5UUok1II@0@o`0000;o/dm?00?o0000okA>BOndCTT01OndCTT2o`0000?o^E=;1Ol00002okE2
;P03o`000?nf@2Oo]T0W00;o]T0W1ol00002ojl/0`?o000000CoVPX0o`000?nJ203oVPP00ol00000
0onElM3o0000oookJP1NoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0DooonfX2
o`0000?o^lKR00?o0000ok34j?n`a>P01?n`a>P2o`0000Go/LCX00Ko0000oi:jlonB^_?o0000oi:j
lol00003oo6QI`?o0000=_oonfX2o`0000;o8P1B00?o0000o`00<ol000000_l000000ol005co0000
o`000002ojVoj@?o000000CoX[[Zo`000?nO]NSo00002OnN/^H01?l0003oV:cUoiR/iOnH[>D5o`00
00?oUj[S00?o0000oi:Wi?nBYn@01onBYn@00ol0003oSj?Ro`00000<ohVQi004o`000?n6X>CoQZ3T
o`0000OoP9[R00?o0000ogfIhommVN<01?mmVN<01Ol0003oM9;QogBBhOmdT^7o000000KoLY7R1ol0
0003of>8h@03o`000?mDOMkoE7gN00;oDgkN0_l000000om?OMoo0000ocmbg003ocmbg004o`000?lj
Km[o0000o`0000;o7E_B0_l00002o`14a@Co00001OoonfX00ol0003ooo]ZoookJP0goookJP03o`00
0?oonf[ooo]Z02Oooo]Z000ToookJP03o`000?oonf[ooo]Z07Oooo]Z1Ol000000olB003o0000o`00
0003o`0000;o@`000ol00002oeP08`03o`000?mW0B[oI`4Z00CoI`4Z1Ol00008oglTBP03o`000?n9
;DgoRBe=00CoRBe=2_l00006oiY6H`03o`000?nQCFGoXDeU00;oXDeU00?o0000oj9=I?nRCF@01OnR
CF@00ol0003oZ5=UojQCI@02ojQCI@03o`000?nZDfCoZU=T00GoZU=T00Co0000ok1IIOn`FFGo0000
2OnaFF<2o`0000Co]UeT2?l00003okA>B@03o`000?niDd_o^E=;00?o^E=;00?o0000okaCAOnlDdD0
1?l00004okI09`;o00000onkART4o`000003ojl/0ol0003o000000;o00000_nJ2004o`0005oooo]Z
00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?nka^;o^lKR00Co^lKR
00?o0000ok34j?l000000_l00003ok33j003o`000?naa>So/LCX00;o/LCX0ol00002oi^ml0;o0000
0_oaXFL00ol0003oj9M_o`000003o`00037ooo]Z0ol00003ob80DP;o000000?o9@Ufo`00I_l00000
1Ol00004oj:jjP;o00002OnN/^H5o`0000WoUj[S00?o0000oi:Wi?nBYn@01OnBYn@01Ol0003oSj?R
ohnSh_n?Xn;o000000_oRJ7T00Co0000ohJPi?n6X>Co00001on0V^800ol0003oOIWSogfIh`03ogfI
h`03o`000?mdT^7oM9;Q00?oM9;Q00?o0000og:Ah_mbTN801?mbTN801?l0003oIhSOofN8gol00002
ofJ9h0;o000000?oHhSQo`000?mDOMh00_mDOMh4oe=ngP;o00001?loL]`00ol0003o:EoBobUOdP02
oaeKdP;o2T_900Go0000o`14aOl08Zko0000omei0002o`0000Cooo]Z00?o0000oookJ_oonfX0=ooo
nfX00ol0003ooo]ZoookJP0WoookJP009?oonfX00ol0003ooo]ZoookJP1eoookJPGo000000?o4P00
o`000?l000000_l000000ol_003o0000o`000002o`0000CoF00S00Co0000ofL1:_mW0B[oI`4Z1?l0
0002og@KB003o`000?mo94[oObA:00OoObA:00?o0000ohT]COn9;Dd01Ol00003oi90H`;o00002onJ
AV<00ol0003oXDeUoj5=I@03oj5=I@03o`000?nRCFCoXTeT00?oXTeT00?o0000ojQCIOnXDfD01?nX
DfD00ol0003oZU=TojYCI004ojYCI005o`000?n`FFGo/5UUok1IIOl000002OnaFF<00ol0003o]UeT
okIMI005okIMI003o`000?njH6;o^V1R00;o^V1R1?l00006okUCB`03o`000?nlDdGo_5=500;o_5=5
2?l00003ok]6:@03o`000?noAb;o_dLR00?o00000_na:`04o`000003oi<00?l0003o000000;o0000
G?oonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z053ooo]Z0_l00008ok_6hP03o`00
0?n``nSo/<?X00Go/<?X00Co0000ok74j?l0003o00000onba>L01ol0003oVkg`o`000?oa[X;o0000
oo6QIol000000ooXUfl4o`0002gooo]Z0ol000001?md=7;o0000ob80D_lR0582o`0000;o9@Uf00?o
001Vo`000?l000000_l00005oj:jjP04o`000?nQ]>GoXKCUo`0000?oW[;V1Ol00002oib/hP03o`00
0?nGZ^?oUj[S00[oUj[S00?o0000oi:Wi?nBYn@01?nBYn@00ol0003oSj?Ro`00000=o`000003ohVQ
i?l0003o000001?o000000?oM9;Qo`000?mbTN801OmbTN801Ol0003oIhSOofN8gomWR=oo000000Co
IXWP0ol00002oeAmgP?oDgkN00?o0000od9`fOl000000_l000000oloL]co0000o`000002obUOdP05
oaeKd_l0003o2T_9o`Y;bOl0A<D01?l000000ooHMP3o0000oookJP02oookJP03o`000?oonf[ooo]Z
03Oooo]Z00?o0000oookJ_oonfX09ooonfX002Cooo]Z00?o0000oookJ_oonfX0LooonfX:o`000004
obl00?l0003o0000o`0000OoF00S1?l00005og@KB003o`000?mo94[oObA:00GoObA:1_l00008oi90
H`03o`000?nIAVCo000000WoVTIS00Co0000oj5=IOnQCFGoXDeU7?l00009ok5IH`03o`000?nfGFCo
]UeT00Ko]UeT00?o0000okYPH_njH6800onjH6800ol0003o_VARo`000004o`000003okUCBol0003o
_5=500Co_5=500Co0000okmGA_noEdKo00000_o1F4H4o`000003ok]6:Ol0003o_dLR00?o_dLR0ol0
00001Ona:`3o0000o`000?l0003oT`0000Go0000F_oonfX00ol0003ooo]ZoookJP1>oookJP03o`00
0?oonf[ooo]Z04kooo]Z0_l00008ok_6hP04o`000?nka>7o^lCQo`0000Oo/<?X0_l00005ok;4i`;o
00000_oa[X82o`0000?oj9M_00?o0000omZ9L_l000000_l0000ZoookJP?o00000omd=7801Ol0003o
8P1Bo`000?m37Gco000000;o9@Uf0ol000000ooJL@3o0000oj:jjP03oj:jjP03o`000?nQ]>GoXKCU
00Go00002?nL[>800ol0003oUj[SoiNZh`07oiNZh`03o`000?nGZ^?oUj[S00So00000on?XN000ol0
003oRj3Roh^PhP09oh^PhP03o`000?n6W^?o000000SoPISQ1OmnVN800ol0003oMi7OogNAg`02ogNA
g`Ko000000?oLY7Ro`000?mWR=l01?mWR=l01Ol0003oIXWPofJ9h?mVRN3o000000;oFh7N0ol00002
oe=ngP03o`000?m2L=Wo@W3I00;o@W3I00?o0000ocmbg?l000000olYGm802_lMFm;o0000o`Y;bOl:
BlWo04C5o`000?oaVC3o0000omQf0?l00003oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oook
J_oonfX09_oonfX002Cooo]Z00?o0000oookJ_oonfX0LOoonfX9o`000006obl00?l0003o0000o`00
0?m701_o00001OmH02<4o`0000SoM1]800?o0000oglTB_l000001Ol00003ohPhHP03o`000?nB@6?o
TT1S00SoTT1S00Co0000oiU6I?nIAVCo00001?nJAV<8o`0000CoYU]f00?o0000ojMLM_nWG7H00_nW
G7H00ol0003o[F5gojeQM`05ojeQM`03o`000?n^HWKo[V9f00?o[V9f00Co0000okAWM_ndIgKo]6Mf
3_l00005okIMI003o`000?njH6;o^V1R00?o^V1R00?o0000okiTH_l000001?o1IV47o`000003okaC
AOl0003o000000Co`EQ600?o0000olILA?o6G4@00ol00003okm78P03o`000?noAA_o_dDK00?o0000
00?o[bH0o`000?l000001_l0001HoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0
COoonfX00ol0003o^lKRok_6hP05ok_6hP;o00001Onka>400ol0003o/<?Xok33j003o`0000?o//?V
00?o0000ok;4ionba>L00_nba>L2o`0000?olJj20_l00002onRGK`06o`000?oJRG;ofXUbomZ9L_l0
003o]CXK0_l0000ToookJP?o00001_md=782o`0000;o@ael00Go0000obD9M_lU2GKo0000o`h3O@03
o`0000?oX[[Z1?l00002oj6ah`03o`000?nL[>;oW:cR00WoW:cR00Co0000oiNZhonGZ^?oUj[S1Ol0
0003oiNXhP05o`000?nBY^?oTZKSoi:Vhol000001on?XN000ol0003oRj3Roh^PhP09oh^PhP03o`00
0?n1V>7oPISQ00SoPISQ1?mnVN800ol0003oMi7OogNAg`04ogNAg`CoM97Q1_l000000omWR=oo0000
ofJ9h002ofJ9h003o`000?mKPMkoFh7N00?oFh7N00?o0000oe=ng_l000001_m2L=T2o`0000?o:EoB
0_l000001Ol:BlWo0000o`000?l0003olIT`00?o00000_oonfX00ol0003ooo]ZoookJP0hoookJP03
o`000?oonf[ooo]Z02Kooo]Z000SoookJP03o`000?oonf[ooo]Z077ooo]Z2?l000000ol_003o0000
o`000003odL06`04o`000?mH02?oF00SoeP08a7o00002On8>6800ol0003oTT1Soi90H`05oi90H`_o
00001?nPEWH00ol0003oYU]fojIKMP05ojIKMP03o`000?nWG7KoYeaf00;oYeaf00?o0000ojeQMon]
HGL01On]HGL00ol0003o[V9fojiRMP03ojiRMP03o`000?ndIgKo]6Mf00;o]6Mf00?o0000okEXM_ne
J7H01_neJ7H2o`0000;o_6ef1_l00005okYPHP03o`000?nnI6;o000000Ko`FIQ00?o0000ol=VGoo3
IUl00_o3IUl6o`0000;o`EQ600?o0000olILA?o6G4@00_o6G4@3o`000006okm78_l0003o_dDKokm5
6ol0003o_dDK1?l000000ond;03o0000oiL40004o`0005Kooo]Z00?o0000oookJ_oonfX0COoonfX0
0ol0003ooo]ZoookJP1<oookJP;o00001onka^800ol0003o^lCQok_4h@06ok_4h@;o00001onb`nH0
1_l0003o//CWo`000?l0003o]<?Uo`0000?olJj200Go0000onNSQ_l0003oj9M_o`000004omZ9LPKo
00006ooonfX7o`0000OoM3Ab0_l00003od<MO005o`000?lU2GKo0000o`000?l>0gd00_l000000ooJ
L@3o0000oj:jjP02o`0000KoXK7S00?o0000oib/h_nL[>801_nL[>800ol0003oW:cRoib/hP03o`00
00WoUjSR00?o0000oi:Vhol000002On?XN000ol0003oRj3Roh^PhP07oh^PhP;o00002on1V>42ogjI
hP03o`000?mgTMooMi7O00KoMi7O1?mdTN400ol0003oK8_Oofb;g`02ofb;g`Co000000?oIXWPo`00
0?mKPMh01?mKPMh01?l0003oEWgMo`000?l00005od9`f@03o`000?laH];o<F;B00;o:EoB0_l>BLL2
o`Y;b@03o`0[]?l0003olIT`00?o00000_oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[o
oo]Z02Kooo]Z000SoookJP03o`000?oonf[ooo]Z06oooo]Z2ol00005odL06`Oo00000_mX3d800ol0
003oM1Y6o`000004o`0000;oOc1N00Co0000ohThHOl0003o00001on8>6800ol0003oTT1Soi90H`06
o`0000?oV51e00Go0000oimFM_nOEWKoWeIfo`000007oj1FMP03o`000?nVFgKoYU]f00KoYU]f00Go
0000ojMLM_nWG7KoYeafo`000008ojeQM`05o`000?n^HWKo[V9fojiRM_l000001OndIgH00ol0003o
]FQfokEXMP06okEXMP;o00001onlKGH:o`0000Ko`FIQ00?o0000ol=VGoo3IUl00oo3IUl2o`0000;o
bFaN0ol00004olILA003o`000?o7Fckoae/n00Go000000?o_dDKo`000?o4BQ/00ol000001?nd;03o
0000o`000?nG1004o`0005Cooo]Z00?o0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP1:oook
JP;o00000_noa^000ol0003o^lKRok_6hP02ok_6hP;o00001onka>400ol0003o^l;Po`000009ok;3
iP;o00000_nd`nD01Ol0003olJj2oo6^P_oa[X;o000000;oij>60_l00004omZ9LP03o`000?o8N7Go
b7Qe00ko00001_oonfX@o`0000KoM3Ab0_l000000omhAXOo0000od<MO002od<MO0;o000000Go>2::
o`000?l>0ggo0000o`00I`02o`0000WoXK7S00Co0000oib/h_nL[>;oW:cR1Ol00003oibZh@03o`00
0?nGZ>;oUjSR00[oUjSR00?o0000ohnQh?n?XN002?n?XN000ol0003oRj3Roh^PhP02oh^PhPko0000
1?n1V>400ol0003oOYWRo`000008ogNAg`05o`000?mdTN7oM97QogBAhOl000001_m/Rml00ol0003o
IhSOofN8g`02o`0000GoFh7N0_l000001?m;L]Oo0000o`000?l00002od9`f@06o`000?l`H=7o<F;B
oc5Rd_lYGm;o00000_l>BLL2o`Y;b@03o`000?oaVC3o000000?o00000_oonfX00ol0003ooo]Zoook
JP0goookJP03o`000?oonf[ooo]Z02Kooo]Z000SoookJP03o`000?oonf[ooo]Z06gooo]Z1Ol00000
0olI003o0000o`000002o`0000GoA`0K1Ol00004ofP?@PGo00001omo<5h01Ol0003oRCQQohThHOn9
>67o000000?oR3QR1_l00009oiQ@M@03o`000?nOEWKoWeIf00;oWeIf00?o0000oj1FM_nPEWH01?nP
EWH00ol0003oYU]fojIKMP06ojIKMP05o`000?nWG7KoYeafojMLM_l000002?n]HGL01Ol0003o[V9f
ojiRM_n^HWKo000000Ko]6Mf00?o0000okEXM_neJ7H01OneJ7H00ol0003o^Vafo`000007oka]MP03
o`000?nmKWGo_Fie00;o_Fie00?o0000ol9bMOo2LWD01Ol00002ol5VH@03o`000?o3IUoo`fIO00?o
`fIO0_l00005olU/GP?o00000_o6G4@4o`000003olMK?_l0003o000000?o00000oo4BQ/2o`000003
ok@/0?l0003o000000Go0000DooonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z04Wo
oo]Z00?o0000oko6h?noa^000onoa^001?l0003o^lKRo`000?l00006ok_4h@;o00001?nk`^000ol0
003o//?Vok;3iP02ok;3iP?o00000onc`^D4o`0000;olJj200Co0000onNSQ_oWXhKoij>60_l00003
omZ9LP03o`000?o8N7Gob7Qe00?ob7Qe4Ol00004oiLZ=003o`000?mW01goI`0M00Go00000on>Ag80
0ol0003oM3Abog@dLP02og@dLP;o00000omhAXL01Ol0003o@aelod<MO?m37Gco000000?o>2::00?o
3P=mo`000?l006L00ol00007oj6ah`Go00002OnLZ^400ol0003oUjSRoiNXhP09oiNXhP03o`000?n?
XN3oSj7P00CoSj7P2Ol00004ohbOh004o`000?n7V]koQi[No`0000KoQ9WO3?l00003ogNAg`04o`00
0?mdTN7oM97Qo`0000SoK8_O00Co0000ofN8gol0003oGgoJ0ol00002oe^1gP;o00001?m;L]L01Ol0
003o@W3Io`000?l`H=7o000000;o<F;B00Oo:EoBo`000?l>BLOo3TW7o`Y;bOl0003olIT`00Co0000
0_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z02Kooo]Z000SoookJP03o`000?oo
nf[ooo]Z06cooo]Z1?l000000olI003o0000o`000002o`000004oc@04Ol0003oA`0KodL06`Co0000
00?oFP8ko`000?mX3d800_mX3d83o`0000;oMBMK00?o0000ogl`G_mo<5h01omo<5h00ol0003oRCQQ
ohThH@05o`0000?oTDUc00?o0000oiQ@MOnHD7D02?nHD7D00ol0003oWeIfoimFMP03oimFMP04o`00
0?nPEWKoX5Ifoj1FMRWo00000oneJ7H00ol0003o^Vafo`000007oka]MP03o`000?nmKWGo_Fie00;o
_Fie00Co0000ol9bMOo2LWGo00001?o4Lg@7o`000004ol=VGol0003oaV]Oo`0000CobFaN00?o0000
ol]]G?o;KE`01?l00004olMK?P;o000000?obelno`000?l000000_o4BQ/00ol0003oad/Bo`000002
o`000003ok@[0?l0003o000000?o0000D_oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[o
oo]Z04Oooo]Z0_l00006oko6h0;o00001onka>400ol0003o^l;Pok_2h005ok_2h004o`000?nb`nKo
0000o`0000So/l;U00Go0000onncS_l0003olJj2o`000003onNSQP04o`000?oJUXSo0000o`0000;o
fXUb00?o0000olQhMOo8N7D00oo8N7D00ol0003o_Fedoke]M002oke]M004o`000?neIWCo]FIdokEV
M0ko00002?n>Ag800ol0003oM3Abog@dLP02o`0000GoN4J700?o0000od<MO?m37G`00_l00003ocPR
RP06o`000?lG48Oo0000o`000?oGK@3o00001?nQ/N<3o`0000;oX:cP00?o0000oibZhOnLZ^402_nL
Z^400ol0003oUjSRoiNXhP03oiNXhP?o000000?oUjSRo`000?l000001_l00005oi2Qh003o`000?n<
Wn3oS9oP00CoS9oP00?o0000ohNJg_n7V]h00_n7V]h00ol0003oQ9WOohBIg`08ohBIg`03o`000?mk
TMgoNi7M00CoNi7M2_l00005ofb;g`03o`000?mWR=oo000000CoGgoJ0_l000000omKPMko0000od]b
e`05od]be`;o000000Co<63Aoc5Rd_laH];o<F;B0_l00002o`i9a`;o000000OolIT`o`000?l0003o
d740o`000?oonf[o000003Wooo]Z00?o0000oookJ_oonfX09_oonfX002?ooo]Z00?o0000oookJ_oo
nfX0J_oonfX9o`0000;o=00A1Ol00003oeX2>`03o`000?mX3d;o000000;o00001Ome9e/00ol0003o
Oc1Nogl`GP04ogl`GPKo00000_n@BG@00ol0003oTDUcoi59L`03oi59L`03o`000?nHD7GoV51e00Go
V51e3Ol00003ojATQ@03o`000?nZJ8KoZVR600KoZVR600Go0000oj]YQ_n[JHKoZfV6o`000008ok1^
QP05o`000?nbKhKo/Vn6ok9_Q_l000001_ngLhH00ol0003o^7B6okQdQP02okQdQP_o00000onlKGH0
1Ol0003o_Fieoke^MOnmKWGo000000;o`W9e00?o0000olAcM?o4Lg@01Oo4Lg@01?l0003oaWEcolIe
Loo6MG<4o`0000CobFaN0ol00003ol]]G0Co000000Coae/no`000?o;Gcko00000_o;Gch2o`000003
olA:6ol0003oad/B00;oad/B1ol0001AoookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oo
nfX0AOoonfX2o`0000Ko_lKP0_l00002okk4g`03o`000?nka>7o^lCQ00;o^lCQ0_l00009ok_2h003
o`000?nc`^Go/l;U00Ko/l;U0ol00002onncSP;o00000ooWXhH01?l0003ofYJ8omZFR?oJUXP3o`00
00Gob7Qe00?o0000oke]M?nmKG@00_nmKG@00ol0003o]FIdokEVM002okEVM003o`000?n/HWSo[69h
00Oo[69h00?o0000ohi7L_n>Ag802?n>Ag83o`0000OoN4J700?o0000od<MO?l000000_m>;XX01Ol0
003o>2::ocPRR_l0003o5a2700So00001_nP[>000ol0003oW:[QoibZh@0:oibZh@Go00000onGYn40
1?l0003oU:;NoiBRg_l0000;oi2Qh003o`000?n<Wn3oS9oP00;oS9oP00?o0000ohNJg_n7V]h01?n7
V]h00ol0003oQ9WOohBIg`07ohBIg`03o`000?mkTMgoNi7M00WoNi7M0_l00003og29g0Oo00002?mO
OmX2o`0000GoBg;G00Co0000ocQRdOl0003o00000_laH]82oaM<a`;o3TW700?o0000oo^aF_l00000
1?l000000ooonf[o0000oookJP0hoookJP03o`000?oonf[ooo]Z02Kooo]Z000SoookJP03o`000?oo
nf[ooo]Z06Sooo]Z2?l00003oc@04@Go00001?mJ0S/3o`0000OoMBMK00?o0000ogl`G_mo<5h01Ol0
0003ohQ2LP03o`000?n@BGCoT4Ud00?oT4Ud00Go0000oi59LonABG?oTDUco`000002oiQ@M@Ko0000
0onMGXD00ol0003oXf>5oj=SQ@04oj=SQ@03o`000?nTI8GoY6B500?oY6B500?o0000ojYXQ_nZJ8H0
1_nZJ8H01Ol0003oZfV6oj]YQ_n[JHKo000000So/6j600Go0000ok9_Q_nbKhKo/Vn6o`000006okMc
QP03o`000?nhM8Ko^7B600Go^7B600?o0000okagQOl000001OnnNHD6o`000003oke^MOl0003o`W9e
00;o`W9e00?o0000olAcM?o4Lg@01?o4Lg@00ol0003oaWEcolIeL`02olIeL`03o`000?o9N7?o0000
00Co000000?obFaNo`000?o;KE`01?o;KE`00ol0003ocViIoli^F@03o`000005ol]O?_l0003obeln
o`000?o@HST00ol00002olM;4P04o`000?o7B@_o0000o`0000;o/bP00_l0001@oookJP03o`000?oo
nf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0@ooonfX2o`0000;o`/KN00?o0000oko6h?noa^000_no
a^000ol0003o_/COokk4g`03okk4g`04o`000?nka>7o0000o`0000So^l;P0_l00002ok[1g`03o`00
0?nc`^Go/l;U00;o/l;U0ol00002okG0h`04o`000?o_/hkokk>>onncSP;o00000_oWXhH00ol0003o
fYJ8omZFR003omZFR0Go00000_o8N7D01?l0003o_Fedoke]M?l00005okEVM003o`000?n/HWSo[69h
00Oo[69h00?o0000ohi7L_n>Ag801On>Ag84o`0000WoN4J70_l00003odh^RP05o`000?lh8X[o0000
o`000?lG48L01Ol0000:oj2/h003o`000?nLZ^7oW:[Q00?oW:[Q1?l00002oibYg`03o`000?nGYn7o
UjOQ00CoUjOQ00?o0000oiBRg_nDX]h00_nDX]h00ol0003oT:7Poi2Qh009oi2Qh005o`000?n<Wn3o
S9oPohbOh?l000001_n7V]h00ol0003oQ9WOohBIg`06ohBIg`03o`000?mnTmgo000000_oNi7M00?o
0000og29g?m`RM`01_m`RM`2o`0000SoGgoJ00Co0000oe1ceom@LmOo00000om;L]L01?l0003o>6;A
ocQRdOlhH]42oc5RdP05o`000?lGC<Oo5dc7o`i9aol000000_ok/EX2o`000004on^F7_l0003o0000
o`0003Wooo]Z00?o0000oookJ_oonfX09_oonfX002;ooo]Z00?o0000oookJ_oonfX0J?oonfX7o`00
00?o=00A1?l00004oeX2>`?o000000?oJAaGo`000?me9e/01Ome9e/5o`0000SoR49b00?o0000oi19
M?n@BG@01?n@BG@00ol0003oTDUco`000003o`0000WoWEj500?o0000oj=SQOnSHhD01?nSHhD00ol0
003oY6B5ojATQ@03ojATQ@03o`000?nZJ8KoZVR600GoZVR600?o0000oj]YQ_n[JHH00_n[JHH00ol0
003o/6j6ok1^QP05ok1^QP03o`000?nbKhKo/Vn600;o/Vn600?o0000okMcQ_ngLhH00ongLhH00ol0
003o^7B6okQdQP06okQdQP03o`000?nlMhGo000000So_WV500?o0000ol1jQOo0NXD02?l00005olAc
M004o`000?o6MG?oaWEcolIeL`?o00000_o<NW84o`0000GobfeL00Co0000oli^FOo>KUWo00000_oA
LUX3o`000003ol]O?_l0003od68i00;od68i0_l000002?o7Ba;o0000olM92oo7B@_o0000ok<X0?l0
003o[1l00_l0001>oookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0@OoonfX2o`00
00Go`/KN00Co0000oko6h?l0003o00001_nna=l2o`0000Wo^l;P00?o0000ok[1gonj`Ml00onj`Ml0
1?l0003o/l;Uo`000?l00004okG0h`03o`000?o[/iOo000000;okk>>00?o0000onJYTOl000000_l0
0005omZFR003o`000?o:Qh[obXN:00;obXN:1_l00006okEVM003o`000?n/HWSo[69h00Go[69h00?o
0000ohi7L_n>Ag801_l00003oiUOR`03o`000?mhAXOoN4J700KoN4J70_l00004odh^RP;o000000Ko
@BjDo`000?lG48Oo5a27o`000?l006d2o`0000[oX:cP00?o0000oibZhOnLZ^400ol00007oibYg`03
o`000?nGYn7oUjOQ00;oUjOQ00?o0000oiBRg_nDX]h01?nDX]h00ol0003oT:7Poi2Qh004oi2Qh0Co
000000?oT:7Po`000?l000005Ol0000:og^Ag@03o`000?m`RMcoL8WL00OoL8WL00?o0000of=ofOmS
OmT01_mOOmX00ol0003oD7?Foe1ce`02oe1ce`;oBg;G00Oo0000ocQRdOlhH]7o>6;AocQTd_laH];o
000000?o5dc700Oo0000oo^aF_ok/E[o0000onnH:?l0003ojiHN00;o0000>_oonfX00ol0003ooo]Z
oookJP0UoookJP008_oonfX00ol0003ooo]ZoookJP1VoookJPOo000000?o6@01o`000?ld01400_l0
00001?m903Co0000odX0=Ol00002oeX2>`;o00001?mY75L01?l0003oMBMKogDWFome9e/3o`0000;o
OcY`00?o0000ohQ2L_n8@W801on8@W800ol0003oT4Udoi19M002oi19M0Go000000?oUeV4o`000?nM
GXD02_nMGXD00ol0003oXf>5oj=SQ@03oj=SQ@03o`000?nTI8GoY6B500CoY6B500?o0000ojYXQ_nZ
J8H01OnZJ8H00ol0003oZfV6oj]YQP02oj]YQP03o`000?n`KXKo/6j600Go/6j600?o0000ok9_Q_nb
KhH00_nbKhH00ol0003o]g>6okMcQP03okMcQP03o`000?nhM8Ko^7B600Ko^7B60_l00009okiiQ@05
o`000?o0NXGo`7Z5ol1jQOl000000oo4OXD00ol0003oaWn4olIoQ004o`000003olAcM?l0003o0000
00?o000000?obGQco`000?o<NW801?o<NW85o`0000;obfeL00?o0000oli^FOl000000_oALUX00ol0
003odg=Ho`000002o`0000?od68i00?o0000om9R=?l000000_l00002olM92`?o000000Co[1l0o`00
0?l0003o0000C?oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z043ooo]Z00Go0000
olC7g?o4amcoa<OLo`000004ol;6gP;o00001_nna=l01?l0003o_/?Mokk3gOl00006ok_2h0;o0000
1onj`Ml00ol0003o]L3SokG0h`04okG0h`?o00000_o_/hh01?l0003oiZVAonJYTOoVZI42o`0000Co
fYJ800?o0000olZ7R_o:QhX01?o:QhX00ol0003o`82<ol20S00Bo`0000WoVEn;00?o0000ogQ6Qomh
AXL00omhAXL3o`000003oh1BTOl0003oCRj:00;oCRj:00Co0000oe<gTOl0003o@BjD0olG48L01Ol0
003o001]o`000?oDJ03o000000[oX:cP0_l0000;oibYg`04o`000?nGYn7oUjOQo`0000GoU:;N2Ol0
0005oi6PgP03o`000?n=W]oo000000SoR9SL00?o0000ohJHg_n6V=h01On6V=h00ol0003oOi7KognA
f`07o`0000?oNi7M00?o0000og>;g?l000002?m`RM`2o`0000CoHgoI0omOOmX00ol0003oD7?Fo`00
0004oe1ce`;o00000olhH]400olhI=;o0000o`000002oaM<a`03o`000?ok/E[onk5J00?o000000?o
jiHNo`000?l00000>_oonfX00ol0003ooo]ZoookJP0UoookJP008_oonfX00ol0003ooo]ZoookJP1U
oookJPKo00000_lI0043o`000004odT0=?l0003o0000odX0=@Co00001OmY75L00ol0003oMBMKo`00
0002o`0000GoOcY`00?o0000ohQ2L_n8@W801On8@W87o`0000CoUUR400?o0000oiMIQ?l000002onM
GXD00ol0003oXf>5oj=SQ@03oj=SQ@04o`000?nTI8GoY6B5ojATQBWo00000onhM8H2o`0000Wo_WV5
00Go0000ol1jQOo0NXGo`7Z5o`000003olAnQ@03o`000?o6OhCoaWn400?oaWn41Ol000001Oo6MG?o
0000olUhLoo9N7?o000000Goc7Yb00Co0000olikLOo>Ng7ocW]a1Ol00002om5bFP05o`000?oCLeSo
dg=Ho`000?oCLeP00_l00002om1R>@04o`000?oBHSCodV8dom9R=0;o000000GoadT;o`000?l0003o
0000oj`O0004o`0004[ooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP0noookJP;o
00001Oo4am`00ol0003o`/KNo`000003ol74g004o`000?nna=oo_/COokk4g`;o00001?nn`md01?l0
003o^l;Pok_2h?nk`^02o`0000Oo^/7O00?o0000okZogOl000001_ne`><00ol0003oj[NNo`000002
o`0000CoiZVA00Co0000om^LT_l0003o00000_oJUXP00ol0003obXN:olZ7RP04olZ7RP04o`000?o0
P8co`82<o`0000Ko^GZ=00?o0000ok1bS?n`LX`01On`LX`00ol0003oVEn;oiUOR`09oiUOR`04o`00
0?mhAXOoN4J7ogQ6Q`;o00001?n0DY401?l0003oCRj:odh^R_l00003oe<gT@05o`000?lG48Oo5a27
o`000?lm;iP00_l000000ooDJ03o0000oj2/h002oj2/h0Go00000_nPZmh00ol0003oW:WOoibYg`0:
oibYg`04o`000?nGYn7o0000oiBRgPGo00000onEX]d00ol0003oTJ3Noi6PgP09oi6PgP03o`000?n8
V=coR9SL00SoR9SL00?o0000ohJHg_n6V=h00on6V=h00ol0003oOi7KognAf`02ognAf`03o`000?mm
TMcoOI7L00?oOI7L2?l00005og29g003o`000?mTOmWo000000OoHgoI0_l000000om@LmKo0000oe1c
e`02oe1ce`;o@FSB00Co0000ocQRdOlhH]7o>6CB0_lOClL02Ol0003o5dc7o`000?l0003onk5Jo`00
0?ok/eCo0000on^F7P02o`0003[ooo]Z00?o0000oookJ_oonfX09OoonfX002;ooo]Z00?o0000oook
J_oonfX0I?oonfX5o`0000?o6@010_l00002odT0=003o`000?m:03GoBP0e00;o00001omY75L3o`00
00OoOcY`00?o0000ohQ2L_n8@W800_n8@W84o`0000;oSe:300?o0000oiIHQ?nFF8@01OnFF8@01?l0
003oUeV4oiMIQ?l00008oieNQ@go00000onXL9@00ol0003o[GBCojedT`05ojedT`03o`000?n^MICo
[WFD00;o[WFD00?o0000ok9iTonbNI<01OnbNI<00ol0003o]7ZDokAjU002okAjU003o`000?nhOI?o
^7fC00?o^7fC00?o0000okYoUOnjOiD00onjOiD:o`0000Co_WV500Go0000ol1jQOo0NXGo`7Z5o`00
0003olAnQ@03o`000?o6OhCoaWn400?o00000_o6Oh@00ol0003oah64olN1Q007o`0000?oc7Yb00?o
0000olikLOo>Ng400oo>Ng400ol0003od7e_o`000002o`000004om5bF_l0003odg=Hom=cF0;o0000
00CoeWEDo`000?l0003o00000ooBHS@00ol0003odf4^o`000002o`000003olI50?l0003o000000Co
0000B_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000olC7g?o4
am`01Oo4am`2o`0000Go`LCL00?o0000okk4gol000001onn`md00ol0003o^l;Po`000007ok[1g`03
o`000?nj_mgo^[oM00;o^[oM00?o0000okG0hone`><00_ne`><01?l0003oj[NNonZgW_oZ]ih2o`00
00CoiZVA00Co0000om^LT_oKW9;ofibB0ol00006olZ7RP04o`000?o0P8co`82<o`0000Ko^GZ=00?o
0000ok1bS?n`LX`01On`LX`00ol0003oVEn;oiUOR`09oiUOR`Co00001_n0DY400ol0003oCRj:o`00
0004oe<gT@03o`000?lG48Oo000000;o?BnH0ol000001?oDJ03o0000o`000?l00008oj2[gP03o`00
0?nLZMooW:WO00WoW:WO1?l00009oiFRg@03o`000?nAX=koTJ3N00SoTJ3N00?o0000ohRHg?n8V=`0
2On8V=`01Ol0003oQYSNohJHg_n6V=ko000000KoOi7K00?o0000ogfAg?mmTM`01OmmTM`00ol0003o
M8WJo`000002og:9f`?o00000_m`RM`01?l0003oI7oIofAofOl00006of=of@04o`000?mFM=Co0000
o`0000?oD7?G00?o0000od5Xd_m1J=801?l00002oam?a`;o000000KooL9lo`000?l0003onk=Do`00
0?o[UQh2o`0003[ooo]Z00?o0000oookJ_oonfX09OoonfX002;ooo]Z00?o0000oookJ_oonfX0H_oo
nfX5o`0000?o6@010_l000000olf02_o0000o`000004o`000003oeX?D_l0003oJAaG00?oJAaG0ol0
00000omd<Vko0000ogljL007ogljL003o`000?n8@W;o000000;o00001_n?DX<00ol0003oUUR4oiIH
Q005oiIHQ004o`000?nGFHCoUeV4o`0000;oWEj51_l00003oj5[T`03o`000?nVKi?oYVnC00?oYVnC
00?o0000ojQ`U?nXL9@01?nXL9@00ol0003o[GBCojedT`04ojedT`03o`000?n^MICo[WFD00?o[WFD
00?o0000ok9iTonbNI<01?nbNI<00ol0003o]7ZDokAjU003okAjU003o`000?nhOI?o^7fC00?o^7fC
00?o0000okYoUOnjOiD01_njOiD2o`0000Go`XJC1ol000001?o0NXGo0000olAnQOo4OXD4o`0000Go
aWn400Go0000olN1Q?o7PHCoah64o`000002ol^4P`03o`000?o=QX?ocHJ300?o000000?oc7Ybo`00
0?o>Ng400oo>Ng400ol0003od7e_o`000002omB0K`Co000000?odg=Ho`000?l000000ooFME@2o`00
00;odV8d00Co0000om=Q;_oCHBkodf4^2?l00019oookJP03o`000?oonf[ooo]Z04[ooo]Z00?o0000
oookJ_oonfX0?OoonfX00ol0003oa<OLolC7g005olC7g003o`000?o3aM_o000000Ko`LCL0_l00007
okk3g@;o00001_nj`Ml2o`0000Ko^[oM00?o0000okG0hol000000_l00004onZgWP;o00000ooVZI40
0ol0003ofibBom^LTP03om^LTPGo00000_o:QhX01?l0003o`82<ol20S?l00006okUjS@03o`000?n`
LXco/7:<00Go/7:<00?o0000oiUORonIGh/01_nIGh/4o`0000WoP5:A0_l00005oe<gT@;o00001?lm
;iP4o`0000_oX:_N00Co0000oibYgonLZMooW:WO1_l00002oiZSf`03o`000?nEX]goUJ;M00[oUJ;M
00?o0000oi6Pg_nAX=h01_nAX=h00ol0003oSY_Lo`00000:ohRHg005o`000?n6V=koQYSNohJHg_l0
00001_moTM/00ol0003oOI7LogfAg004ogfAg005o`000?mdRM[oM8WJogB9f_l000001OmbRM/5o`00
00KoHgoI00Co0000oeIde?mFM=CoEWCD0_l000000om@LmOo0000od5XdP03od5XdP03o`000?lhI=;o
000000;o7do700Go0000oog2O?om`Wco0000oo^cE002o`000003on^F7_l0003o000003Wooo]Z00?o
0000oookJ_oonfX09OoonfX002;ooo]Z00?o0000oookJ_oonfX0HOoonfX5o`000004oaT00Ol0003o
0000o`0000;o=P0[1?l00004oeX?DP03o`000?mY75OoJAaG00;o00001?md<Vh00ol0003oOcY`oglj
L004ogljL0Co00002On?DX<00ol0003oUUR4oiIHQ005oiIHQ0Ko00002OnQJi<00ol0003oYVnCojI_
T`02ojI_T`03o`000?nXL9CoZ72D00GoZ72D00?o0000ojedTon]M9<01?n]M9<00ol0003o[WFDojie
U003ojieU003o`000?nbNI?o/WVC00Co/WVC00?o0000okAjU?ndNY@01?ndNY@00ol0003o^7fCokQm
T`02okQmT`03o`000?njOiGo^WnE00Ko^WnE0_l00009ol:6T`03o`000?o1QICo`HFD00So00001Oo6
Oh@01Ol0003oah64olN1Q?o7PHCo000000;obhB300?o0000olf6Poo=QX<00oo=QX<4o`0000?ocW]a
0_l00003omB0K`03o`000?oFPVkoeX9^00?o00000ooFME@00ol0003of7A@o`000002o`0000?odf4^
0ol00002olU900Go0000AooonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z03_ooo]Z
0_l00006olC7g0;o00000oo3aM/01Ol0003o`LCLol74g?o1a=co000000?o`L;K00?o0000okk3gOnn
`md00_nn`md2o`0000;o_L7L00Co0000ok[1gonj`Moo^/7O0_l00009okZog@04o`000?nf_^3o][kP
o`0000Coj[NN00Go0000onF/V?l0003oiZVAo`000006om^LTP03o`000?o<Si?oc8nC00;oc8nC1_l0
0006okUjS@03o`000?n`LXco/7:<00Go/7:<00?o0000oiUORonIGh/01_l00003oi]WU003o`000?n0
DY7oP5:A00KoP5:A0_l00006oe<gT@;o00001?lm;iP00ol0003o0024o`000002o`0000_oX:_N0ol0
0003oibWgP;o00001?nJXm/00ol0003oUJ;MoiFRg@09oiFRg@03o`000?nAX=koTJ3N00GoTJ3N00?o
0000ohjKg?l000005?l00002ognAf`03o`000?mmTMcoOI7L00CoOI7L00Go0000ogB9f_mdRM[oM8WJ
o`000006og:9f`03o`000?mXP=OoJ83G00Go000000?oHgoIo`000?mFM=@00omFM=@3oeEeeP;o0000
1?m1J=83o`000008oam?aol0003ooL9loog2O?l0003onk=Do`000?oj/dd3o`0003Wooo]Z00?o0000
oookJ_oonfX09OoonfX0027ooo]Z00?o0000oookJ_oonfX0HOoonfX7o`0000Go=P0[00?o0000oeX?
D_mJ3e801?mJ3e84o`0000GoM39^00?o0000ogljL?mo>W000_mo>W03o`0000;oQTb200?o0000ohmB
Pon?DX<02?n?DX<01?l0003oUUR4oiIHQ?nFF8@5o`0000;oVfNC00?o0000oj5[TonQJi<02OnQJi<0
0ol0003oYVnCojI_T`02ojI_T`03o`000?nXL9CoZ72D00GoZ72D00?o0000ojedTon]M9<01?n]M9<0
0ol0003o[WFDojieU003ojieU003o`000?nbNI?o/WVC00Co/WVC00?o0000okAjU?ndNY@01?ndNY@0
1Ol0003o^7fCokQmTonhOI?o000000Wo^WnE00?o0000ol:6Too2QY<01oo2QY<00ol0003o`HFDo`00
0003o`0000?oaHRC00?o0000olJ:Too6RY<01?l000000oo6OhCo0000olN1Q002olN1Q004o`000?o;
Q8?obhB3o`0000KocHJ300?o0000oln7Poo?Qh<01Ol00003omB0K`03o`000?oFPVkoeX9^00?oeX9^
0_l00002omIeE004o`000?oHM53of7A@omQdD0;o000000?odf4^o`000?oFIBd00_l000001Oo9B@3o
0000olU90?l0003o[24000;o0000A_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z
03[ooo]Z00?o0000olC7g?o4am`01Oo4am`00ol0003o`lGKol?5f`04ol?5f`03o`000?o1a=co0000
00Go`L;K00Co0000okk3gOl0003o00001Onm`M`00ol0003o^/7Oo`000008okZog@;o00000oni_M`2
o`0000?oj[NN0_l00002onF/V0;o00001_oKW9800ol0003oc8nColb?T`04olb?T`03o`000?o1QYGo
`HJE01;o00002OnKIi@2o`0000CoP5:A0ol000000on2F9So0000oe<gT@04oe<gT@04o`000?mZBYWo
JTZIo`0000;o?BnH00Ko0000o`XAT?l008Co0000om1Q0?l00005oj2[gPCo00000_nPZMd01?l0003o
W:ONoibWg_nLYmh2o`0000OoVZ?K00?o0000oiFRgOnEX]d01_nEX]d2o`000003oiFRgOl0003o0000
00Oo00000_n>VMX00ol0003oRiWKoh^If`08oh^If`03o`000?n6V=go000000GoPi;J2ol00003ogB9
fP03o`000?mbRM_oLXWK00;oLXWK00?o0000ofR0eomXP=L00_mXP=L4ofN0f0?o00001?mFM=@2oeEe
eP;o@fK?00?o0000od5Xd_m1J=800_m1J=82obeEb004oam?aol0003ooL9loog2O0;o000000?onk=D
o`000?oj/dd00_l0000ioookJP03o`000?oonf[ooo]Z02Gooo]Z000QoookJP03o`000?oonf[ooo]Z
05oooo]Z1?l000000ol1003o0000o`000005ocH0:`;o00001_mJ3e82o`0000SoM39^00?o0000oglj
L?l000000_l00005ohI<PP03o`000?n?DX?oSe:300KoSe:31_l00003oiYUTP05o`000?nKIi?oVfNC
oi]WTol000003?nQJi<01?l0003oYVnCojI_Tol00008ojQ`U003o`000?n]M9?o[GBC00?o[GBC00Co
0000ojieU?n^MICo[WFD5?l000000onhOI?o0000okYoU@08okYoU@03o`000?o2QY?o`XJC00Ko`XJC
0ol00003ol65U005o`000?o5R9?oaHRColF8Tol000001_o6RY<4o`000005olN1Q?l0003obhB3ol^4
Pol000001_o=QX<00ol0003ochN3oln7P`03oln7P`?o00000ooDP6l00ol0003oeX9^omJ2KP02omJ2
KP03o`000?oIQ6co000000;o00000ooHM5000ol0003ofgQ?o`000002o`0000;oeVD]0ol000000oo9
B@3o0000oj`Q0002o`0004Gooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0ioook
JP;o00001_o4am`00ol0003o`lGKol?5f`05ol?5f`;o00001oo1`]/2o`0000Ko_L7L0_l00008okZo
g@03o`000?ni_Mco^KgL00?o^KgL00?o0000onZiXOl000000_oZ]ih00ol0003ogZVNo`000002onF/
V0?o00000ooKW9800ol0003oc8nColb?T`05olb?T`04o`000?o1QYGo`HJEo`0000Ko^X6G00?o0000
ok9hU?nbN9@01OnbN9@00ol0003oVfNDoi]WU009oi]WU004o`000?mnDYCo0000oh1BT@;o00001?n2
F9P00ol0003oDcNAoe<gT@02oe<gT@07o`000?mZBYWoJTZIofY:VOl0003o?BnHo`000002o`XAT003
o`00Q?l26iko000000;o000000CoX:_No`000?l0003o00001onPZMd00ol0003oW:ONo`000009oiZS
f`04o`000?nEX]goUJ;MoiFRg@Go00000onFXM/00ol0003oTYoMoi:Og@02oi:Og@03o`000?n>VM[o
SYWJ00CoSYWJ00?o0000oh^Ifon;VM/02?n;VM/00ol0003oPi;Joh>BfP07oh>BfP03o`000?mmT=_o
OI3K00;oOI3K00?o0000ogV:f?miR]P01?l00004og:9f`03o`000?mXP=OoJ83G00?oJ83G1?mWP=P2
oeahe@?o000000CoEWCDoeEee_mEMMKo00000_m3I/l01Ol0003o@FSBod5Xd_m1J=;o000000;o;EG8
00Go0000oog2O?om`Wco0000ook5N@02o`000004ooZcCOl0003o0000o`0003Sooo]Z00?o0000oook
J_oonfX09OoonfX0027ooo]Z00?o0000oookJ_oonfX0G_oonfX3o`0000;o0@0000?o0000oaT06_l0
00000olf02/2o`000003odX1Bol0003oFPmB00?oFPmB0_l000000omY:6_o0000og@bKP06og@bKP?o
00002?n6C8800ol0003oSe:3ohmBP`02ohmBP`Co00000_nDHI800ol0003oVVFBoiYUTP03oiYUTP03
o`000?nKIi?oVfNC00?oVfNC00?o0000oj5[TonQJi<02OnQJi<01?l0003oYVnCojI_Tol00003ojQ`
U0oo00000onbQ:<00ol0003o]8>PokB3X003okB3X003o`000?nfQZ?o]XJS00Go]XJS00?o0000okV7
WoniQil05?l000000oo2QY?o0000ol65U004ol65U004o`000?o5R9?oaHRCo`0000OoaXZC00?o0000
olR;Too8Ri<01ol00004olf6P`03o`000?o?Qh?ochN300?ochN30_l000000ooES87o0000o`000002
o`0000CoeX9^0_l00003omV4K0;o00000_oHM5001?l0003ofgQ?om]hCooKN4l3o`000004omUV9Ol0
003o0000olU900Co0000A?oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z03Sooo]Z
0_l000000oo7amWo0000olC7g002olC7g0;o00001_o3aM/2o`0000;o`l?J00Co0000ol72foo1`]_o
`L;K0_l00003ol31fP?o000000Go_L7Lo`000?l0003o_KoKo`000006okZog@;o00001Oni_M`02Ol0
003oj[VQonZiXOoZ^J7o0000onZgW_l0003ogZVNo`000002onF/V003o`000?oKXIOofj6G00Co0000
1oo<Si<01?l0003o`HJEol66UOl00005okZ1U`03o`000?nbN9Co/WRD00Ko/WRD00?o0000oi]WU?nK
Ii@02?nKIi@2o`000004ogiBU?l0003o0000o`0000GoPURH00Go0000oe<gTOmC=i7oDcNAo`000004
ofY:V@03o`000?lm;iSo000000;o2Q6@1_l0000:oj2Yg@;o00002?nJXm/6o`0000WoUZ7K00Co0000
oi:OgOnBWmgo00001on>VMX00ol0003oRiWKoh^If`07oh^If`;o00002_n3T]X01?l0003oOI3Kogf@
fol00006ogV:f0Oo00001?mXP=L01Ol0003oIh3HofN0f?mWP=So000000CoG7SE00?o0000oeEee_l0
00001Om3I/l00om1J=;o0000obiEb002obeEb003o`000?om`Wco000000?oo/Ei00?o0000ooZcCOl0
00000_l0000ioookJP03o`000?oonf[ooo]Z02Cooo]Z000QoookJP03o`000?oonf[ooo]Z05gooo]Z
0ol000000ol1003o0000o`000002oaT06P04o`000?lf02_o0000o`0000;oBP5;00?o0000oeX?D_mJ
3e800ol00003ofTXJ`03o`000?md<VkoM39^00;oM39^0ol000000ommAH7o0000ohI<PP08ohI<PP03
o`000?n?DX?o000000;o00001_nDHI800ol0003oVVFBoiYUTP02oiYUTP03o`000?nKIi?oVfNC00Co
VfNC00?o0000oj5[TonQJi<00onQJi<=o`0000Go[7jQ00?o0000ojmnX?n_OZ000on_OZ000ol0003o
/XBSok:4X`05ok:4X`05o`000?ndPj3o]8>PokB3X?l000002?nfQZ<01Ol0003o^HNOokV7WoniQioo
000000Wo_HbR1Ol000000oo0SJ3o0000o`000006o`0000;o`HFD00?o0000olF8Tol000001oo6RY<0
0ol0003ob8^ColR;T`02olR;T`04o`000?o<SY;oc8jBo`0000;ocY2B0ol000000oo=QX?o0000oln7
P`04oln7P`;o00001?oES843o`0000?oeX9^0_l00002omV4K003o`000?oKQF[o000000;o00000ooK
N4l01?l0003ogg];o`000?l00002omUV9@Oo0000@_oonfX00ol0003ooo]ZoookJP1:oookJP03o`00
0?oonf[ooo]Z03Oooo]Z00So0000olW7f?o9amSo0000olO7fOl0003oa<OLo`0000Oo`lGK00?o0000
ol?3f_o3`mX00oo3`mX00ol0003o`L;Ko`000008ol31fP;o00000onm_m/01?l0003o^[oMokZogOnj
_md2o`0000Oo^KgL00?o0000onZiXOoZ^J400_oZ^J42o`000005omjYW_l0003oiJbHonF/V?l00000
1OoKXIL3o`0000Coc8nC00Go0000ol66UOo1QYGo`HJEo`000005okZ1U`03o`000?nbN9Co/WRD00Ko
/WRD00?o0000oi]WU?nKIi@01onKIi@01?l0003oWFZFo`000?l00003oh5IVP?o00000on2F9P00ol0
003oDcNAo`000005ofY:V@;o00001?l:4I001?l0003o0Q^No`000?l00009oj2Yg@;o000000?oWZGJ
o`000?nJXm/00_nJXm/5o`0000?oVZ;K00?o0000oiJQfonFXM/02OnFXM/00ol0003oTYoMo`000008
ohjIfP03o`000?n;VM_oRiWK00KoRiWK00Co0000ohNDfOn7U=Wo00002_n3T]X00ol0003oOI3Ko`00
0007ogV:f004o`000?mcR=[oLhSJo`0000;oKX7E0ol00002ofR0e`;oIh3H00?o0000oeaheOmLN=D0
1OmLN=D00ol0003o@fK?od=Vc`04od=Vc`Co000000?on/fGo`000?l000000oonaGT00ol0003on[==
o`000002o`0003Wooo]Z00?o0000oookJ_oonfX09?oonfX0027ooo]Z00?o0000oookJ_oonfX0G?oo
nfX6o`0000;o6@0J0ol00003odX1B`Co00001_mY:6/00ol0003oM39^o`000002o`0000CoODF100?o
0000ohI<P_n6C8801On6C884o`0000WoU66B00Go0000oiYUT_nJII;oVVFBo`000005oi]WT`So0000
1_nTMj42o`0000[o[7jQ00?o0000ojmnX?n_OZ000_n_OZ000ol0003o/XBSok:4X`06ok:4X`04o`00
0?ndPj3o]8>Po`0000[o]XJS00?o0000okV7Wol000002OnmS:83o`0000Oo`8fP00?o0000ol6@X_o1
T:800_o1T:85o`0000OoaXZC00?o0000olR;Too8Ri<00_o8Ri<01?l0003oc8jBolb>T_l00005olj@
TPCo00000oo?Qh<2o`0000CoeHb100?o0000omN>POoGSX401?l000001?oIQ6co0000omV4K?l00003
om^5JP?o000000GofgQ?o`000?oONd_ogg];o`000002omUV9@05o`000?oJIQko0000o`000?o7A`00
0ol00012oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003obLOH
olW7f002olW7f003o`000?o7amWo000000Ko`lGK0_l00006ol?3fP;o00001oo0`MX01?l0003o_kkI
oknnfOno_]T2o`0000;o_KoK00?o0000okZogOl000001oni_M`3o`0000Coj[VQ00Ko0000omf/Xol0
003o0000onF/V?l00006om^QU`03o`000?o?UISociFH00?o000000?oc8nCo`000?o1QYD00oo1QYD0
0ol0003o^X6GokZ1U`02okZ1U`03o`000?nbN9Co/WRD00Ko/WRD00?o0000oi]WU?nKIi@01?nKIi@6
o`0000OoPEVJ0_l000000on2F9So0000o`000006ofY:V@;o00001?l:4I000ol0003o0Q^No`8KWP02
o`0000OoX:WM00?o0000oijUf_l000001Ol00009oiZRf`03o`000?nFXM_oUZ7K00SoUZ7K0_l00005
ohjIfQOo00001On3T]X00ol0003oNH[HogV:f007ogV:f003o`000?mcR=[o000000GoKX7E0ol00000
0omWP=So0000oeahe@06oeahe@;o00001Om3I/l2ocQJb@;o000000?on/fGo`000?l000000oonaGT6
o`0003Sooo]Z00?o0000oookJ_oonfX09?oonfX0027ooo]Z00?o0000oookJ_oonfX0FooonfX6o`00
00;o6@0J0_l00004odX1B`?o00001omY:6/3o`0000OoODF100?o0000ohI<P_n6C8800_n6C883o`00
00;oSE^B00?o0000oiAQT_nDHI802?nDHI801Ol0003oVVFBoiYUT_l0003oVfNC00Go00000_nPM:40
0ol0003oY7NQojAgX@09ojAgX@03o`000?n/OZ7o[7jQ00Wo[7jQ00Go0000ojmnX?n_OZ3o[gjPo`00
0009ok:4X`04o`000?ndPj3o]8>Po`0000[o]XJS0_l00007okf<XPCo000000?o_8^Qo`000?o0SJ00
1Oo0SJ000ol0003o`I2Rol6@XP05ol6@XP03o`000?o5T9ko000000Co00000oo6RY<00ol0003ob8^C
olR;T`03olR;T`;o00001oo>T9800ol0003od9:Com2BT`05o`0000CoeHb100?o0000omN>POoGSX40
0ooGSX42o`000004omV4K?l0003ofHA/o`0000;ofhEZ0_l000001?oQRVOo0000om]hCol00002ommk
B`;o000000CofFHUo`000?oJIQkofVHN0_l000000oo4A03o0000o`000011oookJP03o`000?oonf[o
oo]Z04Sooo]Z00?o0000oookJ_oonfX0=OoonfX2o`0000GobLOH0_l000000oo6aMSo0000ol?5f`02
ol?5f`;o00001oo3`mX00ol0003o`/7Io`000005ol31fP;o00001_no_]T01?l0003o_KoKo`000?l0
0007okVmg003o`000?ni^m_o000000Coj[VQ00Co0000omf/XooM[:?ogJbS0ol00005om^QU`03o`00
0?o?UISociFH00CociFH1Ol000000oo1QYGo0000okZ1U`02okZ1U`03o`000?nbN9Co/WRD00Oo/WRD
00?o0000oi]WU?l000001?l00002oie/V@04o`000?nNKY_oWVjKo`0000SoPEVJ0ol00006ofY:V@;o
000000Ko>S6Ko`000?l:4I3o2Q6@o`000?l?89l2o`8KWP03o`00S_l0003o000000?oX:WM0_l00000
0onPZMgo0000o`000003oijSf@03o`000?nJX]_oVZ;K00[oVZ;K00?o0000oiJQfonFXM/00_nFXM/3
o`000003oiJQfol0003o000000Ko00001On@V]T00ol0003oRiSJoh^HfP04oh^HfP03o`000?n7T]Oo
Qi;G00;oQi;G00?o0000ohBBfOn4T]T00on4T]T8o`0000OoNH[H0_l00009ofj1e@?o00001_mLN=D2
odiYcP?o00000_m3I/l01?l0003o>5[9ocQJbOl00002oo[=U`04o`000?onaGWoo/Eiook5N@Co0000
00?ogHl9o`000?oonfX0=ooonfX00ol0003ooo]ZoookJP0ToookJP008?oonfX00ol0003ooo]Zoook
JP1KoookJPKo000000Go6@0Jo`000?l0003o=`13o`000003odX1B`;o000000?oFaeVo`000?mY:6/0
1?mY:6/2o`000003og<mOol0003oODF100OoODF100?o0000ohI<P_l000000_l00005oheKTP03o`00
0?nDHI;oU66B00SoU66B1Ol00007oj1dX@03o`000?nTMj7oY7NQ00SoY7NQ0_l0000<ojanX@03o`00
0?n_OZ3o000000_o/XBS0_l0000;okJ6X`03o`000?nmS:;o_HbR00?o_HbR0ol00002okf<XP05o`00
0?nlRj7o_8^Qokb;XOl000001Oo0SJ000ol0003o`I2Rol6@XP05ol6@XP;o00001Oo9UZ07o`0000;o
b8^C0_l00007olj@TP03o`000?o@TY?od9:C00?od9:C0ol00003omF<P@03o`000?oGSX7oehj100?o
ehj100?o0000omZ@P?l000000ol00002om^5JP;o00000_oQRVL2o`0000;ogg];00Co0000on9lA_l0
003o00000_oJIQh3o`000003olA40?l0003o0000043ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?o9amSobLOH00CobLOH00So0000olS5eoo8aMOo0000olK5f?l0
003o`lGKo`0000So`l?J00Go0000ol;1fOo2`MWo`/7Io`000003ol31fP03o`000?no_]Wo_kkI00Oo
_kkI0_l000000onl_M[o0000okVmg003okVmg0;o00000_ni^m/2o`0000?oj[VQ00?o0000omf/XooM
[:<00_oM[:<3o`0000Cofj6G00?o0000olnEV?o?UIP01Oo?UIP01?l0003o`XVIol:9VOo2RITAo`00
00KoWFbI00Go0000oii^VonNKY_oWVjKo`000006oh5IVP;o00000_n3G9d00ol0003oJTZIofY:V@03
ofY:V@03o`000?mOBj;o000000;o>S6K00Co0000o`XAT?l0003o3b2O0_l000000ol008koVRH0o`00
0004o`0000SoWZ?I00?o0000oiZRfonJX]/01onJX]/00ol0003oVZ;KoiZRf`04o`0000;oUYoK00Go
0000oiBJeonDV]OoU9[Go`00000;oi2Jf@03o`000?n;V=[oRiSJ00;oRiSJ00?o0000ohNBeon7T]L0
1?n7T]L00ol0003oQ9;IohBBf@06ohBBf@;o00000omkR]L2o`0000GoNH[H00?o0000ofj1eOm^PMD0
1om^PMD00ol0003oHGOBof5gdP03o`0000?oG7SE00?o0000odiYc_m>JLh00_m>JLh01Ol0003o@fK?
o`000?lhF/Wo000000?on/fG0_l000001?onaGWo0000ooo7M?ooag@4o`0003Sooo]Z00?o0000oook
J_oonfX09?oonfX0023ooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000004o`803ol0003o0000o`00
00?o=`1300Co0000odX1Bol0003o00000omK7FH00ol0003oJBQ[ofTXJ`03o`0000?oLceo00?o0000
oge5POmmAH401?mmAH44o`0000WoSE^B00?o0000oiAQT_nDHI801OnDHI84o`0000[oX7BQ00?o0000
ojAgXOnTMj401onTMj400ol0003oYGVRo`00000<ojanX@;o00001OnbQ:<>o`0000Ko]XJS00?o0000
okf<X_l000000ol00005okf<XP05o`000?nlRj7o_8^Qokb;XOl000001?o0SJ000ol0003o`I2Rol6@
XP06ol6@XP03o`000?o9UZ3obIJP00KobIJP00?o0000olRFX_o8UZ800_o8UZ86o`0000CocY2B00?o
0000om2BToo@TY<01?o@TY<2o`000003omFFTOl0003o000000;o00001OoGSX401?l0003ofY20omZ@
P?oJT805o`000004omj8JOl0003ohHYWon6:I`;o00000_oONd/00ol0003ohWa6on9lAP02o`000004
omYV7_l0003o0000olA400?o0000?ooonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z
03;ooo]Z0_l00006olW7f003o`000?o8aMOob<GG00;ob<GG00Co0000olK5f?l0003o00001_o3`mX2
o`0000Go`/7I00?o0000ol31f_l000002?no_]T01?l0003o_kcHoknlf?no_=P3o`0000;o^KgL00?o
0000okVkfoni^m/00_ni^m/00ol0003oj[^So`000002onZiX@03o`000?oM[:?ogJbS00?ogJbS00Co
0000omZTW_l0003o00000_oKXIL00ol0003ociFHolnEV004olnEV003o`000?o2RIWo`XVI00?o`XVI
00Go0000okZ4VonjQ9_o^XBKo`000009ok9lV003o`000?nMK9WoWFbI00CoWFbI00?o0000oii^VonN
KY/00onNKY/00ol0003oPEVJoh5IVP03o`0000CoPebM0_l00003ofY:V@04o`000?mOBj;oGd^Roem;
XP;o>S6K00?o0000o`XAT?l000000_l?89l00ol0003o002>o`00J003o`0000_oWZ?I00Co0000oiZR
fonJX]_oVZ;K1Ol00003oi^Qf@03o`000?nFWm_oUYoK00;oUYoK00?o0000oiBJeonDV]L00onDV]L0
0ol0003oT9[Ioi2Jf@09oi2Jf@04o`000?n;V=[oRiSJo`0000OoQi;G00?o0000ohBBfOn4T]T01On4
T]T01?l0003oOX_Fogj;e_l00007og^:e`03ogV:f?l0003o000000;o00001om^PMD00ol0003oHGOB
of5gdP03of5gdP05o`000?mLN=Go0000oe1[c_l000001Om>JLh3o`0000?on/fG00Co0000ooc@U_l0
003o00000_ooag@4o`0003Sooo]Z00?o0000oookJ_oonfX09?oonfX0023ooo]Z00?o0000oookJ_oo
nfX0FOoonfX4o`000003o`803ol0003o000000Co=`130ol000000omJ6fKo0000oe/MIP02oe/MIP?o
00001Omc?Gl00ol0003oODF1oge5P@02oge5P@?o00000_n5EY400ol0003oSE^BoheKTP08oheKTP03
o`000?nDHI;oU66B00Go000000CoV6fOo`000?nKLZ?o00002onPM:400ol0003oY7NQojAgX@05ojAg
X@05o`000?nUNJ;oYGVRojEiX_l000001On/OZ4=o`0000Ko/H^^0_l00006okVA[ACo000000?o_8^Q
o`000?o0SJ000oo0SJ000ol0003o`I2Rol6@XP06ol6@XP03o`000?o9UZ3obIJP00GobIJP00?o0000
olRFX_o8UZ801Oo8UZ82o`0000;od9^O0ol000000oo>T9;o0000om2BT`05om2BT`;o00001?oEUY43
o`0000?oehj100?o0000omZ@P?oJT8000_oJT8000ol0003og99oombBO`03o`0000;ohHYW00?o0000
on><IOl000000_l00002on9lAP05o`000?oTOD7o0000o`000?oJIAH01Ol0000noookJP03o`000?oo
nf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003obLOHolW7f005olW7f003o`000?o8
aMOob<GG00?ob<GG0_l00002olK3e`;o00000oo3`mX00ol0003o`/7Iol;1f@05ol;1f@;o00001ono
_]T2o`0000Oo_kcH0ol00003okVkf`04o`000?oZ^j?oj[^SonZkX`;o00001_oM[:<01?l0003ofZBN
omZTW_oJY9h2o`0000OociFH00?o0000ol:9VOo2RIT00oo2RIT01?l0003o^XBKokZ4Vol0000:ok9l
V003o`000?nMK9WoWFbI00?oWFbI00?o0000oii^VonNKY/01?nNKY/3o`0000OoPebM00Go0000ofA9
W?l0003oJTZIo`000004oem;XP04o`000?lj<I_o>S6Ko`0000?o3b2O00?o0000o`00S_l008h00ol0
000:oijSf@Go00002OnKXMT01?l0003oUYoKoiJOfol00007oiBJe`03o`000?n@V]WoT9[I00SoT9[I
00?o0000oh^Hf_l000002?n7T]L00ol0003oQ9;IohBBf@04ohBBf@05o`000?mnRmKoOX_Fogj;e_l0
00002?mkR]L00ol0003oLh;Cog62e002og62e0;o00000om^PMD00ol0003oI7SBo`000006of5gdP;o
000000?oD6_>o`000?m>JLh00om>JLh2oc]Ia`05o`000?ojcIOon/fGoo[=Uol000000_old9H00ol0
003oolMdooo7M005o`0003Oooo]Z00?o0000oookJ_oonfX09?oonfX0023ooo]Z00?o0000oookJ_oo
nfX0F?oonfX3o`0000;o0P0?00?o0000ocL0@olg04<00olg04<2o`0000;oFQ]V00Co0000oe/MI_mK
7FKoFaeV0_l00007og<mO`03o`000?mmAH7o000000;o00001On5EY400ol0003oSE^BoheKTP06oheK
TPGo00001?nHKIl2o`0000;oVg:S00?o0000oj1dXOnPM:402OnPM:400ol0003oY7NQojAgX@04ojAg
X@03o`000?nUNJ;o000000So00001?n/QZd00ol0003o[HR^o`00000;ok6;[P03o`000?nbSJoo0000
00So^I6]0ol000000ongT:ko0000ok^B[@08ok^B[@04o`000?nlU[7o_9JaokbF/@_o00000oo1T:82
o`0000OobIJP00?o0000olRFX_o8UZ801Oo8UZ800ol0003od9^Oom2KW`04om2KW`Co00000oo@TY<0
0ol0003odIBCo`000004omFFT@03o`000?oGVI7oeiVA00Co00001?oJT802o`000003ombBOol0003o
giAn00;o000000?ohHYWo`000?oSS6D00ooSS6D2o`000004on9lA_l0003oi7e1onAm@@;o000000?o
fF@=o`000?l000000_l0000moookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0<?oo
nfX00ol0003obLOHolW7f004olW7f0;o00001Oo8aML01Ol0003oal?FolO3e_o7`mKo000000;oa/?G
00?o0000ol?3f_l000001oo2`MT01Ol0003o`KoHol6of?o1_mSo000000?o_kkI0_l00007oknlf003
o`000?nn^]Ko000000;o^k[H1?l00004onZkX`;o00001?oM[:<00ol0003oeZ:Qo`000003omZTWP?o
00001Oo?UIP00ol0003o`XVIol:9V@03ol:9V@04o`000?njQ9_o^XBKo`0000[o/WbH00?o0000oie/
VOnMK9T00_nMK9T00ol0003oWVjKoii^V`03oii^V`?o00002_n3G9d00ol0003oI4VLo`000005oem;
XP04o`000?lj<I_o>S6Ko`0000?o3b2O00Go3b>Qo`000?l008ko0000o`00S002o`0000GoWZ?I1?l0
0002oijSf003o`000?nKXMWoVj7I00WoVj7I00?o0000oiJOfol000002?nDV]L00ol0003oT9[Ioi2J
f@09oi2Jf@03o`000?n7T]OoQi;G00SoQi;G00?o0000ohBBfOn4T]T00_n4T]T00ol0003oOX_Fogj;
eP03ogj;eP03o`000?mkR]OoNh[G00CoNh[G00Co0000og>2domcP]?oLh;C1_maP]@3o`000003ofAh
d_l0003oHGOB00CoHGOB0_mFKLh2o`0000CoCVW>0_l000001?oae[Go0000oo[=Uol00003ooc@UP03
o`000?ooagCoolMd00Go0000=ooonfX00ol0003ooo]ZoookJP0ToookJP008?oonfX00ol0003ooo]Z
oookJP1FoookJPCo00000_l200l2o`0000?o=`130_l000001Om:3f7o0000oeXKI_l0003oFaeV00?o
000000?oJ3Alo`000?mc?Gl01Omc?Gl3o`0000SoQEJA00?o0000oheKT_n=Fi800_n=Fi84o`0000;o
TVVP00?o0000oiQ]WonHKIl00_nHKIl2o`0000CoVg:S00?o0000oj1dXOnPM:401onPM:4;o`0000?o
ZXN_00?o0000ojb6[On/QZd01_n/QZd01?l0003o[HR^ojf8[_l0000:ok6;[P04o`000?nbSJoo/Xf_
o`0000Go^I6]0ol000001OniTJgo0000okN@[_ngT:ko000000So^i:]00?o0000okbF/OnlU[400onl
U[401Ol0003o_iF[oknEZonoUJ_o000000Goa9b^1_l00006olVFX003o`000?o8UZ;ob9JR00Gob9JR
00?o0000om2KWoo@Vil01Oo@Vil00ol0003oci^QolnKX@04o`0000;odIBC00Go0000omFFTOoEUY7o
eIJAo`000005omNIT@;o00000ooJT8001ol0003og99oo`000?l0003ogiAno`000?oRUgd00ol00003
on><I@04o`000?oVSV;o0000o`0000;oi7e100?o0000onEn>ol000000_oII0d3o`0003cooo]Z00?o
0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0^oookJP?o00001Oo9amP00ol0003ob<GGolS5
e`04olS5e`03o`000?o7`mKoal?F00?oal?F00?o0000olK3eol000000_l00005ol;1f@;o00001Oo1
_mP00ol0003o_kkIo`000007oknlf0;o00000onn^]H00ol0003o^k[Hok^jf002ok^jf003o`000?oZ
^j?oj[^S00;oj[^S00Co0000on6_X_l0003o00000_oM[:<00ol0003oeZ:Qo`000003omZTWP03o`00
0?oAVI_odIVK00?o000000?ociFHo`000?o2RIT01_o2RIT00ol0003o^XBKo`00000;ok9lV004o`00
0?nMK9WoWFbIo`0000;oWVjK1?l00002oj1cW`03o`000?n3G9goPebM00SoPebM0_l000000omVC9ko
0000oem;XP04oem;XP04ocXaVol0003oE4BRo`0000;o3b2O00?o0000o`lSXOl008h01?l00002oijS
f@?o00001onNXmP00ol0003oVj7Ioi^Qf@08oi^Qf@;o00001OnDV]LTo`0000;oOX_F00?o0000og^:
eomkR]L01?mkR]L01Ol0003oLh;Cog>2domcP]?o000000KoLH;D0_mXN]42o`0000GoHGOB00Co0000
oeI]c_mFKLkoEVg>0_l000001?m>JLko0000oc]Iaol00002oo7F]@;o00000_old9H01Ol0003oo]>C
o`000?l0003oolU`00Co0000>?oonfX00ol0003ooo]ZoookJP0SoookJP008?oonfX00ol0003ooo]Z
oookJP1EoookJPCo00000_l200l01?l0003o7P0go`000?lg04<2o`0000?oBPmQ00Co0000oeXKI_l0
003o00001?mX=7`00ol0003oLceoog<mO`02og<mO`;o000000?oO4n@o`000?n5EY402?n5EY400ol0
003oSE^Bo`000002o`0000KoTVVP00Go0000oiQ]WonHKIooV6fOo`000006oi]bX`KoX7BQ1?l00002
oj:0[`05o`000?nVP:_oYX2[ojJ0Zol000001onZQjl00ol0003o[8J]ojb6[@05ojb6[@03o`000?n]
R:ko[HR^00;o[HR^00?o0000ok6;[_naRjh01_naRjh01_l0003o/Xf_ok:=[onbSJoo0000okVA[@Co
00000oniTJd00ol0003o]i2^okN@[P02okN@[P03o`000?nkTZgo^i:]00Co^i:]00?o0000okbF/Onl
U[401?nlU[401?l0003o_iF[oknEZol00009olBL[P03o`000?o1W;;o000000?o00000_o9UZ000ol0
003ob9JRolRFXP06olRFXP03o`000?o@Viood9^O00Cod9^O00?o0000olnKXOo?Vj401?o?Vj44o`00
00;oeIJA00?o0000omNITOoGVI401?oGVI400ol0003ofI^Ao`000003o`000005ombBOol0003o0000
omnDO_l000000ooRUgd2o`0000;ohhaU00Co0000onJ>H_oVSV;oiXiR0_l000001OoTOD7o0000onEn
>ol0003ofF@=00Co0000??oonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z02gooo]Z
00?o0000olg7e?o=am@00_l00003olW7f003o`000?o8aMOob<GG00Cob<GG00?o0000olO3e_o7`mH0
1?o7`mH2o`0000?oaL3F00Go0000ol;1fOo2`MWo`/7Io`000007ol6of0;o00001ono_=P00ol0003o
_[[FokjjeP04okjjeP04o`000?nk^]So0000o`0000Coj[^S00?o0000on6_X_oQ[j800_oQ[j801Ol0
003ogJbSo`000?oFXZ7o000000?ofZBN00?o0000om6IVooAVI/00ooAVI/6o`0000?o`XVI0_l0000<
ok9lV003o`000?nMK9Wo000000?o00001_nPLil00ol0003oPebMoh=LW@07oh=LW@;o00000omVC9h0
1?l0003oGd^Roem;X_mOBj82o`0000?oE4BR0_l000001_lD9Z?o3b>Qo`000?l0003o002<o`00N@?o
00002onNXmP00ol0003oVj7Ioi^Qf@05oi^Qf@Wo00001OnDVmL9oi6If003o`000?n=TmCo000000[o
RY;F00Go0000ohFAf?n5TMSoQI7Ho`000004oh:;e0_o00000omcP]<00ol0003oLH;Dog62e002og62
e003o`000?mXN]7oJ7[A00;oJ7[A0ol000000omQMm;o0000oeI]cP03oeI]cP03o`000?m?JLgoCfW=
00;o00001?oae[D01Ol0003oo=2Fooc@U_l0003oo]>C00;o000000?oolU`o`000?l000000_l0000h
oookJP03o`000?oonf[ooo]Z02?ooo]Z000PoookJP03o`000?oonf[ooo]Z05Cooo]Z1?l000001?l2
00oo0000o`000?lN03L3o`0000CoBPmQ0ol00005ofPdO003o`000?mc?GooLceo00?o00000omlCi00
0ol0003oQEJAohEFT@06ohEFT@?o00002OnBJJ001?l0003oV6fOo`000?l00007oi]bX`;oX7BQ1?l0
0006oj:0[`04o`000?nVP:_oYX2[o`0000WoZXN_00?o0000ojb6[On/QZd00on/QZd00ol0003o[HR^
ojf8[P03ojf8[P03o`000?naRjko/H^^00Go/H^^00Co0000ok:=[onbSJoo/Xf_0ol00006okVA[@03
o`000?ngT:ko]i2^00?o]i2^00?o0000ok^B[OnkTZd00onkTZd00ol0003o_9JaokbF/@06okbF/@;o
00002Oo4W:h01?l0003o`Ibbol6L/_l00003olJK[0Oo00000oo8UZ800ol0003obINSo`000005om2K
W`03o`000?o?Vj7oci^Q00Coci^Q00?o0000om2NY?o@WZ@01?l00006omNIT@03o`000?oIVi7ofI^A
00;ofI^A1?l000000ooOU7ko0000on:GO@02on:GO@06o`000?oTVGco0000o`000?oSS6Go00000_oV
SV801?l0003oj91Oo`000?l00002onEn>`Ko0000>ooonfX00ol0003ooo]ZoookJP17oookJP03o`00
0?oonf[ooo]Z02cooo]Z00?o0000olg7e?o=am@00_o=am@2o`000003olW7f?l0003ob<GG00Gob<GG
00?o0000olO3e_o7`mH01?o7`mH00ol0003oa/7Eo`000004olG0eP03o`000?o2`MWo000000Oo`KoH
00?o0000ol2meol000001_no_=P00ol0003o_[[FokjjeP06okjjeP04o`000?nk^=Oo0000o`0000?o
j[^S00?o0000on6_X_oQ[j800ooQ[j83o`000004omJRXOl0003ofZBNo`0000OodIVK00?o0000okb8
WOnlR9d00_nlR9dDo`0000WoX7>O00?o0000oh=LWOn3G9d01?n3G9d3o`000003ohEOWol0003oITbN
00?oITbN00Go0000oem;X_l0003oHDfTo`000004oeA4XP06o`000?lD9Z?o3b>Qo`lSXOl0003o002<
0ol0000<oijSf004o`000?nKXMWoVj7Ioi^Qf@Go00000_nIW=D00ol0003oU9_GoiBKe`09oiBKe`Ko
TIWH0_l00003ohfCe003o`000?n:T]KoRY;F00SoRY;F00?o0000ohFAf?l000002?n2Rm@00ol0003o
O8WFogb9eP02ogb9eP?oN8?A1?l00003og62e003o`000?mXN]7oJ7[A00?oJ7[A00?o0000of9fdOmR
M]400ol00004oeI]cP03o`000?m?JLgo000000GolMJe0_l000001_old9Ko0000ookCToondi?o0000
ooo9L0Co0000>?oonfX00ol0003ooo]ZoookJP0SoookJP007ooonfX00ol0003ooo]ZoookJP1Doook
JPKo00000_lN03L2o`0000GoBPmQ0_l000000omW<gco0000ofPdO004ofPdO0?o00001omlCi000ol0
003oQEJAohEFT@02ohEFT@?o000000?oRfBOo`000?nBJJ002OnBJJ02o`0000OoVg:S1?l0000;oj:0
[`;o00002_nZQjl00ol0003o[8J]ojb6[@02ojb6[@03o`000?n]R:ko[HR^00Co[HR^00?o0000ok6;
[_naRjh01?naRjh00ol0003o/Xf_o`000002o`0000;o/Xf_00?o0000okVA[OniTJd00oniTJd00ol0
003o]i2^okN@[P04okN@[P03o`000?nkTZgo^i:]00;o^i:]00?o0000okbF/OnlU[401onlU[400ol0
003oa9b^olBL[P07olBL[P03o`000?o1W;;o`Ibb00;o`Ibb00?o0000olJK[?o6Vj`00_o6Vj`00ol0
003obZ:_olZR[`02olZR[`Ko00001?o@Vil00ol0003oci^QolnKX@04olnKX@05o`000?o@WZCod9jT
om2NY?l000000_oDWYl3o`0000?oeiVA00?o0000omVKTOoIVi400ooIVi400ol0003ofijBom^NTP03
o`0000?ohYMm00Co0000onBIO?oTVGcoi9Ul0_l00002onJ>HP04o`000?oXT5ooj91Oo`0000;oiGhk
00Co0000onIl<Ol0003of6830ol0000joookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oo
nfX0;?oonfX00ol0003ocLODolg7e004olg7e0?o00001Oo8aML00ol0003oal?FolO3eP04olO3eP05
o`000?o6`MGoa/7EolK1eOl000000oo5`=H3o`0000Go`KoH0_l00003ol2me`04o`000?no_=So_kcH
oknlf0;o00001onn^]H01ol0003o_KWFo`000?nk^=Oo0000onZlY?l000000_oZ^j<00ol0003ohJnR
on6_XP03on6_XP03o`000?oCXZGodj:U00Co00001_oAVI/00ol0003o_8RMokb8W@06okb8W@;o0000
3?ndPj000ol0003oX7>Ooj1cW`0:oj1cW`04o`000?n3G9goPebMoh=LW@;o00001?n5Gil00ol0003o
ITbNofI<WP02ofI<WP;o00000_mQCJ@00ol0003oE4BRoeA4XP02oeA4XP05o`000?lD9Z?o3b>Qo`lS
XOl000000_l008`3o`0000coWZ?H1Ol00006oiVLe@03o`000?nDVmOoU9_G00WoU9_G1?nAVMP00ol0
003oSI?DohfCe004ohfCe003o`000?n:T]KoRY;F00SoRY;F00?o0000oh:;e?n2Rm@02?n2Rm@01?l0
003oO8WFogb9e_l00006ogR3d@;o00000_maP]@00ol0003oJ7[AofQjd@04ofQjd@03o`000?mRM]7o
HWKA00;oG6c;00Co0000oeI]c_mFKLkoEVg>0ol00004oo7F]@03o`000?ocfKGo000000;o00000_on
di<01?l0003oolU`o`000?onb6T3o`0003Oooo]Z00?o0000oookJ_oonfX08ooonfX001oooo]Z00?o
0000oookJ_oonfX0E?oonfX5o`0000;o7P0g00?o0000ocT0F_l000001?m:3f401Ol0003oFRUio`00
0?mW<gco000000CoJ3Al0_l00009oga?T003o`000?n5EY7o000000;o00001?n;I9l00ol0003oTVVP
oi9YX007oi9YX0;o00000onKLZ<5o`0000;oWGb^00?o0000oj:0[onRP:l02OnRP:l2o`0000_oZXN_
00Go0000ojb6[On/QZgo[8J]o`000008ojf8[P03o`000?naRjko/H^^01Go00000ongT:h01?l0003o
^i:]ok^B[Ol0000:okbF/@03o`000?o4W:koa9b^00Koa9b^00?o0000ol6L/_o1W;800oo1W;801Ol0
003oaY^/olJK[?o6Vjco000000SobZ:_00?o0000olNR/_l000000_l00002om2KW`03o`000?o?Vj7o
ci^Q00Coci^Q00?o0000om2NY?o@WZ@00_o@WZ@00ol0003oe9jOo`000002omRTX0Co00001OoIVi40
1Ol0003ofijBom^NT_l0003ogYj?00;o00000_oRUgd00ol0003oi9UlonBIO002onBIO0;o00000_oV
SV800ol0003oj91OonR@G`03o`0000;oiW`a0_l000000ooCG03o0000o`00000ioookJP03o`000?oo
nf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0003ocLODolg7e004olg7e005o`000?o<
aM?oc<GCol_5e?l000000oo8aML00ol0003oal?FolO3eP03olO3eP;o00001Oo6`MD00ol0003oaL3F
o`000003olBne@?o000000?o`KoHo`000?o0_ML01Oo0_ML00ol0003o_kcHo`000007okjjeP;o0000
0onm^MH01?l0003oj[bTonZlY?oZ_:@2o`0000GohJnR00?o0000om>RYOoCXZD00_oCXZD00ol0003o
fZJPo`000002o`0000CodIVK00?o0000okb8WOnlR9d01_nlR9d00ol0003o]8>PokB3X00:okB3X0;o
00003?nPLil4o`0000KoQEnO00Go0000ofI<W_mVC9koITbNo`000002ofM=X003o`000?mQCJCo0000
00?oE4BR00Wo0000oc8aX?l0003o52JSo`000?l/=j_o0000o`00S?l007D00ol00005oijSf0Co0000
0_nOX]L00ol0003oVj7Ho`000008oiVLe@03o`000?nDVmOoU9_G00WoU9_G00Co0000oi6If?nAVMSo
00001on=Tm@00ol0003oRY;FohZBeP07ohZBeP;o00002_n2Rm@00ol0003oO8WFo`000008ogR3d@03
o`000?maPM?o000000;o00001OmXN]400ol0003oHWKAo`000003oea/b`05o`000?mFKLkoEVg>oeI]
c_l000001Ooae[D01Ol0003olmVeo`000?l0003oo=RL00;o000000?oomJ?o`000?l000001?l0000g
oookJP03o`000?oonf[ooo]Z02?ooo]Z000OoookJP03o`000?oonf[ooo]Z05?ooo]Z1Ol00002oah0
=`04o`000?li05[o>@1Jo`0000;oBPmQ0_l00002oeXYN@05o`000?mW<gcoIc=lo`000?mX=7`00_l0
00000omcAhoo0000oga?T007oga?T0?o00001on;I9l00ol0003oTVVPoi9YX004oi9YX0So00002?nM
O:h00ol0003oXX2_oj:0[`07oj:0[`03o`000?nSPk7o000000coZXN_4Ol00008okJJ_003o`000?nf
U[Oo]YJg00;o]YJg00?o0000okZN^onjW[/00onjW[/;o`0000Go_9Ja00?o0000okfH/Ol000001oo4
W:h00ol0003o`Ibbol6L/P03ol6L/P04o`000?o6VjcoaY^/o`0000SobZ:_00Co0000olNR/_o7X[;o
00000_o<XJ`4o`0000Goci^Q00?o0000om2NY?o@WZ@00_o@WZ@00ol0003oe9jOo`000005omRTX0;o
00000ooIVi401_l0003ofijBom^NT_oKWY;o0000omjNS`Go00001?oTVG`00ol0003oiiajo`000002
o`0000;oj91O00Go0000on^AFol0003o0000onIl<@03o`000003om=L0?l0003ooo]Z03Sooo]Z00?o
0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?o=amCocLOD00CocLOD00?o
0000olc5doo<aM<00_o<aM<2o`000003olS5eol0003oal?F00Coal?F00?o0000olK1eOo6`MD01Oo6
`MD2o`0000Ooa;kE0_l00006ol2me`;o00001onn^]H00ol0003o_KWFokfieP03okfieP03o`000?oZ
_:Coj[bT00;oj[bT0_l00004on6_XP03o`000?oCXZGodj:U00;odj:U00?o0000omZVX?l000000_oA
WZ83o`000003om6IVol0003o_8RM00Oo_8RM00?o0000okB3X?ndPj002_ndPj02o`0000[oX7>O0ol0
0009ohEOW`04o`000?mVC9ko0000o`0000CoIdfP00Go0000of5=Y?mDA:;oE4BRo`000003oc8aX0;o
00000_l/=j/00ol008co0000o`000002o`0000;oWZ?H0ol00006oinRe`;o00002_nIW=D00ol0003o
U9_GoiBKe`06oiBKe`;o000000?oU9_Go`000?l000006_l00005oh:;e003o`000?mhPm7oN8?A00So
N8?A00Co0000ofeic_m]NLkoKGW>0ol00002ofQjd@03o`000?mRM]7o000000GoG6c;0_mFKLh00ol0
003olMJeoo7F]@02oo7F]@05o`000?ocfKGolmVeoo?I]Ol000000_olf9`8o`0003Oooo]Z00?o0000
oookJ_oonfX08ooonfX001oooo]Z00?o0000oookJ_oonfX0D_oonfX6o`000006oah0=ol0003o0000
ocT0F_l0003oBPmQ0_l00004oeXYN@03o`000?mW<gcoIc=l00;o00000omcAhl00ol0003oO4n@oga?
T004oga?T0;o000000?oPefNo`000?n;I9l02?n;I9l01?l0003oTVVPoi9YX?nBJJ05o`0000;oUgV_
00?o0000oiel[_nMO:h02?nMO:h00ol0003oXX2_oj:0[`05oj:0[`;o00000_nSPk400ol0003oZXN_
ojZ7[`04ojZ7[`So00002?naUK/4o`000003ok6B]ol0003o]YZl00Wo]YZl00Co0000okJF]onfU[Oo
00002_njW[/00ol0003o_j6joknQ^P04oknQ^P_o00000oo4W:h00ol0003o`Ibbol6L/P05ol6L/P;o
00002?o:XZl00ol0003oaj:bolNR/P02olNR/P04o`000?o<XJcoc:6/o`0000;od:J^0ol000000oo?
Vj7o0000om2NY004om2NY0;o00001_oHY:000ol0003of:BQo`000003o`0000CofijB0ol00002on:S
SP;o00000ooTVG`01?l0003oiiajonNLN_oWW7X2o`000004onR@Gol0003oji5Kon^AF`?o000000?o
j80`o`000?oCG0000_l0000hoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0:Ooo
nfX00ol0003ocLODolg7e004olg7e003o`000?o<aM?oc<GC00?oc<GC1?l00004olO3eP03o`000?o6
`MGoa/7E00Goa/7E00?o0000olFoe?l000001Oo4_]D01?l0003o`kcDol>le?o3_=@2o`0000?o`;gG
00?o0000oknke_l000001_nn^]H00ol0003o_KWFokfieP04okfieP03o`000?oZ_:Coj[bT00;oj[bT
00Co0000on:bY?l0003o00000_oQ[j800ol0003odj:Uom>RY@03om>RY@03o`000?oAWZ;odIjR00Co
dIjR0ol00006okb8W@;o00002ondPj000ol0003o/7jNok1nWP06oj1cW`Co00000_nOLj400ol0003o
QEnOohEOW`07ohEOW`;o00001omWCJ000ol0003oE4BRo`000005oc8aX006o`000?l/=j_o;3N[ob`g
Zol0003o001e1?l00007oinRe`;o000000?oWIgDo`000?nIW=D02OnIW=D01?l0003oU9_GoiBKeonD
VmL5o`0000;oUI[F0_l0000:ohnDd`03o`000?n:T]KoRY;F00CoRY;F00Go0000ohJ;dOn6Rm7oQX_A
o`000005oh>;d`?o000000?oPX_Do`000?l000002_mhPm400ol0003oKGW>ofeicP04ofeicP;o0000
00?oJ7[Ao`000?mLK</01_mLK</00ol0003oimS6o`000002oo7F]@03o`000?ocfKGolmVe00;olmVe
00Co0000oocHW?olf9co00000_onfiP3o`000003oo_>I_l0003o000003Kooo]Z00?o0000oookJ_oo
nfX08ooonfX001oooo]Z00?o0000oookJ_oonfX0D_oonfX4o`000006o`H0;?l0003o0000ocD0F?l0
003o>@1J0_l00006oeXYN@03o`000?mW<gco000000;o00001?mcAhl00ol0003oO4n@oga?T003o`00
00?oPefN00?o0000oh]TWon;I9l01on;I9l5o`0000KoUgV_00?o0000oiel[_nMO:h02?nMO:h00ol0
003oXX2_oj:0[`03oj:0[`;o00000_nSPk49o`0000GoZHji0_l00006ok6E^`?o00000onaUK/2o`00
00_o]YZl00?o0000okJF]ol000002_njW[/00ongWKgo0000oknQ^P08oknQ^P05o`000?nlXl3o_:?0
okbS`?l000000oo0X;P8o`0000?o`Ibb00?o0000olZR[oo:XZl01oo:XZl00ol0003oaj:bolNR/P02
olNR/P03o`000?o<XJco000000Kod:J^1Ol00003om2NY003o`000?oHY:3of:BP00?of:BP00?o0000
omRTXOoHY:400ooHY:42o`0000?ofijB00Oo0000on:SS_oRXhko0000on:SS_l0003ohjB?00Co0000
0ooWW7X01?l0003ojYiho`000?l00002on^AF`03o`000?o]TeOo000000Ko0000=ooonfX00ol0003o
oo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000olg7e?o=am@01?o=am@00ol0003o
c<GColc5d`03olc5d`03o`000?o;`m;o000000;ob/;C0_l000000oo7`mKo0000olK1e@06olK1e@05
o`000?o5_mCoaKoDolFoe?l000000oo4_]D00ol0003o`kcDol>le004ol>le003o`000?o0_MOo0000
00?o_k_F00Co0000okjje_nn^]Ko_[[F0_l00006okfieP03o`000?oZ_:Coj[bT00;oj[bT00?o0000
on:bY?oR/Z@00_oR/Z@2o`0000Kodj:U00?o0000om6NX_oAWZ801?oAWZ800ol0003oai:NolNBWP04
o`0000;o_8RM00?o0000okj:W_l000002_ndPj000ol0003o/7jNok1nWP02oj1cW`Co00001_nOLj40
0ol0003oQEnOohEOW`06ohEOW`;o00002OmWCJ000ol0003o<S6Poc8aX004oc8aX006o`000?l/=j_o
;3N[ob`gZol0003o00280_l06jP2o`0000GoWj;G0_l00004oifMe003o`000?nIW=GoVIcE00?oVIcE
2?l00006oiFJeP03o`000?nCU=;o000000_oSiCC00?o0000ohZBe_n:T]H00_n:T]H00ol0003oQX_A
ohJ;d@03ohJ;d@03o`000?n3Rm?oPh_C00KoPh_C00?o0000ogf3col000000_l00007ogR3d@03o`00
0?m]NLkoKGW>00OoKGW>0_l00005oea/b`07o`000?oWf<KoimS6onOHa_l0003olMJeo`000003oo?I
]@04o`000?odgKCo0000o`0000?oo]^H0ol000000ookcVKo0000o`00000foookJP03o`000?oonf[o
oo]Z02?ooo]Z000OoookJP03o`000?oonf[ooo]Z057ooo]Z0ol000001ol002Ko0000o`000?l0003o
=@1Ho`000?li05X00_l00006oeXYN@?o00000ombB902o`0000;oLdN?0ol00006oh=MWP03o`000?n;
I9ooRfBO00GoRfBO1?l00009oiMi[`03o`000?nMO:koWGb^00WoWGb^00Co0000oj:0[onRP:ooXX2_
1Ol00002ojN?_003o`000?nYS[WoZHji00SoZHji00?o0000ojfG`?l000000onaUK/3o`0000Go/IFk
0_l0000<okJJ_0;o00002OnjW[/01?l0003o]ifmokNM_Ol00008oknQ^P03o`000?nlXl3o_:?000?o
_:?000Go0000ol2P^?o0X;So`:2ho`000006olBW_0So00001?o:XZl00ol0003oaj:bolNR/P03olNR
/P03o`000?o<XJco000000Ood:J^00Co0000oljV/?o>Y[3ocZJ`1?l00005omRTX003o`000?oHY:7o
f:BQ00?of:BQ00?o0000omVVX_l000000ol00003on:SSP;o00001?oSY8l2o`0000;oiiaj00?o0000
onZNN?oZWWP00_l000002?o[TE_o0000onfCEoo]TeOo0000onMn;Ol0003oj80X0ol0000foookJP03
o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX09_oonfX3o`0000GocLOD00?o0000olc5doo<
aM<00oo<aM<01Ol0003obl?Bol_3d_o;`m;o000000?ob/;C0_l00005olK1e@;o00001Oo5_m@00ol0
003oa;kEo`000008ol>le0;o00001?no^mH00ol0003o_[[Fo`000007okfieP?o00000ooZ_:@00ol0
003oh[:Ton:bY003on:bY0;o00001OoCXZD00ol0003odIjRom6NXP03om6NXP03o`000?o7TYkoai:N
00Goai:N5?l0000:oimcX@03o`000?n5GiooQEnO00CoQEnO0_l000000on9I:7o0000ofM=X007ofM=
X003ogEHXom@AJKo000000Co<S6P00?o0000oc]1[_l000000_l/=j/00ol06Z7o0000o`Dd]P02o`0K
Z0;o00000_nOX]L2o`0000CoWIgD2?l00005oiZLe003o`000?nEV]KoUI[F00GoUI[F00Go0000oi>D
d_nCU=;oTiCBo`00000;ohnDd`04o`000?n:T]KoRY;Fo`0000KoQX_A00?o0000oh>;don3Rm<01On3
Rm<00ol0003oOH??ogf3c`03ogZ3d@?o00000omhPm400ol0003oL7_>o`000008ofeicP;oH6k:00?o
0000oea/bomLK</00_mLK</00ol0003oimS6onOHaP02onOHaP03o`000?ocfKGolmVe00;olmVe00Co
0000ooCM]?odgKCo00000_onfiP3o`0000;onliV0_l0000goookJP03o`000?oonf[ooo]Z02;ooo]Z
000NoookJP03o`000?oonf[ooo]Z057ooo]Z0ol000001?l002Ko0000o`000?l00002ocD0F0;o0000
00?oBaeeo`000?mJ:GT01?mJ:GT00ol0003oIcn>o`000006og98T003o`000?mcAhoo000000SoPefN
00?o0000oh]TWon;I9l01_l000000onAM:oo0000oiMi[`0:oiMi[`03o`000?nMO:koWGb^00KoWGb^
1ol00007ojN?_003o`000?nYS[WoZHji00GoZHji00?o0000ojfG`?n]Ul000_n]Ul03o`0000Oo/IFk
00?o0000ojnG__l000002_nfV[`2o`000003ok>J__l0003o^Yjk00Oo^Yjk00?o0000okNM_OngWKd0
0_ngWKd00ol0003o_j6joknQ^P04oknQ^P03o`000?nlXl3o_:?000Co_:?000Co0000ol2P^?o0X;So
00002Oo4Yk`2o`0000CoaJJi1_l00005olNR/P03o`000?o@YZkod:J^00God:J^00?o0000oljV/?o>
Y[001?o>Y[05o`0000;of:BP00?o0000omRTXOoHY:400_oHY:400ol0003ofJJRomVVXP03omVVXP?o
00000_oRXhh00ol0003ohjB?on>TS`02on>TS`05o`000?oVYhoo0000onNLN_l000000_oZWWP01_l0
003ok:5fo`000?o[TE_o0000onfCE`;o000000?oigh]o`000?oXP2P00ol0000foookJP03o`000?oo
nf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX09OoonfX2o`0000;od<OA00Go0000olg7e?o=amCocLOD
o`000005olc5d`03o`000?o;`m;obl?B00?obl?B00?o0000ol[2dol000000_o9`=801Ol0003oa/7E
olK1eOo6`MGo000000OoaKoD0_l00006ol>le0;o00000oo2^]<3o`000003oknke_l0003o000000Oo
_KWF00Go0000okbgeOl0003oj[fVo`000002onZlY003o`000?oR/ZCoh[:T00?oh[:T00?o0000omVX
Y?l000000_l000000ooCXZGo0000o`000005om6NXP03o`000?o7TYkoai:N00Koai:N00Co0000okj;
X?nnRj3o00002OndQJ801Ol0003o/7nOok1oWon`Oioo000000_oWg>Q00?o0000ohEOWon5Gil00_n5
Gil2o`0000?oRFBQ00?o0000ofM=X?mWCJ001OmWCJ02ogEHX`;oD4FV00Co0000oc8aX?lb<J3o0000
0_lk@Jh00ol0003o;3N[o`000002o`0JX@07o`000?l5=;Ko01^Xo`0NXol0003oWj;Go`000003oifM
e0?o00000_nMWM<00ol0003oVYcDoiZLe009oiZLe003o`000?nEV]KoUI[F00?oUI[F00?o0000oi>D
d_nCU=800onCU=800ol0003oSiCCohnDd`08ohnDd`03o`000?n:T]Ko000000SoQX_A00?o0000oh>;
don3Rm<00on3Rm<00ol0003oOH??ogf3c`02ogf3c`OoNX?A1_l00005ofeicP03o`000?mQK/WoH6k:
00;oH6k:00?o0000oea/bol000001OoWf<H01Ol0003olmVeoo?I]OocfKGo000000?om=fd00Ko0000
ookKV?onfiSo0000ookMUOl00002oo_>IP;o0000=ooonfX00ol0003ooo]ZoookJP0RoookJP007_oo
nfX00ol0003ooo]ZoookJP1@oookJP?o000000Ko000Vo`000?l0003o801@o`000?le05P2o`0000;o
Baee00Co0000oeXYNOmJ:GWoFRUi0_l00002ofLoSP03o`000?mbB93oLTR@00CoLTR@4Ol00004oi5d
[`03o`000?nGNJooUgV_00WoUgV_00?o0000oiel[_nMO:h00_nMO:h4o`000004oin6^?l0003o0000
o`0000[oYhnl00?o0000ojV>^OnYS[T00onYS[T00ol0003o[IO0ojfG`005o`0000Oo/IFk0_l00003
ojnG_P03o`000?nfV[co]YZl00Ko]YZl00Go0000ok>J__ncV[ko/iZno`000007okZN^`03o`000?ng
WKgo]ifm00?o]ifm00?o0000oknQ^_noXKX00onoXKX00ol0003o_:?0okbS`005okbS`003o`000?o0
X;So000000Woa:Nl00Co0000ol2X`_o0Z<;o00001Oo5Y[T01?l0003obJfmolV]_Oo9[Kd3o`0000;o
aj:b00?o0000om2V[_o@YZh01?o@YZh00ol0003ocZJ`oljV/004oljV/003o`000?o>ZK?o000000?o
djV]0ol00004omRTX@03o`000?oIYZ;ofJJR00?ofJJR0_l000000ooNZYoo0000o`000002o`0000?o
hjB?00?o0000onJWSooVYhl00_l00002onZNN003o`000?o/XGKok:5f00;o000000?okI=Go`000?o`
Ue800_l000001?oXP2So0000o`000?l0000foookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oook
J_oonfX09?oonfX01?l0003odLO@om77d?l00002om37d@03o`000?o=amCo000000Goc<GC00?o0000
ol_3d_o;`m801?o;`m82o`0000CobL3B00?o0000olK1eOl000001oo5_m@01?l0003oa;gColBmdol0
0004ol>le003o`000?o2^]?o`[[C00Ko`[[C1?l00004okfieP;o000000?o_;OEo`000?oZ_JH00_oZ
_JH2o`0000Goh[:T00?o0000omVXY?oIZ:@00ooIZ:@4o`0000CodIjR00?o0000olNBW_o7TYh01Oo7
TYh01Ol0003o_X^Pokj;X?nnRj3o000000So]8FR00?o0000ok1oWon`Oil00_n`Oil00ol0003oWg>Q
oimcX@09oimcX@03o`000?n5GiooQEnO00;o00001On9I:400ol0003oIdfPofM=X004ofM=X0?oMERS
0om@AJH00ol0003o<S6Po`000002oc]1[P?o00000_l06Z401ol0003o1CBfo`Dd]_l06jSo01jSo`00
0?nMWM@00ol00006oifMd`03o`000?nJW=CoVYcD00WoVYcD00Co0000oiFJe_nEV]KoUI[F1onCU=80
0ol0003oSiCCohnDd`09ohnDd`03o`000?n6Rm7oQX_A00OoQX_A00?o0000oh>;don3Rm<00_n3Rm<0
0ol0003oOH??ogf3c`03ogf3c`03o`000?mjPm7oNX?A00CoNX?A00Co0000og=lc_mcO<ko00000_m]
NLh2o`0000;oKGW>00?o0000of5^bOmQK/T01OmPK/X00ol0003oimS6onOHaP02onOHaP05o`000?oX
flOo0000oo?I]Ol000000oodgK@01ol0003om^2co`000?onfiSo0000ookMUOl000000_okcVH2o`00
03Oooo]Z00?o0000oookJ_oonfX08_oonfX001kooo]Z00?o0000oookJ_oonfX0CooonfX4o`000004
o`009_l0003o801@ob00D0;o000000KoB1]do`000?m;7GGoBaeeo`000?mJ:GT2o`0000CoIcn>00Co
0000og98T?mbB93oLTR@0ol00002og]JX003o`000?n4HJ;oQ66R00KoQ66R0ol00008oi5d[`03o`00
0?nGNJooUgV_00SoUgV_00?o0000oiel[_l000000_l00003oin6^0;o000000?oXXjoo`000?nWSk`0
2_nWSk`00ol0003oZHjiojV>^@02ojV>^@Co00001?n]Ul000ol0003o/IFkok6E^`03ok6E^`;o0000
1On_Ukh00ol0003o]YZlokJJ_004okJJ_0;o00001OncV[h00ol0003o^YjkokZN^`03okZN^`03o`00
0?ngWKgo]ifm00Co]ifm00?o0000oknQ^_noXKX00_noXKX00ol0003o_:?0okbS`007okbS`003o`00
0?o4Ykcoa:Nl00Ooa:Nl00Go0000ol2X`_o0Z<;o`:S2o`000004olFV^@03o`000?o9[KgobJfm00Go
bJfm1Ol00004om2V[P03o`000?o>Y[3ocZJ`00CocZJ`00Co0000oljY/oo>ZK?o00000ooCZJd00ol0
003of:j^o`000002o`000003omRTXOl0003ofJJR00?ofJJR00?o0000omZZYOl000000ooNZYl3o`00
0003on>TSol0003oiZN?00?oiZN?0_l00002onZNN003o`000?o/XGKok:5f00?o00000oo`Ue85o`00
03Gooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oAam3odLO@
00;odLO@00?o0000om37dOl000000_l00004olc5d`03o`000?o;`m;obl?B00Cobl?B00Co0000ol[1
dOo:`M7o00001?o9`=82o`0000KoaKoD00?o0000olBmdoo4_M<00_o4_M<01?l0003o`kcDo`000?l0
0007ol:jd`03o`000?o1^=;o`KSB00;o`KSB0ol000000onm^MKo0000okbge@02okbge@03o`000?oZ
_JKoj[fV00;oj[fV0_l00004on:bY003o`000?oIZ:CofJRT00?ofJRT00?o0000olbLY_o<W:H00ol0
00000ooAWZ;o0000olNBWP07olNBWP05o`000?nnRj3o_X^Pokj;X?l000001ondQJ800ol0003o/7nO
ok1oW`03ok1oW`03o`000?nOLj7oWg>Q00WoWg>Q0ol00008ohUTX@04o`000?mWCJ3oIdfPofM=X0Ko
MERS0om@AJH00ol0003o>d6^oc]1[P02oc]1[P;o00000ol06Z400ol0003o1CBfo`Dd]P03o`0000Wo
WIgC00?o0000oiZLe?nJW=@02OnJW=@00ol0003oUI[FoiFJeP04oi>DdR7o00001?mmPll00ol0003o
NX?AogZ3d@03ogZ3d@03o`000?mcO<koLgc>00;oLgc>00?o0000ofeic_m]NLh00_m]NLh2o`0000?o
HFk90omPK/X00ol0003oimS6onOHaP02onOHaP06o`000?oXflOoj=_7o`000?ocfKGo00000oodgK@0
1?l0003om^2co`000?l00002ookMU@?o000000?omlaMo`000?l00000=_oonfX00ol0003ooo]Zoook
JP0RoookJP007_oonfX00ol0003ooo]ZoookJP1>oookJP?o000000?o000Io`000?l000000_lP0502
o`0000;oB1]d00?o0000od/MMOm;7GD00_l00006ofLoSPCo00001OmkFZ000ol0003oQ66RohAQXP03
ohAQXP?o000000?oRW2_o`000?nAM:l02?nAM:l00ol0003oUgV_oiMi[`06oiMi[`Co00001?nOQ[P2
o`0000CoXXjo00?o0000ojN?_?nWSk`02OnWSk`00ol0003oZHjio`000002o`0000So[IO000Go0000
ok6E^onaUK_o/IFko`000003ojnG_PKo000000?o]YZlo`000?l000005?l00003okNM_@04o`000?no
XK[o_j6jo`0000Wo_:?00_l00008olBW_003o`000?o0Z<;o`:S200?o`:S200Co0000olFV^Oo5Y[Wo
00002Oo9[Kd01?l0003oaZg1o`000?o;Z[P2o`000003om2V[_l0003ocZJ`00GocZJ`00Go0000oljY
/oo>ZK?ocZVco`000002om>Y[@03o`000?oH[Zkof:j^00?of:j^0_l00004omVVXP04o`000?oJZZGo
fZZUo`0000;ogZZO00?o0000on>_Wol000000_l00004onJWS`03o`000?oXZXko000000;o00000_o/
XGH01?l0003okj=do`000?l00002oo2GDP03o`000?oXP2So000000?o0000=?oonfX00ol0003ooo]Z
oookJP14oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000om77d?oAam001?oAam001?l0003oclC@
olo4d?o?a=02o`000003olc5dol0003obl?B00Gobl?B00?o0000ol[1dOo:`M400_o:`M400ol0003o
bL3Bo`000003olRnd@;o00000oo5_m@00ol0003oa;gColBmd`04olBmd`03o`000?o2^]?o`[[C00Ko
`[[C00?o0000ol6hd_o1^=801?o1^=800ol0003o_kSCo`000002o`0000;o_;OE00?o0000onZmY_oZ
_JH00_oZ_JH00ol0003ohkBUo`000002o`000003on:bY?l0003ofJRT00?ofJRT00Go0000olbLY_o<
W:Koc9bVo`000002om6OX`Co00001_o7TYh00ol0003o_X^Pokj;X002okj;X003o`000?ndQJ;o]8FR
00Co]8FR00?o0000ok1oWon`Oil01?n`Oil00ol0003oWg>QoimcX@05oimcX@Co00002_n9I:400ol0
003oIdfPofM=X007ogEHX`;oD4FV0_l00004oc]1[P;o00000ol06Z401Ol0003o1CBfo`Dd]_l0003o
002A00;o00002OnMWM<00ol0003oVYcDoiZLe006oiZLe003o`000?nJW=Co000000Ko00001OnDUM40
0ol0003oSi?CohnCd`05ohnCd`04o`000?n<SLooS8g?o`0000[oRHgA00?o0000oh>;dol000000on1
QLh4o`000003ogf3col0003oNX?A00;oNX?A00?o0000og=lc_mcO<h00omcO<h00ol0003oKGW>ofei
cP02ofeicP;oJ7370_l000001?mQK/WoH6k:of1^b_l00005onOHaP05o`000?oXflOoj=_7onSKaol0
00000oodgK@01_l0003om^2cooKP/oofh;?o0000ookMU@Co000000?omlaMo`000?l00000=_oonfX0
0ol0003ooo]ZoookJP0RoookJP007_oonfX00ol0003ooo]ZoookJP1>oookJPKo00000_lP05001_l0
003oB1]dodPKM?m86gCo0000od/MM@;o00001_mW?hh2o`0000SoNeZP00Co0000ohAQX_n4HJ;oQ66R
0_l00004ohY`[`03o`000?nAM:ooTGB_00OoTGB_00?o0000oiMi[onGNJl00onGNJl3o`0000;oVX>i
00Co0000oin6^?nOQ[SoWhJh0_l00006oj:>_`03o`000?nWSkcoYhnl00SoYhnl0ol00008ojfG`0_o
00001On/VlH01?l0003o/Yk4ok:Na?l00009ojnNaP04o`000?nfXLCo]Z74o`0000Oo/j351_l00002
okbS`0?o00001?nlXl001?l0003o_:C1okbT`Ol00006olBW_003o`000?o0Z<;o`:S200Co`:S200?o
0000olFV^Ol000002Oo9[Kd01Ol0003oaZg1olJ]`Oo6[L7o000000;objZh1Ol00003oljV/007o`00
0?o>ZK?ocZVcoljY/ol0003odjV]o`000006omR^[P03o`000?oG[k3o000000;o000000OofJJRo`00
0?oJZZGofZZUo`000?oNZYoo000000?ohjnO0ol00003onJWS`04o`000?oXZXkoj:Z>onRZSP;o0000
00?ok:5fo`000?o_Xg@00_l00002oo2GDPOo0000<ooonfX00ol0003ooo]ZoookJP14oookJP03o`00
0?oonf[ooo]Z02;ooo]Z00?o0000om77d?oAam001?oAam02o`0000GoclC@0_l00005ol_3dP03o`00
0?o:`M7ob/7A00Cob/7A00?o0000olRndOo8_]401?o8_]400ol0003oaKoDo`000006olBmd`03o`00
0?o3^m;o000000Go`[[C0_l00008ol6hdP04o`000?nn]];o_[KBokjfdP;o00001?oZ_JH00ol0003o
hkBUon>dY@03on>dY@;o00001?oIZ:@01Ol0003oc9bVolbLY_o<W:Ko000000?odInS00?o0000olVI
YOo9VJD01?l000000oo7TYko0000okj;X004okj;X003o`000?ndQJ;o]8FR00?o]8FR00?o0000ok1o
Won`Oil01On`Oil00ol0003oWg>QoimcX@05o`0000?oWW>R00?o0000ohUTXOn9I:402?n9I:400ol0
003oIdfPogEHX`07ogEHX`05oe15Y_l0003oDDJWoe56Yol000000olk@Jh00ol0003oADR`o`000002
o`0JX@;o000000Co1CBfo`000?l0003o03:i0_l00008oifMd`04o`000?nJW=CoVYcDoiZLe0Ko0000
0_nHU]000ol0003oU9GAoiBEd@09oiBEd@03o`000?n?Tm?oSi?C00;oSi?C0_l00004ohb=c`03o`00
0?n9SM7oRHgA00SoRHgA00?o0000oh65c_n1QLh01_n1QLh7o`0000GoLgc>00Co0000ofeic_m]NLko
00001?mXL<L4o`0000CoimS600?o0000onSKaooXflL00_oXflL2o`0000;om=fd00Ko0000ooKP/oof
h;?om^2co`000?ongID2o`000003ookOT?l0003omlaM00;o0000=_oonfX00ol0003ooo]ZoookJP0R
oookJP007_oonfX00ol0003ooo]ZoookJP1=oookJP?o000000Go000Io`000?lJ04go0000ob00D002
o`0000?oB1]d0_l000000omJ=X_o0000ofLoSP04ofLoSP03o`000?mbE:3o000000SoNeZP1?l00006
ohY`[`03o`000?nAM:ooTGB_00SoTGB_00?o0000oiMi[ol000000_l00006oiZ3^@?o00002OnRS[l0
0ol0003oYhnlojN?_004ojN?_0?o000000?oYi?2o`000?n]Ul000_n]Ul06o`0000?oZi_700?o0000
ojjJ`ol000002on/VlH2o`0000_o[ik60_l0000;ok>Pa@;o00001_njZLP;o`0000;oa:Nl00?o0000
ol2X`_o0Z<801_o0Z<800ol0003obJfmolV]_@07olV]_@03o`000?o6[L7oaZg100;oaZg100Co0000
ol^Z^?o;Z[So00001?o?/K/5o`0000?ocZVc0_l00005omR^[P03o`000?oG[k3oejn`00?oejn`0_l0
0002omZZY@03o`000?oNZYoo000000CohjnO00Go0000on>`X?l0003oiZN?o`000004onRZSP05o`00
0?o[[Hgo0000o`000?o_Xg@00ol000000oo`Ue;o0000oo:HC@05o`0003?ooo]Z00?o0000oookJ_oo
nfX0A?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oAam3odLO@00CodLO@00Co0000om34coo@
a<oo00000oo?a=001?l0003oc/;?olk2col00003ol_3dP03o`000?o:`M7ob/7A00Cob/7A00?o0000
olVnd?l000001_o8_]42o`0000Goa;gC00Go0000ol>kd_o3^m;o`k_Bo`000003ol:jd`03o`000?o1
^=;o`KSB00Ko`KSB00?o0000ol2hd_l000001?nn]]82o`0000?oj[fV00?o0000on>dYOoS]:D00ooS
]:D01?l0003ofj^Uo`000?l00002omVXY003o`000?o<W:Koc9bV00;oc9bV00?o0000om6OXol00000
1oo9VJDHo`0000SoWW>R3?l00008ogEHX`;o00001?mAAZL01?l0003o>d6^o`000?l00002odE8/0;o
00000_l0::d01?l5=;Ko0000o`0LZOl00942o`0U[P;o00001?nMWM<2o`000004oifMdol0003o0000
o`0000?oVY_D0_l00004oiRFd003o`000?nDUM7oU9GA00SoU9GA00?o0000ohnCdon?Tm<00_l00006
ohb=c`03o`000?n9SM7oRHgA00OoRHgA0_l00009oh65cP03o`000?mjPm3o000000?oMgc;0ol00002
og=lcP03o`000?m]NLko000000KoJ73700Co0000omkHdOoNf=7o00000ooWf<H01Ol0003oj=_7onSK
aooXflOo000000;ojMk700?o0000ooCM]?l000000_ofh;<2o`000006ookMUOl0003o0000ookOT?l0
003omlaM0_l0000foookJP03o`000?oonf[ooo]Z02;ooo]Z000MoookJP03o`000?oonf[ooo]Z04go
oo]Z0_l000000ol001;o0000o`000002o`000004ob00D?l0003o=Pe_o`0000;oB1]d0_l00002oeXf
R`04o`000?mW?hkoIcn>ofLoSP;o00000_mbE:000ol0003oNeZPog]JX005og]JX0;o00002_n:L:l0
0ol0003oTGB_oi5d[`05oi5d[`Co00001onJPkT3o`0000_oXXjo00?o0000ojN?_?nWSk`01Ol00000
0onWTl;o0000o`000004o`0000WoZi_70_l0000;ojbKaP;o00002on_W/H2o`0000[o/j350_l00000
0onj/]7o0000okZYb006okZYb003o`000?nn//ko_[;>00?o_[;>00Co0000oknZaOnoZ/Go_j[50_l0
0008ol2X`P;o00002?o9[Kd00ol0003oaZg1olJ]`@03olJ]`@03o`000?o;Z[So000000Oock6k00?o
0000olfa_oo=/Kl01?l00006omR^[P03o`000?oG[k3oejn`00?oejn`00?o0000omRa/Ol000000_l0
00000ooNZYoo0000on>_W`02on>_W`04o`000?oS/:3o0000on>`X0;o00001?oXZXh01Ol0003ojjf=
on^]SOl0003okj=d00;o000000SoljM_o`000?l0003olYQ=o`000?ocVDOo0000onIn5@;o0000<_oo
nfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z023ooo]Z0_l00005om77d003o`000?o@
a<ood<C?00;od<C?00?o0000olo4d?l000001?o>`/l00ol0003obl?Bo`000006ol[1d@05o`000?o9
_]3obKk@olVnd?l000000oo8_]401?l0003oakc@olNld?o7_=03o`000003olBmdol0003o`k_B00Co
`k_B00?o0000ol:jdol000001oo1^=82o`0000?o`;SB00Oo0000okjfd_nn]];o_[KBo`000?oZ_ZSo
000000;oj[fV00?o0000on>dYOoS]:D00_oS]:D00ol0003ofj^Uom^[Y@02om^[Y@;o00001Oo<W:H0
0ol0003odInSo`000008olVIY@03o`000?nhR:;o^8RR00?o^8RR00?o0000okB5XondQJ<00_ndQJ<0
0ol0003o]hRUokN8Y@06okN8Y@03o`000?nNLj;oWW>R00OoWW>R00?o0000oimfY?l000001?n9IjD2
o`0000CoRFRV0_l00005ogEHX`03o`000?m`Fj_o000000CoDDJW00Co0000oc]1[_l0003o?4:_0om5
B;001Ol0003o02R]o`0X[Ol0::go000000;o01bY00Co0000o`0U[_l09Jko01>H1?l00003oijMd`04
o`000?nJVmCoVY_DoiZKe0;o00001_nHU]000ol0003oU9GAoiBEd@08oiBEd@03o`000?n?Tm?o0000
00WoS8g?00?o0000ohV=dOn9SM401On9SM401?l0003oQ8O>ohB7c_l00009oh65cP03o`000?mgO<_o
Mgc;00GoMgc;0ol000000om]NLko0000ofQ`a`03ofQ`a`;o00001?oNf=400ol0003oimS6o`000003
onSKa`03o`000?oYg/OojMk700;ojMk700[o0000ooKP/oofh;?om^2co`000?ogi;;o0000ookOT?l0
003oo]n@1?l0000foookJP03o`000?oonf[ooo]Z02;ooo]Z000MoookJP03o`000?oonf[ooo]Z04co
oo]Z0_l000001?l001;o0000o`000?l204<3o`0000;o=Pe_00Go0000odPKM?l0003oF3F<o`000002
oeXfR`04o`000?mW?hko0000o`0000CoLUBP00?o0000og]JX?mkFZ000omkFZ02o`000003ohA]/Ol0
003oRW2_00WoRW2_00?o0000oi5d[onAM:l00_nAM:l3o`0000;oUGni00?o0000oiZ3^OnJPkT00onJ
PkT3o`0000;oWH_100?o0000oj:>_onRS[l02OnRS[l3o`0000;oYhnl1?l00003ojFIb@03o`000?n[
VlOoZi_700OoZi_70_l000000on^Y]3o0000ojbKaP08ojbKaP;o000000?o/ZcBo`000?n_W/H02?n_
W/H2o`000003okJ_dol0003o/j3500Oo/j350_l00004okZbd@03o`000?njZLSo^ZW800;o^ZW80_l0
0007okjbcP04o`000?noZ/Go_j[5o`0000Go_Zk91ol00006olV]_@03o`000?o6[L7oaZg100CoaZg1
0_l00007olna^`03o`000?o=/KoocK6o00CocK6o00?o0000omR^[_oH[Zh00ooH[Zh00ol0003oejn`
omN_/003omN_/003o`000?oH/K7of;6a00;of;6a0_l00004on>_W`05o`000?oS/:3ohk2Po`000?oS
/:000_l00002onRZSP04o`000?o[[Hgojjf=on^]S@?o000000?ol:Abo`000?ocYfl00ol00002oo>I
A`Co0000<_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z01oooo]Z00Co0000omC6
c?oDa/co00000ooAam000ol0003od<C?om34c`04om34c`;o00001Oo>`/l2o`0000Gob/7A00?o0000
olVnd?o9_]000oo9_]000ol0003ob;kAo`000007olNld0;o00001Oo3^m82o`0000Oo`KSB00?o0000
ol2hd_o0^=801?o0^=800ol0003o_[KBo`000003onZnZ0;o00001OoS]:D00ol0003ofj^Uom^[Y@03
om^[Y@?o00000oo<W:H00ol0003odInSo`000007olVIY@03o`000?nhR:;o^8RR00Co^8RR00Go0000
okB5XondQJ?o]8FSo`000009okN8Y@03o`000?nNLj;oWW>R00GoWW>R0_l00002oimfY003o`000?n9
IjGoRFNU00;o00001_n9J:H00ol0003oLUVWo`000003ogEHX`04o`000?m`Fj_oL5^[o`0000GoDDJW
00Co0000oca2[oll@Zoo00000_m5B;001Ol0003o02R]o`0X[Ol0::go000000?o01bY00Go00NGo`0U
[_l09Jko01>Ho`000006oijMd`03o`000?nJVmCo000000WoV9K@00?o0000oiBEdOnDUM402?nDUM40
0ol0003oS8g?ohb=c`08ohb=c`03o`000?n9SM7oRHgA00CoRHgA00Go0000ohB7c_n4QlkoQ8O>o`00
0008oh65cP;o00002_mgO</00ol0003oJ737ofQ`a`02ofQ`a`03o`000?o>emoo000000Gog]SA00Go
0000onSKaooXflOoj=_7o`000005onWNa`04o`000?ofh;?om^2co`0000;omnBb00Go0000ookOT?on
gi3o0000oogQS003o`0003Oooo]Z00?o0000oookJ_oonfX08OoonfX001gooo]Z00?o0000oookJ_oo
nfX0C?oonfX2o`000003o`004_l0003o0P1300?o00000olf3Fl2o`0000?oF3F<00Co0000oeXfRol0
003o00001ombE:000ol0003oNeZPog]JX002o`0000?oQ6fa00?o0000ohY`[on:L:l02?n:L:l00ol0
003oTGB_o`000002o`0000KoUGni00?o0000oiZ3^Ol000000_l00006oif;`@03o`000?nRS[ooXXjo
00GoXXjo2?l00008ojFIb@03o`000?n[VlOoZi_700?oZi_70ol00004ojjVd003o`000?n/VlKo[9_6
00Go[9_600?o0000ok:/d_nb[=800_nb[=800ol0003o[ik6ojnNaP05ojnNaP03o`000?nf[m?o]ZoC
00;o]ZoC00?o0000ok>PaOncX<D01?ncX<D00ol0003o^[;AokZbd@05okZbd@?o^ZW800?o0000okjb
c_nn//h01onn//h00ol0003o_j[5o`000007okj^b@03o`000?o2^=3o`[S@00;o`[S@1?l00002olV]
_@03o`000?o6[L7oaZg100CoaZg100?o0000olJ]`Ol000001_o?/K/00ol0003ocK6oolfa_`05olfa
_`Co00000_oH[Zh00ol0003oejn`omN_/003omN_/003o`000?oH/K7of;6a00?of;6a0_l00003on>_
W`07o`000?oS/:3ohk2Po`000?oS/:3o0000onFcX003o`0000?ojjf=00?o0000onj`SOl000000_l0
00000oocYfoo0000ooFYK002o`000005oo>IAol0003o0000on9l2ol00000<_oonfX00ol0003ooo]Z
oookJP13oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000omC6c?oDa/`00_oDa/`00ol0003odLO@
o`000006om34c`04o`000?o?`/kocl;>o`0000?oc/;?00Co0000olg0c_o=`<ko00000oo:`M400ol0
003obKk@olVnd004olVnd0;o00001_o7_=001?l0003oa[[?olJjcoo6^/l3o`000004ol>kd_l0003o
`[WBo`0000Ko`KSB00?o0000ol2hd_o0^=801Oo0^=83o`0000Coj[jX0_l00003on>dY@03o`000?oK
ZjGofj^U00Cofj^U00?o0000om:RY_oBXZH00ol000000oo<W:Ko0000olVIY@07olVIY@03o`000?nh
R:;o^8RR00Co^8RR00Go0000okB5XondQJ?o]8FSo`000009okN8Y@03o`000?nNLj;oWW>R00CoWW>R
00?o0000oimfY?nOMZ@00_nOMZ@3o`0000SoRFRV00Ko0000og9IYombFJOo0000ogEHXol00004og1K
Z`03o`000?mAAZOoDDJW00;oDDJW00SoI5BZo`000?ll@Zoo0000odE8/?l0003o7cB]o`0000;o02R]
00Ko9dNmo`000?l07:Wo01bYo`000?l01iL2o`0U[P03o`0CV?l0003oWYgC00CoWYgC0_l0000:oiRF
d003o`000?nDUM7oU9GA00?oU9GA6_l000000on4Qlko0000oh65cP06oh65cP04o`000?mkO/_oNgk;
o`0000WoMgc;0_m/L/L2ofQ`a`05o`000?o>emooc]OOolkGgol000000ooNf=42o`0000?oj=_700?o
0000onWNaooYg/L00_oYg/L2o`000003ooKP/ol0003omnBb00;omnBb00Go0000ookOT?ongi3o0000
oogQS003o`0003Oooo]Z00?o0000oookJ_oonfX08OoonfX001gooo]Z00?o0000oookJ_oonfX0Booo
nfX4o`0000;o0P1300?o0000oc8:K_l000000_lf3Fl2o`0000CoF3F<00?o0000oeXfRol000002?mb
E:03o`0000KoQ6fa00?o0000ohY`[on:L:l01_n:L:l3o`0000OoUGni1?l00009oif;`@04o`000?nR
S[ooXXjooj:>_`Go00000_nRU<H2o`0000_oYIW900?o0000oj^Kaon[VlL00_n[VlL00ol0003o[ZK@
ojjVd005ojjVd003o`000?n/VlKo[9_600?o[9_60_l00005ok:/dP03o`000?n_W/Ko[ik600?o[ik6
0_l00006okJ_d`04o`000?ncX<Go/j35ok>Pa@;o00002?nj/]400ol0003o^ZW8o`00000;okjbcP03
o`000?nn[/Wo_Zk900Go_Zk900?o0000ol:hd?o2^=000oo2^=001?l0003oa:o5olB_aOo4[lD5o`00
00?oaZg100Go0000olJ]`Oo6[L7oaZg1o`000004olna^`03o`000?o=/KoocK6o00GocK6o00?o0000
olbd`_l000000_oB/[T3o`0000Coejn`00?o0000omRa/OoH/K401?oH/K400ol0003ogK>]o`000002
o`0000Cohk2P00?o0000onFcX?oU/j000_oU/j02o`0000;ojjf=00Co0000onj`SOl0003okjn80ol0
0002ooFYK003o`000?ocVDOo000000Co0000<OoonfX00ol0003ooo]ZoookJP13oookJP03o`000?oo
nf[ooo]Z01gooo]Z00?o0000omC6c?oDa/`01?oDa/`2o`0000God<C?00?o0000olo2c_o?`/h00_o?
`/h00ol0003oc/;?o`000004olg0cP03o`000?o:`M7o000000KobKk@00?o0000olRmd?l000001Oo7
_=000ol0003oa[[?olJjc`05olJjc`;o00000_o2^M801?l0003o`KSBol6hd_o1^=82o`0000Oo`;SB
00Co0000okned?l0003o00001?oZ_ZP01_l0003oi;JWo`000?l0003ohkBUo`0000Gofj^U00?o0000
om:RY_oBXZH01?oBXZH4o`0000GobIVU00?o0000okR8X_nhR:801_nhR:800ol0003o]8FSo`00000;
okN8Y@04o`000?nNLj;oWW>RoiicXP;o00000onOMZ@3o`0000_oRFRV00?o0000og9IYol000000_l0
0004og1KZ`05o`000?mAAZOoDDJWoe56Yol000000_mTE:X2o`00000BodE8/?l0003o7cB]oald[Ol0
003o02R]o`000?lWAkgo0000o`0LZOl0003o00NGo`13aOl09Jko01nWo`0CV?l0003oWYgC0ol00000
0onLV<oo0000oiRFd005oiRFd0[o00000onDUM401?l0003oTXo=oi:?cOl0000:ohj>cP04o`000?n9
S=3oRHc@o`0000GoQhK<2_l00002og]nb`03o`000?mgO<_oMgc;00KoMgc;00Go0000ofiba_m/L/Oo
K7;7o`000005olkGg`03o`000?oNf=7o000000;ogm_A00?o0000onSKaol000001?oYg/L00ol0003o
jn77on_Qa`02o`0000;omnBb00Ko0000ooSW/?l0003oo]n@o`000?omhH`3o`0003Oooo]Z00?o0000
oookJ_oonfX08OoonfX001gooo]Z00?o0000oookJ_oonfX0B_oonfX5o`000009o`80@ol0003o0000
oc8:K_l0003o=Pe_o`000?m9:XSo000000CoF3F<0ol00007og9DX0;o00002?n4KK400ol0003oRW2_
ohY`[`04ohY`[`;o000000?oSg^io`000?nEOkT01?nEOkT3o`0000;oUhO100?o0000oif;`OnMRl40
1onMRl46o`0000CoXYC60_l000000onRVlgo0000ojFIb@0:ojFIb@04o`000?n[VlOoZi_7o`0000[o
[ZK@00?o0000ojbKa_n/VlH00_l00008ok:/dP03o`000?n_W/Ko[ik600;o00002?nf[m<01?l0003o
/j35o`000?l0000;okZbd@03o`000?nn//ko_[;>00Wo_[;>00?o^Jk>o`000?nn[/T01Onn[/T00ol0
003o`[S@ol:hd005ol:hd003o`000?o4[lGo000000Go`k;:1Ol00002olJ]`@05o`000?o?/K_ock6k
olna^ol000001oo=/Kl01Ol0003oc;C2olbd`_o<]<;o000000;od[:i00?o0000om:e_?l000000_l0
00000ooG[k3o0000omRa/@04omRa/@03o`000?oH];Go000000;ogK>]0_l00003on>`X0;o00000ooU
/j001Ol0003oj;JQo`000?o[[Hgo000000;ok[2=0_l000001?oc/hKo0000o`000?oeZF`2o`000004
oo>IAol0003o0000on9l2`;o0000<?oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z
01cooo]Z00?o0000omC6c?oDa/`01?oDa/`01?l0003odlC;om?4bol00003om34c`03o`000?o?`/ko
cl;>00Cocl;>00?o0000olg0c_o=`<h01?o=`<h2o`0000CobKk@0_l00003olRmd005o`000?o7_=3o
akc@olNld?l000001_o6^/l01?l0003oaKW?olFicoo5^Ll2o`000004ol:id_l0003o`KSBo`0000So
`;SB00Co0000okned?no]M3o00001?oZ_ZP00ol0003oi;JWonBfY`02onBfY`;o00001OoKZjD00ol0
003odZ:Vom:RYP05om:RYP03o`000?o9VZOobIZW00?o00000_o9VJD00ol0003o^8RRokR8XP06okR8
XP;o00003?ngR:D00ol0003oWW>RoiicXP06o`0000;oXGVW00?o0000ohUXY_n9J:H02On9J:H2o`00
00?oLUZX0_l00002og1KZ`04o`000?mAAZOoDDJWo`0000CoI5BZ00?o0000odE8/?l000000olO=:d2
o`0000;o9dNm00Oo01bYo`000?l05JCo00NGo`13aOl09Jko01nW00?o000000?oW9S?o`000?l00000
1ol00005oiVGd003o`000?nDUM7oU9GA00?oU9GA0_l00004oi:?c@03o`000?n>S/koSXk>00SoSXk>
0_l00008ohN6c003o`000?n1Q<koPHC>00?oPHC>0_mnO/P3o`0000OoMgc;00Go0000ofiba_m^L/Ko
K7;7o`000006olkGg`;o00001?oOfm400ol0003ojMk7onWNa`02onWNa`05o`000?o[hLOojn77on_Q
aol000000oogi;800ol0003on>N`o`000006o`0003Oooo]Z00?o0000oookJ_oonfX08OoonfX001go
oo]Z00?o0000oookJ_oonfX0B_oonfX3o`000006o`00?_l0003o0000oad0I_l0003o<PY^0_l00002
odTZR005o`000?mH=HcoF3F<oePeS?l000000omXD:82o`0000CoLUBP00?o0000ogYT[Ol000002?n4
KK401?l0003oRW2_ohY`[on:L:l3o`0000CoSg^i00?o0000oiEo^Ol000000_l00005oiN7`@03o`00
0?nMRl7oWH_100?oWH_11ol00005oj:DaP03o`000?nRVlgoXY_=00?oXY_=00?o0000ojFIbOnUVLT0
2?nUVLT2o`0000co[ZK@00?o0000ojbKa_l000002_nb[=800ol0003o[ik6o`00000;okJ_d`03o`00
0?nj/]7o^[;A00Wo^[;A00?o0000okF_dol000002Onn//h4okV^cP03o`000?nn[/Wo_Zk900;o_Zk9
00?o0000ol:hd?o2^=001oo2^=000ol0003o`k;:ol>bbP04ol>bbP03o`000?o7^looak_?00;oak_?
0ol00002olna^`03o`000?o=/KoocK6o00GocK6o00?o0000olbd`_o<]<800_o<]<800ol0003od[:i
o`000005om:e_0;o00001?oH/K401?l0003of;BeomRd]Ol00002omfc[@0:o`000?oQ^Jko0000o`00
0?oS/:3o0000onFcX?l0003oiK>Po`0000?oj;JQ0_l00002onj`S@08o`000?oc/hKolk>6oo>cQ_l0
003omJU/o`000?oh[6T6o`00033ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP0L
oookJP;o00001OoDa/`00ol0003odlC;om?4b`02om?4b`03o`000?o@a<oo000000Kocl;>0_l00005
olg0cP03o`000?o<_/goc;k=00;o000000?obKk@o`000?o8_M001Oo8_M000ol0003oakc@o`000006
olJjc`03o`000?o5^LooaKW?00CoaKW?0ol00007ol2hdP;o00000ono]M02o`0000?oj[jX00?o0000
onBfYooT]ZL00_oT]ZL01?l0003og:jWo`000?l00002om^[Y@03o`000?oBXZKodZ:V00GodZ:V0_l0
0005olVJY`Oo00001?nhR:82o`0000Go]hRU2ol00008oj5iY`03o`000?n9J:KoRFRV00OoRFRV0_l0
0006og9JZ0;o000000?oL5^[oe56Yol000001_mTE:X2o`0000Co7cB]00Go0000o`0Z[olWAkgo9dNm
o`000002o`0EY004o`000?l0@lGo0000o`0OY`Co00000_nMV<l00ol0003oVIO@oiVGd009oiVGd003
o`000?nDUM7oU9GA00;o00001_nBSld00ol0003oSXk>ohj>cP07ohj>cP;o00002_n7Q/`01Ol0003o
PHC>oh64c_n1Q<ko000000GoOWk81?l00002ogMlb`05o`000?m^L/KoKW;6ofiba_l000001_o>eml0
1?l0003od=[Pom3Jh?l00003omoKd@03o`000?oYg/OojMk700;ojMk700Go0000on_Qaoo[hLOojn77
o`000002ooOT/P04o`000?ohik3on>N`ooSW/0?o000000?onn:6o`000?l00000=ooonfX00ol0003o
oo]ZoookJP0QoookJP007OoonfX00ol0003ooo]ZoookJP19oookJPKo000000?o7@1Vo`000?lb2Vh0
0_l00003odTZR004o`000?mH=Hco0000o`0000CoJ52R00Ko0000og5EX_l0003o0000og9DX?l00002
ogYT[@03o`000?n4KK7oQ6fa00OoQ6fa0ol00005ohmk^@Co00002OnGQl400ol0003oWH_1o`000005
o`0000CoWY?800Co0000oj:Da_nRU<Ko00001onRVld00ol0003oYIW9ojFIb@05ojFIb@?o000000?o
ZJSEo`000?n^Y]002on^Y]02o`0000_o/ZcB0_l00009okJ_d`;o000000?o/JkEo`000?nj/]402?nj
/]400ol0003o]JoCokF_d`02okF_d`03o`000?nn//ko_[;>00?o_[;>00?o0000okV^c_ni[/h01Oni
[/h01?l0003o_Zk9okj^bOl00009ol:hd003okbbcol0003o`k;:00Co`k;:00?o0000olNkcoo7^ll0
1_o7^ll4o`0000GocK6o00?o0000olbd`_o<]<801?o<]<800ol0003od[Flom:e_004om:e_003o`00
0?oF^koo000000;o000000?of;6ao`000?oH];D00_oH];D00ol0003ogK>]o`000003on6i[P;o0000
0_oU/j02o`0000Coj;JQ0_l000000oo^/8go0000oo>cQP02oo>cQP03o`000?oeZFco000000;on:aY
0_l000001?ocVSSo0000o`000?l0000_oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oo
nfX07?oonfX00ol0003oe<K<o`000003omC6c003o`000?oCa<_odlC;00CodlC;0_l00005olo2cP04
o`000?o=`<kocL3>o`0000?ocL3>00?o0000olbncOo<_/d00oo<_/d2o`0000Kob;g@0_l00006olJj
c`03o`000?o5^LooaKW?00CoaKW?00?o0000ol>fcOo3]/d00_l00005ol2hdP03o`000?no]M3o_kG@
00?o_kG@00?o0000onC1/ol000000_oZ_ZP01Ol0003oi;JWonBfYooT]ZOo000000Cog:jW00?o0000
om^[YOl000001ooBXZH00ol0003obIZVo`000005olVJY`03o`000?o2TJ?o`Y6S00?o`Y6S2ol00007
ok25Y`03o`000?nQNJOoXGVW00WoXGVW00?o0000ohUXY_n9J:H01?n9J:H3o`000003ohe[Y_l0003o
LUZX00KoLUZX0ol00007ofADZP;o@dVb00Ko0000oald[OlO=:go7cB]obA2^Ol00002obM7_@04o`0`
]Ol0003o01FTo`0000;o04?500Ko0000o`0OYol0003o0000o`1Jd_l00002oifHc`03o`000?nIUm3o
VIO@00SoVIO@00?o0000oiBEdOl000002?nBSld00ol0003oSXk>ohj>cP06ohj>cP03o`000?n;RL_o
000000[oQhK<00Co0000oh64c_n1Q<ko00001_mnO/P01?l0003oMgc;ogMlbomgO</3o`000003ofib
a_l0003o000000Koc]OO00?o0000om3Jh?o@f^000_o@f^001Ol0003ogm_Ao`000?oQg];o000000;o
jMk700Wo0000on_Qaoo[hLOojn77o`000?o/i<Oo0000ooOT/_l000000_ohik04o`000003oo_RQ_l0
003o000003Oooo]Z00?o0000oookJ_oonfX08OoonfX001cooo]Z00?o0000oookJ_oonfX0B_oonfX5
o`0000;o7@1V0_l000000om6:8So0000odTZR002odTZR0;o00001_mXD:800ol0003oLEFRog5EXP05
o`000003ogYT[Ol0003oQ6fa00KoQ6fa0_l00002ohmk^@Go00000_n@P/000ol0003oUhO1oiN7`@07
oiN7`@Ko00001OnNTlP3o`0000_oXY_=00?o0000ojFIbOnUVLT00_nUVLT2o`0000GoZJSE00?o0000
ojjVd?n^Y]001_n^Y]03o`000003ojbYe?l0003o/ZcB00So/ZcB1Ol00002okJ_d`_o000000?o^[;A
o`000?l000000onj/]42o`0000Go]JoC00Co0000okjbc_nn//ko_[;>0_l00008okV^cP03o`000?nn
[/Wo000000So`[S@00Go0000okbbconl//oo_;;?o`000003ol>bbP03o`000?o7^looak_?00Soak_?
00?o0000olVfb?o9]/P00ol000000oo=/Koo0000olbd`P06olbd`P03o`000?oB]Kcod[Fl00?od[Fl
00?o0000omJk_ooF^kl00ooF^kl2o`0000?of;Be0_l00004on6i[P04o`000?oQ^[3o0000onFcX0;o
00001?oX]Z400ol0003oj[VQo`000002o`0000;olk>60ol00002ooR/J@?o000000?oliXho`000?l0
0000;ooonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z01_ooo]Z00Oo0000omC6c?oD
a/coe<K<o`000?oDa/co000000KodlC;00Co0000om;2b_oB`/[o00000oo?`/h00ol0003ocL3>olg0
cP02olg0cP03o`000?o=`<ko000000Goc;k=00?o0000ol^lc?o;_<`00_l00003olRmd003o`000?o7
^loo000000Goa[[?00?o0000olFicoo5^Ll01?o5^Ll00ol0003o`kK=ol>fc@02ol>fc@Co000000?o
`;SBo`000?no]M001?no]M000ol0003oi<6conC1/`03o`0000Coi;JW00?o0000omb^YooL[ZL00ooL
[ZL3o`0000GodZ:V00Co0000olVJY_o9VZKo00001?o9VZL00ol0003o`Y6Sol:AX`08ol:AX`03o`00
0?n`QJOo/8FW00_o/8FW00?o0000oj5iYonQNJL02OnQNJL00ol0003oRFRVohUXYP02ohUXYP;o0000
1?n=JjH00ol0003oLUZXog9JZ004og9JZ003o`000?mlHZWoO6:Y00;o00001_mTE:X3od=9/P09o`00
0?lO=:go7cB]o`000?lT@[Wo0000obM7_Ol0003o032e00Co00000_l0;kL01?l07jOo0000o`000?l0
F]83o`0000[oVIO@0_l0000:oi:?c@03o`000?n>S/koSXk>00CoSXk>00Go0000oh^9bon;RL_oRhW;
o`000009ohN6c003o`000?n1Q<ko000000SoOWk800Co0000ogMlbomgO<_o00000_mcM<D00ol0003o
amGTo`000004olkGg`;o00001Oo@f^02o`0000;ohMkB00?o0000onWNaol000000oo[hLL01Ol0003o
k>C7oncTaol0003omnBb00Co000000ConNV^o`000?okhXKonn:60_l0000goookJP03o`000?oonf[o
oo]Z027ooo]Z000LoookJP03o`000?oonf[ooo]Z04Wooo]Z1_l00002oad0IP04o`000?m6:8SoARR8
o`0000;oBBZ80_l00007ofQ@XP?o00001OmkIk4=o`0000SoT8;000?o0000oiN7`OnGQl400onGQl46
o`0000GoWY?80ol00002oj2Ld003o`000?nRVlgoXY_=00WoXY_=00?o0000ojFIbOl000000_l00008
ojVXe@03o`000?n^Y]3o[ZK@00;o[ZK@0ol000000on/ZMCo0000o`000003o`0000;o/ZcB2?l00002
ojV^f`03o`000?n`/=So/;3H00?o/;3H00?o0000ojb_f_n/[mX01?n/[mX01?l0003o/k;Gok>beonc
/]L>o`0000_o^Jk>00?o0000ol:hd?o2^=001Oo2^=02o`0000Co_;;?00Co0000ol>bb_o3//[o0000
2_o7^ll00oo1]<go0000olVfb003olVfb0Co00001Oo<]<800ol0003oc;C3o`000003om:e_003o`00
0?oF^kooe[^o00Coe[^o00?o0000omBk`Ol000000ooH];D00ol0003ohKV^on6i[P02on6i[P?ohKZ`
0ol00003onRfX@04o`000?oZ^J7oj[VQonZiX@;o000000Golk>6o`000?oe]XKomKJ6o`000002ooR/
J@04o`000?oi[VCo0000oo>J>0?o0000;ooonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[o
oo]Z01_ooo]Z0_l00003omC6c003o`000?oCa<_odlC;00CodlC;00?o0000om;2b_oB`/X00_oB`/X0
0ol0003ocl;>o`000005olg0cP;o00001Oo<_/d00ol0003obkc<ol^lc003ol^lc003o`000?o8_M3o
000000?oak_?00Go0000olJjcoo6^/ooa[[?o`000006olFic`03o`000?o3]/go`kK=00Co`kK=00?o
0000ol:fc_l000001Ol00002okned004o`000?oT`K?oi<6conC1/`?o00000ooT]ZL00ol0003og:jW
omb^Y`03omb^Y`03o`000?oDYJOoe:FW00?o00000_oBXZH01?l0003obIZVolVJY_l00004olVJY`03
o`000?o2TJ?o`Y6S00Oo`Y6S0_l0000<ok25Y`;o00003?nQNJL01?l0003oRFRVo`000?l00006ohe[
YP03o`000?mbFZSoLUZX00?oLUZX00Oo0000ogaRZOmlHZWoO6:Yo`000?mOE:go000000CoI5BZ0_mD
E;D3od=9/P;o00000olT@[T01OlWAkgo0000o`0`]Ol0<;Go01FT00;o6E;<00Go0000o`0_]ol0;kOo
0000o`0OY`05o`0000KoVIO@0ol000000onGT/co0000oi:?c@04oi:?cAKo00001On7Q/`00ol0003o
OWk8oginb007oginb004o`000?mgO<_o0000og=da@;o00000oo7eN@01?l0003oc]OOolkGgol00006
om3Jh003o`000?oAgN7o000000?ohMkB00Ko0000on_Qaoo[hLOojn77o`000?o/i<L4o`0000;on>N`
00?o0000ooWY[_oijJh01Ol0000goookJP03o`000?oonf[ooo]Z027ooo]Z000LoookJP03o`000?oo
nf[ooo]Z04Wooo]Z1?l000001OlG06Co0000oad0I_lM06Ko000000?oARR80_l000000omI@igo0000
ofQ@XP05ofQ@XP;o00002?mkIk401?l0003oQ6ncohA_/on4Kk<2o`0000?oSH;300?o0000oi22`?n@
P/002?n@P/000ol0003oUhO1oiN7`@05o`0000?oVY3800?o0000oijCb?nNTlP00ol00006oj2Ld003
o`000?nRVlgoXY_=00SoXY_=0_l00009ojVXe@Co000000?o[ZK@o`000?l000001?l00004ojR[f@03
o`000?n][MOo[JgG00;o[JgG0_l00007ojV^f`03o`000?n`/=So/;3H00;o00002?n/[mX01?l0003o
/k;Go`000?l00009ojn_f0;o00001?ne^=/4o`0000;o^Jk>0_l000000ong]=Ko0000ol:hd005ol:h
d003o`000?nl//oo_;;?00Co_;;?00?o0000ol>bb_l000002Oo7^ll01Ol0003o`KC=ol6dcOo1]<go
000000;obKK800?o0000olRic?o8^L`00_o8^L`3o`000003olbd`_l0003oc;C300;oc;C300Co0000
om:e_?oB]Kco00001OoF^kl01_l0003oe;_1omBk`OoD^l7o0000omRd]@;o00000ooQ^Jh00ol0003o
hKZ`on6j/002on6j/0?o00000_oX]Z401?l0003oj[VQonZiXOoZ^J42o`000004oo>cQ_l0003omKJ6
ooFfQP;o000000Oon:aYo`000?oi[VCo0000oo>J>?l0003olIT`00;o0000;_oonfX00ol0003ooo]Z
oookJP11oookJP03o`000?oonf[ooo]Z01[ooo]Z00Go0000omS5aooHaLOo0000omC6c002o`0000Go
dlC;00?o0000om;2b_oB`/X01?oB`/X2o`0000CocL3>00Co0000olbncOo<_/go00000oo<_/d00ol0
003obkc<ol^lc005ol^lc0;o00001?o7^ll00ol0003oa[[?o`000006olFic`03o`000?o3]/go`kK=
00Go`kK=0_l00006ol6dc@;o00001?oT`K<00ol0003ohkNXon>gZ003o`0000Gog:jW00?o0000omBU
YooDYJL01?oDYJL5o`000005olVJY_l0003obIZWolVJYol000002Oo2TJ<00ol0003o^hbUo`00000;
ok25Y`03o`000?n^PZGo000000[oXGVW0ol0000:ohe[YP03o`000?mbFZSoLUZX00;o00001?mlHZT0
1?l0003oGeB]oemD[Ol00002ofADZP?oE5Be1?m3BK801?l0003o94:iobA2^OlT@[T3o`0000;o032e
00Co0000oaUBc?lID/co6E;<0_l0;kL2o`000005o`YSfOl0003o0000o`1Abol000000_nIUm0=o`00
00GoTi3=00Go0000ohj>c_n>S/koSXk>o`000006ohb8b@03o`000?n7Q/coQhK<00?oQhK<2?l00008
oginb003o`000?mcM<Go000000GoamGT00?o0000olkGgol000001_o@f^001_l0003odMgQom7MhOoA
gN7o0000on7NdP;o00000_o[hLL3o`0000?ok>C700Co0000ooSW/?ohik3o00000_oijJh00ol0003o
nn:6o`000002o`0003Sooo]Z00?o0000oookJ_oonfX08?oonfX001cooo]Z00?o0000oookJ_oonfX0
B?oonfX5o`000003oaL0I?l0003o7@1V00;o00000om6:8P01?l0003oFD>MoeU3WOl00005ofQ@XP03
o`000?mbHK3o000000WoNfNa0ol00006ohf2``03o`000?n@P/3oT8;000OoT8;01Ol00005oiZ@b0Co
00002OnPW=000ol0003oXY_=oj:Kc@05oj:Kc@?o000000?oYJSHo`000?nYZ=D00_nYZ=D6o`0000;o
Yj_I0ol0000;ojR[f@04o`000?n][MOo0000o`0000WoZJkK00?o0000ok2`f?l000002_n/[mX2o`00
00Wo[joH0_l000000on[]N3o0000okFhf`07okFhf`Wo00000_o2^=000ol0003o_;;?okbbc`06okbb
c`03o`000?o7^looak_?00Koak_?00?o0000ol6dcOo1]<d00oo1]<d00ol0003obKK8o`000007olRi
c0?o00000oo<]<<00ol0003od[Flo`000005omJk_`03o`000?oD^l7oe;_100?oe;_11?l00002on6i
[P03o`000?oQ^[3ohKZ`00;ohKZ`00Ko0000on>m/Ol0003o0000onRfXOl00002onZiX@03o`000?o/
_J7ok;fQ00;o00000_oe]XH01Ol0003omkV4o`000?l0003onJiT00?o000000?olIT`o`000?l00000
;_oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z01Wooo]Z00?o0000omS5aooHaLL0
0_oHaLL2o`000003om?4c?l0003odlC;00;odlC;00?o0000om;2b_oB`/X01?oB`/X00ol0003od<3:
om30bP02o`000003olg0c_l0003oc;k=00?oc;k=00?o0000olbncOl000001_o;_<`01?l0003obK[<
olVjc?o9^/`3o`000003olNkcol0003o000000KoaKW?00?o0000ol>fcOo3]/d01Oo3]/d00ol0003o
`[C=o`000006ol6dc@;o00000ooT`K<00ol0003ogKNbo`000003on>gZ0;o00001?oL[ZL00ol0003o
e:FWomBUY`05omBUY`04o`000?o6VJWoaYVYolJIZ@?o000000?obIZWo`000?o2TJ<02?o2TJ<01?l0
003o^hbUok^<YOl00009ok25Y`04o`000?n^PZGo[X:Uojj2Y@KoXGVW1?l00002oiihZ003o`000?n=
JjKoSF^V00SoSF^V00?o0000og9JZ?l000001omlHZT01Ol0003oGeB]oemD[OmTE:[o000000?oE5Be
1?m3BK800omGE[Go0000obA2^@02obA2^@;o@5G000Co0000o`0`]Ol0>kko03^n0_lID/`00ol0@<?o
02ngo`0_]`02o`0000;o2V?I1Ol00006oiNAb`03o`000?nCT<goTi3=00WoTi3=00?o0000ohj>c_l0
00002?n<R<T00ol0003oQhK<ohN6c004ohN6c004o`000?n3OlKoPgo6oh=oaP?oOgo80_l00004ogin
b0?o00001oo7eN@00ol0003od=[Pom3Jh003om3Jh0;o00001?oAgN47o`0000Cok>C700Co0000onkV
a?l0003o00000_oijJh2o`000004oo_RQ_l0003o0000o`0003Sooo]Z00?o0000oookJ_oonfX08?oo
nfX001cooo]Z00?o0000oookJ_oonfX0B?oonfX5o`000005oaL0I?l0003o0000ocDKPol000000om6
:8P01?mH@iko0000oeU3WOl00003ofQ@XP;o00000ombHK000ol0003oNfNaog]W/@05og]W/@;o0000
2?n=P/<00ol0003oT8;0oi22`005oi22`0Co00001OnJT<P3o`0000;oWI_B00?o0000oj2Ld?nPW=00
2OnPW=000ol0003oXY_=oj:Kc@02oj:Kc@;o00000_nUZ=P6o`0000KoYj_I0_l000000onU[moo0000
ojR[f@0;ojR[f@;o00002onY[]/2o`0000Wo[:oJ0_l000000onX]^?o0000ojn_f006ojn_f0;o0000
1?n[]N000ol0003o]KSKokFhf`02okFhf`?o00001_n`]=/00ol0003o^kSGok^he`02o`0000Oo_;;?
00?o0000okZge_l000001oo7^ll00ol0003o`KC=ol6dc@05ol6dc@03o`000?o8^Lcob;W<00Gob;W<
00Co0000olc1d?o<`M3oc<7@0ol000000oo<]<?o0000omJk_`04omJk_`03o`000?oD^l7oe;_100Co
e;_100?o0000omFn`ooE_/<00ol00004on6j/003o`000?oS_K7ohkfa00;ohkfa0_l00002onZiX@04
o`000?o/_J7ok;fQonbmX@;o000000[omKJ6o`000?og^HComkV4o`000?oi[VCo0000ooZ`Gol0003o
lIT`0ol0000]oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0003o
f<G7omS5a`03omS5a`07o`000?oG`lOo0000om?4c?l0003odlC;o`000006om;2bP03o`000?o@`<[o
d<3:00?od<3:0_l00005olbnc@03o`000?o;_<cobkc<00Cobkc<00?o0000olVjc?o9^/`01Oo9^/`2
o`000003olJic_l0003oaKW?00?oaKW?00?o0000ol>fcOo3]/d01Oo3]/d01Ol0003o`[C=ol:dcOo2
]<go000000Co`KC=0_l00004onC1/`04o`000?oM]k;ogKNbo`0000;ohkNX00Co0000ombaZol0003o
00000_oL[ZL00ol0003oe:FWomBUY`04omBUY`03o`000?o6VJWoaYVY00?oaYVY00?o0000olVJYol0
00001Ol00004ol:AX`05o`000?nkS:Go^hbUok^<YOl000002?n`QJL00ol0003o[X:Uojj2Y@02ojj2
Y@;oXGVW1?l00006oiihZ003o`000?n=JjKoSF^V00SoSF^V0_l00008ogaRZ@03o`000?mOE:go0000
00;oKUj_00?o0000oeAD]OmDE;D00om3BK801?l0003oEeJeoeMF]Ol00002obA2^@?o@5G0017o032e
o`000?l0>kko03^noaUBc?l0003o0433o`0_]ol0003o02jfo`000?l:HmWo0000o`1GdOl0003o057;
o`000007oiNAb`03o`000?nCT<goTi3=00SoTi3=0_l00009ohb8b@03o`000?n7Q/coQhK<00;oQhK<
0_l00004oh=oaPOoOgo80ol00002ojg=l004o`000?o7eNCoamGTolOEi0;o00000_o7enD01Ol0003o
d=[Pom3Jh?o@f^3o000000CodMgQ1Ol00002on?QdP03o`000?o/i<Ook>C700;ok>C700Co0000onkV
a?o^i/Co00000ooijJh01?l0003onNb[o`000?oghGl2o`0003Sooo]Z00?o0000oookJ_oonfX08?oo
nfX001cooo]Z00?o0000oookJ_oonfX0AooonfX2o`000006o`00:ol0003o001Jo`000?lG06Co0000
0ole6h<00ol0003oARR8o`000002oeQ3WP05o`000?mI@igo0000ofQ@X_l000001OmbHK000ol0003o
NfNaog]W/@03og]W/@;o000000?oPGBko`000?n=P/<02?n=P/<01?l0003oT8;0oi22`?n@P/04o`00
00?oU8_700?o0000oiZ@b?l000000_l00006oifKdP03o`000?nPW=3oX9c@00SoX9c@00?o0000oj:K
cOl000001_l00003ojF/g003o`000?nWZmWoYj_I00CoYj_I00?o0000ojF_gonU[ml00onU[ml00ol0
003oZ:_IojR[f@06ojR[f@?o000000?oY[CSo`000?nY[]/01onY[]/3o`000003ojJfi?l0003o[:oJ
00Ko[:oJ0_l00004ojRfh`03o`000?n_[mSo[joH00;o[joH0_l00007oj^eh004o`000?ne^=_o0000
o`0000Wo/;CK0ol00006okRkg0Oo00001?o7^ll2o`0000Ko`KC=00?o0000oknidol000001_o8^L`0
0ol0003oc<7@olc1d005olc1d0?o00001?oF^kl00ol0003oe;_1omBk`@03omBk`@06o`000?oE_/?o
eKk3omFn`ol0003og;bi0_l00002on6j/003o`000?oS_K7ohkfa00?ohkfa0ol000000ooZ^J7o0000
onbmX@02onbmX@04o`000?oa_i[o0000o`0000;omkV40ol000000ooj/5oo0000oo6I<003o`0002go
oo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oHaLOof<G700?o
f<G700Ko0000omO3aooG`lOoel?7o`000?oCa<`2o`0000God/;:00?o0000om30b_o@`<X01?o@`<X0
1?l0003od;g9o`000?l00003olbnc@03o`000?o;_<cobkc<00?obkc<00?o0000olVjc?o9^/`01Oo9
^/`00ol0003ob;O:olRgbP03o`0000;oaKW?00?o0000ol>fcOo3]/d01?o3]/d2o`0000Go`[C=00Go
0000ol6dcOo1]<go0000ol2bc002o`0000;oi<6c00?o0000omfg/_oM]k800_oM]k82o`0000Cog;6[
0_l00007omBUY`03o`000?o6VJWoaYVY00?oaYVY00?o0000olVJYol000001Oo3UjXHo`0000[oWWRX
00?o0000ohe[Y_n=JjH01on=JjH2o`0000WoO6:Y0_l00004ofiN[`05o`000?mDE;GoE5Beod=9/_l0
00001?mGE[D00olT@[Wo0000obA3^P03od1E`00=o`0`]Ol0003o03^no`0k__lID/co0000o`10`ol0
;kOo0000o`0^]_l0003o2V?Io`000002o`1Gd@04o`1Abol0003o0000o`0000CoUi7;00?o0000oi>@
cOnCT<d01onCT<d00ol0003oTH_9o`00000:ohb8b@04o`000?n7Q/coQhK<o`0000OoPgo60omoOlP3
o`0000Ko[Lg`00?o0000olOEi?l000001Oo7enD00ol0003od=[Po`000002om7Mh@Co00001?oDhN40
0ol0003ohn7Bo`000003oncTa`05o`000?o^i/Cok^K4onkVa?l000000_oijJh00ol0003onNb[ooW/
Z`04o`0003Sooo]Z00?o0000oookJ_oonfX08?oonfX001_ooo]Z00?o0000oookJ_oonfX0B?oonfX2
o`000003o`00:ol0003o001J00?o00000ole6h<2o`0000CoF4>N0ol00006og9Q/004o`000?mkIk7o
NfNaog]W/@;o00000on1M;/00ol0003oSH;3ohf2``07ohf2``Go00001?nDRlL4o`0000WoWI_B00?o
0000oj2Ld?nPW=001onPW=05o`0000WoYJcL00Go0000ojN[fOnWZmWoYj_Io`000008ojF_g`03o`00
0?nXZmWoZ:_I00;oZ:_I0ol00005ojJdh`03o`000?nY[]_oZJkK00;oZJkK0ol00005ojJfi003o`00
0?n/[m[o[:oJ00;o[:oJ0_l00007ojRfh`04o`000?n_[mSo0000o`0000WoZkGP0_l00009ok2df`;o
000000?oZkSSo`000?nh^m`01Onh^m`2o`0000Go/kOL0ol000000oo7^loo0000ol6dc@06ol6dc@05
o`000?no^M?o_kWCoknidol000001?o8^L`00ol0003oc<7@olc1d005olc1d0;oal7E00Ko0000om2l
aol0003o0000omJk_ol00005omBk`@03o`000?oE_/?oeKk300?oeKk300Ko0000ombo^ooL_k_o0000
on6j/?l00004on>m/@05o`000?oU`;;o0000onG0/_l000000oo/_J401Ol0003ok[nQo`000?oa_i[o
000000;omkV400Co0000ooZlP_l0003on[1O1_l0000/oookJP03o`000?oonf[ooo]Z043ooo]Z00?o
0000oookJ_oonfX05ooonfX00ol0003of<G7omS5a`03omS5a`03o`000?oG`lOoel?700?oel?70_l0
00000ooB`/_o0000om;2bP02om;2bP03o`000?o@`<[od<3:00Cod<3:00?o0000om2mbOo@_LT00_o@
_LT01Ol0003oc;k=o`000?o;_<co000000?obkc<00?o0000olVjc?o9^/`01Oo9^/`00ol0003ob;O:
olRgbP04olRgbP?o00001Oo3]/d00ol0003o`[C=ol:dc@05ol:dc@05o`000?o1]<go0000ol2bc?l0
00000_oU`[<00ol0003oi<6co`000005omfg/P03o`000?oL/J_og;6[00?og;6[0ol00004omBUY`03
o`000?o6VJWoaYVY00GoaYVY00?o0000ol>GZ_o3UjX01oo3UjX00ol0003o^hbUok^<Y@02ok^<Y@03
o`000?n`QZOo/8JW00Go/8JW00?o0000ojj2Y_n^PZH00on^PZH00ol0003oWWRXoiihZ00:oiihZ003
o`000?n=JjKoSF^V00?oSF^V0ol000000on>KJWo0000ogaRZ@07ogaRZ@;o00001_m^GZl00ol0003o
E5Beo`000006oeMF]@03o`000?lT@k[o@5G000?o@5G000?o0000o`0k__l0>kh00ol000000ol0@<?o
0000o`0^]P02ob9/g@04o`000?l0Em7o05OAo`1Gd@;o000000?o<8S/o`000?l000000_l000000onG
TL_o0000oi>@c@05oi>@c@;o00000onARlT00ol0003oS8S9ohb8b@07ohb8b@03o`000?n7Q/co0000
00SoPgo600?oOgo8o`000?l000002_n]cO000ol0003oamOUolOGi@05olOGi@Co00000_oAgN400ol0
003oe>7QomCQh@03omCQh@;o000000Goi>?Ao`000?o/i<Ook>C7o`000002onkVa005o`000?o`jlCo
0000ooWY[_l000000_oik:/5o`0003Oooo]Z00?o0000oookJ_oonfX08?oonfX001_ooo]Z00?o0000
oookJ_oonfX0AooonfX5o`000004o`00F_l0003o<AV3o`0000;o=A^30_l00006oeQ3WP?o00001_mb
HK03o`0000GoPGBk00?o0000ohf2`on=P/<01On=P/<4o`0000;oU8_71Ol00002oiVHdP03o`000?nM
Vm;oWI_B00WoWI_B00?o0000oj2Ld?nPW=000onPW=03o`0000;oXZ_M00?o0000ojF/g?nU[=`02OnU
[=`2o`0000_oYJoO00?o0000ojR[fOl000000_l00008ojJdh`03o`000?nY[]_o000000;o00002OnV
]^@01?l0003o[:oJo`000?l00009ojRfh`;o00002On[]N02o`000003ojFkj?l0003o/;CK00Ko/;CK
0_l00004oj^hh`03o`000?nh^mco^;_L00;o^;_L00?o0000ok>gg?nc]m`01_nc]m`01Ol0003o_k_F
o`000?o1]<go000000Go`KC=00?o0000oknidono^M<00ono^M<01?l0003ob;W<olRic?l00007olc1
d0Coal7E00?o0000om2laoo@_<L00_l00004omBk`@03o`000?oE_/?oeKk300CoeKk300Co0000ombo
^ooL_k_og;nk0_l00004on>m/@03o`000?oU`;;oiL2b00?o00000_o/_J401?l0003ok[nQo`000?oa
_iX2o`000003ooNiQ?l0003on[b200;o000000?on[1Oo`000?l000000ol0000/oookJP03o`000?oo
nf[ooo]Z043ooo]Z00?o0000oookJ_oonfX05_oonfX2o`0000Cof<G700?o0000omO3aooG`lL01?oG
`lL01ol0003oe/76o`000?oB`/_o0000om;2b_l000001_o@`<X00ol0003od;g9om2mb@04om2mb@;o
00000_o;_<`00ol0003obkc<o`000007olVjc003o`000?o8]l[ob;O:00Cob;O:0_l00002olJeb@?o
000000?o`kK=o`000?o2]<d01oo2]<d2o`000003ol2bc?l0003oiL:c00?oiL:c0_l00005omfg/P03
o`000?oL/J_og;6[00?og;6[00?o0000omNYZOoGZJT00ol000000ooDYJOo0000olJIZ@06olJIZ@03
o`000?o3Uj[o`iNZ00Ko`iNZ00?o0000ok^<YOnkS:D00onkS:D00ol0003o/8JWok26Y`04ok26Y`03
o`000?n^PZKo[X:V00Co[X:V00?o0000oiihZ?nNN:P02_nNN:P00ol0003oSF^Vohe[YP03o`0000Go
SVfY00?o0000ogaRZOmlHZT00omlHZT2o`000003ogYU/?l0003oKUj_00KoKUj_0_l00006oeMF]@03
od1D`?l0003o000000?o@5G000Co5T:no`000?l0>kko03^n0_laG/l2o`10``;o00000_lRK=d2o`00
00?o05OA00?o0000oc28k?l`R>`00_l`R>`3o`0000CoTi3=00?o0000oi6;bOnARlT02Ol00005ohb8
b@03o`000?n3OlKoPgo600GoPgo60ol00008ojg=l0?o00000_n^c_401?l0003oamOUolOGiOo7enD4
o`0000CodMgQ00?o0000omCQhOoDhN400ooDhN401ol0003oe^CQomKThOoFi>7o0000oncTaol00000
0oo^i/@01_l0003ol>_4o`000?oijJko0000ooW/Z`Go000000?ooo]Zo`000?oonfX0=OoonfX00ol0
003ooo]ZoookJP0PoookJP006ooonfX00ol0003ooo]ZoookJP17oookJP?o000000Co001Go`000?l0
05[o00000_la6H<2o`000003odThVol0003oF4>N00CoF4>N00CoIebbo`000?maH[;oLF:b0ol00002
og9Q/0;o00002?n1M;/01?l0003oSH;3ohf2`on=P/<9o`0000SoVISB00?o0000oifKd_nMVm802?nM
Vm800ol0003oX9c@oj2Ld003o`0000KoXZ_M00?o0000ojF/g?nU[=`01OnU[=`3o`000003oj>ci?l0
003oYJoO00WoYJoO0ol0000:ojJdh`?o00002onV]^@3o`0000SoZ;KS0ol000000onR_Nco0000oj^e
h006oj^eh0;o00001?nU^nP00ol0003o/;CKok2df`02ok2df`;o00001on[^><01?l0003o^;_Lo`00
0?l00009ok>gg0;o00000onm_]/3o`000003ol6dcOl0003o_kWC00Go_kWC00?o0000olRic?l00000
1_o<`M000ol0003oal7EolO1e@03olO1e@03o`000?o@_<Oo000000;ocko;0_l000000ooD^l7o0000
omFn``05omFn``03o`000?oE_L?o000000;og;nk00?o0000omg2__l000000_oS_K401?l0003oiL2b
onG0/_oU`;82o`000005onO4/ol0003ok;fQo`000?o^_j400_l00002ooC3VP;o000000?on[b2o`00
0?ol_gl00ol000001?o^V2Ko0000o`000?l0000/oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000
oookJ_oonfX05_oonfX00ol0003oflC3o`000003omS5a`03o`000?oG`lOoel?700?oel?700Oo0000
omK1a_oF`LKoe/76o`000?oB`/_o000000Kod<3:00?o0000om2mbOo@_LT01?o@_LT00ol0003oc[_8
oljkb002o`000003ol^lc?l0003obK[<00KobK[<00?o0000olRgb_o8]lX01?o8]lX01?l0003oakK9
olNfbOl00004olJeb@?o00001Oo2]<d2o`000004ol6cc?l0003o`;;<o`0000CoiL:c00?o0000on2j
/Ol000000_l000001?oM]k;o0000omR`/?l00003ombaZ`03o`000?oGZJWoejVY00CoejVY0ol00006
olJIZ@03o`000?o3Uj[o`iNZ00Go`iNZ00?o0000ok^<YOnkS:D01OnkS:D00ol0003o/8JWok26Y`02
ok26Y`03o`000?n^PZKo[X:V00Go[X:V00?o0000oiihZ?nNN:P02OnNN:P?o`0000;oO6:Y00?o0000
ogYU/?mjIK000_mjIK000ol0003oKUj_ofiN[`04ofiN[`;oIF6i0_l00003oeMF]@03o`000?m0E<3o
@5C000;o00000_m0EL001Ol0003o5T:no`0k__l0>kko000000;o<Ek?00Oo0433o`000?l0?/;o0000
ob9/gOl0003o1UoG00;o000000Co05OAo`000?l0003o00000ol`R>`00ol0003o9H;Yo`000006o`00
00?oTX[800?o0000ohb8b_n<R<X00on<R<X=o`0000So[Lg`0ol00005ojk>l@Co00001?o8f>D01?l0
003odMgQom7MhOl00005omCQh@03o`000?oFi>7oe^CQ00;oe^CQ0ol00002onkVa005o`000?o`jlCo
l>_4oo3[a?l000000_oik:/2o`000003ooKPNol0003o000000;ooo]Z00?o0000oookJ_oonfX0<ooo
nfX00ol0003ooo]ZoookJP0PoookJP006ooonfX00ol0003ooo]ZoookJP17oookJP;o00000_l005L3
o`0000;o<AV300Co0000odThVom9>9_o00001?mH@ih3ofML/P03o`000?maH[;oLF:b00;oLF:b2Ol0
0003oh5d^`So00000_n@S/d00ol0003oVISBoiVHdP08oiVHdP03o`000?nMVm;oWI_B00OoWI_B1?l0
000:oj:[g@03o`000?nU[=coYJcL00;oYJcL0_l00005oj>ci003o`000?nU[mooYJoO00CoYJoO0ol0
0003oj>jj@03o`000?nV]>?oY[CS00CoY[CS0ol00003oj:mk003o`000?nV]^CoY[KT00CoY[KT1?l0
0002oj6nk@03o`000?nX]^?oZ;KS00?oZ;KS0ol00005oj:mk003o`000?n[]N3oZkGP00;oZkGP0_l0
0007ojFkj004o`000?n`]=_o0000o`0000WoZkSS0_l00009ok>gg0;o00000_n^^^800ol0003o_KkK
okfnf`02okfnf`;o00002?no^M<00ol0003oc<7@olc1d003olc1d003o`000?o7`MGoal7E00Koal7E
00?o0000olnoboo?_l/00oo?_l/2o`0000GoeKk300Co0000omFm`ooE_L?oeKg30_l00003omg2_P03
o`000?oS_K7o000000?oiL2b00Co0000onO4/ol0003oilBc0_l00002onjoX@07o`000?od`i[om<>J
ooC3V_l0003on[b2o`000002ooboO`Ko0000;?oonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oo
nf[ooo]Z01Gooo]Z00Oo0000om_4`ooKa<?oflC3o`000?oHaLOo000000Goel?700?o0000omK1a_oF
`LH00ooF`LH3o`0000Cod<3:00?o0000om2mbOo@_LT01?o@_LT00ol0003oc[_8oljkb003oljkb0?o
00001Oo9^/`00ol0003ob;O:olRgbP04olRgbP03o`000?o7]/WoakK900;oakK900Go0000olJebOo6
]LWoa[G9o`000002olFcb@?o000000?o`[C=o`000?o1/l`00oo1/l`00ol0003oiL:conG2/`02onG2
/`03o`000?oP^[7oh;Za00?oh;Za0_l000000ooH/;3o0000ombaZ`02ombaZ`03o`000?oGZJWoejVY
00CoejVY00?o0000oljQZOo>XJT00ol00002olJIZ@03o`000?o5V:Wo000000Ko`iNZ00?o0000ok^<
YOnkS:D01OnkS:D01Ol0003o/8JWok26Yon`QZOo000000Wo[X:V00?o0000oiihZ?nNN:P01OnNN:P5
o`0000[oSVn/00Ko0000ogYT[_mjI:ko0000ogaRZOl00004ogYU/003o`000?m^GZooKUj_00?oKUj_
00Ko0000ofEQ^OmUHKWo0000oeAF]ol00002oeMF]@07o`000?m0E<3o@5C0od1D`?l0003o@5G0o`00
0003oaI2_P03o`0k__l0003o<Ek?00;o<Ek?00Ko0433o`000?l0?/;o0000ob9/gOl00002o`IOe`04
o`000?l0Em7o0000ocb:k0;o00000_l`R>`01?l0003o9H;YobF2jOlUP^T;o`0000CoS8S:1ol00004
oh^nn003o`000?n]cO3o[Lg`00?o[Lg`0_l00005ojk>l@?o00000_n^c_400ol0003ob=SUolSHi@03
olSHi@03o`000?oAgN7o000000Coe>7Q0_l00004omKTh@07o`000?oFh]oo0000on?Ze_l0003ok^K4
o`000003oo3[a006o`000?oik:_o0000ooW/Y_l0003om^1k0_l00003oookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX08?oonfX001_ooo]Z00?o0000oookJ_oonfX0A_oonfX3o`0000;o
001G00?o0000oa/9O?l000000_la6H<01Ol0003oBCRKodThVom9>9_o000000;oF4>N1?mWG;801Ol0
003oLF:bog5R/_maH[;o000000?oOWW400?o0000oh=l`on3O<<00on3O<<8o`0000KoT8k=00?o0000
oiVHd_nIV=802?nIV=800ol0003oWI_BoifKdP03oifKdP?o000000?oWZGJoijYg_l000002onRZmd0
0ol0003oYJcLojF/g002o`0000SoXk?T00?o0000ojF_gonU[ml00ol00007oj>jj@03o`000?nV]>?o
Y[CS00?o00001onR_N`00ol0003oY[KTojJfi003o`0000OoXKk]00?o0000ojRfhol000000_l00009
oj:mk004o`000?n[]N3o0000o`0000WoYK_X0_l00008oj^hh`?o000000?oYKcZo`000?nc]m`01_nc
]m`2o`0000Go[[[R0_nm_]/2o`0000Go^[oN1?l000000onm_=Wo0000olc1d003olc1d003o`000?o7
`MGoal7E00Goal7E00?o0000olFmdol000001Oo?_l/00ol0003ocl;>o`000002o`000003omFn`ol0
003oeKg300CoeKg300?o0000omg2__oM`[h00_oM`[h2o`0000;oiL2b00Co0000onO4/ooWa;?oilBc
0_l000001?oXak?o0000onjoXOl00003ooC3VP?o00000_ol_gl00ol0003onk5Io`000003o`0002co
oo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oKa<?oflC300?o
flC30_l00004omO3a`03o`000?oF`LKoe/7600Coe/7600?o0000omBnaOoD_/D00_l000000oo@`<[o
0000om2mb@05om2mb@03o`000?o>^lSoc[_800Coc[_800Co0000olbiaol0003o00000oo9^/`00ol0
003ob;O:olRgbP04olRgbP03o`000?o7]/WoakK900CoakK900?o0000olJebOl000001_o5/lT3o`00
00;o`K?<0_l00004onG2/`03o`000?oP^[7oh;Za00?oh;Za00Co0000omJ_/_l0003o00000_oL/J/0
0ol0003oejVYomNYZ@04omNYZ@03o`000?o>XJWocZ6Y00CocZ6Y2?l00002ol>GZP03o`000?nkS:Go
^hbU00Ko^hbU00Co0000ok26Yon`QZOo00002_n^PZH00ol0003oWWRXoiihZ006o`0000?oXGf/00?o
0000ohi_[?n>Kj`02?n>Kj`00ol0003oNVB^o`000003og]T[P?o000000?oNVF`o`000?m^GZl00om^
GZl00ol0003oIF6iofEQ^@02ofEQ^@05o`000?mDE[Oo0000oeMF]Ol000000om0E<001?l0003o@EG0
o`000?l00003oaI2_P;o00000olaG/l00ol0003o03k2o`0n`P02o`0000?o1UoG0ol00003ocb:k003
o`000?l`R>co000000?o9H;Y00?o0000ofBXmomTZ?L01?mTZ?L00ol0003oGJGfoefUmP04o`0000co
Rkkh00?o0000ojg=l?l000000_l00003ojk>l@Co00000_n^c_42o`000003ojo@l_l0003ob=SU00Go
b=SU00?o0000omCQhOoDhN400_oDhN400ol0003oe^CQomKTh@03omKTh@04o`000?oFh]ooe^;Oo`00
00;ohn[F00Co0000oo3[a?o`jlCol>_40ol00002ooW/YP04o`000?ofh7_o0000o`0000Cooo]Z00?o
0000oookJ_oonfX0<_oonfX00ol0003ooo]ZoookJP0OoookJP006ooonfX00ol0003ooo]ZoookJP16
oookJP?o00000_l005L01ol0003o6`Ulo`000?la6H?o0000odTlX?l000000_m9>9/00ol0003oF4>N
ofML/P04ofML/P04o`000?maH[;oLF:bo`0000CoOWW400?o0000oh=l`on3O<<00ol00003oh=l``;o
00002On@S/d00ol0003oVISBoiVHdP08oiVHdP03o`000?nMVm;oWI_B00?o000000?oWZGJoijYg_nN
ZMh00onNZMh00ol0003oXZ_Moj:[g@07oj:[g@?o00002_nS/n@4o`0000WoXk[Y1?l00009oj:mk0Co
00002OnQ_^d3o`0000_oX[g/0ol00008ojFkj0?o000000?oW[o`o`000?n[^><01?n[^><3o`0000Go
YKcZ00?o0000ok>gg?nc]m`00_nc]m`2o`0000Oo[[[R0_l00007okZogP04o`000?ne_=ko]KcNokFl
gP?o00000_o<`M000ol0003oal7EolO1e@04olO1e@;o00000oo5_M<01Ol0003ocko;olnoboo?_l_o
000000Gocl;>0_l00005omFm``03o`000?oM`[kogL:n00;ogL:n00Go0000on37_ol0003oiL2bo`00
0003onO4/`09o`000?oXak?oj<NconS7/ol0003olLBRo`000?od`i[o000000;om/JJ00?o0000oobo
Oool_gl01ol0000[oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0
003oflC3om_4``04om_4``03o`000?oJ`/;o000000?oel?700?o0000omK1a_oF`LH00ooF`LH01_l0
003oe;k5omBnaOoD_/Go0000omBna@;o00001Oo@_LT00ol0003oc[_8oljkb004oljkb003o`000?o<
^LOoc;W700;oc;W700?o0000olVjc?l000001_o8]lX00ol0003oakK9olNfb@05olNfb@;o00001_o5
/lT01?l0003o`k;9ol>bbOo3//T3o`000005onK3/ol0003oiL:conG2/ol000001OoP^[401?l0003o
eZnbomJ_/_oF[k82o`000003ombaZol0003oejVY00GoejVY00?o0000oljQZOo>XJT01Oo>XJT01?l0
003o`IJ[ol6FZol00003ol>GZPSo00001?nkS:D2o`0000Go[X:V2Ol00002oiihZ0;o00001OnQOJ`0
0ol0003oSVn/ohi_[008ohi_[0;o00001omkI:h3o`0000;oKUj_00?o0000ofEQ^OmUHKT00omUHKT0
0ol0003oE5JgoeAF]`02o`0000Co@5C000Co0000oe9P`omBH<?o00000_lF@[h2o`0000?o<Ek?0_lA
E]000ol0003o=g?OocMcg`02o`0000?o1UoG0_l00005ocb:k0Go00001_mTZ?L01Ol0003oGJGfoefU
m_mMYOKo000000koRkkh00Co0000ojk>lOn^c_7o[/ka0ol00004ojk>l@;o00001?n_d?801ol0003o
b=SUolSHiOo8f>Go0000olWJi_l000000ooDhN400ol0003oe^CQomKTh@03omKTh@03o`000?oFh]oo
e^;O00;oe^;O0_l000001OoVk]?o0000oo3[a?l0003olNk100;o000000?onNbVo`000?l000000ol0
0004oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX07ooonfX001[ooo]Z00?o0000
oookJ_oonfX0A_oonfX01Ol0003o0009o`000?l0003o001G00;o000000?o6`Ulo`000?l000000om9
?:000ol0003oBCRKoeQ3WP07ofML/P;o00001OmnNL@3o`0000GoPgc300?o0000ohV6b_l000002_n@
S/d00ol0003oVISBoiVHdP06oiVHdPCo00000_nNYMX8oijYgP03o`000?nRZmgoXZ_M00?oXZ_M0ol0
0003oj:fi`03o`000?nS/nCoXk?T00CoXk?T0ol00003oj6nkP03o`000?nS^^WoXk[Y00CoXk[Y0ol0
0003oik4l`03o`000?nR_NcoX[g/00CoX[g/0ol00003oi[5mP03o`000?nQ_^goXKk]00CoXKk]0ol0
0003oiS4mP03o`000?nR_NcoX[g/00CoX[g/1?l00002oiW2m003o`000?nU^nSoYK_X00?oYK_X0ol0
0005oijol003o`000?n[^>?o000000;o00002OnU_>X01?l0003o/kOLo`000?l00007ojjjhP;o0000
00?oZKgXo`000?nj_mh01?nj_mh2o`0000Ko]KcN0ol00006olO1e@03o`000?o5_M?oaKgC00CoaKgC
00?o0000olnobol000001Oo?`/h01?l0003oc/C@olk4d?l00003omFm``03o`000?oE`/Oo000000;o
gL:n00Co0000on37_ooPakooh<No0_l00003onO4/`;o00000_oXak<3o`000007ooC3V_l0003om/JJ
ooK6V_l0003oo;moo`000002oog2O0;o000000?onK9;o`000?l00000:ooonfX00ol0003ooo]Zoook
JP0ooookJP03o`000?oonf[ooo]Z01;ooo]Z0_l00005om_4``07o`000?oJ`/;of/;2om[2`_l0003o
el?7o`000005omK1aP03o`000?oD_/Goe;k500?oe;k50_l000000ooB_<Co0000om2mb@02om2mb@03
o`000?o>^lSoc[_800Coc[_800?o0000olbiaoo<^LL01?o<^LL2o`0000Gob;O:00?o0000olNfbOo7
]/T01Oo7]/T00ol0003oaKC9o`000005olFcb@03o`000?o3//Wo`k;900?o`k;900Oo0000onK3/ooV
`k?oi/>co`000?oU`[?o000000Goh;Za00?o0000omJ_/_oF[k800_oF[k84o`0000CoejVY00?o0000
oljQZOo>XJT01Oo>XJT01Ol0003o`IJ[ol6FZoo1UZ_o000000Co`iNZ00?o0000okjE[OnnUJd01?nn
UJd;o`0000Ko[XN/00Go0000oiihZ?nNN:SoWWRXo`000007oj5m[003o`000?n>KjcoSVn/00OoSVn/
0_l0000:og]T[P03o`000?m^GZoo000000KoIF6i00?o0000oeAF]ol000000_mTHKT01Ol0003o@5C0
od1D`?m0E<3o000000?oDV3300Co0000oaI2__l0003o5T:n0_l000002?laG/oo0000oa5Fd?lAE]3o
0000ocMcgol0003o6fSK1?l000001?l2G=Go0000o`000?l00002ocb:k004o`000?l^PnWo;X?Yobj3
j@Ko00000_mTZ?L01Ol0003oGJGfoefUm_mMYOKo000000?oRkkh1ol00003ohbnn0Co00001?n^c_43
o`0000Oo[m3b00?o0000olSHiOl000000oo9f^H00ol0003oe>7Qo`000005omKTh@03o`000?oFh]oo
e^;O00;oe^;O0_l00003onK^d`Co00000_oik:H5o`0000Gooo]Z00?o0000oookJ_oonfX0<OoonfX0
0ol0003ooo]ZoookJP0OoookJP006_oonfX00ol0003ooo]ZoookJP16oookJPGo00000_lH2Gh2o`00
00GoBCbP0ol00006ofML/P04o`000?mnNLCoOWW4ogiia0?o000000?oOWW4o`000?n3O<<00on3O<<2
o`0000?oRHK:00?o0000oi2>cOn@S/d01on@S/d01?l0003oVISBoiVHd_nIV=85o`000003oiVQfOl0
003o000000_oWZWN00?o0000oj:[gOnRZmd00ol00007oj:fi`03o`000?nS/nCoXk?T00?o00001onQ
_^h00ol0003oXk[Yoj>jj@03o`0000OoW/Cc00?o0000oj:mk?nR_N`00ol00007oi[5mP03o`000?nQ
_^goXKk]00?o00001onHa?H00ol0003oX[g/oj:mk003o`0000OoVL;d00?o0000ojFkj?l000000_l0
0007oijol0?o00002onU_>X3o`0000Ko[[[R0ol00004ojVmj003o`000?nj_mko^[oN00;o00002?ne
_=h2o`0000;o`/?K0ol000000oo7`MGo0000olFmd`07olFmd`03o`000?o?`/kocl;>00?ocl;>00?o
0000olk4d?o>a=000_o>a=000ol0003oeKg3o`000002omG2a`03o`000?oM`[ko000000Coh<No00Oo
0000on39`_l0003o0000onO4/ol0003oj<Nc00;o00000_o[b[@2o`0000?om/JJ0ol00002oog2O0;o
000000?onK9;o`000?l00000:ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z017o
oo]Z0_l000000ooKa<?o0000om_4``02om_4``03o`000?oJ`/;of/;200?of/;20_l00004omK1aP03
o`000?oD_/Goe;k500Coe;k500Oo0000om:la?l0003od[c4o`000?o@_LWo000000Koc[_800?o0000
olbiaoo<^LL01Oo<^LL00ol0003obkK6o`000002o`000003olRgb_l0003oakK900KoakK900Go0000
olFdbOo5]<WoaKC9o`000003olFcb@03o`000?o3//Wo`k;900Co`k;900?o0000onK3/ooV`k<00_oV
`k<2o`0000Coh;Za00?o0000omJ_/_oF[k801?oF[k800ol0003oejVZomNYZP03o`000003omNYZOl0
003ocZ6Y00GocZ6Y00?o0000ol6FZoo1UZ/00_o1UZ/01Ol0003o`iNZol>GZ_o3Uj[o000000_o_YF]
00?o0000ojj7[?n^Qj`02on^Qj`3o`0000WoXGf/1_n>Kj`3o`000003oi1a[?l0003oNfB^00SoNfB^
1?l00007ofEQ^@03o`000?mTHKWoI66i00;oI66i00?o0000od1D`?m0E<001OmBH<<00olF@[ko0000
oaI2_P02odIXd003o`000?laG/oo000000?o4EK@00?o=g?Oo`000?lKJ=/00_lKJ=/3o`0000;oBHg/
1?l00003obj3j@03o`000?mYZ?KoJJSf00;oJJSf2_l00007ohbnn0?o000000?oS;kho`000?n^c_40
0on^c_42o`0000_o[m3b00?o0000olWJi_o9f^H00oo9f^H00ol0003oe^CQomKTh@03omKTh@03o`00
0?oFh]ooe^;O00;oe^;O00?o0000omWSgOl000000ooVk]<00ol0003ojO??onWcc`07o`0000Oooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0OoookJP006_oonfX00ol0003ooo]Zoook
JP16oookJP;o000000?o0015o`000?lH2Gh00_lH2Gh2o`0000CoBCbP00Co0000oeUD/Ol0003oIUbc
0_l00003ofML/PGo00001?mnNL@01Ol0003oPgc3oh=l`on3O<?o000000GoRHK:00?o0000oi2>cOn@
S/d01_n@S/d5o`0000CoVJ7I0_l000000onKYMgo0000oijYgP09oijYgPCo00002OnR]^L4o`0000Wo
XKk^1?l00009oik4l`Co00002OnJaOH4o`0000WoV<Cf1?l00009oiW2m0Co00001_nN_o03o`0000?o
Tl;g00?o0000ojFlj_nU_>X01?nU_>X4o`0000;oWKo`00?o0000ojjjh_n^^^800_n^^^82o`0000Oo
ZKgX00?o0000okZog_l000002?ne_=h2o`0000;o/KkS00Co0000ol;3foo2`m_o`/?K0_l00007olFm
d`03o`000?o3`MOo000000Cocl;>00?o0000olk4d?o>a=000oo>a=03o`0000?oeL;700?o0000on37
_ooPakl00ooPakl4on39`P05o`000?oXak?oj<NconS7/ol000000oo[b[@2o`000005ooK6V_l0003o
n<VIooS9VOl000000_om`W`2o`000004ooVbBol0003o0000o`0002[ooo]Z00?o0000oookJ_oonfX0
?_oonfX00ol0003ooo]ZoookJP0BoookJP07o`000?oN`kgo0000om_4`ol0003oflC3o`000005om[2
`P03o`000?oH_l7of;o100;o000000?oe/76o`000?oD_/D01OoD_/D01_l0003od[c4om:la?oB_<Co
0000om:la0;o00001Oo>^lP00ol0003oc;W7olbia`05olbia`03o`000?o;]lKo000000?obkK60ol0
0005olNfb@03o`000?o5]<WoaKC900?oaKC900?o0000olFcbOl000001_o3//T00ol0003oi/>conK3
/`03onK3/`03o`000?oQ_;;o000000;oh;Za00?o0000omJ_/_oF[k801?oF[k800ol0003od:Vbo`00
0004omNYZP?o00001Oo>XJT00ol0003o`IJ[ol6FZ`02ol6FZ`05o`000?o3Uj[o`iNZol>GZ_l00000
2onnUJd00ol0003o[XN/ojj7[00:ojj7[0;o00002onQOJ`4ohi_[0;o00001?n@LJ`00ol0003oNfB^
og]T[P06og]T[P03o`000?n2JZko000000;oJenc0_l00004ofEQ^@;o00001OmTHKT2o`000003od5E
`?mBH<?oDV3300?oDV330_l000001?lF@[koAVS@odIXd?m6J=02o`0000?o4EK@0_l00004oa]Xf`;o
00001?m9SN`4o`000003obj3jOl0003oJJSf00GoJJSf00Go0000of6Um_mQYOKoHJGfo`000005ohbn
n0Co00001On<__P01?l0003o[/kao`000?l00009ojo@lP?o00000_n`d_801?l0003obM[VolWJi_o9
f^H2o`0000Coe^CQ00?o0000omKRgooFh]l00_oFh]l01?l0003ofN?MomWSgOl00002onK^d`04o`00
0?oYlloojO??onWcc`?o000000ColOJao`000?l0003o00002?oonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[ooo]Z01oooo]Z000JoookJP03o`000?oonf[ooo]Z04Kooo]Z0_l000000ol004Go
0000oaP9OP02oaP9OP;o00000om9?:001?l0003oFEBaoeUD/Ol00003ofIL/`Ko00001omnNL@00ol0
003oPgc3ohV6bP06ohV6bP04o`000?n@S/goT8k=oi2>c@Go00000_nCV]L01?l0003oVJ7IoiVQfOnI
XMT2o`0000GoVjGM00?o0000oijYg_nNZMh01?nNZMh3o`0000?oX;KX00?o0000oj:fionR]^L01?nR
]^L3o`0000?oX<;`00?o0000oj6nk_nQ_^h01?nQ_^h3o`0000?oW<Wg00?o0000oik4lonNa?<01?nN
a?<3o`0000?oULgk00?o0000oi[5m_nJaOH01?nJaOH3o`0000CoS/cm00Co0000oiS4m_nHa?KoV<Cf
1Ol00004oh_9o004o`000?nI`_CoVL;doiW2m0Go00001?n<aO/00ol0003oW[o`oijol003o`0000Oo
Tl;g00?o0000ojFlj_nU_>X00ol00007oifol004o`000?n^^^;o0000o`0000WoZKgX0_l00007okFl
gP;o00001Ona_^<2ol;3f`04o`000?o0aMko`<GNol35gP;o00000oo5_M<01Ol0003o`l7Gol?1eoo3
`MOo000000;ocl;>00?o0000olk4d?o>a=000oo>a=001?l0003odL_Com7;dooAbm<2o`000003omG2
aol0003oh<No00?oh<No1OoPbL82o`0000;oj<Nc0_l00002on_:]004o`000?o]c[Go0000o`0000;o
n<VI0ol000000oonaGSo0000ooVbB`03o`0002[ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003o
oo]ZoookJP0AoookJP07o`000?oN`kgog/>momk3_Ol0003oflC3o`000005om[2`P03o`000?oH_l7o
f;o100?of;o10_l00005omBna@03o`000?oB_<Cod[c400?od[c400?o0000om6j`ooA^/<00ol00000
0oo>^lSo0000olbia`06olbia`07o`000?o;]lKobkO6ol^ga_l0003obkK6o`000003olVda@?o0000
00?oakK9o`000?o5]<T01_o5]<T00ol0003o`k;9ol>bb@05ol>bb@03o`000?oV`k?oi/>c00;oi/>c
00Oo0000on6l/_oQ_;;ohKbbo`000?oP^[7o000000GoeZnb00Co0000om2Y/_o@ZK;o00001?oGZJX0
0ol0003od:N_om2W[`03o`000003oljQZOl0003o`IJ[00Go`IJ[00?o0000ol>GZ_l000002onnUJd2
o`0000_o[XN/00?o0000ojf5Z_l000002onQOJ`01?n>Kjco0000o`000?l00007oi1a[003o`000?mk
I:koNfB^00CoNfB^00Co0000oh9Z[_n2JZko00001?m[Gk<2o`000004ofEQ^Ol0003oIF6io`0000Ko
I66i0_l00005oe9P``;o>Ek=00Co0000odIXd?m6J=3oAVS@0_lTF]001Ol0003o4EK@oa5Fd?l0003o
AGSN00;o00000_lKJ=/00ol0003o5fCIo`000004odV=k003o`000?liQN[o>HGZ00?o00001_mYZ?H0
1?l0003oHJGfof6Um_mQYOH5o`0000[oS;kh00?o0000ojo@l_n_d?801_n_d?83o`0000Ko/=;b00?o
0000olWJi_l000000_o;g>H01?l0003oe^CQomKThOl00004omKRg`03o`000?oIhmgofN?M00;ofN?M
0_l00003onWcc`03o`000?oYl/oo000000;olOJa0ol00009oookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX07ooonfX001[ooo]Z00?o0000oookJ_oonfX0AOoonfX3o`000006o`00AOl0
003o60UnoaP9O_l0003o<B^I0_l000000om9?:3o0000oeUD/@02oeUD/@03o`000?mVG;?o000000_o
00000omnNL@00ol0003oRHK:ohV6bP03ohV6bPOo00001onCV]L3o`0000WoVjGM00?o0000oijYg_nN
ZMh00ol00007oj2fj003o`000?nR]^OoX[KW00?o00001onP`_000ol0003oXKk^oj6nkP03o`0000Oo
W<Wg00?o0000oik4lonNa?<00ol00007oiG=n`03o`000?nJaOKoV/Gf00?o00001_n>c?d5o`0000So
RlWl1Ol00008ohc5n`Co00002OnC`_L4o`0000WoWKo`0ol00008ojVmj0?o00000_nR_nh00ol0003o
]KcNokFlgP02okFlgP;o00001ona_^<2o`0000Ko`<GN00?o0000olFmdol000001?o3`ML00ol0003o
cl;>o`000005olk4d003o`000?oAbm?odL_C00CodL_C0ol00002on37_`03o`000?oPbL;oh<W200;o
h<W200?o0000on7<`ooQc<<00_l000001?o[b[Co0000on_:]?l00003ong>]@07o`000?ohbIWon<VI
o`000?ojcIOo0000ook5N005o`0002_ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Zoook
JP0AoookJP03o`000?oN`kgog/>m00;og/>m0ol00003om[2`P03o`000?oH_l7of;o100Cof;o100?o
0000omJn`Ol000000ooD_/D00ol0003od[c4om:la003om:la0;o00001OoA^/<2o`0000Koc;W700?o
0000ol^ga_o;]lH00oo;]lH00ol0003obKC5olVda@05olVda@?o00001Oo5]<T2o`0000Ko`k;90_l0
0004onK3/`03o`000?oQ_;;ohKbb00;ohKbb0_l00005omJ_/P04o`000?o@ZK;od:Vbo`0000?oejVZ
00?o0000om2W[oo@Yjl01?o@Yjl3o`0000Go`IJ[0_l0000;okjE[@03o`000?nhSJWo000000[o[XN/
00Co0000ojf5Z_n]QJ[o00002?nQOJ`4o`0000[oT76/00?o0000og]T[_mkI:h00_mkI:h00ol0003o
PVZ^oh9Z[P03oh9Z[PGoJenc0ol000000omUHKWo0000ofAQ^@05ofAQ^@;oE6?400Go0000oe9P`omB
H<?oDV33o`000003ocUNc@04o`000?m6J=3oAVS@o`0000;o95[@00?o0000oa5Fd?l000000om5N=h2
o`000003oa]Xfol0003o5fCI00?o00000_m9SN`00ol0003o>HGZocV5jP02ocV5jPco00000on<__P7
o`0000CoSKog00?o0000ojo@l_n_d?800on_d?82o`0000[o/=;b00Oo0000ol_Li_o;g>KobmcVo`00
0?oFi>7o000000Coe^;O00?o0000omWSgOoIhmd00_oIhmd2o`0000?ojO??00Go0000onWbcooYl/oo
0000oo7f/@02o`000003omcJIOl0003ooo]Z00Sooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003o
oo]ZoookJP0OoookJP006_oonfX00ol0003ooo]ZoookJP15oookJP;o000000Go0015o`000?l0003o
60Uno`000003oc4[V@;o00000omIE;43o`000003ofIL/ol0003oMWO600CoMWO600?o0000ogeka_mm
NlH00_mmNlH9o`0000CoTI[H00?o0000oi>JeonCV]L01_nCV]L00ol0003oUj3Jo`000009oi^Ug@Co
00002OnP]^P4o`0000WoX<;`1?l00009oic9m`Co00002OnEcO/5o`0000?oS/cm1Ol00004ofkAo004
o`000?n;bOcoRlWloh_9o0Go00001?mUcO/01?l0003oS<Gkohc5non<aO/5o`0000CoNlGn00Co0000
oi?2monC`_OoTl;g1Ol00004ohG3o004o`000?nM_o3oWKo`oifol0Go00000onC`OH00ol0003oZKgX
ojVmj003ojVmj0;o00001_nR_nh01?l0003o]KcNo`000?l00007ok6nh`;o000000?o[L3Xo`000?o0
aMh01Oo0aMh2o`0000Ko`l7G00?o0000olk4d?o>a=000_o>a=02o`0000KodL_C0oo?bmH00ol0003o
h<Noon37_`04on39`P03o`000?oQc<?ohLc300;ohLc300Co0000on_:]?o[b[Co00001?o]c[D00ol0
003on<VIo`000002oo[=U`04o`000?onaGSo0000ooo7L`Co0000:_oonfX00ol0003ooo]ZoookJP0m
oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000omk3_OoN`kd00ooN`kd01_l0003ogL6lo`000?l0
003of/;2o`0000Kof;o100Oo0000omJn`OoF_/7oe[k1o`000?oD_/Go000000God[c400Co0000om6j
a?oA^/Co00000ooA^/<00ol0003ockS3olnh``02o`0000?oc;W700?o0000ol^ga_o;]lH01?o;]lH0
0ol0003obKC5olVda@04olVda@04o`000?o8/lKob;?6olRcaP?o000000GoaKC9o`000?o5/lSoaK?8
o`000004ol>bb@;o000000GoiL>co`000?oV`k?oi/>co`000005on6l/P03o`000?oK]K7o000000;o
000000?oeZnbo`000?o@ZK800oo@ZK801?l0003oejVZomNYZ_l00006om2W[`03o`000?o9WJ_obIf[
00Co000000?o`IJ[o`000?l000002_nnUJd01Ol0003o^8fYokR=ZOnhSJWo000000So[XN/00Go0000
ojf5Z_n]QJ[o[HFZo`000002oj5m[0Ko00000onOO:d00ol0003oT76/oi1a[008oi1a[005o`000?mk
I:koNfB^og]T[_l000001_n2JZh01Ol0003oJencof]O/om[Gk?o000000?oMfNd00?o0000ofEQ^Ol0
00001?mTHKT01Ol0003oE6?4oeASa?mDHlCo000000;oDV3300?o0000ocUNcOliG/d00_liG/d00om6
J=3o0000obAJd004obAJd003oa5Fd?l0003oAGSN00?oAGSN0_l000001?lGI=Wo0000oeJ@k?mFT>`3
o`0000Go>HGZ00?o0000og2Ym?m`ZO@01?l00003ofFUm0Co00003?n=_oL00ol0003o[m3bo`000002
o`0000So/=;b0ol00002ok;ElP05o`000?o;g>KobmcVol_Li_l000001?oFh]l00ol0003ofN?MomWS
g@02omWSg@03o`000?oJjmoo000000;ojO??00Oo0000onWbcooYl/oojO;?o`000?oam[7okoBV00?o
00002_oonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01oooo]Z000JoookJP03o`00
0?oonf[ooo]Z04Gooo]Z0ol000001?l0073o0000oaP9O_l00003oc4[V@Go00000_mIE;42o`0000Ko
MWO600?o0000ogeka_mmNlH00_mmNlH01Ol0003oPhK>oh>6c_n3Q/ko000000WoTI[H00?o0000oi>J
eonCV]L00onCV]L2o`0000?oUj3J00Co0000oi^UgOnKYMgoVjGM1Ol00003oinej003o`000?nP]^So
X;KX00CoX;KX0ol00003oj33l@03o`000?nP`_3oX<;`00CoX<;`0ol00003oic>n@03o`000?nLbOOo
W<Wg00CoW<Wg0ol00004oi?Co@04o`000?nEcO_oULgkoiG=n`Go00000on7d_l5o`0000[oK]7l0ol0
000:ofG=n`?o00001OmkaOh8o`0000OoQL?l1_l00009oi?1mP03o`000?nY_NSo000000;o00001onR
_nh3o`0000Ko/KkS0ol00004ojg0j004o`000?o0aMko`<GNol35gP;o00000onmaN42o`000004ol?1
eol0003o`LCLo`0000?oc/C@00?o0000om7;dooAbm<01?oAbm<00ol0003ocl_Folo;eP03olo;eP03
o`000?oPbL;oh<W200;oh<W200?o0000on7<`ooQc<<00ooQc<<2o`000003on_:]?l0003o000000;o
kLje00Co0000onoB]Ol0003o00000_ojcIL3o`000003ooo7Lol0003o000000;o0000:_oonfX00ol0
003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000omk3_OoN`kd00ooN`kd01?l0
003ogL6lomg1_?oM`K`2o`0000Kof;o100?o0000omJn`OoF_/400ooF_/400ooD_/Go0000om:la003
om:la003o`000?oA^/CodK[400;odK[400?o0000om6j`ol000001Oo?^<<00ol0003oc;W7olbia`06
ol^gaP03o`000?o:]LKo000000CobKC500?o0000olRca_o8/lH01Oo8/lH3o`0000;oaK?800?o0000
ol>bbOo3//T00_l00003onG3/`03o`000?oV`k?o000000CohKbb00?o0000om^e/OoK]K400ooK]K42
o`0000Cod:Vb00?o0000omNYZ_l000001_o@Yjl00ol0003obIf[olVMZ`05olVMZ`So00001?nnUJd0
0ol0003o^8fYokR=Z@02okR=Z@04o`000?n^Qjco[XN/ojj7[0co00002_nOO:d00ol0003oT76/oi1a
[008oi1a[0;oNfB^2?n2JZh01?l0003oJencof]O/ol00005ogMW]0;o00000omTHKT00ol0003oE6?4
oeASa002oeASa004o`000?mBH<?oDV33o`0000Go>Ek=0_l00005obAJd0;o00001Om5N=h3o`0000Co
EY3/2?l00004og2Ym003o`000?mUYOCoIJGd00;oIJGd00?o0000ohfomon=_oL03?n=_oL00ol0003o
/=;bok3BlP06ok3BlP?o00001_nbeO801?l0003obmcVo`000?l00003omKRg`03o`000?oIhmgofN?M
00;ofN?M00Co0000om[[gooJjmoof^_O0_l00003onWbc`?o000000?okoBVo`000?l000003?oonfX0
0ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01kooo]Z000IoookJP03o`000?oonf[ooo]Z
04Kooo]Z0_l00002o`00L0;o00000_la:iT6o`0000?oFEBa00?o0000ogIga_mfMlH01_mfMlH01?l0
003oOG_6o`000?l00005oh>6cP03o`000?nAV]SoTI[H00OoTI[H00Go0000oi>JeonCV]OoTi[Go`00
0004oiNPfPGo00002OnO]NP00ol0003oX;KXoj2fj003o`0000OoX<?a00?o0000oj32l?nP`_000ol0
0007oic>n@03o`000?nLbOOoW<Wg00?o00001_nCdod5o`0000?oQm;o1Ol00004oeo@l`CoK]7l4?l0
0006ocjlj`Ko00001_m6_O401?l0003oQL?lohG3o?n5`o`5o`0000?oHLGl00?o0000oi?1m_nC`OH0
1onC`OH4o`0000KoX[o^1?l00002oi_1lP03o`000?na_^?o/KkS00;o/KkS0_l00007ojg0j004o`00
0?o0aMko0000o`0000Ko_LGQ0_l00003ol74g003o`000?o>a=3o000000KodL_C00?o0000olo;e_o?
bmH00oo?bmH00oo>b=Go0000o`000003on39`P03o`000?oQc<?ohLc300;ohLc300Co0000on;?a?oR
clCo00000_o]c[D00ol0003okLjeo`000002onoB]@03o`000?ojcIOo000000;oo=2E00?o0000ooo7
Lol000000ol0000ZoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX03ooonfX00ol0
003og/>momk3_@03omk3_@03o`000?oM`KcogL6l00;ogL6l0_l00004omRo`@03o`000?oF_/7oe[k1
00Coe[k100Ko0000omJk_ol0003o0000om:la?l00006om6ja003o`000?o?^<?ockS300GockS300?o
c;W7o`000?o;]lH01?o;]lH01Ol0003ob[G6olZea_o:]LKo000000;obKC500?o0000olRca_o8/lH0
1Oo8/lH01?l0003oa[34olJ`a?o6/<@3o`000004ol>bbOl0003o`Zo8o`0000CoiL>c0_l00004on6l
/P03o`000?oK]K7ofkFa00?ofkFa00Co0000omF^/Ol0003o00000_o@ZK800ol0003oejVZo`000006
om2W[`03o`000?o9WJ_obIf[00KobIf[0_l00005okjE[@go00001?n^Qj`00ol0003o/8^^ok2;[P02
ok2;[P03o`000?nOO:goWgb]00[oWgb]00?o0000oi1a[?n@LJ`01_n@LJ`2o`000003og]T[_n2JZko
PVZ^00SoPVZ^00?oJenco`000?mgIk@01_mgIk@2o`000003ofAQ^Ol0003oE6?400CoE6?400Co0000
oe1Pa?l0003o00001OliG/d2oeI`d@;o00000olTF]02o`0000GoAGSN00Co0000obe]g?l0003o0000
0omFT>`;o`000003og2Ym?l0003oIJGd00CoIJGd00Co0000ohfomon=_oOoSKog1ol00004oho1m`03
o`000?n`d_;o/=;b00?o/=;b0_l0000:ok;ElP03o`000?o=g^Go000000;oe^;O00?o0000omWSgOoI
hmd00_oIhmd00ol0003of^_Oom[[g`02om[[g`06o`000?oYl/oojO;?onWbcol0003oj_G<1Ol0000=
oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX07_oonfX001Wooo]Z00?o0000oook
J_oonfX0AOoonfX3o`0000;o001`1?l000000ola:iWo0000o`000003oeQD/`04o`000?mIE;7o0000
o`0000SoMWO60_l00007oh>6cP03o`000?nAV]SoTI[H00OoTI[H00Co0000oi>JeonCV]OoUj3J1Ol0
0002oib`iP03o`000?nO]NSoWkGX00SoWkGX1?l00009oj33l@Co00002OnLc_T4o`0000KoTm?m0ol0
0003ohCHo`Go00002_mOd?<6o`000003oe[>l?l0003o000001So00001Om6_O43o`0000WoHLGl00Co
0000oi?1m_nC`OKoTl7f1Ol00004ohO1nP03o`000?nR_nkoX[o^00?o00001onK`O801?l0003o/KkS
o`000?l00009ojg0j0;o00001_nmaN42o`0000?o^lKS0_l000000oo1a=co0000om7;d`05om7;d`03
o`000?o?bmKocl_F00;ocl_F00Co0000olk8eOo>b=Goc/SE0_l000000ooPbL;o0000on7<``03on7<
``04o`000?oRclCoh/o4on;?a0;o00000_o]c[D01?l0003okm:eonoB]Oo_d[D3o`0000;oo=2E00?o
0000ooo7Lol000000ol0000ZoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX03_oo
nfX2o`0000Cog/>m00?o0000omg1_?oM`K`00ooM`K`00ol0003og;jlo`000003omRo`@03o`000?oF
_/7oe[k100?oe[k100?o0000omJk_ooF^kl00_oF^kl2o`0000KodK[400?o0000olnh`oo?^<<01?o?
^<<00ol0003oc[K3oljf``03o`000003ol^ga_l0003ob[G600?ob[G600?o0000olVdaOl000001oo8
/lH00ol0003oa[34olJ`a005olJ`a0Co00001?oU`k<00ol0003ohKbbo`000002on6l/P03o`000?oK
]K7ofkFa00?ofkFa00?o0000omF^/OoE[[400_oE[[42o`000003om2Y/_l0003od:N_00God:N_00?o
0000olVMZoo9WJ/01_o9WJ/00ol0003o`YR/o`000008okjE[@03o`000?ncRZ_o/hZ[00?o/hZ[00?o
0000ojj7[?n^Qj`01?n^Qj`00ol0003o/8^^ok2;[P03ok2;[P03o`000?nOO:goWgb]00[oWgb]00?o
0000oi1a[?n@LJ`00on@LJ`3o`0000;oTG>^00?o0000oh9Z[_n2JZh01on2JZh2o`0000SoMfNd00Co
0000of5Q_?l0003o00001_mDHl@00ol0003oGfW5oemYa@02o`0000?o>Ek=1?mFL=401Ol0003o95[@
obAJd?l0003o8UW?00;o00000om5N=h01?l0003o;FgLobe]g?l]KM`5o`0000GoAXWZ00Co0000ogJZ
l_mfZ_;oMZ[b2ol0000<oho1m`03o`000?n`d_;o000000;o00002?nbeO83o`0000;o]MWb00Co0000
olgNiOl0003oe^;O1?oIhmd00ol0003of^_Oom[[g`02om[[g`;o00000_oYl/l01Ol0003oj_G<on[e
c?l0003okoBV00?o00003_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01kooo]Z
000IoookJP03o`000?oonf[ooo]Z04Gooo]Z1_l000001?l^:I[o0000oc4[VOl00002odQ:/004o`00
0?mHE;?oF5BcoeQD/`Co00001omfMlH00ol0003oPhK>oh>6cP07oh>6cP03o`000?nAV]SoTI[H00Ko
TI[H1?l00008oib`iP03o`000?nO]NSoWkGX00CoWkGX0ol00003oj32l003o`000?nP`o7oX<?a00Co
X<?a0ol00003oik?n@03o`000?nLc_WoW<ki00CoW<ki0ol00004oiGHoP03o`000?nCdogoTm?m00?o
00000on4f?l3o`0000?oHmK^1ol00003odk7k@Oo000000Co5P00okb9WonlRIoo00002?ndQ:400ol0
003o/7nOoj9fX@04oj9fX@;o00001OlO000?o`0000GoHLGl0ol00008ohO1nPCo00002OnK`O83o`00
00So[L3X0ol00002ojO2k003o`000?nmaN7o_LGQ00;o_LGQ00?o0000ok_6honka^<01Onka^<4o`00
00?odL_C00?o0000olo;e_o?bmH00_o?bmH00ol0003oc/SEolk8e@03olk8e@?o00000ooQc<<01Ol0
003oh/o4on;?a?oRclCo000000;oi=;500?o0000ong>]Ol000000_o_d[D01?l0003olMJeo`000?l0
0002ooc@U@Co000000?olJlgo`000?oonfX0:OoonfX00ol0003ooo]ZoookJP0moookJP03o`000?oo
nf[ooo]Z00kooo]Z00?o0000on;1]ol000000_oN`kd00ol0003ogL6lomg1_003omg1_007o`000?oL
_[cog;jlombn_?l0003of;o1o`000005omJn`@03o`000?oF^kooe[^o00?oe[^o00Co0000omBi_ol0
003o00000ooA^/@00ol0003od;S3o`000004olnh``03o`000?o>]/?oc[K300Coc[K30_l00005olZe
aP03o`000?o8/lKob;?600Gob;?600?o0000olJ`a?o6/<@01Oo6/<@01?o5[/Co0000olB^a?l00004
onG3/`07o`000?oQ_;;ohKbbon6l/_l0003ohKbbo`000005om^e/@03o`000?oE[[7oeJja00CoeJja
1?l00004om2W[`03o`000?o9WJ_obIf[00GobIf[00Go0000ol:H[?o2V:co`YR/o`000006okjE[@03
o`000?ncRZ_o/hZ[00Go/hZ[00?o0000ojj7[?n^Qj`00_n^Qj`00ol0003o/8^^ok2;[P05ok2;[P03
o`000?nOO:goWgb]00[oWgb]00?o0000oi1a[?l000000_l000000onALjko0000o`000006o`0000Go
PVZ^00?o0000oh5^]?l000002OmgIk@00ol0003oKVZmofiZ_@03o`0000?oE6?400?o0000oemYaOmO
JLD00_mOJLD01?l0003o>Ek=ocUNcOl00004oeI`d@06o`000?lTF]3o0000ob9Icol0003oEWoO0_l0
00000om5N=ko0000o`000003o`0000?oHYC[1?l00003odJ9jP03o`000?mfZ_;oMZ[b00;oMZ[b00?o
0000ofbVlom/Y_<00om/Y_<00ol0003oSl7goho1m`0=oho1m`03o`000?nbeO;o/]Gb00Ko/]Gb0ol0
0006okGIlP;o00001?oIhmd00ol0003of^_Oom[[g`02om[[g`05o`000?oMk]go0000onWbcol00000
0ooZmL`2o`000003oncdWol0003o000000oooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]Z
oookJP0NoookJP006OoonfX00ol0003ooo]ZoookJP15oookJPKo000000Co;RVJo`000?la:iWo0000
0_m8B[001Ol0003oF5BcoeQD/omHE;?o000000;oJW771?l00003ogIgaP;o00002On3Q/h00ol0003o
TI[Hoi6Jf002oi6Jf0Co000000?oTj;Oo`000?nL/>H02_nL/>H00ol0003oWkGXoinej003o`0000Oo
X<;`00?o0000oj33lOnP`o400ol00007oik?n@03o`000?nLc_WoW<ki00?o00001_nEf?h5o`0000;o
Q=So0ol00003of?FkP;oHM?_1_l000000om>ango0000o`000002o`0000;od9jS1?l00003okb9W`;o
00002?ndQ:400ol0003o/7nOoj9fX@02oj9fX@Go00000_nQMZ800ol0003oRFBQobh00003o`0000So
08bo00?o0000oeS5n?l000001olo]_801?l0003oQl7johO1n_n7`OX5o`0000?oNKkl00?o0000oi_1
l_nK`O801?nK`O83o`0000?oT/3f00?o0000ojg0j?n]`>P00on]`>P2o`0000KoYl;/00Co0000okg5
hOl0003o00001_nka^<2o`0000;o^<CT00Go0000olW:f_l0003odL_Co`000004olo;eP03o`000?o>
b=Goc/SE00Goc/SE00Go0000om_>c?l0003ohLc3o`000004on;?a009o`000?oTd/Goi=;5onCBaOl0
003okm:eo`000?o_d[Go000000;olMJe0ol00002ookCTPGo0000:OoonfX00ol0003ooo]ZoookJP0m
oookJP03o`000?oonf[ooo]Z00gooo]Z00Oo0000on;1]ooR`KOoh/6go`000?oN`kgo000000CogL6l
00?o0000ombn_?oL_[`00ooL_[`2o`0000Coe[k100?o0000omJk_ooF^kl00ooF^kl00ol0003oe;Vo
omBi_`02omBi_`03o`000?oA^/Co000000?od;S300Co0000olnh`oo?^<?o00001oo>]/<00ol0003o
cKC2o`000002o`000003olZea_l0003o000000Kob;?600?o0000olJ`a?o6/<@01Oo6/<@3olF^a003
o`000?oOaKoo000000;oiL>c00?o0000on6l/_oQ_;800ooQ_;82o`0000CofkFa00?o0000omF^/OoE
[[401OoE[[42o`0000;od:N_0ol000000oo@Yjoo0000olVMZ`06olVMZ`05o`000?o2V:co`YR/ol:H
[?l000001OnnUJd00ol0003o/hZ[ok>:Z`06ok>:Z`05o`000?n^Qjco[XN/ojj7[?l000002?n`Rjh0
0ol0003oWgb]oiml[@0:oiml[@Ko00001OnAM[400ol0003oPFfcoh5]/`03o`000005oh9Z[_l0003o
PFjdoh5^]?l000002?mgIk@00ol0003oKVZmofiZ_@04ofiZ_@04o`000?mDHlCoE6?4o`0000GoGfW5
00Co0000ocUNcOl0003o00001OmFL=42o`000003ob9Icol0003oEWoO00Co00000ol]KM`01Ol0003o
HYC[of:DjomRU>_o000000;oDhcY1Ol00004ogJZlP03o`000?m/Y_?oK:Kc00?oK:Kc00?o0000oho1
mon?`OL01On?`OL5o`0000?oT/?g00?o0000ok;El_nbeO800onbeO82o`0000Oo]MWb00Co0000okWM
l_nigO;o00000ooIhmd00ol0003of^_Oom[[g`02om[[g`03o`000?oMk]gogNkM00;o00000ooZmL`3
o`000003oncdWol0003ooo]Z00oooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0N
oookJP006OoonfX00ol0003ooo]ZoookJP12oookJPGo000000Ko001^o`000?lF6I?o5QVCo`000?l^
:IX2o`0000;oB4Z`00Co0000oeQD/omHE;?o00000omZLLL01?l0003oMGS8ogEhb?meN<PEo`0000Co
Tj;O00?o0000oib`i_nL/>H01onL/>H4o`0000WoX<;`1?l00009oik?n@Go00000onEf?h5o`0000Go
QMkm0_l000000omSe^ko0000o`000006o`000003on6aY?l0003o000000?odZ:U00?o0000om2NXoo@
WZ<00oo@WZ<01?l0003oaY:OolJBWoo6TYlBo`0000OoXGJR00?o0000ohUTXOn9I:401On9I:42o`00
0003ofmDXol]003o000000;o08bo2?l00002ocnflP?o00002Omi__`00ol0003oVl7boi_1lP03o`00
00OoT/3f00?o0000ojg0j?l000000_l00007ojO2k0?o00001_nka^<2o`0000Go^<CT00Co0000olW:
f_l0003o00000oo?bmH00ol0003oc/SEolk8e@04olk8e@03o`000?o>c=So000000;oflk<00?o0000
on;?a?oRcl@00_oRcl@00ol0003oi=;5onCBa@02onCBa@04o`000?o_d[Gokm:eo`0000?olMJe0ol0
0002ookCTP;o000000?ooLQVo`000?l00000:_oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oo
nf[ooo]Z00kooo]Z00?o0000on;1]ooR`KL00_oR`KL2o`0000CogL6l00?o0000ombn_?oL_[`00ooL
_[`01_l0003of[^ko`000?l0003oe[k1o`0000Goe[^o00?o0000omBi_ooD^Kl01?oD^Kl2o`0000?o
d;S300?o0000olnh`ol000001oo>]/<00ol0003ocKC2olfd`P03olfd`P;o000000?obKC5o`000?o8
/lH00oo8/lH00ol0003oa[34olJ`a005olJ`a0?oaJk40_l00002omo5_`03o`000?oU`k?o000000Go
hKbb00Co0000ombh]?l0003o00000_oK]K400ol0003oeJjaomF^/@04omF^/@04o`000?o:YK?obZFc
o`0000Cod:N_1Ol00003olVMZ`03o`000?o2V:co`YR/00;o`YR/00?o0000okjE[OnnUJd00_nnUJd0
0ol0003o/hZ[ok>:Z`07ok>:Z`04o`000?n^Qjco[XN/o`0000Wo/8^^00?o0000oiml[OnOO:d01_nO
O:d4o`0000_oTGJa00?o0000oh5]/on1KK<00_n1KK<5o`000003oh5^]?l0003oMfNd00GoMfNd00?o
0000og5[_Ol000001om^J[d3o`0000KoGfW50ol00004oeI`d@03ocm`f_l0003o000000;o00000_mF
Oml00ol0003o?ggTo`000002o`000005obe]g?l0003oHYC[of:Djol000001_mCS>T;o`000004ofbV
lol0003oSl7goho1m`Co00002OnB`oL00ol0003o/]Gbo`000002o`0000Oo]MWb00?o0000okWMl_ni
gO800onigO800ol0003ofN?Mo`000004om[[g`05o`000?oMk]gogNkMomg^gOl000000ooZmL`00ol0
003okOC8o`000003o`00017ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0Noook
JP006OoonfX00ol0003ooo]ZoookJP0noookJPCo00000_oonfX5o`0000;o5QVC0_l00002od]A]`03
o`000?m8B[3oB4Z`00;o00001OmZLLL01?l0003oMGS8ogEhb?l00004ogb3d003o`000?n=W=goSIcM
00OoSIcM00Co0000oi6Mg?l0003o00001onCX]l00ol0003oW;3Voib`iP03oib`iP?o00000onO_^h0
0ol0003oX<;`oj32l004oj32l0?o00000onPcoP00ol0003oW/oioik?n@04oik?n@?o00000onIf_d5
o`0000CoQMkm0ol000001?m`g?3o0000o`000?l00003od_;d`;o000000?oj[bTo`000?oQ/J@00ooQ
/J@00ol0003of:NUo`000002o`000003oljLY?l0003od9jS00;od9jS00?o0000olJBWoo6TYl01?o6
TYl00ol0003o_HbQo`000007okB5X`04o`000?n`PJ7o/86Qo`0000WoXGJR00?o0000ohUTXOn9I:40
0_n9I:43o`000003oheWXol0003oKeBS00CoKeBS00CoNejUobd00?l0003o>KK]1_l00002oc6Yl0go
00002?nB`?H4o`0000KoYl;/1?l00002oj;2l003o`000?nka^?o^lKS00;o^lKS0_l00007okS4i0;o
00000_o8c=`00ol0003ocl_Fo`000006olk8e@06o`000?o>c=Soc/cHolk<f?l0003oflk<0_l00002
on;?a003o`000?oTd/Goi=;500;oi=;500Co0000onGEa_l0003okm:e0_l000001?oae[Go0000oo?I
]OocfKD3o`000003oooFSOl0003o000000;o0000:_oonfX00ol0003ooo]ZoookJP0koookJP03o`00
0?oonf[ooo]Z00gooo]Z00?o0000on;1]ooR`KL00ooR`KL01_l0003oh;jfo`000?l0003ogL6lo`00
00Gog;jl00?o0000omZk^ol000000_oJ^k/2o`0000Coe[^o00?o0000omBi_ooD^Kl01OoD^Kl00ol0
003odkNno`000002o`000003om2h`ol0003oc[K300Koc[K300?o0000olfd`_o=]<801?o=]<800ol0
003obk71o`000002o`0000;ob;?600?o0000olJ`a?o6/<@01Oo6/<@4olF^a003o`000?oPa[ko0000
00;oglFo00?o0000on6l/_oQ_;800ooQ_;800ol0003og;Rdombh]002ombh]003o`000?oK]K7o0000
00GoeJja00Go0000olZU/oo:YK?obZFco`000004om2W[`03o`000?o;Y;7objBa00;objBa1ol00002
ol:H[005o`000?nnUJgo_YF]okjE[Ol000002_ncRZ/2o`0000_o/8^^00?o0000oiml[OnOO:d01ol0
0002oj61/@coTGJa00Co0000oh5]/ol0003o00001On7LK<5o`0000;oMfNd00Co0000og5[_OmaJkgo
LF^m1om^J[d2ofA^b003o`000?mOJLGoGfW500CoGfW50_m=Jm000ol0003oEW3AoeI`d@03o`0000?o
?g3J00Co0000oeIogomFOmoo00001?loON@2o`0000;oHYC[00?o0000oe><jOmCS>T01OmCS>T00ol0
003oOJcaogf/l@02ogf/l@03o`000?mcYo;oLjOb00;oLjOb1?l0000>oi;3m`03o`000?nefO;o]MWb
00Ko]MWb0_l00006okWMlP?o00000ooJjml01?l0003ogNkMomg^gOoMk]d2o`0000;oj_G<00Go0000
ongdb?o]m<So0000oncdW`02o`0001;ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Zoook
JP0NoookJP006?oonfX00ol0003ooo]ZoookJP0loookJP?o00001_oonfX4o`000004oaDLUol0003o
5QVCo`0000CoBe6g00?o0000odQ:/?l000001_mZLLL00ol0003oMGS8o`000006ogb3d003o`000?n=
W=goSIcM00OoSIcM00?o0000oi>RgonCX]l01onCX]l00ol0003oW;3Voib`iP03o`0000OoWkk^00?o
0000oj32l?nP`_000ol00007oj3?n003o`000?nNcoWoW/oi00?o00000onIf_d3o`0000?oTN;m1Ol0
0003og3Ll0;o000000KoBl_Co`000?l0003o0000oo77YOl00002onZmYP;o00000ooQ/J@00ol0003o
f:NUomRWY@02omRWY@Go000000?od9jSo`000?o6TYl01?o6TYl01?l0003o_HbQokf<XOl00006okB5
X`05o`000?n`PJ7o/86Qok21XOl000002OnQMZ800ol0003oRFBQo`000002o`0000CoSFNS00?o0000
ofmDXom_E:<00_m_E:<2og]NY@03oeY=ZOl0003o?c^T00;o?c^T1_l000001?lIXMco0000o`000?l0
0008oeJmn`04o`000?nB`?KoT/3foi;0mPGo00001?n8_oT00ol0003oYl;/ojO2k003o`0000OoX/;`
00Co0000ok_6hol0003o00001onha>@2o`000003okG6iol0003ob<cL00;ob<cL00?o0000olk8eOo>
b=D00oo>b=D2o`0000Goc/cH00Ko0000om_@c_oKd<ko0000on;?a?l00003onCBa@05o`000?oUeLKo
iMG6onGEa_l000000_oae[D01_l0003olmVeoo?I]OocfKGo0000oocHV`Ko0000:_oonfX00ol0003o
oo]ZoookJP0koookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000on;1]ooR`KL00_oR`KL00ol0003o
h;jfon2n]P02on2n]P;o00001?oL_[`02Ol0003of[^komZk^ooJ^k_o0000omZk^ol0003of;Vjo`00
0003omJk_`03o`000?oD^Kooe;Vo00Coe;Vo00?o0000om>g__oC]kh00ooC]kh3o`0000Goc[K300?o
0000olfd`_o=]<801?o=]<800ol0003obk71ol^a`@03ol^a`@?o00001_o6/<@4olF^a006o`000?oP
a[koh<Jnon36__l0003oglFo0_l00004on6l/P03o`000?oL^;Cog;Rd00?og;Rd0_l00005omF^/@03
o`000?o:YK?obZFc00;obZFc00Co0000om2W[oo@Yjoo00001oo;Y;400ol0003o_IF^okfE[P02okfE
[PCo000000?o_YF]o`000?ncRZ/02_ncRZ/00ol0003o/8^^ok2;[P04ok2;[PWo00000_nOO:d2o`00
00GoXH6a3?nAM[42o`0000SoQg6c00Oo0000ogAY^?mdJKSoM6Vho`000?mgIkCo000000?oLF^m00?o
0000ofiZ_Om^J[d00om^J[d01?l0003oI6k8ofA^b?mTK/P2o`0000?oGfW500?o0000ode[d?l00000
0ol000000omFL=7o0000ocm`fP04ocm`fP;o000000?oEWoOo`000?loON@01?loON@3o`000003oe><
jOl0003o000000GoDhcY00Go0000ogf/lOmm[?7oOJcao`000007og>WlP03o`000?nB`oOoT/?g00Go
T/?g1Ol00002oiK6m`03o`000?nefO;o]MWb00Co]MWb0_l00006okWMlP03o`000?nmgO3o000000;o
anG]00?o0000om[[gol000000ooMk]d01Ol0003oh?7Ko`000?oZmLco000000?okOC81?l0000Coook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX07_oonfX001Sooo]Z00?o0000oookJ_oo
nfX0>OoonfX3o`0000Wooo]Z1?l000001?lE79Oo0000oaHITol00005od]A]`;o00001omZLLL00ol0
003oO8?@ogb3d005ogb3d003o`000?n=W=goSIcM00GoSIcM00?o0000oi2Qgol000002?nCX]l4o`00
00WoWkk^1?l00009oj3?n0Go00000_nIf_d3o`0000?oTN;m1?l00004ogoSm0Go00000_ofdJL01?l0
003olLNUoo77YOl00003onZmYP;o00000_oQ/J@00ol0003of:NUomRWY@02omRWY@03o`000?o;W:Oo
000000;od9nT0ol00004olJBW`05o`000?nmS:7o_HbQokf<XOl000001?ndQJ<00ol0003o/86Qok21
X@03ok21X@03o`000?nQMZ;oXGJR00CoXGJR1?l00007oheWX`03o`000?m_E:?oKeBS00CoNejU0_mJ
CJT00ol0003o?c^To`000002odI8/004o`000?ma003o07Jko`1f^`_o00000_mF_O/3o`0000SoR;oi
1?l00009oj;2l0?o00001_nha>@3o`0000Co]LKW00Go0000olS<g?l0003ob<gNo`000003olk8e@03
o`000?o>c=Soc/cH00?oc/cH00?o0000olg>f_l000000ooKd<h2o`0000?oi=;500Co0000onGEa_oU
eLKoiMG60_l000001_oae[Go0000o`000?ocfKGo0000ooGM]0;o000000?oo]^Fo`000?l000000_l0
000ZoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003oh/6gon;1
]`02on;1]`03o`000?oP_[Koh;jf00?oh;jf00?o0000omjl]_l000000ooL_[`00ol0003of[^komZk
^`02omZk^`07o`000?oH^K[of;VjomRi^_l0003oe[^oo`000006omBi_`03o`000?oC]kkodkNn00Co
dkNn00Co0000om2d_Ol0003o00000oo>]/<00ol0003ocKC2olfd`P04olfd`P03o`000?o;/L7obk71
00Cobk7100?o0000olV_`?o9[l000ol00002olJ`a0GoaJk400?o0000on36__oPa[h00_oPa[h2o`00
0005omZn__l0003ohKbbon6l/_l000001_oL^;@00ol0003of;:bo`000002o`000003omF^/Ol0003o
bZFc00CobZFc00?o0000om2W[ol000001oo;Y;400ol0003o_IF^okfE[P05okfE[P03o`000?nmUZko
000001?o00001_n/R;000ol0003oWgb]o`000002o`0000OoXH6a2onAM[42o`0000WoQg6c00Co0000
ogAY^?mdJKSo00000ommKkT2o`000003og5[_Ol0003oKVZm00?oKVZm00?o0000ofA^b?mTK/P00_mT
K/P00ol0003oGF[7o`000004o`0000;oCF_@00?o0000oeI`dOmFL=400_l00004ocm`fP03o`000?mG
O]goEgkM00?o00000oloON@00ol0003oI9?Yo`000003of>Cj@Go000000?oDhcYo`000?mm[?400_mm
[?400ol0003oLjObog>WlP05og>WlP03o`000?nB`oOoT/?g00Co00002?nFa_L00ol0003o]MWbokGI
lP02okGIlP03o`000?nigO;o^Mgb00Co^Mgb0_l00002okgMl003o`000?o7iNgoanG]00;o00000ooM
k]d00ol0003oh?7Kon3af`02o`0000?okOC80_l000000oo/lY[o0000oookJP0DoookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX07_oonfX001Sooo]Z00?o0000oookJ_oonfX0=_oonfX3
o`0000cooo]Z00Co0000o`00G?l0003o00000_lE79L3o`0000CoBe6g00?oG6S6o`000?l000000_l0
0003ofYaa`;o00002?mlPm000ol0003oSIcMohfLg@03ohfLg@05o`000?n@XMooT:7Ooi2Qgol00000
0_nCX]l5o`0000?oVkO[00?o0000oinnk_nO_^h01?nO_^h3o`0000?oXL_f00?o0000oj3?n?nPcoP0
1?nPcoP3o`0000CoW]_l0ol00003oi7Ro@Co00001?moho@4o`000004odW8__ohgJgo0000o`0000;o
m]6W0_l000000ooaajGo0000onZmYP02onZmYP05o`000?oR/jKo0000on6aY?l000000ooHYjD01?l0
003obibWol^LYol00002om2OY003o`000?o8VJKob9VV00?o000000?oaY:Oo`000?nmS:400_nmS:40
0ol0003o]8FSokB5X`02okB5X`03o`000?n`PJ7o/86Q00?o/86Q00?o0000oj5fX_l000001?l00002
oimfY003o`000?n=Ij?oSFNS00KoSFNS00?o0000ofmDXomkGZD01OmkGZD2oeY=Z@;o00000om6B;02
o`000004o`LUYol0003o0000o`1/_0;o07Jk1Ol00005odB`m`04o`000?n8_oWoR;oiohRon@Go0000
0omo_?X00ol0003oX/;`oj;2l004oj;2l0?o00000_nM`_800ol0003o^<CTokS4i002okS4i0;o0000
1onea^L2o`0000?ob<gN00?o0000olk8eOl000001?o>c=P2o`0000?ocLkJ00?o0000om_@c_l00000
0_oLdll00ol0003oi=;5o`000003onGEaP0=o`000?oWf<KoimS6o`000?ocfKGo0000oo?I]Ol0003o
mMfdo`000?onfiKo0000ookMT`03o`0002[ooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]Z
oookJP0<oookJP;o00000ooR`KL00ol0003oh;jfon2n]P02on2n]P07o`000?oN_;Kog[bfomjl]_l0
003og;jlo`000005omZk^`;o00000ooH^KX2o`0000Goe;Vo00?o0000om>g__oC]kh01?oC]kh00ol0
003od;Bmom2d_@02om2d_@03o`000?o>]/?o000000KocKC200?o0000ol^a`Oo;/L401Oo;/L400oo9
[l3o0000olV_`003olV_`0?o00000oo5[/@00ol0003oh<Jnon36_P03on36_P03o`000?oL`;go0000
00;o000000?ohKbbo`000?oL^;@01?oL^;@00ol0003of;:bomRb/P03omRb/P?o00001Oo:YK<00ol0
003objBaol^T/@06ol^T/@03o`000?nmUJko_IF^00Go_IF^0_l0000<okZD/@;o00003?n/R;02o`00
00_oXH6a1onAM[43o`000003oi9f/Ol0003oQg6c00WoQg6c0_l00006oge_^@?o00000om^J[d00ol0
003oI6k8ofA^b002ofA^b0?o000000?oGF[7o`000?l000001?m=Jm001?l0003oEW3Ao`000?mRMm82
o`0000?o?g3J00?o0000oeMngOl000000_mPQ=h3o`000003ocmmi?l0003o000000SoHi?Y4?l0000=
oiK6m`04o`000?nefO;o0000o`0000Go^Mgb0_l00004okgMl0?o00000_o<jn/00ol0003ogNkMo`00
0003on3af`04o`000?o]m<SokOC8ongdb0Go00005OoonfX00ol0003ooo]ZoookJP0WoookJP03o`00
0?oonf[ooo]Z01gooo]Z000HoookJP03o`000?oonf[ooo]Z03;ooo]Z1?l0000?oookJP04o`000?l0
05co0000o`0000;o5AbG0_l`?k401ol0003oBe6god]A]om;DKOo0000oeaXa_l000000omYLLP6o`00
00OoO8?@00?o0000ohfLgOn=W=d02_l00009oi^gj`03o`000?nO_^koWkk^00?o00001onQboH00ol0
003oX<ohoj3?n003o`0000CoW]_l0ol00003oiWTo@04o`000?nAh_go0000o`0000;oOn?d2?l00000
1?okijKo0000ooSM[Ol00002ooKAY`03o`000?o`ajSol<NX00;o00000_oZ_JH01?l0003oh[>Von:c
Y_oR/jH2o`0000?of:NU00Ko0000ol^LYoo;W:Oo0000om2OY?l00006olRIYQ;o00001onOMZ@6o`00
00?oSFNS00?o0000og]NYOmkGZD01OmkGZD01OmJCJWo0000oeY=ZOmJCJWo000000;oATR`00Co0000
odm?/_l0003o1bFW0_l000001OlA>kWo0000o`1/_?l0K;co000000;o@K;e1Ol000001?m4/?Oo0000
o`000?l00009ognlnP03o`000?nR`_3oX/;`00?o00001_nM`_801?l0003o^<CTo`000?l00007okG6
i`;o000000?o//OYo`000?o8cMh00_o8cMh2o`0000Coc/cH00?o0000olg>f_o=c]X01?o=c]X00ol0
003og=??omcCc`02omcCc`05o`000?oUeLKoiMG6onGEa_l000000ooWf<H01?l0003olmVeoo?I]Ol0
0002ooGM]004o`000?onfiKo0000ookMT`Co0000:OoonfX00ol0003ooo]ZoookJP0koookJP03o`00
0?oonf[ooo]Z00_ooo]Z00Ko0000onFo/?oU_k3o0000on;1]ol00004on2n]P03o`000?oN_;Kog[bf
00?og[bf0_l00004omZk^`04o`000?oH^K_of;Vko`0000;of;Vj00?o0000omNg^_l000000_l00000
0ooD^Koo0000om>g_P05om>g_P03o`000?o@];god;Bm00?od;Bm0ol00005olfd`P03o`000?o;/L7o
bk7100Gobk710oo9[l001?l0003obJo0olV_`?l00003olN]_`?o00001OoPa[h00ol0003og<2momc0
_@03omc0_@03o`000?oL^;Cog;Rd00?og;Rd00?o0000omRb/_oH/[801?oH/[800ol0003odJbcom6/
/`03o`0000;obZFc00?o0000ol^T/Oo;Y;401Oo;Y;400ol0003o_IF^okfE[P06okfE[P03o`000?nj
U;7o^YBa00[o^YBa00?o0000okJ>[Ol000002on/R;000ol0003o[8R_o`00000;oj61/@CoTGJa0ol0
0004oi9f/@03o`000?n7LK?oQg6c00OoQg6c0_l00009oge_^@05o`000?m^J[goKVZmo`000?mTK/P0
1?l000001?mTK/So0000oeeZaomMJ/L2ofYbb0;o00000_m=Jm000ol0003oEW3Ao`000003of9gdP;o
000000?o?g3Jo`000?l000001_mPQ=h3o`0000[oHi?Y0on4[_000ol0003oO:S`ogbXl006ogbXl003
o`000?nFa_OoU/Kg00goU/Kg00?o0000okWMl_nigO801?nigO800ol0003o_Mg`okgMl004okgMl003
o`000?o<jn_oc>_[00;oc>_[0_l00003on3af`;o00000_o]m<P01?l0003ojO[2o`000?o/lYX2o`00
01Kooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0MoookJP006?oonfX00ol0003o
oo]ZoookJP0_oookJP?o00004ooonfX01_l0003o001Lo`000?l0003o5AbGo`0000?o<3na00?o0000
od]A]ol000000omLJ<H00ol0003oJG78ofUab002ofUab003o`000?mbO]3oLWk@00co00002?n@Xn80
0ol0003oVkO[oi^gj`06oi^gj`Co00002_nQboH3o`0000GoW]_l0_l00005oiWTo@[o000000GoHmJn
o`000?odl[;o0000oo[XZ002o`000005ooSM[Ol0003om]6WooKAYol000000_o`ajP01Ol0003ojKjX
o`000?oZ_JKo000000?oh[>V00Ko0000omZ[Y_l0003o0000omRWYOl00003ol^LY`;o00001_o8VJH0
0ol0003o^8VSokR9X`02okR9X`05o`000?ndQZCo]8JTokB6Y?l000001_nfRJD00ol0003oWgJToimf
Y005oimfY003o`000?nQN:Go000000CoSFZV1_l00004og]NY@;o00001?mJCJT00ol0003oATR`o`00
0002odm?/P?o000000Oo4C^io`0T[_l01YSo0000o`1Q^ol0003o@K;e00Go00000_liYO@00ol0003o
OkcjognlnP04ognlnPOo00002?nM`_83o`0000Oo]LKW0_l00004ok;7j@03o`000?o8cMko000000?o
alkP00?o0000olk<f?l000001Oo=c]X00ol0003ocM7Lo`000003omcCc`;o00000ooUeLH01ol0003o
imS6onOHa_l0003oj=_7o`000?ocfKD00ol000001OofhK?o0000o`000?l0003oo]n=00?o0000:Ooo
nfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z00_ooo]Z00Co0000onFo/?oU_k3oiKn`
0_l00004on2n]P03o`000?oN_;Kog[bf00?og[bf00?o0000omfj]Ol000000_oJ^k/00ol0003of;Vk
omRi^`02omRi^`;o00001OoG]kX2o`0000GodkNn00?o0000om2d_Oo@];d01?o@];d00ol0003ock:l
olnb_003o`000003olfd`_l0003obk7100Kobk711?o9[l000ol0003obJo0o`000006olN]_`03o`00
0?oPa[koh<Jn00?oh<Jn00?o0000omc0_OoL`;d00ooL`;d2o`0000Cog;Rd00?o0000omRb/_oH/[80
0ooH/[800ol0003odJbcom6//`04om6//`Co00001Oo;Y;400ol0003o_IF^okfE[P07okfE[P03o`00
0?njU;7o^YBa00Wo^YBa00Go0000okJ>[OnfSZgo]Xj]o`000009ojb8/004o`000?n/R:oo[8R_o`00
00_oXH6a00CoTGJao`000?l0003o00002?nBM[400ol0003oQg6cohMa/`04ohMa/`;o000000?oQWFh
o`000?mmKkT02?mmKkT5o`0000GoI6k800?o0000oeeZaol000001?mZL/P01?l0003oCF_@o`000?l0
0006of9gdP03o`000?loL=[o000000WoH8CN00Co0000of>CjOmSTnWo00001omSTnT2ohB^l003o`00
0?mlZ?3oO:S`00OoO:S`00?o0000oiK6monFa_L01OnFa_L5o`0000?oVlWg00Co0000okWMl_nigO;o
^Mgb0_l00005okgMl003o`000?o1h>oo000000?oc>_[00Co0000om3aj?o@lNSod?7X1?l00002ongd
b003o`000?oYn/;o000000;o00006?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
01gooo]Z000HoookJP03o`000?oonf[ooo]Z02cooo]Z0ol0000FoookJP;o000000Co0028o`000?lE
79Oo00000ol`?k43o`0000?oG6S600Go0000ofUab?mYLLSoJG78o`000003og9nd003o`000?n8Vmoo
R9_O00OoR9_O00?o0000oi2Sh_n@Xn802?n@Xn800ol0003oVkO[oi^gj`05o`0000CoWlCb00?o0000
oj7;m_nQboH01?nQboH3o`0000?oX]Sj00?o0000oikKo?l000000_l00004oiWTo@Co00000_nGjOX4
o`000003ogkWgOmSe[ko000000;o000000?om?:bo`000?ojj:P01Ol000001OofdJOo0000oo37Z?o`
ajSo000000;ojKjX00Go0000on:cY_oR/jKoh[>Vo`000004omZ[YPCo000000?obibWo`000?l00000
1Oo8VJH00ol0003o^8VSokR9X`03okR9X`04o`000?ndQZCo]8JTo`0000Oo]XVU00?o0000oimfY?nO
MZ@00onOMZ@2o`0000;oXGRU00?o0000oheZY_l000000_l00004ohe[Y`08o`000?mhGZWo0000o`00
0?mkGZGo0000ogIP[?l00005oeY=Z@03o`000?m7B[7oCdnb00;oCdnb00Oo0000o`Ta/_lA>kWo0000
o`0T[_l01YSo02Va013o00001_m_`?h01?l0003oWL;boig2l_nM`_85o`0000?oV<;d00?o0000okG6
ionea^L00_nea^L2o`0000Ko//OY0_l00005olO>h003o`000?o=c][ocLkJ00?ocLkJ00Oo0000olgA
g?o=dMcocM7Lo`000?oLdloo000000;ogMK@00?o0000onGEa_l000000_oWf<H01Ol0003oj=_7onSK
aooXflOo000000;omMfd00Ko0000ooKQ/ol0003oo]fCo`000?onghd3o`0002[ooo]Z00?o0000oook
J_oonfX0>_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oU_k3oiKn`00;oiKn`00Ko0000on>l
/?l0003o0000on2n]_l00005omjl]P07o`000?oM^[GogKZeomfj]Ol0003of[^ko`000005omRi^`03
o`000?oG]k[oekNj00?oekNj00Co0000omBe^_l0003o00000ooC]kh00ol0003od;Bmom2d_@03om2d
_@03o`000?o?/[go000000Cock:l0ol00005ol^a`@03o`000?o9[l3obJo000?obJo000?o0000olN]
_oo7[Kl01?o7[Kl2o`0000Coh<Jn00?o0000omc0_OoL`;d00ooL`;d2o`000005ombi]Ol0003o0000
ombh]?l000001OoH/[800ol0003odJbcom6//`06om6//`03o`000?o6X[Co000000?o00000_o;Y;40
0ol0003o_IF^okfE[P06okfE[P03o`000?nnUjoo000000Wo^YBa00?o0000okJ>[OnfSZd00_nfSZd0
0ol0003o[8R`ojb8/006ojb8/003o`000?n/R:oo[8R_00;o[8R_00?o0000oj61/OnQPK401OnQPK44
o`0000_oTWJa00?o0000ohMa/on7LK<00_n7LK<2o`0000CoQWFh00?o0000oge_^OmmKkT01?mmKkT4
o`0000;oMg;10ol00004ofA^b003o`000?mZL/SoJW;800CoJW;800?o0000ode[d?l000002?mRMm82
o`0000SoH8CN00Co0000og:JjOmbV^WoLY[Y1ol000000omSTnWoQ:k`o`00000:ogbXl003o`000?nF
a_OoU/Kg00Co00002OnKbOL00ol0003o^Mgbo`000005okgMl0;o00000_o1h>l01?l0003oc>_[olc[
jol00003om3aj008o`000?o@k>Sod>cXom3/j?l0003okOC8o`000?oYn/82o`000003omKdW?l0003o
oo]Z01Sooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0MoookJP005ooonfX00ol0
003ooo]ZoookJP0ZoookJP?o00006OoonfX2o`0000;o002800?o0000oc0o/Ol`?k400_l`?k42o`00
0003of5cc_l0003o000000;oG6S600?o0000ofUab?l000001OmbO]000ol0003oR9_OohRKg`06ohRK
g`03o`000?n@Xn;oT:?R00OoT:?R1?l0000:oio4lP03o`000?nQboKoXL_f00?o00001_nRf?X4o`00
00;oVNCm1?l000001?nGjO[o0000o`000?n1j>H4o`000003of?F__l0003o000000?o000000Kom?:b
o`000?l0003o0000ooKU]_l00002oo;J]`04o`000?o`ajSol<NXo`0000?ojKjX0_l00002on:cYP03
o`000?oJZjKofZ^V00;ofZ^V00Co0000om6QY_oAXJKodJ6V1Ol00003olRIYP03o`000?nhRJ?o^8VS
00Co^8VS0_l00009okJ9Y@05o`000?nOMZCoWgJToimfY?l000000_nQN:D4o`0000OoSF^W00?o0000
ogQNZOmhGZT00ol00002ogIP[006o`000?mJCJWoFTfYoeY=ZOl0003oJeV/0_l00002odm?/P04o`00
0?l9<K;o2C6bo`0000;o02B^00?o00fMo`0Y/Ol000000ol000000olIU^Oo0000o`000004o`0000_o
Kl3n0ol00009oiS2m004o`000?nea^Oo0000o`0000Go//OY0ol00002ok38k007o`000?o7c^3oalkP
olO>h?l0003oa]3Qo`000003olg>fP03o`000?o=dMcocM7L00?ocM7L00Co0000omgFd?oMe]3ogMK@
0_l00003onOHaP08o`000?oXflOoj=_7onSKaol0003omMfdo`000?ofhK<2o`000003ookMTol0003o
o]n=00?o0000:_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z00_ooo]Z00Go0000
onFo/?oU_k3oiKn`o`000004on>l/0;o00001?oN_;H00ol0003ogKZeomfj]@03omfj]@;o00001?oH
^K/2o`0000CoekNj00?o0000omBe^_oD]KX00_oD]KX00ol0003odkNno`000006om2d_@?ock:m00Co
0000olnb_?o?/[co00000oo=/;`3o`0000;obk711_o9[l000ol0003oajfoolN]_`04olN]_`03o`00
0?oQa[ko000000;oh<Jn00?o0000omc0_OoL`;d00ooL`;d01?l0003oeKRmomFh_Ol00002ombi]@;o
00001OoH/[800ol0003odJbcom6//`05om6//`04o`000?o6X[CoaZ:do`0000?obZBa1_l00004okfE
[P04o`000?nnUjoo_YN_o`0000So^YBa00?o0000okJ>[OnfSZd00onfSZd00ol0003o[8R`ojb8/005
ojb8/003o`000?n/R:oo[8R_00?o[8R_00?o0000oj61/OnQPK401Ol00003oj21/@03o`000?nBM[7o
TWJa00WoTWJa00Go0000ohMa/on7LK?oQg6co`000006ohIe^004o`000?mmKkWoOFnioge_^@?o0000
00CoOFniogUd`OmiM<7o00001OmgL/42o`000003ofA^b?l0003o000000SoJW;80_l00007of9gdP;o
00000_m/R]l00ol0003oH8CNof24gP03of24gP;o00002OmbV^T@o`0000koVlWg00?o0000okgMl?nm
gO000_nmgO02o`0000Go`N3_0_l00003om3aj003o`000?o@k>Sod>cX00;od>cX1ol0000KoookJP03
o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX07OoonfX001Oooo]Z00?o0000oookJ_oonfX0
9ooonfX3o`0001_ooo]Z0ol00002o`00R0;o00000ol`?k400ol0003oHG?>of5ccP02of5ccP?o0000
00?oJG78o`000?mbO]001OmbO]000ol0003oR9_OohRKg`04ohRKg`03o`000?n;XN;o000000?oT:?R
1Ol00002oiZjkP03o`000?nOa?;oWlCb00SoWlCb1?l00006oj;HnP?o00000onRho`4o`000003oiOY
n_l0003o000000[o000000?ogobho`000?l000000ol000000oocl[[o0000o`000003oo;J]`Co0000
0_oY_ZP01_l0003ohkJWon>fYol0003oh[>Vo`0000?ofZ^V00?o0000om6QY_oAXJH00ooAXJH01?l0
003ob9ZWolRJYoo8VZL7o`0000?o^8VS0_l00009okJ9Y@03o`000?nOMZCoWgJT00Co00000_nRNjP0
0ol0003oSF^Wohe[Y`06ohe[Y`?o00000omhGjT00ol0003oMV2/o`000002oeY=Z@0@o`000?m[FJco
JeV/of]I[?l0003oCdnbo`000?l/?K7o0000o`Ta/_lbCKoo0000o`0T[_l0003o00fMo`0Y/@;o0000
00Co04Ffo`000?l0003o00000olIU^L7o`0000GoH;Wm00?o0000oiS2m?nH`_@01onH`_@4o`0000Go
//OY0_l00006ok38k003o`000?o7c^3o000000?oa]3Q00?o0000olg>f_l000001?o=dM`01_l0003o
c]CNolkDg_l0003ogMK@o`0000;og]SA00?o0000onOHa_l000000ooXflL02ol0003oj]k7o`000?l0
003om^6co`000?ohiK7o0000ookOSOl0003oo>6700;o0000:_oonfX00ol0003ooo]ZoookJP0ioook
JP03o`000?oonf[ooo]Z00[ooo]Z00?o0000onFo/?oU_k000_oU_k000ol0003ohkb`on>l/002on>l
/003o`000?oQ^Zoo000000?og[bf00?o0000omfj]OoM^[D00ooM^[D01_l0003ofkNdo`000?l0003o
f;Vko`0000;oe[Nj00Co0000omNg^_oG]k[o00001_oD]KX2o`0000God;Bm00Oo0000olnb_Oo?/[go
ck:mo`000?o?/[co000000OocK2l0_l00005olV_`003o`000?o8[/3o000000Coajfo00Oo0000on76
__oQa[kohLJno`000?oPa[ko000000Cog<2m00?o0000omFh_OoE^;d00_oE^;d01?l0003og;Veo`00
0?oG/[<3o`000003omRb/_l0003odJbc00KodJbc00?o0000olJR]?o6X[@00_o6X[@01Ol0003obZBa
olZT/Oo:Y;7o000000CoaZ:d2?l00007okZD/@03o`000?nfSZgo]Xj]00Go]Xj]00?o0000ojb8/?n/
R;000on/R;000ol0003o[8R_ojb8[`07o`0000WoX86a00?o0000oi9f/OnBM[402OnBM[400ol0003o
Qg6co`000007ohIe^0Co00000ommKkT4ogUd`@OoMg;11?l00007ofYbb004o`000?m]OmCoKGoDo`00
00GoHWOB00?o0000odM_e_l000001?m/R]l3of24gP03o`000?m5O>;o000000[oLY[Y00?o0000ohB^
l?n4[_002_n4[_000ol0003oVlWgoi_9m`05oi_9m`Go00001?nOc_P00ol0003o_Mg`o`000007ol7P
k`05o`000?o@lNSod?7Xom3aj?l000001?o@k>P01?oHk^;o0000omomd?l00002omomd003omKdW?l0
003ooo]Z01_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0MoookJP005ooonfX0
0ol0003ooo]ZoookJP0SoookJPCo00007_oonfX2o`000006o`01R_l0003o0028o`000?lhB[Wo0000
0_l`?k400ol0003oHG?>of5ccP04of5ccPOo00000_mbO]000ol0003oR9_OohRKg`03ohRKg`03o`00
0?n;XN;o000000Co00002?nJ^^h00ol0003oWlCboio4lP04oio4lP?o00001?nSdOP00ol0003oX]Sj
oj;HnP03o`0000CoX^?l0_l000001?nQi_coY^OkojKWnonVio/<o`000005omol^?l0003o0000onci
^_l000000_ocl[X00ol0003om>Nio`000002oo;J]`03o`000?o[c;Gojlbe00;o00000_oY_ZP01?l0
003ohkJWon>fYooS]ZL3o`0000;ofZ^V00?o0000om6QY_oAXJH00_oAXJH00ol0003obIZWo`000004
olRJY`03o`000?o1TJCo`I6T00;o`I6T4_l00005oj9kZ003o`000?n=JjOoSF^W00GoSF^W0_l00006
ogQOZ@;o000000?oFTfYo`000?m[FJ`01?m[FJ`02?m?Ck;o0000ob`m/Ol/?K7o2C6bo`000?lbCKoo
02B^0_l000000ol0B<So02Vao`07QP02o`000003o`11Z_l0003o2hSR00;o00000olIU^L3o`0000Oo
H;Wm00Co0000oiS2m?nH`_CoV<;d1Ol00004oi?1mP03o`000?nbanWo000000;o00002?n`b>`2o`00
00Coa]3Q0_l00003olgAg0;o00001?o>e=h00ol0003og]SAomkHd@02omkHd@05o`000?oXflOoj=_7
onSKaol000000_oZg/L00ol0003om^6cooKQ/`03o`000003ookOSOl0003oo>6700;o0000:_oonfX0
0ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z00Wooo]Z0ol00002onFo/003o`000?oS_;3o
hkb`00;ohkb`00Oo0000on6j[ooQ^ZoohKZ_o`000?oN_;Ko000000GogKZe00?o0000om^g]?oK]k@0
0_oK]k@2o`0000?oe[Nj00?o0000omNg^_l000001_oD]KX00ol0003odk>io`000002o`000003om2d
_Ol0003ock:m00Cock:m00?o0000olf`_?o=/;`01_o=/;`00ol0003oc:nmo`000002o`000005olV_
`?l0003ob:k0olR^`?l000000oo7[Kl00ol0003ohLJnon76_P03on76_P;o00001?oL`;d00ol0003o
eKRmomFh_@03omFh_@03o`000?oG/[?oek:c00?oek:c0_l00006om6//`03o`000?o6X[CoaZ:d00?o
aZ:d00Co0000olZT/Oo:Y;7o00002?o6X[@01?l0003o^YFaokZE/OnjUK4Io`0000CoZh^d00?o0000
oj21/OnPPK402OnPPK400ol0003oTWJaoi9f/@04oi9f/@Go000000?oQg6co`000?l000001ol00000
0on6MKSo0000oge_^@03oge_^@GoNGC11_mgL/401?l0003oKgO;ofmgbom_Ml/3o`0000CoJW;800?o
0000oeEYbomEJL/01?m]Om@01_l0003oHWOBof9gd_l0003oAfoFo`0000OoK8[O0ol0000:og:Jj@;o
00003?n4[_000ol0003oVlWgoi_9m`04o`0000[oWlkh00?o0000ol7Pkoo1h>l00oo1h>l2o`000005
olCSk_l0003od?7Xom3aj?l000001?o@k>P2omS^hP;o00000ooOoM000ol0003ooo]ZoookJP0Koook
JP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX07OoonfX001Oooo]Z00?o0000oookJ_oo
nfX08?oonfX3o`0002;ooo]Z0_l000001_l00H[o0000o`000?lD;:Wo0000ocQ:^@;o000000?oB5_3
o`000?mQLlh01?mQLlh00om]P]Oo0000oh2Hh004oh2Hh0[o00000_n;XN<00ol0003oV[[^oiZjkP09
oiZjkP03o`000?nOa?;oWlCb00?o00001_nSdOP4o`0000CoX^?l1Ol00003ojKWn`03oiS`l?l0003o
000000?o000000?oSnoOo`000?l000000_l000000ooBoKco0000o`000003o`000003ooGY^Ol0003o
000000;om>Ni00Co0000oo;J]oobf[Oo00000_o[c;D01Ol0003oi<6co`000?oY_ZSo000000?ohkJW
00?o0000omb]YooL[JL00ol00004om6QYP03o`000?o9VZOo000000?ob9ZW00?o0000ol6AY?o1TJ@0
1_o1TJ@00ol0003o/HJXok66Z008ok66Z003o`000?nRNjSoXW^X00OoXW^X00Co0000ohe[Yon=JjOo
SF^W0ol000000on@KZSo0000ogQOZ@05ogQOZ@?o00001_m[FJ`00ol0003o;3faob`m/@02ob`m/@09
o`000?lbCKoo<Tfoo`000?l07J[o00fMo`18b?l0003o00N600Co000000?o6Y3Yo`000?l;R>800_l;
R>800olIU^Oo0000o`000006o`0000;oH;Wm0ol00008oi?1mP?o00002?n`b>`3o`0000;o[l[]00Co
0000olK@hOl0003o00000_o6dN<00ol0003ocM7Lo`000005olkDgP03o`000?o>emoo000000?og]SA
00Go0000onSKaooXflOoj=_7o`000002on[Na`;o000000Oom^6co`000?ohiK7o0000ookOSOl0003o
o>6700;o0000:_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z00Wooo]Z00Ko0000
onRlZ?l0003o0000onFo/?l00004on>l/003o`000?oQ^ZoohKZ_00;ohKZ_0_l00004omfj]@03o`00
0?oK]kCofkNd00?ofkNd00Co0000omVe]?l0003o00000_oF]kX00ol0003oe;FjomBe^P04omBe^P03
o`000?oC/kWodk>i00?odk>i0_l00005olnb_@03o`000?o=/;cocK2l00GocK2l00?o0000olb__Oo<
[kd00oo<[kd3o`0000;ob:k000Co0000olN]_oo7[Koo00001OoQa[h01_l0003ogL:mo`000?l0003o
g<2mo`0000KoeKRm00?o0000omNb/ooG/[<00ooG/[<01?l0003od[6go`000?l00004om6//`03o`00
0?o6X[CoaZ:d00?oaZ:d00?o0000olZT/Ol000002?o6X[@00ol0003o^YFaokZE/@03okZE/@03o`00
0?njU;7o^YBa00;o^YBa00?o0000okNE]?ngUK@01ongUK@01?l0003o[8V`o`000?l00009oj^;]003
o`000?nPPK7oX86a00WoX86a1ol000001OnDO;Ko0000o`000?l0003oU7bf00?oQWFh2_l00002oge_
^@KoNGC100?o0000ogMb`OmgL/400_mgL/400ol0003oKgO;ofmgb`02ofmgb`03o`000?mXLl_oJ7?;
00;o00000_mZL/P01?l0003oEFW;oeEYbol00006ofeoe0;o000000?oAfoFo`000?m/R]l01Om/R]l0
0ol0003oF8?QoeR3h@07o`0000CoLY[Y0_l00006ohB^l0So00002OnOc_P3o`0000;oYM?h00?o0000
ol7Pkoo1h>l00_o1h>l01ol0003oa>?^olCSk_o4hnko0000om3aj?l000001?o@k>P2omS^hP;o0000
0ooOoM02o`0001kooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0MoookJP005ooo
nfX00ol0003ooo]ZoookJP0MoookJP?o00009OoonfX2o`0000;o006:00?o0000oa@/ZOl000000_lh
B[T3o`0000CoHG?>00Co0000off2eom]P]Oo00001on0V>000ol0003oR9cPo`000007oh^Qh`03o`00
0?nJ^^koV[[^00OoV[[^1?l00006oj?An0?o00001?nVgO/01?l0003oX^?lo`000?l00002oj7Vo004
o`000?nVio_oY^OkojKWn`?o000000GoSnoOo`000?l0003oSnoOohO[cP04o`000009om;m_?l0003o
0000on3l^Ol0003ok?Vjo`000?oejKWo000000;om>Ni00Oo0000oo3E]Ol0003ol]Zgo`000?o[c;Go
000000;oi<6c0ol00002on>fY`03o`000?oL[JOog:fW00;og:fW00?o0000om>UZ?l000000_l00000
1?oAXJKo0000olVJYol00003olRJY`03o`000?o1TJCo`I6T00Go`I6T0_l00009ok66Z0;o00002OnR
NjP4o`0000GoT6jX00?o0000ogQOZOmhGjT00_mhGjT00ol0003oPFJ[oh5VZ`02o`0000CoJeV/00?o
GEZfode@]?l000000ol/?K402?l_BKco0000oc9=_ol7>;Wo0000o`0MZ_l0003o04S82Ol000001?l<
Q>?o2hSRo`^8h_l00003ofNjo@;o00001OmL/o/01?l0003oTl7foi?1m_nC`OH5o`0000;oT<3g00?o
0000ok38k?n`b>`00on`b>`3o`0000Go[l[]0_l00004olKAh`;o00001Oo>e=h02ol0003oc]OOolkG
goo>emoo0000omkHdOl0003oh=_Ao`000?oXflOo000000;oj]k700Wo0000on_Raoo[h/Oo0000ooSU
/Ol0003onNR_o`000?olhHL00ol0000ZoookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000oookJ_oo
nfX02?oonfX01?l0003oj;bXonRlZ?oX_:P3o`0000?ohkb`00?o0000on6j[ooQ^Zl00ooQ^Zl00ol0
003ogkN_o`000003omfj]@03o`000?oK]kCofkNd00;ofkNd00?o0000omVe]?oI]K@00_oI]K@00ol0
003oe[Njo`000005omBe^P03o`000?oC/kWodk>i00Codk>i00?o0000om:a^?l000000_l000001?o?
/[go0000olj`_Ol00005olf`_003o`000?o<[kgoc:nm00Coc:nm00?o0000ol^/^oo;[;/00ol00000
0oo7[Koo0000on76_P04on76_P03o`000?oM`[gogL:m00;ogL:m0_l00005omFh_@03o`000?o@/kgo
000000?oek:c00?o0000om:a]ooB/KL00_oB/KL2o`000003om6//ol0003oaZ:d00KoaZ:d00?o0000
olJR]?o6X[@01_o6X[@00ol0003o^YFaokZE/@04okZE/@05o`000?njU;7o^YBaokZD/Ol000002_ng
UK@2o`0000coZh^d00?o0000oj21/OnPPK401_nPPK42o`000003oj65]_l0003oU7bf00;oU7bf0ol0
0003oiAl]PCo00002?n6MKP00ol0003oNg:moge_^@02o`0000GoNGC100Go0000ogMb`OmgL/7oMg;1
o`000006ofmgb`03o`000?mXLl_oJ7?;00;oJ7?;0_l00003oeEYb`03o`000?m]OmCoKGoD00?oKGoD
00Co0000oeage?l0003o00001_m/R]l01?l0003oF8?QoeR3hOl00006og^Nj0co00001on4]oH00ol0
003oWlkhoio>n004oio>n0?o00001_nUdoP01?l0003o`N3_o`000?l00004olCSkP;o00001?o@k>P3
omS^hP04o`000?oOoM3ogog@omomd0;o00008?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oo
nf[ooo]Z01cooo]Z000GoookJP03o`000?oonf[ooo]Z01[ooo]Z0ol0000XoookJP05o`000?l007Co
0000o`01R_l@;Zd00_l00002ocQ:^@03o`000?m;Hl[o000000CoHG?>00Co0000off2eom]P]Oo0000
2?n0V>000ol0003oRj7Soh^Qh`07oh^Qh`04o`000?nJ^^koV[[^oiZjkPGo00001?nOao@00ol0003o
Xm7hoj?An003o`0000KoY]gk1Ol000001?nQi_co0000ojKWnonHl?02o`0000;oSnoO3Ol000000ooP
o;Wo0000o`000002ooGY^@03o`000?odikWo000000?ol=Fe00Co0000on_<]Oo[c;Go00000ooT`K<0
1Ol0003ohkJXo`000?oS]ZOo000000?og:fW00?o0000om>UZ?oCYJP00ooCYJP3o`000005olVJYol0
003ob9ZWolRJYol000001_o1TJ@00ol0003o^XbVo`000008ok66Z003o`000?n_PjKo000000OoXW^X
0ol00008oi1^Z003o`000?mhGjWoN5nY00;o00000on1IZ/00ol0003oIeV_o`000002of]I[0;oGEZf
0_m=D;@00ol0003o;3fao`000002obm9_003oc9=_ol0003o1cRi00?o000000Co04S8o`000?l0003o
05_B1?l000000olJRnWo0000o`000002o`b4h`[o000000CoG;?ko`000?l0003o00002?n@`?L00ol0
003o/<S/o`000002o`0000Go[l[]0ol000000on^bnoo0000olKAh`02olKAh`04o`000?o6dnCoa]?T
o`0000?oc]CN00?o0000olkGgoo>eml00_o>eml2o`0000?oh=_A00Co0000on[NaooZg/Oo00000oo[
h/L01?l0003on>Fao`000?oij:l5o`0002[ooo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]Z
oookJP08oookJP03o`000?oX_:Soj;bX00;oj;bX00Ko0000onJiYol0003o0000on>l/?l00004on6j
[`07o`000?oO]joogkN_omng[ol0003ogKZeo`000005om^g]003o`000?oI]KCofKFd00?ofKFd0ol0
0004omBe^P03o`000?oC/kWodk>i00?odk>i00?o0000om:a^?oB/KP00ooB/KP2o`0000;oc[2m00Go
0000olf`_?o=/;cocK2lo`000006olb__@03o`000?o;[;_objbk00Cobjbk00?o0000on76__oQa[h0
0ooQa[h00ol0003ogL:momg2_@03omg2_@04o`000?oJ_Kco0000o`0000;oeKRm00Co0000om2c_Oo@
/kgo00000ooG/[<00ol0003od[6gom:a]`04om:a]`?o00001_o6X[@00ol0003oaZ:dolJR]005olJR
]003o`000?njUK7o^YFa00Ko^YFa00?o0000okZD/Ol000002ongUK@00ol0003oZh^doj^;]00;oj^;
]003o`000?nPPK7oX86a00?oX86a0ol00003oj65]PCo00000onDO;H3o`0000;oU7bf2_n6MKP2o`00
00?oPgNm1Ol000001?miM<7oMg;1ogMb`Ol00007ofmgb`03o`000?mXLl_oJ7?;00;oJ7?;0_mcNL/2
o`000003oeEYbol0003oKGoD00?oKGoD00?o0000oeage?mLMm@00_mLMm@4o`0000;oK8[O00Go0000
oeR3hOmHPn7oF8?Qo`000009og^Nj003o`000?mZVngo000000goQ;Of00?o0000oio>n?nOc_P00ol0
000:ojGCn003o`000?o4hnkoa>?^00Coa>?^00?o0000om3/j?o@k>P00_o@k>P3omS^hP05omOhhOl0
003ogog@omomd?oOo/L00_l0000QoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0
7?oonfX001Oooo]Z00?o0000oookJ_oonfX05_oonfX4o`0002_ooo]Z0ol000000ol00H[o0000oa0^
[@03o`0000?oBf?:1_l00002off2e`03o`000?n0V>3oP9SP00GoP9SP0_l00005oh^Qh`Oo00002OnO
ao@3o`0000KoY]gk0ol00004ojOWn`co00000_nann000ol0003o_?c;o`000002o`000003om?m^_l0
003oh?bi00?o000000?omNVio`000?ocgKL00_l00003oo3E]@;o000000?ojlbeo`000?oT`K<00_oT
`K<00ol0003ohkJXon>fZ002o`0000?og:fW00?o0000om>UZ?oCYJP00ooCYJP00ol0003oaIVYolFI
Z@08o`0000?o`I6T00Co0000okZ<Y_njS:Ko00001_naQZP01?l0003o[h>Vojn3Y_n_PjH2oj9kZ0Go
00000_nPNZP00ol0003oT6jXoi1^Z006oi1^Z003o`000?mhGjWo000000GoPFJ[00Go0000ofMI[omW
FJooJeV/o`000002oeeJ]P?oCE2d0_l00002obm9_0;o00000_l7>;T00ol07J[o8EO>ob5GcP02o`0c
^P03o`000?l0Fm;o05_B00Co000000Ko6X_Yo`000?l?PNCo0000o`b4hol00004of:eo0CoFJkj00?o
0000oi30mon@`?L01on@`?L4o`0000Go[l[]0_l00005ojk;k`03o`000?o6dN?o000000Coa]?T00?o
0000olkDg_l000001?o>eml01Ol0003od=[Qom3JhOl0003oh=_A00;o00000_oZg/L01Ol0003ojn;7
on_Raol0003okNG700?o000000?onN^/o`000?l000000_l0000[oookJP03o`000?oonf[ooo]Z03So
oo]Z00?o0000oookJ_oonfX02?oonfX00ol0003oj;bXonRlZ002onRlZ0;o00000_oV^JL2o`0000Co
hKZ_00?o0000omng[ooO]jl00_oO]jl2o`0000CofkNd00?o0000omVe]?oI]K@01?oI]K@00ol0003o
ek:comNb/`02o`000003omBe^_l0003odk>i00Codk>i00?o0000om:a^?oB/KP01?oB/KP00ol0003o
d:ngo`000003o`000003olf`_?l0003oc:nm00Goc:nm00?o0000ol^/^oo;[;/01?o;[;/00ol0003o
hLJno`000003on76_P03o`000?oM`[gogL:m00?ogL:m00?o0000omZm_?oJ_K`00_oJ_K`00ol0003o
eKRmo`000003om2c_@03o`000?oG/[?o000000Ood[6g00?o0000oljZ]Oo>Z[D00ol00002olJR]003
o`000?o6X[Co000000KoaZ:d00?o0000okZE/OnjUK401_njUK42o`0000co]iFd00?o0000oj^;]?n[
Rk@02on[Rk@01?l0003oX86aoj21/OnPPK42o`0000?oXHFf1?l00002oiAl]PCo00001OnDO;H8ohIe
^0;o000000?oQgFhoh=g_On3Mkd01on3Mkd5o`0000OoKgO;00Co0000ofQcbomXLl_o00001?mcNL/2
o`0000CoKGoD00?o0000oeage?mLMm@00_mLMm@4ogJ@g`Ko000000?oF8?Qo`000?mkW^P01omkW^P0
1?l0003oJY_]ofZKkOl0000=ohBgmP;o00002OnUdoP3o`0000?oZ]Wh00Ko0000olCSk_l0003o0000
olSVk?l00003om3/j0?of>kR0_oGn>401?l0003ogog@omonaooOo/L2o`0002;ooo]Z00?o0000oook
J_oonfX07ooonfX00ol0003ooo]ZoookJP0LoookJP005_oonfX00ol0003ooo]ZoookJP0DoookJP?o
0000;ooonfX4o`0000?o42j]0_l00004od]SbP03o`000?mQLloo000000;oM93P0ol00006oh2Hh0So
00001_nH^o000ol0003oWlOdoio7m004oio7m0?o00000onUdoP00ol0003oY]gkojKMn`03o`0000Co
YnOk0ol000001?nWio_o0000o`000?nWmNl3o`000005ojGgh_l0003o[_WYo`000?nann000_l00000
1?nlo<_o0000olOl_?l00002om?m^P;o000000Oolnnlo`000?oejKWomNVio`000?ocgKOo000000?o
l=Fe00?o0000on_;]?o[bk@00_l00002onC1/`06o`000?oL]k;o0000on>fZ?l0003og;2[0_l00000
0ooL[JOo0000om>UZ003om>UZ003o`000?o5VJWoaIVY00;oaIVY00?o0000olRJZ?l000001?o2UjX5
o`000004okZ<Y_l0003o/HJXok66Z0[o00001onPNZP00ol0003oT6jXoi1^Z006oi1^Z0;o00001on1
IZ/01Ol0003oIeV_ogAR/?mdH[3o000000;oGEZf0_m=D;@2oemK]`05o`000?l_BKco;dVlodUJ`_l0
00000_l7>;T00ol0003o8EO>ob5GcP02o`0c^P?o000000?o05;<o`000?l000000ol00003o`n1i0Oo
00000_mI[_X01?l0003oT<3goi30mon@`?L5o`0000CoSKog00?o0000ojo:kOl000000_l00007ojk;
k`;o00001Oo6dn@2o`0000?oc]OO0_l00003om3Jh@;o00000_oQg]82o`0000;ojn;700Oo0000ongU
aoo]iLOo0000ooWX[ol0003onN^/00Co0000:ooonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oo
nf[ooo]Z00Oooo]Z0_l00003onRlZ008o`000?oV^JSoi[VXo`000?oV^JOo0000onBfYol00002on6j
[`03o`000?oO]joogkN_00?ogkN_00?o0000omfe[_l000000_l000000ooK]kCo0000omVe]004omVe
]006o`000?oG/[?oek:comNb/ol0003oek:c0_l00005om>c^@03o`000?oB/KSod[6h00?od[6h00?o
0000om2_]oo@[kL00oo@[kL3o`0000Goc:nm00?o0000ol^/^oo;[;/01?o;[;/01ol0003ohLJnon76
__oQa[ko0000on76__l000001OoM`[d00ol0003of[flomZm_004omZm_0;o00000oo@/kd00ol0003o
ek:co`000006om:a]`03o`000?o>Z[GocZZe00CocZZe2?l00002olJR]003o`000?njUK7o^YFa00Oo
^YFa00?o0000okNE]?ngUK@02_ngUK@00ol0003o]92ao`00000=oj^;]0So00000onQQKH3o`0000Wo
U7bf1_n6MKP2o`0000?oQgFh2_n3Mkd01?l0003oOG[5ogejaOmmN/D3o`0000CoKgO;00?o0000ofQc
bol000001omcNL/4o`000003oeage?l0003oG7OD00?oG7OD1OmfT=l01?l0003oJ8SOofR8gomXR=l7
o`0000?oNikX00Go0000ofZKkOmZVngoJY_]o`000003ohBgmPKo00000on:_?L00ol0003oYM?hojGC
n006ojGCn0;o00001onZfOP01Ol0003ob>K/olSVk?o8i^co000000;od>cX0_oHk^801Ol0003oeoSQ
omOhhOl0003ogog@00;ogok70_l0000SoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX07?oonfX001Kooo]Z00?o0000oookJ_oonfX04OoonfX3o`0003;ooo]Z0_l000000ol007Co0000
oa0^[@02oa0^[@;o00001Om;HlX00ol0003oM93PogB@h004ogB@h0Oo00000_n4WN<00ol0003oV;_`
oiRkl009oiRkl003o`000?nOaoCoWlOd00?o00001_nUdoP3o`0000GoYnOk1_l00002ojOek`03o`00
0?nTmn3o000000;o000000?o[_WYo`000?l000000_l000001?nlo<_o0000o`000?l00002om?m^P?o
000000Colnnlo`000?oejKWo00000_ocgKL01?l0003ol=Feoo3E]Ol00003on_;]005o`000?oU`[?o
0000onC1/ol000000_oL]k82o`0000?og;2[0_l00004om>UZ003o`000?o5VJWoaIVY00?oaIVY00?o
0000ol:GZ_o2UjX01Oo2UjX00ol0003o^XfVokZ=YP04o`0000?o/HNX00?o0000ojn4Y_n_Q:H00_n_
Q:H00ol0003oX7ZXoj1jZ007oj1jZ003o`000?n@KZSoT6jX00;oT6jX0ol000000onAL:[o0000oh5V
Z`06oh5VZ`;o00000omdH[001?l0003oGEZfode@]?l00003oemK]`06o`000?l_BKcoBE[2odUJ`_l0
003o1cRi0_l000001?lQElko04G6o`0c^_l0<kX3o`000003o`1Bc?l0003o000000;o7XSZ0ol00000
0ol?PNCo0000oenan`04oenan`;oF:[i1?l00007ohfom`Co00001on^bnl3o`000003ojg<l?l0003o
a]?T00;oa]?T0_l00002olOEi003o`000?o>emoo000000Cod=[Q00Ko0000om;MhOoBgN7o0000on7N
d_l00003on_Ra`07o`000?o]iLOokNG7o`000?oij:oo0000ooW[[004o`0002_ooo]Z00?o0000oook
J_oonfX0=ooonfX00ol0003ooo]ZoookJP08oookJP06o`000?o[^9go0000o`000?oX_:So00000ooV
^JP01ol0003oi;JWonBfYooT]ZOo0000on6j[ol000001?oO]jl00ol0003ogKF^omfe[P03omfe[P;o
00001?oI]K@00ol0003oek:comNb/`03omNb/`03o`000?oF/;?oe[2c00?o000000?odk>io`000?oB
/KP01?oB/KP00ol0003od:ngom2_]`04om2_]`;o000000KocZbgo`000?l0003o0000olb__Ol00007
ol^/^`;o00000ooQa[h2o`0000CogL:m00?o0000omZm_?oJ_K`01OoJ_K`00ol0003oeKRlo`000002
o`000003om2c_Ol0003od[6g00God[6g00?o0000oljZ]Oo>Z[D01_o>Z[D01?l0003o`Z2fol:P]_l0
0003olJR]0Oo00001?njUK42o`0000_o]iFd00Co0000okB@/OndT;7o00002On[Rk@7o`0000CoXHFf
1Ol0000;oiAl]PCoQWFh0_l00006ohMe^0OoPgNm0_l000000on1O<CoOG[5ogeja@04ogeja@?o0000
0_m_Ml/00ol0003oLgW;og=ib`06og=ib`03o`000?m/P=Ko000000?oMHGF0ol00002oeage0?oMY3O
00?o0000ofR8gomXR=l01?mXR=l00ol0003oQ:?XohBSj002ohBSj0_o00002_n:_?L00ol0003oYM?h
ojGCn003ojGCn0;o00001onZfOP01?l0003o/>3hok3Pn?n`h?P2olSVk005o`000?o@k>Sof>kRomS^
h_l000000ooGn>400ol0003ogok7omona`03o`0002Cooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP0LoookJP005_oonfX00ol0003ooo]ZoookJP0>oookJP?o0000=OoonfX5o`0000;o
42j]00Co0000oeA`d_l0003o00000om;HlX00ol0003oM93PogB@h004ogB@h005o`000?n1Un3oPIOP
oh6Gh?l000001On4WN<00ol0003oV;_`oiRkl007oiRkl0Co00001onUdoP2o`0000?oZMkj00?o0000
ojOWnol000000_l000001?nWio_o0000o`000?l00002ojOek`;o000000CoY?OPo`000?l0003o[_WY
0_l000000onann3oXo2bo`000003o`000009olOl_?l0003odofjo`000?o`m<3o0000oo?__?l0003o
m>>j00;o000000Kolmfgo`000?o_d[Go0000oo3E]Ol00002on_;]004o`000?oU`[?oiL:conG2/`;o
00000ooL]k801_l0003og;2[omb`ZooL/:_o0000omJXZ@?o000000?odjFXo`000?o5VJT01?o5VJT0
0ol0003o`YNZol:GZP04ol:GZP03o`000?njSJKo^XfV00;o^XfV00?o0000ok67Z?naQjP00_naQjP0
0ol0003o[hBVojn4YP03ojn4YP03o`000?nPNZSoX7ZX00OoX7ZX00?o0000oi1^Z?l000000_l00004
oi5`ZP03o`000?n1IZ_oPFJ[00CoPFJ[0_l00005ogAR/0;o00001OmOFkL2o`0000;oBE[200Oo1cRi
o`000?l0003o8EO>o`000?l0ALKo03>j00;o000000?o3FGJo`000?l000000_l000000olUQn_o0000
o`000002oaB0iPWo000000?oF:[io`000?n=_oL00_n=_oL5o`0000?oRkoh00?o0000ojk;kon^bnl0
0on^bnl2o`0000Go[Lc`00?o0000olKCi?l000001Oo7eN@00ol0003od=[Qom3Jh@02om3Jh@04o`00
0?oBgN7od]gQom;Mh@;o000000Cohn7Bo`000?o[h/Oo00000_o]iLL01_l0003oknO4o`000?oijjco
0000ooW]Z0?o0000:ooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z00Sooo]Z00Co
0000on^hWOo[^9gojkRM0_l00003onJiZ003o`000?oT]ZOoi;JW00;oi;JW0_l00004omng[`03o`00
0?oM]JkogKF^00?ogKF^00?o0000ombb[_l000000ooI]K@00ol0003oek:comNb/`03omNb/`03o`00
0?oF/;?oe[2c00?oe[2c0_l00005om:a^003o`000?o@[kOod:ng00?od:ng00Co0000olj/]oo>[;Oo
00000oo>[;L3o`0000Gobjbk00Co0000omW9b_oIbL[o00000_oQa[h00ol0003ogL:mo`000003omg2
_@03o`000?oJ_Kcof[fl00Cof[fl00?o0000omFh_?oE^;`00ooE^;`3o`0000God[6g00?o0000oljZ
]Oo>Z[D01Oo>Z[D00ol0003o`Z2fol:P]P02ol:P]P05o`000?o6X[CoaZ:dolJR]?l000001Oo2X;L7
o`0000Wo]iFd00Go0000okB@/OndT;7o]92ao`000003oj^;]0Ko000000GoZh^do`000?n]T;Oo[I2g
o`000003oj65]P?o00001OnQQKH00ol0003oU7bfoiAl]P09oiAl]P03ohIe^?l0003o000000SoQgFh
1_n3Mkd01Ol0003oPGc4oh5la?n1O<Co000000SoOG[50ol00009og=ib`03o`000?meQMKoMHGF00Go
MHGF0ol00002ogJ@g`03o`000?mXR=ooJ8SO00GoJ8SO00?o0000ohBSj?n4XnP01?n4XnP00ol0003o
MYo[ogJOj`02ogJOj`03o`000?n:_?OoR[cg00_oR[cg00?o0000ojGCn?l000000_l00006oj[In0;o
00001_n`h?P2o`0000;of>kR00Co0000omOhhOoGn>7oeoSQ0_l000001?oOo/Oo0000o`000?l0000V
oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX07?oonfX001Kooo]Z00?o0000oook
J_oonfX02ooonfX3o`0003Wooo]Z0ol000001OlG>;Co0000o`000?laD/Co000000;oE73B0ol00000
0omLN=Go0000ogB@h005ogB@h003o`000?n1Un3o000000OoQ9gS00Co0000oiRkl?nH^o3oV;_`1Ol0
0003oik7m003o`000?nUdoSoYM?h00;oYM?h0ol00005ojWNnPCo000000?oYnOko`000?l000000_nW
mNl2o`0000;oY?OP00Ko0000ojkijOl0003o/O_Oo`000?nann03o`000003okck`_l0003oaobl00?o
00000_o`m<02o`0000;om>>j00Co0000oo?M]oocgKOo00000_o_d[D01?l0003ojl^don_;]?l00004
onG2/`04o`000?oO^K7o0000ombg/P;o00000_oL/:/00ol0003oeZRYomJXZ@03omJXZ@Co00000_o5
VJT2o`0000Go`YNZ00?o0000okZ=Y_njSJH00onjSJH01Ol0003o/HNXok67Z?naQjSo000000Oo[hBV
00?o0000oj1jZ?nPNZP01_nPNZP<o`0000;oPFJ[0_l000000omnJK7o0000ogAR/004ogAR/0;o0000
1OmOFkL00ol0003o<4ZlodUJ`P02odUJ`PGo000000?o04G6o`0c^_l000001_l00003obF7j`;o0000
00?o583Vo`000?mN[OT01?mN[OT00ol0003oF:Oho`000003o`0000WoRkoh00?o0000ojk;kol00000
0_l00006ojg<l0?o00001?o7eN@00ol0003oamOUo`000003om3Jh@05o`000?oBgN7od]gQom;MhOl0
00000_oDhN400ol0003ohn7Bo`000002ongUa`07o`000?o_ilCoknO4o`000?oijjco0000ooW]Z004
o`0002[ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP07oookJP03o`000?o[^9go
jkRM00;ojkRM00?o0000onVeWOl000000_oV^JP2o`0000?oi;JW00Co0000on6dZ?l0003o00000_oO
]jl00ol0003ogKF^omfe[P02omfe[P07o`000?oL/Zkog;:^ombb[_l0003ofKFdo`000005omNb/`03
o`000?oE/;?o000000Coe[2c00?o0000om>_]?l000000_l000000ooB/KSo0000om2_]`05om2_]`04
o`000?o>[;OocZbgo`0000?ocZbg00?o0000olbZ^?o<Z[P00ol000000oo;[;_o0000omW9bP03omW9
bP;o00000ooM`[d00ol0003ogL:mo`000006omZm_003o`000?oE^;coeKRl00CoeKRl00?o0000olb_
_Oo<[kd00ol000000ooB/KOo0000oljZ]@06oljZ]@03o`000?o2X;Ko`Z2f00?o`Z2f00Co0000olJR
]?o6X[Co00002Oo2X;L00ol0003o^9FdokRE]00Bo`0000KoZh^d00Co0000ojf@]on]T;Oo[I2g1?l0
0008oj65]P03o`000?nDO;KoU7bf00OoU7bf0ol0000:ohMe^0CoPgNm00?o0000oh5la?n1O<@01?n1
O<@8ogeja@03o`000?mbM<Go000000;o00001omcNL/00ol0003oMHGFogF5eP08ogF5ePGo00001_mX
R=l00ol0003oQ:?XohBSj003ohBSj003o`000?mfWn_oMYo[00?oMYo[00?o0000ohZlmon:_?L02on:
_?L00ol0003oZ]Whoj[In005oj[In0;o00001_n`h?P01_l0003o]NOgokGWmol0003of>kRo`0000?o
eoSQ00Go0000omWkfol0003o0000on?m_@02o`0002Oooo]Z00?o0000oookJ_oonfX07?oonfX00ol0
003ooo]ZoookJP0LoookJP005_oonfX00ol0003ooo]ZoookJP07oookJPCo0000??oonfX00ol0003o
001ao`000002oaLh]0?o00001?mDL=87o`0000?oM93P00?o0000ohBMhon4WN<00on4WN<7o`0000Wo
W/Od00Co0000ojGCn?l0003o00001_nYg_X2o`0000;o[NSi1Ol000001?nWmNoo0000ojCgh?nTmn02
o`000003ojkijOl0003o000000?o000000CodOcQo`000?nlnl;o_?_20_l000001?oXmloo0000oo3d
`?o`m<03o`0000;om>>j0_l000001?ocgKOo0000onoB]Oo_d[D2o`000003on_;]?l0003oiL:c00;o
iL:c00Co0000omni/OoO^K7ogkVa0_l000001?oG[k3o0000omb`Zol00005omJXZ@04o`000?o=XJWo
cJ6YolfQZ@Go00001?o2UjX00ol0003o^XfVokZ=YP04okZ=YP04o`000?naQjSo/HNXo`0000Oo[hBV
00Co0000oj1jZ?nPNZSoX7ZX1_l00008oi5b[@06o`000?moJ:ooOfR_o`000?n1IZ_o00000_mnJK40
0ol0003oM6:`ogAR/002ogAR/003o`000?m[IK[oJfFj00;o00000_mOFkL01?l0003oBE[1o`000?l0
0002odUJ`P;o8DS100Go2471ocURd?liH]3o0000o`15aP02o`0000;o9VkN00Go0000o`1Hd_l0003o
0000oc28k003o`000003oaf1j?l0003o000000Co000000?oGZgio`000?mHYoP00_mHYoP00ol0003o
Rkohoh^on003oh^on0Ko00001_n]c?03o`0000Co[Lga00?o0000olOEi?l000000oo7enD00ol0003o
d=[Qo`000003om;Mh@04o`000?oDhN7oe>7QomCQh@?o00000_o]iLL01ol0003oknO4onoWa?l0003o
nN^/o`000?oikJP00ol000000ooonf[o0000oookJP0XoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o
0000oookJ_oonfX01ooonfX01Ol0003ojkRMon^hWOo[^9go000000?ojKFM0_l00002onBgZ004o`00
0?oT]ZOoi;JWo`0000?ohKBX0_l00005omfe[P03o`000?oL/Zkog;:^00;og;:^0_l00004omNb/`05
o`000?oE/;?oeK2comF`/ol000000_oF/;<00ol0003odjndom>_]003om>_]0;o00001Oo@[kL00ol0
003ocZbgolj/]`02olj/]`03o`000?o>[;Oo000000Koc:Zh00?o0000omW9b_oIbLX01?oIbLX00ol0
003ogL:momg2_@02omg2_@;o00001OoJ_K`00ol0003oeKRlomFh_004omFh_005o`000?o<[kgoc:nm
olb__Ol000000_oB/KL3o`0000GocZZe00?o0000ol:P]_o2X;H01?o2X;H00ol0003oaZ:do`000009
ol:P]`05o`000?nhUKCo^9FdokRE]?l000001_ngUK@00ol0003o]9JhokBF^005okBF^003o`000?n[
RkCoZh^d00CoZh^d0_l000001_n]T;Oo0000o`000?l0003o[I2go`0000[oXHFf00?o0000oiAl]_nD
O;H00onDO;H4o`0000;oUGbf00?o0000ohMe^?n7MKP02On7MKP2oh=g_@03o`000?n1O<CoPGc400Go
PGc400?o0000ogejaOmmN/D01?mmN/D00ol0003oLWC5og9da@03og^1cPCo00000_mcNL/00ol0003o
JGoFo`00000:ogF5eP04o`000?mlUN3oO9GPogbEh0Go000000?oJ8SOo`000?n4XnP01?n4XnP00ol0
003oMYo[ogJOj`04ogJOj`04o`000?n:_?OoR[cgohZlm`Ko00001?nA`_P00ol0003oZ]Whoj[In002
oj[In0;o00001On`h?P2o`0000Co]NOg1?l000001_oGn>7o0000omWkfol0003ogok7on?m_@;o0000
:OoonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z01cooo]Z000FoookJP03o`000?oo
nf[ooo]Z00Cooo]Z0ol00010oookJP07o`000?l0077o0000o`000?lG>;Co0000oc=IbP02o`0000?o
E73B00?o0000ofB2fol000001?mfS]h9o`0000GoTkO`00?o0000oik7m?nNao@01onNao@4o`0000Co
ZMkj0ol00002ojgXn@;o000000?o[NSio`000?nUk_P00_nUk_P9o`000004ojoje?l0003odOcQo`00
00;o_?_20ol000001_oXmloo0000oo3d`?l0003ol>[4o`0000;om>>j00Co0000oo3J^oo`f[_o0000
0_o_d[D00ol0003oj/Zdon[:]002o`0000;oiL:c00?o0000omni/OoO^K400_oO^K401_l0003oeJnb
o`000?l0003og;2[o`0000CoeZRY00?o0000olfQZOo=XJT00oo=XJT00ol0003o`9J/ol2F[009o`00
00?o^XfV00?o0000ok67Z?l000000on_Q:H9o`000003oj1jZOl0003o000000;oXWj]00?o0000oi5b
[OnALZd01onALZd2o`0000?oOfR_0_l000001OmnJK7o0000ogAR/?mdH[3o000000?oJfFj00Go0000
oeaK^?l0003oGe^go`000002odUJ`@03o`000?m9F/;o000000?o8DS10oliH]002?l0ALKo0000o`14
aOl0003o9VkNo`000?l:HMSo05SB0_l00003oc28k0;o000000?o7H7Xo`000?mPZ_P00_mPZ_P;o`00
00KoRkkh00?o0000ojg<l?n]c?000ol00008ojg=l@03o`000?o7enGoamOU00?oamOU00Go0000om;M
hOoBgN7od]gQo`000003omCQh@04o`000?oGiN7oenGQonGTd@;o00000_o_il@01?l0003ol>g3o`00
0?oikJP3o`0000;ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0goookJP03o`00
0?oonf[ooo]Z00Oooo]Z00Go0000on^hWOo[^9gojkRMo`000004onVeW@;o00000_oT]jP2o`0000Go
hKBX0_l00003omfe[P03o`000?oL/Zkog;:^00?og;:^00?o0000omZ`[Ol000000_l000000ooG/[?o
0000omF`/`02omF`/`03o`000?oF/;?o000000Kodjnd00Co0000om://_l0003o00000_o@[kL00ol0
003ocZbgolj/]`03olj/]`03o`000?o>[;Oo000000Goc:Zh0_l00005omW9bP03o`000?oE`lWo0000
00?ogL:m00Co0000omZm_?l0003o00000ooJ_K`00ol0003oeKRlomFh_003omFh_003o`000?o<[kgo
c:nm00?oc:nm00?o0000om:a]ol000000_o>Z[D3o`000003oljZ]Ol0003o`Z2f00Oo`Z2f00?o0000
ol:P]oo2X;L01oo2X;L00ol0003o^9FdokRE]003okRE]003o`000?ngUKCo]iFd00;o]iFd00?o0000
okBF^?ndU[P01_ndU[P00ol0003oZh^doj^;]003oj^;]0Co00001?n]T;L00ol0003oXHFfoj65]P09
oj65]P03o`000?nDO;Ko000000;o00001?nEO;H>o`000004oh=g_Ol0003o0000o`0000KoPGc400?o
0000ogejaOmmN/D00ommN/D00ol0003oLWC5og9da@02og9da@OoNh7>1?l0000:ogF5eP03o`000?ml
UN3oO9GP00KoO9GP4_l0000;oi72n004o`000?nZfOSo0000o`0000Go/>3h0_l00005okGWm`04o`00
0?o7m>goaoC]olOdk@;o00000_oInm/00ol0003ohofmon?m_@02o`0002[ooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP0KoookJP005OoonfX00ol0003ooo]ZoookJP02oookJP?o0000
@ooonfX01_l0003o001ao`000?l0003o5cRdo`0000;o<eW:00Co0000oeA`d_mDL=;o00000omTP]/0
0ol0003oMXkNogJ>gP04ogJ>gP;o00002_nC]o001?l0003oW/Odoik7m?nNao@5o`0000CoYM;h00Co
0000ojWNn_l0003o00000on]j?T2o`000004ojgXnOncl?Ko0000ojG^n0;o00000onfkOH2okSkiP04
o`000?o2mngo`_O]olCoeP;o000000CodOcQo`000?nlnl;o_?_20ol000002OoXmloo0000o`000?o`
m<3o0000oo3Za?l0003om>>jo`000003oo3J^`04o`000?o_d[Gokm:eo`0000;oj/Zd00Go0000onG2
/ol0003oiL:co`000003omni/@03o`000?oE[k;oeJnb00;oeJnb0_l00003omJXZ@03o`000?o=XJWo
cJ6Y00?ocJ6Y00Go0000ol2F[?o0UZco`9J/o`000003ol:GZ`03o`000?nmUJgo_IF]00;o_IF]2Ol0
0005ojj7[003o`000?nPNZWoX7ZY00;o00001?nROZd00ol0003oTG:]oi5b[@06oi5b[@;o00001_mo
J:l2o`000003ogAR/?l0003oJfFj00?oJfFj00?o0000oeaK^?mLFkP00_l00002odUJ`@04o`000?m9
F/7o0000o`0000?o8DS10oliH]002Ol0ALKo0000o`14aOl0003o9VkNo`000?l:HMSo0000o`1Fd003
o`000005oc28k?l0003o9X;Yoaf1j?l000001OmPZ_P01?l0003oFZKgoeZVmol00009oh^nn0Co0000
1on]cO43o`000003ojk?lOl0003oamOU00;oamOU00?o0000olSHi_l000000_oBgN401Ol0003oe>7Q
omCQhOoDhN7o000000?oenGQ0ol000001_o_ilCo0000oo3]`oo`kL?o0000ooW]Z0?o00000ooonfX0
0ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX01ooonfX2
o`0000;ojkRM00?o0000onVeWOoY]Id00_oY]Id00ol0003oik:Mo`000002onBgZ003o`000?oQ]:So
hKBX00?ohKBX00Ko0000on2aYol0003o0000omfe[_l00004ombb[P03o`000?oJ/:gof[2]00?of[2]
0_l00004omF`/`03o`000?oC[kCodjnd00Codjnd00?o0000om://_oB[;800_oB[;800ol0003od:ng
o`000006olj/]`03o`000?o<Z[Soc:Zh00Coc:Zh00?o0000om[9bOl000000ooIbLX01ol0003oeL?9
omG3bOoE`lWo0000omg2_Ol000001?oJ_K`00ol0003of[flo`000005omFh_003o`000?o<[kgoc:nm
00Goc:nm00?o0000oljZ]Oo>Z[D01?o>Z[D3o`0000Oo`Z2f00?o0000ol:P]oo2X;L01_o2X;L00ol0
003o^9FdokRE]004okRE]005o`000?ngUKCo]iFdokNE]?l000002OndU[P00ol0003oZh^doj^;]003
o`0000So[I2g00?o0000oj65]_nQQKH01onQQKH4o`0000;oUGbf1Ol00003oiJ2^`03o`000?n;O;go
Rgbm00OoRgbm0_l00003ohQn`PGo00000_n1O<@01Ol0003oOG[5ogejaOmmN/Go000000GoLWC500?o
0000og^1c_mkPLh01OmkPLh00ol0003oKg_>ofmkcP05o`0000CoMHGF00?o0000of^<h?l000002_ml
UN001Ol0003oPjCYoh>TjOn3Y>Wo000000OoPjCY00?o0000oi72n?nA`_P03?nA`_P00ol0003o/>3h
ok3Pn003ok3Pn0;o00001_neioL01Ol0003oaoC]olOdkOo7m>go000000;obO_V1Ol000000onXfgSo
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX06ooonfX001Gooo]Z
00?o0000oookJ_l000000_l00016oookJP;o000000?o01FQo`000?l000001?lcFLX4o`0000?oI8;K
00?o0000ogJ>g_mfS]h00_mfS]h01?l0003oPZ?Yoh:SjOl00008oi>gl0Go00002?nUd_P5o`000003
ojgXnOl0003o000000?o/o3f0ol00002okK]mP08o`000?nhnnKo^?_VokSki_l0003o`_O]o`000?o4
omH2o`00000:om7lhOl0003o0000okck`_l0003ohO[Do`000?oXmloo0000oo3d`0;o000000?ol>[4
o`000?ochkX00_l00002oo3J^`07o`000?o_d[Ko0000onoB]Ol0003oj/Zdo`000003onG2/`;o0000
0ooO^K400ol0003oeJnbomF_/P02omF_/P06o`000?oFZJ[o0000o`000?oFZ:Wo00001Oo=XJT01Ol0
003o`9J/ol2F[?o0UZco000000;o`YN[00?o0000okfE[OnmUJd01_nmUJd00ol0003o[XN/ojj7[008
ojj7[0?o00001onROZd5oi5b[@?o000000?oTgB]o`000?moJ:l01_moJ:l3o`0000GoJfFj0_l00002
of]U^P04o`000?m9F/7oBE[1o`0000;oFFC400Co0000ob58`OlQB<7o00000oliH]02o`0000;o?7KO
0_l000000ol:HMSo0000o`000002ocj;k@03o`000?l`R>co000000;o9X;Y2?l000000omJY_Oo0000
oh^nn002oh^nn0Go00000_n;__P00ol0003o[Lgaojg=l@03ojg=l@?o00001On^co400ol0003oamOU
o`000003olSHiP;o00000ooDhN402Ol0003oenGQomOUhOoGiN7o0000omKSh?l0003ohn_Fo`000003
oo3]``;o000000?onNbSo`000?l000001?oonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[o
oo]Z03Kooo]Z00?o0000oookJ_oonfX01ooonfX01?l0003okK:Ao`000?l00004onVeW@07o`000?oW
/Ygoik:MonNbWOl0003oi;NXo`000004on6dZ003o`000?oP/JOoh;6W00;oh;6W0_l00004ombb[P03
o`000?oJ/:gof[2]00?of[2]00?o0000omR^[Ol000000_l000000ooE/;?o0000om>_]004om>_]003
o`000?oB[;;odZbb00CodZbb0ol00005olj/]`03o`000?o<Z[Soc:Zh00?oc:Zh00Oo0000om[9bOoJ
bLWof/W9o`000?oIbL[o000000GoeL?900?o0000omZm_?oJ_K`01?oJ_K`2o`0000GoeKRl00?o0000
olb__Oo<[kd01Oo<[kd00ol0003ocZZeoljZ]@04oljZ]@03o`000?o:[;_obZbk00Co00000_o2X;H0
0ol0003o`j6fo`000006ol:P]`03o`000?nhUKCo^9Fd00Go^9Fd00Co0000okNE]?ngUKCo00002Ond
U[P5o`0000[o[I2g00?o0000oj65]_nQQKH00onQQKH4o`0000;oX8Bf1?l00008oiJ2^`03o`000?n;
O;goRgbm00GoRgbm0_l000000on;O;goR7k2ohQn`P07ohQn`P?o00000_mmN/D00ol0003oLWC5og9d
a@05og9da@03o`000?mkPLkoNh7>00?oNh7>00Go0000ofmkc_m_NlkoKg_>o`000004ogj=f0Oo0000
2omlUN000ol0003oPjCYo`000009oh>Tj@04o`000?nA`_SoTL;hoi72n0Oo00001OnGbOT01?l0003o
/>3ho`000?l00005okGWm`;o000000?o_NKco`000?o7m>d00_l00002olWkiP03o`000?oDm>Goe?CU
00;o000000?ocOo8o`000?oonfX0:ooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z
01_ooo]Z000EoookJP;o0000BOoonfX2o`000004o`0EXOl0003o0000o`0000?o<eW:0_l00002ofZ@
i0Co00001?mfS]h01Ol0003oPZ?Yoh:SjOn2XnWo000000;oTkO`1Ol00003oi[3m003o`000?nUd_So
YM;h00CoYM;h0ol00004oj_Ln@Co00000_ncl?H2o`0000;o]^gf00?o0000okSki_nhnnH00_nhnnH0
0ol0003o`_O]o`000002olCoeP04o`000?oAo>7o0000om_ocP;o000000OohO[Do`000?l0003oj?O?
o`000?o`m<3o000000;ol>[400?o0000oo?S^_l000000_o`f[/01Ol0003okm:fonoB]_o_d[Ko0000
00;oj/Zd00Ko0000onG2/ooU`[?oiL:co`000?oP^k82o`000003omni/Ol0003oeJnb00?oeJnb00Co
0000omJYZ_oFZJ[oeZVZ1?l00003olfQZ@03o`000?o0UZco`9J/00;o`9J/0_l00008okfE[@;o0000
2_n^Qj`00ol0003oXWj]oj9n[@07oj9n[@;oTG:]0ol00004oi=d[@03o`000?moJ:ooOfR_00CoOfR_
00CoQVf_o`000?maI;CoLFBd0_l00003of]U^P03o`000?m[IK[oJfFj00;oJfFj00?o0000odUJ`OmI
I<@00omII<@01?lQB<7o0000ob58`Om=K=42ocURd0;o65[B00Co0000ocafgol0003o86[L1?l00004
ocj;k@Co00001?mTZ?L00ol0003oGJGfoefUmP04o`0000SoRkkh00?o0000ojg=lOl000000_l00009
ojk?l@03o`000?o8f>Kob=SV00;ob=SV00Go0000omCQhOoDhN7oe>7Qo`000003omOUh@04o`000?oF
hn3oe^?PomKSh0?o000000?ol>g3o`000?l000001?l00005oookJP03o`000?oonf[ooo]Z02Gooo]Z
00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP07oookJP03o`000?o]/Y7okK:A00;o0000
0ooY]Id00ol0003oik:MonNbW@02onNbW@?o00000_oQ]:P00ol0003oh;6Won2aY`03on2aY`04o`00
0?oN[jOo0000o`0000;og;:^00?o0000omZ`[OoJ/:d00_oJ/:d00ol0003of:j]omR^[@03omR^[@?o
00001?oC[k@00ol0003odZbbom://P04om://P03o`000?o@Z[;od:Zb00?o000000CocZbgo`000?o=
ZkOo00000oo<Z[P00ol0003of/W9om[9b@03om[9b@;o00001OoE`lT00ol0003of[flomZm_003omZm
_003o`000?oE^;coeKRl00?o000000?oeKRlo`000?o<[kd01_o<[kd00ol0003ob:bno`000004oljZ
]@03o`000?o:[;_obZbk00GobZbk1Ol00005ol:P]`03o`000?nhUKCo^9Fd00Oo^9Fd0_l00006okBF
^0Co00000_ndU[P2o`0000co[I2g00?o0000oj65]_l000000_l00003oj24]P?o000000?oXXVjo`00
0?nFP[/02_nFP[/00ol0003oRgbmoh]l_@02oh]l_@03o`000?n;O;goRgbm00?oRgbm2_n8O/86o`00
00GoLWC500?o0000og^1c_mkPLh00_mkPLh00ol0003oKg_>ofmkcP03ofmkcP03o`000?mnSMSoOXgH
00CoOXgH00?o0000og67fOmaQmT02?l00005ogbEh003o`000?n3Y>WoPjCY00?oPjCY2Ol0000=oiO9
n@03o`000?neioOo]NOg00?o]NOg0_l00003okgVl`;o00000oo9nnH00ol0003oe?CUomCdi@02o`00
0003olgob?nXfgSooo]Z02gooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0Koook
JP005ooonfX00ol0003ooo]ZoookJP16oookJP06o`00COl0003o0000o`0EXOl0003o>fCA0_l00002
oc=IbP03o`000?mZT>CoJY3T00?oJY3T3?l00009oi[3m003o`000?nUd_SoYM;h00?o00001?n[g?T3
o`0000?o/NGh0ol00002okK]mP;o00000onhnnH3o`0000;oa?oF0_l000000ooAo>7o0000om_ocP02
o`000004on7je?l0003o0000onSgc`[o000000?ol=Zko`000?o_d[H00_o_d[H2o`000005on[:]?l0
003oiL:conG2/ol000001?oP^k82o`0000?oeJnb00?o0000olnY/_l000000_oFZJX01?l0003ocjJ_
olnV[oo?YZl5o`0000?o`9J/0_l00007okfE[@04o`000?nhSJ[o^8fZo`0000So[XN/0_l00007oj9n
[@Co00002?nCM:d01?l0003oOfR_ogmX[omoJ:l4ohI][`CoLFBd00Co0000of]U^_l0003o00001Om[
IKX2o`0000CoFFC40_l000001?lQB<7oCFcAocURd?l00002oaQJdP03ocafgol0003o86[L00;o86[L
1_l000000olnRngo0000oc23jP04o`0000;oI:Sg00Go0000oefUm_mMYOKoGJGfo`00000:oh^nn003
o`000?n^co7o[/oa00Ko[/oa0ol00002ojk@lP03o`000?o8f>Ko000000;obM[V00?o0000omCQhOl0
00000ooGiN401?l0003oe^?PomKSh?oFhn02o`0000;oi_3C1ol00006oookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP07oookJP07o`000?o]/Y7okK:A
onfbTOl0003ojk2Ao`000002onVeW@03o`000?oW/Ygoik:M00;oik:M00Ko0000onB`W_l0003o0000
on6dZ?l00004on2aY`03o`000?oN[jOogZnW00;ogZnW0_l00005omZ`[@03o`000?oH[Zgof:j]00?o
f:j]00?o0000omJ[[Ol000000ooC[k@00ol0003odZbbom://P04om://P03o`000?o@Z[;od:Zb00Co
d:Zb1?l00002olbZ^003o`000?oJbLWof/W900Cof/W900?o0000omS6b?l000000ooE`lT00ol0003o
dKk8o`000003omZm_003o`000?oE^;coeKRl00CoeKRl0ol00005olb__@04o`000?o8[;kob:bno`00
00CocZZe00?o0000olZ/^oo:[;/01_o:[;/00ol0003o_inhoknO^00;o`0000Go^9Fd00?o0000okBF
^?ndU[P00_ndU[P3o`0000Go]9Jh0_l00007ojf@]`So00000onPQ;H3o`0000CoXXVj00?o0000oiJ2
^onFP[/02OnFP[/01?l0003oRgbmoh]l_Ol00007oh]l_@WoR7k200?o0000ohJ3b?l000001?n3PLP6
o`0000?oNh7>00?o0000ofmkc_m_Nlh01?m_Nlh00ol0003oOXgHogj=f003ogj=f003o`000?maQmWo
LHOI00;oLHOI00?o0000ohFLh_n5W>801?n5W>8;o`0000KoPk?d00?o0000oiO9nOnGbOT02?nGbOT3
o`0000;oW]7j00?o0000okGWmoneioL00_neioL00ol0003o_NKcokgVl`02okgVl`;o00000oo9nnH0
1ol0003oe?CUomCdiOoDm>Go0000olgob?l00000<?oonfX00ol0003ooo]ZoookJP0HoookJP03o`00
0?oonf[ooo]Z01_ooo]Z000HoookJP;o0000AooonfX01?l0003o01FRo`000?l00003oc]Td@03o`00
0?lcFL[o000000OoJY3T00?o0000ogfKiOl000001_n1X>L00ol0003oV/?doi[3m006oi[3m0Co0000
1On[g?T2o`0000Co/NGh0_l000000ongk_Go0000o`000004o`000003okSki_l0003o000000;o0000
0_o4omH01?l0003odOcQo`000?l00002om_ocPOo000000Coi?SCo`000?oXl]3o00000_o[j/`00ol0
003oj^78on[Qb002o`0000;okm:f00?o0000on[:]OoZb[D00_l00002onG2/`03o`000?oP^k;oh;^b
00;oh;^b00Go0000om^d/_l0003oeJnbo`000002olnY/P03o`000?oFZJ[o000000KocjJ_00?o0000
olRM[?o8WJ`01?l00008okfE[@04o`000?nhSJ[o^8fZo`0000Oo[XN/00Go0000ojf6Zon]QZ_o0000
oj9n[@05o`0000;oX7f]00?o0000oi=d[OnCM:d01onCM:d00ol0003oOfR_ogmX[`05ohI][`CoLFBd
0ol000000om/IK[o0000of]U^P03of]U^P;oG6O500Co0000oeUTa?mII<CoFFC40_m1Hld00ol0003o
CFcAode/d@02o`0000;o65[B0_l00004ob1Zg004o`000?m<S^coC8k/odb>k0Go00000omZZ?D;o`00
00KoS;kh00?o0000ojk?lOn^co400on^co42o`0000Ko[]3b00?o0000olWJi_o9f^H00_o9f^H01Ol0
003oenGQomOUhOoGiN7o000000?oe^?P00Go0000omWTgOl0003oi_3Co`000002onWecP;o000000?o
koJ]o`000?l000001_oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX01ooonfX01Ol0003okK:AonfbTOo]/Y7o000000;ojk2A0_l00004onNbW@03o`00
0?oT/9koi;2N00;oi;2N0_l00004on2aY`03o`000?oN[jOogZnW00?ogZnW0_l00003omZ`[@03o`00
0?oH[Zgof:j]00?of:j]00Co0000omJ[[OoFZjgoeZ^]1?l00006om://P03o`000?o@Z[;od:Zb00Co
d:Zb00?o0000oljW/Oo>Yk401?l00005om[9b@07o`000?oHa/Sof<K8omS6b?l0003oeL?9o`000003
om6nb003o`000?oJ_Kco000000OoeKRl00?o0000om:h`?oB^<000ol000000oo<[kgo0000olR/_P03
olR/_P04o`000?o>Z[GocZZeo`0000SobZbk00?o0000oknO^?noWkP00_noWkP01Ol0003o`Z2gol:P
]oo2X;Oo000000Go_Z2j6ol00006oj^>^003o`000?nPQ;Ko000000;o00002?nRRKX00ol0003oUX:k
oiJ2^`07oiJ2^`;o00002_n;O;d7ohQn`P;o00000on6PlP00ol0003oPh78oh>1b006oh>1b0Oo0000
1Om_Nlh00ol0003oOXgHogj=f002ogj=f003o`000?maQmWoLHOI00?oLHOI00?o0000ohFLh_n5W>80
2?n5W>800ol0003oPk?doh>cm00:oh>cm003o`000?nGbOWoUlWi00CoUlWi0ol00006oikAnP04o`00
0?neioOo0000o`0000Go_NKc00?o0000olWki_o9nnH00_l00003omCdi@04o`000?o=olSoeOjmo`00
037ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0KoookJP006_oonfX00ol0003o
oo]ZoookJP14oookJP03o`000?l05J;o01FR00;o00000olkI=43o`0000OoJY3T00?o0000oh6Pion1
X>L01_n1X>L00ol0003oV/?doi[3m005o`0000CoX/kg00?o0000oj_LnOl000000_l00004ok7Un0;o
00000_ngk_D3o`0000Co^nKd3ol00002omgke`04o`000?oTn=?oi?SCo`0000;oj?;@00?o0000on_Z
c?l000000ooZhLP01Ol0003oj=S5o`000?o_d[Ko000000;oj/Ze00Go0000onG3/ol0003oiL:co`00
0003on2k/P04o`000?oK];;ofkBbom^d/P;o00000_o?ZK800ol0003oeZVZo`000005olnV[`03o`00
0?o8WJcob9f/00Cob9f/6Ol00008oj1m[@03o`000?nCM:goTgB]00GoTgB]00?o0000ogmX[on6KJl0
1_n6KJl01?l0003oLFBdog5T]?l00003og][]@;o00000om[IKX01?l0003oG6O5oeaWaOmLIlD3oeUT
a005o`000?m1Hlgo@F?=o`000?m=K=400_l/G]401?l0003o65[Bo`000?m;N]h3o`000003ob1Zg?l0
003o000000CoC8k/00Co0000oc^6j_l0003o00001OmZZ?D01?l0003oHJGfof6Um_l0000;ohbnn003
o`000?n^co7o000000;o00001On^d?82o`0000;o/=?b00Go0000olWJi_l0003obmgVo`000002omOU
h@05o`000?oFhn3oe^?PomKSh?l000000_oIi=d2o`0000;ojOG>0_l00002onof[@;o00001ooonfX0
0ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX01ooonfX2
o`000003onfbTOl0003ojk2A00?ojk2A0_l00003onNbW@03o`000?oT/9koi;2N00;oi;2N00Co0000
on:]W_l0003o00000_oP/JL00ol0003ogZnWomj_Y`03omj_Y`06o`000?oL[JKo0000o`000?oJ/:go
00001OoH[Zd02?l0003oeZ^]omJ[[OoFZjgo0000omJ[[Ol0003odjV]0_l00003om://P03o`000?o@
Z[;od:Zb00Cod:Zb00?o0000oljW/Oo>Yk400_o>Yk42o`0000Gof/W900?o0000omS6b?oHa/P00ooH
a/P2o`0000CodKk800?o0000omFh_?oE^;`01OoE^;`00ol0003od[S0om:h`004om:h`0?o00000oo8
[;h00ol0003ocZZeo`000008olZ/^`03o`000?noWkSo_inh00?o_inh00Co0000ol:P]oo2X;Oo0000
2OnnX;X4o`0000So]9Jh00?o0000ok:H_?nbV;`00_nbV;`00ol0003oZhjhoj^>^009oj^>^0?o0000
2onRRKX00ol0003oUX:koiJ2^`04oiJ2^`?o000000?oUh:jo`000?n;O;d02_n;O;d5ohQn`P03o`00
0?n6PlSoQX?800?oQX?800?o0000oh>1b?n3PLP01on3PLP2o`0000CoPXSA1_l00004ogj=f003o`00
0?maQmWoLHOI00CoLHOI00?o0000ohFLh_n5W>801_n5W>800ol0003oMI[Xo`00000<oh>cm003o`00
0?nGbOWoUlWi00?o00002_nNdOX00ol0003o_NKcokgVl`02okgVl`;o000000Co`^[ao`000?o9nnKo
00001?oDm>D01?o<o]oo0000o`000?l0000boookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX06ooonfX001_ooo]Z00?o0000oookJ_oonfX0@ooonfX01Ol0003o01FRo`0EX_lAB<Go0000
00?o>fCA00?o0000oe=lgOl000001?l00003ofZ@i003o`000?n1X>OoPJ3W00?oPJ3W1_l00009oj;>
m`?o00001?naiOP2o`0000?o]nke0_l00004ok_Vm005o`000?o3n>co`oS/ol?hk?l000000_nnn^/3
om3`j004o`000?o=oN3ocOgPomKmf`;o00000_oMnmL01?l0003ojNc?o`000?l00002onSbd004o`00
0?o[hLOo0000o`0000;oj^7800Co0000onOD`ol0003oj=S50_l000000ooZb[Go0000onG3/`02onG3
/`;o00000_oP^k800ol0003ofkBbom^d/P02om^d/P03o`000?oD[[7o000000?o00001Oo?YZl00ol0
003ob9f/olRM[005olRM[003o`000?nmUJko_IF^00Go_IF^00Go0000ok>;ZoncRj_o/h^[o`000005
ojj8[003o`000?naS:oo/Hb_00;o/Hb_00?o0000oj1m[OnPOJd01onPOJd00ol0003oTgB]oi=d[@02
oi=d[@?o000000?oTgJ_o`000?n6KJl01on6KJl00omaI;Co0000og][]@05og][]@03o`000?m[IK[o
000000CoG6O500?o0000oeUTa?l000001?m1Hld00om=K=7o0000obaNd@02obaNd@03oaQJd_l0003o
Bg[N00;oBg[N00?o0000ob1Zg?l000000ol00002odb>k003o`000?lkQ^[o>hKZ00[o00001_n<__P3
o`0000;oS;kh00?o0000ojk@l_n^d?800on^d?82o`0000Ko/=?b00Co0000ol_Mi_o;gNKobmgV0_l0
0003omKSh003o`000?oIi=gofNCM00;o00000_oYmLh01_l0003ojOC>o`000?o_mZgok?BOo`0000Wo
oo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z00Oo
oo]Z00Co0000onnZPOl0003o00001?o[/9401_l0003ojJfBo`000?l0003oik:Mo`0000Coi;2N00Co
0000on:]W_oR[IkohZfN0_l00005omj_Y`03o`000?oL[JKog:fV00;og:fV0_l00004omR^[@03o`00
0?oFZjgoeZ^]00?oeZ^]00?o0000om>Y[OoCZJd00_oCZJd2o`000003om://_l0003od:Zb00Cod:Zb
00?o0000oljW/Oo>Yk400oo>Yk400ol0003of/W9om[9b@03om[9b@03o`000?oHa/Sof<K800?of<K8
00Co0000omG2aooE`/Oo00000ooA_/P00ol0003oeKRlomFh_004omFh_003o`000?oB^<3od[S000Go
d[S000?o0000olnb__o?/[h01?l000000oo>Z[Go0000olZ/^`06olZ/^`03o`000?noWkSo_inh00Go
_inh0_l00006okjP^PGo00000_neU[L00ol0003o]9JhokBF^005okBF^003o`000?nbV;co/YRl00?o
/YRl00?o0000oj^>^?n[S[P02?n[S[P00ol0003o[9>lo`00000<oj:9^P03o`000?nFP[_oUX:k00;o
UX:k0_l00005oiN2^P03o`000?n;O;goRgbm00SoRgbm1?n8O/800ol0003oQX?8ohJ3b005ohJ3b003
o`000?n3PLSoPh7800GoPh7800?o0000oh27dOl000002On2R=4:o`0000;oLHOI00?o0000ohFLh_n5
W>801_n5W>801?l0003oMI[XogFJj?l00006oh>cm0Go000000?oPk?do`000?l000002OnNdOX3o`00
00?oY=Wj00?o0000okgVlol000000oo2j_42o`0000?oe?CU00Co0000olcngol0003ocOo80_l0000c
oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX06ooonfX001cooo]Z0_l00013oook
JP;o000000?o01FRo`000?lAB<D00_l000001?lkI=7o0000oe=lgOl00004off=h@Wo00001OnB^o<0
0ol0003oX/kgoj;>m`04oj;>m`?o00000onYeoP01?l0003o/NGho`000?l00003okO^m@;o00001?nk
i_@2o`0000;o`oS/1?l00003om3`j003o`000?o=oN3o000000;oe_gK00Co0000omgkeooMnmOo0000
0_oYk<l01?l0003oj?;@onSbd?l00002on_Qa`04o`000?oZhLSoj^78o`0000?oimC300Co0000onC>
`_oTc/;o00001?oU`k<01Ol0003oh;^bo`000?oP^k;o000000?ofkBb00?o0000omB^/OoD[[400ooD
[[44o`0000;ocjJ_00?o0000olRM[?o8WJ`01?o8WJ`00ol0003o`IN/o`000005okfE[P03o`000?nc
Rj_o/h^[00?o/h^[00Go0000ojj8[?n^R:co[XR/o`000005ok6<[`03o`000?nPOJgoX7f]00OoX7f]
00?o0000oi=d[Ol000000_l000000onCMZoo0000o`000004o`0000GoQVf_0_l00007og][]@?o0000
1OmLIlD3o`0000?o@F?=0ol00003obaNd@;o00001?m;N]h3o`0000;oFI7[0_l00002oc^6jP03o`00
0?maZOCoLJWd00?oLJWd00?o0000ofJUm?mVYO@01ol00006ohfom`03o`000?n^d?;o000000;o0000
1On`do82o`0000;o/]Kb00Co0000ol_Mi_o;gNKo00000ooFhn001_l0003ofNCMomWTgOl0003of^cO
o`0000;ojOG>1?l000000oo/m9oo0000oookJP09oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000
oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP07oookJP03o`000?o_ZX7okjZ100;o00000oo[/940
1?l0003ojJfBonV]T_oY[I82o`0000Coi;2N0_l00003on:]WP;o00000ooN[jL00ol0003og:fVomb]
YP03omb]YP03o`000?oJZjKo000000;o000000?of:j]o`000?oFZjd01?oFZjd00ol0003odjV]om>Y
[@04om>Y[@;o00001Oo@Z[800ol0003ocZNaoljW/@02oljW/@03o`000?oJbLWof/W900?of/W900?o
0000omS6b?oHa/P00ooHa/P00ol0003oeL;7omG2a`02omG2a`05o`000?oA_/So0000olfjaol00000
1?oE^;`00ol0003od[S0om:h`005om:h`003o`000?o?/[kock:n00Cock:n1?l00005olZ/^`03o`00
0?noWkSo_inh00Ko_inh00?o0000okjP^_nnX;X00_nnX;X3o`0000?o_Z2j00?o0000okFF]oneU[L0
0_neU[L00ol0003o]9JhokBF^003okBF^003o`000?nbV;co/YRl00Go/YRl00?o0000oj^>^?n[S[P0
1On[S[P2o`0000?o[9>l00?o0000oj:9^_nRRKX02_nRRKX4o`0000OoUh:j00?o0000oh]l_On;O;d0
2?n;O;d3ohQn`PWoQX?800?o0000oh>1b?n3PLP01?n3PLP01Ol0003oP8OAoh27dOn0Qm7o000000Wo
PXSA00?o0000ogb@fol000001_mlSm/Eo`0000OoRk_f00?o0000oikAn_nNdOX01?nNdOX3o`0000Oo
Y=Wj00Co0000ol;ZlOo2j_7o`^[a0_l00002omCdi@;o00000_o<o]l3o`0003Gooo]Z00?o0000oook
J_oonfX05_oonfX00ol0003ooo]ZoookJP0JoookJP007_oonfX00ol0003ooo]ZoookJP10oookJPCo
000000?o4DS5o`000?lkI=400_l00002oe=lg@03o`000?m]SN7oKHgQ00?oKHgQ00?o0000ogbSk?l0
00002_nB^o<00ol0003oX/kgoj;>m`03o`0000KoZMOh1?l00002okO^m@03o`000?nki_Co000000?o
^nKd00Oo0000ol?hk?o3n>co`oS/o`000?o=nNOo000000Cod?3X00?of_[Lo`000?l000000_oFoM/2
o`000003omgkeol0003ojNc?00;ojNc?00?o0000onSbd?l000000oo[hLL01?l0003oj^78on[Qb?l0
0003onOD``;o000000?oi<k2o`000?l000000_oU`k<01?l0003oh;^bon2k/_oP^k82o`0000?ofkBb
00?o0000omB^/OoD[[400ooD[[42o`0000;ocjN_1?l00004olRM[004o`000?o1Ujco`IN/o`0000Co
_IF^00?o0000ok>;ZoncRj/01?ncRj/01?l0003o[XR/ojj8[?l00007ok6<[`03o`000?nPOJgoX7f]
00CoX7f]2?l00004oi=h/@03o`000?n5L;Co000000;o000000CoQVf_o`000?n5LKCo00001omkJkD0
0ol0003oLffmog=]_@02o`0000?oG6O500?o0000ofI]aOmVKLD00_l000001Om1HlgoFg?Aoe]cdOmK
Lm7o000000;o;5kA00Co0000obYMd?l0003o00000_m;N]h01?l0003o<W3Mo`000?l00002oeVAj`03
o`000?m8RN[o000000;o00001OmaZO@01Ol0003oIZGdofJUm?mVYOCo000000_oSKog00?o0000ok3C
l_n`do800on`do82o`0000Ko/]Kb00?o0000olgOi_l000000_oFhn001?l0003ofNCMomWTgOl00003
om[/g`;o000000CojOC>on[gb_l0003ok?BO0_l0000;oookJP03o`000?oonf[ooo]Z027ooo]Z00?o
0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP06oookJP09o`000?o_ZX7okjZ1onnZPOl0003o
kJR2o`000?o[/97o000000CojJfB00Co0000onN[T_l0003o00000_oT/9h00ooR[Iko0000on:]WP02
on:]WP06o`000?oOZioo0000o`000?oN[jOo00001?oL[JH00ol0003ofZ^VomZ[YP03omZ[YP;o0000
1?oFZjd00ol0003oe:Z/o`000005om>Y[@03o`000?oBYjco000000;o000000?od:Zbo`000?o>Yk40
0_o>Yk42o`000003om[9b?l0003of/W900;of/W900?o0000omS6b?oHa/P00ooHa/P00ol0003oeL;7
omG2a`04omG2a`?o000000?ocK[7o`000?oE^;`00_oE^;`00ol0003od[S0om:h`004om:h`003o`00
0?o?/[kock:n00Gock:n0_l00002olZ/^`?o000000?obZbko`000?noWkP02?noWkP5o`0000Go_Z2j
00?o0000okFF]oneU[L00oneU[L00ol0003o]9JhokBF^002okBF^003o`000?nbV;co/YRl00Ko/YRl
00?o0000oj^>^?n[S[P00on[S[P2o`0000Go[9>l00?o0000oj:9^_nRRKX02?nRRKX3o`0000SoUh:j
3_l000000on8O/;o0000o`000004o`0000CoQX?800?o0000oh>1b?n3PLP00on3PLP00ol0003oP8OA
oh27d@02oh27d@03o`000?n2R=7oPXSA00SoPXSA00?o0000ogb?fomlSm/02?mlSm/7ohbSh`03o`00
0?n2W^GoPYkU00;oPYkU00?o0000oh^km_n;^oH02on;^oH00ol0003oW]7joikAnP03o`0000KoY=Wj
0ol00003oj[SnP03o`000?o2j_7o000000;oe?CU00Co0000olcngoo<o]ooc?kO0ol0000goookJP03
o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX06_oonfX001oooo]Z0_l00011oookJPCo0000
00?o4DS5o`000?lkI=401Ol00004off=h@04o`000?mlXncoO:?/o`0000SoT[_c1?l00006ojWGn0?o
00001?n`goL4o`0000;o^nKd0_l00002ol?hk0;o000000?ocOWWo`000?o@l>P00_o@l>P01?l0003o
f_[Lom[jg?l00002omKmf`04o`000?oQk=So0000o`0000?ojNc?0ol00003on_Qa`04o`000?oYfLCo
0000o`0000?oimC300?o0000onC=`?oTcL000_l000001?oOaKoo0000onG3/ol00003on2k/P06o`00
0?oL^;Go0000o`000?oK];;o00001?oD[[401?l0003obJBcolVT/ol00002olnW[`03o`000?o:Xk7o
bZ>a00?o000000Gob9f/o`000?o1Ujco`IN/o`000004okfE[P03o`000?ncRj_o/h^[00Co/h^[00?o
0000ojj8[?l000002?naS:l00ol0003oX7f]o`000005o`0000;oXX:a2OnCN;401?l0003oQG2dohE`
]?n5L;@4o`000003ohEa]?l0003oNf^e00CoNf^e00?oMVjmog=]_OmcKKd00omcKKd00ol0003oG6O5
oeaWa@05ofI]a@03od5ScOl0003oFg?A00?oFg?A00?o;5kAo`000?lZGM000_mJPMh00ol0003oBg[N
o`000003oc9`g@;o000000?oFI7[o`000?m8RNX00_m8RNX;o`0000?oSKog1Ol00003oho1m`03o`00
0?n`do;o000000;o00001Onbe_82o`0000;o]MWc00Co0000olgOi_l0003oe^?P0_oIi=d00ol0003o
f^cOom[/g`02om[/g`04o`000?oYm<ko0000on[gbP?o00003?oonfX00ol0003ooo]ZoookJP0Qoook
JP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX01_oonfX01Ol0003okjZ1onnZPOo_ZX7o
000000;okJR20_l00004onV]TP04o`000?oWZi;oij^BonN[TP;o00000_oR[Ih00ol0003ohZfNo`00
0004omn[W`;o00001?oL[JH00ol0003ofZ^VomZ[YP03omZ[YP03o`000?oHZ:Go000000;o000000Co
eZ^]o`000?oDZZco00001?oCZJd00ol0003odZN/om:W[003om:W[0?o000000WocZNao`000?o@bmGo
d<_Eo`000?oJbLSo0000om[9bOl000001OoHa/P00ol0003oeL;7omG2a`05omG2a`03o`000?oB_lOo
d[o700?o000000?oeKRlo`000?oB^<001OoB^<000ol0003ock:nolnb_P05olnb_P04o`000?o4Z[oo
a:Zoo`0000CobZbk0ol00006oknO^0Co00001onnX;X00ol0003o]IJgokFF]`04okFF]`05o`000?nd
U[So]9JhokBF^?l000002OnbV;`00ol0003oZhjhoj^>^002oj^>^003o`000?n/Tkco[9>l00Go[9>l
00?o0000oj:9^_nRRKX01?nRRKX4o`0000;oXHVj00Co0000oiN2^_nGP[[oUh:j1Ol00003oiR7`003
o`000?n?Pl;oSh?200OoSh?200?oSX?2ohb5a_n<QLH01On<QLH>o`000003oh27dOl0003oPXSA00Wo
PXSA00?o0000ogb?fomlSm/02OmlSm/5ohbSh`03o`000?n2W^GoPYkU00CoPYkU00?o0000oh^km_n;
^oH02on;^oH2o`0000OoY=Wj0_l00007oj[SnP;o000000?oe?CUo`000?o<o]l00_o<o]l3o`0003Wo
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0JoookJP008OoonfX00ol0003ooo]Z
oookJP0noookJP?o000000Go44c8o`000?l0003o>fCAo`000003oeR8i@Go00001?mlXn`00ol0003o
T[_coi:kl`05o`0000CoV/Kf00?o0000ojWGn?nYeoP00ol00005ok3Om`;o00000ongi_H00ol0003o
^nKdo`000003ol?hk004o`000?o=nNOocOWWo`0000?od?3X00Co0000om[jg?oJn]co00000_oFoM/0
1?l0003ohNcHon7/f?l00003onW/c`03o`000?oWhlko000000?ojn7700Co0000onWIa?oYfLCo0000
0ooWe<<02Ol0003oi<g0onC=`?oTcL3o0000on36__l0003oglFoo`000003on2k/P03o`000?oL^;Go
g;Re00;og;Re0_l00003omB^/@07o`000?o9Y;?obJBcolVT/ol0003ocjN_o`000006olZS/@Oo0000
00?o_IF^o`000?ncRj/01oncRj/00ol0003o/Hb_ok6<[`02ok6<[`Oo00000_nPOZh2o`0000CoXX:a
2OnCN;44o`0000CoRg>c1?l00002og][]@?oMVjm1_mcKKd2o`0000GoIVg50_l00004oe]cd@;o0000
00Wo:Ug@oeZ1g_mJPMkoFX7No`000?lbL=go0000oc9`gOl000000_mTU>X00ol0003oB8WZo`000002
odR9jP03o`000?mhZ_;oN:[b00;oN:[b00Co0000offVlom]Y_?oKJKc1?l00009oho1m`03o`000?nb
e_;o/]Kb00Co/]Kb0_l00005okGIl`;o00000_oIi=d00ol0003of^cOom[/g`02om[/g`04omg`gOl0
003o0000on[gbPCo00003OoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z03Cooo]Z
00?o0000oookJ_oonfX01_oonfX2o`0000;okjZ100Co0000onfXP_o]Z8;okJR20_l00003onV]TP03
o`000?oWZi;oij^B00;oij^B0_l000001?oR[Iko0000on:]W_l00004omn[W`04o`000?oNZ9ko0000
o`0000;og:fV00?o0000omZ[Y_oJZjH00_oJZjH00ol0003of:RUomRXY@03omRXY@;o00000_oDZZ`0
1?l0003odjV]om>Y[Ol00006om:W[004o`000?o@YJcod:F/o`0000Cod<_E00Co0000om[9b?l0003o
00001?oHa/P00ol0003oeL;7omG2a`05omG2a`03o`000?oB_lOod[o700Cod[o70_l00005om:h`003
o`000?o?/[kock:n00Gock:n00Go0000olBZ_oo4Z[ooa:Zoo`000004olZ/^`03o`000?o6Z[koaZZn
00Oo00000_o0XKT00ol0003o_Z2jokjP^P04okjP^P03o`000?neU[Oo]IJg00Go]IJg00Co0000okBF
^?ndU[So00002_nbV;`01Ol0003oZhjhoj^>^?n[S[So000000Wo[9>l00?o0000oj:9^_l000000ol0
0006oj69^PCo00002?nHQl000ol0003oSh?2ohn3`P05ohn3`PCoSX?22on<QLH01?l0003oPXG>oh:5
c_l00005ohR8c@Oo00001?n2R=400ol0003oO8oKo`00000;ogb?f`?oS:?S00?o0000oh:NiOn2W^D0
1_n2W^D01?l0003oRk_foh^km_n;^oH6o`0000CoT/?h00?o0000ojCIn_nTfOX00onTfOX2o`0000Oo
Z^?j00?o0000ojo/n?l000000_l000000oo<o]oo0000olcng`02o`000003okKi`Ol0003ooo]Z03So
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0JoookJP008_oonfX2o`0003kooo]Z
00?o0000o`00Q_l000000_l@C<P2o`0000GoF8SU00?o0000ogJJiomfV^L02?l00009oi[6mP?o0000
1_n`goL2o`0000?o]nKf1_l000001?o3n>co0000olgiioo=nNL2o`0000;od?3X00?o0000om[jg?oJ
n]`00_l000001?oFoM_o0000on7/f?oQk=P2o`0000;ojNc?00Co0000onOSc_oWhlko00000oo[hLL0
0ol0003ojMW4onWIa002o`000003onOD`ol0003oi<g000;oi<g000Co0000on36__oPa[koh<Jn0_l0
0002on2k/P03o`000?oL^;Gog;Re00?og;Re00Ko0000omNa/ol0003o0000omB^/Ol00003olVT/`03
o`000?o?Yjoo000000KobZ>a00?o0000okfE[_nmUJh00_nmUJh00ol0003o_IF^o`00000>o`0000Go
[HV`00Co0000oj1n[_l0003o00001_nRP[48oi=h/@;o00002?n;Lk<01?l0003oNFfiogU]^OmkJkD2
o`0000;oMVjm1OmcKKd01?l0003oJG77o`000?l00004ofI]a@03oeA^d?l0003oFg?A00?oFg?A00Co
0000odEbf_l0003o00000_mJPMh00ol0003o@goTod=oi003o`000004ofBDj_l0003oEXgYoeJ=j@Co
00001?mhZ_800ol0003oKJKcoffVl`02offVl`04o`000?n?`OOoSl7goho1m`Go00000_nB`oL00ol0
003o/]Kbok;FlP02ok;FlP;o00001OnefO<01?l0003o^MgbokWMl_nigO82o`0000?of^cO00Oo0000
omg`gOoMl=go0000on[gb_l0003ok?K600?o00003_oonfX00ol0003ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX01_oonfX01Ol0003okim[o`000?o_ZX7o000000?o
kJR200Go0000on^VPol0003ojJfBo`000005onN[TP06o`000?oTZ9?o0000o`000?oR[Iko00001?oO
Zil01?l0003ogZRNomjXW_oNZ9h2o`0000GofZ^V00?o0000omRXYOoHZ:D00ooHZ:D00ol0003oeJFU
o`000002o`0000;odjV]00?o0000om:W[?oBYj`00ooBYj`01?l0003od:F/om2U[?l00005om3;e@;o
00000_oHa/L2o`000003omS6b?l0003oeL;700KoeL;700?o0000om:oaooB_lL01?oB_lL2o`000006
om:h`?l0003o0000o`000?oB^<3o00001oo?/[h00ol0003oa:ZoolBZ_`03olBZ_`04o`000?o:[;_o
bZbko`0000;oaZZn0ol00002olJZ_PWo00000_nnX;X00ol0003o]IJgokFF]`07okFF]`;o00003?nb
V;`00ol0003oZhjhojbC_004ojbC_0So00001onQRKX3o`000003oj:>_ol0003oV8O000[oV8O000?o
0000ohn3`_n?Pl800_n?Pl86ohj3`P03o`000?n<QLKoS8G600WoS8G60_l00008ohR8c@03o`000?n0
S=GoP8cE00;oP8cE3_l00004ogb?f`04o`000?n<Xn?oS:?So`0000CoPYkU2?l0000;oi;3n003o`00
0?nTfO[o000000;o00001_nZhoX2o`0000;o[nch0_l00003okkjjP?o000000?o]_W1o`000?oonfX0
>_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z01[ooo]Z000ToookJP03o`000?oo
nf[ooo]Z03cooo]Z00?o0026o`000?l000000_l@C<P3o`0000CoF8SU00?o0000ogJJiol000001_mj
WnT00ol0003oV/Kfoi[6mP04oi[6mP?o00000_nRc_L00ol0003o/=ogok3Om`02ok3Om`;o00000ong
i_H2o`000003oko[l_l0003o]>[g00?o]>[g1_l000000oo@l>So0000om[jg002om[jg003on;cf?l0
003o000000;ohNcH00?o0000onW/cooYk<l00_l00002onOScP05o`000?o[hLOo0000on_Qaol00000
0_oYfL@01?l0003oim;2onOB`_l00004onC=`004o`000?oPa[koh<Jnon36_P?o000000?oh;^bo`00
0?oL^;D00ooL^;D00ol0003oek6comNa/`02omNa/`;o00001?o9Y;<00ol0003obZ>aolZS/@04olZS
/@03o`000?nmUJko_IF^00?o_IF^0_l00009okVD/@;o00002On]RK02o`0000WoXX:a1?nCN;43o`00
0003oiAh/Ol0003oRg>c00SoRg>c0_l00003oh9b^@?o00000omcKKd01?l0003oJG77ofUaaomYLLL2
o`0000;oIVg500?o0000oeA^d?mDK]000_l000000omKLm7o0000odEbfP03odEbfP03o`000?mJPMko
000000Go@goT00?o0000ofBDj_l000001?mFSNT>o`0000SoT/?g00Co0000ok;Fl_l0003o00001?ne
fO<2o`0000Go^Mgb00Go0000om[/gooJk=oof^cOo`000002omg`g@;o000000?oj_O:o`000?o/m/H0
0ol0000?oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]Z
oookJP07oookJP03o`000?o_Wf_okim[00;o00000oo]Z8800ol0003ojjJ3on^VP`02o`0000Goij^B
00Go0000onBXTooTZ9?oi:RCo`000005omn[W`03o`000?oNZ9kogZRN00;ogZRN0_l00004omZ[YP03
o`000?oHZ:Gof:RU00;of:RU00?o0000omFUYOoEYJD00ooEYJD3o`0000CodZN/00Co0000om2U[?o@
YJco00001Oo@bmD01?l0003oc/ODolk7e?l00003omS6a`;o00001_oE`/L00ol0003od[o7om:oa`04
om:oa`04o`000?o:]lOob[O7o`0000?od[S00ol00005olnb_P03o`000?o4Z[ooa:Zo00Coa:Zo00?o
0000olZ/^ol000000ol00005olJZ_P03o`000?nlWk_o_9nk00?o_9nk00?o0000okjP^_nnX;X03Ol0
000=ok:H_0Oo00001_nZTK`00ol0003oXHVjoj69^P03oj69^P?o00001OnRS[l00ol0003oV8O0oiR7
`008oiR7`003o`000?n?Pl;oSh?200SoSX?200?o0000ohb5a_n<QLH02?n<QLH2o`0000[oR8S=00?o
0000oh2<eOn0S=D00_n0S=D00ol0003oP8_Eoh2;e@03oh2;e@03o`000?n;VmgoRi_M00CoRi_M3?l0
0005oh^Vi`03o`000?nB`oSoT/?h00coT/?h00?o0000oj[Sn_nZhoX01OnZhoX2o`0000Co[nch00?o
0000okkjj_nnn^X00_l000001?o=mnWo0000okKi`Ol0000moookJP03o`000?oonf[ooo]Z01;ooo]Z
00?o0000oookJ_oonfX06_oonfX002Gooo]Z00?o0000oookJ_oonfX0>ooonfX2o`000005oaYHd?l0
003o0000ocA]fol000000_mMQN43o`000003oeR8iOl0003oNYoY00OoNYoY00?o0000oi[6m_nJa_H0
0ol00006oj;>m`04o`000?n`goOo0000o`0000?o]nKf0_l00003oko[lP04o`000?ndj_Oo0000o`00
00?o_>kc0oo8i>`8o`0000;ohNcH00Go0000onW/cooYk<oojNc?o`000002onOScP05o`000?o[hLOo
jn77on_Qaol000000_oYfL@01?l0003oim;2onOB`_oWd/82o`0000;oi<g000Go0000on36__oPa[ko
h<Jno`000002ombo_@;o00001?oL^;D00ol0003oek6comNa/`03omNa/`03o`000?o@Zk?o000000;o
000000?obJBco`000?o:Xk401?o:Xk400ol0003o_IF^okfE[P04okfE[P03o`000?niU;7o^IBa00Oo
^IBa00?o0000okJ?[_l000002?n]RK000ol0003o[8R_o`000009oj:2/@04oi=h/Ol0003o0000o`00
00GoU7Ra00?o0000oh]c/on;Lk<01On;Lk<2o`0000OoPW:i0_mcKKd00ol0003oJG77ofUaa`02ofUa
a`03o`000?mTKLOoI6g700;o00000_mDK]000ol0003oFg?Aoe]cd@02o`0000?oAG;J00Co0000oeb0
gOl0003o00001?m3On@00ol0003oIY?Xo`000005oeJ=j@05o`000?mnZo7oOZ_aogj[lOl000001Omd
Yo800ol0003oT/?goi;3m`09oi;3m`03o`000?nefO?o]MWc00;o]MWc0_l00005okWMlP06o`000?nm
g_3oanK]o`000?oJk=oo00000_oMl=d01Ol0003oh??Jo`000?l0003ok?K600?o00004OoonfX00ol0
003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0
003okim[onnOJ`02o`0000;okJR200Co0000on^VPoo[YX?ojjJ30_l00003onN[TP03o`000?oTZ9?o
i:RC00;oi:RC0ol00002omn[W`03o`000?oNZ9kogZRN00?ogZRN00?o0000ombVW_l000000ol00005
omRXY@03o`000?oEYJGoeJFU00?oeJFU00?o0000om>SY_oCXjH00ol000001?oBYjco0000om2U[?l0
0005om3;e@03o`000?o>amCoc/OD00;oc/OD00Go0000omS6aooHa/Oo0000omK2a`02o`0000?oeL;7
00?o0000om:oaooB_lL01?oB_lL00ol0003ob[O7olZga`02olZga`04o`000?oB^<3od[S0o`0000;o
ck:n0ol000000oo?/[ko0000olBZ_`04olBZ_`Co00002?o6Z[h00ol0003o_9nkokbO^`05okbO^`;o
00002_nkX;d00ol0003o/iRkok>H^`07o`0000Co/YNl00Co0000ok2J`?n`V/3o00003?nZTK`00ol0
003oXHVjoj69^P02o`0000SoXXjo00?o0000oiR7`?nHQl001_nHQl03o`0000_oSX?200?o0000ohb5
a_n<QLH01On<QLH2o`000003oh^:c?l0003oR8S=00[oR8S=00Co0000oh2<eOn0S=Go00001on0RmD0
0ol0003oRi_Moh^Kg@09oh^Kg@03o`000?n;Y^OoRjKW00WoRjKW00?o0000oi;3n?nB`oP01OnB`oP4
o`0000?oVLcj00?o0000oj[Sn_nZhoX00_nZhoX2o`0000Go[nch00Co0000okkjj_nnn^[o00000_o=
mnT00onmoMgo0000o`00000ooookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX06_oo
nfX002Kooo]Z0_l0000koookJP;o00000olJF=000ol0003o=6gKo`000004oef5h@go00002?nRc_L5
o`000003okOVm_l0003o000000Co_n_b0ol00002okc^l`;o00001?o8i>`00ol0003obO?]o`000004
om3bj0Go000000?ojNc?o`000?l000000_oWhlh01?l0003ojn77on_Qaoo[hLL2o`000005onWIa?l0
003oim;2onOB`_l000000_oTc<000ol0003oi<g0o`000002on36_P03o`000?oL_kgog;nm00;og;nm
1?l000000ooL^;Go0000omNa/`03omNa/`03o`000?o@Zk?od:^c00?od:^c1Ol000000oo:Xk7o0000
okfE[P06okfE[P03o`000?niU;7o^IBa00Ko^IBa00Co0000okJ?[_nfSjko00001_n]RK02o`0000;o
[8R_00?o0000oj:2/OnRP[401OnRP[43o`0000SoU7Ra00?o0000oh]c/on;Lk<00on;Lk<2o`000003
ohYg^?l0003oPW:i00KoPW:i0ol00005ofUaa`04o`000?mTKLOoKgC8ofmdb0;o000000GoE6k@o`00
0?mKLm7o0000ofMjdP03o`000004odEbf_l0003o0000ofB5gP?o00000_m3On@2o`0000;oIY?X1Ol0
0002ogj[l@03o`000?mdYo;oM:Ob00CoM:Ob00Co0000oi;3monB`oOoT/?g1Ol00003oiK6m`04o`00
0?nefO?o0000o`0000Co^Mgb0_l00003okgNl006olOVkOl0003o0000o`000?oMl=go00000_oPlmX0
0ol0003ok?K6o`000003o`00017ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0c
oookJP03o`000?oonf[ooo]Z00Sooo]Z00Go0000onnOJoo_Wf_o0000onfMK@03o`0000?ojjJ300?o
0000onRSQ?l000000ol00004onBXT`;o000000CohJFDo`000?l0003o00001?oNZ9h00ol0003og:JN
ombVWP03ombVWP;o00001?oHZ:D00ol0003oeJFUomFUY@03omFUY@03o`000?oCXjKodj>V00?odj>V
0ol00005om3;e@03o`000?o>amCoc/OD00Coc/OD0_l00004omK2a`03o`000?oE`/Oo000000Kod[o7
00?o0000olZgaoo:]lL00oo:]lL00ol0003od[S0o`000006olnb_P?o000000Coa:Zoo`000?l0003o
00000_o4Z[l2o`0000OoaZZn00?o0000okbO^onlWk/01_nlWk/00ol0003o^j2mok^P_@08ok^P_@05
o`000?ncV;_o/iRkok>H^ol000002OnbUk`01Ol0003o/9[0ok2J`?n`V/3o000000coZY6l0_l0000;
oj:>_`03o`000?nHQl3oV8O000?oV8O00ol00002oiV7_`03o`000?n>Pl;oSX?200WoSX?200?o0000
ohb5a_n<QLH01?n<QLH00ol0003oRh[<oh^:c002oh^:c003o`000?n8R<goR8S=00SoR8S=00?o0000
oh2<eOl000002?n0RmD00ol0003oRi_Moh^Kg@08oh^Kg@;o00003?n;Y^L00ol0003oT/?hoi;3n004
o`0000SoVLcj00Co0000oj[Sn_l0003o00001On_k?P00ol0003o^^_do`000002o`0000;ocOOY00?o
_OgMo`000?l00000@OoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z01[ooo]Z000X
oookJP03o`000?oonf[ooo]Z03Wooo]Z0_l00003oaYHd003o`000?ldKM_o000000CoGHGQ0_l0000:
ohbjm@03o`000?nRc_OoX/kg00Go00001?nZe_L3o`0000Co_n_b0_l00003okc^l`03o`000?o8i>co
b>C/00?ob>C/00?od_;Wo`000?l000001?o@l^P00ooGlN?o0000o`000003om[^h0Go00000oo[hLL0
1?l0003ojMW4onWIa?l00003onOB`P05o`000?oTc<3oi<c0onC<`?l000000ooPa[h00ol0003og;nm
ombo_@02ombo_@;o00000_oK^;D2o`0000?oek6c00?o0000om2[/oo@Zk<01?o@Zk<00ol0003oaJ6d
o`000002olZS/PGo00000onmUJh00ol0003o_YN_o`000006okVD/@03o`000?nfSjko]Xn^00;o]Xn^
00?o0000ojf9/?n]RK000_n]RK000ol0003o[8R_ojb8[`03ojb8[`03o`000?nRP[7o000000Co0000
0_nQP[400ol0003oU7RaoiAh/@06oiAh/@04o`000?n;Lk?oRg>coh]c/`;o00000on:MkP00ol0003o
PW:ioh9b^@04oh9b^@04ogif`OmkM<7oNgC1og]d`@;o00001?mYLLL00ol0003oKgC8ofmdb002ofmd
b003o`000?mDK]3o000000GoIg[B00?o0000odEbf_l000001?mTQMh3o`0000OoIY?X3_l00009oiK6
m`03o`000?nigO;o^Mgb00;o^Mgb0_l00005okgNl003o`000?o;k>cobnc/00;o00000_oPlmX2o`00
0004oncfa_l0003o0000o`0001?ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0b
oookJP03o`000?oonf[ooo]Z00Sooo]Z00Co0000onnOJoo_Wf_o00000oo]WFd2o`0000;ojjJ300?o
0000onRSQ?oXXh@00_oXXh@2o`0000?oi:RC0_l00003on6UU0;o00000ooNZ9h00ol0003og:JNombV
WP03ombVWP03o`000?oJY9go000000?o00001OoEYJD2o`0000Godj>V0ol00004om3;e@03o`000?o>
amCoc/OD00Goc/OD0_l00005omK2a`;o00001OoB_lL00ol0003ob[O7olZga`05olZga`03o`000?o?
/[kock:n00Gock:n1_l00002olBZ_`04o`000?o4ZKooa:Voo`0000GoaZZn00?o0000okbO^onlWk/0
1_nlWk/2o`0000Wo^j2m00?o0000ok>H^oncV;/00_ncV;/00ol0003o/YNlok:G_005ok:G_0;o0000
1On`V/000ol0003oZY6lojZA_007ojZA_0;o000000?oZiK1o`000?nRS[l02onRS[l00ol0003oV8O0
o`000002o`0000KoVHNo00?o0000ohj3`_n>Pl802?n>Pl800ol0003oS8G6ohb5aP02ohb5aP;o0000
1On;R/`00ol0003oR8S=ohR8c@09ohR8c@03o`000?n0RmGoP8_E00SoP8_E00?o0000oh^KgOn;Vmd0
1_n;Vmd01?l0003oQZCWohJTiol00006oh^Vi`So00003OnIc?X00ol0003o[nchojo/n002ojo/n0;o
00000_njjo@2o`0000;ocOOY00Co0000okgmgOl0003o0000@ooonfX00ol0003ooo]ZoookJP0@oook
JP03o`000?oonf[ooo]Z01Wooo]Z000YoookJP;o0000>OoonfX02?l0003o02jgo`000?l0003o6US@
o`000?lnN>3o00001OmMQN42o`0000SoS;[e1?l00007oj[Fm`;o00000onag?H01ol0003o_n_bo`00
0?l0003ob>O]o`000?nlk_<00_l00003olSTk0;o000000?od_;Wo`000?l000000oo@l^P01?l0003o
eo7SomOahol00003om[^h004o`000?oMjM_ogNWKomgYf`?o000000?ojn77o`000?oYfL@00_oYfL@0
1?l0003oim;2onOB`_l00004onC<`0;o000000?oh<Jno`000?oL_kd00ooL_kd01ol0003oe;NmomBg
_Ol0003ofkReo`000?oG/K<00_l000000ooG/K?o0000om2[/`04om2[/`04o`000?o5XKCoaJ6do`00
00;obZ>b00?o0000olFQ]?o5XK@00_o5XK@9o`0000;o^IBa00?o0000okJ?[_nfSjh00onfSjh00ol0
003o[HV`o`00000:o`0000OoXH:a00?o0000oiAh/OnDN;401onDN;400ol0003oRg>co`000006ohYg
^003o`000?n2L[WoPW:i00;oPW:i0_mnM/400ol0003oNgC1og]d`@02og]d`@;o000000?oJG77o`00
0?l000001_m_M<P00ol0003oIg[BofMjdP05ofMjdP;o00001_mTQMh4o`0000CoIY?X0_n5[^l00ol0
003oOJS_ogfXk`06ogfXk`04o`000?nFa_OoU/KgoiK6m`Go00000onJbOP01?l0003o^Mgbo`000?l0
0005okgNl003o`000?o0hNoo000000;o00000_o?l^T7o`000003ol_]S_oonf[ooo]Z01;ooo]Z00?o
0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z00Sooo]Z0_l0
00000oo_Wf_o0000onfMK@02onfMK@05o`000?o[Vfoo0000on^VPol000001?oXXh@01ol0003oiZ65
o`000?oTZ9?o0000on:VTol000000ooQYI@01_l0003ogj>Do`000?l0003ogZRNo`0000Cog:JN00?o
0000omZTWOoJY9d00ooJY9d2o`0000CoeJFU00?o0000omBTYOl000000ooCXjH2o`0000;od/cC0_l0
00000oo@bmGo0000olk7e006olk7e004o`000?o;`m?obl?Co`0000?oe/;700?o0000om:na_oB_/H0
0ol000000ooB_lOo0000olZga`06olZga`;o00001?o?/[h3o`0000KobkC40ol00002olBY_`03o`00
0?o6Z[koaZZn00;oaZZn00?o0000okbO^onlWk/01_nlWk/01?l0003o_J6lokfQ_?l00007ok^P_@03
o`000?ncV;_o/iRk00Co/iRk00?o0000ok:G_?nbUk`00onbUk`00ol0003o/9[0ok2J`005ok2J`003
o`000?nZTKcoZY6l00GoZY6l0_l00003oj^F`@03o`000?nRS[ooXXjo00SoXXjo1?l00009oiV7_`03
o`000?n>Pl;oSX?200CoSX?28ol00004oh2;e@03o`000?n;VmgoRi_M00;oRi_M3_l00007ohbhm003
o`000?nIc?[oVLcj00GoVLcj1?l00003oioGn`04o`000?n_k?So0000o`0000?o^^_d00Co0000olgg
jOo=mnWo00000_nmoMd2o`0004Cooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0I
oookJP00:ooonfX00ol0003ooo]ZoookJP0goookJP;o000000?o6US@o`000?l000000_lnN>08o`00
00;oS;[e1Ol00003oiC3mP03o`000?nZe_OoZ]Kg00;oZ]Kg0ol00005ok7LmPCo000000?ob>O]o`00
0?l000001?o8i>`00ol0003od_;Wom;bi`02o`0000?od?;X00Go0000omOahooGlN?oeo7So`000002
om[^h004o`000?oMjM_ogNWKomgYf`;o00000_oNi=P3o`000006onWIa?l0003oim;1o`000?oWd/;o
00000ooTc<000ol0003ohLJnon76_P02o`0000?og;nm00?o0000omBg_OoD]kd00_oD]kd00ol0003o
ek6comNa/`02omNa/`;o00001?o@Zk<00ol0003oaJ6dolFQ]002olFQ]0;o00001oo5XK@01Ol0003o
^YFaokZE/OnjUK7o000000;o^IBa2_l000000on]RK3o0000oj^;]006oj^;]003o`000?nQP[7oXH:a
00OoXH:a00?o0000oiAh/OnDN;400_nDN;4:o`0000?oRWNh00Co0000oh9b^On2L[WoPW:i1?mnM/46
og]d`@Co00001Om_M<P4o`0000CoIg[B00?o0000ofn;g_m_Rmh00_l00003ofB5gP04o`000?mdV^So
M9[XogBJj0Go000000?oQJk_o`000?mmZ>l00ommZ>l8o`0000WoV/Wh00?o0000okgNl?nmg_000_nm
g_02o`0000;o`>7_0_l00003olobj@04o`000?o@kNSod>gXom3]j0Go00005OoonfX00ol0003ooo]Z
oookJP0KoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX02?oonfX01?l0003ok8e<
o`000?l00003onfMK@03o`000?o[Vfooji]_00;o00001?oXXh@00ol0003oiZ65onJQQ@02o`0000;o
hZJC00Co0000on6UU?oQYICo00000ooOXi@2o`0000Cog:JN00?o0000omZTWOoJY9d00ooJY9d00ol0
003of::Mo`000002o`000004omFUYOl0003oe:BUo`0000?odj>V00?o0000om;<dooBc=<00ooBc=<2
o`0000Goc/OD0_l00004ol_3d`03o`000?oF`/Oo000000Kod[k60_l00006olZga`03o`000?o6]<So
a[C800Co000000?ock:no`000?o;]<@01_o;]<@00ol0003o`JS1ol6X`@03o`0000?oaZZn00?o0000
okbO^onlWk/01_nlWk/01Ol0003o_J6lokfQ_?nmXKco000000Ko^j2m00?o0000ok>H^oncV;/01Onc
V;/01?l0003o/YNlok:G_?nbUk`2o`0000So/9[000?o0000ojZA_?nZTK`00onZTK`2o`0000KoZiK1
00?o0000oj:>_onRS[l00onRS[l4o`0000;oXHfo00?o0000oiV7_onIQkl01_nIQkl9o`0000GoTX[7
0_l0000:oi2<b`03o`000?n7SM;oQhgB00GoQhgB00Co0000ohN<dOn7S=7o00001_n=V=T9o`0000?o
RIoR00?o0000ohVNhOn9W^400_n9W^400ol0003oS;Sdohbhm00;ohbhm003o`000?nIc?[oVLcj00Co
00002?nOeo/00ol0003o^^_dok[[m002ok[[m004o`000?o=mnWocOOYo`0000;o_OgM0_l00016oook
JP03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX06OoonfX002cooo]Z0_l0000goookJP?o
000000Ko6US@o`000?l0003o0000ocihh?l00003ofFAi`03o`000?mhYNooN:G_00;o00002OnD`oH0
1?l0003oZ]Kgo`000?l00006ok7LmP;o00000onhh?@3o`0000?ob>C/0_l00002om;bi`03o`000?oH
jn7o000000;od?;X00Ko0000omOahooGlN?oeo7So`000?oJhM/2o`0000?ogNWK00?o0000omoLd_oO
g=800_l00003omoMe005o`000?oWd/7oim;1onOB`Ol000000ooTc<001_l0003ohLJnon76__oQa[ko
0000omg1_@;o000000?og;nmo`000?oD]kd00ooD]kd00ol0003oek6comNa/`02omNa/`06o`000?oB
/;Oo0000o`000?o@Zk?o00001Oo5XK@00ol0003oaJ6dolFQ]005olFQ]003o`000?njUK7o^YFa00;o
^YFa00Co0000okVD/OniU;7o00001ongUK@00ol0003o[HV`o`000008oj^;]003o`000?nQP[7oXH:a
00KoXH:a2Ol000000onFOKKoRWNhohYg^004ohYg^0Go000000?oPW:io`000?mnM/400omnM/400ol0
003oNgC1og]d`@02og]d`@04o`000?mdNL[oM7W:ogAibP;o00000om_M<P00ol0003oFfg;og61d`02
og61d`06o`000?mWN];oIg[Bo`000?m=LMKo00001Om_Rmh3o`0000OoM9[X1_l00005ohJ]k`03o`00
0?nJbOSoV/Wh00CoV/Wh0ol00003oio>n004o`000?nmg_3o0000o`0000Co`>7_00?o0000olobjOo?
l^T00_l00003om3]j005omS_h_l0003o0000omcncOl000005ooonfX00ol0003ooo]ZoookJP0Joook
JP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX02OoonfX01?l0003ok8e<o`000?l00002
onfMK@04o`000?o[Vfooji]_on^KK`;o00000ooXXh@01?l0003oiZ65onJQQOoVXHD4o`000003on6U
U?l0003ogj>D00?ogj>D00?o0000omfQU?l000000_l000000ooLYYko0000omZTW@04omZTW@03o`00
0?oHXYgof::M00;of::M0_l000001OoDY:Go0000om>SY_oCXjKo000000Kod/cC00?o0000om38d_l0
00000oo>am@00ol0003obl?Col_3d`05ol_3d`03o`000?oB_/Kod[k600Cod[k600?o0000olnja_o?
^/H00_l00003olZga`Co000000Goa[C8o`000?o?/[kock:no`000007ol^da003o`000?o1Z<7o`JS1
00Co`JS11ol00004okbO^`03o`000?nmXKco_J6l00?o_J6l00?o0000ok^P_OnkX;d00_nkX;d00ol0
003o/iRkok>H^`06ok>H^`04o`000?nbUkco/YNlo`0000[o/9[000Co0000ojZA_?nZTKcoZY6l0_l0
0008oj^F`@03o`000?nRS[oo000000?o00001onQSKl00ol0003oVHNooiV7_`05o`0000?oVXg500?o
0000oi::aonBR/L01OnBR/L3o`000003oi::aol0003oT8c;00[oT8c;00?o0000ohN=d_n7SM800_n7
SM82o`0000CoQhcA00?o0000ohfHfOn=V=T02?n=V=T00ol0003oRIoRohVOhP03ohVOhP03o`000?n9
W^7oRIkQ00CoRIkQ00?o0000ohbhm?n<^?@02on<^?@2o`0000SoWmOk0ol00004ojCRo005o`000?nn
l_;o0000olggjOl000000_nmoMd2o`0004Sooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Z
oookJP0IoookJP00;_oonfX00ol0003ooo]ZoookJP0eoookJP04o`000?l0;[Oo0000o`0000;o@87V
0ol00002ofFAi`05o`000?mhYNooN:G_ogRUkol000002?nD`oH4o`0000Co/Mcf0ol00003okSPm0;o
00000_noiO42o`000003olSTk?l0003od_;W00;od_;W00Co0000omS[hOoHjn7of>_Q0_l00003omOa
h`04o`000?oJhM_of^7Ko`0000?ogNWK00Go0000omoLd_oOg=;ogmcBo`000003omoMe009o`000?oN
e]3o0000onOB`Ol0003oi<c0o`000?oTc<3o000000?ohLJn00?o0000omg1_OoM`Kd00_oM`Kd2o`00
00?oe;Nm00?o0000olnb_?l000000_oG/K<00ol0003od[2gom:`]`02om:`]`Co00000oo5XK@00ol0
003oaJ6dolFQ]004olFQ]003o`000?njUK7o^YFa00Co^YFa0_l00009okNE]003o`000?n[RkCoZh^d
00SoZh^d00?o0000oj62/OnQP[400_nQP[43o`000003oj:6]_l0003oUWff00?o00001OnFOKH8ohYg
^0;o00000_n7NKd3o`000003ogif`Ol0003oNgC100;oNgC100?o0000ogAib_mdNLX00_mdNLX00ol0
003oKGK:o`000002ofmdb003o`000?mKKL_oFfg;00GoLH7C1?l00005ofn;gP03o`000?mLQN7o0000
00Go00000_mdV^P00ol0003oQZg_ohJ]k`08ohJ]k`03o`000?nJbOSoV/Wh00?o00001onOc_P00ol0
003o`>7_ol3Qk`02ol3Qk`05o`000?o4i>ko0000olobjOl000001?o@kNP01?oHkn;o0000o`000?oL
o/d2o`0001Sooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z00Wooo]Z00Oo0000onb=C?l0003ojXa@o`000?o]WFgo000000?oji]_00Go0000onRILOl0
003oj:>4o`000004onJQQ@03o`000?oTWhKoi9n600?o00001?oOXi@00ol0003ogJ6DomfQU002omfQ
U0;o00001OoJY9d00ol0003of::MomRRW@02omRRW@03o`000?oEWiko000000?o00001_oBc=<01ol0
003od<SBom38d_o@b=;o0000olk7e?l000001oo;`m<2o`0000God[k600?o0000olnja_o?^/H00oo?
^/H4o`0000Coa[C800?o0000olnb__l000001oo;]<@00ol0003o`JS1ol6X`@06ol6X`@03o`000?o3
YK_o`jFk00?o`jFk0ol000000onlWk_o0000o`000002o`0000;o_J6l00Go0000ok^P_OnkX;go^j2m
o`00000:ok>H^`;o00003?n`V/000ol0003oZY6lo`000004oj^F`@So00002_nQSKl4o`0000WoVXg5
00?o0000oi::aonBR/L00_nBR/L2o`0000GoTX[700?o0000oi2<bon@S</02?n@S</00ol0003oQhgB
ohN=dP02o`0000KoQhcA00?o0000ohfHfOn=V=T02On=V=T01Ol0003oRIoRohVOh_n9Wn;o000000So
RIkQ00Co0000ohbhm?n<^?CoS;Sd1_l00003oi?2m`03o`000?nOeo_oWmOk00CoWmOk0ol00005ojCR
o003o`000?nWk?WoYnci00Co000000?o_OgMo`000?l00000B_oonfX00ol0003ooo]ZoookJP0=oook
JP03o`000?oonf[ooo]Z01Wooo]Z000_oookJP03o`000?oonf[ooo]Z03Cooo]Z0ol000000olJF=3o
0000od21iP03od21iP?o00001?mhYNl00ol0003oU<?foiC3mP05o`0000CoWL[g00Co0000ok7Lm_l0
003o00001?nhh?@2o`0000Co_nGa1Ol000000ooBl^Oo0000omS[h@02omS[h@;o00000ooGlN<00ol0
003of^7Kom[Qf`02o`0000;ogNWK00Wo0000omoLd_oOg=;ogmcBo`000?oOeloo0000omoMe?l00000
0ooNe]02o`0000;oi<c00_l00002on76_P03o`000?oM`KgogL6m00?ogL6m00Go0000omVl_?l0003o
e;Nmo`000002olnb_003o`000?oG/K?o000000God[2g00Co0000olfY]Oo=ZKGocJVe1Ol00004olFQ
]003o`000?njUK7o^YFa00Go^YFa00?o0000okNE]?ngUK@01ongUK@2o`0000[oZh^d00?o0000oj62
/Ol000000_l00003oj:6]P?o00002?nFOKH6ohYg^0;o000000?oRgRhohMi_On7NKd01?n7NKd2o`00
00;oNgC100?o0000ogAib_mdNLX00omdNLX01?l0003oKGK:ofefb_m]M/X2o`0000;oFfg;00?o0000
og61domaPM<00_maPM<00ol0003oHGWDof5ie004o`000005ofn;g_l0003oG8GQoeb5hOl000001Omm
W^P4o`0000GoQZg_1ol00006oio>n0?o00000onTdoP00ol0003o`>7_o`000002olCTkP;o00001?o@
kNP2omS_hP04o`000?oLo/go0000o`0001Wooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Z
oookJP0aoookJP03o`000?oonf[ooo]Z00[ooo]Z0_l000000oo/SDco0000onZ<D002o`0000?oji]_
00?o0000onRILOoXVG400_l00004onJQQ@05o`000?oTWhKoi9n6o`000?oSWHH00_l00003omnSU003
o`000?oMXICogJ6D00;ogJ6D00Co0000om^NU?l0003o00000_oJY9d00ol0003of::MomRRW@03omRR
W@04o`000?oEWiko0000o`0000?oa<cQ00Go0000om;<dooBc=?od/cCo`000005om38dP;o00001_o;
`m<01?l0003ob<3ColS0dol00003om:naP04o`000?o?^/Kock[6olnjaP?o000000Cock[6o`000?l0
003o00001Oo6]<P00ol0003obkC4ol^da005ol^da003o`000?o1Z<7o`JS100Ko`JS10_l00007ol>U
^`03o`000?noZ/Co_j[400?o_j[43?l00005ok>H^`03o`000?n`V/3o/9[000_o/9[01ol00006ojZE
`@03o`000?nQSKooXHfo00KoXHfo0ol000000onSTlCo0000oiZ=a@0:oiZ=a@05o`000?nBR/OoTX[7
oi::aol000001onBR/L00ol0003oT8c;oi2<b`08oi2<b`03o`000?n7SM;o000000WoQhcA00?o0000
ohfHfOn=V=T02On=V=T00ol0003oRIoRo`000004ohVNh@Wo00002_nC`_L00ol0003oWmOkoioGn`03
o`0000GoY>;l0_l00003ojO/n@;o00000_nan^L2o`000003oi3KR_oonf[ooo]Z04[ooo]Z00?o0000
oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0IoookJP00<?oonfX2o`0003Cooo]Z1_l00003od21
iP03o`000?m_W>co000000Oo00002?nMb_L4o`0000Co^>3d00?o0000okoUlOnoiO400_noiO43o`00
00Co_NGb0ol000001?oHjn7o0000om_Ug?l00002omOah`04o`000?oJhM_of^7Ko`0000;oh>?F0_l0
0003omoLdP05o`000?oOeloogmO?omoGcol000000ooNe]002_l0003oflo=om_?cOl0003oi<c0o`00
0?oQa[ko0000on76__l00004omg1_@04o`000?oI_;cofKblomVl_0;o00000oo?/[`00ol0003od[2g
om:`]`03om:`]`03o`000?o=ZKGocJVe00CocJVe00?o0000ol:O]_l000002?l00003okZE/@;o0000
2?ngUK@00ol0003o]92ao`00000:oj^;]0;o000000?oXXJfo`000?l000000ol00002oj:6]P03o`00
0?nFOKKoUWff00KoUWff1?n:MkP2o`0000CoRgRh1on7NKd4o`0000GoM7W:00?o0000ofefb_l00000
0_mgNlX3o`0000?oLH7C00?o0000of5ie?mQNM@00_mQNM@3ogVAgPCo000000?oG8GQo`000?mmW^P0
1_mmW^P6o`0000OoQ;Of00?o0000oio>n?nOc_P00ol00007ojCCn005o`000?o4i>koa>C^olCTk_l0
00000oo@kNP3omS_hP03omGjh?l0003o000000;o00006_oonfX00ol0003ooo]ZoookJP0HoookJP03
o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX02_oonfX01?l0003oeE`4o`000?l00002onZ<
D0;o00000oo[Vfl00ol0003oj9UaonRIL@02o`0000?oiZ6500?o0000onBOQ_l000000_oSWHH01_l0
003oh9^6o`000?l0003ogj>Do`0000CogJ6D00Co0000om^NU?oKWYCofijD0ol00005omRRW@;o0000
1_o4c>400ol0003od/cCo`000005om38dP03o`000?o>aM7oc/GA00;o00000oo;`m<00ol0003ob<3C
olS0d`02olS0d`03o`000?oB_/Ko000000Co00000oo?^/H01?l0003oc;g;olbmboo<_L/3o`000004
olJdb?l0003oa[?7o`0000GobkC400?o0000ol6X`Oo1Z<401_o1Z<401?l0003o_ZS3okjX`ol00005
ol>U^`03o`000?noZ/Co_j[400Oo_j[40_l00007okRK^Pgo00001?n`V/001?l0003o[ig5ojnMaOl0
000<ojZE`@03o`000?nQSKooXHfo00;oXHfo0ol00005oj>Ca003o`000?nJSLGoVXg500SoVXg50_l0
000:oi::a`03o`000?n@S<_oT8c;00WoT8c;00?o0000ohN<dOn7S=402?n7S=400ol0003oSISIohfH
f@04ohfHf@co00001_n</Nl00ol0003oTl;goi?2m`0;oi?2m`;o00001_nTh_`2o`0000CoYnci00?o
0000ok7jionan^L00ol000000on@fh[ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX06OoonfX003;ooo]Z00?o0000oookJ_oonfX0<_oonfX01Ol0003o03>jo`000?l0
003oBH_[00?o000000?o@87Vo`000?l000001omdXNh00ol0003oWL[goig:m`05o`0000CoYM3g00Co
0000okSPm?l0003o00001?noiO400ol0003oa^;/o`000002okgUlP;o00001?o4i^l3o`000003om_U
g?l0003o000000;of^7K00Go0000on3Se_oPhmKoh>?Fo`000003omoLdP03o`000?oOeloogmO?00;o
gmO?0_l000000ooNe]3o0000om_?c@03om_?c@;o00000_oQa[h2o`0000?ogL6m00?o0000omVl_?oI
_;`00_oI_;`00ol0003oeKNlo`000003o`0000Cod[2g00?o0000olfY]Oo=ZKD01?o=ZKD01?l0003o
`Ynfol:O]_l00003olFQ]003o`000?o1X;Oo`J2g00;o`J2g1_l00006okNE]005o`000?ndT;7o]92a
okB@/Ol000001?n[Rk@8o`0000OoXXJf00?o0000oiIm]_nFOKH01onFOKH00on:MkSo0000o`000006
oh]h^0KoQgVm00?o0000ohAma?n1O<@00_n1O<@4o`000003ogAib_l0003o000000KoMg_:0ol00006
of5ie0?oNI7N00?o0000ofb9g_m/RMh00ol00006ogfNj003o`000?m/W>go000000_oQ;Of0_l00006
ojCCn0?o00000_nYf_P01?l0003oa>C^o`000?l00002om3]j0?of>oR00GoeO[Po`000?oLo/gofok2
o`00000LoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oEG0Co000000?o000000?oj8]Do`000?l000000_l00002onRIL@03o`00
0?oVUg?o000000?o000000Goi9n6o`000?oSWHKohif6o`000003on2KQP;o00001?oMXI@00ol0003o
fijDom^NU003om^NU0;o00000ooHXYd2o`0000Ooa<cQ0_l00005om38dP03o`000?o>aM7oc/GA00?o
c/GA00?o0000ol_3dol000001?o8`=<4o`0000Kock[600?o0000olbmboo<_L/01Oo<_L/5o`0000?o
bkC400?o0000ol6X`Oo1Z<401_o1Z<401Ol0003o_ZS3okjX`onnZ<?o000000Co`jFk00?o0000oknZ
a?noZ/@01onoZ/@2o`0000[o^9^j00Go0000okJSaOnfXlGo]Z?5o`000008ok2J`0;o00001?n_WLD0
0ol0003oZYG1ojZE`@09ojZE`@03o`000?nQSKooXHfo00;o00002?nSTl@00ol0003oVXg5oiZ=a@05
oiZ=a@?o000000?oVhg4o`000?nBR/L02_nBR/L00ol0003oT8c;oi2<b`02oi2<baSo00001?nCX=d0
0ol0003oRicNo`00000<ohbak`03o`000?nC`_OoTl;g00CoTl;g1?l00003oiW=nP03o`000?nTh_co
Y>;l00;oY>;l0_l00004ojO/n@08o`000?ndkOOo0000ok7jiol0003oa?_Xo`000?n@fhY?oookJP03
o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX06OoonfX003?ooo]Z0_l0000boookJP;o0000
00?o03>jo`000?m9Rn/00om9Rn/3o`0000CoM:7^1_l00009ojG@m`?o00000onoiO42o`0000;oa^;/
0ol00004olCVk`03o`000?o:f^Gob][U00;ob][U0ol000000ooJhM_o0000on3SeP03on3SeP;o0000
00?ogmcBo`000?oOell00ooOell01?l0003og];<omkBc?l00005om_?c@09o`000?oHbL[o0000on76
__l0003ogL6mo`000?oM`Kgo000000CofKbl00?o0000omFg_?oE]k`00ooE]k`4o`000003om:`]ol0
003ocJVe00CocJVe00?o0000ol:O]_o2WkH00_o2WkH00ol0003oaJ6do`000007ol6P]`03o`000?ng
UKCo]iFd013o00000_n[Rk@2o`000003ojf@]ol0003oXXJf00SoXXJf00?o0000oiIm]_nFOKH01_nF
OKH2o`0000SoRgRh1On7NKd4ohAma0KoPGc40_l00007ogMkbP04o`000?m`P]Go0000ogV7e@?o0000
0_mQNM@01?l0003oNI7NogVAg_l00005ofb9gP[o00000on4]oH5o`0000;oR[cg00?o0000ojCCn?nT
doP00onTdoP2o`0000KoZM[h00Co0000olSWkOl0003od>gX0_oHkn801Ol0003oeO[PomGjh?l0003o
fok200;o00007OoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX02ooonfX00ol0003oeE`4omEL1004o`0000?oj8]D0_l000000ooXVG7o0000onJGL`03
onJGL`05o`000?oTWhKo0000on>MQ_l000001OoPVhH2o`0000?ogJ6D00?o0000om^NU?oKWY@00ooK
WY@00ol0003ofIbDo`000003o`0000Koa<cQ0_l00002ol;9g`05o`000?o@b=;od<SBom38d_l00000
1oo>aM42o`000008olS0dol0003o0000o`000?o8`=?o0000olFmdol00005olnjaP03o`000?o<_L_o
c;g;00Goc;g;00?o0000olBbbOo4//T00_o4//T2o`000003ol^da?l0003o`JS100Oo`JS100?o0000
okjX`onnZ<<00onnZ<<01?l0003o`jFkol>U^ol00009oknZa003o`000?ngXL;o000000So^9^j0_l0
0005okJSa@03o`000?n`V/3o/9[000?o/9[00_l00006ojnMa@03o`000?nZUL7oZYG100WoZYG10_l0
000;oj>Ca003o`000?nJSLGoVXg500;oVXg50ol00005oi^=a003o`000?nBR/OoTX[700?oTX[72_l0
0003oi2Ad@05o`000?n?TM3oSi7@ohnAd?l000002_n;Vmh00ol0003oTj3Moi>Pg@06oi>Pg@05o`00
0?n;W=koRicNoh^Lg_l000003?n</Nl00ol0003oTl;goi?2m`03o`0000SoVLgj00Co0000ojCRo?l0
003o00001?nWk?T2o`000003okC]mol0003o000000?o000000?oT=^:oookJ_oonfX0CooonfX00ol0
003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01Sooo]Z000eoookJP03o`000?oonf[ooo]Z033o
oo]Z0_l000000ol0<k[o0000odV;j`04odV;j`Go00001On6^_L00ol0003oYM3gojG@m`04ojG@m`?o
00000on/e?D00ol0003o_nGao`000004olKRk003o`000?o4i^ooa>K_00;oa>K_0_l00004ol[Ji@;o
d^CT00Co0000om3Si_l0003o00000ooPhmH01?l0003oh=cAon3LdOl00004omoGc`04o`000?oNd/co
g];<omkBc0;o00000ooKcld01Ol0003of<W:omS9b_oHbL[o000000?ogL6m0_l00003omVl_003o`00
0?oE]kcoeKNl00?oeKNl00?o0000ol^^_Ol000000_oB/;L2o`0000GocJVe00?o0000ol:O]_o2WkH0
0_o2WkH00ol0003oaJ6do`000006ol6P]`05o`000?ngUKCo]iFdokNE]?l000001?ngUK@00ol0003o
]9JhokBF^003okBF^003o`000?n[RkCoZh^d00;oZh^d0_l00004ojf@]`03o`000?nRQ[KoXXJf00Oo
XXJf00?o0000oiIm]_nFOKH00_nFOKH3o`000003oiMn]_l0003oRgRh00SoRgRh0_n7NKd00ol0003o
Q7g4ohAma003ohAma0GoPGc400Co0000ogMfaOmgM/Go00001omgNlX00ol0003oNHOEogV7e@03ogV7
e@?o000000?oNI7No`000?m/RMh01Om/RMh00ol0003oQJ?WohFSi`03ohFSi`03o`000?mhWn_oN9o[
00Co00002?n:_?L00ol0003oY=?ho`000002o`0000GoZM[h0_l00002ojoQn0;o00000_oHkn800ol0
003oeO[PomGjh004o`0001oooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0`oook
JP03o`000?oonf[ooo]Z00_ooo]Z00Go0000omEL1?oEG0Co0000omIN3003o`0000;oj8]D00Go0000
onJ:FOl0003oj9Uao`000003onJGL`Go00001OoPVhH00ol0003ogYV7o`000003o`0000GofijD00?o
0000omVLU?l000000oo6cMl00ol0003oa<cQolC<h@02olC<h@03o`000?o2bMoo`/WO00?o`/WO00?o
0000om38d_l000001_o>aM47o`000003olS0dol0003oaKgC00;oaKgC00Go0000olnja_o?^/Kock[6
o`000007olbmb`03o`000?o4//Woa;;900Coa;;91?l00007ol6X`@Ko_ZS300?o0000ol>U^ol00000
2OnoZ/@01Ol0003o]j72okNQ`_ngXL;o000000Ko^9^j00?o0000okJSaOnfXlD01OnfXlD00ol0003o
/9[0ok2J`002ok2J`003o`000?n_WLGo[ig500Ko[ig500?o0000ojZE`OnZUL401onZUL42o`000003
oj^Ja_l0003oXi?400_oXi?400Co0000oiZ=aOl0003o00001OnKSL@9o`0000GoUI7=00?o0000oi2A
dOn@TM400on@TM42o`0000GoSi7@00?o0000oh^Kg_n;Vmh02?n;Vmh00ol0003oTj3Moi>Pg@04oi>P
g@03o`000?n;W=koRicN00?oRicN00?o0000ohbakon</Nl01on</Nl2o`000003ohbakol0003o0000
00coVLgj00?o0000ojO/nOnWk?T00_nWk?T2o`0000;o]>gg0_l000001?o4nnSo0000o`000?n@fhYC
oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX06?oonfX003Kooo]Z0_l0000aoook
JPKo00000_m9Rn/00ol0003oGI[`o`000008ohJjm`03o`000?nUd?OoYM3g00?o00001_n/e?D3o`00
00?oa^;/0_l00003olCVk`03o`000?o:f^Gob][U00;ob][U00?o0000om;Ti?oBi>@00_oBi>@2o`00
0004oloQiOl0003oh>?Fo`0000?oh=cA00Go0000omoGcooOeloogmO?o`000003omkBc006o`000?oL
c/_og<k;o`000?oKclgo00001?oHbLX01_l0003ogL6momg1_OoM`Kgo0000omVl_0;o000000?ofKbl
o`000?oE]k`00ooE]k`02?l0003objjmol^^_Oo;[[go0000om:`]ol0003ocJVe0ol000000oo=ZKGo
0000ol:O]P05ol:O]P03o`000?o1X;Oo`J2g00Co`J2g00?o0000okNE]?ngUK@00_ngUK@01Ol0003o
]iFdokNE]?ngUKCo000000Ko]9Jh00Go0000oj^;]?n[RkCoZh^do`000006ojf@]`03o`000?nRQ[Ko
XXJf00OoXXJf00?o0000oiIm]_l000004?l000000on7NKgo0000o`000005ohAma005o`000?n1O<Co
PGc4oh5la?l000000omgM/D3ogn3c@03o`000?mgNl[oMg_:00;oMg_:0_l00007ogV7e@;o000000?o
K8WNo`000?l000000_l00002ofb9gP05o`000?n5XnOoQJ?WohFSiol000001OmhWn/00ol0003oR[cg
ohZlm`08ohZlm`03o`000?nYf_SoZM[h00?oZM[h0_l00006ojoQn003o`000?oHkn;o000000;oeO[P
0_l000000ooKo/;o0000o`00000OoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
<?oonfX00ol0003ooo]ZoookJP0<oookJP;o000000CoeE`4o`000?oFGPcoeUh<1?l00002onJ:F@;o
00000_oVUg<2o`0000?ohi9b0_l00004on2KQP03o`000?oNVHOogYV700;ogYV70_l00003om^NU003
o`000?oIW9Co000000Goa/gO00Co0000olC<hOl0003o00001_o2bMl2o`0000Goc/GA0ol00006olc2
d@;o00001?o5_M<00ol0003ock[6o`000007olbmb`03o`000?o4//Woa;;900Goa;;90_l00002olR`
`P?o00000oo1Z<48okjX``03o`000?noZ/Co_j[400Oo_j[400?o0000okNQ`_ngXL800_ngXL800ol0
003o^9^jokRK^P03okRK^P03o`000?nfXlGo]Z?500Ko]Z?500?o0000ok2J`?n`V/000_l0000:ojnM
a@03o`000?nZUL7oZYG100?oZYG10ol00003oj^JaP03o`000?nSTlCoXi?400OoXi?41?l00003oi^=
a0Go00000onMU<X00ol0003oUI7=oiFAc@09oiFAc@03o`000?n@TM7oT97A00;o00001on?TM000ol0
003oRi_Noh^KgP09oh^KgP03o`000?nCX=goTj3M00;oTj3M00?o0000oh^Lg_n;W=h01?n;W=h01?l0
003oS;7_ohbakon</Nl6o`0000?oT[cc00?o0000oiW=n_nIcOX01OnIcOX4o`0000CoW]Wl00?o0000
ojO/nOl000000ondkOL01_l0003oa?_Xo`000?nYn=;o0000oi3KRUGooo]Z00?o0000oookJ_oonfX0
2OoonfX00ol0003ooo]ZoookJP0HoookJP00>?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?l0
>Kko000000;o000000?oD8WYo`000?l000000_l000000omMV_3o0000ohJjm`03ohJjm`Ko00001_n/
e?D3o`0000?o/]Sd00?o0000olKRk?l000000_o;g^L00ol0003oa>K_o`000003ol[Ji@;o00001?oB
i>@2o`0000?ocn7U0ol000001_oPg=7o0000omoGc_l0003ogmO?o`0000?og];<00?o0000omc>booL
c//00_oLc//2o`0000?of<W:00Go0000omG3b?l0003ogL6mo`000004omVl_0;o00000ooE]k`00ol0
003objjmol^^_@03ol^^_@03o`000?o=ZKGocJVe00?ocJVe1?l00003ol:O]P;o00001Oo1X;L00ol0
003o]iFdokNE]004okNE]003o`000?ngUKCo000000So]9Jh0ol00007ojf@]`03o`000?nRQ[KoXXJf
00GoXXJf1ol00004oiR3^`03o`000?n>O[goSWjm00KoSWjm0_l00002oh]o`@Go000000CoQ7g4oh5l
a?n1O<Co00001OmgM/D5ogn3c@Ko00001_miQmD00ol0003oOiKOognFg`03ognFga;o00001_nA`_P0
0ol0003oZM[ho`000002o`0000Go[n7h0_l000001ondj?Oo0000o`000?l0003oeO[Po`000?oGoMX0
0ol0000QoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]Z
oookJP0=oookJP?o00000_oFGP`00ol0003oeelDo`000007o`000003onFDL?l0003ohi9b00;ohi9b
00Ko0000on2@M?l0003o0000on2KQ_l00005omjIQ`03o`000?oLUhOo000000Co00001oo6cMl2o`00
00Ko`/WO00Co0000ol37goo0amoo`<OO1Ol00006olc2d@04o`000?o8_]7ob;kAolRnd@;o00000_o5
_M<2o`0000Ooc;g;00?o0000olBbbOo4//T01Oo4//T00ol0003o`;7;o`000005olR``PKo00001?nn
Z<<2o`0000So_j[41ongXL800ol0003o^9^jokRK^P02o`0000[o]Z?50_l0000<ojnMa@04o`000?nZ
UL7oZYG1ojZE`@;o00001on[V/H00ol0003oXi?4oj>Ca006o`0000?oXY;41?l00009oifDbP03o`00
0?nETLgoUI7=00SoUI7=00?o0000oi2AdOl000002_n?TM000ol0003oRi_Noh^KgP08oh^KgP05o`00
0?nCX=goTj3Moi>PgOl000000on;W=h8o`0000[oT[cc00?o0000oiW=n_nIcOX01?l00009oikIo00:
o`000?ndkOOo]>ggokC]mol0003oa?_Xo`000?nYn=;o0000oi3KRUOooo]Z00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP0HoookJP00>OoonfX00ol0003ooo]ZoookJP0^oookJPGo00000om@
RNT7o`0000KoS/7h00?o0000ojcDmOn/e?D00ol00006ok;Hm0Co000000?obmkWo`000?l000000oo:
f^D00ol0003od^CTom;Ti003om;Ti005o`000?oDgn3o0000oloQiOl000001?oBgN42o`0000;ogmO>
00Go0000omkBc?oNd/cog];<o`000004omc>b`06o`000?oJbLWof/W9o`000?oHbL[o00000ooE`lP0
0ol0003ofKblomVl_003omVl_005o`000?oE]kco0000omFg_?l000001_o;[[d00ol0003ocJVeolfY
]@03olfY]@04o`000?o9Zk_obJ^kolV[^`So000000?o`J2go`000?ngUK@01_ngUK@2o`0000Wo]9Jh
00?o0000ojf@]on]T;L02?n]T;L00ol0003oXXJfo`000005o`000003oj>:^_l0003oV8>k00SoV8>k
00?o0000ohin_On>O[d00on>O[d2o`000003ohim_On;Ol7oRgo100KoRgo11Ol00004ogMfa@03o`00
0?moPlgoOh?=00;oOh?=00Co0000og=mc_mcOLkoLgg>0on1S]L01?l0003oNHOEogV7eOmiQmD2o`00
00SoOiKO00Co0000ohFTjOn5Y>Wo00001_n4Y>T00ol0003oTL;hoi72n009oi72n003o`000?n_hOSo
[n7h00?o[n7h0_l00003okCXm`03o`000?o5m^goaOK]00;o000000CoeogJo`000?o5o<7o00008ooo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX03_oo
nfX02?l0003oXQT0o`000?l0003oeUh<o`000?oGGaCo00000ooSPTl00ol0003ohX5Bon:1DP02o`00
00?ohi9b00Co0000on2@M?oPT7Coh91d0_l00005omjIQ`03o`000?oLUhOog9N700;o00000onabnd0
1Ol0003oa/gOolK=goo6cMoo000000?oaL_N00Co0000ol;9goo2bMoo`/WO0_l000002?o0amoo0000
o`000?l0003o`<OOo`000?o>aM7o00001_o<`]400ol0003ob;kAolRnd@05olRnd@?o00001_o<_L/0
0ol0003oa;;9olBbb@05olBbb@05o`000?o0/L_o`;7;ol2abol000001?o8/<800ol0003o`j_2ol>[
`P03ol>[`POo00001_noZ/@8okNQ`P03o`000?nhVk[o000000co]Z?500?o0000ojnMaOn_WLD02on_
WLD01?l0003oZYG1ojZE`Ol00006oj^JaPKo00001_nRT/@3o`000003oj:Hb_l0003oWIC:00[oWIC:
00?o0000oiFAcOnETLd02?nETLd2o`0000_oSi7@00?o0000oh^Kg_n;Vmh01?n;Vmh<o`0000GoTZGS
00?o0000oi:llonB_?<02onB_?<2o`0000WoW]Wl0ol00003oj3Vo0Co000000?oZOSBo`000?l00000
F?oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01Sooo]Z000joookJP;o0000;_oo
nfX00ol0003o03Vno`000002oaMZg@04o`000?m@RNWo0000o`0000;oIZ7b00?o0000ohk1n?n>`OP0
1_n>`OP4o`0000Oo/]Sd0_l00003okOIl@Co00000_o:f^D00ol0003od^CTom;Ti003om;Ti003o`00
0?oDgn3oe=oP00;o00000ooBgN401_l0003odmWMom?IgOoCfMgo0000omoGcP;o000000?og];<o`00
0?oLc//00ooLc//00ol0003of/W9om[9b@02om[9b@;o00000ooE`lP2o`0000?ofKbl00Co0000omFg
_?oE]kcoeKNl0_l00005ol^^_@03o`000?o7Zkgo000000?ocJVe00?o0000olV[^oo9Zk/01?o9Zk/0
1?l0003o_YjhokjN^?l00002ol6P]`Go00001?ngUK@00ol0003o]9JhokBF^008okBF^003o`000?n]
T;Oo[I2g00?o[I2g1ol00002oj65]P;o00001?nSR[X00ol0003oV8>koiR3^`06oiR3^`05o`000?n>
O[goSWjmohin_Ol000001On>OKd7oh]o`@;o00000on6PlP5o`0000?oOh?=00?o0000og=mc_mcOLh0
0omcOLh5oh6>e`Co00002?moU]l2o`0000SoQ:CY00Co0000oi72n?nA`_SoTL;h1Ol00003oiO9n@03
o`000?n_hOSo000000;o00000ondj?L00ol0003o_>Oco`000002o`000003olKli?l0003odoKU00;o
000000?oaOc0oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z02oo
oo]Z00?o0000oookJ_oonfX04?oonfX2o`000003ojPM0?l0003o000000;oeelD0_l000000ooSPToo
0000on:1DP02on:1DP;o00000_oSTW800ol0003oh91don2@M002on2@M0;o00000ooNVHL4o`0000Ko
/L_]00?o0000olK=gol000001Oo5bmh00ol0003o`/WOo`000003o`0000Co`<OO0_l00005olc2d@;o
00001_o8_]401?l0003oaK_AolFkdOo5^m42o`0000Coc;g;00?o0000olBbbOo4//T01?o4//T2o`00
00Go`;7;00Co0000olR``_o8/<;o00001oo3Zl800ol0003o`K?<ol6cc002ol6cc0_o00001OngXL80
0ol0003o]Z?5okJSa@0:okJSa@;o00003On_WLD2o`0000;oZi[61_l00003ojVIaP03o`000?nRT/Co
XY;400CoXY;40_l00005oj:HbP03o`000?nMU<[oWIC:00WoWIC:00?o0000oiFAcOnETLd01?nETLd3
o`000003oiNAc?l0003oSi7@00GoSi7@3?l00004oiNPf`;o00003?nBYN<00ol0003oT[ccoi:ll`04
oi:ll`Co00000onGaoP00ol0003oW]WloikIo004oikIo0?o00001?nPi_`01?l0003oX>ofo`000?l0
0002ok[hk@03og3HZ_oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP0HoookJP00??oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?l0>Kko000000;o00000_mHTnd5
o`0000;oS/7h1Ol00003oiK6n003o`000?nbf?Co/]Sd00;o/]Sd0ol00003okOIl@;o00000onlfo03
o`0000Cod^CT0_l00002omCOh003o`000?oEfmco000000;od]gQ00?o0000om?IgOoCfMd00ooCfMd0
0ol0003og];<omkBc002o`0000?og<k;00?o0000om[9bOoJbLT00ooJbLT01Ol0003of<K8o`000?oE
`lSo000000;odKk800?o0000omVl_?l000001?oE]k`00ol0003od[S0o`000002o`000005ol^^_Ol0
003oaj^molN[_Ol000000_o=ZKD00ol0003obJ^kolV[^`04olV[^`05o`000?nnW[So_YjhokjN^?l0
00000_o1X;L00ol0003o_YnjokjO^P02okjO^QGo00001On[S[P01?l0003oXHFfo`000?l00006oj>:
^P03o`000?nHPk_oV8>k00KoV8>k0_l00008ohim_@KoRgo100?o0000ohV4aol000001on6PlP6o`00
00CoLgg>00?o0000oh6>eon1S]L00_n1S]L00ol0003oM8SIogB8f@06o`0000CoOiKO00?o0000ohBT
jOn4Y>T00_n4Y>T8o`0000WoUlWi00?o0000okCXmondj?L00_ndj?L00ol0003o_>OcokcWl`02o`00
00;oa_cT00Go0000om?fiOl0003o0000olGl`00VoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000
oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0AoookJPCo00000_oGGa@01Ol0003oef4Ko`000?oS
PToo000000;ohX5B00Ko0000on21E_l0003o0000on>BL_l00003on2@M003o`000?oNSgGo000000?o
00002_nabnd00ol0003oaL_NolG;gP03olG;gPCo00001_o0aml01?l0003o_/COokk4gol00003olc2
d@03o`000?o8_]7ob;kA00Gob;kA00?o0000olFkdOo5^m401?o5^m42o`000003olbmbol0003oa;;9
00Goa;;900?o0000ol2aboo0/L/01Oo0/L/00ol0003ob;32o`000007ol>[`P03o`000?o1/lco`K?<
00Co`K?<00Co0000oknYa?noZLCo00001_nlXl06o`0000_o]Z?500Co0000okBO`ondWl?o00001On_
WLD3o`0000;o[ig51_l0000:ojVIaP05o`000?nRT/CoXY;4oj:Ba?l000002?nRV<X00ol0003oWIC:
oifDbP09oifDbP03o`000?nETLgoUI7=00;oUI7=0_l00002oiNAc0Wo00001_nCW]`9oiNPf`04o`00
0?nEYn;oUJORo`0000coTZGS00?o0000oi:llonB_?<00ol00008oiO7n003o`000?nNfOcoW]Wl00?o
00000onPi_`3o`000003oj3_m_l0003o000000;o^_S]0_l0001MoookJP03o`000?oonf[ooo]Z00Ko
oo]Z00?o0000oookJ_oonfX06?oonfX003gooo]Z0_l0000]oookJP;o000000?o7G7Qo`000?l00000
0_mHTnd00ol0003oKZOcofjWl`03o`0000WoU/Kh00Co0000ok;Hm?l0003o00001?ngfO42o`0000Go
_=_`0ol00003om;Ti005o`000?oDgn3oe=oPomCOh?l000000ooEfm`2o`0000CodmWM00[o0000om?D
f_oCe=[o0000omkBc?l0003og<g:o`000?oLc/_o00001OoJbLT01?l0003of<K8omS6b?oHa/P2o`00
00?odKk800?o0000omFg_?oE]k`00_oE]k`00ol0003od[S0om:h`003om:h`0Go000000?ocJVeo`00
0?o9Zk/01Oo9Zk/00ol0003o_YjhokjN^003okjN^0;o00001onnWkX01?l0003o]IJgokFF]ol00006
okBF^005o`000?nbUkco/YNlok:G_?l000002On[S[P2o`0000SoXhZj00?o0000oiR3^onHPk/00onH
Pk/3o`000003oiV3^_l0003oSWfm00OoSWfm1?n;Ol400ol0003oRHC7ohV4a`02ohV4a`03o`000?n6
PlSoQX?800GoQX?80_l00003ohF9d0Go00000on1S]L00ol0003oM8SIogB8f@02ogB8f@03o`000?n7
W>7oQicQ00;oQicQ2Ol00005ohBcm003o`000?nGbOWoUlWi00CoUlWi0ol00003oigAnP04o`000?nd
j?Oo0000o`0000?o_>Oc00Co0000olKli?l0003o00000_oCm^D00ol0003oaOc0oookJP0VoookJP03
o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0CoookJPCo
000000?oeelDo`000?oGHA/00_l00003on:1DP03o`000?oPPEKoh85F00;o00000ooPT7@01?l0003o
gXmeo`000?l00009ok7;k@;o00000_nabN`6o`0000?oa<WN00Co0000ol37goo0amoo`<OO0_l00004
okk4g`03o`000?o<`]7o000000Oob;kA00?o0000olFkdOo5^m401_o5^m43o`0000Goa;;900?o0000
ol2aboo0/L/01_o0/L/2o`0000Oo`j_200?o0000ol6cc?o1/l`01_o1/l`2o`0000Wo_:?000Co0000
okV/c?ni[<co^Jc<5?l00003ojnLa003o`000?n^X<Wo[Z3900;o[Z3900?o0000ojVIa_nYVLH02_nY
VLH2o`0000coXYS:00?o0000oifDb_nMU<X02?nMU<X00ol0003oUI7=oiFAc@06o`0000?oV9cF00?o
0000oi>Ng?nCW]`02_nCW]`7oiNPf`03o`000?nEYn;oUJOR00;oUJOR00?o0000oi:UhonBYN<01?nB
YN<8o`0000coUlOh0_l00004oj3Vo0;o00000onPkoH2o`0000;o^_S]00?oL=RZoookJ_oonfX0G_oo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Sooo]Z000ooookJP03o`000?oonf[o
oo]Z02_ooo]Z0_l00002oaeah@04o`000?mHTngoF9?]o`0000CoKZOc00?o0000oiK6n?nFa_P00onF
a_P6o`0000Co]mWa00?o0000okcKl?nlfo000onlfo02o`000006ol3KkOl0003o^][`o`000?oBi>Co
00000ooDgn000ol0003oeM_LomGKg002omGKg004o`000?oCfMgodmWMom?Ig@;o00001?oCe=X2o`00
00;og<g:00?o0000om[9bOoJbLT00ooJbLT00ol0003of<K8omS6b002omS6b004o`000?oE`/Oo0000
om6nb0;o00000ooE]k`00ol0003od[S0om:h`003om:h`003o`000?o>/[koc[:n00;oc[:n1?l00004
olV[^`03o`000?nnW[So_Yjh00Co_Yjh00?o0000okjO^_nnWkX01OnnWkX00ol0003o]IJgokFF]`02
okFF]`03o`000?ndU[So]9Jh00;o]9Jh00?o0000ok:G_?nbUk`00onbUk`00ol0003oZhjhoj^>^004
oj^>^0;o000000?o[I>ko`000?nSR[X02?nSR[X00ol0003oV8>ko`000002o`0000GoVH>j00?o0000
ohim_On>OKd01_n>OKd2oh]o`@03o`000?n9Q<OoRHC700?oRHC700?o0000ohJ3b?n6PlP01?n6PlP0
0ol0003oPhS@o`000007ohF9d0So00000_mdR=T00ol0003oQicQohNLh@05ohNLh@03o`000?n4/oCo
Q;?d00SoQ;?d00?o0000oiO9nOnGbOT00ol00007oigAnP06o`000?nlio?o_>OcokcWlol0003o`^_a
0_l00003om?fi@03olSng?l0003o000002Sooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]Z
oookJP0^oookJP03o`000?oonf[ooo]Z01Cooo]Z1Ol00002omMQ6`;o00000_oRPE801?l0003oh85F
on21E_oPPEH2o`000004on2@M?l0003o0000o`0000So/L_]0ol00002ok79k0Co000000?oaL_No`00
0?o4bMh01Oo4bMh00ol0003o`<OOo`000006okk4g`;o00001oo8_]400ol0003oaK_AolFkd@06olFk
d@;oa<?I00?o0000ol^jb_l000000_l000000oo4//Wo0000ol2ab`07ol2ab`03o`000?nm/<ko0000
00Ko`j_200?o0000ol6cc?o1/l`01_o1/l`2o`0000Wo_:?000?o0000okV/c?ni[<`00_ni[<`00ol0
003o]Z?5okJSa@05okJSa@03o`000?ndYL[o]:G:00Co]:G:00?o0000ojnLa?n_W<@00on_W<@2o`00
00Ko[Z3900?o0000ojVIa_nYVLH01onYVLH2o`000003ojZNbonRV<[oXYS:00_oXYS:00?o0000oifD
b_nMU<X01_nMU<X6o`0000WoV9cF00?o0000oi>Ng?nCW]`02OnCW]`00ol0003oUj3KoiNPf`02oiNP
f`03o`000?nEYn;oUJOR00;oUJOR2Ol00006oiBil003o`000?nGaoSoUlOh00GoUlOh1?l00004oi_D
o004o`000?nPi_co0000o`0000CoX>of00Go0000ok[hkOnjn>goL=RZo`00001RoookJP03o`000?oo
nf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX05ooonfX0043ooo]Z0_l0000[oookJP05o`00Q?l0003o
0000o`000?lMLN403Ol00006oig:m`04o`000?ngfO7o0000o`0000Co_=_`0_l00004ol3Kk@Go0000
00?oe=oPo`000?oEfm`00ooEfm`01Ol0003oeMKIo`000?oCfMgo000000GodmCJ00Go0000om;?eooB
cmOo0000omc=bP02o`0000?of/W900?o0000omS6b?oHa/P00_oHa/P01?l0003oeL;7omG2aooE`/L2
o`000005olfiaol0003oeKNlomFg_?l000001?oB^<000ol0003oc[:noljb_P04oljb_P;o000000Go
bJ^ko`000?l0003obJ^ko`000006okjN^0;o00001_nnWkX00ol0003o]IJgokFF]`03okFF]`05o`00
0?ndU[So]9JhokBF^?l000001_nbUk`00ol0003oZhjhoj^>^002oj^>^0;o00000on]Tk/00ol0003o
XhZjoj>:^P05oj>:^PCo00001_nIPkX;o`000003oh]o`Ol0003o000000?o00000_n9Q<L00ol0003o
QX?8ohJ3b003ohJ3b005o`000?n3R=3oPhS@oh>8d?l000001on5RM000ol0003oOi3Jo`000004ogn@
fPOo00000_n7W>400ol0003oMi_Wo`000005ohBcm0?o00000_n4/o@2o`0000GoWM7j0ol00003oj?J
n`04o`000?nlio?o0000ol;[l@;o00000_oCm^D01?l0003ob?kLo`000?o=nk@ZoookJP03o`000?oo
nf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0EoookJP;o00000_lG
QnP7o`000003on21E_l0003o000000?o00001?n<`OT00ol0003o/L_]ok7;k@02ok7;k@;o000000?o
/LW/o`000?l000000_l00004ok79k003o`000?o4bMkoa<WN00Koa<WN0_l00005okk4g`04o`000?nk
`^3o^l;Po`0000Gob;kA00?o0000olFkdOo5^m401Oo5^m400ol0003oa<?IolC3f@02olC3f@04o`00
0?o;^/[obk[:ol^jbP?o00001_o0/L/01Ol0003o_K3>okf`c_nm/<ko000000Co`j_200?o0000ol6c
c?o1/l`01_o1/l`00ol0003o^:W:o`000008okbS`003o`000?ni[<co^Jc<00Co^Jc<00?o0000okJS
aOnfXlD00_nfXlD2o`0000So]:G:00?o0000ojnLa?n_W<@00_l00008ojjPb@03o`000?nYVLKoZIW6
00CoZIW60ol00004ojZNb`coXYS:00Co0000oifDb_nMU<[oWIC:1Ol00003oifJd003o`000?nHW=Ko
V9cF00WoV9cF00?o0000oi>Ng?nCW]`02OnCW]`01Ol0003oUj3KoiNPfonGX=_oUJOR00Go00000onE
Yn800ol0003oU;W`oiBil00:oiBil003o`000?nGaoSoUlOh00Co00002OnKe?`01?l0003oX>ofoj3_
m_nPkoH3o`000004ok[hkOl0003oL=RZo`0006?ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003o
oo]ZoookJP0GoookJP00@_oonfX00ol0003ooo]ZoookJP0YoookJP03o`00Q?l0003o6GKS00Co0000
1_me[?@00ol0003oWL[goig:m`06oig:m`Co00001?nlfo000ol0003o`=_]ol3Kk@03ol3Kk@;o0000
1?nnfNd2o`0000?oeM_L00Go0000omGFfOoEe]WoeMKIo`000005om?DfP03o`000?oBcmOod/oG00;o
d/oG0_l000001?oJbLSo0000om[9bOl00004omS6b003o`000?oE`/OoeL;700;oeL;700Ko0000om:n
aol0003o0000omFg_?l00004om:h`003o`000?o>/[koc[:n00Coc[:n00Co0000olBY_oo4ZKoo0000
0_o9Zk/4o`0000?o_Yjh00Co0000oknP^OnoX;Wo00001?nnWkX00ol0003o]IJgokFF]`04okFF]`04
o`000?ndU[So]9Jho`0000Oo/YNl00Go0000oj^>^?n[S[SoZhjho`000006ojfC^`03o`000?nSR[[o
000000Co00000_nRRKX00ol0003oVH>joiV3^P05o`0000;oVXRo00?o0000oi64`_nAQ<801_nAQ<86
ohn6aP_o000000?oPhS@o`000?n5RM001on5RM000ol0003oOi3Jogn@fP06ogn@fPCoSZ?R2_l00006
oh^kmP03o`000?nMdO[oWM7j00?o00001onSf_/01?l0003o`^_aol;[lOl00002om?fi@04o`000?o8
o]co0000olgk]2cooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0^oookJP03o`00
0?oonf[ooo]Z01Oooo]Z0ol000000olGQnSo0000od2Om@04o`0000[oS<7i00?o0000ok7;kOl00000
1?l00005ok79k0;o00000on`b>`01?l0003oa<WNolC9g_o4bMh2o`0000?o`/KN0ol000000onna=oo
0000ok_2h003ok_2h005o`000?o8_]7ob;kAolRndOl000001_o5^m42o`0000Koa<?I00?o0000ol^j
b_l000000oo6]/X3o`0000;o`;7;00?o0000okf`c_nm/<h00onm/<h01?l0003o`j_2ol>[`_l00008
ol6cc005o`000?nhZL[o^:W:okRYb_l000001OnlXl02o`0000So^Jc<00Co0000okJSaOnfXlGo0000
2_ndYLX00ol0003o[ic4o`00000;ojjPb@04o`000?nYVLKoZIW6ojVIaP;o00001onZW//;oj:HbPOo
00001onMV]000ol0003oV9cFoiRLeP09oiRLeP03o`000?nCW]coTikL00KoTikL0_l000000onCW]co
0000oiNPf`02o`0000WoUJOR00?o0000oiBil?nD^O001onD^O000ol0003oU;W`oiBil002o`0000Wo
VmCl0ol00003oicQo@;o000000?o[O;eo`000?njn>d00_m`f:X00ol0003ooo]ZoookJP1SoookJP03
o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX05ooonfX004?ooo]Z00?o0000oookJ_oonfX0
:OoonfX01?l008Co0000oaUfholIM^<3o`0000KoMJcd00?o0000oig:monMb_L01Ol00004oj;=mP04
o`000?nlfo3o0000o`0000Co`=_]0_l000000oo3f>Wo0000okkIk@02o`0000?o`MOZ00?o0000omGK
g?l000000ooEe]T00ol0003oe=;Go`000003om?DfP03o`000?oBcmOod/oG00;od/oG0oo@bmD01?l0
003of/W8o`000?l00003omS6b003o`000?oE`/OoeL;700;oeL;700?o0000om:naooB_/L00_oB_/L4
o`000003om:h`?l0003oc[:n00Goc[:n00Go0000olBY_oo4ZKooa:Voo`000002olV[^`04o`000?o5
ZKkoaJVnolFY_PWo000000?o_Ynjo`000?neU[L01oneU[L2o`0000Wo/YNl00?o0000oj^>^?l00000
0_n]Tk/7o`0000OoXXVj0ol00007oiZ8_`03o`000?nAQ<;oTHC200OoTHC22?n?Q/H00ol0003oQHK=
o`000005oh^9c0Ko00000on5RM02o`0000WoOi3J1?n>Xn801Ol0003oQ9kTohBNi?n4W^Co000000_o
Rk_f0_l00005oj?Jn`?o00001?nXi?/2o`000003om?fiOl0003ob?kL00;o0000;_oonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX06OoonfX01?l<Pn?o
0000oaN7j?l00003od2Om@03o`000?n<`OWoS<7i00SoS<7i0ol00006ok79k0?o00001_n`b>`00ol0
003oa<WNo`000008ol;6gP;o00001Onk`^000ol0003ob;kAo`000006olFkd@03o`000?o4`mWoa<?I
00Koa<?I0_l00007olJfbPKo00000_nm/<h00ol0003o`j_2o`000008ol6cc003o`000?nhZL[o^:W:
00;o^:W:00?o0000okbS`?nlXl000_nlXl000ol0003o^Jc<okV/c008okV/c003o`000?nfXlGo0000
00_o]:G:0_l0000<ojjPb@04o`000?nYVLKoZIW6o`0000[oZYk;1_nRV<X8o`0000[oWI[@00?o0000
oiRLe_nHW=H02OnHW=H01?l0003oTikLoi>Ng?nCW]`5o`0000;oUj;M00?o0000oiNRg?l000003?nE
Yn801?l0003oU;W`oiBil?nD^O05o`0000CoV<Cf00?o0000oi_Do?nKe?`01?nKe?`3o`0000CoW>7m
00Co0000oiW/n?nIk?SoVNch1Ol0001WoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oo
nfX05ooonfX004Cooo]Z0_l0000ZoookJPCo000000?o6GKSo`000?l000002?l00008oj;=mPCo0000
1?o0fnd01?l0003o`mSYol?HjOo3f>T2o`0000Ko`MOZ00Go0000omGFfOoEe]WoeMKIo`000003omCB
e`03o`000?oCe=[o000000?od/oG00?o0000om3;eOo@bmD00_o@bmD2o`0000;of<G700?o0000omS6
b?l000001?oE`/L00ol0003od[k7om:na`03om:na`;o00000_oB^<02o`0000Goc[:n00?o0000olBY
_oo4ZKl00_o4ZKl00ol0003obJ^ko`000006olFY_P05o`000?nlW[_o_9jkokbN^ol000000_nnWkX;
o`0000Wo/YNl1_l00005oj^A_003o`000?nRRK[oXXVj00?oXXVj0ol000000onSS[oo0000oiZ8_`08
oiZ8_`03o`000?nAQ<;oTHC200KoTHC200?o0000ohn6a_n?Q/H01On?Q/H2o`0000SoRhW<00Co0000
oh><e?n3S=CoPhcD2ol00003ogn@fP04o`000?n>Xn;oSZ?Ro`0000GoQ9kT00Co0000oh^km_n;^oKo
Rk_f1Ol00003oi;3n003o`000?nSf__oXm[k00?o00001?nXi?/2o`000003ojg]n?l0003o000000Co
0000<?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oo
nfX06_oonfX00ol0003o38?So`b3h`0>o`0000;oS<7i00?o0000ok79k?nabN`00_nabN`2o`0000[o
/<S/00?o0000ol;6g_o2a]h01?o2a]h2o`0000?o_lCN0ol00002ok_2h0;o00001Oo5^m42o`0000So
a<?I00?o0000okbieol000001_o6]/X00ol0003o`K;;ol6bb`04ol6bb`Co00002?o1/l`00ol0003o
^:W:okRYbP04okRYbP04o`000?nlXl3o_:?0o`0000_o^Jc<0_l0000:okBUbP;o000000?o/j;8ojjP
bOn^X<T02on^X<T2o`0000coZYk;0onRV<X6o`0000?oY9k?00?o0000oifJd?nMV]002_nMV]000ol0
003oV9cFoiRLeP06oiRLeP;o000000CoV9cFo`000?l0003o00001OnGX]d00ol0003oUj;LoiNRg002
oiNRg003o`000?nEYn;oUJOR00OoUJOR1_l0000:oiS4mP03o`000?nKe?coVmCl00?o00000onLhOd3
o`0000?oVNch0_l00003ojkfkf[ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0G
oookJP00A_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?lJN^Go6W[U00?o00002?m^Z?@00ol0
003oX/gfoj;=mP05o`0000CoYlkd00Co0000ol3KkOl0003o00000oo3f>T00ol0003oaMGVo`000003
ol7GjP;o00000_o3eNL00ol0003oeMKIo`000004omCBe`;o00000ooBcmL00ol0003od<_Eom3;e@02
om3;e@04o`000?o>am?oc/OCo`0000;of<G70_l00003omG2a`03o`000?oB_/Ood[k700?od[k700Oo
0000olZfaoo:]/Oo0000om:h`?l0003oc[:m00?o000000?oc[:no`000?o4ZKl01?o4ZKl2o`0000Ko
aJVn00?o0000okbN^onlW[/00onlW[/2o`0000Oo^inm00Co0000ok>H^oncV;_o00001onbUk/01?l0
003o/I[0ok6J`?l0000:oj^A_003o`000?nRRK[o000000;o00001?nSS[l00ol0003oVXRooiZ8_`05
oiZ8_`?o00002?nAQ<800ol0003oShK6ohn6aP03ohn6aP;o000000?oSX_;o`000?n;RL`02?n;RL`0
1?l0003oPhcDoh><e?l00004oh><e003o`000?n=VmcoSI_L00?oSI_L4?l00009oi;3n0;o00001?nX
i?/2o`0000?o[Ngh0_l000001?ninnOo0000ol_ij?l0000aoookJP03o`000?oonf[ooo]Z00kooo]Z
00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0KoookJP?o000000?o38?So`000?l00000
0_llW_@4o`0000OoS<7i00Co0000ok79k?l0003o00002?n`b>`3o`0000;o[/O/00?o0000ol;6g_o2
a]h00_o2a]h00ol0003o_lCNoko4gP06oko4gP?o000000?o^<7Qo`000?o5^m400_o5^m400ol0003o
a<?IolC3f@06olC3f@;o00000onl^ML01?l0003oa[K:olJfb_o6]/X2o`0000Oo`K;;00Co0000oknk
e_no^mKo_k_F1?l00004ol6cc0Oo^:W:00?o0000okbS`?l000002_ni[<`2o`000003okNVb?l0003o
]:G:00So]:G:00?o0000ok>Rb?ncX/P00_ncX/P9ojjPb@?o000000?o[Z3:o`000?nZW//02onZW//0
1?l0003oXYS:o`000?l00009ojBNc`03o`000?nMV]3oWI[@00WoWI[@00Co0000oiRLe_nHW=KoV9cF
1Ol00003oiZPf@03o`000?nGX]goUj;M00?oUj;M00?o0000oiNRg?nGX]`01?nGX]`01?l0003oUJOR
oiFWh_nEYn86o`0000?oV;W_00?o0000oiS4m_nHa?H02onHa?H2o`0000CoW>7m0_l00005oiW/n004
o`000?n^m^oo[_K_ojkfkfgooo]Z00Go0000oookJ_oonf[ooo]Zo`00000IoookJP00AooonfX2o`00
02Wooo]Z00?o0000oaYjiOlJN^D00_lJN^D00ol0003oKZSdofjXm002ofjXm0Ko00002OnWc_@3o`00
00?o`mSY00Oo0000olGEi_o5eNKoaMGVo`000?o1en[o000000Go`mGW0_l00003omCBe`06o`000?oC
cmGodloEo`000?oBcmOo00001?o@bmD00ol0003oc/OColk7d`02olk7d`07o`000?oF`/Ooe/;7omK2
aol0003oeL;7o`000005om:na`03o`000?o:]/Oob[K700;ob[K700?o0000oljb_Oo>/[d00oo>/[d4
o`0000;oa:Vo00?o0000olBY_ol000001Oo5ZKh00ol0003o_9jkokbN^`04okbN^`03o`000?nkWkgo
^inm00Go^inm00?o0000ok>H^oncV;/00_ncV;/00ol0003o/YNkok:G^`03ok:G^`03o`000?naV/3o
/I[000;o/I[000?o0000oj^A_?n[TK`01_n[TK`3o`0000SoXhjo00?o0000oiZ8_ol000001?l00002
oiZ8_`03o`000?nAQ<;oTHC200OoTHC200?o0000ohn6a_n?Q/H00_l00004ohj;b`03o`000?n;RLco
RhW<00KoRhW<00?o0000oh><e?l000001_n3S=@00ol0003oSI_LohfKg006ohfKg003o`000?n<Y^Ko
S:KV00SoS:KV00?o0000oi;3n?nB`oP01Ol00003oiS=nP03o`000?nXi?_o000000;o00001?n]kOP0
1_l0003o^O_Wo`000?l0003oboWXo`0003?ooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Z
oookJP0/oookJP03o`000?oonf[ooo]Z01kooo]Z0_l0Nm/6o`0000GoS<7i0ol00002ohc1n@03o`00
0?n`b>co/<S/00Go/<S/0ol00006ojk7k004o`000?o2a]ko0000o`0000Oo_lCN00?o0000okc1g_nl
`Mh00_nl`Mh3o`000003olFkdOl0003oa<?I00Ooa<?I00?o0000okbieonl^ML01?nl^ML00ol0003o
a[K:o`000007ol6bb`;o00001?no^mH01?l0003o`K?<ol6cc?o1/l`7o`0000Co^:W:0ol00009okV/
c003o`000?ngY/So]jK800;o]jK800?o0000okBUb_ndYLX01?ndYLX2o`0000Go/j;800?o0000ojjP
bOn^X<T01?n^X<T2o`0000Go[Z3:00?o0000ojZNbonZW//01?nZW//7o`0000coY9k?00?o0000oifJ
d?nMV]001_nMV]06o`0000WoVZ3I00Co0000oiNRgOnGX]goUj;M1_nGX]`6o`0000[oV;W_00?o0000
oiS4m_nHa?H01?nHa?H4o`0000CoVm;k00Co0000oicQoOl0003o00001OnIk?P01Ol0003o[_K_ojkf
kon^m^oo000006oooo]Z00Co0000oookJ_oonf[o00006OoonfX004Wooo]Z00?o0000oookJ_oonfX0
9ooonfX00ol0003o87_Uo`000006o`0000GoOKWi00?o0000ojO>m?nWc_@01?nWc_@3o`0000?oZloc
00?o0000ol?HjOl000001?o5eNH2o`0000?o`mGW0_l00003olCBi003o`000?oDd]Oo000000CodloE
0_l00003om3;e@03o`000?o>am?oc/OC00;oc/OC00?o0000ol_3dol000000ooF`/L2o`0000Cod[k7
00?o0000olZfaoo:]/L00_o:]/L2o`0000Coc[:m00?o0000ol^c`oo;/l<00_o;/l<6o`0000?oaJVn
00?o0000okbN^onlW[/01?nlW[/2o`0000Ko^inm00?o0000ok>H^oncV;/00oncV;/01?l0003o/YNk
ok:G^onbUk/2o`0000Go/I[000?o0000oj^A_?n[TK`01?n[TK`2o`000003ojbF`?l0003oXhjo00Ko
Xhjo1?l00008oiZ8_`03o`000?nAQ<;oTHC200;oTHC24ol00004oh^9c003o`000?n3S=CoPhcD00Go
PhcD00?o0000ohfKg?n=Vm`01On=Vm`00ol0003oR:CVo`000005ohbViPOo00002OnHcOX00ol0003o
[Nghojg]n002ojg]n0;o000000Co^Nceo`000?l0003oboWX0ol0000doookJP03o`000?oonf[ooo]Z
00gooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0NoookJP?o00000ol0Nm/7o`00
00OoRL3i0_l000001?n`b>co0000o`000?l0000:ojk7k003o`000?noa=ko_lCN00Go_lCN0_l00008
okc1gP;o00001oo4`mT00ol0003o_;WGokbie`05okbie`;o00001oo1///00ol0003o_k_FoknkeP05
oknkeP04o`000?o1/lco0000o`0000Ko_Zc82ol00003okV/c0;o00001OngY/P00ol0003o]:G:okBU
bP03okBUbP03o`000?ncX/So/j;800Go/j;800?o0000ojjPbOn^X<T00_n^X<T2o`0000;o[Z3:3?l0
0005ojRMb`03ojVQc_l0003oY9k?00_oY9k?00Co0000oifJd?nMV]3oWI[@1Ol00003oj2ReP03o`00
0?nJX=WoVZ3I00WoVZ3I0_l00003oiNRg0Go00000onI/NP00ol0003oV;W_oiRik`0;oiRik`03o`00
0?nHa?KoV<Cf00?o00002OnKd_/01?l0003oVNchoiW/n?nIk?P4o`000003ojkfkol0003oFlbR077o
oo]Z00Co0000oookJ_oonf[o00006OoonfX004[ooo]Z0_l0000XoookJP03o`000?lPNnGo87_U00;o
000000?o?i?`o`000?mm^OT01_mm^OT00ol0003oYlkdojO>m003o`0000KoZloc0ol00003olGEiP06
o`000?o6dnCoa]?To`000?o3eNOo00001_o4d^@2o`0000?odloE00Ko0000om;;dooBbm?o0000om3;
eOl00004olk7d`07o`000?o;`m?obl?Col_3dol0003oe/;7o`000002om:naP;o000000?od[k7o`00
0?o:]/L00oo:]/L01?l0003oa[?8olJcb?l00002oljb_@03o`000?o;/l?obk?300Cobk?300Co0000
ol6X`?o1Z<3o`JS00_l000000oo5ZKko0000okbN^`05okbN^`04o`000?nmXKco_J6lo`0000Co^inm
00?o0000ok>H^oncV;/01?ncV;/01?l0003o/YNkok:G^ol00007ok6J`004o`000?n[TKcoZi6loj^A
_0?o00001?n/U/000ol0003oXhjoo`000004o`0000;oXXjn00?o0000oiZ8_onJR;l00onJR;l9o`00
00CoU8_70_l00008oi:=bP03o`000?n:SM7oRXgA00;oRXgA7?l00005ohfhl`03o`000?nHcO[oV<gj
00CoV<gj0ol00002oikGo004o`000?n]kOSo0000o`0000;o^Nce00?o0000ol_ij?l000000ol0000f
oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0J
oookJPCo00001?oonfX01?l0L<oo07_Ko`1kfol00002ocJMl`03o`000?n9`?WoRL3i00WoRL3i00?o
0000ojk7k?n^an`01on^an`3o`0000?o[<G]00Co0000oko4g_noa=ko_lCN0_l00008okc1gP03o`00
0?ni`=oo^L3O00?o00000oo4`mT2o`0000Oo_;WG00?o0000okRhfOl000001_o1///00ol0003o_k_F
oknkeP06oknkeP;o00002Onn[<P00ol0003o^Z_;okZ[b`03okZ[b`04o`000?nj[<co^Zc<okZ/c0So
00000_ngY/P00ol0003o]:G:okBUbP02okBUbPCo/j;82?l000000on^X<Wo0000o`000003o`0000Go
[Z3900?o0000ojRMbonXWL/01_nXWL/5ojVQcP03o`000?nTW/ooY9k?00[oY9k?0ol00009oj2ReP03
o`000?nJX=WoVZ3I00GoVZ3I2?l00009oiVaj003o`000?nH^NooV;W_00_oV;W_0_l00006oi_Bn`Co
00001OnJgod01ol0003oY?3fo`000?n^m^oo0000oe_<X_l00000LooonfX01?l0003ooo]ZoookJ_l0
000HoookJP00C?oonfX00ol0003ooo]ZoookJP0VoookJP04o`000?lPNnGo87_Uob1ki@co00001_n[
co<3o`0000?o[/oa00?o0000olGEi_l000001?o6dn@00ol0003oa=;TolCBi003olCBi007o`000?o5
cn;oaLoRolG?h_l0003odloEo`000004om;;d`;o00000oo>am<00ol0003obl?Col_3d`03ol_3d`03
o`000?oB_/Kod[k600?od[k60ol00002olZfa`07o`000?o6/lSoa[?8olJcb?l0003oc[:mo`000006
ol^c``03o`000?o1Z<3o`JS000?o`JS01Ol00003okbN^`05o`000?nmXKco_J6lokfQ_?l000000onk
Wkd00ol0003o/iRkok>H^`06ok>H^`;o00002OnaV/000ol0003oZi6lo`000002ojbF`0Oo00001onR
S[h6o`0000CoW8k400?o0000oiB;aonDRlL00onDRlL3o`000003oiB:a_l0003oTXg:00SoTXg:00?o
0000ohZ=dOn:SM400_n:SM401?l0003oRHg@ohV=d?l00008ohnHf003o`000?n;Wn7oRioQ00;oRioQ
00?o0000oh^Nh?n;W^000_n;W^000ol0003oSKScohfhl`08ohfhl`03o`000?nHcO[oV<gj00?o0000
1_nNeo`02?l0003o^NceokW/mOnik?Go0000ol_ij?l0003o]OcG0_l0000hoookJP03o`000?oonf[o
oo]Z00_ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0GoookJP?o00002_oonfX0
0ol0003o073?o`000003o`0000?oRL3i1Ol00004ohJonP03o`000?n^anco[/O/00?o[/O/0_l00007
ojc5k@03o`000?noa=ko000000Oo_<7N0_l00005okW0g`05o`000?o4`mWo0000olC3fOl000001onl
^ML2o`0000?o^;SI00Co0000ol6bboo1//_o`K;;0_l00008oknkeP03o`000?ng/MCo000000So_Zc8
00?o0000okZ[bonjZl/01OnjZl/01?l0003o^Zc<okZ/c?l00007okNVa`_o00001oncX/L00ol0003o
[Z39ojjPb@0:ojjPb@03o`000?nXWL_oZ9g;00;oZ9g;2OnYXLh00ol0003oY9k?ojBNc`03ojBNc`Co
00000_nSY=H00ol0003oX:;Foj2ReP0:oj2ReP03o`000?nJX=WoVZ3I00;oVZ3I1Ol00002oib]h`03
o`000?nI/NSoVK7X00[oVK7X00Co0000oiRikonH^NooV;W_1_l00004oi[5mP03o`000?nKd__oVm;k
00Co00001OnJgod3o`0000;oT^Wh1Ol0001eoookJP03o`000?oonf[o000001Sooo]Z001=oookJP03
o`000?oonf[ooo]Z02Kooo]Z00?o0000ob:0j?l000000_l000000om3Uo;o0000oh>ln@07oh>ln@03
o`000?n[co?oZloc00?o00001_n^co43o`0000?oa]?T00?o0000olOAh_l000000oo4d^@00ol0003o
aLoRolG?hP03olG?hP03o`000?oBbm?od/_C00;od/_C00Ko0000om38d_o@b=;o0000olk7dol00005
ol_3d`03o`000?o8_m;o000000?od[k600Co0000olnja_o?^/Kock[60ol00004olJcb003o`000?o;
/l?obk?300Cobk?300?o0000ol6X`?o1Z<001?o1Z<000ol0003o`jFkol>U^`02ol>U^`;o000000?o
_9jko`000?l000002ol00004ok>H^`03o`000?naV/3o/I[000So/I[01Ol00005oj^E`003o`000?nR
S[koXXjn00?oXXjn0ol000000onTTlCo0000oib>a008oib>a005o`000?nDRlOoU8_7oiB;aol00000
1OnDR/H00ol0003oTXg:oi:=bP06oi:=bP03o`000?n:SM7oRXgA00;o00001?n9SM000ol0003oSiSH
ohnHf006ohnHf004o`000?n;Wn7oRioQo`0000KoRikP00?o0000ohfhlon=^?<00on=^?<3o`0000;o
SKSc0_l00005oikGo0?o00000onRho`2o`000003ol_ij?l0003o]OcG00;o0000>OoonfX00ol0003o
oo]ZoookJP0;oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX04ooonfX4o`0000oo
oo]Z00?o062mo`000?l000001?l0000:ohJonP03o`000?n^anco000000;o00002_n/aNd00ol0003o
_<7Nokc1gP05okc1gP03o`000?ni`=oo^L3O00Ko^L3O00?o0000olC3fOl000000_l00005okbie`03
o`000?nh^=Wo^;SI00Co^;SI00?o0000ol6bbol000002?no^mH2o`0000?o]k7D00?o0000okj/b?nn
[<P00onn[<P2o`0000So^Z_;00?o0000okZ/c?l000002_ngY/L00ol0003o];7Fo`00000:ok>Ra`;o
000000?o/JK=o`000?n^X<T03?n^X<T00ol0003oZJ7>ojVQcP0:ojVQcP03o`000?nTW/ooY9k?00?o
00001onSY=H00ol0003oX:;Foj2ReP09oj2ReP03o`000?nJX=WoVZ3I00?o00001onL[N<00ol0003o
VK7XoiVaj00:oiVaj0?o00002onJaOH2o`0000OoV]om0_l00003oi;Yn0;o00000onNlnahoookJP;o
00006?oonfX004kooo]Z0_l0000WoookJP04o`000?lRP>So8X3Xob:0j0?o00001?n3_?T6o`0000Ko
[/oa0ol00003ok3?l003o`000?o6dnCo000000?oam7R00?o0000olCBi?l000001?o5cn801ol0003o
a<cPolC<h?o4c>3o0000om;;dol000001?o@b=82o`0000Cobl?C00Oo0000olRod_o8_m;ob;oBo`00
0?oB_/Ko000000Cock[600?o0000olblboo<_</00ol000000oo6/lSo0000ol^c``04ol^c``03o`00
0?o1Z<3o`JS000Co`JS000?o0000okfW`ol000001?o3YK/00ol0003o_jW4oknYa004oknYa0;o0000
1_nhVkX:o`0000?o/IVo00?o0000ojnLa?l000002_n[UL000ol0003oXXjno`000002o`0000GoY9?4
00?o0000oib>a?nLS/@01_nLS/@2o`0000SoU8[600?o0000oi:=b_nBSLX01_nBSLX00ol0003oRXgA
o`000006ohV=d003o`000?n?V=SoSiSH00KoSiSH00?o0000oh^OhOl000001?n;W^09o`0000KoTl;g
00?o0000oikGo?nNeo`00ol00003oj;So0;o000000?oY>gio`000?l000000ol0000loookJP03o`00
0?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0@oookJP?o0000
5?oonfX00ol0003o062mo`1P_@03o`0000_oQ[oj00?o0000ojc5kOn/aNd01on/aNd3o`0000;oZ<G^
00?o0000okc1g_nl`Mh00_nl`Mh2o`0000[o^L3O00Co0000ol>oeoo3_mOo`koG0ol000000onl^MOo
0000okRhf@06okRhf@;o00002?no^mH00ol0003o]k7DokNae004okNae005o`000?nn[<So_Zc8okj/
b?l000002onjZl/00ol0003o]jK7okNVa`07okNVa`;o00000ond/MH00ol0003o/j;7ok>Ra`05ok>R
a`;o00001?naY/d00ol0003o[Z39ojjPb@07ojjPb@;o000000?o[JG@o`000?nYXLh03?nYXLh2o`00
00_oXjCF00?o0000oj2Re_nPX]H01_nPX]H00ol0003oX:;Fo`000002o`0000_oW:gS00?o0000oiVa
j?nI/NP00onI/NP4o`0000?oVkc_00?o0000oi[5m_nJaOH01?nJaOH4o`0000?oVm?k00?o0000oi[O
oOnJgod00onJgod2o`0000CoT^Wh00Co0000oikck?nNlnco0000NOoonfX3o`0001Sooo]Z001@oook
JP03o`000?oonf[ooo]Z02Gooo]Z00Ko0000ob:0j?l0003o8X3Xo`000?m5V_<4o`0000KoQkoi00?o
0000ojk?lOn^co400ol00006ok3?l0;o00001?o7dN82o`0000?oaLoR0_l00004olC<h0;o00000oo@
b=801?l0003oc/GAolk5dOo>aM42o`000003ol_3dol0003ob;oB00?ob;oB0_l00004olnjaP03o`00
0?o<_<_oc;c;00?oc;c;1?l00003ol^c``03o`000?o1Z<3o`JS000Co`JS000Go0000okfW`onmYl?o
_JO3o`000002ol>U^`03o`000?noZLCo_jW400Go_jW400?o]j31o`000?nhVkX01_nhVkX01?l0003o
]Z;5okJRaOl00006ok6I_`;o00000on_W<@00ol0003oZiG0oj^E`006oj^E`0?o00002?nTTl@00ol0
003oW8k4oib>a003oib>a0?o000000?oW8k4o`000?nDR/H01onDR/H00ol0003oTXg:oi:=bP02oi:=
bQgo00001?n=/Nl00ol0003oTl;goi?2m`09oi?2m`;o00000onRho`3o`0000;oY>gi0_l000000onZ
nN;o0000o`00000noookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0
003ooo]ZoookJP0<oookJPCo00006OoonfX2o`0000;o062m1_l00006oh6nn`03o`000?n/aNgo[<G]
00?o[<G]0ol00006ojS5kP04o`000?nl`Mko0000o`0000Wo^L3O0_l00002okK0hP03o`000?o3_mOo
`koG00?o`koG1?l00003okRhf@;o000000?o^K[Jo`000?no^mH01_no^mH00ol0003o]k7DokNae006
okNae003o`000?nn[<So000000Wo^Z_;0_l000000ong^=[o0000okNVa`06okNVa`;o00001Ond/MH0
0ol0003o/j;7ok>Ra`04ok>Ra`03o`000?naY/go/JK=00Co/JK=00?o0000ojjPbOn^X<T01?n^X<T3
o`0000Co[JG@00?o0000ojVQc_nYXLh01_nYXLh3o`000003ojVZf?nSY=KoXjCF00_oXjCF00Co0000
oj2Re_nPX]KoX:;F1Ol00003oj2Zg@03o`000?nL[N?oW:gS00[oW:gS00?o0000oiVaj?nI/NP00ol0
0008oi^lk`03o`000?nJaOKoV/Gf00?o00002?nKdo/00ol0003oV]omo`000002o`0000CoT^Wh00Co
0000oikck?l0003o0000MooonfX4o`0001_ooo]Z001AoookJP;o00009ooonfX4o`000003odFJlol0
003oQkoi00CoQkoi1_l00006ok3?l0?o00000_nacNl01?l0003oam7Ro`000?l00002olK?h003o`00
0?o5cn;o000000Goa<cP00Ko0000ol;9goo2bMoo0000om38d_l00006olk5d@;o00000oo8_m800ol0
003oaKgCo`000003olnjaP03o`000?o<_<_oc;c;00?oc;c;00?o0000ol>ab?o3/LP00_o3/LP4o`00
00Go`JS000?o0000okfW`onmYl<00_nmYl<00ol0003o`jFko`000007oknYa0?o]j3100?o0000okRK
^_nhVkX00onhVkX00ol0003o]Z;5okJRa@02okJRa@03o`000?naVKoo/IVo00;o/IVo00?o0000ojnL
a?n_W<@00on_W<@00ol0003oZiG0oj^E`004oj^E`0;o000000?oZi[5o`000?nTTl@02?nTTl@00ol0
003oW8k4oib>a003o`0000CoW8k400?o0000oiB:a_nDR/H00_nDR/H9o`000003oi:Bd?l0003oTI7?
00;oTI7?00?o0000ohbKgOn<Vmd01_n<Vmd00ol0003oU9oLoiBOg004oiBOg004o`000?n=W=goSIcM
o`0000WoSK7_00Co0000oi?2monC`_OoTl;g1Ol00003oiS=nP04o`000?nRhoco0000o`0000?oY>gi
00?o0000ok;^mol000000ol00010oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
:ooonfX00ol0003ooo]ZoookJP08oookJPCo00008?oonfX00ol0003o062mo`000002o`0000WoPKkk
00?o0000ojc5kOl000000_l0000:ojS5kP03o`000?ni`=oo^L3O00Ko^L3O0ol00005okK0hP04o`00
0?o3_mOo0000o`0000Go_[cH1Ol00002okVjfP03o`000?no^mKo_k_F00?o_k_F00?o0000okNae?ng
/M@01ong/M@2o`0000So^Z_;0_l00004okNhfP03o`000?ngY/Oo]jK700?o]jK700?o0000okBae_nd
/MH01_nd/MH01?l0003o/j;7ok>RaoncX/L2o`0000So/JK=00Co0000ojjPbOn^X<Wo[Z390_l00008
ojfUd003o`000?nYXLkoZJ7>00;oZJ7>0ol00005ojVZf0_oXjCF1ol00007oj2Zg@03o`000?nL[N?o
W:gS00OoW:gS00?o0000oib]honL[N<00_l0000<oi^lk`;o00003?nKdo/01?l0003oT^Whoi;Yn?nB
jOP3o`000003oikck?l0003o000007Gooo]Z1?l0000OoookJP00DooonfX00ol0003ooo]ZoookJP0U
oookJP03o`000?lSQ>[o8hCZ00Oo00001_n9`?T00ol0003o/<o`ok3?l003o`0000Go/Lg_0ol00003
olK?h0?o00000oo4c>02o`0000?o`/WO0_l00005olk5d@07o`000?o<`M7oc<7Aolc1dOl0003ob;oB
o`000003olFmd`03o`000?o?^/Ko000000Goc;c;00?o0000ol>ab?o3/LP00oo3/LP2o`0000;ob:o1
0ol00002ol6X`0Ko_JO300?o0000oknYa?noZL@01OnoZL@4okNP`@04o`000?nhVk[o^9^jokRK^P;o
00001OnfX/D00ol0003o/IVook6I_`02o`0000Ko[ic400Co0000oj^E`?n[UL3oZiG00ol00004oj^J
a@03o`000?nTTlCoY9?400GoY9?41?l00003oib>a0Wo00001OnGTL`00ol0003oTY;@oi:Bd002o`00
00GoTI7?00?o0000ohbKgOn<Vmd01_n<Vmd00ol0003oU9oLoiBOg002oiBOg003o`000?n=W=goSIcM
00;oSIcM00?o0000ohfakon=/Nl01on=/Nl3o`0000WoV<gj00?o0000ojC]nOnTkOT00_l00002ok;^
m`Co0000@_oonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oook
J_oonfX01_oonfX3o`0002Kooo]Z2ol00002oh6nn`03o`000?nXaNkoZ<G^00KoZ<G^0ol00004ojC4
l003o`000?ni`=oo^L3O00;o^L3O0_l00009okK0hP03o`000?nn_=So_[cH00Co_[cH0_l00004okVi
f@Co00000ono^mH9okNae0;o000000?o/k?Ho`000?njZl/01_njZl/00ol0003o]kSJokNhfP05okNh
fP03o`000?ngY/Oo]jK700;o00002Ond/MH01?l0003o/j;7o`000?l0000:ok6Vc@04o`000?n^X<Wo
0000o`0000[o[JG@00?o0000ojVQc_l000000_l00008ojVZf003o`000?nSY=KoXjCF00GoXjCF1ol0
000;oj2Zg@04o`000?nL[N?oW:gSoib]h`Go00001?nN]nX00ol0003oVkc_oi^lk`04oi^lk`Co0000
0onLbOL00ol0003oVm?koi_Cn`04oi_Cn`Co00001OnFhOd4o`0007Cooo]Z1?l0000SoookJP00E?oo
nfX2o`0002Kooo]Z1?l00002odJMm003o`000?n9`?WoRL3i00?oRL3i1_l00005ok7=k`?o00000ona
c>d00ol0003oa/oPo`000003olK=g`03o`000?o4c>3o000000Co`/WO00Co0000ol36goo0a]oo0000
0oo>aM400ol0003oc<7Aolc1d@03olc1d@Co00000_o5_M<00ol0003oc;c;olblb`03olblb`03o`00
0?o3/LSo`k7800?o`k7800?o0000ol2`bol000001Oo8[l44o`0000?o_JO30_l00006oknYa0Go]j31
00Co0000okRK^_nhVk[o00001onfX/D00ol0003o/IVoo`000009ojnLa003o`000?n[UL3o000000Oo
Zi[500?o0000ojBCa?nTTl@01Ol00002oj>B``Go00001?nNU<T00ol0003oUi7<oiNAc008oiNAc0;o
00001onATLl00ol0003oS9_MohbKg@06ohbKg@05o`000?nDWmcoU9oLoiBOg?l000001On=W=d00ol0
003oSK7_ohfak`05o`0000;oT[_c00?o0000oiS=n_nHcOX01?nHcOX3o`0000CoW=[m00Ko0000ok;^
monbk_Oo/^kgo`000?o0o>H2o`0004?ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Zoook
JP0ZoookJP03o`000?oonf[ooo]Z00;ooo]Z1?l0000[oookJP03o`1H]ol0003o000000;o00002?mi
_?`2o`0000;oZ<G^0ol00008ojC4l004o`000?ni`=oo0000o`0000So]/3R0_l00002ok71i@03o`00
0?nn_=So_[cH00;o_[cH00?o0000okVifOni^MT01oni^MT5o`0000Oo]k7D00?o0000ok>cf?nc/mP0
0_nc/mP00ol0003o^Z_;okZ[b`02okZ[b`;o00002?ng^=X00ol0003o]jK7o`00000;okBaeP;o0000
3OnaY/d00ol0003o[JG@ojfUd00;ojfUd003o`000?nYZ]SoZJ[H00WoZJ[H00?o0000oj>Te_nSY=H0
0_nSY=H6o`0000;oY:cM00?o0000oj2ZgOnPZ]d02OnPZ]d5o`0000[oW[OZ00?o0000oi^lkonK_>l0
0ol00008oic9m`03o`000?nKdo_oVm?k00?o00001_nFhOd2o`000003ohSXm?l0003o000007;ooo]Z
1?l0000WoookJP00E_oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?lRQn_o8XO[00So00001_n<
`OT00ol0003o/Lg_o`000002o`0000Ko/Lc]0_l00005olK=g`;o00000oo2bMl00ol0003o`<KOol36
g`02ol36g`03o`000?o>aM7o000000Coc<7A00?o0000olRnd?o8_]000oo8_]04o`0000?oc;c;00?o
0000ol>ab?o3/LP00oo3/LP01Ol0003o`;3;ol2`boo0/<_o000000;ob:o100?o0000ol>Z`Oo3Z/40
0oo3Z/48o`0000;o_jW41ongX<42o`0000So]Z;50_l00009ojnLa0;o00001On[V/D7o`0000CoXi;3
0ol000000onSV<Wo0000oijDb@07oijDb@03o`000?nGTLcoUi7<00KoUi7<0_l00008oi6Ac`03o`00
0?n<VmgoS9_M00?oS9_M4?l00008oi:kl`03o`000?nHcO[oV<gj00?o00001?nLf_d2o`0000?oWNKl
0_l000000oo0o>Ko0000o`000015oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0
:_oonfX00ol0003ooo]Zo`000002o`0003;ooo]Z00?o05Rgo`000?l000001ol00002ogVlo0;o0000
3?nTa?000ol0003o]/3RokK0hP05okK0hP?o00001Ona`ND01?l0003o_[cHo`000?l00008okVif@;o
00000_nf^mh00ol0003o_[WDokjie003o`0000;o]k7D0_l00006ok>cf004o`000?njZl_o0000o`00
00[o]kSJ0_l0000:okBaeP;o000000?o[ZcEo`000?naY/d02OnaY/d2o`000003ojfafol0003o[JG@
00Wo[JG@0_l000000on]/M_o0000ojVZf009ojVZf0Co000000?oXjCFo`000?l000002?nT[=d00ol0
003oX:[Moj2Zg@04oj2Zg@Co00000_nQ]>H00ol0003oW[OZoijgjP0;oijgjP;o00003?nLbOL2o`00
00GoU^7m0ol000001?n8j?Co0000o`000?n4j]a_oookJPGo0000:ooonfX005Oooo]Z00?o0000oook
J_oonfX09?oonfX4o`0000;oAYke00?o0000ohc1nOn<`OT01_n<`OT3o`0000Ko/Lc]0ol00003ok7;
k@03o`000?o6cMoo000000?oaL_N00?o0000ol;9gol000001Oo0a]l2o`0000Coc<7A00?o0000olRn
d?o8_]000oo8_]000ol0003oaK[@olFjd002olFjd003o`000?o<_<_o000000Go`k7800?o0000ol2`
boo0/</00_o0/</00ol0003ob:o1o`000006ol>Z`@03o`000?o1//co`K;<00;o`K;<00?o0000oknY
`onoZL<01Ol00004okNP`@03o`000?nfX/Go]Z;500Ko]Z;500?o0000okBO`_l000001?n_W<@01?l0
003o[ic4ojnLa?n_W<@8o`0000GoZYW500Co0000oj>B`onST/?oXi;30_l00005oj>Hb@03o`000?nN
U<WoWYC900KoWYC900?o0000oiNAc?nGTL`00_nGTL`3o`000003oiRAbol0003oTI7?00CoTI7?2Ol0
0004oiRPfP;o00002OnCYN800ol0003oT[_coi:kl`07oi:kl`;o00001?nLf_d2o`0000CoWNKl00?o
0000ojCejonTmN/00_l00018oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0:_oo
nfX2o`0003Oooo]Z00?o05Rgo`000?m</OT02?m</OT00ol0003oY<C`ojC4l004ojC4l0Co00000onN
a?800ol0003o]/3RokK0hP02okK0hP;o00002Ona`ND00ol0003o^KWIokVif@07okVif@03o`000?nf
^mko][_N00?o][_N00?o0000okjie?nn^M@00_nn^M@6o`0000Co/k?H0_l00009okNhfP?o000000?o
];7Fo`000?nd/MH01ond/MH2o`0000Co[ZcE00?o0000ok6VcOnaY/d01?naY/d3o`0000Co[K7K00?o
0000ojfUd?n]YM001?n]YM03o`0000Co[K7K00?o0000ojVZf?nYZ]P00onYZ]P4o`000004ojNYf?l0
003o0000o`0000coY:cM00?o0000oj2ZgOnPZ]d00ol00007oj6diP03o`000?nN]n[oW[OZ00CoW[OZ
1?l00003oik3lP03o`000?nLbOOoW<Wg00CoW<Wg1?l00004oiWHo@03o`000?nFhOgo000000;o0000
0_n8j?@00ol0003oQ>[LoookJP1]oookJPCo0000<?oonfX005Sooo]Z0_l0000VoookJP06o`000?lN
R>[o0000o`000?m6W_Go00000_n<`OT5o`0000?oS<7i00?o0000ok7<kOnac>d00ol00007ok7;k@03
o`000?o5bmkoaL_N00?oaL_N0_l00003ol36g`;o00000onna=l00ol0003oc<7Ao`000005olRnd003
o`000?o5^]3oaK[@00CoaK[@0_l00004ol>ab003o`000?o0/<_o`;3;00?o`;3;0_l00006ol>Z`@03
o`000?o1//co`K;<00Co`K;<0_l00005okbR_aCo00000_n_W<@00ol0003o[Yo9ojjOb@02ojjOb@03
o`000?nZVLGoZYW500OoZYW50ol00008oj>Hb@03o`000?nNU<WoWYC900KoWYC900?o0000oiNAc?nG
TL`00_l000000onHTL_o0000o`000007o`0000CoU9kJ1onHX=X2o`000003oiNWhOl0003oTjGR00Oo
TjGR1ol00005oiO7n003o`000?nLf_go000000;o00000_nMi_`2o`000003oi[_m?l0003o000000;o
0000BooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX0=_oonfX2o`0000SoC;7i00?o0000ojC4l?nTa?000ol00008oik4lP04o`000?nf`>;o0000o`00
00So/L7U0_l00002ojg1j@03o`000?ni^MWo^KWI00Co^KWI0_l00007okJkgP04o`000?nn^MCo0000
o`0000Ko^KGE2_l00003okNhfP;o00001Ond/MH00ol0003o];7FokBaeP03okBaeP;o00001on^[=D0
1?l0003o/JK=ok6VcOnaY/d2o`0000So[K7K00Co0000ojfUd?n]YM3o[JG@0_l00007ojfaf`03o`00
0?nYZ]SoZJ[H00?o00000_nWZMP3o`0000;oYjkL00?o0000ojB/gOnT[=d02onT[=d2o`0000_oXKCV
00?o0000oijgj_nN]nX00ol00008oik3lP03o`000?nLbOOoW<Wg00?o00002OnIf?d00ol0003oR>Sd
ohSXm002o`000003ohCZg?oonf[ooo]Z06[ooo]Z1?l0000doookJP00F_oonfX00ol0003ooo]Zoook
JP0ToookJPCo000000?oA9oeo`000?l000001on<`OT4o`0000Oo/L_]0_l00003ok79k003o`000?o5
bmko000000?oa<SN00?o0000ol36gol000001Onna=l2o`0000Cob;k@0_l00006olFjd003olC2f?l0
003obkW900;o000000?o`k78o`000?o0/</01?o0/</00ol0003o_;3=o`000005ol>Z`@03o`000?o1
//co`K;<00Co`K;<0_l00007okbR_`05o`000?niZl_o^J_;okV[bol000001?nfX/@00ol0003o]:G9
okBUb@03okBUb@04o`000?n_W<Co[ic4ojnLa0;o00001_n^WlT00ol0003oZYW5ojZIa@04ojZIa@;o
000000?oZik:oj>HbOnSV<T02?nSV<T00ol0003oWYC9oijDb@04oijDb@So00001?nIVm@00ol0003o
U9kJoiBNfP07oiBNfPGoV:3J00?o0000oiNWhOnGYn400_nGYn401?l0003oTjGRoi>Uh_nCYN84o`00
00;oU;S`00?o0000oiO7n?nGaoP02?nGaoP00ol0003oWNKloigVo003o`0000;oV^od0_l00002okGi
jdgooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0]oookJP;o0000>?oonfX8o`00
0003odbanOl0003o000000coW/Cb00?o0000ok71iOna`ND01_na`ND2o`0000Go[L7Y00Co0000okVi
fOni^MWo^KWI0_l0000:okJkgP03o`000?ni]MGo^KGE00Ko^KGE0_l00004okBffP04o`000?ng]mWo
]kOIokNgf@So00000ond/MH01Ol0003o];7FokBae_nd/MKo000000Wo[ZcE00Co0000ok6VcOl0003o
00002_n]/M/01?l0003o[JG@o`000?l00004ojfaf`So00000onWZMP00ol0003oYjkLojN^g005ojN^
g003o`000?nT[=goY:cM00CoY:cM1?l00002ojBdi003o`000?nQ]>KoXKCV00_oXKCV0_l0000<oik3
lP;o00001_nIf?d4o`0000CoSNCk0_l0001ZoookJPCo0000>?oonfX005_ooo]Z0_l0000VoookJP06
oaN7j?l0003o0000o`000?m4WoGo00000_n<`OT4o`0000?oS<7i00?o0000ok7;kOnabnd00_nabnd3
o`0000Ko/LW/00?o0000olC8g_o4b=h00oo4b=h2o`0000Co_/CO00?o0000ok_2gol000000oo8_]00
0ol0003oaK[@olFjd004olFjd005o`000?o4`]Soa<;HolC2f?l000000_o;^LT4o`0000;o`;3;00Go
0000okb`cOnl/<go_;3=o`000003ol>Z`@03o`000?o1//co`K;<00Co`K;<00?o0000okRXbOl00000
1OnlX[l2o`0000Go^J_;00Co0000okJRa?nfX/Co00001ondYLT00ol0003o[ic4o`000008ojjOb@04
o`000?nZVLGoZYW5ojZIa@?o00001?n[W/X:oj>Hb@03o`000?nNU<Wo000000?o00000onOV/l00ol0
003oVI_DoiVKe007oiVKe003o`000?nDW][oU9kJ00KoU9kJ00Go0000oiRPf_nHX=[oV:3Jo`000002
oiNWh@Ko00002?nD^?000ol0003oUlOhoiO7n005o`0000CoV]Cl00?o0000oi[_m?nJko@00_l00000
1?nXl_Co0000okGijol0001>oookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0;_oo
nfX00ol0003ooo]ZoookJP0hoookJP?o00001OmH]o`2o`0000?oW/Cb1Ol00004oiO3mP03o`000?na
`NGo/L7U00;o/L7U0_l00008ojg1j@03o`000?ni^MWo000000Wo][_N0_l000000ona_N;o0000okVe
e@05okVee@;o00001ond]]X01?l0003o]kOIo`000?l00007okF`e1?o00003?n]/M/8o`0000KoZk3L
0ol0000:ojN^g003o`000?nT[=goY:cM00Co00001onT]>@00ol0003oXKCVoj6diP04oj6diPCo0000
0_nP`>l00ol0003oW/?boik3lP05oik3lPCo00000onKdO/00ol0003oVMSmoiWHo@04o`0000GoSNCk
00Co0000ohGWlol0003o0000IooonfX4o`0003cooo]Z001MoookJP03o`000?oonf[ooo]Z02Cooo]Z
0_l000000olGQnSo0000o`000002o`0000SoS<7i00Co0000ok7;kOl0003o00001_nabN`2o`0000;o
/<S[00Co0000olC8g_l0003o00000oo2a]d2o`000003okk4gol0003o^l;O00;o^l;O00?o0000olRn
d?l000001Oo5^]02o`0000Coa<;H00?o0000ol^ibOl000001?o6]LX5o`0000;o_;3=00?o0000ol>Z
`Ol000001Oo1//`2o`0000?o^:S900?o0000okbR_onlX[l00_l00007okV[b`03o`000?nfX/Co0000
00So]:G90_l00009ojjOb@04o`000?nZVLGoZYW5o`0000OoZik:2?nSV<T4o`0000SoWi[?00?o0000
oiVKe?nIVm@01_nIVm@00ol0003oU9kJoiBNfP03oiBNfP?o000000?oU9kJo`000?nHX=X01?l00004
oiNWh@03o`000?nD^?3oU;S`00SoU;S`0_l00005oi[Do0?o00000onJh_d2o`000004ojSbm?l0003o
0000o`00053ooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oo
nf[ooo]Z03Wooo]Z00?o08SFo`000?l000002?l0000:oiO3mP04o`000?na`NGo0000o`0000_o[L7Y
00?o0000okJkg_nf^mh01Onf^mh3o`0000Co/KgR00?o0000okVeeOni]MD00_ni]MD00ol0003o];KJ
okBffP08okBffP03o`000?ne/=Co]K3D00So]K3D0_l000000ona]Mco0000ok>^d`07ok>^d`;o0000
0on`/]X00ol0003o[K7Kojfaf`06ojfaf`?o00000_n]/M/00ol0003oZk3Loj^`g007oj^`g0?o0000
00?oZ[;No`000?nW[]`02onW[]`2o`0000_oY;CT00?o0000oj6di_nQ]>H01?l00007oj30k`03o`00
0?nN`o;oW/?b00Co00002?nKdO/2o`0000?oSNCk0ol000000on5io?o0000o`000002o`0006Gooo]Z
1?l00010oookJP00G_oonfX2o`0002Gooo]Z00?o0000o`^2hol000001?l00008ohc1n@03o`000?na
bNco/LW/00?o/LW/0ol00005ok38j`03o`000?o2a]go`/KM00Go`/KM0ol00002ok_2g`;o00001Oo5
^]000ol0003oa<;HolC2f004olC2f0;o00001Oo6]LX00ol0003o`K7:ol6abP02ol6abPOo00000oo1
//`5okRXb@03o`000?nlX[oo000000Wo^J_;0_l00007okBUb@;o000000?o/j;7ojjObOn^WlT02?n^
WlT2o`0000WoZik:0onSV<T5o`0000;oY9g>00?o0000oinJconOV/l01onOV/l00ol0003oVI_DoiVK
e003oiVKe0?o000000?oVI_Do`000?l000000ol00003oiRRf`;oV:7K00?o0000oiNWhOnGYn401onG
Yn400ol0003oU;S`oiBhl005o`0000?oV<Cf00?o0000oi[Do?nJe?`00ol00003oi[Ro@;o00000onC
joH2o`0005?ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0`oookJP;o0000>_oo
nfX5o`0000CoAk3h00?o0000oiO3m_nG`oH02OnG`oH00ol0003o[L7Yojg1j@05ojg1j@Co00000onW
`^d00ol0003o][_NokJkgP02okJkgP;o00002?na_N801?l0003o^KGEo`000?l00008okBffP;o0000
00?o/K[Po`000?ne/=@01_ne/=@3o`0000Co/KGL00?o0000ok>^donc[]<00_nc[]<3o`0000Ko/;;J
00?o0000ojfafon]/M/00on]/M/2o`0000Ko[K7K00?o0000oj^`g?n[/=`01?n[/=`2o`0000GoZ[;N
00?o0000ojN^g?nW[]`01?nW[]`3o`0000;oY[OU00?o0000ojBdi?nT]>@02onT]>@2o`0000coX<3_
0_l00006oi_An`Co00001OnBg_h2o`000003ohGWlol0003o000000;o0000I?oonfX4o`0004Cooo]Z
001PoookJP03o`000?oonf[ooo]Z02?ooo]Z0ol000000ol;P^?o0000o`000004o`0000KoS<7i00Co
0000ok79k?l0003o00001On`b>/2o`0000;o[/K/00Co0000ol;6gOo2a]go`/KM0_l00004oko4g@?o
000000?o^<3Qo`000?o5^]000_o5^]000ol0003oa<;HolC2f004olC2f004o`000?nl^=Ko_;SFo`00
00?oa[G:00?o0000ol6ab_o1/LX00oo1/LX01?l0003o_k[Foknje_l00003ol6bc0Ko00000onhZ<T0
0ol0003o^J_;okV[b`06okV[b`;o000000?o]jK8o`000?ndYLT01?ndYLT2o`0000Co/j;71_n^WlT3
o`000003ojjPbOl0003oZik:00OoZik:0_l000000onSV<Wo0000ojBMcP07ojBMcP03o`000?nOV/oo
Wi[?00GoWi[?1ol00005oibPe`04o`000?nHX]_oV:;KoiRRf`KoV:7K00?o0000oiNWhOnGYn400onG
Yn46o`0000WoV<Cf0_l00003oi[Ro@?o00000onCjoH2o`0005Kooo]Z00?o0000oookJ_oonfX00_oo
nfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03[ooo]Z00?o06Vco`000?l000002_l0
0007ohg3n@03o`000?n]`NWo[L7Y00?o00002?nW`^d01?l0003o][_No`000?l0000;ok6mhP03o`00
0?nd]][o];KJ00Go];KJ0ol00004ok6jh003o`000?ne/=Co]K3D00;o]K3D0_l00008ok6eg004o`00
0?nc[]?o0000o`0000[o/;;J00?o0000ojfafol000000_l00009ojfaf`05o`000?n[/=coZk3Loj^`
g?l000002OnZ/]h00ol0003oYjkLojN^g003o`0000KoY[OU00?o0000ojBdi?nT]>@01?nT]>@4o`00
00?oX[o^00?o0000oj30konP`>l01?nP`>l4o`0000CoWLgh00?o0000oi_AnonKdO/00ol00006oi;N
oP;o00000on4i?L2o`0006?ooo]Z1?l00018oookJP00HOoonfX00ol0003ooo]ZoookJP0ToookJP;o
07WJ1?l00009ohc1n@03o`000?n`b>_o/<S[00?o/<S[0_l00005ojk6k003o`000?o2a]go000000Go
_lCM00Co0000okc1gOnl`Mgo_<7M0ol000000oo5^]3o0000olC2f004olC2f0;o00001?nl^=H00ol0
003oa[G:o`000005ol6abP03o`000?no^]Ko_k[F00;o_k[F00?o0000ol6bc?l000001_nmZlL4o`00
00Ko^J_;0_l00004okNVb005o`000?ndYLWo]:G9okBUbOl000001_ncX/L01?l0003o[Yo9ojjObOn^
WlT2o`0000Go[Z3900?o0000oj^Nb_n[W/X01Ol000000onXWL[oZJ3=o`000009ojBMcP03o`000?nO
V/ooWi[?00Go00000_nQXMD00ol0003oW:3GoibPe`07oibPe`;o00001onHXM/7o`0000GoV;W^00?o
0000oiS4m_nHa?H01Ol00003oi[Bn`04o`000?nJh_go0000o`0000?oTn_f00?o0000ojSfk?l00000
FOoonfX01Ol0003ooo]ZoookJ_oonf[o000003Gooo]Z0_l0000noookJP05o`1Y/ol0003o0000o`00
0?lcY_800_l0000:ohg3n@;o00003?nW`^d00ol0003o/KgRok6mhP07ok6mhP?o00000_n/_nP00ol0
003o];KJokBffP02okBffP;o00002?na^^001?l0003o]K3Do`000?l0000;ok6eg003o`000?n`/][o
/;;J00_o/;;J00?o0000ojfafon]/M/02on]/M/00ol0003oZ[;NojZbgP0;ojZbgP;o00002_nV]nD0
0ol0003oY;CTojBdi003o`0000SoX[o^00?o0000oj30konP`>l00ol00009oig=n0;o00001OnBg_h3
o`0000CoQ>Cg00?oNn?^oookJ_oonfX0H?oonfX4o`0004cooo]Z001RoookJP;o00009ooonfX2o`1i
fPKo00001_n9`?T01?l0003o/<S[o`000?l00008ojk6k003o`000?noa=go_lCM00;o_lCM0_l00007
okc1g@;o00001?o4`]P00ol0003o_;SFokbheP04okbheP;o00001?o1/LX2o`0000Go_k[F0_l00007
okf[a`04o`000?njZl[o^Z_:okZ[bQWo000000?o[Yo9o`000?l000002Ol00003ojRMbPGoZJ3=00?o
0000ojBMc_nTWLh01onTWLh2o`0000SoXJ7E00?o0000oibPeonLX=L00onLX=L3o`000004oifPe_l0
003oV:7KoiRQf`Go00000_nJ/NL00ol0003oV;W^oiRikP08oiRikP;o00002OnJd_/00ol0003oTn_f
oi?[mP02o`000003ojSfk?l0003o000005_ooo]Z00Co0000oookJ_oonf[o0000=ooonfX00ol0003o
oo]ZoookJP0noookJP03o`1Y/ol0003o000000Ko00001omo`O`2o`0000?oYl;]1Ol00003oio4lP03
o`000?na_N;o/KgR00?o/KgR0ol00006ojboj004o`000?nd]][o0000o`0000_o/K[P00?o0000ok6e
g?na]M`01ona]M`3o`000003ojfjhol0003o/;;J00So/;;J0ol000000on]^>7o0000ojfaf`08ojfa
f`?o000000?oZ[SSo`000?nZ/]h02?nZ/]h3o`000003ojNkiol0003oY[OU00_oY[OU0_l0000<oj:o
kP;o00001_nMcOP4o`0000CoTm_n00?o0000oi;No_l000000_l00002ohCTm`03o`000?mkhnko0000
063ooo]Z1Ol0001@oookJP00I?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?l0KLco000000;o
00002On9`?T00ol0003o[/K/ojk6k004ojk6k0?o00000on/aN`00ol0003o_lCMo`000006okc1g@;o
00000_ni_ml3o`000003olC2f?l0003o_;SF00Co_;SF0_l000000onh^=Wo0000ol6abP02ol6abP03
o`000?no^]Ko_k[F00Co_k[F00?o0000okNadol000001OnmZlL2o`0000Go^Z_:00?o0000okV[bol0
00002OngYLL00ol0003o/j76ok>QaP08ok>QaP03o`000?n^WlSo[Yo800So[Yo800?o0000ojRMb_nY
X<d01onYX<d00ol0003oY9g>ojBMcP03ojBMcP?o000000?oY:CEo`000?nQXMD02?nQXMD00ol0003o
W:3GoibPe`0:o`0000SoV[7W00?o0000oiRik_nH^Nh01Ol00003oi[5mP03o`000?nJd__oV];k00Go
00001?nGh?h5o`0005cooo]Z00Co0000oookJ_oonf[o0000>?oonfX2o`00047ooo]Z00Co07C4o`00
0?l0003o00002omo`O`3o`0000WoWlCb00?o0000ok6mh_l000000_l0000:ojboj003o`000?na^^3o
/K[P00Oo/K[P0ol00002oj^ni`03o`000?na]Mco/KGL00?o/KGL0ol00005ojfjh`03o`000?n`/][o
/;;J00?o/;;J0ol00005ojfhh@03o`000?n]/M_o[K7K00?o[K7K0ol00005ojZhh`03o`000?nZ/]ko
Z[;N00?oZ[;N0ol00005ojNki`03o`000?nV]nGoY[OU00CoY[OU0ol00003oj?1kP03o`000?nR_nko
X[o^00CoX[o^1?l00004oik<m`03o`000?nMcOSoWLgh00?o00002OnCfoh00ol0003oQ>Cgo`000003
o`0005oooo]Z1?l0001EoookJP00IOoonfX2o`0002Oooo]Z00?o05bio`000?l000001Ol00005ohJo
nP03o`000?n^a^co[/K/00?o00001on/aN`00ol0003o_<7Mokc1g@02okc1g@?o00001Oni_ml5o`00
00;o_;SF0_l00004okRhf@03o`000?o1/L[o000000Ko_k[F00Go0000okNadong/M?o]k7Co`000003
okf[a`03o`000?njZl[o^Z_:00Ko^Z_:00?o0000okNUaongYLL01OngYLL2o`000003okB`eOl0003o
/j7600Ko/j760_l000000onaY/co0000ojjOb006ojjOb0;o000000?o[JG?o`000?nYX<d02?nYX<d0
0ol0003oY9g>ojBMcP03o`0000GoY:CE00?o0000oj6QeOnQXMD01onQXMD5o`0000GoWJcR00?o0000
oiZaionJ/NL02?nJ/NL2o`0000WoV/Gf0_l00005oiOPoP?o000000CoRnWeo`000?nElNKoUO7VGooo
nfX01?l0003ooo]ZoookJ_l0000ioookJP03o`000?oonf[ooo]Z047ooo]Z00?o07C4o`000?l00000
1?l00006oc:]k`03o`000?nOa?;oWlCb00WoWlCb00?o0000ojboj?n/_nP01_n/_nP3o`0000?oYL;^
00?o0000ok6jh?na^^000ona^^03o`0000KoZkkW00?o0000ok6eg?l000000_l00009ojfjh`03o`00
0?n`/][o000000;o00002On]^>400ol0003o[K7Ko`000002o`0000WoZ[SS00?o0000ojZbg_l00000
0_l00009ojNki`03o`000?nV]nGoY[OU00?o00001onS`Nh00ol0003oX[o^oj:okP03o`0000WoW/cg
0_l00006oi?KoPCo00000_mmhOL00omag^oo<;J_oc2f[`1NoookJPCo0000FOoonfX006Oooo]Z00?o
0000oookJ_oonfX09_oonfX2o`1L^@Ko00001?n6_oX2o`0000Ko[<G/0ol00002ojS4kP04o`000?nl
`Mgo0000o`0000Go^KoO0_l00002okK0hP04o`000?o2_]Ko`[kFol:nePGo00000onh^=T2o`0000Go
_k[F0_l00005okNad`03o`000?nmZlOo000000Ko^Z_:0_l000000ong]mWo0000okNUa`04okNUa`;o
00001?nd/=D01?l0003o/j76ok>Qa_ncXLH3o`0000Co/JK<00Co0000ojjOb?n^WlSo[Yo80ol00004
ojfUc`03o`000?nYX<goZJ3=00OoZJ3=0_l00008ojBTe@03o`000?nQXMGoXJ7E00?oXJ7E0ol00000
0onQXMGo0000oif/hP09oif/hP03o`000?nJ/NOoV[7W00Go00000_nL_>l00ol0003oV/Gfoi[5mP04
oi[5mP?o00000_nJe?`00ol0003oUn3noiOPoP03o`0000?oRnWe0_l0001RoookJP03o`000?oonf[o
000003[ooo]Z00?o0000oookJ_oonfX0AOoonfX9oc:]k`04o`000?nOa?;oWlCboio4lPGo00001?nC
aOP2o`0000;o[;oX0ol00007ojG2kP03o`000?na^^3o000000;o00002_n[_^L00ol0003o[K[Sojfj
h`0;ojfjh`03o`000?n]^>7o[KSQ00_o[KSQ00?o0000ojZhhonZ^><02onZ^><00ol0003oYk_WojNk
i`0;ojNki`;o00002onS`Nh2o`0000KoW/cg1?l00004oi;IoP03o`000?nCfokoTm_n00?o000000Co
ON7go`000?l0003o<;J_0_l0001MoookJPCo0000GOoonfX006Sooo]Z0_l0000XoookJP05o`000?l0
G;Wo0000ob2Ck?l000001on1__/00ol0003o[<G/ojc5k003o`0000KoZ<C^00?o0000okVogoni_ml0
0oni_ml2o`0000Go]/3R00?o0000ol:ne_l000001Onn^mL6o`0000?o_k[F00?o0000okNadong/M<0
1Ong/M<2o`0000Go^Z_:0_l00004okNgf@05o`000?ngYLOo]jG7okNUaol000001_nd/=D01?l0003o
/j76o`000?l00007ok6Vc004o`000?n^WlSo0000o`0000Oo[JG?00?o0000ojVPcOnYX<d00onYX<d3
o`000003ojVYeonTY=GoY:CE00SoY:CE2?l00003oj6Yg003o`000?nM[>;oWJcR00SoWJcR0_l00008
oiblk`03o`000?nJaOKoV/Gf00?o00001_nJe?`2o`0000;oRnWe1?l0001UoookJP;o0000>ooonfX2
o`0004Sooo]Z0_l0O;`3o`0000;o<Zg_0ol0000;oi?5n0;o00002onU`^h00ol0003oZkkWoj^ni`06
oj^ni`?o00000onT`nl00ol0003o[K[Sojfjh`04ojfjh`Co00000onW`>/00ol0003o[KSQojfhh@04
ojfhh@Co00000onX_nX00ol0003oZ[SSojZhh`04ojZhh`Co00000onV`>`00ol0003oYk_WojNki`04
ojNki`Co00000onRaO401?l0003oXl7^oj?1k_nS`Nh5o`0000GoWLgh00?o0000oik<monNc?L00ol0
0009oi;IoPSo0000G?oonfX4o`00067ooo]Z001ZoookJP03o`000?oonf[ooo]Z02Oooo]Z2Ol00002
oh6nn`;o00001OnXa>h3o`0000?oY<C`00Co0000okVogol0003o00002?nf`>800ol0003o_[_Gokjk
e`03okjke`03o`000?ni^=So^KSH00?o^KSH0_l00002oknjePKo]k7C0_l000000onc/]Oo0000okZ[
bP03okZ[bP03o`000?ng]mWo]kOI00Co]kOI00Co0000okNUaol0003o00001ond/=D2o`0000[o/JK<
00?o0000ojfUcon]YLl01on]YLl00ol0003oZJ3=ojVPc@03o`0000GoZJWG1_nTY=D7o`0000SoXJWL
00?o0000oif/h_nM[>801Ol00002oijgj@03o`000?nL_>ooW;c_00SoW;c_0_l00005oi[Do0?o0000
0onCh_d4o`0006Kooo]Z0ol0000moookJP03o`000?oonf[ooo]Z04Sooo]Z00?oCP00o`000?l00000
2_l00007oh?5o@04o`000?nU`^koYL;^ojG2kPGo00001?nJa_H2o`0000;oZkkW0ol00007ojC3k`03
o`000?n]^^?o[K[S00?o00002?nW`>/00ol0003o[KSQojfhh@03o`0000SoZ;oZ00?o0000ojZhhonZ
^><00ol00008ojK0k003o`000?nW^nOoYk_W00?o00002?nRaO43o`0000_oWLgh0_l00005oi;IoPCo
00000omafo@4o`0005cooo]Z1?l0001UoookJP00JooonfX2o`0002Wooo]Z00?o05Bao`000?l00000
2?mi_?`00ol0003oZ<C^o`000002o`0000OoY<C`00?o0000okK0h_nf`>801Onf`>82o`0000;o//3U
00Go0000okjkeonn^mOo_[_Go`000008okVhf0Co00000_ng/M<2o`0000Co/k;G00Co0000okZ[b_l0
003o00001ong]mT2o`0000Oo];3E0_l000000on^ZmCo0000ok6Vc006ok6Vc0;o000000?o[[7Jo`00
0?n]YLl02On]YLl2o`0000WoZJWG0onTY=D5o`0000;oYJcL00?o0000oj6Yg?nQZM`01_nQZM`4o`00
00SoW[OY00?o0000oiblkonL_>l01Ol00003oic:m`03o`000?nJe?coV]Cl00?o00000onCh_d4o`00
06Cooo]Z1Ol00011oookJP;o0000COoonfX00om>003o0000o`000003o`0000[oPlGm0ol0000;oi[6
mP;o00002onT`nl2o`0000coYl3[0_l0000<ojRojP;o00003?nV`>`2o`0000KoX/Ga0ol00004oiW@
n`04o`000?nMcOSoWLghoig=n0Go00001_n>fOl3o`0000;oLM_d1Ol0001MoookJPCo0000JOoonfX0
06gooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0E;7o0000o`000005o`0000;oNKcl00?o0000ojC4
l?nTa?001?nTa?03o`000003oio4l_l0003o]/3R00?o]/3R0ol00005ok;0i@03o`000?nn^mOo0000
00Ko^KSH0_l000000onf^]go0000okjhe002okjhe0Ko00000onc/]L00ol0003o]kOIokNgf@05okNg
f@;o000000?o];3Do`000?nd/=D01?nd/=D2o`0000Co[Z_D00?o0000ok6Vc?naY/`00_naY/`2o`00
00Co[[7J00?o0000ojfUcon]YLl00on]YLl3o`0000;o[K3J00?o0000ojVYeonYZML00onYZML5o`00
0003ojBTeOl0003oYJcL00OoYJcL00?o0000oj6Yg?nQZM`01Ol00002oj:diP03o`000?nN]nWoW[OY
00SoW[OY0_l00009oic:m`;o00000_nCh_d5o`0006?ooo]Z1?l00018oookJP03o`000?oonf[ooo]Z
04_ooo]Z00?o0000oookJ_oonfX01ol00007obNZi@04o`000?nJa_KoV/Kfoi[6mPGo00001?n9b?d0
0ol0003oY<?_ojC3k`04ojC3k`?o00001?nHb?P00ol0003oYl3[ojO0j`04ojO0j`?o00000onNao@0
0ol0003oZ;oZojRojP04ojRojPCo00001?nOao@01?l0003oY/3/ojK0k?nV`>`5o`0000GoW/[g00?o
0000oj;5lOnRaO400ol00008oiW@n`?o00001On>fOl4o`0000GoG=;[0_l0001NoookJPCo0000KOoo
nfX006kooo]Z00?o0000oookJ_oonfX0:_oonfX2o`0000KoBK3i00?o0000ojC4l?nTa?000ol00005
oio4lP04o`000?nf`>;o0000o`0000Wo//3U00?o0000okVhf?ni^=P00_ni^=P3o`0000Co][[M00?o
0000okjhe?l000001_ni]=@8o`0000;o]kOI00?o0000okB`e?nd/=@00_nd/=@01Ol0003o];3EokB`
eOnd/=Go000000Oo[Z_D00Co0000ok6Vc?l0003o00001on^/MX00ol0003o[JG?o`000002o`000003
ojf`f_l0003o000000So00000onWZ=L2ojR]f`03o`000?nU[=coYJcL00SoYJcL0_l00008oj:diP03
o`000?nN]nWoW[OY00Go00000onN`o800ol0003oW<[goic:m`05o`0000CoV=Wn0_l000000omoiNoo
0000o`00001PoookJPGo0000COoonfX2o`0004_ooo]Z00?o0000oookJ_oonfX01OoonfX5o`0000Go
9j[U0ol0000:ohW8o@03o`000?nT`nooY<?_00?o00002?nHb?P00ol0003oYl3[ojO0j`03o`0000Oo
W/Od00?o0000ojRoj_nX_nX00ol00009oio7m0?o00002onNb_L2o`0000KoVM3k0ol00004oh;HoP03
o`000?n>fOooS]Wo00?o00001_mLd^]OoookJPCo0000LOoonfX006oooo]Z0_l0000]oookJP04oabK
j?l0003o0000oeFgn`;oBK3i0_l00009oio4lP03o`000?nb`>Go//3U00Go//3U0ol00002ojg1j004
o`000?ni^=So0000o`0000So][[M00?o0000okVde?ni]=@01?ni]=@2o`0000Co]KGI00?o0000okNg
fOng]mT03ol00005ojj[e003o`000?n^/M[o[[7J00Oo[[7J1_l00005oj^_f`;o000000?oYjSGojR]
fonX[M/01_nX[M/00ol0003oYJcLojF/g005o`0000;oY;CT00?o0000oj:di_nR]>H02?nR]>H2o`00
00WoW/?b0_l00004oiSIoP?o000000GoR>?jo`000?l0003oLn;Po`00001NoookJPCo0000E?oonfX0
0ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z00cooo]Z0_lb0009o`0000KoRLSm0_l0000<
oiS8n0;o00002onNao@2o`0000GoWlOd1?l00005oi3@o@04o`000?nNb_OoW/[goik:m`Go00001On=
e?l00ol0003oVM3koiW@n`03o`0000SoP]Sn0_l00002oecBj`;o0000GooonfX5o`0007Gooo]Z001a
oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oeFgnol000001ol00006oiO3mP03o`000?nb`>Go
//3U00?o00001_n]`NP00ol0003o][[MokJjg@04okJjg@?o00000_na_>800ol0003o^KCDokVde002
okVde003o`000?ne]MWo]KGI00Go]KGI0_l00009okF`e003o`000?nc[M;o/jgB00?o/jgB2_l00000
1?n^/=[o0000o`000?l00002ojj`fP03o`000?n[[m_oZjoK00CoZjoK0ol000000onZ/Mgo0000ojR]
f`09ojR]f`;o00002?nT]>@00ol0003oX[CVoj:diP05o`0000?oXL3_00?o0000oik3l_nN`o801Ol0
0004oi_An`;o00000_n8hoX3o`000003og?Rh?l0003ooo]Z05cooo]Z1?l0001IoookJP03o`000?oo
nf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX04_oonfX00olU003o0000o`000006o`0000Go;[7V1_l0
0007ohC<oP04o`000?nNaoCoW/Odoik7m0Go00001On>c_d3o`0000_oT=3m0ol0000;ohgDo`;o0000
1On2f?h01?l0003o?<3FoaNU]?l0001SoookJPCo0000N_oonfX007;ooo]Z0_l0000`oookJPKo0000
2?nG`oH2o`0000Go[L7X0ol00003ojO2k@03o`000?nf^]go000000;o00001_na_>801?l0003o^KCD
o`000?l00005okFef@;o000000?o/KWOo`000?ne/=@01One/=@3o`000003ok:dfol0003o/jgB00Co
/jgB0ol00003ok2af@03o`000?n^/=[o000000;o00001_n^/=X01?l0003oZjoKoj^_fon[[m/2o`00
00GoZ[7M00?o0000ojR]fonX[M/00onX[M/3o`000003ojNfi?l0003oY;CT00WoY;CT0_l00009oj70
k`;o00001OnKdO/3o`0000?oS]on0_l000000omch^3o0000oookJP1JoookJPGo0000G_oonfX2o`00
04Oooo]Z00?o0000oookJ_oonfX07OoonfX2oc0000Wo00001_n4c?h3o`0000CoS/km1?l00004ocVj
i@04o`000?n@d?goT=3moi3@o@Go00001_m4`^P6o`0000Go@l?T0_l0001XoookJPCo0000O_oonfX0
07Cooo]Z00?o0000oookJ_oonfX0;ooonfX8o`0000KoSL?i00?o0000ojg1j?l000000_l00007ojO2
k@03o`000?na_>;o/KcR00So/KcR00?o0000okFefOne]MT00_ne]MT3o`0000Co/KWO00?o0000okF`
e?ne/=@00ol00005ok:df`03o`000?nc[M;o000000;o00001on`/MT00ol0003o[[3Jojj`fP08ojj`
fP;o00002?nZ/Md00ol0003oZ:gKojR]f`03o`0000GoYkKT00?o0000ojBdi?nT]>@01Ol00003oj>o
k@03o`000?nQ`>ooXL3_00Go00000onMcOT00ol0003oVm7koi_An`03o`0000?oS]on0ol000000om_
gnOooo]ZoookJP1HoookJPCo0000IOoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z
02Kooo]Z0ol000000olPZ]Oo0000ob2Ze`05ob2Ze`?o00002_li^^D3o`0000CoA<;X3_l0001Zoook
JPCo0000P_oonfX007Gooo]Z0_l0000boookJP03o`1]_Ol0003o000000Go00001?n=`oT00ol0003o
Yl;]ojO2k@03ojO2k@?o00000onO`o800ol0003o/KcRok6lhP05o`0000?o[;oW00Co0000okFefOl0
003o00002?na^Ml2o`0000Wo/[CK00?o0000ok2afOn`/MT01?n`/MT3o`000003ojfghOl0003o[[3J
00Go[[3J0ol000000on[]n;o0000ojZag@09ojZag@;o00002OnW]^@2o`0000WoXko]0_l00009oig=
n@;o00000_n>goh4o`000003ofoOiooonf[ooo]Z05Kooo]Z1Ol0001ZoookJP;o0000A?oonfX00ol0
003ooo]ZoookJP2ioookJPCo0000Q_oonfX007Oooo]Z00?o0000oookJ_oonfX0<ooonfX6o`0000Co
O/7l0_l00009oio3lP;o00002On/_nL00ol0003o/KWOok6ig`04ok6ig`?o000000?o[;gWo`000?nb
]=/01Onb]=/3o`0000;o[[[R00?o0000ok2afOn`/MT00ol00005ojfgh@03o`000?n^/=[o[[3J00?o
00001On[]n800ol0003oZ[7MojZag@05o`0000?oZ;[V00?o0000ojNfi?nW]^@01Ol00003ojC1kP03
o`000?nS_ngoXko]00Go00000onNc?P00ol0003oWLgioig=n@05o`0000CoTM_o0ol000000om_gnOo
oo]ZoookJP1EoookJPCo0000LOoonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z0;Go
oo]Z1?l0002:oookJP00N?oonfX00ol0003ooo]ZoookJP0eoookJP?o00001_l[ZN/00ol0003oWl?b
oio3lP04o`0000CoTlGh00?o0000ojboion/_nL01?l00004ojG2kP03o`000?na^Moo000000;o0000
1On/_NL00ol0003o/[CKok:df`03o`0000Ko[[[R0_l00009ojfgh@;o00002On[]n82o`0000WoZ;[V
0_l00009ojC1kP;o00002OnNc?P2o`0000CoTM_o0ol000000omeg_?o0000oookJP1EoookJPGo0000
M_oonfX2o`00047ooo]Z00?o0000oookJ_oonfX0/OoonfX4o`0008kooo]Z001ioookJP;o0000>?oo
nfX5o`0000;o:jW[0_l00009oi?5n0;o00002OnU`^h00ol0003o[;gWojbmi`07ojbmi`;o00001On^
^^83o`0000;oZ;o[00?o0000ojfghOn]]n400on]]n43o`0000;oZ;kZ00?o0000oj^gh_n[]n800on[
]n83o`0000;oY/3/00?o0000ojRji_nX^^H00onX^^H3o`0000?oXlGa00?o0000ojC1k_nT`Nh01?l0
0003oic=n@03o`000?nNc?SoW/ch00Go00001?n@fOl2o`000004ogGNlol0003o0000o`0005Gooo]Z
1?l0001moookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX0[OoonfX4o`0009;ooo]Z
001koookJP03o`000?oonf[ooo]Z03Wooo]Z2_l00005oh;5o@03o`000?nU`^koYL;^00Go00000onJ
a_H00ol0003o[;gWojbmi`04o`0000CoY<;_00?o0000ojjjh_l000000_l00006ojRoj`03o`000?n]
]n7o000000;o00001_nX_^X00ol0003oZkORo`000002o`0000KoY/3/00?o0000ojRji_l000000_l0
0007oj?5l@;o00002?nLcOT2o`0000CoT=Wo0ol00002ofOHk`;o0000EOoonfX4o`0008;ooo]Z00?o
0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP2YoookJPCo0000U_oonfX007cooo]Z0_l0000k
oookJP04o`000?oonf[ooo]ZoookJPKo00001?n2aOd2o`0000WoV/Kf0_l00009ojC2k`03o`000?nX
_n_oZ;o[00SoZ;o[00?o0000ojRnj_nX_^X02?nX_^X00ol0003oY/3/ojK0k008ojK0k003o`000?nS
aO7oXlGa00?oXlGa0ol00003oiSAo003o`000?nLcOWoW<gi00Co00001On;fOl2o`000004ofOHkol0
003o0000o`0005Cooo]Z1Ol00027oookJP;o0000?OoonfX00ol0003ooo]ZoookJP2ToookJPGo0000
V_oonfX007kooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP05oookJPGo00001?lM
Y=h4o`0000GoRLSm00?o0000ojC2konT`^l01Ol00003oiS8n003o`000?nX_n_oZ;o[00Go00000onN
ao@00ol0003oZ;kZojRnjP05o`0000?oWlOd00?o0000ojK0k?nV`>`01Ol00004oig:m`;o00002OnH
dO`2o`0000CoRmWo0ol000000om?c>;o<[[9o`@0001EoookJPCo0000S_oonfX00ol0003ooo]Zoook
JP0ioookJP03o`000?oonf[ooo]Z0:7ooo]Z1?l0002OoookJP00OooonfX2o`0003Sooo]Z00?o0000
oookJ_oonfX02ooonfX00om1003o0000o`000006o`0000CoRLSm0_l00009oiS8n0;o00002OnNao@2
o`0000WoWlOd0_l00004oig:m`?o00000on;e?l00ol0003oV=7loiSAo005o`0000CoOMSn0_l00000
0om?c>;o<[[9o`@0001EoookJPGo0000TooonfX2o`0003Wooo]Z00?o0000oookJ_oonfX0WOoonfX4
o`000:?ooo]Z0021oookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX04?oonfX00olb
003o0000o`000004o`0000Co8j[N1?l00007oh?<o`Co00001_n=c_d5o`0000KoSm3n0_l00009oh_D
o`;o00001?mmf?h3o`0005Sooo]Z1?l0002JoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oook
J_oonfX0VOoonfX4o`000:Oooo]Z0022oookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oo
nfX06?oonfX2od0000So00001_lAX<`4o`0000Oo;;?L1?l00006ocNkh0Go000000?o=K_Io`000?l0
0000GOoonfX5o`0009oooo]Z0_l0000foookJP03o`000?oonf[ooo]Z09Gooo]Z1?l0002[oookJP00
PooonfX2o`0003Cooo]Z00?o0000oookJ_oonfX0W_oonfX4o`000:Kooo]Z00?o0000oookJ_oonfX0
<ooonfX00ol0003ooo]ZoookJP2AoookJPCo0000[ooonfX008Gooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP2IoookJPGo0000ZooonfX00ol0003ooo]ZoookJP0boookJP03o`000?oo
nf[ooo]Z08gooo]Z1?l0002coookJP00Q_oonfX2o`00037ooo]Z00?o0000oookJ_oonfX0UOoonfX4
o`000;7ooo]Z0_l0000boookJP03o`000?oonf[ooo]Z08Wooo]Z1?l0002goookJP00R?oonfX00ol0
003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z097ooo]Z1?l0002goookJP03o`000?oonf[ooo]Z
02oooo]Z00?o0000oookJ_oonfX0QOoonfX4o`000;_ooo]Z0029oookJP;o0000;_oonfX00ol0003o
oo]ZoookJP2<oookJPGo0000_?oonfX2o`0002oooo]Z00?o0000oookJ_oonfX0POoonfX4o`000;oo
oo]Z002;oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0R?oonfX4o`000<?ooo]Z
00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1loookJPGo0000`ooonfX008cooo]Z00?o
0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP23oookJPGo0000b?oonfX00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z07Sooo]Z1?l00038oookJP00SOoonfX2o`0002[ooo]Z00?o0000
oookJ_oonfX0OooonfX4o`000<kooo]Z0_l0000[oookJP03o`000?oonf[ooo]Z07Cooo]Z1?l0003<
oookJP00SooonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07[ooo]Z1Ol0003Doook
JP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0L?oonfX4o`000=3ooo]Z002@oookJP;o
00009ooonfX00ol0003ooo]ZoookJP1foookJPCo0000f_oonfX2o`0002Sooo]Z00?o0000oookJ_oo
nfX0K?oonfX4o`000=Cooo]Z002BoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
L_oonfX4o`000>3ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP1XoookJPCo0000
f?oonfX009?ooo]Z0_l0000ToookJP03o`000?oonf[ooo]Z06gooo]Z1Ol0003UoookJP;o00009Ooo
nfX00ol0003ooo]ZoookJP1ToookJPCo0000g?oonfX009Gooo]Z00?o0000oookJ_oonfX08OoonfX0
0ol0003ooo]ZoookJP1YoookJPCo0000k?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[o
oo]Z063ooo]Z1?l0003PoookJP00U_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z
06Cooo]Z1Ol0003aoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0GOoonfX4o`00
0>Cooo]Z002GoookJP;o00008?oonfX00ol0003ooo]ZoookJP1PoookJPCo0000mooonfX2o`00023o
oo]Z00?o0000oookJ_oonfX0F?oonfX5o`000>Sooo]Z002IoookJP03o`000?oonf[ooo]Z01gooo]Z
00?o0000oookJ_oonfX0FooonfX5o`000?gooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]Z
oookJP1DoookJPCo0000kOoonfX009[ooo]Z0_l0000MoookJP03o`000?oonf[ooo]Z05Oooo]Z1?l0
003ooookJPCooo]Z0_l0000MoookJP03o`000?oonf[ooo]Z053ooo]Z1?l0003aoookJP00W?oonfX0
0ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z05?ooo]Z1?l0003ooookJP[ooo]Z00?o0000
oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP1<oookJPCo0000mOoonfX009gooo]Z0_l0000Joook
JP03o`000?oonf[ooo]Z04kooo]Z1Ol0003ooookJPoooo]Z0_l0000JoookJP03o`000?oonf[ooo]Z
04Sooo]Z1?l0003ioookJP00WooonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z04[o
oo]Z1?l0003ooookJQKooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP14oookJPCo
0000oOoonfX00:3ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP15oookJPGo0000
oooonfXKoookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000?oooo]Z
0_oonfX00:7ooo]Z0_l0000FoookJP03o`000?oonf[ooo]Z047ooo]Z1?l0003ooookJR7ooo]Z0_l0
000FoookJP03o`000?oonf[ooo]Z03cooo]Z1?l0003ooookJPKooo]Z002SoookJP03o`000?oonf[o
oo]Z01?ooo]Z00?o0000oookJ_oonfX0??oonfX5o`000?oooo]Z9ooonfX00ol0003ooo]ZoookJP0C
oookJP03o`000?oonf[ooo]Z03Sooo]Z1?l0003ooookJP[ooo]Z002ToookJP;o00004_oonfX00ol0
003ooo]ZoookJP0ioookJPCo0000oooonfX]oookJP;o00004ooonfX00ol0003ooo]ZoookJP0coook
JPGo0000oooonfX>oookJP00Y_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z03Co
oo]Z1Ol0003ooookJS?ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0_oookJPCo
0000oooonfXCoookJP00YooonfX2o`0000oooo]Z00?o0000oookJ_oonfX0<?oonfX4o`000?oooo]Z
>OoonfX2o`00013ooo]Z00?o0000oookJ_oonfX0:ooonfX4o`000?oooo]Z5ooonfX00:Wooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0/oookJPCo0000oooonfXooookJP03o`000?oo
nf[ooo]Z00gooo]Z00?o0000oookJ_oonfX09ooonfX4o`000?oooo]Z6ooonfX00:[ooo]Z00?o0000
oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0WoookJPGo0000oooonfY4oookJP03o`000?oonf[o
oo]Z00cooo]Z00?o0000oookJ_oonfX08ooonfX4o`000?oooo]Z7ooonfX00:_ooo]Z0_l0000;oook
JP03o`000?oonf[ooo]Z02?ooo]Z1?l0003ooookJT[ooo]Z0_l0000<oookJP03o`000?oonf[ooo]Z
01oooo]Z1?l0003ooookJR?ooo]Z002]oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oo
nfX07_oonfX5o`000?oooo]ZD?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01_o
oo]Z1?l0003ooookJROooo]Z002^oookJP;o00002?oonfX00ol0003ooo]ZoookJP0JoookJPCo0000
oooonfYFoookJP;o00002?oonfX00ol0003ooo]ZoookJP0HoookJPCo0000oooonfX[oookJP00/?oo
nfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Gooo]Z1Ol0003ooookJUcooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0DoookJPCo0000oooonfX_oookJP00/OoonfX2
o`0000Gooo]Z00?o0000oookJ_oonfX04OoonfX4o`000?oooo]ZH_oonfX2o`0000Gooo]Z00?o0000
oookJ_oonfX03ooonfX5o`000?oooo]Z<ooonfX00;?ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0
003ooo]ZoookJP0=oookJPCo0000oooonfYXoookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oook
J_oonfX02ooonfX4o`000?oooo]Z>?oonfX00;Cooo]Z00Go0000oookJ_oonf[ooo]Zo`00000:oook
JPGo0000oooonfY]oookJP05o`000?oonf[ooo]ZoookJ_l000002OoonfX4o`000?oooo]Z??oonfX0
0;Gooo]Z0_l000000ooonf[o0000oookJP05oookJPCo0000oooonfYcoookJP;o000000?ooo]Zo`00
0?oonfX01?oonfX4o`000?oooo]Z@?oonfX00;Oooo]Z0_l000000ooonf[o0000o`000003o`000?oo
oo]ZNOoonfX2o`000003oookJ_l0003o000000;o0000oooonfY4oookJP00^?oonfX2o`000?oooo]Z
OooonfX2o`000?oooo]ZB?oonfX00?oooo]Zoooonf[ooookJXCooo]Z003ooookJ_oooo]ZoooonfZ4
oookJP00oooonf[ooookJ_oooo]ZQ?oonfX00?oooo]Zoooonf[ooookJXCooo]Z003ooookJ_oooo]Z
oooonfZ4oookJP00oooonf[ooookJ_oooo]ZQ?oonfX00?oooo]Zoooonf[ooookJXCooo]Z003ooook
J_oooo]ZoooonfZ4oookJP00oooonf[ooookJ_oooo]ZQ?oonfX00?oooo]Zoooonf[ooookJXCooo]Z
003ooookJ_oooo]ZoooonfZ4oookJP00\
\>"],
  ImageRangeCache->{{{0, 896.938}, {463.25, 0}} -> {-0.051048, -0.0258552, \
0.00234364, 0.00234364}, {{21.75, 428.125}, {452.188, 11}} -> {0.00279835, \
-0.023347, 0.00211004, 0.00211004}, {{468.75, 875.125}, {452.188, 11}} -> \
{-0.98841, -0.0245443, 0.00221825, 0.00221825}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["I am not sure why I am only getting the top half here...", \
"Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(H31m1 = \ HAtomShow[3, 1, \(-1\), 0.8]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .34074 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00811284 0.47619 [
[ 0 0 0 0 ]
[ 1 .34074 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .34074 L
0 .34074 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00811284 0.477324 0.332627 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.27298e-16 1.049 -0.115465 1.049 [
[ 0 0 0 0 ]
[ 1 .71555 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01972 .25737 m
0 .38187 L
s
0 .38187 m
.3974 .71555 L
s
.3974 .71555 m
.40133 .60286 L
s
.40133 .60286 m
.01972 .25737 L
s
.69411 0 m
.98374 .43282 L
s
.98374 .43282 m
1 .5519 L
s
1 .5519 m
.70165 .13026 L
s
.70165 .13026 m
.69411 0 L
s
.01972 .25737 m
0 .38187 L
s
0 .38187 m
.70165 .13026 L
s
.70165 .13026 m
.69411 0 L
s
.69411 0 m
.01972 .25737 L
s
.40133 .60286 m
.98374 .43282 L
s
.98374 .43282 m
1 .5519 L
s
1 .5519 m
.3974 .71555 L
s
.3974 .71555 m
.40133 .60286 L
s
0 0 m
1 0 L
1 .71555 L
0 .71555 L
closepath
clip
newpath
.5 Mabswid
.688 .446 .551 r
.53088 .5375 m .54433 .53734 L .54398 .55028 L p F P
0 g
s
.688 .446 .551 r
.54398 .55028 m .53248 .55041 L .53088 .5375 L p F P
0 g
s
.693 .45 .551 r
.50827 .53746 m .53088 .5375 L .53248 .55041 L p F P
0 g
s
.693 .45 .551 r
.53248 .55041 m .50774 .55037 L .50827 .53746 L p F P
0 g
s
.713 .467 .551 r
.49913 .53701 m .50827 .53746 L .50774 .55037 L p F P
0 g
s
.666 .428 .55 r
.54433 .53734 m .57047 .53567 L .57269 .54846 L p F P
0 g
s
.666 .428 .55 r
.57269 .54846 m .54398 .55028 L .54433 .53734 L p F P
0 g
s
.713 .467 .551 r
.50774 .55037 m .50032 .55001 L .49913 .53701 L p F P
0 g
s
.719 .472 .55 r
.47179 .53518 m .49913 .53701 L .50032 .55001 L p F P
0 g
s
.662 .425 .551 r
.57047 .53567 m .57837 .53509 L .57818 .54806 L p F P
0 g
s
.662 .425 .551 r
.57818 .54806 m .57269 .54846 L .57047 .53567 L p F P
0 g
s
.719 .472 .55 r
.50032 .55001 m .47287 .54819 L .47179 .53518 L p F P
0 g
s
.726 .477 .549 r
.46957 .535 m .47179 .53518 L .47287 .54819 L p F P
0 g
s
.638 .406 .55 r
.57818 .54806 m .57837 .53509 L .6107 .5309 L p F P
0 g
s
.726 .477 .549 r
.47287 .54819 m .46881 .54785 L .46957 .535 L p F P
0 g
s
.744 .492 .55 r
.4482 .5322 m .46957 .535 L .46881 .54785 L p F P
0 g
s
.744 .492 .55 r
.46881 .54785 m .44899 .54528 L .4482 .5322 L p F P
0 g
s
.752 .498 .549 r
.4271 .52901 m .4482 .5322 L .44899 .54528 L p F P
0 g
s
.611 .384 .548 r
.61064 .54388 m .6107 .5309 L .63769 .52576 L p F P
0 g
s
.638 .406 .55 r
.6107 .5309 m .61064 .54388 L .57818 .54806 L p F P
0 g
s
.681 .417 .516 r
.53248 .55041 m .54398 .55028 L .54274 .56243 L p F P
0 g
s
.681 .417 .516 r
.54274 .56243 m .5373 .5625 L .53248 .55041 L p F P
0 g
s
.686 .419 .513 r
.50774 .55037 m .53248 .55041 L .5373 .5625 L p F P
0 g
s
.686 .419 .513 r
.5373 .5625 m .50624 .56245 L .50774 .55037 L p F P
0 g
s
.708 .439 .516 r
.50032 .55001 m .50774 .55037 L .50624 .56245 L p F P
0 g
s
.657 .396 .513 r
.54274 .56243 m .54398 .55028 L .57269 .54846 L p F P
0 g
s
.708 .439 .516 r
.50624 .56245 m .50413 .56234 L .50032 .55001 L p F P
0 g
s
.714 .442 .513 r
.47287 .54819 m .50032 .55001 L .50413 .56234 L p F P
0 g
s
.752 .498 .549 r
.42635 .53883 m .4271 .52901 L p .44899 .54528 L F P
0 g
s
.767 .512 .549 r
.42635 .53883 m .42593 .52879 L .4271 .52901 L closepath p F P
0 g
s
.775 .519 .548 r
.42593 .52879 m .42635 .53883 L .42611 .54184 L p F P
0 g
s
.775 .519 .548 r
.4063 .52452 m .42593 .52879 L p .42611 .54184 L F P
0 g
s
.653 .395 .515 r
.57743 .55716 m .57269 .54846 L .57818 .54806 L closepath p F P
0 g
s
.657 .396 .513 r
.57269 .54846 m .57743 .55716 L p .54274 .56243 L F P
0 g
s
.714 .442 .513 r
.50413 .56234 m .47657 .56053 L .47287 .54819 L p F P
0 g
s
.721 .446 .51 r
.46881 .54785 m .47287 .54819 L .47657 .56053 L p F P
0 g
s
.627 .371 .511 r
.57818 .54806 m .61064 .54388 L .60978 .55612 L p F P
0 g
s
.627 .371 .511 r
.57743 .55716 m .57818 .54806 L p .60978 .55612 L F P
0 g
s
.721 .446 .51 r
.47657 .56053 m .46693 .55973 L .46881 .54785 L p F P
0 g
s
.741 .465 .513 r
.44899 .54528 m .46881 .54785 L .46693 .55973 L p F P
0 g
s
.61 .383 .549 r
.64172 .53496 m .63769 .52576 L .64166 .52499 L closepath p F P
0 g
s
.611 .384 .548 r
.63769 .52576 m .64172 .53496 L p .61064 .54388 L F P
0 g
s
.741 .465 .513 r
.46693 .55973 m .45198 .55781 L .44899 .54528 L p F P
0 g
s
.748 .47 .509 r
.42652 .54191 m .44899 .54528 L .45198 .55781 L p F P
0 g
s
.752 .498 .549 r
.44899 .54528 m .42652 .54191 L .42635 .53883 L p F P
0 g
s
.581 .361 .546 r
.64166 .52499 m .6713 .51731 L .67151 .53037 L p F P
0 g
s
.581 .361 .546 r
.64172 .53496 m .64166 .52499 L p .67151 .53037 L F P
0 g
s
.775 .519 .548 r
.42611 .54184 m .40678 .53767 L .4063 .52452 L p F P
0 g
s
.784 .526 .546 r
.3875 .51994 m .4063 .52452 L .40678 .53767 L p F P
0 g
s
.598 .347 .508 r
.60978 .55612 m .61064 .54388 L .64174 .53801 L p F P
0 g
s
.611 .384 .548 r
.64172 .53496 m .64174 .53801 L .61064 .54388 L p F P
0 g
s
.759 .504 .547 r
.42652 .54191 m .42611 .54184 L .42635 .53883 L closepath p F P
0 g
s
.672 .382 .474 r
.5416 .56842 m .5373 .5625 L .54274 .56243 L closepath p F P
0 g
s
.676 .381 .465 r
.5373 .5625 m .5416 .56842 L .54048 .5737 L p F P
0 g
s
.676 .381 .465 r
.50624 .56245 m .5373 .5625 L p .54048 .5737 L F P
0 g
s
.676 .381 .465 r
.50566 .56511 m .50624 .56245 L p .54048 .5737 L F P
0 g
s
.7 .406 .475 r
.50566 .56511 m .50413 .56234 L .50624 .56245 L closepath p F P
0 g
s
.644 .355 .464 r
.54274 .56243 m .57715 .56027 L .57513 .5716 L p F P
0 g
s
.644 .355 .464 r
.5416 .56842 m .54274 .56243 L p .57513 .5716 L F P
0 g
s
.657 .396 .513 r
.57743 .55716 m .57715 .56027 L .54274 .56243 L p F P
0 g
s
.706 .406 .466 r
.50413 .56234 m .50566 .56511 L .5036 .57352 L p F P
0 g
s
.706 .406 .466 r
.47657 .56053 m .50413 .56234 L p .5036 .57352 L F P
0 g
s
.627 .371 .511 r
.60978 .55612 m .57973 .55996 L .57743 .55716 L p F P
0 g
s
.63 .372 .508 r
.57973 .55996 m .57715 .56027 L .57743 .55716 L closepath p F P
0 g
s
.748 .47 .509 r
.45198 .55781 m .42943 .55444 L .42652 .54191 L p F P
0 g
s
.756 .474 .506 r
.42611 .54184 m .42652 .54191 L .42943 .55444 L p F P
0 g
s
.756 .474 .506 r
.42943 .55444 m .42374 .55347 L .42611 .54184 L p F P
0 g
s
.774 .492 .509 r
.40678 .53767 m .42611 .54184 L .42374 .55347 L p F P
0 g
s
.706 .406 .466 r
.5036 .57352 m .48306 .57217 L .47657 .56053 L p F P
0 g
s
.713 .408 .461 r
.46693 .55973 m .47657 .56053 L .48306 .57217 L p F P
0 g
s
.676 .381 .465 r
.54048 .5737 m .5119 .57365 L .50566 .56511 L p F P
0 g
s
.681 .381 .459 r
.5119 .57365 m .5036 .57352 L .50566 .56511 L closepath p F P
0 g
s
.615 .328 .459 r
.57715 .56027 m .57973 .55996 L .59489 .56926 L p F P
0 g
s
.615 .328 .459 r
.59489 .56926 m .57513 .5716 L .57715 .56027 L p F P
0 g
s
.613 .331 .465 r
.57973 .55996 m .60978 .55612 L .60806 .56759 L p F P
0 g
s
.613 .331 .465 r
.60806 .56759 m .59489 .56926 L .57973 .55996 L p F P
0 g
s
.784 .526 .546 r
.40678 .53767 m .3879 .53311 L .3875 .51994 L p F P
0 g
s
.793 .533 .544 r
.37853 .51752 m .3875 .51994 L .3879 .53311 L p F P
0 g
s
.713 .408 .461 r
.48306 .57217 m .46384 .5706 L .46693 .55973 L p F P
0 g
s
.734 .431 .467 r
.45198 .55781 m .46693 .55973 L .46384 .5706 L p F P
0 g
s
.581 .361 .546 r
.67151 .53037 m .64525 .53712 L .64172 .53496 L p F P
0 g
s
.582 .36 .545 r
.64525 .53712 m .64174 .53801 L .64172 .53496 L closepath p F P
0 g
s
.565 .319 .503 r
.64101 .55027 m .64174 .53801 L .64525 .53712 L p F P
0 g
s
.598 .347 .508 r
.64174 .53801 m .64101 .55027 L .60978 .55612 L p F P
0 g
s
.644 .355 .464 r
.57513 .5716 m .5467 .57338 L .5416 .56842 L p F P
0 g
s
.648 .354 .458 r
.5467 .57338 m .54048 .5737 L .5416 .56842 L closepath p F P
0 g
s
.734 .431 .467 r
.46384 .5706 m .45731 .56977 L .45198 .55781 L p F P
0 g
s
.742 .434 .46 r
.42943 .55444 m .45198 .55781 L .45731 .56977 L p F P
0 g
s
.774 .492 .509 r
.42374 .55347 m .40916 .55035 L .40678 .53767 L p F P
0 g
s
.783 .498 .505 r
.3879 .53311 m .40678 .53767 L .40916 .55035 L p F P
0 g
s
.793 .533 .544 r
.3879 .53311 m .37716 .53023 L .37853 .51752 L p F P
0 g
s
.806 .546 .544 r
.37004 .5149 m .37853 .51752 L .37716 .53023 L p F P
0 g
s
.549 .336 .543 r
.69979 .50794 m .6713 .51731 L .67151 .53037 L p F P
0 g
s
.566 .323 .507 r
.67121 .53753 m .64525 .53712 L .67151 .53037 L closepath p F P
0 g
s
.565 .319 .503 r
.64525 .53712 m .67121 .53753 L p .64101 .55027 L F P
0 g
s
.58 .301 .458 r
.60806 .56759 m .60978 .55612 L .64101 .55027 L p F P
0 g
s
.806 .546 .544 r
.37716 .53023 m .37026 .52811 L .37004 .5149 L p F P
0 g
s
.816 .554 .542 r
.35389 .50937 m .37004 .5149 L .37026 .52811 L p F P
0 g
s
.742 .434 .46 r
.45731 .56977 m .4347 .5664 L .42943 .55444 L p F P
0 g
s
.75 .437 .454 r
.42374 .55347 m .42943 .55444 L .4347 .5664 L p F P
0 g
s
.63 .3 .394 r
.54048 .5737 m .5467 .57338 L .56225 .58265 L p F P
0 g
s
.63 .3 .394 r
.56225 .58265 m .53704 .58393 L .54048 .5737 L p F P
0 g
s
.661 .332 .406 r
.5119 .57365 m .54048 .5737 L .53704 .58393 L p F P
0 g
s
.661 .332 .406 r
.53704 .58393 m .5238 .58391 L .5119 .57365 L p F P
0 g
s
.665 .33 .396 r
.5036 .57352 m .5119 .57365 L .5238 .58391 L p F P
0 g
s
.665 .33 .396 r
.5238 .58391 m .4997 .58354 L .5036 .57352 L p F P
0 g
s
.694 .36 .407 r
.48306 .57217 m .5036 .57352 L .4997 .58354 L p F P
0 g
s
.75 .437 .454 r
.4347 .5664 m .41993 .56391 L .42374 .55347 L p F P
0 g
s
.769 .459 .461 r
.40916 .55035 m .42374 .55347 L .41993 .56391 L p F P
0 g
s
.627 .305 .406 r
.5467 .57338 m .57513 .5716 L .5721 .58204 L p F P
0 g
s
.627 .305 .406 r
.5721 .58204 m .56225 .58265 L .5467 .57338 L p F P
0 g
s
.783 .498 .505 r
.40916 .55035 m .39022 .5458 L .3879 .53311 L p F P
0 g
s
.792 .504 .501 r
.37716 .53023 m .3879 .53311 L .39022 .5458 L p F P
0 g
s
.694 .36 .407 r
.4997 .58354 m .4926 .58307 L .48306 .57217 L p F P
0 g
s
.698 .353 .389 r
.46384 .5706 m .48306 .57217 L .4926 .58307 L p F P
0 g
s
.593 .272 .394 r
.5721 .58204 m .57513 .5716 L .59489 .56926 L p F P
0 g
s
.698 .353 .389 r
.4615 .57592 m .46384 .5706 L p .4926 .58307 L F P
0 g
s
.725 .39 .412 r
.4615 .57592 m .45731 .56977 L .46384 .5706 L closepath p F P
0 g
s
.531 .294 .501 r
.67121 .53753 m .69672 .52214 L .67151 .53037 L closepath p F P
0 g
s
.549 .336 .543 r
.70005 .51795 m .69979 .50794 L p .67151 .53037 L F P
0 g
s
.549 .336 .543 r
.67151 .53037 m .69672 .52214 L .70005 .51795 L p F P
0 g
s
.769 .459 .461 r
.41993 .56391 m .41355 .56255 L .40916 .55035 L p F P
0 g
s
.779 .463 .453 r
.39022 .5458 m .40916 .55035 L .41355 .56255 L p F P
0 g
s
.792 .504 .501 r
.39022 .5458 m .37413 .54153 L .37716 .53023 L p F P
0 g
s
.806 .52 .504 r
.37026 .52811 m .37716 .53023 L .37413 .54153 L p F P
0 g
s
.543 .269 .449 r
.63945 .56174 m .64101 .55027 L .67095 .54269 L p F P
0 g
s
.565 .319 .503 r
.67121 .53753 m .67095 .54269 L .64101 .55027 L p F P
0 g
s
.58 .301 .458 r
.64101 .55027 m .63945 .56174 L .60806 .56759 L p F P
0 g
s
.732 .387 .396 r
.45731 .56977 m .4615 .57592 L .45928 .58022 L p F P
0 g
s
.732 .387 .396 r
.4347 .5664 m .45731 .56977 L p .45928 .58022 L F P
0 g
s
.816 .554 .542 r
.37026 .52811 m .35405 .52261 L .35389 .50937 L p F P
0 g
s
.827 .563 .54 r
.33846 .50356 m .35389 .50937 L .35405 .52261 L p F P
0 g
s
.593 .281 .409 r
.60665 .57337 m .59489 .56926 L .60806 .56759 L closepath p F P
0 g
s
.593 .272 .394 r
.59489 .56926 m .60665 .57337 L p .5721 .58204 L F P
0 g
s
.806 .52 .504 r
.37413 .54153 m .37216 .54093 L .37026 .52811 L p F P
0 g
s
.817 .527 .499 r
.35405 .52261 m .37026 .52811 L .37216 .54093 L p F P
0 g
s
.515 .309 .539 r
.70005 .51795 m .70329 .50652 L .69979 .50794 L closepath p F P
0 g
s
.553 .239 .39 r
.60806 .56759 m .63945 .56174 L .63695 .57237 L p F P
0 g
s
.553 .239 .39 r
.60665 .57337 m .60806 .56759 L p .63695 .57237 L F P
0 g
s
.511 .305 .538 r
.70329 .50652 m .72712 .49669 L p .70012 .52102 L F P
0 g
s
.511 .305 .538 r
.70012 .52102 m .70005 .51795 L .70329 .50652 L p F P
0 g
s
.732 .387 .396 r
.45928 .58022 m .44255 .57772 L .4347 .5664 L p F P
0 g
s
.737 .381 .377 r
.41993 .56391 m .4347 .5664 L .44255 .57772 L p F P
0 g
s
.527 .288 .496 r
.67095 .54269 m .67121 .53753 L .69672 .52214 L p F P
0 g
s
.779 .463 .453 r
.41355 .56255 m .39456 .558 L .39022 .5458 L p F P
0 g
s
.788 .466 .444 r
.37413 .54153 m .39022 .5458 L .39456 .558 L p F P
0 g
s
.698 .353 .389 r
.4926 .58307 m .46598 .58088 L .4615 .57592 L p F P
0 g
s
.703 .352 .378 r
.46598 .58088 m .45928 .58022 L .4615 .57592 L closepath p F P
0 g
s
.827 .563 .54 r
.35405 .52261 m .33856 .51682 L .33846 .50356 L p F P
0 g
s
.838 .572 .537 r
.32371 .49746 m .33846 .50356 L .33856 .51682 L p F P
0 g
s
.737 .381 .377 r
.41706 .56888 m .41993 .56391 L p .44255 .57772 L F P
0 g
s
.761 .418 .403 r
.41706 .56888 m .41355 .56255 L .41993 .56391 L closepath p F P
0 g
s
.591 .208 .285 r
.53704 .58393 m .56225 .58265 L p .56767 .59123 L F P
0 g
s
.591 .208 .285 r
.53406 .58987 m .53704 .58393 L p .56767 .59123 L F P
0 g
s
.638 .271 .331 r
.53406 .58987 m .5238 .58391 L .53704 .58393 L closepath p F P
0 g
s
.633 .244 .289 r
.5238 .58391 m .53406 .58987 L .53216 .59292 L p F P
0 g
s
.633 .244 .289 r
.4997 .58354 m .5238 .58391 L p .53216 .59292 L F P
0 g
s
.633 .244 .289 r
.49765 .58713 m .4997 .58354 L p .53216 .59292 L F P
0 g
s
.675 .305 .336 r
.49765 .58713 m .4926 .58307 L .4997 .58354 L closepath p F P
0 g
s
.548 .334 .542 r
.69672 .52214 m .70012 .52102 L .70005 .51795 L closepath p F P
0 g
s
.675 .285 .301 r
.4926 .58307 m .49765 .58713 L .49414 .59211 L p F P
0 g
s
.675 .285 .301 r
.46598 .58088 m .4926 .58307 L p .49414 .59211 L F P
0 g
s
.817 .527 .499 r
.37216 .54093 m .35589 .53545 L .35405 .52261 L p F P
0 g
s
.828 .535 .494 r
.33856 .51682 m .35405 .52261 L .35589 .53545 L p F P
0 g
s
.501 .233 .44 r
.66953 .55417 m .67095 .54269 L .69966 .53332 L p F P
0 g
s
.527 .288 .496 r
.70012 .52102 m .69966 .53332 L .67095 .54269 L p F P
0 g
s
.527 .288 .496 r
.69672 .52214 m .70012 .52102 L p .67095 .54269 L F P
0 g
s
.543 .269 .449 r
.67095 .54269 m .66953 .55417 L .63945 .56174 L p F P
0 g
s
.77 .416 .386 r
.41355 .56255 m .41706 .56888 L .41431 .57283 L p F P
0 g
s
.77 .416 .386 r
.39456 .558 m .41355 .56255 L p .41431 .57283 L F P
0 g
s
.603 .244 .334 r
.57047 .58586 m .56225 .58265 L .5721 .58204 L closepath p F P
0 g
s
.591 .208 .285 r
.56225 .58265 m .57047 .58586 L .56767 .59123 L p F P
0 g
s
.553 .239 .39 r
.63695 .57237 m .62388 .5748 L .60665 .57337 L p F P
0 g
s
.55 .227 .374 r
.62388 .5748 m .6053 .57812 L .60665 .57337 L closepath p F P
0 g
s
.593 .272 .394 r
.60665 .57337 m .6053 .57812 L .5721 .58204 L p F P
0 g
s
.554 .184 .295 r
.5721 .58204 m .6053 .57812 L .60126 .58749 L p F P
0 g
s
.554 .184 .295 r
.57047 .58586 m .5721 .58204 L p .60126 .58749 L F P
0 g
s
.513 .204 .38 r
.63695 .57237 m .63945 .56174 L .66953 .55417 L p F P
0 g
s
.788 .466 .444 r
.37301 .54387 m .37413 .54153 L p .39456 .558 L F P
0 g
s
.804 .488 .456 r
.37301 .54387 m .37216 .54093 L .37413 .54153 L closepath p F P
0 g
s
.486 .256 .489 r
.69966 .53332 m .70012 .52102 L .72755 .50979 L p F P
0 g
s
.511 .305 .538 r
.72712 .49669 m .72755 .50979 L .70012 .52102 L p F P
0 g
s
.814 .493 .446 r
.37216 .54093 m .37301 .54387 L .36898 .55103 L p F P
0 g
s
.814 .493 .446 r
.35589 .53545 m .37216 .54093 L p .36898 .55103 L F P
0 g
s
.675 .285 .301 r
.49414 .59211 m .47911 .59085 L .46598 .58088 L p F P
0 g
s
.667 .253 .25 r
.45928 .58022 m .46598 .58088 L .47911 .59085 L p F P
0 g
s
.667 .253 .25 r
.45304 .5881 m .45928 .58022 L p .47911 .59085 L F P
0 g
s
.712 .323 .311 r
.45304 .5881 m .44255 .57772 L .45928 .58022 L closepath p F P
0 g
s
.788 .466 .444 r
.39456 .558 m .37632 .55318 L .37301 .54387 L p F P
0 g
s
.798 .471 .436 r
.37632 .55318 m .36898 .55103 L .37301 .54387 L closepath p F P
0 g
s
.633 .244 .289 r
.53216 .59292 m .5077 .59252 L .49765 .58713 L p F P
0 g
s
.634 .235 .27 r
.5077 .59252 m .49414 .59211 L .49765 .58713 L closepath p F P
0 g
s
.838 .572 .537 r
.33856 .51682 m .32375 .51074 L .32371 .49746 L p F P
0 g
s
.849 .582 .534 r
.31673 .49429 m .32371 .49746 L .32375 .51074 L p F P
0 g
s
.77 .416 .386 r
.41431 .57283 m .40112 .56968 L .39456 .558 L p F P
0 g
s
.779 .416 .37 r
.37632 .55318 m .39456 .558 L .40112 .56968 L p F P
0 g
s
.737 .381 .377 r
.44255 .57772 m .42075 .57405 L .41706 .56888 L p F P
0 g
s
.744 .381 .365 r
.42075 .57405 m .41431 .57283 L .41706 .56888 L closepath p F P
0 g
s
.51 .143 .28 r
.60126 .58749 m .6053 .57812 L .62388 .5748 L p F P
0 g
s
.554 .184 .295 r
.60126 .58749 m .58885 .58896 L .57047 .58586 L p F P
0 g
s
.549 .166 .267 r
.58885 .58896 m .56767 .59123 L .57047 .58586 L closepath p F P
0 g
s
.716 .311 .279 r
.44255 .57772 m .45304 .5881 L .45286 .58827 L p F P
0 g
s
.716 .311 .279 r
.42075 .57405 m .44255 .57772 L p .45286 .58827 L F P
0 g
s
.47 .275 .532 r
.72755 .50979 m .72712 .49669 L .75334 .48351 L p F P
0 g
s
.828 .535 .494 r
.35589 .53545 m .34034 .52967 L .33856 .51682 L p F P
0 g
s
.839 .543 .488 r
.32375 .51074 m .33856 .51682 L .34034 .52967 L p F P
0 g
s
.591 .208 .285 r
.56767 .59123 m .54191 .59255 L .53406 .58987 L p F P
0 g
s
.59 .194 .26 r
.54191 .59255 m .53216 .59292 L .53406 .58987 L closepath p F P
0 g
s
.814 .493 .446 r
.36898 .55103 m .3595 .54786 L .35589 .53545 L p F P
0 g
s
.826 .499 .436 r
.34034 .52967 m .35589 .53545 L .3595 .54786 L p F P
0 g
s
.849 .582 .534 r
.32375 .51074 m .31454 .50659 L .31673 .49429 L p F P
0 g
s
.858 .591 .534 r
.30992 .49097 m .31673 .49429 L .31454 .50659 L p F P
0 g
s
.523 .174 .318 r
.6361 .57483 m .62388 .5748 L .63695 .57237 L closepath p F P
0 g
s
.51 .143 .28 r
.62388 .5748 m .6361 .57483 L p .60126 .58749 L F P
0 g
s
.464 .16 .365 r
.6672 .5648 m .66953 .55417 L .69839 .54482 L p F P
0 g
s
.501 .233 .44 r
.69966 .53332 m .69839 .54482 L .66953 .55417 L p F P
0 g
s
.513 .204 .38 r
.66953 .55417 m .6672 .5648 L .63695 .57237 L p F P
0 g
s
.716 .311 .279 r
.45286 .58827 m .43166 .5846 L .42075 .57405 L p F P
0 g
s
.71 .283 .232 r
.41431 .57283 m .42075 .57405 L .43166 .5846 L p F P
0 g
s
.454 .194 .429 r
.69839 .54482 m .69966 .53332 L .72722 .52213 L p F P
0 g
s
.486 .256 .489 r
.72755 .50979 m .72722 .52213 L .69966 .53332 L p F P
0 g
s
.779 .416 .37 r
.40112 .56968 m .38289 .56483 L .37632 .55318 L p F P
0 g
s
.785 .41 .346 r
.36898 .55103 m .37632 .55318 L .38289 .56483 L p F P
0 g
s
.71 .283 .232 r
.40818 .57842 m .41431 .57283 L p .43166 .5846 L F P
0 g
s
.752 .355 .299 r
.40818 .57842 m .40112 .56968 L .41431 .57283 L closepath p F P
0 g
s
.49 .008 .036 r
.53216 .59292 m .54191 .59255 L p .56136 .59874 L F P
0 g
s
.49 .008 .036 r
.52631 .59927 m .53216 .59292 L p .56136 .59874 L F P
0 g
s
.587 .144 .166 r
.52631 .59927 m .5077 .59252 L .53216 .59292 L closepath p F P
0 g
s
.474 .128 .299 r
.6361 .57483 m .63695 .57237 L .6672 .5648 L p F P
0 g
s
.544 .112 .17 r
.5631 .59717 m .54191 .59255 L .56767 .59123 L closepath p F P
0 g
s
.49 .008 .036 r
.54191 .59255 m .5631 .59717 L .56136 .59874 L p F P
0 g
s
.547 .06 .05 r
.5077 .59252 m .52631 .59927 L .52521 .60007 L p F P
0 g
s
.547 .06 .05 r
.49414 .59211 m .5077 .59252 L p .52521 .60007 L F P
0 g
s
.858 .591 .534 r
.31454 .50659 m .30981 .50431 L .30992 .49097 L p F P
0 g
s
.87 .602 .531 r
.29706 .48411 m .30992 .49097 L .30981 .50431 L p F P
0 g
s
.547 .06 .05 r
.48957 .59645 m .49414 .59211 L p .52521 .60007 L F P
0 g
s
.635 .194 .184 r
.48957 .59645 m .47911 .59085 L .49414 .59211 L closepath p F P
0 g
s
.839 .543 .488 r
.34034 .52967 m .32548 .52361 L .32375 .51074 L p F P
0 g
s
.851 .551 .481 r
.31454 .50659 m .32375 .51074 L .32548 .52361 L p F P
0 g
s
.785 .41 .346 r
.36355 .5567 m .36898 .55103 L p .38289 .56483 L F P
0 g
s
.807 .449 .379 r
.36355 .5567 m .3595 .54786 L .36898 .55103 L closepath p F P
0 g
s
.453 0 .065 r
.56767 .59123 m .58885 .58896 L p .59538 .59517 L F P
0 g
s
.453 0 .065 r
.5631 .59717 m .56767 .59123 L p .59538 .59517 L F P
0 g
s
.44 .219 .48 r
.75389 .49666 m .72755 .50979 L .72722 .52213 L p F P
0 g
s
.47 .275 .532 r
.75334 .48351 m .75389 .49666 L .72755 .50979 L p F P
0 g
s
.616 .141 .102 r
.47911 .59085 m .48957 .59645 L .4862 .59862 L p F P
0 g
s
.616 .141 .102 r
.45338 .58833 m .47911 .59085 L p .4862 .59862 L F P
0 g
s
.667 .253 .25 r
.47911 .59085 m .45338 .58833 L .45304 .5881 L p F P
0 g
s
.826 .499 .436 r
.3595 .54786 m .3439 .54209 L .34034 .52967 L p F P
0 g
s
.837 .505 .425 r
.32548 .52361 m .34034 .52967 L .3439 .54209 L p F P
0 g
s
.474 .128 .299 r
.6672 .5648 m .66573 .56918 L .6361 .57483 L p F P
0 g
s
.45 .081 .245 r
.63315 .58177 m .6361 .57483 L .66573 .56918 L p F P
0 g
s
.51 .143 .28 r
.6361 .57483 m .63315 .58177 L .60126 .58749 L p F P
0 g
s
.758 .344 .265 r
.40112 .56968 m .40818 .57842 L .40625 .57969 L p F P
0 g
s
.758 .344 .265 r
.38289 .56483 m .40112 .56968 L p .40625 .57969 L F P
0 g
s
.51 .098 .195 r
.59978 .5899 m .58885 .58896 L .60126 .58749 L closepath p F P
0 g
s
.453 0 .065 r
.58885 .58896 m .59978 .5899 L .59538 .59517 L p F P
0 g
s
.669 .244 .227 r
.45338 .58833 m .45286 .58827 L .45304 .5881 L closepath p F P
0 g
s
.818 .45 .36 r
.3595 .54786 m .36355 .5567 L .36133 .55844 L p F P
0 g
s
.818 .45 .36 r
.3439 .54209 m .3595 .54786 L p .36133 .55844 L F P
0 g
s
.616 .141 .102 r
.4862 .59862 m .47128 .59706 L .45338 .58833 L p F P
0 g
s
.566 .046 0 r
.45286 .58827 m .45338 .58833 L .47128 .59706 L p F P
0 g
s
.566 .046 0 r
.44456 .59335 m .45286 .58827 L p .47128 .59706 L F P
0 g
s
.671 .206 .141 r
.44456 .59335 m .43166 .5846 L .45286 .58827 L closepath p F P
0 g
s
.851 .551 .481 r
.31084 .51396 m .31454 .50659 L p .32548 .52361 L F P
0 g
s
.86 .565 .487 r
.31084 .51396 m .30981 .50431 L .31454 .50659 L closepath p F P
0 g
s
.454 .04 .163 r
.59978 .5899 m .60126 .58749 L .63315 .58177 L p F P
0 g
s
.87 .602 .531 r
.30981 .50431 m .29689 .49747 L .29706 .48411 L p F P
0 g
s
.882 .613 .526 r
.28483 .47695 m .29706 .48411 L .29689 .49747 L p F P
0 g
s
.873 .574 .48 r
.30981 .50431 m .31084 .51396 L .30935 .51631 L p F P
0 g
s
.873 .574 .48 r
.29689 .49747 m .30981 .50431 L p .30935 .51631 L F P
0 g
s
.408 .11 .344 r
.72609 .53365 m .69839 .54482 L .69622 .55546 L p F P
0 g
s
.454 .194 .429 r
.72722 .52213 m .72609 .53365 L .69839 .54482 L p F P
0 g
s
.464 .16 .365 r
.69839 .54482 m .69622 .55546 L .6672 .5648 L p F P
0 g
s
.425 .241 .526 r
.75919 .47998 m .75334 .48351 L .75389 .49666 L p F P
0 g
s
.758 .344 .265 r
.40625 .57969 m .39202 .57587 L .38289 .56483 L p F P
0 g
s
.762 .333 .233 r
.36532 .55973 m .38289 .56483 L .39202 .57587 L p F P
0 g
s
.785 .41 .346 r
.38289 .56483 m .36532 .55973 L .36355 .5567 L p F P
0 g
s
.417 .073 .273 r
.66573 .56918 m .6672 .5648 L .69622 .55546 L p F P
0 g
s
.837 .505 .425 r
.3439 .54209 m .32901 .53604 L .32548 .52361 L p F P
0 g
s
.849 .511 .414 r
.31128 .51726 m .32548 .52361 L .32901 .53604 L p F P
0 g
s
.851 .551 .481 r
.32548 .52361 m .31128 .51726 L .31084 .51396 L p F P
0 g
s
.656 .161 .062 r
.43166 .5846 m .44456 .59335 L .44344 .59374 L p F P
0 g
s
.656 .161 .062 r
.41064 .58062 m .43166 .5846 L p .44344 .59374 L F P
0 g
s
.71 .283 .232 r
.43166 .5846 m .41064 .58062 L .40818 .57842 L p F P
0 g
s
.454 .04 .163 r
.63315 .58177 m .62941 .58769 L .59978 .5899 L p F P
0 g
s
.401 0 .046 r
.59538 .59517 m .59978 .5899 L .62941 .58769 L p F P
0 g
s
.547 .06 .05 r
.52521 .60007 m .49856 .59919 L .48957 .59645 L p F P
0 g
s
.54 .04 .017 r
.49856 .59919 m .4862 .59862 L .48957 .59645 L closepath p F P
0 g
s
.403 .152 .417 r
.75158 .51007 m .72722 .52213 L .72609 .53365 L p F P
0 g
s
.44 .219 .48 r
.75374 .50586 m .75389 .49666 L p .72722 .52213 L F P
0 g
s
.44 .219 .48 r
.72722 .52213 m .75158 .51007 L .75374 .50586 L p F P
0 g
s
.818 .45 .36 r
.36133 .55844 m .34942 .55405 L .3439 .54209 L p F P
0 g
s
.828 .452 .341 r
.32901 .53604 m .3439 .54209 L .34942 .55405 L p F P
0 g
s
.714 .276 .209 r
.41064 .58062 m .40625 .57969 L .40818 .57842 L closepath p F P
0 g
s
.794 .411 .33 r
.36532 .55973 m .36133 .55844 L .36355 .5567 L closepath p F P
0 g
s
.425 .241 .526 r
.75389 .49666 m .75795 .49423 L .75919 .47998 L p F P
0 g
s
.415 .232 .523 r
.77831 .46804 m .75919 .47998 L .75795 .49423 L p F P
0 g
s
.374 0 .101 r
.62941 .58769 m .63315 .58177 L .66364 .57425 L p F P
0 g
s
.45 .081 .245 r
.66573 .56918 m .66364 .57425 L .63315 .58177 L p F P
0 g
s
.453 0 .065 r
.59538 .59517 m .57346 .59758 L .5631 .59717 L p F P
0 g
s
.427 0 0 r
.57346 .59758 m .56136 .59874 L .5631 .59717 L closepath p F P
0 g
s
.49 .008 .036 r
.56136 .59874 m .53053 .59994 L .52631 .59927 L p F P
0 g
s
.474 0 0 r
.53053 .59994 m .52521 .60007 L .52631 .59927 L closepath p F P
0 g
s
.656 .161 .062 r
.44344 .59374 m .42555 .59014 L .41064 .58062 L p F P
0 g
s
.617 .086 0 r
.40625 .57969 m .41064 .58062 L .42555 .59014 L p F P
0 g
s
.864 .561 .474 r
.31128 .51726 m .30935 .51631 L .31084 .51396 L closepath p F P
0 g
s
.417 .073 .273 r
.69622 .55546 m .69546 .55792 L .66573 .56918 L p F P
0 g
s
.379 .011 .208 r
.66364 .57425 m .66573 .56918 L .69546 .55792 L p F P
0 g
s
.762 .333 .233 r
.39202 .57587 m .37458 .57071 L .36532 .55973 L p F P
0 g
s
.758 .308 .18 r
.36133 .55844 m .36532 .55973 L .37458 .57071 L p F P
0 g
s
.617 .086 0 r
.39933 .5823 m .40625 .57969 L p .42555 .59014 L F P
0 g
s
.718 .249 .133 r
.39933 .5823 m .39202 .57587 L .40625 .57969 L closepath p F P
0 g
s
.18 0 0 r
.52521 .60007 m .53053 .59994 L p .55157 .60303 L F P
0 g
s
.18 0 0 r
.51842 .60315 m .52521 .60007 L p .55157 .60303 L F P
0 g
s
.445 0 0 r
.51842 .60315 m .49856 .59919 L .52521 .60007 L closepath p F P
0 g
s
.392 0 0 r
.55552 .60216 m .53053 .59994 L .56136 .59874 L closepath p F P
0 g
s
.18 0 0 r
.53053 .59994 m .55552 .60216 L .55157 .60303 L p F P
0 g
s
.873 .574 .48 r
.30935 .51631 m .29823 .51046 L .29689 .49747 L p F P
0 g
s
.885 .584 .472 r
.28462 .49034 m .29689 .49747 L .29823 .51046 L p F P
0 g
s
.882 .613 .526 r
.29689 .49747 m .28462 .49034 L .28483 .47695 L p F P
0 g
s
.895 .625 .521 r
.27324 .46949 m .28483 .47695 L .28462 .49034 L p F P
0 g
s
.758 .308 .18 r
.35428 .56144 m .36133 .55844 L p .37458 .57071 L F P
0 g
s
.8 .386 .264 r
.35428 .56144 m .34942 .55405 L .36133 .55844 L closepath p F P
0 g
s
.27 0 0 r
.49856 .59919 m .51842 .60315 L .51435 .60369 L p F P
0 g
s
.27 0 0 r
.4862 .59862 m .49856 .59919 L p .51435 .60369 L F P
0 g
s
.849 .511 .414 r
.32901 .53604 m .31478 .5297 L .31128 .51726 L p F P
0 g
s
.861 .515 .396 r
.30935 .51631 m .31128 .51726 L .31478 .5297 L p F P
0 g
s
.39 .181 .471 r
.75374 .50586 m .75795 .49423 L .75389 .49666 L closepath p F P
0 g
s
.167 0 0 r
.56136 .59874 m .57346 .59758 L p .58643 .59995 L F P
0 g
s
.167 0 0 r
.55552 .60216 m .56136 .59874 L p .58643 .59995 L F P
0 g
s
.27 0 0 r
.48139 .6005 m .4862 .59862 L p .51435 .60369 L F P
0 g
s
.526 0 0 r
.48139 .6005 m .47128 .59706 L .4862 .59862 L closepath p F P
0 g
s
.861 .515 .396 r
.30089 .52194 m .30935 .51631 L p .31478 .5297 L F P
0 g
s
.871 .538 .416 r
.30089 .52194 m .29823 .51046 L .30935 .51631 L closepath p F P
0 g
s
.369 0 0 r
.59257 .59743 m .57346 .59758 L .59538 .59517 L closepath p F P
0 g
s
.167 0 0 r
.57346 .59758 m .59257 .59743 L .58643 .59995 L p F P
0 g
s
.828 .452 .341 r
.34942 .55405 m .33451 .54799 L .32901 .53604 L p F P
0 g
s
.839 .454 .321 r
.31478 .5297 m .32901 .53604 L .33451 .54799 L p F P
0 g
s
.416 0 0 r
.47128 .59706 m .48139 .6005 L .47397 .60134 L p F P
0 g
s
.416 0 0 r
.44657 .59416 m .47128 .59706 L p .47397 .60134 L F P
0 g
s
.566 .046 0 r
.47128 .59706 m .44657 .59416 L .44456 .59335 L p F P
0 g
s
.371 .163 .462 r
.75795 .49423 m .77894 .48122 L p .75367 .50901 L F P
0 g
s
.371 .163 .462 r
.75367 .50901 m .75374 .50586 L .75795 .49423 L p F P
0 g
s
.415 .232 .523 r
.75795 .49423 m .77894 .48122 L .77831 .46804 L p F P
0 g
s
.357 .022 .253 r
.69546 .55792 m .70769 .55087 L .69622 .55546 L closepath p F P
0 g
s
.408 .11 .344 r
.72503 .53944 m .72609 .53365 L p .69622 .55546 L F P
0 g
s
.408 .11 .344 r
.69622 .55546 m .70769 .55087 L .72503 .53944 L p F P
0 g
s
.705 .207 .053 r
.39202 .57587 m .39933 .5823 L .39417 .58313 L p F P
0 g
s
.705 .207 .053 r
.37458 .57071 m .39202 .57587 L p .39417 .58313 L F P
0 g
s
.557 .023 0 r
.44657 .59416 m .44344 .59374 L .44456 .59335 L closepath p F P
0 g
s
.286 0 0 r
.59257 .59743 m .59538 .59517 L .62768 .58961 L p F P
0 g
s
.401 0 .046 r
.62941 .58769 m .62768 .58961 L .59538 .59517 L p F P
0 g
s
.354 .069 .335 r
.72503 .53944 m .73671 .52843 L .72609 .53365 L closepath p F P
0 g
s
.403 .152 .417 r
.72609 .53365 m .73671 .52843 L .75158 .51007 L p F P
0 g
s
.806 .376 .225 r
.34942 .55405 m .35428 .56144 L .34963 .56244 L p F P
0 g
s
.806 .376 .225 r
.33451 .54799 m .34942 .55405 L p .34963 .56244 L F P
0 g
s
.289 0 .049 r
.65929 .58122 m .66364 .57425 L .69278 .56485 L p F P
0 g
s
.379 .011 .208 r
.69546 .55792 m .69278 .56485 L .66364 .57425 L p F P
0 g
s
.374 0 .101 r
.66364 .57425 m .65929 .58122 L .62941 .58769 L p F P
0 g
s
.416 0 0 r
.47397 .60134 m .47151 .60102 L .44657 .59416 L p F P
0 g
s
.216 0 0 r
.44344 .59374 m .44657 .59416 L .47151 .60102 L p F P
0 g
s
.304 0 .182 r
.69278 .56485 m .69546 .55792 L .70769 .55087 L p F P
0 g
s
.216 0 0 r
.43603 .59491 m .44344 .59374 L p .47151 .60102 L F P
0 g
s
.553 0 0 r
.43603 .59491 m .42555 .59014 L .44344 .59374 L closepath p F P
0 g
s
.286 0 0 r
.62768 .58961 m .62941 .58769 L .65929 .58122 L p F P
0 g
s
.43 .208 .474 r
.75158 .51007 m .75367 .50901 L .75374 .50586 L closepath p F P
0 g
s
.885 .584 .472 r
.29823 .51046 m .28591 .50335 L .28462 .49034 L p F P
0 g
s
.898 .595 .463 r
.27297 .48291 m .28462 .49034 L .28591 .50335 L p F P
0 g
s
.895 .625 .521 r
.28462 .49034 m .27297 .48291 L .27324 .46949 L p F P
0 g
s
.908 .637 .516 r
.26227 .46173 m .27324 .46949 L .27297 .48291 L p F P
0 g
s
.884 .545 .402 r
.29823 .51046 m .30089 .52194 L .29985 .52233 L p F P
0 g
s
.884 .545 .402 r
.28591 .50335 m .29823 .51046 L p .29985 .52233 L F P
0 g
s
.387 .134 .403 r
.75367 .50901 m .75158 .51007 L .73671 .52843 L p F P
0 g
s
.304 0 .182 r
.70769 .55087 m .72398 .5442 L p .69278 .56485 L F P
0 g
s
.389 .083 .32 r
.70769 .55087 m .72398 .5442 L .72503 .53944 L closepath p F P
0 g
s
.839 .454 .321 r
.33451 .54799 m .32028 .54165 L .31478 .5297 L p F P
0 g
s
.849 .455 .298 r
.30122 .52307 m .31478 .5297 L .32028 .54165 L p F P
0 g
s
.861 .515 .396 r
.31478 .5297 m .30122 .52307 L .30089 .52194 L p F P
0 g
s
.362 .193 .513 r
.78722 .4614 m .77831 .46804 L .77894 .48122 L p F P
0 g
s
.705 .207 .053 r
.39417 .58313 m .38693 .58094 L .37458 .57071 L p F P
0 g
s
.69 .168 0 r
.35775 .5653 m .37458 .57071 L .38693 .58094 L p F P
0 g
s
.758 .308 .18 r
.37458 .57071 m .35775 .5653 L .35428 .56144 L p F P
0 g
s
.27 0 0 r
.51435 .60369 m .49993 .60291 L .48139 .6005 L p F P
0 g
s
.254 0 0 r
.49993 .60291 m .47397 .60134 L .48139 .6005 L closepath p F P
0 g
s
.323 .082 .384 r
.7788 .49355 m .75367 .50901 L .75255 .52041 L p F P
0 g
s
.371 .163 .462 r
.77894 .48122 m .7788 .49355 L .75367 .50901 L p F P
0 g
s
.387 .134 .403 r
.73671 .52843 m .75255 .52041 L .75367 .50901 L p F P
0 g
s
.449 0 0 r
.42555 .59014 m .43603 .59491 L .42849 .59437 L p F P
0 g
s
.449 0 0 r
.40552 .58578 m .42555 .59014 L p .42849 .59437 L F P
0 g
s
.617 .086 0 r
.42555 .59014 m .40552 .58578 L .39933 .5823 L p F P
0 g
s
.611 .071 0 r
.40552 .58578 m .39417 .58313 L .39933 .5823 L closepath p F P
0 g
s
.314 .019 .294 r
.73671 .52843 m .75255 .52041 L p .72398 .5442 L F P
0 g
s
.314 .019 .294 r
.72398 .5442 m .72503 .53944 L .73671 .52843 L p F P
0 g
s
.286 0 0 r
.62768 .58961 m .62237 .59348 L .59257 .59743 L p F P
0 g
s
.096 0 0 r
.58643 .59995 m .59257 .59743 L .62237 .59348 L p F P
0 g
s
.145 0 0 r
.62237 .59348 m .62768 .58961 L .65846 .58214 L p F P
0 g
s
.286 0 0 r
.65929 .58122 m .65846 .58214 L .62768 .58961 L p F P
0 g
s
.763 .301 .151 r
.35775 .5653 m .34963 .56244 L .35428 .56144 L closepath p F P
0 g
s
.806 .376 .225 r
.34963 .56244 m .34222 .55942 L .33451 .54799 L p F P
0 g
s
.811 .368 .189 r
.32028 .54165 m .33451 .54799 L .34222 .55942 L p F P
0 g
s
.18 0 0 r
.55157 .60303 m .53286 .6035 L .51842 .60315 L p F P
0 g
s
.128 0 0 r
.53286 .6035 m .51435 .60369 L .51842 .60315 L closepath p F P
0 g
s
.167 0 0 r
.58643 .59995 m .57696 .60091 L .55552 .60216 L p F P
0 g
s
.076 0 0 r
.57696 .60091 m .55157 .60303 L .55552 .60216 L closepath p F P
0 g
s
.898 .595 .463 r
.28591 .50335 m .27422 .49595 L .27297 .48291 L p F P
0 g
s
.912 .606 .452 r
.26196 .47517 m .27297 .48291 L .27422 .49595 L p F P
0 g
s
.908 .637 .516 r
.27297 .48291 m .26196 .47517 L .26227 .46173 L p F P
0 g
s
.69 .168 0 r
.38693 .58094 m .37045 .5754 L .35775 .5653 L p F P
0 g
s
.657 .111 0 r
.34963 .56244 m .35775 .5653 L .37045 .5754 L p F P
0 g
s
.884 .545 .402 r
.29985 .52233 m .2888 .51599 L .28591 .50335 L p F P
0 g
s
.897 .553 .387 r
.27422 .49595 m .28591 .50335 L .2888 .51599 L p F P
0 g
s
.449 0 0 r
.42849 .59437 m .4261 .59381 L .40552 .58578 L p F P
0 g
s
.302 0 0 r
.39417 .58313 m .40552 .58578 L .4261 .59381 L p F P
0 g
s
.874 .522 .381 r
.30122 .52307 m .29985 .52233 L .30089 .52194 L closepath p F P
0 g
s
.21 0 .017 r
.68934 .57073 m .69278 .56485 L .72068 .55353 L p F P
0 g
s
.304 0 .182 r
.72398 .5442 m .72068 .55353 L .69278 .56485 L p F P
0 g
s
.289 0 .049 r
.69278 .56485 m .68934 .57073 L .65929 .58122 L p F P
0 g
s
.922 .65 .509 r
.25194 .45366 m .26227 .46173 L .26196 .47517 L p F P
0 g
s
.236 0 .158 r
.75051 .53087 m .72398 .5442 L .72068 .55353 L p F P
0 g
s
.314 .019 .294 r
.75255 .52041 m .75051 .53087 L .72398 .5442 L p F P
0 g
s
.362 .193 .513 r
.77894 .48122 m .78656 .47559 L .78722 .4614 L p F P
0 g
s
.346 .18 .509 r
.80189 .44994 m .78722 .4614 L .78656 .47559 L p F P
0 g
s
.849 .455 .298 r
.32028 .54165 m .30672 .53502 L .30122 .52307 L p F P
0 g
s
.857 .45 .263 r
.29985 .52233 m .30122 .52307 L .30672 .53502 L p F P
0 g
s
.316 .122 .45 r
.78656 .47559 m .77894 .48122 L .7788 .49355 L p F P
0 g
s
.857 .45 .263 r
.29125 .52262 m .29985 .52233 L p .30672 .53502 L F P
0 g
s
.875 .494 .316 r
.29125 .52262 m .2888 .51599 L .29985 .52233 L closepath p F P
0 g
s
.17 0 0 r
.65846 .58214 m .65929 .58122 L .68934 .57073 L p F P
0 g
s
.216 0 0 r
.44877 .59744 m .43603 .59491 L p .46679 .6002 L F P
0 g
s
.227 0 0 r
.44877 .59744 m .42849 .59437 L .43603 .59491 L closepath p F P
0 g
s
0 .513 .731 r
.44877 .59744 m .46479 .59938 L p .42848 .59433 L F P
0 g
s
0 .513 .731 r
.42743 .59419 m .44877 .59744 L .42848 .59433 L F
.216 0 0 r
.47151 .60102 m .44877 .59744 L p .46679 .6002 L F P
0 g
s
.302 0 0 r
.39046 .58316 m .39417 .58313 L p .4261 .59381 L F P
0 g
s
.62 .067 0 r
.39046 .58316 m .38693 .58094 L .39417 .58313 L closepath p F P
0 g
s
.657 .111 0 r
.34506 .56256 m .34963 .56244 L p .37045 .5754 L F P
0 g
s
.765 .283 .091 r
.34506 .56256 m .34222 .55942 L .34963 .56244 L closepath p F P
0 g
s
.091 0 0 r
.51042 .60364 m .49993 .60291 L .51435 .60369 L closepath p F P
0 g
s
.033 .604 .733 r
.51042 .60364 m .51435 .60369 L .53286 .6035 L p F P
0 g
s
.811 .368 .189 r
.34222 .55942 m .32804 .55306 L .32028 .54165 L p F P
0 g
s
.815 .359 .149 r
.30672 .53502 m .32028 .54165 L .32804 .55306 L p F P
0 g
s
.019 0 0 r
.54778 .60325 m .53286 .6035 L .55157 .60303 L closepath p F P
0 g
s
.033 .604 .733 r
.53286 .6035 m .54778 .60325 L p .51042 .60364 L F P
0 g
s
.256 0 .284 r
.77329 .50775 m .75255 .52041 L .75051 .53087 L p F P
0 g
s
.323 .082 .384 r
.7783 .49959 m .7788 .49355 L p .75255 .52041 L F P
0 g
s
.323 .082 .384 r
.75255 .52041 m .77329 .50775 L .7783 .49959 L p F P
0 g
s
.085 .644 .731 r
.54778 .60325 m .55157 .60303 L .57696 .60091 L p F P
0 g
s
.096 0 0 r
.49993 .60291 m .51042 .60364 L p .47312 .60132 L F P
0 g
s
.096 0 0 r
.47312 .60132 m .47397 .60134 L .49993 .60291 L p F P
0 g
s
.013 0 0 r
.65245 .5864 m .65846 .58214 L .68773 .57264 L p F P
0 g
s
.145 0 0 r
.65846 .58214 m .65245 .5864 L .62237 .59348 L p F P
0 g
s
.17 0 0 r
.68934 .57073 m .68773 .57264 L .65846 .58214 L p F P
0 g
s
.554 0 0 r
.38693 .58094 m .39046 .58316 L .38155 .58172 L p F P
0 g
s
.554 0 0 r
.38155 .58172 m .37045 .5754 L .38693 .58094 L p F P
0 g
s
.244 0 0 r
.47312 .60132 m .47151 .60102 L .47397 .60134 L closepath p F P
0 g
s
0 .559 .787 r
.47151 .60102 m .47312 .60132 L .46479 .59938 L p F P
0 g
s
0 .559 .787 r
.46479 .59938 m .44877 .59744 L .47151 .60102 L p F P
0 g
s
.03 0 0 r
.58514 .60022 m .57696 .60091 L .58643 .59995 L closepath p F P
0 g
s
.085 .644 .731 r
.57696 .60091 m .58514 .60022 L p .54778 .60325 L F P
0 g
s
.752 .248 .018 r
.34222 .55942 m .34506 .56256 L .33582 .56128 L p F P
0 g
s
.752 .248 .018 r
.33582 .56128 m .32804 .55306 L .34222 .55942 L p F P
0 g
s
.096 0 0 r
.51042 .60364 m .50231 .60138 L .47312 .60132 L p F P
0 g
s
.454 .785 .998 r
.50231 .60138 m .47312 .60132 L .46479 .59938 L p F P
0 g
s
0 0 0 r
.61912 .59445 m .62237 .59348 L .65245 .5864 L p F P
0 g
s
.096 0 0 r
.62237 .59348 m .61912 .59445 L .58643 .59995 L p F P
0 g
s
0 0 0 r
.58514 .60022 m .58643 .59995 L .61912 .59445 L p F P
0 g
s
.316 .122 .45 r
.7788 .49355 m .78239 .49091 L .78656 .47559 L p F P
0 g
s
.294 .101 .44 r
.80261 .46315 m .78656 .47559 L .78239 .49091 L p F P
0 g
s
.346 .18 .509 r
.78656 .47559 m .80261 .46315 L .80189 .44994 L p F P
0 g
s
.897 .553 .387 r
.2888 .51599 m .27707 .5086 L .27422 .49595 L p F P
0 g
s
.909 .561 .37 r
.26317 .48824 m .27422 .49595 L .27707 .5086 L p F P
0 g
s
.912 .606 .452 r
.27422 .49595 m .26317 .48824 L .26196 .47517 L p F P
0 g
s
.925 .617 .44 r
.25159 .46713 m .26196 .47517 L .26317 .48824 L p F P
0 g
s
.922 .65 .509 r
.26196 .47517 m .25159 .46713 L .25194 .45366 L p F P
0 g
s
.302 0 0 r
.4261 .59381 m .40777 .58885 L .39046 .58316 L p F P
0 g
s
.331 0 0 r
.40777 .58885 m .39046 .58316 L .38155 .58172 L p F P
0 g
s
.885 .495 .288 r
.2888 .51599 m .29125 .52262 L .28165 .52083 L p F P
0 g
s
.885 .495 .288 r
.28165 .52083 m .27707 .5086 L .2888 .51599 L p F P
0 g
s
.935 .664 .501 r
.24225 .44528 m .25194 .45366 L .25159 .46713 L p F P
0 g
s
.033 .604 .733 r
.54778 .60325 m .53992 .60126 L .51042 .60364 L p F P
0 g
s
.522 .812 .999 r
.53992 .60126 m .51042 .60364 L .50231 .60138 L p F P
0 g
s
.657 .111 0 r
.37045 .5754 m .35456 .56962 L .34506 .56256 L p F P
0 g
s
.65 .098 0 r
.35456 .56962 m .34506 .56256 L .33582 .56128 L p F P
0 g
s
0 0 0 r
.61912 .59445 m .61509 .5949 L .58514 .60022 L p F P
0 g
s
.457 .855 .973 r
.61509 .5949 m .58514 .60022 L .57753 .59931 L p F P
0 g
s
.085 .644 .731 r
.58514 .60022 m .57753 .59931 L .54778 .60325 L p F P
0 g
s
0 .513 .731 r
.42743 .59419 m .42849 .59437 L .44877 .59744 L p F P
0 g
s
.523 .837 .999 r
.57753 .59931 m .54778 .60325 L .53992 .60126 L p F P
0 g
s
.815 .359 .149 r
.32804 .55306 m .31454 .5464 L .30672 .53502 L p F P
0 g
s
.815 .347 .104 r
.29384 .52809 m .30672 .53502 L .31454 .5464 L p F P
0 g
s
.857 .45 .263 r
.30672 .53502 m .29384 .52809 L .29125 .52262 L p F P
0 g
s
.259 .035 .371 r
.7783 .49959 m .78239 .49091 L .7788 .49355 L closepath p F P
0 g
s
.21 0 .017 r
.72068 .55353 m .71943 .55591 L .68934 .57073 L p F P
0 g
s
.064 0 0 r
.68773 .57264 m .68934 .57073 L .71943 .55591 L p F P
0 g
s
.449 0 0 r
.37045 .5754 m .38155 .58172 L .37357 .57916 L p F P
0 g
s
.449 0 0 r
.35456 .56962 m .37045 .5754 L p .37357 .57916 L F P
0 g
s
.284 .135 .496 r
.8072 .445 m .80189 .44994 L .80261 .46315 L p F P
0 g
s
.138 0 .007 r
.71943 .55591 m .73055 .54861 L .72068 .55353 L closepath p F P
0 g
s
.236 0 .158 r
.74932 .53466 m .75051 .53087 L p .72068 .55353 L F P
0 g
s
.236 0 .158 r
.72068 .55353 m .73055 .54861 L .74932 .53466 L p F P
0 g
s
.213 0 .341 r
.78239 .49091 m .80251 .47543 L p .77776 .50491 L F P
0 g
s
.213 0 .341 r
.77776 .50491 m .7783 .49959 L .78239 .49091 L p F P
0 g
s
.294 .101 .44 r
.78239 .49091 m .80251 .47543 L .80261 .46315 L p F P
0 g
s
.734 .211 0 r
.32804 .55306 m .33582 .56128 L .32994 .55958 L p F P
0 g
s
.734 .211 0 r
.31454 .5464 m .32804 .55306 L p .32994 .55958 L F P
0 g
s
0 0 0 r
.65245 .5864 m .65021 .58699 L .61912 .59445 L p F P
0 g
s
.266 .773 .795 r
.61509 .5949 m .61912 .59445 L .65021 .58699 L p F P
0 g
s
.866 .451 .235 r
.29384 .52809 m .29125 .52262 L .28165 .52083 L p F P
0 g
s
.27 0 0 r
.42743 .59419 m .4261 .59381 L .42849 .59437 L closepath p F P
0 g
s
0 .495 .779 r
.4261 .59381 m .42743 .59419 L .41879 .59128 L p F P
0 g
s
0 .495 .779 r
.41879 .59128 m .40777 .58885 L .4261 .59381 L p F P
0 g
s
0 0 0 r
.68275 .57644 m .68773 .57264 L .71565 .56109 L p F P
0 g
s
.013 0 0 r
.68773 .57264 m .68275 .57644 L .65245 .5864 L p F P
0 g
s
.064 0 0 r
.71943 .55591 m .71565 .56109 L .68773 .57264 L p F P
0 g
s
.17 0 .156 r
.74932 .53466 m .75766 .52653 L .75051 .53087 L closepath p F P
0 g
s
.256 0 .284 r
.75051 .53087 m .75766 .52653 L .77329 .50775 L p F P
0 g
s
0 .513 .731 r
.46479 .59938 m .45637 .59557 L .42743 .59419 L p F P
0 g
s
.45 .753 .994 r
.45637 .59557 m .42743 .59419 L .41879 .59128 L p F P
0 g
s
.299 .056 .367 r
.77329 .50775 m .77776 .50491 L .7783 .49959 L closepath p F P
0 g
s
.909 .561 .37 r
.27707 .5086 m .26599 .50092 L .26317 .48824 L p F P
0 g
s
.921 .569 .351 r
.25276 .48022 m .26317 .48824 L .26599 .50092 L p F P
0 g
s
.925 .617 .44 r
.26317 .48824 m .25276 .48022 L .25159 .46713 L p F P
0 g
s
.938 .628 .426 r
.24186 .45877 m .25159 .46713 L .25276 .48022 L p F P
0 g
s
.935 .664 .501 r
.25159 .46713 m .24186 .45877 L .24225 .44528 L p F P
0 g
s
.894 .497 .261 r
.27707 .5086 m .28165 .52083 L .28159 .5208 L p F P
0 g
s
.894 .497 .261 r
.26599 .50092 m .27707 .5086 L p .28159 .5208 L F P
0 g
s
0 0 0 r
.71565 .56109 m .71943 .55591 L .73055 .54861 L p F P
0 g
s
.222 0 .253 r
.77776 .50491 m .77329 .50775 L .75766 .52653 L p F P
0 g
s
.948 .678 .491 r
.24225 .44528 m .23321 .43656 L .23277 .45009 L p F P
0 g
s
.948 .678 .491 r
.23277 .45009 m .24186 .45877 L .24225 .44528 L p F P
0 g
s
.271 .769 .728 r
.65021 .58699 m .65245 .5864 L .68275 .57644 L p F P
0 g
s
.284 .135 .496 r
.80261 .46315 m .80692 .45917 L .8072 .445 L p F P
0 g
s
.259 .116 .488 r
.82256 .42979 m .8072 .445 L .80692 .45917 L p F P
0 g
s
.815 .347 .104 r
.31454 .5464 m .30171 .53945 L .29384 .52809 L p F P
0 g
s
.813 .333 .054 r
.28166 .52085 m .29384 .52809 L .30171 .53945 L p F P
0 g
s
.866 .451 .235 r
.28165 .52083 m .28166 .52085 L .29384 .52809 L p F P
0 g
s
.449 0 0 r
.37357 .57916 m .37188 .57851 L .35456 .56962 L p F P
0 g
s
.348 0 0 r
.33924 .56358 m .35456 .56962 L .37188 .57851 L p F P
0 g
s
.65 .098 0 r
.33582 .56128 m .33924 .56358 L .35456 .56962 L p F P
0 g
s
0 0 0 r
.73055 .54861 m .7472 .53999 L p .71565 .56109 L F P
0 g
s
.187 0 .101 r
.73055 .54861 m .7472 .53999 L .74932 .53466 L closepath p F P
0 g
s
.454 .785 .998 r
.46479 .59938 m .49412 .59693 L .50231 .60138 L p F P
0 g
s
.577 .774 .973 r
.49412 .59693 m .46479 .59938 L .45637 .59557 L p F P
0 g
s
.063 0 .049 r
.75766 .52653 m .77567 .51514 L p .7472 .53999 L F P
0 g
s
.063 0 .049 r
.7472 .53999 m .74932 .53466 L .75766 .52653 L p F P
0 g
s
.222 0 .253 r
.75766 .52653 m .77567 .51514 L .77776 .50491 L p F P
0 g
s
.091 .601 .89 r
.40777 .58885 m .41879 .59128 L .41007 .58694 L p F P
0 g
s
.091 .601 .89 r
.41007 .58694 m .38968 .58375 L .40777 .58885 L p F P
0 g
s
.331 0 0 r
.38155 .58172 m .38968 .58375 L .40777 .58885 L p F P
0 g
s
.134 0 .222 r
.79619 .4908 m .77776 .50491 L .77567 .51514 L p F P
0 g
s
.213 0 .341 r
.80229 .47811 m .79619 .4908 L .77776 .50491 L p F P
0 g
s
.213 0 .341 r
.80251 .47543 m .80229 .47811 L p .77776 .50491 L F P
0 g
s
0 .458 .746 r
.38968 .58375 m .37357 .57916 L .38155 .58172 L closepath p F P
0 g
s
.224 .049 .421 r
.80692 .45917 m .80261 .46315 L .80251 .47543 L p F P
0 g
s
.734 .211 0 r
.32994 .55958 m .32503 .55713 L .31454 .5464 L p F P
0 g
s
.714 .178 0 r
.30171 .53945 m .31454 .5464 L .32503 .55713 L p F P
0 g
s
.266 .773 .795 r
.65021 .58699 m .64534 .58733 L .61509 .5949 L p F P
0 g
s
.529 .878 .986 r
.64534 .58733 m .61509 .5949 L .60762 .59294 L p F P
0 g
s
.457 .855 .973 r
.57753 .59931 m .60762 .59294 L .61509 .5949 L p F P
0 g
s
.522 .812 .999 r
.50231 .60138 m .53194 .59678 L .53992 .60126 L p F P
0 g
s
.62 .777 .956 r
.53194 .59678 m .50231 .60138 L .49412 .59693 L p F P
0 g
s
.577 0 0 r
.33924 .56358 m .32994 .55958 L .33582 .56128 L closepath p F P
0 g
s
.387 .848 .853 r
.64534 .58733 m .65021 .58699 L .67968 .57736 L p F P
0 g
s
.271 .769 .728 r
.68275 .57644 m .67968 .57736 L .65021 .58699 L p F P
0 g
s
.523 .837 .999 r
.53992 .60126 m .56979 .59562 L .57753 .59931 L p F P
0 g
s
.624 .792 .962 r
.56979 .59562 m .53992 .60126 L .53194 .59678 L p F P
0 g
s
.602 .831 .987 r
.60762 .59294 m .57753 .59931 L .56979 .59562 L p F P
0 g
s
.921 .569 .351 r
.26599 .50092 m .25554 .49292 L .25276 .48022 L p F P
0 g
s
.931 .577 .328 r
.24299 .47189 m .25276 .48022 L .25554 .49292 L p F P
0 g
s
.938 .628 .426 r
.25276 .48022 m .24299 .47189 L .24186 .45877 L p F P
0 g
s
.224 .049 .421 r
.80251 .47543 m .80374 .4743 L .80692 .45917 L p F P
0 g
s
.189 .019 .405 r
.82233 .44403 m .80692 .45917 L .80374 .4743 L p F P
0 g
s
.259 .116 .488 r
.80692 .45917 m .82233 .44403 L .82256 .42979 L p F P
0 g
s
.894 .497 .261 r
.28159 .5208 m .27054 .51317 L .26599 .50092 L p F P
0 g
s
.901 .499 .231 r
.25554 .49292 m .26599 .50092 L .27054 .51317 L p F P
0 g
s
0 .329 .695 r
.32994 .55958 m .33924 .56358 L .35525 .57121 L p F P
0 g
s
0 .329 .695 r
.3521 .56979 m .32994 .55958 L .35525 .57121 L F
.32655 .55833 m .32994 .55958 L p .35735 .57221 L F P
0 g
s
.623 .058 0 r
.32655 .55833 m .32503 .55713 L .32994 .55958 L closepath p F P
0 g
s
.565 0 0 r
.32503 .55713 m .32655 .55833 L .31725 .55385 L p F P
0 g
s
0 .324 .688 r
.34344 .56564 m .32927 .55951 L p .31725 .55385 L F P
0 g
s
0 .324 .688 r
.32927 .55951 m .32655 .55833 L .32505 .55761 L p F P
0 g
s
0 .324 .688 r
.32505 .55761 m .31725 .55385 L p .32927 .55951 L F P
0 g
s
0 .329 .695 r
.35525 .57121 m .35735 .57221 L p .3521 .56979 L F P
0 g
s
.348 0 0 r
.37188 .57851 m .35735 .57221 L .33924 .56358 L p F P
0 g
s
.95 .64 .41 r
.24186 .45877 m .23277 .45009 L .23386 .46323 L p F P
0 g
s
.95 .64 .41 r
.23386 .46323 m .24299 .47189 L .24186 .45877 L p F P
0 g
s
.021 .557 .849 r
.38968 .58375 m .41007 .58694 L p .37258 .57878 L F P
0 g
s
.26 0 0 r
.37258 .57878 m .37188 .57851 L .37357 .57916 L closepath p F P
0 g
s
.021 .557 .849 r
.37258 .57878 m .37357 .57916 L .38968 .58375 L p F P
0 g
s
.871 .443 .187 r
.28166 .52085 m .28159 .5208 L .28165 .52083 L closepath p F P
0 g
s
.813 .333 .054 r
.30171 .53945 m .28957 .53219 L .28166 .52085 L p F P
0 g
s
.801 .309 0 r
.28159 .5208 m .28166 .52085 L .28957 .53219 L p F P
0 g
s
.801 .309 0 r
.27212 .51615 m .28159 .5208 L p .28957 .53219 L F P
0 g
s
.861 .415 .13 r
.27212 .51615 m .27054 .51317 L .28159 .5208 L closepath p F P
0 g
s
0 0 0 r
.71565 .56109 m .71318 .56329 L .68275 .57644 L p F P
0 g
s
.369 .828 .744 r
.67968 .57736 m .68275 .57644 L .71318 .56329 L p F P
0 g
s
.961 .692 .479 r
.23321 .43656 m .22481 .42751 L .22433 .44107 L p F P
0 g
s
.961 .692 .479 r
.22433 .44107 m .23277 .45009 L .23321 .43656 L p F P
0 g
s
.45 .753 .994 r
.41879 .59128 m .44789 .59009 L .45637 .59557 L p F P
0 g
s
.553 .754 .971 r
.44789 .59009 m .41879 .59128 L .41007 .58694 L p F P
0 g
s
0 0 0 r
.71318 .56329 m .73285 .55231 L .71565 .56109 L closepath p F P
0 g
s
0 0 0 r
.74359 .5458 m .73285 .55231 L .71565 .56109 L p F P
0 g
s
0 0 0 r
.7472 .53999 m .74359 .5458 L p .71565 .56109 L F P
0 g
s
0 0 0 r
.74359 .5458 m .76552 .52849 L .7472 .53999 L closepath p F P
0 g
s
.063 0 .049 r
.77366 .52102 m .76552 .52849 L .7472 .53999 L p F P
0 g
s
.063 0 .049 r
.77567 .51514 m .77366 .52102 L p .7472 .53999 L F P
0 g
s
.714 .178 0 r
.32503 .55713 m .31233 .55013 L .30171 .53945 L p F P
0 g
s
.686 .143 0 r
.28957 .53219 m .30171 .53945 L .31233 .55013 L p F P
0 g
s
.15 0 .329 r
.80229 .47811 m .80374 .4743 L .80251 .47543 L closepath p F P
0 g
s
.577 .774 .973 r
.45637 .59557 m .48586 .5905 L .49412 .59693 L p F P
0 g
s
.64 .748 .927 r
.48586 .5905 m .45637 .59557 L .44789 .59009 L p F P
0 g
s
.085 0 .289 r
.80374 .4743 m .81916 .45925 L p .80142 .48659 L F P
0 g
s
.085 0 .289 r
.80142 .48659 m .80229 .47811 L .80374 .4743 L p F P
0 g
s
.189 .019 .405 r
.80374 .4743 m .81916 .45925 L .82233 .44403 L p F P
0 g
s
.387 .848 .853 r
.67968 .57736 m .67585 .57774 L .64534 .58733 L p F P
0 g
s
.549 .895 .98 r
.67585 .57774 m .64534 .58733 L .63802 .58495 L p F P
0 g
s
.529 .878 .986 r
.60762 .59294 m .63802 .58495 L .64534 .58733 L p F P
0 g
s
0 .432 .784 r
.37188 .57851 m .37258 .57878 L .36357 .57432 L p F P
0 g
s
0 .432 .784 r
.36357 .57432 m .35735 .57221 L .37188 .57851 L p F P
0 g
s
.62 .777 .956 r
.49412 .59693 m .52388 .58993 L .53194 .59678 L p F P
0 g
s
.665 .735 .902 r
.52388 .58993 m .49412 .59693 L .48586 .5905 L p F P
0 g
s
.565 0 0 r
.31725 .55385 m .31233 .55013 L .32503 .55713 L p F P
0 g
s
.017 0 .061 r
.77366 .52102 m .78416 .50867 L .77567 .51514 L closepath p F P
0 g
s
.134 0 .222 r
.77567 .51514 m .78416 .50867 L .79619 .4908 L p F P
0 g
s
.021 .557 .849 r
.41007 .58694 m .4013 .58138 L .37258 .57878 L p F P
0 g
s
.425 .714 .984 r
.4013 .58138 m .37258 .57878 L .36357 .57432 L p F P
0 g
s
.19 0 .323 r
.79619 .4908 m .80142 .48659 L .80229 .47811 L closepath p F P
0 g
s
.624 .792 .962 r
.53194 .59678 m .56193 .58925 L .56979 .59562 L p F P
0 g
s
.665 .738 .905 r
.56193 .58925 m .53194 .59678 L .52388 .58993 L p F P
0 g
s
.369 .828 .744 r
.71318 .56329 m .70772 .56563 L .67968 .57736 L p F P
0 g
s
.448 .882 .855 r
.67585 .57774 m .67968 .57736 L .70772 .56563 L p F P
0 g
s
.626 .827 .978 r
.63802 .58495 m .60762 .59294 L .6 .58808 L p F P
0 g
s
.602 .831 .987 r
.56979 .59562 m .6 .58808 L .60762 .59294 L p F P
0 g
s
.652 .766 .933 r
.6 .58808 m .56979 .59562 L .56193 .58925 L p F P
0 g
s
.901 .499 .231 r
.27054 .51317 m .26007 .50519 L .25554 .49292 L p F P
0 g
s
.906 .5 .197 r
.24573 .48461 m .25554 .49292 L .26007 .50519 L p F P
0 g
s
.931 .577 .328 r
.25554 .49292 m .24573 .48461 L .24299 .47189 L p F P
0 g
s
.94 .583 .302 r
.24299 .47189 m .23386 .46323 L .23658 .47597 L p F P
0 g
s
.94 .583 .302 r
.23658 .47597 m .24573 .48461 L .24299 .47189 L p F P
0 g
s
0 .329 .695 r
.35735 .57221 m .34344 .56564 L .32655 .55833 L p F P
0 g
s
.231 .094 .479 r
.82375 .42853 m .82256 .42979 L .82233 .44403 L p F P
0 g
s
.426 .85 .703 r
.70772 .56563 m .71318 .56329 L .73285 .55231 L p F P
0 g
s
.859 .406 .084 r
.27054 .51317 m .27212 .51615 L .26259 .50993 L p F P
0 g
s
.859 .406 .084 r
.26259 .50993 m .26007 .50519 L .27054 .51317 L p F P
0 g
s
.961 .65 .39 r
.23277 .45009 m .22433 .44107 L .22539 .45424 L p F P
0 g
s
.961 .65 .39 r
.22539 .45424 m .23386 .46323 L .23277 .45009 L p F P
0 g
s
.151 .037 .458 r
.83381 .41564 m .82375 .42853 L .82452 .44173 L p F P
0 g
s
.231 .094 .479 r
.82233 .44403 m .82452 .44173 L .82375 .42853 L p F P
0 g
s
.087 0 .184 r
.80142 .48659 m .79619 .4908 L .78416 .50867 L p F P
0 g
s
.973 .705 .465 r
.22481 .42751 m .21706 .41812 L .21655 .43171 L p F P
0 g
s
.973 .705 .465 r
.21655 .43171 m .22433 .44107 L .22481 .42751 L p F P
0 g
s
.686 .143 0 r
.31233 .55013 m .30031 .54283 L .28957 .53219 L p F P
0 g
s
.651 .106 0 r
.27815 .52461 m .28957 .53219 L .30031 .54283 L p F P
0 g
s
.801 .309 0 r
.28957 .53219 m .27815 .52461 L .27212 .51615 L p F P
0 g
s
.79 .293 0 r
.27815 .52461 m .27212 .51615 L .26259 .50993 L p F P
0 g
s
0 0 0 r
.73285 .55231 m .74218 .54732 L .74359 .5458 L closepath p F P
0 g
s
.426 .85 .703 r
.73285 .55231 m .74218 .54732 L p .70772 .56563 L F P
0 g
s
.553 .754 .971 r
.41007 .58694 m .43935 .58318 L .44789 .59009 L p F P
0 g
s
.614 .744 .939 r
.43935 .58318 m .41007 .58694 L .4013 .58138 L p F P
0 g
s
.003 .506 .863 r
.35735 .57221 m .36357 .57432 L .3545 .56889 L p F P
0 g
s
.003 .506 .863 r
.3545 .56889 m .34344 .56564 L .35735 .57221 L p F P
0 g
s
0 0 0 r
.74218 .54732 m .74359 .5458 L .76552 .52849 L p F P
0 g
s
0 0 0 r
.78416 .50867 m .79927 .49658 L p .77232 .52401 L F P
0 g
s
0 0 0 r
.77232 .52401 m .77366 .52102 L .78416 .50867 L p F P
0 g
s
.087 0 .184 r
.78416 .50867 m .79927 .49658 L .80142 .48659 L p F P
0 g
s
.5 0 0 r
.31233 .55013 m .31725 .55385 L .3079 .54835 L p F P
0 g
s
.5 0 0 r
.3079 .54835 m .30031 .54283 L .31233 .55013 L p F P
0 g
s
0 0 .145 r
.81287 .47547 m .80142 .48659 L .79927 .49658 L p F P
0 g
s
.085 0 .289 r
.81916 .45925 m .81287 .47547 L .80142 .48659 L p F P
0 g
s
.64 .748 .927 r
.44789 .59009 m .47753 .58227 L .48586 .5905 L p F P
0 g
s
.676 .724 .886 r
.47753 .58227 m .44789 .59009 L .43935 .58318 L p F P
0 g
s
.448 .882 .855 r
.70772 .56563 m .70656 .56586 L .67585 .57774 L p F P
0 g
s
.54 .911 .952 r
.70656 .56586 m .67585 .57774 L .66871 .57564 L p F P
0 g
s
.549 .895 .98 r
.63802 .58495 m .66871 .57564 L .67585 .57774 L p F P
0 g
s
.022 0 0 r
.76552 .52849 m .77232 .52401 L .77366 .52102 L closepath p F P
0 g
s
0 0 0 r
.76552 .52849 m .77232 .52401 L p .74218 .54732 L F P
0 g
s
.153 0 .388 r
.82452 .44173 m .82233 .44403 L .81916 .45925 L p F P
0 g
s
.665 .735 .902 r
.48586 .5905 m .51573 .58088 L .52388 .58993 L p F P
0 g
s
.69 .703 .857 r
.51573 .58088 m .48586 .5905 L .47753 .58227 L p F P
0 g
s
.906 .5 .197 r
.26007 .50519 m .25024 .49689 L .24573 .48461 L p F P
0 g
s
.907 .498 .158 r
.24573 .48461 m .23658 .47597 L .24105 .48828 L p F P
0 g
s
.907 .498 .158 r
.24105 .48828 m .25024 .49689 L .24573 .48461 L p F P
0 g
s
.665 .738 .905 r
.52388 .58993 m .55395 .58031 L .56193 .58925 L p F P
0 g
s
.684 .695 .854 r
.55395 .58031 m .52388 .58993 L .51573 .58088 L p F P
0 g
s
.946 .588 .273 r
.23386 .46323 m .22539 .45424 L .22808 .467 L p F P
0 g
s
.946 .588 .273 r
.22808 .467 m .23658 .47597 L .23386 .46323 L p F P
0 g
s
.853 .396 .036 r
.26007 .50519 m .26259 .50993 L .25306 .50222 L p F P
0 g
s
.853 .396 .036 r
.25306 .50222 m .25024 .49689 L .26007 .50519 L p F P
0 g
s
0 0 0 r
.73733 .5505 m .76353 .53337 L .74218 .54732 L closepath p F P
0 g
s
.426 .85 .703 r
.74218 .54732 m .73733 .5505 L p .70772 .56563 L F P
0 g
s
0 0 0 r
.76798 .53013 m .76353 .53337 L .74218 .54732 L p F P
0 g
s
0 0 0 r
.77232 .52401 m .76798 .53013 L p .74218 .54732 L F P
0 g
s
.425 .714 .984 r
.36357 .57432 m .39246 .57482 L .4013 .58138 L p F P
0 g
s
.499 .725 .973 r
.39246 .57482 m .36357 .57432 L .3545 .56889 L p F P
0 g
s
.06 0 .359 r
.83385 .42987 m .82452 .44173 L .82436 .45383 L p F P
0 g
s
.151 .037 .458 r
.82452 .44173 m .83385 .42987 L .83381 .41564 L p F P
0 g
s
.153 0 .388 r
.81916 .45925 m .82436 .45383 L .82452 .44173 L p F P
0 g
s
.629 .84 .981 r
.66871 .57564 m .63802 .58495 L .63052 .57963 L p F P
0 g
s
.626 .827 .978 r
.6 .58808 m .63052 .57963 L .63802 .58495 L p F P
0 g
s
.652 .766 .933 r
.56193 .58925 m .59223 .58041 L .6 .58808 L p F P
0 g
s
.67 .709 .877 r
.59223 .58041 m .56193 .58925 L .55395 .58031 L p F P
0 g
s
.654 .755 .924 r
.63052 .57963 m .6 .58808 L .59223 .58041 L p F P
0 g
s
.97 .66 .368 r
.22433 .44107 m .21655 .43171 L .21758 .44491 L p F P
0 g
s
.97 .66 .368 r
.21758 .44491 m .22539 .45424 L .22433 .44107 L p F P
0 g
s
0 .324 .688 r
.31725 .55385 m .33016 .55879 L .34344 .56564 L p F P
0 g
s
0 .422 .803 r
.33016 .55879 m .31725 .55385 L .3079 .54835 L p F P
0 g
s
.651 .106 0 r
.30031 .54283 m .28897 .53521 L .27815 .52461 L p F P
0 g
s
.609 .069 0 r
.26747 .5167 m .27815 .52461 L .28897 .53521 L p F P
0 g
s
.79 .293 0 r
.26259 .50993 m .26747 .5167 L .27815 .52461 L p F P
0 g
s
0 0 0 r
.76798 .53013 m .78748 .51187 L .77232 .52401 L closepath p F P
0 g
s
0 0 0 r
.79799 .50011 m .78748 .51187 L .77232 .52401 L p F P
0 g
s
0 0 0 r
.79927 .49658 m .79799 .50011 L p .77232 .52401 L F P
0 g
s
.982 .718 .448 r
.21706 .41812 m .20999 .40838 L .20944 .422 L p F P
0 g
s
.982 .718 .448 r
.20944 .422 m .21655 .43171 L .21706 .41812 L p F P
0 g
s
.103 .559 .913 r
.34344 .56564 m .3545 .56889 L .34536 .56265 L p F P
0 g
s
.103 .559 .913 r
.34536 .56265 m .33016 .55879 L .34344 .56564 L p F P
0 g
s
.48 .896 .818 r
.70656 .56586 m .715 .56182 L .70772 .56563 L closepath p F P
0 g
s
.426 .85 .703 r
.73733 .5505 m .715 .56182 L .70772 .56563 L p F P
0 g
s
.051 0 .264 r
.82436 .45383 m .81916 .45925 L .81287 .47547 L p F P
0 g
s
.761 .261 0 r
.26747 .5167 m .26259 .50993 L .25306 .50222 L p F P
0 g
s
.614 .744 .939 r
.4013 .58138 m .43075 .57507 L .43935 .58318 L p F P
0 g
s
.652 .735 .91 r
.43075 .57507 m .4013 .58138 L .39246 .57482 L p F P
0 g
s
.431 0 0 r
.30031 .54283 m .3079 .54835 L .2985 .54193 L p F P
0 g
s
.431 0 0 r
.2985 .54193 m .28897 .53521 L .30031 .54283 L p F P
0 g
s
.109 .005 .444 r
.84317 .40252 m .83381 .41564 L .83385 .42987 L p F P
0 g
s
.527 .919 .893 r
.715 .56182 m .70656 .56586 L .69964 .5647 L p F P
0 g
s
.54 .911 .952 r
.66871 .57564 m .69964 .5647 L .70656 .56586 L p F P
0 g
s
.676 .724 .886 r
.43935 .58318 m .46914 .57246 L .47753 .58227 L p F P
0 g
s
.7 .707 .853 r
.46914 .57246 m .43935 .58318 L .43075 .57507 L p F P
0 g
s
.527 .919 .893 r
.73398 .5512 m .715 .56182 L p .69964 .5647 L F P
0 g
s
.498 .905 .815 r
.715 .56182 m .73398 .5512 L .73733 .5505 L closepath p F P
0 g
s
.69 .703 .857 r
.47753 .58227 m .50752 .56973 L .51573 .58088 L p F P
0 g
s
.707 .679 .82 r
.50752 .56973 m .47753 .58227 L .46914 .57246 L p F P
0 g
s
.684 .695 .854 r
.51573 .58088 m .54589 .56883 L .55395 .58031 L p F P
0 g
s
.696 .662 .813 r
.54589 .56883 m .51573 .58088 L .50752 .56973 L p F P
0 g
s
.903 .494 .116 r
.23658 .47597 m .22808 .467 L .23252 .47933 L p F P
0 g
s
.903 .494 .116 r
.23252 .47933 m .24105 .48828 L .23658 .47597 L p F P
0 g
s
.67 .709 .877 r
.55395 .58031 m .58433 .56995 L .59223 .58041 L p F P
0 g
s
.678 .665 .83 r
.58433 .56995 m .55395 .58031 L .54589 .56883 L p F P
0 g
s
.841 .383 0 r
.25306 .50222 m .25024 .49689 L .24105 .48828 L p F P
0 g
s
0 0 .145 r
.79927 .49658 m .80321 .49276 L .81287 .47547 L p F P
0 g
s
0 0 .071 r
.8232 .46478 m .81287 .47547 L .80321 .49276 L p F P
0 g
s
.051 0 .264 r
.81287 .47547 m .8232 .46478 L .82436 .45383 L p F P
0 g
s
.948 .591 .239 r
.22539 .45424 m .21758 .44491 L .22024 .4577 L p F P
0 g
s
.948 .591 .239 r
.22024 .4577 m .22808 .467 L .22539 .45424 L p F P
0 g
s
0 0 0 r
.79799 .50011 m .80321 .49276 L .79927 .49658 L closepath p F P
0 g
s
0 0 .227 r
.83138 .44496 m .82436 .45383 L .8232 .46478 L p F P
0 g
s
.06 0 .359 r
.82436 .45383 m .83138 .44496 L .83385 .42987 L p F P
0 g
s
.624 .872 .989 r
.69964 .5647 m .66871 .57564 L .66136 .57063 L p F P
0 g
s
.629 .84 .981 r
.63052 .57963 m .66136 .57063 L .66871 .57564 L p F P
0 g
s
.654 .755 .924 r
.59223 .58041 m .62285 .57144 L .63052 .57963 L p F P
0 g
s
.66 .696 .872 r
.62285 .57144 m .59223 .58041 L .58433 .56995 L p F P
0 g
s
.609 .069 0 r
.28897 .53521 m .27835 .52727 L .26747 .5167 L p F P
0 g
s
.561 .032 0 r
.25756 .50843 m .26747 .5167 L .27835 .52727 L p F P
0 g
s
.761 .261 0 r
.25306 .50222 m .25756 .50843 L .26747 .5167 L p F P
0 g
s
.975 .668 .341 r
.21655 .43171 m .20944 .422 L .21044 .43523 L p F P
0 g
s
.975 .668 .341 r
.21044 .43523 m .21758 .44491 L .21655 .43171 L p F P
0 g
s
.499 .725 .973 r
.3545 .56889 m .38355 .56747 L .39246 .57482 L p F P
0 g
s
.546 .73 .96 r
.38355 .56747 m .3545 .56889 L .34536 .56265 L p F P
0 g
s
.647 .764 .935 r
.66136 .57063 m .63052 .57963 L .62285 .57144 L p F P
0 g
s
.181 .593 .941 r
.33016 .55879 m .34536 .56265 L .33614 .55575 L p F P
0 g
s
.181 .593 .941 r
.33614 .55575 m .31755 .55165 L .33016 .55879 L p F P
0 g
s
0 .422 .803 r
.3079 .54835 m .31755 .55165 L .33016 .55879 L p F P
0 g
s
.696 .468 .575 r
.53108 .40928 m .53636 .40927 L .53711 .42391 L p F P
0 g
s
.696 .468 .575 r
.53711 .42391 m .52868 .42393 L .53108 .40928 L p F P
0 g
s
.72 .486 .57 r
.50017 .40765 m .53108 .40928 L .52868 .42393 L p F P
0 g
s
.623 .412 .576 r
.53711 .42391 m .53636 .40927 L .56986 .40311 L p F P
0 g
s
.019 .489 .875 r
.31755 .55165 m .3079 .54835 L .2985 .54193 L p F P
0 g
s
.629 .961 .832 r
.73398 .5512 m .73733 .5505 L .76353 .53337 L p F P
0 g
s
.004 0 .331 r
.84383 .416 m .83385 .42987 L .83138 .44496 L p F P
0 g
s
.109 .005 .444 r
.84381 .41265 m .84317 .40252 L p .83385 .42987 L F P
0 g
s
.109 .005 .444 r
.83385 .42987 m .84383 .416 L .84381 .41265 L p F P
0 g
s
.989 .73 .427 r
.20999 .40838 m .20358 .39827 L .20301 .41193 L p F P
0 g
s
.989 .73 .427 r
.20301 .41193 m .20944 .422 L .20999 .40838 L p F P
0 g
s
0 0 0 r
.80321 .49276 m .81739 .47808 L p .79569 .50495 L F P
0 g
s
0 0 0 r
.79569 .50495 m .79799 .50011 L .80321 .49276 L p F P
0 g
s
0 0 .071 r
.82202 .47005 m .8232 .46478 L p .80321 .49276 L F P
0 g
s
0 0 .071 r
.80321 .49276 m .81739 .47808 L .82202 .47005 L p F P
0 g
s
.72 .486 .57 r
.52868 .42393 m .49837 .42208 L .50017 .40765 L p F P
0 g
s
.757 .52 .574 r
.49511 .40683 m .50017 .40765 L .49837 .42208 L p F P
0 g
s
0 .17 .621 r
.28897 .53521 m .2985 .54193 L .28904 .53467 L p F P
0 g
s
0 .17 .621 r
.28904 .53467 m .27835 .52727 L .28897 .53521 L p F P
0 g
s
.726 .231 0 r
.25306 .50222 m .25756 .50843 L .24842 .4998 L p F P
0 g
s
.726 .231 0 r
.24842 .4998 m .24356 .49302 L .25306 .50222 L p F P
0 g
s
.841 .383 0 r
.24105 .48828 m .24356 .49302 L .25306 .50222 L p F P
0 g
s
.757 .52 .574 r
.49837 .42208 m .4959 .42168 L .49511 .40683 L p F P
0 g
s
.777 .535 .571 r
.4782 .40311 m .49511 .40683 L .4959 .42168 L p F P
0 g
s
0 0 0 r
.78748 .51187 m .79569 .50495 L .79799 .50011 L closepath p F P
0 g
s
.652 .735 .91 r
.39246 .57482 m .42209 .56601 L .43075 .57507 L p F P
0 g
s
.679 .73 .889 r
.42209 .56601 m .39246 .57482 L .38355 .56747 L p F P
0 g
s
.696 .662 .813 r
.50752 .56973 m .53776 .55481 L .54589 .56883 L p F P
0 g
s
.705 .637 .777 r
.53776 .55481 m .50752 .56973 L .49925 .55663 L p F P
0 g
s
.707 .679 .82 r
.46914 .57246 m .49925 .55663 L .50752 .56973 L p F P
0 g
s
0 0 0 r
.76353 .53337 m .76713 .53088 L .76798 .53013 L closepath p F P
0 g
s
.629 .961 .832 r
.76353 .53337 m .76713 .53088 L p .73398 .5512 L F P
0 g
s
.504 .833 .537 r
.76713 .53088 m .76798 .53013 L .78748 .51187 L p F P
0 g
s
.504 .833 .537 r
.78748 .51187 m .79569 .50495 L p .76713 .53088 L F P
0 g
s
.721 .66 .79 r
.49925 .55663 m .46914 .57246 L .4607 .5613 L p F P
0 g
s
.7 .707 .853 r
.43075 .57507 m .4607 .5613 L .46914 .57246 L p F P
0 g
s
.719 .697 .828 r
.4607 .5613 m .43075 .57507 L .42209 .56601 L p F P
0 g
s
.678 .665 .83 r
.54589 .56883 m .57633 .55664 L .58433 .56995 L p F P
0 g
s
.683 .631 .791 r
.57633 .55664 m .54589 .56883 L .53776 .55481 L p F P
0 g
s
.66 .696 .872 r
.58433 .56995 m .61503 .56035 L .62285 .57144 L p F P
0 g
s
.66 .648 .828 r
.61503 .56035 m .58433 .56995 L .57633 .55664 L p F P
0 g
s
.495 .313 .563 r
.57064 .41767 m .56986 .40311 L .59741 .38977 L p F P
0 g
s
.623 .412 .576 r
.56986 .40311 m .57064 .41767 L .53711 .42391 L p F P
0 g
s
.777 .535 .571 r
.4959 .42168 m .47659 .41747 L .4782 .40311 L p F P
0 g
s
.831 .583 .565 r
.46162 .39674 m .4782 .40311 L .47659 .41747 L p F P
0 g
s
.893 .486 .069 r
.22808 .467 m .22024 .4577 L p .2247 .47009 L F P
0 g
s
.893 .486 .069 r
.2247 .47009 m .23252 .47933 L .22808 .467 L p F P
0 g
s
.823 .368 0 r
.24356 .49302 m .24105 .48828 L .23252 .47933 L p F P
0 g
s
.504 .833 .537 r
.7925 .50906 m .7829 .51743 L .76713 .53088 L p F P
0 g
s
.504 .833 .537 r
.79569 .50495 m .7925 .50906 L p .76713 .53088 L F P
0 g
s
.566 .912 .699 r
.76179 .5336 m .7829 .51743 L .76713 .53088 L closepath p F P
0 g
s
.629 .961 .832 r
.76713 .53088 m .76179 .5336 L p .73398 .5512 L F P
0 g
s
.527 .919 .893 r
.69964 .5647 m .73073 .55124 L .73398 .5512 L p F P
0 g
s
.615 .916 .979 r
.73073 .55124 m .69964 .5647 L .69249 .56071 L p F P
0 g
s
.624 .872 .989 r
.66136 .57063 m .69249 .56071 L .69964 .5647 L p F P
0 g
s
.701 .5 .613 r
.52868 .42393 m .53711 .42391 L .53914 .44005 L p F P
0 g
s
.701 .5 .613 r
.53914 .44005 m .52183 .44009 L .52868 .42393 L p F P
0 g
s
.727 .53 .624 r
.49837 .42208 m .52868 .42393 L .52183 .44009 L p F P
0 g
s
.634 .452 .619 r
.53914 .44005 m .53711 .42391 L .57064 .41767 L p F P
0 g
s
.021 0 .417 r
.84381 .41265 m .84362 .40176 L .84317 .40252 L closepath p F P
0 g
s
.24 .613 .955 r
.31755 .55165 m .33614 .55575 L .32686 .5483 L p F P
0 g
s
.24 .613 .955 r
.32686 .5483 m .30571 .54417 L .31755 .55165 L p F P
0 g
s
.019 .489 .875 r
.2985 .54193 m .30571 .54417 L .31755 .55165 L p F P
0 g
s
0 0 .227 r
.8232 .46478 m .82626 .46093 L .83138 .44496 L p F P
0 g
s
0 0 .177 r
.84135 .43116 m .83138 .44496 L .82626 .46093 L p F P
0 g
s
.004 0 .331 r
.83138 .44496 m .84135 .43116 L .84383 .416 L p F P
0 g
s
.944 .591 .2 r
.21758 .44491 m .21044 .43523 L .21307 .44804 L p F P
0 g
s
.944 .591 .2 r
.21307 .44804 m .22024 .4577 L .21758 .44491 L p F P
0 g
s
.627 .96 .899 r
.73073 .55124 m .74645 .54262 L .73398 .5512 L closepath p F P
0 g
s
.629 .961 .832 r
.76179 .5336 m .74645 .54262 L .73398 .5512 L p F P
0 g
s
.561 .032 0 r
.27835 .52727 m .26845 .519 L .25756 .50843 L p F P
0 g
s
.507 0 0 r
.25756 .50843 m .24842 .4998 L .25928 .51038 L p F P
0 g
s
.507 0 0 r
.25928 .51038 m .26845 .519 L .25756 .50843 L p F P
0 g
s
0 0 .392 r
.84362 .40176 m .85038 .38863 L p .84399 .41574 L F P
0 g
s
0 0 .392 r
.84399 .41574 m .84381 .41265 L .84362 .40176 L p F P
0 g
s
.647 .764 .935 r
.62285 .57144 m .65382 .56279 L .66136 .57063 L p F P
0 g
s
.645 .7 .886 r
.65382 .56279 m .62285 .57144 L .61503 .56035 L p F P
0 g
s
.64 .797 .958 r
.69249 .56071 m .66136 .57063 L .65382 .56279 L p F P
0 g
s
0 0 .062 r
.82202 .47005 m .82626 .46093 L .8232 .46478 L closepath p F P
0 g
s
.727 .53 .624 r
.49672 .42726 m .49837 .42208 L p .52183 .44009 L F P
0 g
s
.757 .549 .615 r
.49672 .42726 m .49837 .42208 L .4959 .42168 L closepath p F P
0 g
s
.976 .674 .31 r
.20944 .422 m .20301 .41193 L .20398 .42518 L p F P
0 g
s
.976 .674 .31 r
.20398 .42518 m .21044 .43523 L .20944 .422 L p F P
0 g
s
.546 .73 .96 r
.34536 .56265 m .37458 .55953 L .38355 .56747 L p F P
0 g
s
.577 .733 .949 r
.37458 .55953 m .34536 .56265 L .33614 .55575 L p F P
0 g
s
.752 .545 .617 r
.4959 .42168 m .47659 .41747 L p .49322 .43768 L F P
0 g
s
.752 .545 .617 r
.49322 .43768 m .49672 .42726 L .4959 .42168 L p F P
0 g
s
.705 .637 .777 r
.53366 .54648 m .53776 .55481 L p .49925 .55663 L F P
0 g
s
.705 .637 .777 r
.49925 .55663 m .51617 .5463 L .53366 .54648 L p F P
0 g
s
.715 .659 .794 r
.49925 .55663 m .51617 .5463 L .4926 .54468 L closepath p F P
0 g
s
.721 .66 .79 r
.4926 .54468 m .49925 .55663 L p .4607 .5613 L F P
0 g
s
.112 .529 .913 r
.30571 .54417 m .2985 .54193 L .28904 .53467 L p F P
0 g
s
0 .206 .674 r
.27835 .52727 m .28904 .53467 L .27954 .52661 L p F P
0 g
s
0 .206 .674 r
.27954 .52661 m .26845 .519 L .27835 .52727 L p F P
0 g
s
.683 .631 .791 r
.56957 .54302 m .57633 .55664 L p .53776 .55481 L F P
0 g
s
.683 .631 .791 r
.53776 .55481 m .56092 .54379 L .56957 .54302 L p F P
0 g
s
.681 .626 .787 r
.53776 .55481 m .56092 .54379 L .53366 .54648 L closepath p F P
0 g
s
.687 .207 0 r
.24356 .49302 m .24842 .4998 L .24006 .4908 L p F P
0 g
s
.687 .207 0 r
.24006 .4908 m .23408 .48232 L .24356 .49302 L p F P
0 g
s
.823 .368 0 r
.23252 .47933 m .23408 .48232 L .24356 .49302 L p F P
0 g
s
.727 .53 .624 r
.52183 .44009 m .49841 .43847 L .49672 .42726 L p F P
0 g
s
.755 .549 .618 r
.49841 .43847 m .49672 .42726 L .49322 .43768 L closepath p F P
0 g
s
.992 .74 .403 r
.20358 .39827 m .19788 .38778 L .19727 .40147 L p F P
0 g
s
.992 .74 .403 r
.19727 .40147 m .20301 .41193 L .20358 .39827 L p F P
0 g
s
0 0 0 r
.7925 .50906 m .80357 .49675 L .79569 .50495 L closepath p F P
0 g
s
0 0 0 r
.81739 .47808 m .80357 .49675 L .79569 .50495 L p F P
0 g
s
.721 .66 .79 r
.4607 .5613 m .48711 .54417 L .4926 .54468 L p F P
0 g
s
.738 .656 .769 r
.48711 .54417 m .4607 .5613 L .45221 .54906 L p F P
0 g
s
.719 .697 .828 r
.42209 .56601 m .45221 .54906 L .4607 .5613 L p F P
0 g
s
.703 .52 .638 r
.52183 .44009 m .53914 .44005 L .54219 .45735 L p F P
0 g
s
.703 .52 .638 r
.54219 .45735 m .51147 .45742 L .52183 .44009 L p F P
0 g
s
.727 .552 .653 r
.49841 .43847 m .52183 .44009 L .51147 .45742 L p F P
0 g
s
.635 .474 .648 r
.53914 .44005 m .57251 .43354 L p .55875 .45401 L F P
0 g
s
.635 .474 .648 r
.55875 .45401 m .54219 .45735 L .53914 .44005 L p F P
0 g
s
.634 .452 .619 r
.57064 .41767 m .57251 .43354 L .53914 .44005 L p F P
0 g
s
.66 .648 .828 r
.57633 .55664 m .60708 .5463 L .61503 .56035 L p F P
0 g
s
.657 .619 .799 r
.60226 .53596 m .60708 .5463 L .57633 .55664 L p F P
0 g
s
.657 .619 .799 r
.57633 .55664 m .56957 .54302 L .60226 .53596 L p F P
0 g
s
.679 .73 .889 r
.38355 .56747 m .41336 .55628 L .42209 .56601 L p F P
0 g
s
.7 .73 .874 r
.41336 .55628 m .38355 .56747 L .37458 .55953 L p F P
0 g
s
0 0 0 r
.82626 .46093 m .83618 .44723 L p .82082 .47429 L F P
0 g
s
0 0 0 r
.82082 .47429 m .82202 .47005 L .82626 .46093 L p F P
0 g
s
0 0 .177 r
.82626 .46093 m .83618 .44723 L .84135 .43116 L p F P
0 g
s
.681 .623 .784 r
.56092 .54379 m .53366 .54648 L .52956 .53802 L p F P
0 g
s
.706 .635 .775 r
.53366 .54648 m .52956 .53802 L .51617 .5463 L closepath p F P
0 g
s
.831 .583 .565 r
.47659 .41747 m .46019 .41105 L .46162 .39674 L p F P
0 g
s
.885 .634 .554 r
.44886 .38905 m .46162 .39674 L .46019 .41105 L p F P
0 g
s
.736 .693 .81 r
.45221 .54906 m .42209 .56601 L .41336 .55628 L p F P
0 g
s
.715 .657 .791 r
.52218 .52036 m .52956 .53802 L .51617 .5463 L p F P
0 g
s
.715 .657 .791 r
.51882 .52024 m .52218 .52036 L p .51617 .5463 L F P
0 g
s
.715 .657 .791 r
.49094 .54166 m .51882 .52024 L p .51617 .5463 L F P
0 g
s
.715 .657 .791 r
.51617 .5463 m .4926 .54468 L .49094 .54166 L p F P
0 g
s
.523 .366 .61 r
.57251 .43354 m .57064 .41767 L .5984 .4045 L p F P
0 g
s
.495 .313 .563 r
.59741 .38977 m .5984 .4045 L .57064 .41767 L p F P
0 g
s
.061 0 .427 r
.84383 .416 m .84399 .41574 L .84381 .41265 L closepath p F P
0 g
s
.752 .545 .617 r
.47659 .41747 m .47238 .43276 L .49322 .43768 L p F P
0 g
s
.834 .616 .608 r
.46019 .41105 m .47659 .41747 L .47238 .43276 L p F P
0 g
s
.727 .552 .653 r
.51147 .45742 m .50233 .45679 L .49841 .43847 L p F P
0 g
s
.754 .568 .645 r
.49322 .43768 m .49841 .43847 L .50233 .45679 L p F P
0 g
s
.61 .949 .925 r
.74645 .54262 m .73073 .55124 L .72384 .54884 L p F P
0 g
s
.615 .916 .979 r
.69249 .56071 m .72384 .54884 L .73073 .55124 L p F P
0 g
s
.754 .568 .645 r
.50233 .45679 m .48537 .45421 L .49322 .43768 L p F P
0 g
s
.793 .601 .641 r
.47238 .43276 m .49322 .43768 L .48537 .45421 L p F P
0 g
s
.721 .659 .788 r
.4926 .54468 m .49094 .54166 L .48711 .54417 L closepath p F P
0 g
s
0 0 .299 r
.84399 .41574 m .84383 .416 L .84135 .43116 L p F P
0 g
s
.681 .623 .784 r
.52956 .53802 m .56005 .52023 L p .56092 .54379 L F P
0 g
s
.69 .604 .755 r
.55927 .51798 m .56005 .52023 L .52956 .53802 L p F P
0 g
s
.69 .604 .755 r
.52956 .53802 m .52218 .52036 L .55927 .51798 L p F P
0 g
s
0 0 .256 r
.85066 .40292 m .84399 .41574 L .84371 .42759 L p F P
0 g
s
0 0 .392 r
.85038 .38863 m .85066 .40292 L .84399 .41574 L p F P
0 g
s
0 0 .299 r
.84135 .43116 m .84371 .42759 L .84399 .41574 L p F P
0 g
s
.283 .622 .96 r
.30571 .54417 m .32686 .5483 L .3175 .54039 L p F P
0 g
s
.283 .622 .96 r
.3175 .54039 m .29473 .53633 L .30571 .54417 L p F P
0 g
s
.112 .529 .913 r
.28904 .53467 m .29473 .53633 L .30571 .54417 L p F P
0 g
s
.738 .656 .769 r
.45221 .54906 m .463 .54052 L .48711 .54417 L p F P
0 g
s
.712 .639 .774 r
.4826 .52482 m .463 .54052 L .48711 .54417 L p F P
0 g
s
.712 .639 .774 r
.48711 .54417 m .49094 .54166 L .4826 .52482 L p F P
0 g
s
0 0 .014 r
.81739 .47808 m .82082 .47429 L .82202 .47005 L closepath p F P
0 g
s
.645 .7 .886 r
.61503 .56035 m .6461 .55213 L .65382 .56279 L p F P
0 g
s
.636 .647 .845 r
.6461 .55213 m .61503 .56035 L .60708 .5463 L p F P
0 g
s
.683 .628 .788 r
.56957 .54302 m .56823 .54027 L .56092 .54379 L closepath p F P
0 g
s
.681 .623 .784 r
.56005 .52023 m .56823 .54027 L .56092 .54379 L p F P
0 g
s
.727 .607 .723 r
.51882 .52024 m .49094 .54166 L .4826 .52482 L p F P
0 g
s
.798 .352 0 r
.23408 .48232 m .23252 .47933 L .2247 .47009 L closepath p F P
0 g
s
.874 .474 .017 r
.22465 .47002 m .22024 .4577 L .21307 .44804 L p F P
0 g
s
.893 .486 .069 r
.22024 .4577 m .22465 .47002 L .2247 .47009 L p F P
0 g
s
.709 .562 .686 r
.51147 .45742 m .54219 .45735 L p .53155 .47665 L F P
0 g
s
.709 .562 .686 r
.50485 .4667 m .51147 .45742 L p .53155 .47665 L F P
0 g
s
.727 .565 .671 r
.50485 .4667 m .51147 .45742 L .50233 .45679 L closepath p F P
0 g
s
.639 .492 .666 r
.54351 .46369 m .55875 .45401 L .54219 .45735 L closepath p F P
0 g
s
.709 .562 .686 r
.54219 .45735 m .54351 .46369 L .53155 .47665 L p F P
0 g
s
.66 .617 .796 r
.599 .52886 m .60226 .53596 L .56957 .54302 L p F P
0 g
s
.66 .617 .796 r
.56957 .54302 m .56823 .54027 L .599 .52886 L p F P
0 g
s
0 .036 .547 r
.24842 .4998 m .24006 .4908 L .25086 .5014 L p F P
0 g
s
0 .036 .547 r
.25086 .5014 m .25928 .51038 L .24842 .4998 L p F P
0 g
s
.61 .949 .925 r
.75848 .53388 m .74645 .54262 L p .72384 .54884 L F P
0 g
s
.622 .96 .869 r
.74645 .54262 m .75848 .53388 L .76179 .5336 L closepath p F P
0 g
s
.729 .567 .67 r
.50233 .45679 m .48537 .45421 L p .49862 .47559 L F P
0 g
s
.729 .567 .67 r
.49862 .47559 m .50485 .4667 L .50233 .45679 L p F P
0 g
s
.933 .586 .157 r
.21044 .43523 m .20398 .42518 L p .20729 .43909 L F P
0 g
s
.933 .586 .157 r
.20729 .43909 m .21307 .44804 L .21044 .43523 L p F P
0 g
s
0 0 0 r
.82082 .47429 m .81739 .47808 L .80357 .49675 L p F P
0 g
s
.654 .575 .754 r
.599 .52886 m .56823 .54027 L .56005 .52023 L p F P
0 g
s
.651 .514 .684 r
.54657 .47615 m .54351 .46369 L .55875 .45401 L p F P
0 g
s
.696 .542 .674 r
.54657 .47615 m .54351 .46369 L .53155 .47665 L closepath p F P
0 g
s
.709 .609 .743 r
.55192 .49601 m .55927 .51798 L .52218 .52036 L p F P
0 g
s
.709 .609 .743 r
.55128 .49604 m .55192 .49601 L p .52218 .52036 L F P
0 g
s
.709 .609 .743 r
.52218 .52036 m .52133 .51826 L .55128 .49604 L p F P
0 g
s
.715 .612 .741 r
.52218 .52036 m .52133 .51826 L .51882 .52024 L closepath p F P
0 g
s
.64 .797 .958 r
.65382 .56279 m .68513 .55401 L .69249 .56071 L p F P
0 g
s
.632 .726 .916 r
.68513 .55401 m .65382 .56279 L .6461 .55213 L p F P
0 g
s
.641 .852 .981 r
.72384 .54884 m .69249 .56071 L .68513 .55401 L p F P
0 g
s
.727 .607 .723 r
.4826 .52482 m .4897 .51806 L .51882 .52024 L p F P
0 g
s
.702 .588 .724 r
.51078 .4973 m .4897 .51806 L .51882 .52024 L p F P
0 g
s
.702 .588 .724 r
.51396 .49751 m .51078 .4973 L p .51882 .52024 L F P
0 g
s
.702 .588 .724 r
.51882 .52024 m .52133 .51826 L .51396 .49751 L p F P
0 g
s
.709 .562 .686 r
.53155 .47665 m .50754 .47651 L .50485 .4667 L p F P
0 g
s
.738 .579 .677 r
.50754 .47651 m .50485 .4667 L .49862 .47559 L closepath p F P
0 g
s
.696 .584 .726 r
.52133 .51826 m .55128 .49604 L .51396 .49751 L closepath p F P
0 g
s
.637 .174 0 r
.23408 .48232 m .2247 .47009 L p .23248 .48143 L F P
0 g
s
.637 .174 0 r
.23248 .48143 m .24006 .4908 L .23408 .48232 L p F P
0 g
s
.769 .683 .768 r
.463 .54052 m .45221 .54906 L .44366 .53609 L p F P
0 g
s
.736 .693 .81 r
.41336 .55628 m .44366 .53609 L .45221 .54906 L p F P
0 g
s
.577 .733 .949 r
.33614 .55575 m .36552 .55121 L .37458 .55953 L p F P
0 g
s
.597 .737 .942 r
.36552 .55121 m .33614 .55575 L .32686 .5483 L p F P
0 g
s
.696 .577 .718 r
.53155 .47665 m .54657 .47615 L p .55128 .49604 L F P
0 g
s
.696 .577 .718 r
.51308 .4949 m .53155 .47665 L p .55128 .49604 L F P
0 g
s
.709 .571 .698 r
.51308 .4949 m .53155 .47665 L .50754 .47651 L closepath p F P
0 g
s
.714 .574 .697 r
.50754 .47651 m .49862 .47559 L p .51078 .4973 L F P
0 g
s
.714 .574 .697 r
.51078 .4973 m .51308 .4949 L .50754 .47651 L p F P
0 g
s
.554 .41 .64 r
.57251 .43354 m .60063 .42075 L p .5896 .44444 L F P
0 g
s
.554 .41 .64 r
.5896 .44444 m .57404 .443 L .57251 .43354 L p F P
0 g
s
.523 .366 .61 r
.5984 .4045 m .60063 .42075 L .57251 .43354 L p F P
0 g
s
.635 .474 .648 r
.57251 .43354 m .57404 .443 L .55875 .45401 L p F P
0 g
s
.97 .676 .274 r
.20301 .41193 m .19727 .40147 L p .19905 .41626 L F P
0 g
s
.97 .676 .274 r
.19905 .41626 m .20398 .42518 L .20301 .41193 L p F P
0 g
s
.645 .521 .697 r
.5518 .49563 m .54657 .47615 L .57979 .46942 L p F P
0 g
s
.696 .577 .718 r
.54657 .47615 m .5518 .49563 L .55128 .49604 L p F P
0 g
s
.651 .514 .684 r
.57556 .4508 m .57979 .46942 L .54657 .47615 L p F P
0 g
s
.651 .514 .684 r
.55875 .45401 m .57556 .4508 L p .54657 .47615 L F P
0 g
s
.769 .683 .768 r
.44366 .53609 m .44478 .53504 L .463 .54052 L p F P
0 g
s
.728 .635 .755 r
.46657 .51402 m .44478 .53504 L .463 .54052 L p F P
0 g
s
.728 .635 .755 r
.47858 .51612 m .46657 .51402 L p .463 .54052 L F P
0 g
s
.728 .635 .755 r
.463 .54052 m .4826 .52482 L .47858 .51612 L p F P
0 g
s
0 .234 .715 r
.27954 .52661 m .26845 .519 L .25928 .51038 L p F P
0 g
s
.696 .577 .718 r
.55128 .49604 m .51396 .49751 L .51308 .4949 L p F P
0 g
s
.726 .593 .708 r
.51396 .49751 m .51308 .4949 L .51078 .4973 L closepath p F P
0 g
s
.737 .992 .86 r
.75848 .53388 m .76179 .5336 L .7829 .51743 L p F P
0 g
s
.75 .64 .74 r
.48419 .4943 m .51078 .4973 L .4897 .51806 L p F P
0 g
s
.714 .574 .697 r
.49862 .47559 m .48419 .4943 L .51078 .4973 L p F P
0 g
s
.793 .601 .641 r
.48537 .45421 m .46613 .4488 L .47238 .43276 L p F P
0 g
s
.84 .645 .639 r
.45662 .42615 m .47238 .43276 L .46613 .4488 L p F P
0 g
s
.834 .616 .608 r
.47238 .43276 m .45662 .42615 L .46019 .41105 L p F P
0 g
s
.729 .567 .67 r
.48537 .45421 m .47565 .47141 L .49862 .47559 L p F P
0 g
s
.807 .632 .665 r
.46613 .4488 m .48537 .45421 L .47565 .47141 L p F P
0 g
s
.34 .201 .542 r
.60046 .3871 m .59741 .38977 L .5984 .4045 L p F P
0 g
s
.774 .64 .714 r
.47565 .47141 m .49862 .47559 L .48419 .4943 L p F P
0 g
s
.64 .483 .655 r
.57556 .4508 m .57404 .443 L .55875 .45401 L closepath p F P
0 g
s
.882 .663 .602 r
.44751 .40333 m .46019 .41105 L .45662 .42615 L p F P
0 g
s
.885 .634 .554 r
.46019 .41105 m .44751 .40333 L .44886 .38905 L p F P
0 g
s
.178 .55 .93 r
.29473 .53633 m .28904 .53467 L .27954 .52661 L p F P
0 g
s
0 0 0 r
.81701 .48186 m .82082 .47429 L p .80357 .49675 L F P
0 g
s
0 0 0 r
.80357 .49675 m .81664 .48232 L .81701 .48186 L p F P
0 g
s
.656 .912 .6 r
.80357 .49675 m .81664 .48232 L p .79007 .51103 L F P
0 g
s
.656 .912 .6 r
.79007 .51103 m .7925 .50906 L .80357 .49675 L p F P
0 g
s
.654 .575 .754 r
.59215 .51097 m .599 .52886 L p .56005 .52023 L F P
0 g
s
.654 .575 .754 r
.56005 .52023 m .57268 .515 L .59215 .51097 L p F P
0 g
s
.646 .553 .736 r
.56005 .52023 m .57268 .515 L .55927 .51798 L closepath p F P
0 g
s
.75 .64 .74 r
.47424 .50645 m .48419 .4943 L p .4897 .51806 L F P
0 g
s
.75 .64 .74 r
.4897 .51806 m .47858 .51612 L .47424 .50645 L p F P
0 g
s
.748 .644 .745 r
.4826 .52482 m .4897 .51806 L .47858 .51612 L closepath p F P
0 g
s
.645 .548 .73 r
.57268 .515 m .55927 .51798 L .55192 .49601 L p F P
0 g
s
.933 .683 .536 r
.43889 .38032 m .44886 .38905 L .44751 .40333 L p F P
0 g
s
0 0 .363 r
.85615 .37566 m .85038 .38863 L .85066 .40292 L p F P
0 g
s
.69 .567 .711 r
.55192 .49601 m .5518 .49563 L .55128 .49604 L closepath p F P
0 g
s
.653 .546 .72 r
.55192 .49601 m .5518 .49563 L .5825 .48029 L p F P
0 g
s
.645 .521 .697 r
.57979 .46942 m .5825 .48029 L .5518 .49563 L p F P
0 g
s
.645 .548 .73 r
.55192 .49601 m .58518 .48933 L p .57268 .515 L F P
0 g
s
.653 .546 .72 r
.5825 .48029 m .58518 .48933 L .55192 .49601 L p F P
0 g
s
.737 .992 .86 r
.7829 .51743 m .79007 .51103 L p .75848 .53388 L F P
0 g
s
.497 .84 .565 r
.7829 .51743 m .79007 .51103 L .7925 .50906 L closepath p F P
0 g
s
0 0 0 r
.81701 .48186 m .82807 .46425 L .82082 .47429 L closepath p F P
0 g
s
0 0 0 r
.83618 .44723 m .82807 .46425 L .82082 .47429 L p F P
0 g
s
.752 .692 .795 r
.44366 .53609 m .41336 .55628 L .40457 .54616 L p F P
0 g
s
.7 .73 .874 r
.37458 .55953 m .40457 .54616 L .41336 .55628 L p F P
0 g
s
0 0 .129 r
.84371 .42759 m .84135 .43116 L .83618 .44723 L p F P
0 g
s
.553 .425 .66 r
.57556 .4508 m .57404 .443 L .5896 .44444 L closepath p F P
0 g
s
.636 .647 .845 r
.60708 .5463 m .63823 .53862 L .6461 .55213 L p F P
0 g
s
.624 .593 .798 r
.63154 .52481 m .63823 .53862 L .60708 .5463 L p F P
0 g
s
.624 .593 .798 r
.60708 .5463 m .60226 .53596 L .63154 .52481 L p F P
0 g
s
.99 .747 .374 r
.19788 .38778 m .19537 .38232 L .19553 .39771 L p F P
0 g
s
.99 .747 .374 r
.19553 .39771 m .19727 .40147 L .19788 .38778 L p F P
0 g
s
.716 .734 .865 r
.40457 .54616 m .37458 .55953 L .36552 .55121 L p F P
0 g
s
.34 .201 .542 r
.5984 .4045 m .60327 .40027 L .60046 .3871 L p F P
0 g
s
.25 .133 .518 r
.61603 .37037 m .60046 .3871 L .60327 .40027 L p F P
0 g
s
.75 .64 .74 r
.47858 .51612 m .47424 .50645 L .46657 .51402 L closepath p F P
0 g
s
.771 .646 .723 r
.47424 .50645 m .48419 .4943 L .46708 .48997 L closepath p F P
0 g
s
.774 .64 .714 r
.46586 .48701 m .47565 .47141 L p .48419 .4943 L F P
0 g
s
.774 .64 .714 r
.48419 .4943 m .46708 .48997 L .46586 .48701 L p F P
0 g
s
.563 .449 .681 r
.57979 .46942 m .57556 .4508 L .5896 .44444 L p F P
0 g
s
.653 .569 .748 r
.59215 .51097 m .59081 .50737 L .57268 .515 L closepath p F P
0 g
s
.645 .548 .73 r
.58518 .48933 m .59081 .50737 L .57268 .515 L p F P
0 g
s
.31 .622 .959 r
.29473 .53633 m .3175 .54039 L .30806 .53207 L p F P
0 g
s
.31 .622 .959 r
.30806 .53207 m .28471 .52807 L .29473 .53633 L p F P
0 g
s
.178 .55 .93 r
.27954 .52661 m .28471 .52807 L .29473 .53633 L p F P
0 g
s
.804 .64 .678 r
.47565 .47141 m .46586 .48701 L .45746 .46708 L p F P
0 g
s
.804 .64 .678 r
.45746 .46708 m .45834 .4654 L .47565 .47141 L p F P
0 g
s
.807 .632 .665 r
.47565 .47141 m .45834 .4654 L .46613 .4488 L p F P
0 g
s
.622 .589 .796 r
.63021 .52202 m .63154 .52481 L .60226 .53596 L p F P
0 g
s
.622 .589 .796 r
.60226 .53596 m .599 .52886 L .63021 .52202 L p F P
0 g
s
.746 .635 .736 r
.46657 .51402 m .47424 .50645 L .46708 .48997 L p F P
0 g
s
.78 .7 .775 r
.44731 .50875 m .46657 .51402 L .44478 .53504 L p F P
0 g
s
.746 .635 .736 r
.46403 .48927 m .44731 .50875 L .46657 .51402 L p F P
0 g
s
.746 .635 .736 r
.46708 .48997 m .46403 .48927 L p .46657 .51402 L F P
0 g
s
0 0 .08 r
.84872 .41799 m .84371 .42759 L .84226 .43803 L p F P
0 g
s
0 0 .256 r
.84371 .42759 m .84872 .41799 L .85066 .40292 L p F P
0 g
s
0 0 .129 r
.83618 .44723 m .84226 .43803 L .84371 .42759 L p F P
0 g
s
.778 .702 .779 r
.44366 .53609 m .44478 .53504 L .4424 .53414 L closepath p F P
0 g
s
.78 .7 .775 r
.43507 .5226 m .44731 .50875 L p .44478 .53504 L F P
0 g
s
.78 .7 .775 r
.44478 .53504 m .4424 .53414 L .43507 .5226 L p F P
0 g
s
.752 .692 .795 r
.4424 .53414 m .44366 .53609 L p .40457 .54616 L F P
0 g
s
.835 .669 .677 r
.45132 .44189 m .46613 .4488 L .45834 .4654 L p F P
0 g
s
.84 .645 .639 r
.46613 .4488 m .45132 .44189 L .45662 .42615 L p F P
0 g
s
.637 .174 0 r
.2247 .47009 m .22466 .47004 L .23248 .48143 L p F P
0 g
s
.818 .386 0 r
.22466 .47004 m .2247 .47009 L .22465 .47002 L closepath p F P
0 g
s
.788 .373 0 r
.22465 .47002 m .22466 .47004 L .21791 .46026 L p F P
0 g
s
.788 .373 0 r
.21791 .46026 m .21541 .45474 L .22465 .47002 L p F P
0 g
s
.874 .474 .017 r
.21307 .44804 m .21541 .45474 L .22465 .47002 L p F P
0 g
s
.592 .154 0 r
.22466 .47004 m .21791 .46026 L .22565 .47168 L p F P
0 g
s
.592 .154 0 r
.22565 .47168 m .23248 .48143 L .22466 .47004 L p F P
0 g
s
.632 .726 .916 r
.6461 .55213 m .67757 .5447 L .68513 .55401 L p F P
0 g
s
.615 .667 .877 r
.67757 .5447 m .6461 .55213 L .63823 .53862 L p F P
0 g
s
.608 .549 .763 r
.62205 .50173 m .63021 .52202 L .599 .52886 L p F P
0 g
s
.608 .549 .763 r
.60913 .50412 m .62205 .50173 L p .599 .52886 L F P
0 g
s
.608 .549 .763 r
.599 .52886 m .59215 .51097 L .60913 .50412 L p F P
0 g
s
.85 .463 0 r
.21541 .45474 m .21307 .44804 L .20729 .43909 L closepath p F P
0 g
s
.752 .692 .795 r
.40457 .54616 m .42591 .52969 L .4424 .53414 L p F P
0 g
s
.752 .692 .794 r
.4424 .53414 m .43507 .5226 L .42591 .52969 L closepath p F P
0 g
s
.61 .949 .925 r
.72384 .54884 m .75526 .53358 L .75848 .53388 L p F P
0 g
s
.65 .919 .977 r
.75526 .53358 m .72384 .54884 L .71671 .54389 L p F P
0 g
s
.641 .852 .981 r
.68513 .55401 m .71671 .54389 L .72384 .54884 L p F P
0 g
s
.575 .467 .693 r
.5825 .48029 m .57979 .46942 L .60838 .45717 L p F P
0 g
s
.563 .449 .681 r
.60524 .44459 m .60838 .45717 L .57979 .46942 L p F P
0 g
s
.563 .449 .681 r
.5896 .44444 m .60524 .44459 L p .57979 .46942 L F P
0 g
s
.877 .69 .645 r
.44426 .41835 m .45662 .42615 L .45132 .44189 L p F P
0 g
s
.882 .663 .602 r
.45662 .42615 m .44426 .41835 L .44751 .40333 L p F P
0 g
s
0 .063 .591 r
.24006 .4908 m .23248 .48143 L .24317 .49206 L p F P
0 g
s
0 .063 .591 r
.24317 .49206 m .25086 .5014 L .24006 .4908 L p F P
0 g
s
.712 .978 .913 r
.75526 .53358 m .76649 .52646 L .75848 .53388 L closepath p F P
0 g
s
.737 .992 .86 r
.78648 .51258 m .76649 .52646 L .75848 .53388 L p F P
0 g
s
.737 .992 .86 r
.79007 .51103 m .78648 .51258 L p .75848 .53388 L F P
0 g
s
.392 .281 .607 r
.60327 .40027 m .5984 .4045 L .60063 .42075 L p F P
0 g
s
0 0 0 r
.84226 .43803 m .83618 .44723 L .82807 .46425 L p F P
0 g
s
.982 .745 .34 r
.19537 .38232 m .19318 .37679 L .19264 .39049 L p F P
0 g
s
.982 .745 .34 r
.19264 .39049 m .19553 .39771 L .19537 .38232 L p F P
0 g
s
.767 .637 .718 r
.46708 .48997 m .46586 .48701 L .46403 .48927 L closepath p F P
0 g
s
.913 .577 .108 r
.20635 .43685 m .20398 .42518 L .19905 .41626 L closepath p F P
0 g
s
.933 .586 .157 r
.20398 .42518 m .20635 .43685 L .20729 .43909 L p F P
0 g
s
.587 .497 .72 r
.58518 .48933 m .5825 .48029 L .61373 .47686 L p F P
0 g
s
.575 .467 .693 r
.60838 .45717 m .61373 .47686 L .5825 .48029 L p F P
0 g
s
.923 .709 .594 r
.43754 .39463 m .44751 .40333 L .44426 .41835 L p F P
0 g
s
.933 .683 .536 r
.44751 .40333 m .43754 .39463 L .43889 .38032 L p F P
0 g
s
.769 .641 .72 r
.46403 .48927 m .46586 .48701 L .45746 .46708 L p F P
0 g
s
.631 .779 .952 r
.71671 .54389 m .68513 .55401 L .67757 .5447 L p F P
0 g
s
.69 .965 .736 r
.78648 .51258 m .79735 .50272 L .79007 .51103 L closepath p F P
0 g
s
.656 .912 .6 r
.81664 .48232 m .79735 .50272 L .79007 .51103 L p F P
0 g
s
.606 .543 .758 r
.59215 .51097 m .59081 .50737 L .60913 .50412 L closepath p F P
0 g
s
.601 .513 .727 r
.58518 .48933 m .61385 .47723 L p .60913 .50412 L F P
0 g
s
.601 .513 .727 r
.60913 .50412 m .59081 .50737 L .58518 .48933 L p F P
0 g
s
.587 .497 .72 r
.61373 .47686 m .61385 .47723 L .58518 .48933 L p F P
0 g
s
.806 .685 .732 r
.44576 .48358 m .46403 .48927 L .44731 .50875 L p F P
0 g
s
.769 .641 .72 r
.45746 .46708 m .44576 .48358 L .46403 .48927 L p F P
0 g
s
0 0 .207 r
.85645 .38999 m .85066 .40292 L .84872 .41799 L p F P
0 g
s
0 0 .363 r
.85066 .40292 m .85645 .38999 L .85615 .37566 L p F P
0 g
s
.597 .737 .942 r
.32686 .5483 m .35638 .54268 L .36552 .55121 L p F P
0 g
s
.607 .74 .939 r
.35638 .54268 m .32686 .5483 L .3175 .54039 L p F P
0 g
s
0 .255 .745 r
.26998 .51776 m .25928 .51038 L .25086 .5014 L p F P
0 g
s
0 .234 .715 r
.25928 .51038 m .26998 .51776 L .27954 .52661 L p F P
0 g
s
.974 .731 .506 r
.43889 .38032 m .43141 .37065 L .42998 .38501 L p F P
0 g
s
.974 .731 .506 r
.42998 .38501 m .43754 .39463 L .43889 .38032 L p F P
0 g
s
.215 .552 .932 r
.27954 .52661 m .28471 .52807 L .27569 .51939 L p F P
0 g
s
.215 .552 .932 r
.27569 .51939 m .26998 .51776 L .27954 .52661 L p F P
0 g
s
.775 .714 .795 r
.42591 .52969 m .40457 .54616 L .39569 .53594 L p F P
0 g
s
.716 .734 .865 r
.36552 .55121 m .39569 .53594 L .40457 .54616 L p F P
0 g
s
.956 .673 .233 r
.19798 .41135 m .19727 .40147 L .19553 .39771 L closepath p F P
0 g
s
.97 .676 .274 r
.19727 .40147 m .19798 .41135 L .19905 .41626 L p F P
0 g
s
.564 .442 .672 r
.60524 .44459 m .5896 .44444 L .60386 .4382 L closepath p F P
0 g
s
.554 .41 .64 r
.60063 .42075 m .60386 .4382 L .5896 .44444 L p F P
0 g
s
.806 .685 .732 r
.44731 .50875 m .43188 .50222 L .44576 .48358 L p F P
0 g
s
.803 .688 .738 r
.44731 .50875 m .43507 .5226 L .42641 .50927 L p F P
0 g
s
.803 .688 .738 r
.42641 .50927 m .43188 .50222 L .44731 .50875 L p F P
0 g
s
.83 .675 .69 r
.45746 .46708 m .45834 .4654 L .45621 .46438 L closepath p F P
0 g
s
.835 .669 .677 r
.44901 .44756 m .45132 .44189 L p .45834 .4654 L F P
0 g
s
.835 .669 .677 r
.45834 .4654 m .45621 .46438 L .44901 .44756 L p F P
0 g
s
.392 .281 .607 r
.60063 .42075 m .61067 .41212 L .60327 .40027 L p F P
0 g
s
.335 .259 .621 r
.61819 .38382 m .60327 .40027 L .61067 .41212 L p F P
0 g
s
.25 .133 .518 r
.60327 .40027 m .61819 .38382 L .61603 .37037 L p F P
0 g
s
.729 .742 .862 r
.39569 .53594 m .36552 .55121 L .35638 .54268 L p F P
0 g
s
.796 .663 .717 r
.44576 .48358 m .45746 .46708 L .45621 .46438 L p F P
0 g
s
.775 .714 .795 r
.39569 .53594 m .41033 .52326 L .42591 .52969 L p F P
0 g
s
.754 .696 .797 r
.42641 .50927 m .41033 .52326 L .42591 .52969 L p F P
0 g
s
.754 .696 .797 r
.42591 .52969 m .43507 .5226 L .42641 .50927 L p F P
0 g
s
.738 .342 0 r
.21541 .45474 m .20729 .43909 L p .21191 .45009 L F P
0 g
s
.738 .342 0 r
.21191 .45009 m .21791 .46026 L .21541 .45474 L p F P
0 g
s
.796 .663 .717 r
.45621 .46438 m .44247 .45886 L p .44576 .48358 L F P
0 g
s
.812 .66 .694 r
.45621 .46438 m .44901 .44756 L .44247 .45886 L closepath p F P
0 g
s
.656 .839 .429 r
.81689 .48202 m .81701 .48186 L .82807 .46425 L p F P
0 g
s
.656 .839 .429 r
.82807 .46425 m .83694 .45078 L p .81689 .48202 L F P
0 g
s
0 0 0 r
.84083 .44289 m .84226 .43803 L p .82807 .46425 L F P
0 g
s
0 0 0 r
.82807 .46425 m .83694 .45078 L .84083 .44289 L p F P
0 g
s
.423 .33 .646 r
.61067 .41212 m .60063 .42075 L .60386 .4382 L p F P
0 g
s
.615 .667 .877 r
.63823 .53862 m .66984 .53282 L .67757 .5447 L p F P
0 g
s
.594 .588 .815 r
.66194 .51837 m .66984 .53282 L .63823 .53862 L p F P
0 g
s
.594 .588 .815 r
.63776 .52119 m .66194 .51837 L p .63823 .53862 L F P
0 g
s
.594 .588 .815 r
.63823 .53862 m .63154 .52481 L .63776 .52119 L p F P
0 g
s
.87 .699 .668 r
.44901 .44756 m .45132 .44189 L .44322 .43655 L closepath p F P
0 g
s
.877 .69 .645 r
.44047 .43067 m .44426 .41835 L p .45132 .44189 L F P
0 g
s
.877 .69 .645 r
.45132 .44189 m .44322 .43655 L .44047 .43067 L p F P
0 g
s
.964 .741 .299 r
.19318 .37679 m .18954 .36529 L .18899 .37902 L p F P
0 g
s
.964 .741 .299 r
.18899 .37902 m .19264 .39049 L .19318 .37679 L p F P
0 g
s
.331 .618 .955 r
.30806 .53207 m .28471 .52807 L .27569 .51939 L p F P
0 g
s
.674 .968 .922 r
.76649 .52646 m .75526 .53358 L .74844 .53075 L p F P
0 g
s
.65 .919 .977 r
.71671 .54389 m .74844 .53075 L .75526 .53358 L p F P
0 g
s
.924 .644 .161 r
.19553 .39771 m .19264 .39049 L .19387 .40371 L p F P
0 g
s
.924 .644 .161 r
.19798 .41135 m .19553 .39771 L p .19387 .40371 L F P
0 g
s
0 0 .33 r
.85854 .36928 m .85615 .37566 L .85645 .38999 L p F P
0 g
s
.833 .712 .731 r
.43117 .47667 m .44576 .48358 L .43188 .50222 L p F P
0 g
s
.796 .663 .717 r
.44247 .45886 m .43117 .47667 L .44576 .48358 L p F P
0 g
s
.834 .691 .705 r
.44247 .45886 m .44901 .44756 L .44322 .43655 L p F P
0 g
s
.913 .723 .632 r
.44426 .41835 m .44047 .43067 L .43175 .41835 L p F P
0 g
s
.913 .723 .632 r
.43175 .41835 m .43436 .40964 L .44426 .41835 L p F P
0 g
s
.923 .709 .594 r
.44426 .41835 m .43436 .40964 L .43754 .39463 L p F P
0 g
s
.674 .968 .922 r
.78076 .51285 m .76649 .52646 L p .74844 .53075 L F P
0 g
s
.7 .984 .87 r
.76649 .52646 m .78076 .51285 L .78648 .51258 L closepath p F P
0 g
s
0 0 .08 r
.84226 .43803 m .84445 .43386 L .84872 .41799 L p F P
0 g
s
0 0 .006 r
.85451 .40512 m .84872 .41799 L .84445 .43386 L p F P
0 g
s
0 0 .207 r
.84872 .41799 m .85451 .40512 L .85645 .38999 L p F P
0 g
s
.605 .53 .743 r
.62205 .50173 m .60913 .50412 L .62126 .49946 L closepath p F P
0 g
s
.601 .513 .727 r
.61385 .47723 m .62126 .49946 L .60913 .50412 L p F P
0 g
s
.738 .342 0 r
.20729 .43909 m .20664 .438 L .21191 .45009 L p F P
0 g
s
.889 .532 .052 r
.20664 .438 m .20729 .43909 L .20635 .43685 L closepath p F P
0 g
s
0 0 0 r
.81664 .48232 m .81689 .48202 L .81701 .48186 L closepath p F P
0 g
s
.691 .957 .703 r
.81689 .48202 m .81664 .48232 L .79735 .50272 L p F P
0 g
s
.851 .51 0 r
.20635 .43685 m .19905 .41626 L p .20144 .42741 L F P
0 g
s
.851 .51 0 r
.20144 .42741 m .20664 .438 L .20635 .43685 L p F P
0 g
s
.723 .933 .606 r
.81126 .48649 m .82522 .46903 L .81689 .48202 L closepath p F P
0 g
s
.656 .839 .429 r
.83694 .45078 m .82522 .46903 L .81689 .48202 L p F P
0 g
s
.691 .957 .703 r
.81126 .48649 m .81689 .48202 L p .79735 .50272 L F P
0 g
s
0 0 .439 r
.21791 .46026 m .21191 .45009 L .21956 .46155 L p F P
0 g
s
0 0 .439 r
.21956 .46155 m .22565 .47168 L .21791 .46026 L p F P
0 g
s
.924 .644 .161 r
.19387 .40371 m .1983 .41473 L .19798 .41135 L p F P
0 g
s
.95 .655 .212 r
.1983 .41473 m .19905 .41626 L .19798 .41135 L closepath p F P
0 g
s
.498 .399 .673 r
.60386 .4382 m .62175 .42299 L p .6178 .45011 L F P
0 g
s
.498 .399 .673 r
.6178 .45011 m .60524 .44459 L .60386 .4382 L p F P
0 g
s
.423 .33 .646 r
.60386 .4382 m .62175 .42299 L .61067 .41212 L p F P
0 g
s
.593 .585 .813 r
.63154 .52481 m .63021 .52202 L .63776 .52119 L closepath p F P
0 g
s
0 .085 .623 r
.23248 .48143 m .22565 .47168 L .23621 .48236 L p F P
0 g
s
0 .085 .623 r
.23621 .48236 m .24317 .49206 L .23248 .48143 L p F P
0 g
s
0 0 0 r
.84083 .44289 m .84445 .43386 L .84226 .43803 L closepath p F P
0 g
s
.695 .325 0 r
.20664 .438 m .20144 .42741 L .20666 .43953 L p F P
0 g
s
.695 .325 0 r
.20666 .43953 m .21191 .45009 L .20664 .438 L p F P
0 g
s
.96 .755 .582 r
.43754 .39463 m .42998 .38501 L .42663 .40011 L p F P
0 g
s
.96 .755 .582 r
.42663 .40011 m .43436 .40964 L .43754 .39463 L p F P
0 g
s
.631 .779 .952 r
.67757 .5447 m .70938 .53653 L .71671 .54389 L p F P
0 g
s
.609 .714 .92 r
.70938 .53653 m .67757 .5447 L .66984 .53282 L p F P
0 g
s
.851 .51 0 r
.19905 .41626 m .1983 .41473 L .20144 .42741 L p F P
0 g
s
.804 .999 .843 r
.78076 .51285 m .78648 .51258 L .79735 .50272 L p F P
0 g
s
.804 .999 .843 r
.79735 .50272 m .80906 .48863 L p .78076 .51285 L F P
0 g
s
.691 .957 .703 r
.79735 .50272 m .80906 .48863 L .81126 .48649 L p F P
0 g
s
.593 .55 .776 r
.63776 .52119 m .63021 .52202 L .62205 .50173 L p F P
0 g
s
.65 .856 .978 r
.74844 .53075 m .71671 .54389 L .70938 .53653 L p F P
0 g
s
.851 .719 .717 r
.4296 .45128 m .44247 .45886 L .43117 .47667 L p F P
0 g
s
.834 .691 .705 r
.43889 .43414 m .4296 .45128 L .44247 .45886 L p F P
0 g
s
.834 .691 .705 r
.44322 .43655 m .43889 .43414 L p .44247 .45886 L F P
0 g
s
.83 .715 .737 r
.43188 .50222 m .42641 .50927 L .41765 .49668 L p F P
0 g
s
.83 .715 .737 r
.41765 .49668 m .41896 .49483 L .43188 .50222 L p F P
0 g
s
.833 .712 .731 r
.43188 .50222 m .41896 .49483 L .43117 .47667 L p F P
0 g
s
.485 .408 .695 r
.60838 .45717 m .60524 .44459 L .6178 .45011 L closepath p F P
0 g
s
.795 .735 .797 r
.41033 .52326 m .39569 .53594 L .38672 .52591 L p F P
0 g
s
.729 .742 .862 r
.35638 .54268 m .38672 .52591 L .39569 .53594 L p F P
0 g
s
.607 .74 .939 r
.3175 .54039 m .34714 .53406 L .35638 .54268 L p F P
0 g
s
.61 .743 .94 r
.34714 .53406 m .3175 .54039 L .30806 .53207 L p F P
0 g
s
.849 .682 .676 r
.44322 .43655 m .44047 .43067 L .43889 .43414 L closepath p F P
0 g
s
.795 .735 .797 r
.38672 .52591 m .3973 .51596 L .41033 .52326 L p F P
0 g
s
.775 .713 .794 r
.41765 .49668 m .3973 .51596 L .41033 .52326 L p F P
0 g
s
.775 .713 .794 r
.41033 .52326 m .42641 .50927 L .41765 .49668 L p F P
0 g
s
.812 .494 0 r
.1983 .41473 m .19387 .40371 L .19698 .41641 L p F P
0 g
s
.812 .494 0 r
.19698 .41641 m .20144 .42741 L .1983 .41473 L p F P
0 g
s
0 .266 .762 r
.26039 .50809 m .25086 .5014 L .24317 .49206 L p F P
0 g
s
0 .255 .745 r
.25086 .5014 m .26039 .50809 L .26998 .51776 L p F P
0 g
s
.229 .541 .926 r
.26998 .51776 m .27569 .51939 L .26764 .51028 L p F P
0 g
s
.229 .541 .926 r
.26764 .51028 m .26039 .50809 L .26998 .51776 L p F P
0 g
s
.997 .778 .437 r
.43141 .37065 m .42679 .35989 L .42519 .37434 L p F P
0 g
s
.997 .778 .437 r
.42519 .37434 m .42998 .38501 L .43141 .37065 L p F P
0 g
s
.086 .024 .484 r
.61781 .36729 m .61603 .37037 L .61819 .38382 L p F P
0 g
s
.537 .453 .708 r
.60838 .45717 m .6178 .45011 L p .61428 .47694 L F P
0 g
s
.537 .453 .708 r
.61428 .47694 m .61373 .47686 L .60838 .45717 L p F P
0 g
s
.884 .731 .686 r
.43889 .43414 m .44047 .43067 L .43175 .41835 L p F P
0 g
s
.739 .754 .865 r
.38672 .52591 m .35638 .54268 L .34714 .53406 L p F P
0 g
s
0 0 .283 r
.86029 .36302 m .85854 .36928 L .85932 .38241 L p F P
0 g
s
0 0 .33 r
.85645 .38999 m .85932 .38241 L .85854 .36928 L p F P
0 g
s
.593 .55 .776 r
.62205 .50173 m .65389 .50111 L p .63776 .52119 L F P
0 g
s
.544 .494 .751 r
.64654 .483 m .65389 .50111 L .62205 .50173 L p F P
0 g
s
.544 .494 .751 r
.62205 .50173 m .62126 .49946 L .64654 .483 L p F P
0 g
s
.595 .584 .811 r
.66194 .51837 m .63776 .52119 L .65792 .50981 L closepath p F P
0 g
s
.593 .55 .776 r
.65389 .50111 m .65792 .50981 L .63776 .52119 L p F P
0 g
s
.536 .485 .745 r
.64569 .48085 m .64654 .483 L .62126 .49946 L p F P
0 g
s
.536 .485 .745 r
.61428 .47694 m .64569 .48085 L p .62126 .49946 L F P
0 g
s
.536 .485 .745 r
.62126 .49946 m .61385 .47723 L .61428 .47694 L p F P
0 g
s
.879 .744 .709 r
.42849 .42563 m .43889 .43414 L .4296 .45128 L p F P
0 g
s
.884 .731 .686 r
.43175 .41835 m .42849 .42563 L .43889 .43414 L p F P
0 g
s
.889 .628 .112 r
.19264 .39049 m .18899 .37902 L .1902 .39227 L p F P
0 g
s
.889 .628 .112 r
.1902 .39227 m .19387 .40371 L .19264 .39049 L p F P
0 g
s
0 0 0 r
.84445 .43386 m .85018 .42108 L p .83937 .4467 L F P
0 g
s
0 0 0 r
.83937 .4467 m .84083 .44289 L .84445 .43386 L p F P
0 g
s
0 0 .006 r
.84445 .43386 m .85018 .42108 L .85451 .40512 L p F P
0 g
s
.382 .326 .67 r
.62197 .39938 m .61067 .41212 L .62175 .42299 L p F P
0 g
s
.335 .259 .621 r
.62002 .38799 m .61819 .38382 L p .61067 .41212 L F P
0 g
s
.335 .259 .621 r
.61067 .41212 m .62197 .39938 L .62002 .38799 L p F P
0 g
s
.53 .473 .736 r
.61385 .47723 m .61373 .47686 L .61428 .47694 L closepath p F P
0 g
s
.534 .492 .756 r
.64569 .48085 m .61428 .47694 L .63824 .45961 L closepath p F P
0 g
s
.537 .453 .708 r
.63735 .45695 m .63824 .45961 L .61428 .47694 L p F P
0 g
s
.537 .453 .708 r
.6178 .45011 m .63735 .45695 L p .61428 .47694 L F P
0 g
s
0 0 .154 r
.85932 .38241 m .85645 .38999 L .85451 .40512 L p F P
0 g
s
.85 .738 .74 r
.41916 .46885 m .43117 .47667 L .41896 .49483 L p F P
0 g
s
.851 .719 .717 r
.43117 .47667 m .41916 .46885 L .4296 .45128 L p F P
0 g
s
0 0 .435 r
.62241 .3564 m .61781 .36729 L .61907 .38232 L p F P
0 g
s
.086 .024 .484 r
.61819 .38382 m .61907 .38232 L .61781 .36729 L p F P
0 g
s
.344 .611 .949 r
.29855 .52337 m .27569 .51939 L .26764 .51028 L p F P
0 g
s
.331 .618 .955 r
.27569 .51939 m .29855 .52337 L .30806 .53207 L p F P
0 g
s
.948 .769 .628 r
.43175 .41835 m .43436 .40964 L .42663 .40011 L p F P
0 g
s
0 0 0 r
.83694 .45078 m .83937 .4467 L .84083 .44289 L closepath p F P
0 g
s
.609 .714 .92 r
.66984 .53282 m .70185 .52691 L .70938 .53653 L p F P
0 g
s
.58 .658 .891 r
.70185 .52691 m .66984 .53282 L .66194 .51837 L p F P
0 g
s
.935 .731 .253 r
.18954 .36529 m .18669 .35334 L .18612 .36711 L p F P
0 g
s
.935 .731 .253 r
.18612 .36711 m .18899 .37902 L .18954 .36529 L p F P
0 g
s
.674 .968 .922 r
.74844 .53075 m .7801 .51277 L .78076 .51285 L p F P
0 g
s
.685 .937 .965 r
.7801 .51277 m .74844 .53075 L .7414 .52568 L p F P
0 g
s
.65 .856 .978 r
.70938 .53653 m .7414 .52568 L .74844 .53075 L p F P
0 g
s
.875 .753 .724 r
.41941 .44273 m .4296 .45128 L .41916 .46885 L p F P
0 g
s
.879 .744 .709 r
.4296 .45128 m .41941 .44273 L .42849 .42563 L p F P
0 g
s
.846 .74 .747 r
.41765 .49668 m .41896 .49483 L .41273 .49037 L closepath p F P
0 g
s
.85 .738 .74 r
.40879 .48525 m .41916 .46885 L p .41896 .49483 L F P
0 g
s
.85 .738 .74 r
.41896 .49483 m .41273 .49037 L .40879 .48525 L p F P
0 g
s
.796 .736 .797 r
.3973 .51596 m .41765 .49668 L .41273 .49037 L p F P
0 g
s
.693 .882 .5 r
.83937 .4467 m .83694 .45078 L .82522 .46903 L p F P
0 g
s
.81 .754 .8 r
.3973 .51596 m .38672 .52591 L .37765 .5163 L p F P
0 g
s
.81 .754 .8 r
.37765 .5163 m .38602 .50801 L .3973 .51596 L p F P
0 g
s
.796 .736 .797 r
.40705 .48702 m .38602 .50801 L .3973 .51596 L p F P
0 g
s
.796 .736 .797 r
.41273 .49037 m .40705 .48702 L p .3973 .51596 L F P
0 g
s
.739 .754 .865 r
.34714 .53406 m .37765 .5163 L .38672 .52591 L p F P
0 g
s
.993 .811 .555 r
.42998 .38501 m .42519 .37434 L .42142 .38961 L p F P
0 g
s
.993 .811 .555 r
.42142 .38961 m .42663 .40011 L .42998 .38501 L p F P
0 g
s
0 0 .283 r
.85932 .38241 m .86074 .37736 L .86029 .36302 L p F P
0 g
s
0 0 .23 r
.86278 .35074 m .86029 .36302 L .86074 .37736 L p F P
0 g
s
.486 .438 .729 r
.63735 .45695 m .6178 .45011 L .63164 .43816 L closepath p F P
0 g
s
.498 .399 .673 r
.62884 .42815 m .63164 .43816 L .6178 .45011 L p F P
0 g
s
.498 .399 .673 r
.62175 .42299 m .62884 .42815 L p .6178 .45011 L F P
0 g
s
0 0 .478 r
.21191 .45009 m .20666 .43953 L .21422 .45103 L p F P
0 g
s
0 0 .478 r
.21422 .45103 m .21956 .46155 L .21191 .45009 L p F P
0 g
s
0 .102 .647 r
.22565 .47168 m .21956 .46155 L .22997 .47228 L p F P
0 g
s
0 .102 .647 r
.22997 .47228 m .23621 .48236 L .22565 .47168 L p F P
0 g
s
.948 .769 .628 r
.42663 .40011 m .42276 .41251 L .43175 .41835 L p F P
0 g
s
.928 .796 .695 r
.43175 .41835 m .42849 .42563 L .42115 .416 L p F P
0 g
s
.928 .796 .695 r
.42115 .416 m .42276 .41251 L .43175 .41835 L p F P
0 g
s
.232 .522 .915 r
.26039 .50809 m .26764 .51028 L .2605 .50076 L p F P
0 g
s
.232 .522 .915 r
.2605 .50076 m .25077 .49755 L .26039 .50809 L p F P
0 g
s
0 .266 .762 r
.24317 .49206 m .25077 .49755 L .26039 .50809 L p F P
0 g
s
.61 .743 .94 r
.30806 .53207 m .33781 .52544 L .34714 .53406 L p F P
0 g
s
.61 .746 .942 r
.32837 .51686 m .29855 .52337 L .30806 .53207 L p F P
0 g
s
.61 .746 .942 r
.30806 .53207 m .33781 .52544 L .32837 .51686 L p F P
0 g
s
.628 .789 .959 r
.7414 .52568 m .70938 .53653 L .70185 .52691 L p F P
0 g
s
.197 .161 .589 r
.62002 .38799 m .61819 .38382 L .61907 .38232 L closepath p F P
0 g
s
0 0 .292 r
.20144 .42741 m .19698 .41641 L .20215 .42857 L p F P
0 g
s
0 0 .292 r
.20215 .42857 m .20666 .43953 L .20144 .42741 L p F P
0 g
s
0 0 0 r
.8588 .39386 m .85451 .40512 L .85018 .42108 L p F P
0 g
s
0 0 .154 r
.85451 .40512 m .8588 .39386 L .85932 .38241 L p F P
0 g
s
0 .268 .77 r
.25077 .49755 m .24317 .49206 L .23621 .48236 L p F P
0 g
s
0 0 .105 r
.86074 .37736 m .85932 .38241 L .8588 .39386 L p F P
0 g
s
.226 .181 .596 r
.61907 .38232 m .62432 .36998 L p .62386 .39629 L F P
0 g
s
.226 .181 .596 r
.62386 .39629 m .62002 .38799 L .61907 .38232 L p F P
0 g
s
0 0 .435 r
.61907 .38232 m .62432 .36998 L .62241 .3564 L p F P
0 g
s
.91 .792 .719 r
.42849 .42563 m .42115 .416 L .41172 .43327 L p F P
0 g
s
.91 .792 .719 r
.41172 .43327 m .41941 .44273 L .42849 .42563 L p F P
0 g
s
.745 .769 .872 r
.37765 .5163 m .34714 .53406 L .33781 .52544 L p F P
0 g
s
.773 .987 .896 r
.7801 .51277 m .78185 .51145 L .78076 .51285 L closepath p F P
0 g
s
.804 .999 .843 r
.80906 .48863 m .78185 .51145 L .78076 .51285 L p F P
0 g
s
.756 .463 0 r
.19387 .40371 m .1902 .39227 L .19328 .405 L p F P
0 g
s
.756 .463 0 r
.19328 .405 m .19698 .41641 L .19387 .40371 L p F P
0 g
s
.839 .989 .724 r
.82522 .46903 m .83301 .4558 L p .81046 .48679 L F P
0 g
s
.839 .989 .724 r
.81046 .48679 m .81126 .48649 L .82522 .46903 L p F P
0 g
s
.693 .882 .5 r
.8357 .45185 m .83937 .4467 L p .82522 .46903 L F P
0 g
s
.693 .882 .5 r
.82522 .46903 m .83301 .4558 L .8357 .45185 L p F P
0 g
s
.888 .751 .247 r
.42679 .35989 m .42612 .34766 L .42425 .36224 L p F P
0 g
s
.888 .751 .247 r
.42425 .36224 m .42519 .37434 L .42679 .35989 L p F P
0 g
s
.87 .755 .734 r
.41916 .46885 m .40879 .48525 L .39978 .47544 L p F P
0 g
s
.87 .755 .734 r
.39978 .47544 m .4092 .46027 L .41916 .46885 L p F P
0 g
s
.875 .753 .724 r
.41916 .46885 m .4092 .46027 L .41941 .44273 L p F P
0 g
s
.804 .734 .787 r
.41273 .49037 m .40879 .48525 L .40705 .48702 L closepath p F P
0 g
s
0 0 0 r
.85018 .42108 m .84329 .4379 L .83937 .4467 L p F P
0 g
s
.738 .867 .445 r
.8357 .45185 m .84329 .4379 L .83937 .4467 L closepath p F P
0 g
s
.58 .658 .891 r
.66194 .51837 m .69415 .51517 L .70185 .52691 L p F P
0 g
s
.556 .564 .817 r
.6863 .50143 m .69415 .51517 L .66194 .51837 L p F P
0 g
s
.556 .564 .817 r
.66812 .50131 m .6863 .50143 L p .66194 .51837 L F P
0 g
s
.556 .564 .817 r
.66194 .51837 m .65792 .50981 L .66812 .50131 L p F P
0 g
s
.214 .175 .596 r
.62197 .39938 m .62002 .38799 L .62386 .39629 L closepath p F P
0 g
s
.78 .957 .927 r
.78185 .51145 m .7801 .51277 L .77341 .51011 L p F P
0 g
s
.685 .937 .965 r
.7414 .52568 m .77341 .51011 L .7801 .51277 L p F P
0 g
s
.78 .957 .927 r
.77341 .51011 m .79099 .49805 L .78185 .51145 L p F P
0 g
s
.791 .981 .903 r
.81046 .48679 m .80906 .48863 L .78185 .51145 L p F P
0 g
s
.791 .981 .903 r
.80508 .48731 m .81046 .48679 L p .78185 .51145 L F P
0 g
s
.791 .981 .903 r
.78185 .51145 m .79099 .49805 L .80508 .48731 L p F P
0 g
s
.734 .978 .745 r
.80906 .48863 m .81046 .48679 L .81126 .48649 L closepath p F P
0 g
s
.409 .365 .698 r
.62884 .42815 m .62175 .42299 L .6262 .41804 L closepath p F P
0 g
s
.382 .326 .67 r
.62175 .42299 m .6262 .41804 L .62197 .39938 L p F P
0 g
s
.347 .6 .942 r
.28895 .51425 m .26764 .51028 L .2605 .50076 L p F P
0 g
s
.344 .611 .949 r
.26764 .51028 m .28895 .51425 L .29855 .52337 L p F P
0 g
s
.84 .602 .056 r
.18899 .37902 m .18612 .36711 L .18732 .38039 L p F P
0 g
s
.84 .602 .056 r
.18732 .38039 m .1902 .39227 L .18899 .37902 L p F P
0 g
s
.554 .559 .814 r
.65792 .50981 m .65389 .50111 L .66812 .50131 L closepath p F P
0 g
s
0 0 .211 r
.62304 .34412 m .62241 .3564 L .62432 .36998 L p F P
0 g
s
.971 .822 .639 r
.42663 .40011 m .42142 .38961 L .4159 .40557 L p F P
0 g
s
.971 .822 .639 r
.42276 .41251 m .42663 .40011 L p .4159 .40557 L F P
0 g
s
.819 .764 .801 r
.40705 .48702 m .40879 .48525 L .39978 .47544 L p F P
0 g
s
.822 .772 .805 r
.39674 .4786 m .40705 .48702 L .38602 .50801 L p F P
0 g
s
.819 .764 .801 r
.39978 .47544 m .39674 .4786 L .40705 .48702 L p F P
0 g
s
.276 .254 .653 r
.62386 .39629 m .62197 .39938 L .6262 .41804 L p F P
0 g
s
.827 1 .812 r
.80508 .48731 m .81661 .47557 L .81046 .48679 L closepath p F P
0 g
s
.839 .989 .724 r
.83301 .4558 m .81661 .47557 L .81046 .48679 L p F P
0 g
s
0 0 .105 r
.8588 .39386 m .85921 .39243 L .86074 .37736 L p F P
0 g
s
0 0 .032 r
.86325 .36513 m .86074 .37736 L .85921 .39243 L p F P
0 g
s
0 0 .23 r
.86074 .37736 m .86325 .36513 L .86278 .35074 L p F P
0 g
s
0 0 0 r
.85837 .39617 m .8588 .39386 L p .85018 .42108 L F P
0 g
s
0 0 0 r
.85018 .42108 m .855 .40842 L .85837 .39617 L p F P
0 g
s
.706 .793 .318 r
.855 .40842 m .85018 .42108 L .84329 .4379 L p F P
0 g
s
.897 .789 .733 r
.41941 .44273 m .41172 .43327 L .40113 .45098 L p F P
0 g
s
.897 .789 .733 r
.40113 .45098 m .4092 .46027 L .41941 .44273 L p F P
0 g
s
.821 .772 .807 r
.38602 .50801 m .37765 .5163 L .36845 .50726 L p F P
0 g
s
.821 .772 .807 r
.36845 .50726 m .37615 .49952 L .38602 .50801 L p F P
0 g
s
.822 .772 .805 r
.38602 .50801 m .37615 .49952 L .39674 .4786 L p F P
0 g
s
.745 .769 .872 r
.33781 .52544 m .36845 .50726 L .37765 .5163 L p F P
0 g
s
.559 .535 .784 r
.66812 .50131 m .65389 .50111 L .64654 .483 L p F P
0 g
s
.227 .498 .901 r
.25077 .49755 m .2605 .50076 L .25417 .49084 L p F P
0 g
s
.227 .498 .901 r
.25417 .49084 m .24113 .48605 L .25077 .49755 L p F P
0 g
s
0 .268 .77 r
.23621 .48236 m .24113 .48605 L .25077 .49755 L p F P
0 g
s
.628 .789 .959 r
.70185 .52691 m .73415 .51856 L .7414 .52568 L p F P
0 g
s
.597 .729 .937 r
.73415 .51856 m .70185 .52691 L .69415 .51517 L p F P
0 g
s
.894 .711 .2 r
.18669 .35334 m .18468 .34093 L .18409 .35474 L p F P
0 g
s
.894 .711 .2 r
.18409 .35474 m .18612 .36711 L .18669 .35334 L p F P
0 g
s
.606 .747 .945 r
.31883 .50828 m .28895 .51425 L .29855 .52337 L p F P
0 g
s
.606 .747 .945 r
.29855 .52337 m .32837 .51686 L .31883 .50828 L p F P
0 g
s
.676 .882 .975 r
.77341 .51011 m .7414 .52568 L .73415 .51856 L p F P
0 g
s
.276 .254 .653 r
.6262 .41804 m .63241 .408 L .62386 .39629 L p F P
0 g
s
.069 .128 .618 r
.62898 .38282 m .62386 .39629 L .63241 .408 L p F P
0 g
s
.226 .181 .596 r
.62432 .36998 m .62898 .38282 L .62386 .39629 L p F P
0 g
s
.978 .86 .474 r
.42519 .37434 m .42425 .36224 L .41973 .37781 L p F P
0 g
s
.978 .86 .474 r
.41973 .37781 m .42142 .38961 L .42519 .37434 L p F P
0 g
s
.403 .361 .697 r
.6262 .41804 m .63241 .408 L p .63554 .43318 L F P
0 g
s
.403 .361 .697 r
.63554 .43318 m .62884 .42815 L .6262 .41804 L p F P
0 g
s
0 .117 .665 r
.21956 .46155 m .21422 .45103 L p .22799 .46847 L F P
0 g
s
0 .117 .665 r
.22799 .46847 m .22997 .47228 L .21956 .46155 L p F P
0 g
s
0 0 .51 r
.20666 .43953 m .20215 .42857 L .20963 .44011 L p F P
0 g
s
0 0 .51 r
.20963 .44011 m .21422 .45103 L .20666 .43953 L p F P
0 g
s
.559 .535 .784 r
.64654 .483 m .64836 .4813 L p .66812 .50131 L F P
0 g
s
.513 .503 .782 r
.64654 .483 m .64569 .48085 L .64836 .4813 L closepath p F P
0 g
s
.971 .822 .639 r
.4159 .40557 m .41977 .41255 L .42276 .41251 L p F P
0 g
s
.964 .862 .691 r
.41977 .41255 m .42276 .41251 L .42115 .416 L closepath p F P
0 g
s
.387 .361 .708 r
.63164 .43816 m .62884 .42815 L .63554 .43318 L closepath p F P
0 g
s
.522 .485 .757 r
.64836 .4813 m .64569 .48085 L .63824 .45961 L p F P
0 g
s
0 .264 .771 r
.24113 .48605 m .23621 .48236 L .22997 .47228 L p F P
0 g
s
0 0 .169 r
.86432 .3386 m .86278 .35074 L .86325 .36513 L p F P
0 g
s
.749 .785 .882 r
.35913 .49886 m .32837 .51686 L .33781 .52544 L p F P
0 g
s
.749 .785 .882 r
.33781 .52544 m .36845 .50726 L .35913 .49886 L p F P
0 g
s
0 0 .338 r
.19698 .41641 m .19328 .405 L .19841 .41719 L p F P
0 g
s
0 0 .338 r
.19841 .41719 m .20215 .42857 L .19698 .41641 L p F P
0 g
s
.89 .79 .743 r
.39978 .47544 m .4092 .46027 L .40113 .45098 L p F P
0 g
s
.473 .43 .729 r
.63164 .43816 m .63554 .43318 L p .63981 .45793 L F P
0 g
s
.473 .43 .729 r
.63981 .45793 m .63735 .45695 L .63164 .43816 L p F P
0 g
s
.94 .871 .743 r
.42115 .416 m .41172 .43327 L .40676 .42278 L p F P
0 g
s
.94 .871 .743 r
.41977 .41255 m .42115 .416 L p .40676 .42278 L F P
0 g
s
.851 .934 .558 r
.84329 .4379 m .84797 .42535 L p .83449 .45296 L F P
0 g
s
.851 .934 .558 r
.83449 .45296 m .8357 .45185 L .84329 .4379 L p F P
0 g
s
.706 .793 .318 r
.84329 .4379 m .84797 .42535 L .855 .40842 L p F P
0 g
s
0 0 0 r
.85837 .39617 m .85921 .39243 L .8588 .39386 L closepath p F P
0 g
s
.522 .485 .757 r
.63824 .45961 m .63981 .45793 L p .64836 .4813 L F P
0 g
s
.46 .439 .748 r
.63824 .45961 m .63735 .45695 L .63981 .45793 L closepath p F P
0 g
s
.559 .535 .784 r
.64836 .4813 m .67831 .48578 L p .66812 .50131 L F P
0 g
s
.472 .464 .768 r
.64836 .4813 m .67831 .48578 L .67019 .46822 L p F P
0 g
s
.472 .464 .768 r
.67019 .46822 m .66247 .46578 L .64836 .4813 L p F P
0 g
s
.522 .485 .757 r
.63981 .45793 m .66247 .46578 L .64836 .4813 L p F P
0 g
s
0 0 .032 r
.85921 .39243 m .86171 .38025 L .86325 .36513 L p F P
0 g
s
0 0 0 r
.855 .40842 m .85662 .40317 L .85837 .39617 L closepath p F P
0 g
s
.733 .719 .191 r
.85921 .39243 m .86171 .38025 L p .85662 .40317 L F P
0 g
s
.733 .719 .191 r
.85662 .40317 m .85837 .39617 L .85921 .39243 L p F P
0 g
s
.689 .426 0 r
.1902 .39227 m .18732 .38039 L .19039 .39315 L p F P
0 g
s
.689 .426 0 r
.19039 .39315 m .19328 .405 L .1902 .39227 L p F P
0 g
s
.435 .475 .802 r
.65113 .44302 m .63981 .45793 L .66247 .46578 L p F P
0 g
s
.473 .43 .729 r
.63554 .43318 m .65113 .44302 L .63981 .45793 L p F P
0 g
s
0 0 .387 r
.6247 .35782 m .62432 .36998 L .62898 .38282 L p F P
0 g
s
0 0 .387 r
.62864 .37093 m .6247 .35782 L p .62609 .36594 L F P
0 g
s
0 0 .387 r
.62898 .38282 m .62864 .37093 L p .62609 .36594 L F P
0 g
s
0 0 .312 r
.62864 .37093 m .63443 .38358 L p .63122 .37597 L F P
0 g
s
.78 .467 0 r
.6247 .35782 m .62864 .37093 L p .62592 .36233 L F P
0 g
s
0 0 .211 r
.62432 .36998 m .6247 .35782 L p .6235 .35336 L F P
0 g
s
.78 .467 0 r
.62454 .36009 m .621 .34683 L p .62378 .35559 L F P
0 g
s
.78 .467 0 r
.62864 .37093 m .62454 .36009 L p .62378 .35559 L F P
0 g
s
0 0 .312 r
.62454 .36009 m .62864 .37093 L p .63122 .37597 L F P
0 g
s
.842 .441 0 r
.62454 .36009 m .62864 .37025 L .62538 .36508 L p F P
0 g
s
.842 .441 0 r
.62538 .36508 m .62043 .35725 L p .62454 .36009 L F P
0 g
s
.78 .467 0 r
.621 .34683 m .6247 .35782 L p .62592 .36233 L F P
0 g
s
0 0 .211 r
.6247 .35782 m .62304 .34412 L p .6235 .35336 L F P
0 g
s
0 0 .085 r
.42612 .34766 m .42962 .33653 L .42823 .34962 L p F P
0 g
s
0 0 .085 r
.42823 .34962 m .42425 .36224 L .42612 .34766 L p F P
0 g
s
.55 .583 .84 r
.6863 .50143 m .66812 .50131 L .6799 .48893 L closepath p F P
0 g
s
.559 .535 .784 r
.67831 .48578 m .6799 .48893 L .66812 .50131 L p F P
0 g
s
.89 .79 .743 r
.40113 .45098 m .39061 .4675 L .39978 .47544 L p F P
0 g
s
.835 .799 .817 r
.39978 .47544 m .39674 .4786 L .38886 .46929 L p F P
0 g
s
.835 .799 .817 r
.38886 .46929 m .39061 .4675 L .39978 .47544 L p F P
0 g
s
.342 .584 .933 r
.27929 .50465 m .2605 .50076 L .25417 .49084 L p F P
0 g
s
.347 .6 .942 r
.2605 .50076 m .27929 .50465 L .28895 .51425 L p F P
0 g
s
.83 .79 .814 r
.39674 .4786 m .38886 .46929 L .3676 .4905 L p F P
0 g
s
.83 .79 .814 r
.3676 .4905 m .37615 .49952 L .39674 .4786 L p F P
0 g
s
.957 .828 .675 r
.4135 .4113 m .4159 .40557 L .41977 .41255 L closepath p F P
0 g
s
.94 .871 .743 r
.40676 .42278 m .4135 .4113 L .41977 .41255 L p F P
0 g
s
.758 .924 .563 r
.83301 .4558 m .83449 .45296 L .8357 .45185 L closepath p F P
0 g
s
.743 .961 .939 r
.79099 .49805 m .77341 .51011 L .7665 .50551 L p F P
0 g
s
.676 .882 .975 r
.73415 .51856 m .7665 .50551 L .77341 .51011 L p F P
0 g
s
.218 .47 .884 r
.24113 .48605 m .25417 .49084 L .24858 .48054 L p F P
0 g
s
.218 .47 .884 r
.24858 .48054 m .2315 .47347 L .24113 .48605 L p F P
0 g
s
0 .264 .771 r
.22997 .47228 m .2315 .47347 L .24113 .48605 L p F P
0 g
s
.838 .998 .774 r
.83449 .45296 m .83301 .4558 L .81661 .47557 L p F P
0 g
s
.597 .729 .937 r
.69415 .51517 m .72671 .50959 L .73415 .51856 L p F P
0 g
s
.559 .676 .917 r
.72671 .50959 m .69415 .51517 L .6863 .50143 L p F P
0 g
s
.992 .881 .602 r
.42142 .38961 m .41973 .37781 L .41312 .39417 L p F P
0 g
s
.992 .881 .602 r
.41312 .39417 m .4159 .40557 L .42142 .38961 L p F P
0 g
s
.829 .79 .815 r
.36845 .50726 m .37615 .49952 L .3676 .4905 L p F P
0 g
s
.918 .832 .744 r
.41172 .43327 m .40676 .42278 L .39514 .44088 L p F P
0 g
s
.918 .832 .744 r
.39514 .44088 m .40113 .45098 L .41172 .43327 L p F P
0 g
s
.326 .391 .777 r
.64297 .41925 m .63554 .43318 L .65113 .44302 L p F P
0 g
s
.403 .361 .697 r
.63241 .408 m .64297 .41925 L .63554 .43318 L p F P
0 g
s
.829 .79 .815 r
.3676 .4905 m .35913 .49886 L .36845 .50726 L p F P
0 g
s
.777 .566 0 r
.18612 .36711 m .18409 .35474 L .18528 .36805 L p F P
0 g
s
.777 .566 0 r
.18528 .36805 m .18732 .38039 L .18612 .36711 L p F P
0 g
s
.891 .624 .11 r
.6195 .33305 m .62304 .34412 L .6247 .35782 L p F P
0 g
s
.743 .961 .939 r
.79942 .48604 m .79099 .49805 L p .7665 .50551 L F P
0 g
s
.788 .983 .901 r
.79099 .49805 m .79942 .48604 L .80508 .48731 L closepath p F P
0 g
s
.594 .744 .948 r
.30919 .49962 m .27929 .50465 L .28895 .51425 L p F P
0 g
s
.594 .744 .948 r
.28895 .51425 m .31883 .50828 L .30919 .49962 L p F P
0 g
s
.867 .978 .85 r
.81661 .47557 m .82301 .46268 L p .79942 .48604 L F P
0 g
s
.867 .978 .85 r
.79942 .48604 m .80508 .48731 L .81661 .47557 L p F P
0 g
s
.838 .998 .774 r
.82991 .45493 m .83449 .45296 L p .81661 .47557 L F P
0 g
s
.838 .998 .774 r
.81661 .47557 m .82301 .46268 L .82991 .45493 L p F P
0 g
s
0 0 0 r
.86479 .35303 m .86325 .36513 L .86171 .38025 L p F P
0 g
s
0 0 .169 r
.86325 .36513 m .86479 .35303 L .86432 .3386 L p F P
0 g
s
.87 .98 .685 r
.82991 .45493 m .83799 .44324 L .83449 .45296 L closepath p F P
0 g
s
.851 .934 .558 r
.84797 .42535 m .83799 .44324 L .83449 .45296 L p F P
0 g
s
.65 .825 .967 r
.7665 .50551 m .73415 .51856 L .72671 .50959 L p F P
0 g
s
.794 .859 .413 r
.85662 .40317 m .855 .40842 L .84797 .42535 L p F P
0 g
s
.047 .164 .665 r
.63583 .39511 m .63241 .408 L .64297 .41925 L p F P
0 g
s
.069 .128 .618 r
.63241 .408 m .63583 .39511 L .62898 .38282 L p F P
0 g
s
.75 .8 .893 r
.34968 .49105 m .31883 .50828 L .32837 .51686 L p F P
0 g
s
.75 .8 .893 r
.32837 .51686 m .35913 .49886 L .34968 .49105 L p F P
0 g
s
.838 .681 .142 r
.18468 .34093 m .18411 .33448 L .18363 .34954 L p F P
0 g
s
.838 .681 .142 r
.18363 .34954 m .18409 .35474 L .18468 .34093 L p F P
0 g
s
0 .122 .672 r
.22192 .45926 m .21422 .45103 L .20963 .44011 L p F P
0 g
s
0 .117 .665 r
.21422 .45103 m .22192 .45926 L .22799 .46847 L p F P
0 g
s
.894 .815 .763 r
.40113 .45098 m .39514 .44088 L .3826 .45934 L p F P
0 g
s
.894 .815 .763 r
.39061 .4675 m .40113 .45098 L p .3826 .45934 L F P
0 g
s
0 0 .537 r
.20215 .42857 m .19841 .41719 L p .20776 .43449 L F P
0 g
s
0 0 .537 r
.20776 .43449 m .20963 .44011 L .20215 .42857 L p F P
0 g
s
0 0 0 r
.42425 .36224 m .4242 .36243 L p .42336 .36406 L F P
0 g
s
0 0 0 r
.42823 .34962 m .42425 .36224 L p .42336 .36406 L F P
0 g
s
0 0 0 r
.42495 .36085 m .42716 .35338 L .42336 .36406 L closepath p F P
0 g
s
.638 .776 .316 r
.42336 .36406 m .42495 .36085 L .42302 .36473 L p F P
0 g
s
.638 .776 .316 r
.42302 .36473 m .4201 .37062 L p .42336 .36406 L F P
0 g
s
0 0 0 r
.4242 .36243 m .41973 .37781 L .42336 .36406 L p F P
0 g
s
0 .257 .767 r
.2315 .47347 m .22997 .47228 L .22799 .46847 L closepath p F P
0 g
s
.969 .887 .695 r
.4159 .40557 m .41312 .39417 L .40492 .41114 L p F P
0 g
s
.969 .887 .695 r
.4135 .4113 m .4159 .40557 L p .40492 .41114 L F P
0 g
s
0 0 .379 r
.19328 .405 m .19039 .39315 L p .1962 .4082 L F P
0 g
s
0 0 .379 r
.1962 .4082 m .19841 .41719 L .19328 .405 L p F P
0 g
s
.559 .676 .917 r
.6863 .50143 m .71911 .499 L .72671 .50959 L p F P
0 g
s
.54 .577 .841 r
.71137 .48701 m .71911 .499 L .6863 .50143 L p F P
0 g
s
.54 .577 .841 r
.68245 .48595 m .71137 .48701 L p .6863 .50143 L F P
0 g
s
.54 .577 .841 r
.6863 .50143 m .6799 .48893 L .68245 .48595 L p F P
0 g
s
0 0 .487 r
.62864 .37093 m .62898 .38282 L .63583 .39511 L p F P
0 g
s
0 0 .101 r
.86493 .32661 m .86432 .3386 L .86479 .35303 L p F P
0 g
s
.215 .47 .885 r
.2315 .47347 m .22799 .46847 L p .24368 .46987 L F P
0 g
s
.215 .47 .885 r
.24368 .46987 m .24858 .48054 L .2315 .47347 L p F P
0 g
s
.969 .887 .695 r
.40492 .41114 m .40541 .4128 L .4135 .4113 L p F P
0 g
s
.955 .921 .735 r
.40541 .4128 m .4135 .4113 L .40676 .42278 L closepath p F P
0 g
s
.878 .954 .606 r
.8518 .4129 m .84797 .42535 L .83799 .44324 L p F P
0 g
s
.794 .859 .413 r
.85373 .40843 m .85662 .40317 L p .84797 .42535 L F P
0 g
s
.794 .859 .413 r
.84797 .42535 m .8518 .4129 L .85373 .40843 L p F P
0 g
s
.833 .848 .386 r
.85373 .40843 m .85806 .39613 L .85662 .40317 L closepath p F P
0 g
s
.733 .719 .191 r
.86171 .38025 m .85806 .39613 L .85662 .40317 L p F P
0 g
s
.894 .815 .763 r
.3826 .45934 m .38648 .46477 L .39061 .4675 L p F P
0 g
s
.849 .834 .831 r
.38648 .46477 m .39061 .4675 L .38886 .46929 L closepath p F P
0 g
s
.837 .833 .843 r
.38886 .46929 m .3676 .4905 L .36048 .48089 L p F P
0 g
s
.837 .833 .843 r
.38648 .46477 m .38886 .46929 L p .36048 .48089 L F P
0 g
s
0 0 .182 r
.42962 .33653 m .43112 .33334 L .42896 .34807 L p F P
0 g
s
0 0 .182 r
.42896 .34807 m .42823 .34962 L .42962 .33653 L p F P
0 g
s
0 0 .219 r
.18732 .38039 m .18528 .36805 L p .18921 .38603 L F P
0 g
s
0 0 .219 r
.18921 .38603 m .19039 .39315 L .18732 .38039 L p F P
0 g
s
.33 .565 .923 r
.26957 .49448 m .25417 .49084 L .24858 .48054 L p F P
0 g
s
.342 .584 .933 r
.25417 .49084 m .26957 .49448 L .27929 .50465 L p F P
0 g
s
0 0 0 r
.86171 .38025 m .86324 .36821 L .86479 .35303 L p F P
0 g
s
.812 .775 .267 r
.86324 .36821 m .86171 .38025 L .85806 .39613 L p F P
0 g
s
.215 .47 .885 r
.22799 .46847 m .22535 .46153 L .24368 .46987 L p F P
0 g
s
.07 .34 .816 r
.22535 .46153 m .22799 .46847 L .22192 .45926 L closepath p F P
0 g
s
.891 .624 .11 r
.6247 .35782 m .621 .34683 L .6195 .33305 L p F P
0 g
s
.835 .81 .826 r
.35913 .49886 m .3676 .4905 L .36048 .48089 L p F P
0 g
s
.835 .81 .826 r
.36048 .48089 m .34968 .49105 L .35913 .49886 L p F P
0 g
s
.577 .734 .95 r
.29946 .49073 m .26957 .49448 L .27929 .50465 L p F P
0 g
s
.577 .734 .95 r
.27929 .50465 m .30919 .49962 L .29946 .49073 L p F P
0 g
s
.737 .616 .048 r
.18411 .33448 m .18416 .32781 L .18369 .34161 L p F P
0 g
s
.737 .616 .048 r
.18369 .34161 m .18363 .34954 L .18411 .33448 L p F P
0 g
s
.929 .933 .785 r
.40676 .42278 m .39514 .44088 L .39185 .42977 L p F P
0 g
s
.929 .933 .785 r
.40541 .4128 m .40676 .42278 L p .39185 .42977 L F P
0 g
s
.743 .961 .939 r
.7665 .50551 m .79861 .48575 L .79942 .48604 L p F P
0 g
s
.728 .922 .958 r
.79861 .48575 m .7665 .50551 L .75938 .4992 L p F P
0 g
s
.65 .825 .967 r
.72671 .50959 m .75938 .4992 L .7665 .50551 L p F P
0 g
s
.537 .573 .839 r
.6799 .48893 m .67831 .48578 L .68245 .48595 L closepath p F P
0 g
s
.905 .906 .501 r
.41973 .37781 m .42336 .36406 L .41497 .38108 L p F P
0 g
s
.905 .906 .501 r
.41497 .38108 m .41312 .39417 L .41973 .37781 L p F P
0 g
s
.045 0 .341 r
.43112 .33334 m .44555 .3156 L .44269 .33065 L p F P
0 g
s
.045 0 .341 r
.44269 .33065 m .42896 .34807 L .43112 .33334 L p F P
0 g
s
.616 .772 .955 r
.75938 .4992 m .72671 .50959 L .71911 .499 L p F P
0 g
s
.972 .661 .298 r
.61281 .32287 m .6195 .33305 L .621 .34683 L p F P
0 g
s
.444 .486 .808 r
.67019 .46822 m .66247 .46578 L .66623 .45916 L closepath p F P
0 g
s
.435 .475 .802 r
.66196 .4491 m .65113 .44302 L p .66247 .46578 L F P
0 g
s
.435 .475 .802 r
.66247 .46578 m .66623 .45916 L .66196 .4491 L p F P
0 g
s
.543 .555 .817 r
.68245 .48595 m .67831 .48578 L .67019 .46822 L p F P
0 g
s
0 0 .063 r
.18409 .35474 m .18363 .34954 L .18515 .36657 L p F P
0 g
s
0 0 .063 r
.18515 .36657 m .18528 .36805 L .18409 .35474 L p F P
0 g
s
.916 .98 .742 r
.83799 .44324 m .84151 .43096 L p .82636 .45522 L F P
0 g
s
.916 .98 .742 r
.82636 .45522 m .82991 .45493 L .83799 .44324 L p F P
0 g
s
.878 .954 .606 r
.83799 .44324 m .84151 .43096 L .8518 .4129 L p F P
0 g
s
.347 .415 .79 r
.66196 .4491 m .65113 .44302 L .65488 .43196 L closepath p F P
0 g
s
.326 .391 .777 r
.65366 .42889 m .64297 .41925 L p .65113 .44302 L F P
0 g
s
.326 .391 .777 r
.65113 .44302 m .65488 .43196 L .65366 .42889 L p F P
0 g
s
.888 .815 .771 r
.38126 .46122 m .3826 .45934 L .38648 .46477 L closepath p F P
0 g
s
.837 .833 .843 r
.36048 .48089 m .38126 .46122 L .38648 .46477 L p F P
0 g
s
.066 .31 .794 r
.22192 .45926 m .22535 .46153 L .22195 .45022 L p F P
0 g
s
.066 .31 .794 r
.22195 .45022 m .21242 .44326 L .22192 .45926 L p F P
0 g
s
0 .122 .672 r
.20963 .44011 m .21242 .44326 L .22192 .45926 L p F P
0 g
s
.743 .811 .906 r
.34009 .48367 m .30919 .49962 L .31883 .50828 L p F P
0 g
s
.743 .811 .906 r
.31883 .50828 m .34968 .49105 L .34009 .48367 L p F P
0 g
s
0 0 .101 r
.86479 .35303 m .86541 .34108 L .86493 .32661 L p F P
0 g
s
.766 .675 .125 r
.86541 .34108 m .86479 .35303 L .86324 .36821 L p F P
0 g
s
.83 .966 .892 r
.79861 .48575 m .80009 .48449 L .79942 .48604 L closepath p F P
0 g
s
.867 .978 .85 r
.82301 .46268 m .80009 .48449 L .79942 .48604 L p F P
0 g
s
.491 .536 .83 r
.68245 .48595 m .71137 .48701 L .7035 .47392 L p F P
0 g
s
.491 .536 .83 r
.7035 .47392 m .69159 .47195 L .68245 .48595 L p F P
0 g
s
.543 .555 .817 r
.67019 .46822 m .69159 .47195 L .68245 .48595 L p F P
0 g
s
.101 .219 .701 r
.64297 .41925 m .65366 .42889 L .64531 .40817 L p F P
0 g
s
.101 .219 .701 r
.64531 .40817 m .64435 .40704 L .64297 .41925 L p F P
0 g
s
.047 .164 .665 r
.64297 .41925 m .64435 .40704 L .63583 .39511 L p F P
0 g
s
.854 .998 .791 r
.82301 .46268 m .82636 .45522 L .82991 .45493 L closepath p F P
0 g
s
.911 .85 .771 r
.39514 .44088 m .39185 .42977 L .37743 .4489 L p F P
0 g
s
.911 .85 .771 r
.37743 .4489 m .3826 .45934 L .39514 .44088 L p F P
0 g
s
.911 .89 .471 r
.85806 .39613 m .85956 .38416 L p .85247 .40998 L F P
0 g
s
.911 .89 .471 r
.85247 .40998 m .85373 .40843 L .85806 .39613 L p F P
0 g
s
.812 .775 .267 r
.85806 .39613 m .85956 .38416 L .86324 .36821 L p F P
0 g
s
.845 .959 .884 r
.82636 .45522 m .82301 .46268 L .80009 .48449 L p F P
0 g
s
.82 .934 .905 r
.80009 .48449 m .79861 .48575 L .79187 .48191 L p F P
0 g
s
.728 .922 .958 r
.75938 .4992 m .79187 .48191 L .79861 .48575 L p F P
0 g
s
.82 .934 .905 r
.79187 .48191 m .80422 .47222 L .80009 .48449 L p F P
0 g
s
.845 .959 .884 r
.82374 .45484 m .82636 .45522 L p .80009 .48449 L F P
0 g
s
.845 .959 .884 r
.80009 .48449 m .80422 .47222 L .82374 .45484 L p F P
0 g
s
0 .117 .669 r
.21242 .44326 m .20963 .44011 L .20776 .43449 L closepath p F P
0 g
s
0 .089 .641 r
.63443 .38358 m .63583 .39511 L .64435 .40704 L p F P
0 g
s
0 0 .487 r
.63583 .39511 m .63443 .38358 L .62864 .37093 L p F P
0 g
s
0 0 .552 r
.20311 .42467 m .19841 .41719 L .1962 .4082 L closepath p F P
0 g
s
0 0 .537 r
.19841 .41719 m .20311 .42467 L .20776 .43449 L p F P
0 g
s
.204 .447 .87 r
.22535 .46153 m .22195 .45022 L .23949 .45882 L p F P
0 g
s
.204 .447 .87 r
.23949 .45882 m .24368 .46987 L .22535 .46153 L p F P
0 g
s
.499 .518 .807 r
.69159 .47195 m .67019 .46822 L .66623 .45916 L p F P
0 g
s
0 0 .01 r
.18416 .32781 m .18519 .31394 L .18472 .32778 L p F P
0 g
s
0 0 .01 r
.18472 .32778 m .18369 .34161 L .18416 .32781 L p F P
0 g
s
.967 .936 .652 r
.41312 .39417 m .41497 .38108 L .40467 .39881 L p F P
0 g
s
.967 .936 .652 r
.40467 .39881 m .40492 .41114 L .41312 .39417 L p F P
0 g
s
0 0 0 r
.42716 .35338 m .42896 .34807 L .42823 .34962 L closepath p F P
0 g
s
0 0 0 r
.42336 .36406 m .42716 .35338 L .42823 .34962 L p F P
0 g
s
0 0 .179 r
.18363 .34954 m .18369 .34161 L .18526 .35482 L p F P
0 g
s
0 0 .179 r
.18526 .35482 m .18515 .36657 L .18363 .34954 L p F P
0 g
s
0 0 .028 r
.86477 .32074 m .86493 .32661 L .86541 .34108 L p F P
0 g
s
0 0 .413 r
.19412 .40219 m .19039 .39315 L .18921 .38603 L closepath p F P
0 g
s
0 0 .379 r
.19039 .39315 m .19412 .40219 L .1962 .4082 L p F P
0 g
s
.904 .849 .779 r
.38126 .46122 m .3826 .45934 L .37743 .4489 L p F P
0 g
s
0 0 .038 r
.42896 .34807 m .44269 .33065 L .43521 .34736 L p F P
0 g
s
0 0 .038 r
.42716 .35338 m .42896 .34807 L p .43521 .34736 L F P
0 g
s
.435 .475 .802 r
.66623 .45916 m .66196 .4491 L .67032 .45197 L closepath p F P
0 g
s
.499 .518 .807 r
.66623 .45916 m .67032 .45197 L p .69159 .47195 L F P
0 g
s
.084 .313 .793 r
.21242 .44326 m .20776 .43449 L p .21921 .43853 L F P
0 g
s
.084 .313 .793 r
.21921 .43853 m .22195 .45022 L .21242 .44326 L p F P
0 g
s
.553 .718 .95 r
.28964 .48143 m .25981 .4836 L .26957 .49448 L p F P
0 g
s
.553 .718 .95 r
.26957 .49448 m .29946 .49073 L .28964 .48143 L p F P
0 g
s
.33 .565 .923 r
.24858 .48054 m .25981 .4836 L .26957 .49448 L p F P
0 g
s
.904 .849 .779 r
.37743 .4489 m .37175 .45614 L .38126 .46122 L p F P
0 g
s
.833 .865 .869 r
.38126 .46122 m .36048 .48089 L .35519 .47057 L p F P
0 g
s
.833 .865 .869 r
.35519 .47057 m .37175 .45614 L .38126 .46122 L p F P
0 g
s
.859 .898 .478 r
.8518 .4129 m .85247 .40998 L .85373 .40843 L closepath p F P
0 g
s
.837 .834 .844 r
.34968 .49105 m .36048 .48089 L .35519 .47057 L p F P
0 g
s
.837 .834 .844 r
.35519 .47057 m .34009 .48367 L .34968 .49105 L p F P
0 g
s
.315 .542 .912 r
.25981 .4836 m .24858 .48054 L .24368 .46987 L p F P
0 g
s
.921 .557 .125 r
.61424 .3367 m .621 .34683 L .62454 .36009 L p F P
0 g
s
.972 .661 .298 r
.621 .34683 m .61424 .3367 L .61281 .32287 L p F P
0 g
s
.616 .772 .955 r
.71911 .499 m .75208 .49139 L .75938 .4992 L p F P
0 g
s
.577 .726 .944 r
.75208 .49139 m .71911 .499 L .71137 .48701 L p F P
0 g
s
.912 .97 .668 r
.85247 .40998 m .8518 .4129 L .84151 .43096 L p F P
0 g
s
.957 .888 .721 r
.404 .41285 m .40492 .41114 L .40541 .4128 L closepath p F P
0 g
s
.929 .933 .785 r
.39185 .42977 m .404 .41285 L .40541 .4128 L p F P
0 g
s
.883 .818 .341 r
.86384 .35632 m .86324 .36821 L .85956 .38416 L p F P
0 g
s
.766 .675 .125 r
.86324 .36821 m .86384 .35632 L .86541 .34108 L p F P
0 g
s
0 0 .038 r
.43521 .34736 m .42495 .36085 L .42716 .35338 L p F P
0 g
s
.44 .472 .796 r
.67032 .45197 m .66196 .4491 L .65488 .43196 L p F P
0 g
s
0 0 .262 r
.18599 .37108 m .18528 .36805 L .18515 .36657 L closepath p F P
0 g
s
0 0 .219 r
.18528 .36805 m .18599 .37108 L .18921 .38603 L p F P
0 g
s
.084 .313 .793 r
.20776 .43449 m .20652 .42854 L .21921 .43853 L p F P
0 g
s
0 .143 .683 r
.20652 .42854 m .20776 .43449 L .20311 .42467 L closepath p F P
0 g
s
.704 .875 .962 r
.79187 .48191 m .75938 .4992 L .75208 .49139 L p F P
0 g
s
.953 .636 .39 r
.61281 .32287 m .6033 .31349 L .60475 .32733 L p F P
0 g
s
.953 .636 .39 r
.60475 .32733 m .61424 .3367 L .61281 .32287 L p F P
0 g
s
.961 .942 .693 r
.404 .41285 m .40492 .41114 L .40467 .39881 L p F P
0 g
s
0 0 .388 r
.18515 .36657 m .18526 .35482 L .189 .36741 L p F P
0 g
s
0 0 .388 r
.18599 .37108 m .18515 .36657 L p .189 .36741 L F P
0 g
s
.73 .816 .918 r
.33038 .47649 m .29946 .49073 L .30919 .49962 L p F P
0 g
s
.73 .816 .918 r
.30919 .49962 m .34009 .48367 L .33038 .47649 L p F P
0 g
s
.893 .982 .808 r
.82374 .45484 m .8277 .45014 L .82636 .45522 L closepath p F P
0 g
s
.916 .98 .742 r
.84151 .43096 m .8277 .45014 L .82636 .45522 L p F P
0 g
s
.961 .942 .693 r
.40467 .39881 m .39432 .41492 L .404 .41285 L p F P
0 g
s
.901 .977 .804 r
.404 .41285 m .39185 .42977 L .3924 .41726 L p F P
0 g
s
.901 .977 .804 r
.3924 .41726 m .39432 .41492 L .404 .41285 L p F P
0 g
s
0 0 .388 r
.189 .36741 m .18888 .38065 L .18599 .37108 L p F P
0 g
s
0 0 .354 r
.18888 .38065 m .18921 .38603 L .18599 .37108 L closepath p F P
0 g
s
0 .159 .689 r
.20311 .42467 m .1962 .4082 L p .20486 .41631 L F P
0 g
s
0 .159 .689 r
.20486 .41631 m .20652 .42854 L .20311 .42467 L p F P
0 g
s
.935 .944 .605 r
.84814 .41223 m .85356 .40091 L .85247 .40998 L closepath p F P
0 g
s
.911 .89 .471 r
.85956 .38416 m .85356 .40091 L .85247 .40998 L p F P
0 g
s
.912 .97 .668 r
.84814 .41223 m .85247 .40998 L p .84151 .43096 L F P
0 g
s
0 0 .028 r
.86541 .34108 m .86519 .3334 L .86477 .32074 L p F P
0 g
s
.76 .588 .016 r
.86425 .31487 m .86477 .32074 L .86519 .3334 L p F P
0 g
s
.44 .472 .796 r
.65488 .43196 m .65566 .43002 L p .67032 .45197 L F P
0 g
s
.355 .41 .78 r
.65488 .43196 m .65366 .42889 L .65566 .43002 L closepath p F P
0 g
s
.35 .411 .784 r
.65566 .43002 m .65366 .42889 L .64531 .40817 L p F P
0 g
s
0 0 0 r
.4201 .37062 m .41497 .38108 L p .41039 .38433 L F P
0 g
s
0 0 0 r
.4201 .37062 m .41704 .37507 L .41969 .37143 L p F P
0 g
s
.638 .776 .316 r
.4201 .37062 m .41497 .38108 L .42103 .3688 L p F P
0 g
s
0 0 0 r
.41969 .37143 m .4241 .36538 L .4201 .37062 L p F P
0 g
s
.638 .776 .316 r
.42103 .3688 m .42336 .36406 L p .4201 .37062 L F P
0 g
s
.915 .976 .774 r
.84423 .41876 m .84151 .43096 L .8277 .45014 L p F P
0 g
s
.912 .97 .668 r
.84151 .43096 m .84423 .41876 L .84814 .41223 L p F P
0 g
s
0 0 .225 r
.18369 .34161 m .18472 .32778 L .18629 .34103 L p F P
0 g
s
0 0 .225 r
.18629 .34103 m .18526 .35482 L .18369 .34161 L p F P
0 g
s
0 0 .551 r
.18921 .38603 m .18888 .38065 L .19505 .39253 L p F P
0 g
s
0 0 .551 r
.19412 .40219 m .18921 .38603 L p .19505 .39253 L F P
0 g
s
0 .159 .689 r
.1962 .4082 m .19581 .40527 L .20486 .41631 L p F P
0 g
s
0 0 .532 r
.19581 .40527 m .1962 .4082 L .19412 .40219 L closepath p F P
0 g
s
.848 .727 .204 r
.86519 .3334 m .86541 .34108 L .86384 .35632 L p F P
0 g
s
0 0 .551 r
.19505 .39253 m .19581 .40527 L .19412 .40219 L p F P
0 g
s
.44 .472 .796 r
.65566 .43002 m .67396 .43926 L .67032 .45197 L p F P
0 g
s
.207 .373 .809 r
.65807 .41751 m .65566 .43002 L .67396 .43926 L p F P
0 g
s
.35 .411 .784 r
.64531 .40817 m .65807 .41751 L .65566 .43002 L p F P
0 g
s
.914 .898 .797 r
.39185 .42977 m .3924 .41726 L .37489 .43746 L p F P
0 g
s
.914 .898 .797 r
.37489 .43746 m .37743 .4489 L .39185 .42977 L p F P
0 g
s
.499 .518 .807 r
.67032 .45197 m .69431 .45969 L .69159 .47195 L p F P
0 g
s
.377 .512 .867 r
.67396 .43926 m .67032 .45197 L .69431 .45969 L p F P
0 g
s
0 .162 .692 r
.64531 .40817 m .64435 .40704 L .64409 .40536 L closepath p F P
0 g
s
0 .089 .641 r
.63695 .38788 m .63443 .38358 L p .64435 .40704 L F P
0 g
s
0 .089 .641 r
.64435 .40704 m .64409 .40536 L .63695 .38788 L p F P
0 g
s
.943 .905 .519 r
.8601 .37233 m .85956 .38416 L .85356 .40091 L p F P
0 g
s
.883 .818 .341 r
.85956 .38416 m .8601 .37233 L .86384 .35632 L p F P
0 g
s
.524 .694 .946 r
.27976 .47152 m .25001 .47186 L .25981 .4836 L p F P
0 g
s
.524 .694 .946 r
.25981 .4836 m .28964 .48143 L .27976 .47152 L p F P
0 g
s
.315 .542 .912 r
.24368 .46987 m .25001 .47186 L .25981 .4836 L p F P
0 g
s
.081 .292 .775 r
.20652 .42854 m .20486 .41631 L .2172 .42643 L p F P
0 g
s
.081 .292 .775 r
.2172 .42643 m .21921 .43853 L .20652 .42854 L p F P
0 g
s
.23 .354 .784 r
.65807 .41751 m .64531 .40817 L .64409 .40536 L p F P
0 g
s
.804 .913 .914 r
.80422 .47222 m .79187 .48191 L .78493 .47658 L p F P
0 g
s
.704 .875 .962 r
.75208 .49139 m .78493 .47658 L .79187 .48191 L p F P
0 g
s
0 0 .312 r
.62864 .37025 m .62454 .36009 L p .62959 .37209 L F P
0 g
s
0 0 .312 r
.63443 .38358 m .62864 .37025 L .62959 .37209 L F
0 0 .431 r
.62864 .37025 m .62043 .35725 L p .62825 .36947 L F P
0 g
s
0 0 .431 r
.63035 .37276 m .62864 .37025 L p .62825 .36947 L F P
0 g
s
0 0 .453 r
.63695 .38788 m .63443 .38358 L .63134 .37637 L closepath p F P
0 g
s
0 0 .312 r
.63443 .38358 m .63134 .37637 L .62864 .37025 L p F P
0 g
s
.577 .726 .944 r
.71137 .48701 m .74463 .48233 L .75208 .49139 L p F P
0 g
s
.534 .684 .935 r
.74463 .48233 m .71137 .48701 L .7035 .47392 L p F P
0 g
s
0 0 0 r
.42495 .36085 m .43521 .34736 L .4241 .36538 L p F P
0 g
s
0 0 0 r
.4241 .36538 m .4201 .37062 L .42495 .36085 L p F P
0 g
s
.206 .427 .855 r
.22195 .45022 m .21921 .43853 L p .23914 .45756 L F P
0 g
s
.206 .427 .855 r
.23914 .45756 m .23949 .45882 L .22195 .45022 L p F P
0 g
s
.892 .963 .833 r
.8277 .45014 m .82374 .45484 L .81726 .45236 L p F P
0 g
s
.892 .963 .833 r
.81726 .45236 m .82984 .4382 L .8277 .45014 L p F P
0 g
s
.915 .976 .774 r
.8277 .45014 m .82984 .4382 L .84423 .41876 L p F P
0 g
s
.23 .354 .784 r
.64409 .40536 m .64406 .39518 L p .65807 .41751 L F P
0 g
s
.089 .245 .73 r
.64409 .40536 m .63695 .38788 L .64406 .39518 L closepath p F P
0 g
s
0 .141 .671 r
.19581 .40527 m .19505 .39253 L .20395 .40364 L p F P
0 g
s
0 .141 .671 r
.20395 .40364 m .20486 .41631 L .19581 .40527 L p F P
0 g
s
.804 .913 .914 r
.78493 .47658 m .808 .4599 L .80422 .47222 L p F P
0 g
s
.842 .968 .882 r
.81726 .45236 m .808 .4599 L .80422 .47222 L p F P
0 g
s
.842 .968 .882 r
.80422 .47222 m .82374 .45484 L .81726 .45236 L p F P
0 g
s
.172 0 .382 r
.44555 .3156 m .44849 .31271 L .44738 .32606 L p F P
0 g
s
.172 0 .382 r
.44738 .32606 m .44269 .33065 L .44555 .3156 L p F P
0 g
s
.409 .51 .85 r
.69159 .47195 m .7035 .47392 L .69554 .46007 L p F P
0 g
s
.409 .51 .85 r
.69554 .46007 m .69431 .45969 L .69159 .47195 L p F P
0 g
s
.842 .441 0 r
.62043 .35725 m .61763 .35002 L .62454 .36009 L p F P
0 g
s
.921 .557 .125 r
.62454 .36009 m .61763 .35002 L .61424 .3367 L p F P
0 g
s
.838 .636 .09 r
.8623 .30338 m .86425 .31487 L .86484 .32935 L p F P
0 g
s
.76 .588 .016 r
.86519 .3334 m .86484 .32935 L .86425 .31487 L p F P
0 g
s
.907 .896 .806 r
.37175 .45614 m .37743 .4489 L .37489 .43746 L p F P
0 g
s
.832 .863 .869 r
.35255 .45926 m .33038 .47649 L .34009 .48367 L p F P
0 g
s
.832 .863 .869 r
.34009 .48367 m .35519 .47057 L .35255 .45926 L p F P
0 g
s
.937 .565 .252 r
.61424 .3367 m .60475 .32733 L .60824 .34064 L p F P
0 g
s
.937 .565 .252 r
.60824 .34064 m .61763 .35002 L .61424 .3367 L p F P
0 g
s
.816 .889 .896 r
.37175 .45614 m .35519 .47057 L .35255 .45926 L p F P
0 g
s
0 0 0 r
.41497 .38108 m .40467 .39881 L .41039 .38433 L p F P
0 g
s
0 0 .068 r
.18519 .31394 m .18726 .2995 L p .18674 .31366 L F P
0 g
s
0 0 .068 r
.18674 .31366 m .18472 .32778 L .18519 .31394 L p F P
0 g
s
.907 .896 .806 r
.37489 .43746 m .36207 .45184 L .37175 .45614 L p F P
0 g
s
.816 .889 .896 r
.35255 .45926 m .36207 .45184 L .37175 .45614 L p F P
0 g
s
0 0 .547 r
.18888 .38065 m .189 .36741 L .19512 .37933 L p F P
0 g
s
0 0 .547 r
.19512 .37933 m .19505 .39253 L .18888 .38065 L p F P
0 g
s
.905 .593 .444 r
.6033 .31349 m .59057 .30507 L .59212 .31888 L p F P
0 g
s
.905 .593 .444 r
.59212 .31888 m .60475 .32733 L .6033 .31349 L p F P
0 g
s
.297 .517 .899 r
.25001 .47186 m .24368 .46987 L .23949 .45882 L p F P
0 g
s
0 .203 .725 r
.64406 .39518 m .63695 .38788 L .63134 .37637 L p F P
0 g
s
.414 .185 .455 r
.44738 .32606 m .44849 .31271 L .47649 .29799 L p F P
0 g
s
.675 .832 .959 r
.78493 .47658 m .75208 .49139 L .74463 .48233 L p F P
0 g
s
.709 .813 .93 r
.32055 .46922 m .28964 .48143 L .29946 .49073 L p F P
0 g
s
.709 .813 .93 r
.29946 .49073 m .33038 .47649 L .32055 .46922 L p F P
0 g
s
.934 .845 .404 r
.8635 .34456 m .86384 .35632 L .8601 .37233 L p F P
0 g
s
.848 .727 .204 r
.86392 .34064 m .86519 .3334 L p .86384 .35632 L F P
0 g
s
.848 .727 .204 r
.86384 .35632 m .8635 .34456 L .86392 .34064 L p F P
0 g
s
.963 .94 .65 r
.85356 .40091 m .85401 .38918 L p .84515 .4127 L F P
0 g
s
.963 .94 .65 r
.84515 .4127 m .84814 .41223 L .85356 .40091 L p F P
0 g
s
.943 .905 .519 r
.85356 .40091 m .85401 .38918 L .8601 .37233 L p F P
0 g
s
.878 .731 .217 r
.86392 .34064 m .86484 .32935 L .86519 .3334 L closepath p F P
0 g
s
0 0 .41 r
.18526 .35482 m .18629 .34103 L .19004 .35365 L p F P
0 g
s
0 0 .41 r
.19004 .35365 m .189 .36741 L .18526 .35482 L p F P
0 g
s
.911 .975 .789 r
.40467 .39881 m .41039 .38433 L .39505 .40387 L p F P
0 g
s
.911 .975 .789 r
.39432 .41492 m .40467 .39881 L p .39505 .40387 L F P
0 g
s
0 .203 .725 r
.63134 .37637 m .63035 .37276 L p .64406 .39518 L F P
0 g
s
0 .015 .589 r
.63134 .37637 m .62864 .37025 L .63035 .37276 L closepath p F P
0 g
s
.487 .646 .928 r
.73705 .47229 m .7035 .47392 L .69554 .46007 L p F P
0 g
s
.534 .684 .935 r
.7035 .47392 m .73705 .47229 L .74463 .48233 L p F P
0 g
s
.492 .664 .938 r
.26984 .46077 m .24021 .45908 L .25001 .47186 L p F P
0 g
s
.492 .664 .938 r
.25001 .47186 m .27976 .47152 L .26984 .46077 L p F P
0 g
s
.297 .517 .899 r
.23949 .45882 m .24021 .45908 L .25001 .47186 L p F P
0 g
s
.044 0 .222 r
.44269 .33065 m .44738 .32606 L .44483 .33801 L p F P
0 g
s
.044 0 .222 r
.44483 .33801 m .43521 .34736 L .44269 .33065 L p F P
0 g
s
.932 .968 .695 r
.84423 .41876 m .84515 .4127 L .84814 .41223 L closepath p F P
0 g
s
.933 .761 .285 r
.86484 .32935 m .86288 .31791 L p .86332 .34291 L F P
0 g
s
.933 .761 .285 r
.86332 .34291 m .86392 .34064 L .86484 .32935 L p F P
0 g
s
.838 .636 .09 r
.86484 .32935 m .86288 .31791 L .8623 .30338 L p F P
0 g
s
.915 .963 .797 r
.84515 .4127 m .84423 .41876 L .82984 .4382 L p F P
0 g
s
0 .203 .725 r
.63035 .37276 m .64041 .38424 L .64406 .39518 L p F P
0 g
s
0 0 .546 r
.62391 .36256 m .63035 .37276 L .64041 .38424 L p F P
0 g
s
0 0 .431 r
.62043 .35725 m .62391 .36256 L .63035 .37276 L p F P
0 g
s
0 0 .267 r
.18472 .32778 m .18674 .31366 L .18782 .33047 L p F P
0 g
s
0 0 .267 r
.18782 .33047 m .18629 .34103 L .18472 .32778 L p F P
0 g
s
.23 .354 .784 r
.64406 .39518 m .65641 .4061 L .65807 .41751 L p F P
0 g
s
0 .172 .709 r
.64041 .38424 m .64406 .39518 L .65641 .4061 L p F P
0 g
s
.911 .975 .789 r
.39505 .40387 m .39289 .41528 L .39432 .41492 L p F P
0 g
s
.898 .982 .799 r
.39289 .41528 m .39432 .41492 L .3924 .41726 L closepath p F P
0 g
s
.207 .373 .809 r
.67396 .43926 m .67335 .4277 L .65807 .41751 L p F P
0 g
s
.028 .29 .784 r
.65641 .4061 m .65807 .41751 L .67335 .4277 L p F P
0 g
s
.899 .482 .116 r
.62043 .35725 m .61763 .35002 L .60824 .34064 L p F P
0 g
s
.843 .541 .477 r
.59057 .30507 m .57351 .29799 L .57525 .31173 L p F P
0 g
s
.843 .541 .477 r
.57525 .31173 m .59212 .31888 L .59057 .30507 L p F P
0 g
s
.97 .91 .563 r
.85971 .36065 m .8601 .37233 L .85401 .38918 L p F P
0 g
s
.934 .845 .404 r
.8601 .37233 m .85971 .36065 L .8635 .34456 L p F P
0 g
s
.85 .99 .848 r
.3924 .41726 m .37489 .43746 L .3764 .42454 L p F P
0 g
s
.85 .99 .848 r
.39289 .41528 m .3924 .41726 L p .3764 .42454 L F P
0 g
s
.906 .541 .334 r
.60475 .32733 m .59212 .31888 L .59598 .33206 L p F P
0 g
s
.906 .541 .334 r
.59598 .33206 m .60824 .34064 L .60475 .32733 L p F P
0 g
s
.783 .917 .929 r
.808 .4599 m .78493 .47658 L .77781 .46997 L p F P
0 g
s
.675 .832 .959 r
.74463 .48233 m .77781 .46997 L .78493 .47658 L p F P
0 g
s
.377 .512 .867 r
.6875 .44567 m .67396 .43926 L p .69431 .45969 L F P
0 g
s
.229 .393 .82 r
.67396 .43926 m .6875 .44567 L .67941 .43144 L p F P
0 g
s
.229 .393 .82 r
.67941 .43144 m .67335 .4277 L .67396 .43926 L p F P
0 g
s
.098 .282 .762 r
.20486 .41631 m .20395 .40364 L p .21675 .42118 L F P
0 g
s
.098 .282 .762 r
.21675 .42118 m .2172 .42643 L .20486 .41631 L p F P
0 g
s
.346 .066 .338 r
.44483 .33801 m .44738 .32606 L .47561 .3115 L p F P
0 g
s
.414 .185 .455 r
.47649 .29799 m .47561 .3115 L .44738 .32606 L p F P
0 g
s
.205 .399 .833 r
.23045 .44465 m .21921 .43853 L .2172 .42643 L p F P
0 g
s
.206 .427 .855 r
.21921 .43853 m .23045 .44465 L .23914 .45756 L p F P
0 g
s
.816 .895 .898 r
.35225 .44775 m .32055 .46922 L .33038 .47649 L p F P
0 g
s
.816 .895 .898 r
.3537 .44838 m .35225 .44775 L p .33038 .47649 L F P
0 g
s
.816 .895 .898 r
.33038 .47649 m .35255 .45926 L .3537 .44838 L p F P
0 g
s
.899 .671 .16 r
.85941 .29205 m .8623 .30338 L .86288 .31791 L p F P
0 g
s
.892 .927 .836 r
.82984 .4382 m .83118 .42635 L p .81129 .4488 L F P
0 g
s
.892 .927 .836 r
.81129 .4488 m .81726 .45236 L .82984 .4382 L p F P
0 g
s
.915 .963 .797 r
.84208 .41225 m .84515 .4127 L p .82984 .4382 L F P
0 g
s
.915 .963 .797 r
.82984 .4382 m .83118 .42635 L .84208 .41225 L p F P
0 g
s
0 0 0 r
.42672 .36611 m .41586 .37695 L p .41704 .37507 L F P
0 g
s
0 0 0 r
.41039 .38433 m .41704 .37507 L p .41765 .37408 L F P
0 g
s
.667 .874 .498 r
.41376 .37905 m .41704 .37507 L .41496 .37795 L p F P
0 g
s
.667 .874 .498 r
.41496 .37795 m .41039 .38433 L .41376 .37905 L p F P
0 g
s
.513 .83 .521 r
.41376 .37905 m .40703 .38549 L .41127 .38131 L p F P
0 g
s
0 0 0 r
.41586 .37695 m .41376 .37905 L .41704 .37507 L p F P
0 g
s
.513 .83 .521 r
.41127 .38131 m .42672 .36611 L .41376 .37905 L p F P
0 g
s
0 0 0 r
.41704 .37507 m .4201 .37062 L p .41765 .37408 L F P
0 g
s
.903 .971 .811 r
.38449 .41658 m .39505 .40387 L .39289 .41528 L closepath p F P
0 g
s
.85 .99 .848 r
.3764 .42454 m .38449 .41658 L .39289 .41528 L p F P
0 g
s
.645 .795 .954 r
.77781 .46997 m .74463 .48233 L .73705 .47229 L p F P
0 g
s
0 .145 .666 r
.19505 .39253 m .19512 .37933 L p .20394 .39336 L F P
0 g
s
0 .145 .666 r
.20394 .39336 m .20395 .40364 L .19505 .39253 L p F P
0 g
s
.857 .885 .857 r
.37489 .43746 m .3764 .42454 L .35342 .44665 L p F P
0 g
s
.857 .885 .857 r
.36207 .45184 m .37489 .43746 L p .35342 .44665 L F P
0 g
s
0 0 .064 r
.43521 .34736 m .44483 .33801 L .44112 .34888 L p F P
0 g
s
0 0 .064 r
.44112 .34888 m .4241 .36538 L .43521 .34736 L p F P
0 g
s
.783 .917 .929 r
.81129 .4488 m .808 .4599 L p .77781 .46997 L F P
0 g
s
.828 .935 .899 r
.808 .4599 m .81129 .4488 L .81726 .45236 L closepath p F P
0 g
s
.386 .521 .87 r
.69554 .46007 m .69431 .45969 L .69437 .45798 L closepath p F P
0 g
s
.377 .512 .867 r
.69431 .45969 m .69437 .45798 L .6875 .44567 L p F P
0 g
s
.681 .801 .939 r
.31063 .46155 m .27976 .47152 L .28964 .48143 L p F P
0 g
s
.681 .801 .939 r
.28964 .48143 m .32055 .46922 L .31063 .46155 L p F P
0 g
s
.817 .896 .898 r
.3537 .44838 m .36207 .45184 L .35255 .45926 L closepath p F P
0 g
s
.912 .764 .275 r
.8635 .34456 m .86332 .34291 L .86392 .34064 L closepath p F P
0 g
s
.487 .646 .928 r
.69554 .46007 m .72935 .46154 L .73705 .47229 L p F P
0 g
s
.482 .575 .872 r
.72156 .45038 m .72935 .46154 L .69554 .46007 L p F P
0 g
s
.482 .575 .872 r
.69765 .44709 m .72156 .45038 L p .69554 .46007 L F P
0 g
s
.482 .575 .872 r
.69554 .46007 m .69437 .45798 L .69765 .44709 L p F P
0 g
s
.284 .489 .882 r
.24021 .45908 m .23949 .45882 L .23914 .45756 L closepath p F P
0 g
s
.857 .885 .857 r
.35342 .44665 m .3537 .44838 L .36207 .45184 L p F P
0 g
s
.426 .566 .891 r
.25989 .44894 m .26984 .46077 L .24021 .45908 L p F P
0 g
s
.426 .566 .891 r
.23881 .44644 m .25989 .44894 L p .24021 .45908 L F P
0 g
s
.426 .566 .891 r
.24021 .45908 m .23914 .45756 L .23881 .44644 L p F P
0 g
s
.476 .568 .869 r
.69437 .45798 m .6875 .44567 L .69765 .44709 L closepath p F P
0 g
s
.948 .953 .728 r
.84208 .41225 m .8453 .4069 L .84515 .4127 L closepath p F P
0 g
s
.963 .94 .65 r
.85401 .38918 m .8453 .4069 L .84515 .4127 L p F P
0 g
s
.396 .539 .882 r
.23881 .44644 m .23914 .45756 L .23045 .44465 L closepath p F P
0 g
s
0 .004 .555 r
.189 .36741 m .19004 .35365 L p .19584 .36983 L F P
0 g
s
0 .004 .555 r
.19584 .36983 m .19512 .37933 L .189 .36741 L p F P
0 g
s
.762 .272 0 r
.62043 .35725 m .62391 .36256 L .61402 .35334 L p F P
0 g
s
.762 .272 0 r
.61402 .35334 m .61232 .35082 L .62043 .35725 L p F P
0 g
s
.899 .482 .116 r
.60824 .34064 m .61232 .35082 L .62043 .35725 L p F P
0 g
s
0 0 .121 r
.18689 .31012 m .18726 .2995 L .18743 .29865 L closepath p F P
0 g
s
0 0 .068 r
.18726 .2995 m .18689 .31012 L .18674 .31366 L p F P
0 g
s
.971 .861 .465 r
.86332 .34291 m .8635 .34456 L .85971 .36065 L p F P
0 g
s
.968 .935 .677 r
.85352 .37758 m .85401 .38918 L .8453 .4069 L p F P
0 g
s
.97 .91 .563 r
.85401 .38918 m .85352 .37758 L .85971 .36065 L p F P
0 g
s
0 0 .219 r
.18743 .29865 m .19235 .28374 L .19206 .29761 L p F P
0 g
s
0 0 .219 r
.18689 .31012 m .18743 .29865 L p .19206 .29761 L F P
0 g
s
.779 .488 .494 r
.57351 .29799 m .55574 .2938 L .55495 .30698 L p F P
0 g
s
.779 .488 .494 r
.55495 .30698 m .57525 .31173 L .57351 .29799 L p F P
0 g
s
.591 .334 .496 r
.47561 .3115 m .47649 .29799 L .51186 .29103 L p F P
0 g
s
.977 .84 .441 r
.85874 .34763 m .86162 .33313 L .86332 .34291 L closepath p F P
0 g
s
.933 .761 .285 r
.86288 .31791 m .86162 .33313 L .86332 .34291 L p F P
0 g
s
.971 .861 .465 r
.85874 .34763 m .86332 .34291 L p .85971 .36065 L F P
0 g
s
0 0 0 r
.4241 .36538 m .44112 .34888 L p .42672 .36611 L F P
0 g
s
0 0 0 r
.41704 .37507 m .4241 .36538 L p .42672 .36611 L F P
0 g
s
.849 .497 .386 r
.59212 .31888 m .57525 .31173 L .5798 .32468 L p F P
0 g
s
.849 .497 .386 r
.5798 .32468 m .59598 .33206 L .59212 .31888 L p F P
0 g
s
0 0 .433 r
.18629 .34103 m .18782 .33047 L .19071 .34907 L p F P
0 g
s
0 0 .433 r
.19071 .34907 m .19004 .35365 L .18629 .34103 L p F P
0 g
s
.88 .451 .165 r
.60824 .34064 m .59598 .33206 L .60171 .34478 L p F P
0 g
s
.88 .451 .165 r
.61232 .35082 m .60824 .34064 L p .60171 .34478 L F P
0 g
s
.967 .775 .34 r
.85999 .30661 m .86288 .31791 L .86162 .33313 L p F P
0 g
s
.899 .671 .16 r
.86288 .31791 m .85999 .30661 L .85941 .29205 L p F P
0 g
s
0 0 .546 r
.64041 .38424 m .63369 .37413 L .62391 .36256 L p F P
0 g
s
.629 .125 0 r
.62391 .36256 m .61402 .35334 L .62409 .36482 L p F P
0 g
s
.629 .125 0 r
.62409 .36482 m .63369 .37413 L .62391 .36256 L p F P
0 g
s
.473 .572 .874 r
.69765 .44709 m .6875 .44567 L .67941 .43144 L p F P
0 g
s
.554 .853 .537 r
.41039 .38433 m .39505 .40387 L .40457 .38803 L p F P
0 g
s
.554 .853 .537 r
.41376 .37905 m .41039 .38433 L p .40457 .38803 L F P
0 g
s
.947 .937 .75 r
.8453 .4069 m .84208 .41225 L .83568 .40973 L p F P
0 g
s
.947 .937 .75 r
.83568 .40973 m .84463 .39543 L .8453 .4069 L p F P
0 g
s
.968 .935 .677 r
.8453 .4069 m .84463 .39543 L .85352 .37758 L p F P
0 g
s
0 .172 .709 r
.65641 .4061 m .65178 .39548 L .64041 .38424 L p F P
0 g
s
0 .074 .615 r
.63369 .37413 m .64041 .38424 L .65178 .39548 L p F P
0 g
s
.756 .467 .494 r
.55574 .2938 m .55038 .29287 L .55232 .30652 L p F P
0 g
s
.756 .467 .494 r
.55232 .30652 m .55495 .30698 L .55574 .2938 L p F P
0 g
s
.368 .499 .859 r
.23045 .44465 m .23881 .44644 L .23856 .43374 L p F P
0 g
s
.368 .499 .859 r
.23856 .43374 m .22076 .42858 L .23045 .44465 L p F P
0 g
s
.205 .399 .833 r
.2172 .42643 m .22076 .42858 L .23045 .44465 L p F P
0 g
s
.783 .917 .929 r
.77781 .46997 m .81055 .4483 L .81129 .4488 L p F P
0 g
s
.762 .886 .933 r
.81055 .4483 m .77781 .46997 L .77054 .46231 L p F P
0 g
s
.645 .795 .954 r
.73705 .47229 m .77054 .46231 L .77781 .46997 L p F P
0 g
s
.614 .763 .95 r
.77054 .46231 m .73705 .47229 L .72935 .46154 L p F P
0 g
s
.028 .29 .784 r
.67335 .4277 m .66985 .41688 L .65641 .4061 L p F P
0 g
s
0 .256 .767 r
.65178 .39548 m .65641 .4061 L .66985 .41688 L p F P
0 g
s
.713 .436 .505 r
.55038 .29287 m .51749 .29102 L .52004 .30442 L p F P
0 g
s
.713 .436 .505 r
.52004 .30442 m .55232 .30652 L .55038 .29287 L p F P
0 g
s
0 0 .219 r
.19206 .29761 m .18682 .31337 L .18689 .31012 L p F P
0 g
s
0 0 .178 r
.18682 .31337 m .18674 .31366 L .18689 .31012 L closepath p F P
0 g
s
.983 .905 .597 r
.85838 .3491 m .85971 .36065 L .85352 .37758 L p F P
0 g
s
.971 .861 .465 r
.85971 .36065 m .85838 .3491 L .85874 .34763 L p F P
0 g
s
.296 0 .229 r
.44483 .33801 m .47351 .32379 L p .4556 .34194 L F P
0 g
s
.296 0 .229 r
.4556 .34194 m .44112 .34888 L .44483 .33801 L p F P
0 g
s
.346 .066 .338 r
.47561 .3115 m .47351 .32379 L .44483 .33801 L p F P
0 g
s
.917 .955 .801 r
.83118 .42635 m .84208 .41225 L .83568 .40973 L p F P
0 g
s
.787 .888 .918 r
.34231 .44317 m .31063 .46155 L .32055 .46922 L p F P
0 g
s
.787 .888 .918 r
.32055 .46922 m .35225 .44775 L .34231 .44317 L p F P
0 g
s
.649 .778 .943 r
.30064 .45319 m .26984 .46077 L .27976 .47152 L p F P
0 g
s
.649 .778 .943 r
.27976 .47152 m .31063 .46155 L .30064 .45319 L p F P
0 g
s
.942 .693 .223 r
.85559 .28087 m .85941 .29205 L .85999 .30661 L p F P
0 g
s
.065 .321 .803 r
.67335 .4277 m .67941 .43144 L .6713 .41794 L p F P
0 g
s
.065 .321 .803 r
.6713 .41794 m .66985 .41688 L .67335 .4277 L p F P
0 g
s
.682 .407 .5 r
.51749 .29102 m .51186 .29103 L .51104 .30444 L p F P
0 g
s
.591 .334 .496 r
.51186 .29103 m .51104 .30444 L .47561 .3115 L p F P
0 g
s
.682 .407 .5 r
.51104 .30444 m .52004 .30442 L .51749 .29102 L p F P
0 g
s
0 0 .365 r
.18674 .31366 m .18682 .31337 L .18891 .32647 L p F P
0 g
s
0 0 .365 r
.18891 .32647 m .18782 .33047 L .18674 .31366 L p F P
0 g
s
0 0 .387 r
.18682 .31337 m .19206 .29761 L .19418 .31074 L p F P
0 g
s
0 0 .387 r
.19418 .31074 m .18891 .32647 L .18682 .31337 L p F P
0 g
s
.857 .983 .854 r
.39505 .40387 m .40457 .38803 L .3821 .41007 L p F P
0 g
s
.857 .983 .854 r
.38449 .41658 m .39505 .40387 L p .3821 .41007 L F P
0 g
s
.196 .371 .812 r
.22076 .42858 m .2172 .42643 L .21675 .42118 L closepath p F P
0 g
s
.892 .927 .836 r
.83118 .42635 m .81136 .44753 L .81129 .4488 L p F P
0 g
s
.874 .911 .852 r
.83172 .41457 m .83118 .42635 L .81136 .44753 L p F P
0 g
s
.917 .955 .801 r
.83568 .40973 m .83172 .41457 L .83118 .42635 L p F P
0 g
s
.11 .267 .744 r
.21124 .41002 m .20395 .40364 L .20394 .39336 L closepath p F P
0 g
s
.098 .282 .762 r
.20395 .40364 m .21124 .41002 L .21675 .42118 L p F P
0 g
s
.859 .919 .869 r
.81055 .4483 m .81136 .44753 L .81129 .4488 L closepath p F P
0 g
s
.852 .883 .861 r
.35225 .44775 m .35342 .44665 L .3537 .44838 L closepath p F P
0 g
s
.736 .401 .414 r
.57525 .31173 m .5798 .32468 L .55788 .31911 L p F P
0 g
s
.736 .401 .414 r
.55495 .30698 m .57525 .31173 L p .55788 .31911 L F P
0 g
s
.846 .894 .873 r
.81136 .44753 m .81055 .4483 L .80362 .44264 L p F P
0 g
s
.846 .894 .873 r
.80362 .44264 m .81078 .43619 L .81136 .44753 L p F P
0 g
s
.874 .911 .852 r
.81136 .44753 m .81078 .43619 L .83172 .41457 L p F P
0 g
s
.762 .886 .933 r
.77054 .46231 m .80362 .44264 L .81055 .4483 L p F P
0 g
s
.857 .983 .854 r
.3821 .41007 m .37934 .41707 L .38449 .41658 L p F P
0 g
s
.857 .983 .854 r
.37934 .41707 m .38449 .41658 L .3764 .42454 L closepath p F P
0 g
s
.561 .266 .424 r
.47351 .32379 m .47561 .3115 L .51104 .30444 L p F P
0 g
s
.018 .148 .659 r
.20197 .38814 m .19512 .37933 L .19584 .36983 L closepath p F P
0 g
s
0 .145 .666 r
.19512 .37933 m .20197 .38814 L .20394 .39336 L p F P
0 g
s
.801 .985 .892 r
.3764 .42454 m .35342 .44665 L .35375 .43403 L p F P
0 g
s
.801 .985 .892 r
.37934 .41707 m .3764 .42454 L p .35375 .43403 L F P
0 g
s
.413 .555 .888 r
.69765 .44709 m .72156 .45038 L .71369 .43911 L p F P
0 g
s
.413 .555 .888 r
.71369 .43911 m .69725 .43546 L .69765 .44709 L p F P
0 g
s
.473 .572 .874 r
.67941 .43144 m .69725 .43546 L .69765 .44709 L p F P
0 g
s
.554 .853 .537 r
.40703 .38549 m .41376 .37905 L p .40677 .38588 L F P
0 g
s
.515 .872 .634 r
.40703 .38549 m .41405 .37858 L p .42899 .36699 L F P
0 g
s
.515 .872 .634 r
.41405 .37858 m .42672 .36611 L p .42899 .36698 L F P
0 g
s
.515 .872 .634 r
.42899 .36699 m .41405 .37858 L .42899 .36698 L F
.42672 .36611 m .43586 .35828 L p .42899 .36699 L F P
0 g
s
.515 .872 .634 r
.43586 .35828 m .42956 .36654 L .42899 .36699 L p F P
0 g
s
.632 .963 .864 r
.38689 .39309 m .39595 .39135 L .42053 .37272 L p F P
0 g
s
0 0 0 r
.42053 .37272 m .41958 .37329 L .41985 .37317 L p F P
0 g
s
.709 .986 .846 r
.42053 .37272 m .39595 .39135 L p .42688 .36853 L F P
0 g
s
.515 .872 .634 r
.42899 .36699 m .40729 .3851 L p .40703 .38549 L F P
0 g
s
.562 .912 .704 r
.39698 .39109 m .42899 .36699 L .40597 .3862 L closepath p F P
0 g
s
.709 .986 .846 r
.39595 .39135 m .39698 .39109 L .42899 .36699 L p F P
0 g
s
0 0 0 r
.42942 .36666 m .42956 .36654 L .4295 .36659 L p F P
0 g
s
0 0 0 r
.4295 .36659 m .42899 .36699 L .42942 .36666 L p F P
0 g
s
0 0 0 r
.43305 .36731 m .42406 .3712 L p .42942 .36666 L F P
0 g
s
.709 .986 .846 r
.42899 .36699 m .42942 .36666 L p .42218 .37201 L F P
0 g
s
.709 .986 .846 r
.39595 .39135 m .42218 .37201 L .42942 .36666 L F
.42688 .36853 m .42925 .36678 L .42053 .37272 L F
.42942 .36666 m .42935 .3667 L p .42925 .36678 L F P
0 g
s
.709 .986 .846 r
.42935 .3667 m .42053 .37272 L p .42925 .36678 L F P
0 g
s
0 0 0 r
.42406 .3712 m .42053 .37272 L .42942 .36666 L p F P
0 g
s
0 0 0 r
.41985 .37317 m .43305 .36731 L .42053 .37272 L p F P
0 g
s
.515 .872 .634 r
.40729 .3851 m .40597 .3862 L .40703 .38549 L p F P
0 g
s
.554 .853 .537 r
.40457 .38803 m .40703 .38549 L p .40677 .38588 L F P
0 g
s
.858 .914 .869 r
.35225 .44775 m .35342 .44665 L .35375 .43403 L p F P
0 g
s
.858 .914 .869 r
.35375 .43403 m .34231 .44317 L .35225 .44775 L p F P
0 g
s
.995 .839 .484 r
.86162 .33313 m .85871 .32189 L p .85812 .34789 L F P
0 g
s
.995 .839 .484 r
.85812 .34789 m .85874 .34763 L .86162 .33313 L p F P
0 g
s
.967 .775 .34 r
.86162 .33313 m .85871 .32189 L .85999 .30661 L p F P
0 g
s
.443 .58 .895 r
.25989 .44894 m .23881 .44644 L .23856 .43374 L p F P
0 g
s
.814 .334 .049 r
.60973 .35069 m .61232 .35082 L .61402 .35334 L closepath p F P
0 g
s
.88 .451 .165 r
.60171 .34478 m .60973 .35069 L .61232 .35082 L p F P
0 g
s
.361 .502 .865 r
.22076 .42858 m .21675 .42118 L p .23867 .42074 L F P
0 g
s
.361 .502 .865 r
.23867 .42074 m .23856 .43374 L .22076 .42858 L p F P
0 g
s
.412 .553 .887 r
.69725 .43546 m .67941 .43144 L .6713 .41794 L p F P
0 g
s
.969 .92 .696 r
.85207 .36612 m .85352 .37758 L .84463 .39543 L p F P
0 g
s
.983 .905 .597 r
.85352 .37758 m .85207 .36612 L .85838 .3491 L p F P
0 g
s
.85 .447 .274 r
.59598 .33206 m .5798 .32468 L .58659 .33704 L p F P
0 g
s
.85 .447 .274 r
.58659 .33704 m .60171 .34478 L .59598 .33206 L p F P
0 g
s
0 .02 .557 r
.19328 .36013 m .19004 .35365 L .19071 .34907 L closepath p F P
0 g
s
0 .004 .555 r
.19004 .35365 m .19328 .36013 L .19584 .36983 L p F P
0 g
s
.702 .163 0 r
.61402 .35334 m .62409 .36482 L .61135 .35639 L p F P
0 g
s
.702 .163 0 r
.60973 .35069 m .61402 .35334 L p .61135 .35639 L F P
0 g
s
0 0 .51 r
.18782 .33047 m .18891 .32647 L .19356 .3388 L p F P
0 g
s
0 0 .51 r
.19356 .3388 m .19071 .34907 L .18782 .33047 L p F P
0 g
s
.361 .502 .865 r
.21675 .42118 m .21752 .41335 L .23867 .42074 L p F P
0 g
s
.272 .396 .806 r
.21752 .41335 m .21675 .42118 L .21124 .41002 L closepath p F P
0 g
s
.736 .401 .414 r
.55788 .31911 m .55411 .31074 L .55495 .30698 L p F P
0 g
s
.744 .409 .415 r
.55411 .31074 m .55232 .30652 L .55495 .30698 L closepath p F P
0 g
s
.614 .763 .95 r
.72935 .46154 m .76312 .45382 L .77054 .46231 L p F P
0 g
s
.585 .737 .948 r
.76312 .45382 m .72935 .46154 L .72156 .45038 L p F P
0 g
s
.988 .78 .386 r
.85615 .29547 m .85999 .30661 L .85871 .32189 L p F P
0 g
s
.942 .693 .223 r
.85999 .30661 m .85615 .29547 L .85559 .28087 L p F P
0 g
s
.696 .358 .4 r
.55232 .30652 m .52004 .30442 L .52736 .31635 L p F P
0 g
s
.696 .358 .4 r
.55411 .31074 m .55232 .30652 L p .52736 .31635 L F P
0 g
s
0 0 .253 r
.19235 .28374 m .19827 .26866 L .19754 .28372 L p F P
0 g
s
0 0 .253 r
.19754 .28372 m .19206 .29761 L .19235 .28374 L p F P
0 g
s
0 .074 .615 r
.65178 .39548 m .64475 .38548 L .63369 .37413 L p F P
0 g
s
.51 .013 0 r
.63369 .37413 m .62409 .36482 L .63548 .37605 L p F P
0 g
s
.51 .013 0 r
.63548 .37605 m .64475 .38548 L .63369 .37413 L p F P
0 g
s
.613 .747 .941 r
.29059 .44384 m .25989 .44894 L .26984 .46077 L p F P
0 g
s
.613 .747 .941 r
.26984 .46077 m .30064 .45319 L .29059 .44384 L p F P
0 g
s
.702 .163 0 r
.61135 .35639 m .60422 .34909 L .60973 .35069 L p F P
0 g
s
.839 .371 .045 r
.60422 .34909 m .60171 .34478 L .60973 .35069 L closepath p F P
0 g
s
.742 .856 .933 r
.80362 .44264 m .77054 .46231 L .76312 .45382 L p F P
0 g
s
.282 .395 .801 r
.21124 .41002 m .20394 .39336 L p .21952 .39952 L F P
0 g
s
.282 .395 .801 r
.21952 .39952 m .21752 .41335 L .21124 .41002 L p F P
0 g
s
0 .256 .767 r
.66317 .40562 m .65178 .39548 L p .66985 .41688 L F P
0 g
s
0 .14 .672 r
.65178 .39548 m .66317 .40562 L .65503 .39495 L p F P
0 g
s
0 .14 .672 r
.65503 .39495 m .64475 .38548 L .65178 .39548 L p F P
0 g
s
.665 .35 .429 r
.52004 .30442 m .51104 .30444 L .50883 .3164 L p F P
0 g
s
.561 .266 .424 r
.51104 .30444 m .50883 .3164 L .47351 .32379 L p F P
0 g
s
.665 .35 .429 r
.50883 .3164 m .52736 .31635 L .52004 .30442 L p F P
0 g
s
.942 .91 .758 r
.84463 .39543 m .84301 .38409 L p .83149 .4072 L F P
0 g
s
.942 .91 .758 r
.83149 .4072 m .83568 .40973 L .84463 .39543 L p F P
0 g
s
.969 .92 .696 r
.84463 .39543 m .84301 .38409 L .85207 .36612 L p F P
0 g
s
.991 .86 .506 r
.85838 .3491 m .85812 .34789 L .85874 .34763 L closepath p F P
0 g
s
.753 .872 .934 r
.33228 .43786 m .30064 .45319 L .31063 .46155 L p F P
0 g
s
.753 .872 .934 r
.31063 .46155 m .34231 .44317 L .33228 .43786 L p F P
0 g
s
0 .009 .518 r
.18891 .32647 m .19418 .31074 L .19885 .32311 L p F P
0 g
s
0 .009 .518 r
.19885 .32311 m .19356 .3388 L .18891 .32647 L p F P
0 g
s
.968 .704 .278 r
.85082 .26986 m .85559 .28087 L .85615 .29547 L p F P
0 g
s
.987 .895 .627 r
.85812 .34789 m .85838 .3491 L .85207 .36612 L p F P
0 g
s
.085 .143 .626 r
.19071 .34907 m .19356 .3388 L .20102 .35031 L p F P
0 g
s
.085 .143 .626 r
.19328 .36013 m .19071 .34907 L p .20102 .35031 L F P
0 g
s
.229 0 .123 r
.43952 .35238 m .4556 .34194 L .44112 .34888 L closepath p F P
0 g
s
0 0 0 r
.44112 .34888 m .43952 .35238 L .42672 .36611 L p F P
0 g
s
.852 .978 .865 r
.37453 .41726 m .3821 .41007 L .37934 .41707 L closepath p F P
0 g
s
.801 .985 .892 r
.35375 .43403 m .37453 .41726 L .37934 .41707 L p F P
0 g
s
.74 .403 .41 r
.55236 .3182 m .55411 .31074 L .55788 .31911 L closepath p F P
0 g
s
.696 .358 .4 r
.52736 .31635 m .55236 .3182 L .55411 .31074 L p F P
0 g
s
0 .295 .792 r
.6713 .41794 m .66985 .41688 L .66678 .41114 L closepath p F P
0 g
s
0 .256 .767 r
.66985 .41688 m .66678 .41114 L .66317 .40562 L p F P
0 g
s
.994 .873 .585 r
.85266 .34695 m .85549 .33789 L .85812 .34789 L closepath p F P
0 g
s
.995 .839 .484 r
.85871 .32189 m .85549 .33789 L .85812 .34789 L p F P
0 g
s
.987 .895 .627 r
.85266 .34695 m .85812 .34789 L p .85207 .36612 L F P
0 g
s
.282 .395 .801 r
.20394 .39336 m .20442 .39032 L .21952 .39952 L p F P
0 g
s
.165 .272 .729 r
.20442 .39032 m .20394 .39336 L .20197 .38814 L closepath p F P
0 g
s
.085 .143 .626 r
.20102 .35031 m .19682 .36536 L .19328 .36013 L p F P
0 g
s
.051 .13 .627 r
.19682 .36536 m .19584 .36983 L .19328 .36013 L closepath p F P
0 g
s
.785 .397 .319 r
.5798 .32468 m .55788 .31911 L .5664 .33086 L p F P
0 g
s
.785 .397 .319 r
.5664 .33086 m .58659 .33704 L .5798 .32468 L p F P
0 g
s
.188 .276 .723 r
.20197 .38814 m .19584 .36983 L p .20761 .37586 L F P
0 g
s
.188 .276 .723 r
.20761 .37586 m .20442 .39032 L .20197 .38814 L p F P
0 g
s
.412 .553 .887 r
.6713 .41794 m .69389 .42459 L .69725 .43546 L p F P
0 g
s
.337 .538 .902 r
.69389 .42459 m .6713 .41794 L .66678 .41114 L p F P
0 g
s
.188 .276 .723 r
.19584 .36983 m .19682 .36536 L .20761 .37586 L p F P
0 g
s
.906 .93 .818 r
.83172 .41457 m .83149 .4072 L .83568 .40973 L closepath p F P
0 g
s
.508 .179 .344 r
.47351 .32379 m .50883 .3164 L p .48784 .3311 L F P
0 g
s
.508 .179 .344 r
.48784 .3311 m .47178 .33012 L .47351 .32379 L p F P
0 g
s
.296 0 .229 r
.47351 .32379 m .47178 .33012 L .4556 .34194 L p F P
0 g
s
.863 .893 .855 r
.83149 .4072 m .83172 .41457 L .81078 .43619 L p F P
0 g
s
.833 .877 .875 r
.81078 .43619 m .80362 .44264 L .79653 .43595 L p F P
0 g
s
.742 .856 .933 r
.76312 .45382 m .79653 .43595 L .80362 .44264 L p F P
0 g
s
.833 .877 .875 r
.79653 .43595 m .80933 .42496 L .81078 .43619 L p F P
0 g
s
.863 .893 .855 r
.82903 .40545 m .83149 .4072 L p .81078 .43619 L F P
0 g
s
.863 .893 .855 r
.81078 .43619 m .80933 .42496 L .82903 .40545 L p F P
0 g
s
.346 .469 .842 r
.21752 .41335 m .21952 .39952 L p .23885 .41907 L F P
0 g
s
.346 .469 .842 r
.23885 .41907 m .23867 .42074 L .21752 .41335 L p F P
0 g
s
.802 .322 .073 r
.60171 .34478 m .58659 .33704 L .5951 .349 L p F P
0 g
s
.802 .322 .073 r
.60422 .34909 m .60171 .34478 L p .5951 .349 L F P
0 g
s
1 .831 .512 r
.85485 .3108 m .85871 .32189 L .85549 .33789 L p F P
0 g
s
.988 .78 .386 r
.85871 .32189 m .85485 .3108 L .85615 .29547 L p F P
0 g
s
.263 .363 .779 r
.20442 .39032 m .20761 .37586 L p .22192 .38712 L F P
0 g
s
.263 .363 .779 r
.22192 .38712 m .21952 .39952 L .20442 .39032 L p F P
0 g
s
.097 0 0 r
.43586 .35828 m .43952 .35238 L .4556 .34194 L p F P
0 g
s
0 0 0 r
.43586 .35828 m .43952 .35238 L .42672 .36611 L closepath p F P
0 g
s
.342 .54 .902 r
.69725 .43546 m .71369 .43911 L .70576 .42802 L p F P
0 g
s
.342 .54 .902 r
.70576 .42802 m .69389 .42459 L .69725 .43546 L p F P
0 g
s
.819 .955 .904 r
.3604 .41916 m .33228 .43786 L .34231 .44317 L p F P
0 g
s
.819 .955 .904 r
.34231 .44317 m .35375 .43403 L .3604 .41916 L p F P
0 g
s
.965 .902 .708 r
.84965 .35482 m .85207 .36612 L .84301 .38409 L p F P
0 g
s
.987 .895 .627 r
.85207 .36612 m .84965 .35482 L .85266 .34695 L p F P
0 g
s
0 0 .405 r
.19206 .29761 m .19754 .28372 L .19831 .30036 L p F P
0 g
s
0 0 .405 r
.19831 .30036 m .19418 .31074 L .19206 .29761 L p F P
0 g
s
.585 .737 .948 r
.72156 .45038 m .75559 .44471 L .76312 .45382 L p F P
0 g
s
.558 .717 .947 r
.75559 .44471 m .72156 .45038 L .71369 .43911 L p F P
0 g
s
.576 .707 .932 r
.28052 .43321 m .24996 .43578 L .25989 .44894 L p F P
0 g
s
.576 .707 .932 r
.25989 .44894 m .29059 .44384 L .28052 .43321 L p F P
0 g
s
.443 .58 .895 r
.23856 .43374 m .24996 .43578 L .25989 .44894 L p F P
0 g
s
.757 .969 .928 r
.37453 .41726 m .35375 .43403 L .3604 .41916 L p F P
0 g
s
.337 .538 .902 r
.66678 .41114 m .66507 .40631 L p .69389 .42459 L F P
0 g
s
.29 .506 .892 r
.66678 .41114 m .66317 .40562 L .66507 .40631 L closepath p F P
0 g
s
.181 .253 .702 r
.19682 .36536 m .20102 .35031 L p .21157 .36121 L F P
0 g
s
.181 .253 .702 r
.21157 .36121 m .20761 .37586 L .19682 .36536 L p F P
0 g
s
.71 .958 .689 r
.40597 .3862 m .40703 .38549 L .40457 .38803 L closepath p F P
0 g
s
.414 .55 .883 r
.24996 .43578 m .23856 .43374 L .23867 .42074 L p F P
0 g
s
.602 .93 .716 r
.40457 .38803 m .3821 .41007 L .3943 .39323 L p F P
0 g
s
.602 .93 .716 r
.40597 .3862 m .40457 .38803 L p .3943 .39323 L F P
0 g
s
.617 .077 0 r
.62409 .36482 m .61135 .35639 L .62375 .36729 L p F P
0 g
s
.617 .077 0 r
.62375 .36729 m .63548 .37605 L .62409 .36482 L p F P
0 g
s
.723 .343 .329 r
.55788 .31911 m .55236 .3182 L .54831 .3279 L p F P
0 g
s
.723 .343 .329 r
.54831 .3279 m .5664 .33086 L .55788 .31911 L p F P
0 g
s
.097 0 0 r
.4556 .34194 m .47006 .33476 L p .43586 .35828 L F P
0 g
s
.256 0 .184 r
.47006 .33476 m .47178 .33012 L .4556 .34194 L closepath p F P
0 g
s
.765 .992 .785 r
.37453 .41726 m .3821 .41007 L .3943 .39323 L p F P
0 g
s
.765 .992 .785 r
.3943 .39323 m .36448 .41643 L .37453 .41726 L p F P
0 g
s
.757 .969 .928 r
.3604 .41916 m .36448 .41643 L .37453 .41726 L p F P
0 g
s
.996 .776 .424 r
.85136 .2845 m .85615 .29547 L .85485 .3108 L p F P
0 g
s
.968 .704 .278 r
.85615 .29547 m .85136 .2845 L .85082 .26986 L p F P
0 g
s
.734 .218 0 r
.59728 .35017 m .60422 .34909 L .61135 .35639 L closepath p F P
0 g
s
.802 .322 .073 r
.5951 .349 m .59728 .35017 L .60422 .34909 L p F P
0 g
s
.67 .284 .306 r
.55236 .3182 m .52736 .31635 L .5385 .32718 L p F P
0 g
s
.67 .284 .306 r
.5385 .32718 m .54831 .3279 L .55236 .3182 L p F P
0 g
s
.602 .93 .716 r
.3943 .39323 m .39698 .39109 L .40597 .3862 L p F P
0 g
s
.496 .135 .284 r
.47006 .33476 m .47178 .33012 L .48784 .3311 L closepath p F P
0 g
s
.722 .83 .932 r
.79653 .43595 m .76312 .45382 L .75559 .44471 L p F P
0 g
s
0 .062 .565 r
.65503 .39495 m .64475 .38548 L .63548 .37605 L p F P
0 g
s
.646 .294 .361 r
.52736 .31635 m .50883 .3164 L .50549 .32726 L p F P
0 g
s
.508 .179 .344 r
.50883 .3164 m .50549 .32726 L .48784 .3311 L p F P
0 g
s
.646 .294 .361 r
.50549 .32726 m .5385 .32718 L .52736 .31635 L p F P
0 g
s
.716 .844 .943 r
.32217 .43146 m .29059 .44384 L .30064 .45319 L p F P
0 g
s
.716 .844 .943 r
.30064 .45319 m .33228 .43786 L .32217 .43146 L p F P
0 g
s
.228 .511 .909 r
.66507 .40631 m .66317 .40562 L .65503 .39495 L p F P
0 g
s
.103 .141 .616 r
.19356 .3388 m .19885 .32311 L p .20494 .33877 L F P
0 g
s
.103 .141 .616 r
.20494 .33877 m .20102 .35031 L .19356 .3388 L p F P
0 g
s
.981 .706 .324 r
.84509 .25902 m .85082 .26986 L .85136 .2845 L p F P
0 g
s
.916 .909 .799 r
.82903 .40545 m .83081 .40309 L .83149 .4072 L closepath p F P
0 g
s
.942 .91 .758 r
.84301 .38409 m .83081 .40309 L .83149 .4072 L p F P
0 g
s
.933 .896 .768 r
.84041 .3729 m .84301 .38409 L .83081 .40309 L p F P
0 g
s
.965 .902 .708 r
.84301 .38409 m .84041 .3729 L .84965 .35482 L p F P
0 g
s
.991 .859 .607 r
.85549 .33789 m .85266 .34695 L .84623 .34366 L p F P
0 g
s
.991 .859 .607 r
.84623 .34366 m .85159 .32686 L .85549 .33789 L p F P
0 g
s
1 .831 .512 r
.85549 .33789 m .85159 .32686 L .85485 .3108 L p F P
0 g
s
.337 .538 .902 r
.66507 .40631 m .68839 .41423 L .69389 .42459 L p F P
0 g
s
.213 .513 .912 r
.65837 .39621 m .66507 .40631 L .68839 .41423 L p F P
0 g
s
.228 .511 .909 r
.65503 .39495 m .65837 .39621 L .66507 .40631 L p F P
0 g
s
0 0 .333 r
.19827 .26866 m .19909 .26715 L .19904 .28098 L p F P
0 g
s
0 0 .333 r
.19904 .28098 m .19754 .28372 L .19827 .26866 L p F P
0 g
s
.786 .342 .193 r
.58659 .33704 m .5664 .33086 L .577 .34211 L p F P
0 g
s
.786 .342 .193 r
.577 .34211 m .5951 .349 L .58659 .33704 L p F P
0 g
s
0 0 .353 r
.19909 .26715 m .21021 .24869 L .21021 .26257 L p F P
0 g
s
0 0 .353 r
.21021 .26257 m .19904 .28098 L .19909 .26715 L p F P
0 g
s
.069 0 0 r
.42956 .36654 m .43586 .35828 L .46522 .34441 L p F P
0 g
s
.097 0 0 r
.47006 .33476 m .46522 .34441 L .43586 .35828 L p F P
0 g
s
.539 .662 .916 r
.27045 .42104 m .24006 .42107 L .24996 .43578 L p F P
0 g
s
.539 .662 .916 r
.24996 .43578 m .28052 .43321 L .27045 .42104 L p F P
0 g
s
.414 .55 .883 r
.23867 .42074 m .24006 .42107 L .24996 .43578 L p F P
0 g
s
.452 .054 .194 r
.46522 .34441 m .47006 .33476 L .48784 .3311 L p F P
0 g
s
.984 .877 .643 r
.84965 .35482 m .85266 .34695 L .84623 .34366 L p F P
0 g
s
.558 .717 .947 r
.71369 .43911 m .74796 .43519 L .75559 .44471 L p F P
0 g
s
.535 .703 .947 r
.74796 .43519 m .71369 .43911 L .70576 .42802 L p F P
0 g
s
.906 .889 .803 r
.83081 .40309 m .82903 .40545 L .82215 .39955 L p F P
0 g
s
.906 .889 .803 r
.82215 .39955 m .82793 .39206 L .83081 .40309 L p F P
0 g
s
.933 .896 .768 r
.83081 .40309 m .82793 .39206 L .84041 .3729 L p F P
0 g
s
.863 .895 .856 r
.80933 .42496 m .82903 .40545 L .82215 .39955 L p F P
0 g
s
.998 .818 .536 r
.85003 .29986 m .85485 .3108 L .85159 .32686 L p F P
0 g
s
.996 .776 .424 r
.85485 .3108 m .85003 .29986 L .85136 .2845 L p F P
0 g
s
.027 .029 .522 r
.19418 .31074 m .19831 .30036 L .20066 .31861 L p F P
0 g
s
.027 .029 .522 r
.20066 .31861 m .19885 .32311 L .19418 .31074 L p F P
0 g
s
.822 .861 .876 r
.80933 .42496 m .79653 .43595 L .78929 .42841 L p F P
0 g
s
.722 .83 .932 r
.75559 .44471 m .78929 .42841 L .79653 .43595 L p F P
0 g
s
.618 .052 0 r
.61135 .35639 m .62375 .36729 L .60893 .35941 L p F P
0 g
s
.618 .052 0 r
.59728 .35017 m .61135 .35639 L p .60893 .35941 L F P
0 g
s
.822 .861 .876 r
.78929 .42841 m .80699 .41385 L .80933 .42496 L p F P
0 g
s
.863 .895 .856 r
.82215 .39955 m .80699 .41385 L .80933 .42496 L p F P
0 g
s
.275 .525 .91 r
.69389 .42459 m .70576 .42802 L .69778 .41734 L p F P
0 g
s
.275 .525 .91 r
.69778 .41734 m .68839 .41423 L .69389 .42459 L p F P
0 g
s
.958 .883 .716 r
.84622 .34369 m .84965 .35482 L .84041 .3729 L p F P
0 g
s
.984 .877 .643 r
.84623 .34366 m .84622 .34369 L .84965 .35482 L p F P
0 g
s
.776 .938 .934 r
.35435 .41374 m .32217 .43146 L .33228 .43786 L p F P
0 g
s
.776 .938 .934 r
.36247 .41593 m .35435 .41374 L p .33228 .43786 L F P
0 g
s
.776 .938 .934 r
.33228 .43786 m .3604 .41916 L .36247 .41593 L p F P
0 g
s
.452 .054 .194 r
.48784 .3311 m .50403 .33075 L p .46522 .34441 L F P
0 g
s
.462 .081 .23 r
.50403 .33075 m .48784 .3311 L .50549 .32726 L closepath p F P
0 g
s
.647 .223 .224 r
.5664 .33086 m .577 .34211 L .55245 .33726 L p F P
0 g
s
.647 .223 .224 r
.54831 .3279 m .5664 .33086 L p .55245 .33726 L F P
0 g
s
.333 .436 .817 r
.23028 .40396 m .21952 .39952 L .22192 .38712 L closepath p F P
0 g
s
.346 .469 .842 r
.21952 .39952 m .23028 .40396 L .23885 .41907 L p F P
0 g
s
.996 .766 .454 r
.84561 .27369 m .85136 .2845 L .85003 .29986 L p F P
0 g
s
.981 .706 .324 r
.85136 .2845 m .84561 .27369 L .84509 .25902 L p F P
0 g
s
0 .108 .58 r
.63548 .37605 m .62375 .36729 L .63726 .37804 L p F P
0 g
s
0 .062 .565 r
.64689 .38619 m .65503 .39495 L p .6505 .39057 L F P
0 g
s
0 .062 .565 r
.63548 .37605 m .64689 .38619 L p .6505 .39057 L F P
0 g
s
.036 .485 .882 r
.64689 .38619 m .64881 .38687 L .64571 .38476 L p F P
0 g
s
0 .108 .58 r
.64689 .38619 m .63548 .37605 L p .63726 .37804 L F P
0 g
s
.036 .485 .882 r
.64571 .38476 m .64328 .3831 L .64689 .38619 L p F P
0 g
s
.706 .81 .929 r
.78929 .42841 m .75559 .44471 L .74796 .43519 L p F P
0 g
s
.268 .347 .759 r
.22066 .38433 m .20761 .37586 L .21157 .36121 L closepath p F P
0 g
s
.263 .363 .779 r
.20761 .37586 m .22066 .38433 L .22192 .38712 L p F P
0 g
s
.048 0 .465 r
.19754 .28372 m .19904 .28098 L .20188 .2939 L p F P
0 g
s
.048 0 .465 r
.20188 .2939 m .19831 .30036 L .19754 .28372 L p F P
0 g
s
.14 .506 .91 r
.65503 .39495 m .65837 .39621 L .64881 .38687 L p F P
0 g
s
.14 .506 .91 r
.64881 .38687 m .64689 .38619 L .65503 .39495 L p F P
0 g
s
.677 .805 .944 r
.31202 .42366 m .28052 .43321 L .29059 .44384 L p F P
0 g
s
.677 .805 .944 r
.29059 .44384 m .32217 .43146 L .31202 .42366 L p F P
0 g
s
.393 .515 .862 r
.24006 .42107 m .23867 .42074 L .23885 .41907 L closepath p F P
0 g
s
.984 .701 .362 r
.83839 .24835 m .84509 .25902 L .84561 .27369 L p F P
0 g
s
.647 .223 .224 r
.55245 .33726 m .54568 .33228 L .54831 .3279 L p F P
0 g
s
.642 .218 .222 r
.54568 .33228 m .5385 .32718 L .54831 .3279 L closepath p F P
0 g
s
.474 .558 .861 r
.26043 .40705 m .27045 .42104 L .24006 .42107 L p F P
0 g
s
.474 .558 .861 r
.2436 .40591 m .26043 .40705 L p .24006 .42107 L F P
0 g
s
.474 .558 .861 r
.24006 .42107 m .23885 .41907 L .2436 .40591 L p F P
0 g
s
.2 .249 .689 r
.21138 .36064 m .20102 .35031 L .20494 .33877 L closepath p F P
0 g
s
.181 .253 .702 r
.20102 .35031 m .21138 .36064 L .21157 .36121 L p F P
0 g
s
.568 .185 .276 r
.50549 .32726 m .5385 .32718 L p .51688 .33603 L F P
0 g
s
.568 .185 .276 r
.51688 .33603 m .50403 .33075 L .50549 .32726 L p F P
0 g
s
.568 .185 .276 r
.5385 .32718 m .54568 .33228 L p .51688 .33603 L F P
0 g
s
.618 .052 0 r
.60893 .35941 m .59606 .35014 L .59728 .35017 L p F P
0 g
s
.763 .253 0 r
.59606 .35014 m .5951 .349 L .59728 .35017 L closepath p F P
0 g
s
.213 .513 .912 r
.68839 .41423 m .68114 .40428 L .65837 .39621 L p F P
0 g
s
.167 .511 .913 r
.65837 .39621 m .64881 .38687 L .67224 .39471 L p F P
0 g
s
.167 .511 .913 r
.67224 .39471 m .68114 .40428 L .65837 .39621 L p F P
0 g
s
.084 .015 .472 r
.19904 .28098 m .21021 .26257 L .21313 .27552 L p F P
0 g
s
.084 .015 .472 r
.21313 .27552 m .20188 .2939 L .19904 .28098 L p F P
0 g
s
.777 .94 .933 r
.36247 .41593 m .36448 .41643 L .3604 .41916 L closepath p F P
0 g
s
.451 .532 .849 r
.2436 .40591 m .23885 .41907 L .23028 .40396 L closepath p F P
0 g
s
.984 .839 .62 r
.85159 .32686 m .84673 .31598 L p .84619 .34363 L F P
0 g
s
.984 .839 .62 r
.84619 .34363 m .84623 .34366 L .85159 .32686 L p F P
0 g
s
.998 .818 .536 r
.85159 .32686 m .84673 .31598 L .85003 .29986 L p F P
0 g
s
.925 .877 .77 r
.83681 .36188 m .84041 .3729 L .82793 .39206 L p F P
0 g
s
.958 .883 .716 r
.84041 .3729 m .83681 .36188 L .84622 .34369 L p F P
0 g
s
.764 .94 .94 r
.36448 .41643 m .3943 .39323 L p .37251 .40228 L F P
0 g
s
.764 .94 .94 r
.37251 .40228 m .36247 .41593 L .36448 .41643 L p F P
0 g
s
.763 .289 .118 r
.59606 .35014 m .5951 .349 L .577 .34211 L p F P
0 g
s
.535 .703 .947 r
.70576 .42802 m .74023 .42543 L .74796 .43519 L p F P
0 g
s
.519 .695 .949 r
.74023 .42543 m .70576 .42802 L .69778 .41734 L p F P
0 g
s
.561 0 0 r
.59606 .35014 m .60893 .35941 L .58979 .35283 L p F P
0 g
s
.561 0 0 r
.58979 .35283 m .58777 .35172 L .59606 .35014 L p F P
0 g
s
.763 .289 .118 r
.577 .34211 m .58777 .35172 L .59606 .35014 L p F P
0 g
s
.764 .94 .94 r
.3943 .39323 m .39595 .39135 L p .37251 .40228 L F P
0 g
s
.738 .992 .845 r
.39595 .39135 m .39698 .39109 L .3943 .39323 L closepath p F P
0 g
s
.762 .936 .941 r
.35435 .41374 m .37251 .40228 L .36247 .41593 L closepath p F P
0 g
s
.154 .12 .564 r
.19831 .30036 m .20188 .2939 L .2078 .30587 L p F P
0 g
s
.154 .12 .564 r
.2078 .30587 m .20066 .31861 L .19831 .30036 L p F P
0 g
s
.128 .144 .608 r
.20281 .32937 m .19885 .32311 L .20066 .31861 L closepath p F P
0 g
s
.103 .141 .616 r
.19885 .32311 m .20281 .32937 L .20494 .33877 L p F P
0 g
s
.991 .802 .554 r
.84425 .2891 m .85003 .29986 L .84673 .31598 L p F P
0 g
s
.996 .766 .454 r
.85003 .29986 m .84425 .2891 L .84561 .27369 L p F P
0 g
s
.896 .87 .804 r
.82793 .39206 m .82215 .39955 L .81509 .39256 L p F P
0 g
s
.896 .87 .804 r
.81509 .39256 m .82407 .38118 L .82793 .39206 L p F P
0 g
s
.925 .877 .77 r
.82793 .39206 m .82407 .38118 L .83681 .36188 L p F P
0 g
s
.569 .149 .205 r
.50065 .33661 m .50403 .33075 L .51688 .33603 L closepath p F P
0 g
s
.452 .054 .194 r
.50403 .33075 m .50065 .33661 L .46522 .34441 L p F P
0 g
s
.812 .846 .875 r
.80699 .41385 m .78929 .42841 L .78191 .42015 L p F P
0 g
s
.706 .81 .929 r
.74796 .43519 m .78191 .42015 L .78929 .42841 L p F P
0 g
s
.764 .94 .94 r
.39595 .39135 m .38689 .39309 L .37251 .40228 L p F P
0 g
s
.222 .519 .915 r
.68839 .41423 m .69778 .41734 L .68975 .40724 L p F P
0 g
s
.222 .519 .915 r
.68975 .40724 m .68114 .40428 L .68839 .41423 L p F P
0 g
s
.45 .533 .851 r
.23028 .40396 m .22192 .38712 L p .24878 .39078 L F P
0 g
s
.45 .533 .851 r
.24878 .39078 m .2436 .40591 L .23028 .40396 L p F P
0 g
s
.849 .871 .857 r
.80699 .41385 m .82215 .39955 L .81509 .39256 L p F P
0 g
s
.812 .846 .875 r
.78191 .42015 m .80369 .40289 L .80699 .41385 L p F P
0 g
s
.849 .871 .857 r
.81509 .39256 m .80369 .40289 L .80699 .41385 L p F P
0 g
s
.4 0 .113 r
.4621 .34951 m .46522 .34441 L .50065 .33661 L p F P
0 g
s
.069 0 0 r
.46522 .34441 m .4621 .34951 L .42956 .36654 L p F P
0 g
s
.524 0 0 r
.62375 .36729 m .60893 .35941 L .62435 .36952 L p F P
0 g
s
.524 0 0 r
.62435 .36952 m .63726 .37804 L .62375 .36729 L p F P
0 g
s
0 0 0 r
.42942 .36666 m .42956 .36654 L .4621 .34951 L p F P
0 g
s
.975 .857 .66 r
.84622 .34369 m .84619 .34363 L .84623 .34366 L closepath p F P
0 g
s
.947 .862 .723 r
.84619 .34363 m .84622 .34369 L .83681 .36188 L p F P
0 g
s
.965 .851 .678 r
.83941 .33732 m .8413 .33288 L .84619 .34363 L closepath p F P
0 g
s
.947 .862 .723 r
.83941 .33732 m .84619 .34363 L p .83681 .36188 L F P
0 g
s
.984 .839 .62 r
.84673 .31598 m .8413 .33288 L .84619 .34363 L p F P
0 g
s
.653 .211 .187 r
.54284 .33618 m .54568 .33228 L .55245 .33726 L closepath p F P
0 g
s
.568 .185 .276 r
.54568 .33228 m .54284 .33618 L .51688 .33603 L p F P
0 g
s
0 0 0 r
.42942 .36666 m .45898 .35275 L p .43312 .36727 L F P
0 g
s
0 0 0 r
.43304 .36731 m .42942 .36666 L .43312 .36727 L F
.632 .963 .864 r
.41958 .37329 m .38689 .39309 L p .41875 .3738 L F P
0 g
s
.632 .963 .864 r
.42053 .37272 m .41958 .37329 L p .41875 .3738 L F P
0 g
s
0 0 0 r
.45237 .3586 m .43305 .36731 L p .44833 .35874 L F P
0 g
s
0 0 0 r
.45898 .35275 m .45237 .3586 L p .44833 .35874 L F P
0 g
s
0 0 0 r
.45237 .3586 m .47173 .35443 L .4538 .35855 L p F P
0 g
s
.321 .789 .679 r
.45078 .35924 m .45237 .3586 L .4519 .35881 L p F P
0 g
s
.321 .789 .679 r
.4519 .35881 m .43305 .36731 L .45078 .35924 L p F P
0 g
s
.369 .827 .738 r
.45078 .35924 m .45005 .35949 L p .44122 .36355 L F P
0 g
s
.369 .827 .738 r
.45005 .35949 m .44257 .36201 L p .44122 .36355 L F P
0 g
s
0 0 0 r
.43305 .36731 m .43304 .36731 L .43312 .36727 L F
.369 .827 .738 r
.41958 .37329 m .43305 .36731 L .45078 .35924 L p F P
0 g
s
0 0 0 r
.45078 .35924 m .47173 .35443 L p .44577 .36118 L F P
0 g
s
0 0 0 r
.44257 .36201 m .45078 .35924 L p .44577 .36118 L F P
0 g
s
0 0 0 r
.4538 .35855 m .45078 .35924 L .45237 .3586 L p F P
0 g
s
.369 .827 .738 r
.44257 .36201 m .42903 .36751 L p .41958 .37329 L F P
0 g
s
.369 .827 .738 r
.42903 .36751 m .40956 .37543 L .41958 .37329 L p F P
0 g
s
.369 .827 .738 r
.41958 .37329 m .44122 .36355 L .44257 .36201 L F
0 0 0 r
.4621 .34951 m .45898 .35275 L .42942 .36666 L p F P
0 g
s
.99 .752 .478 r
.83888 .26306 m .84561 .27369 L .84425 .2891 L p F P
0 g
s
.984 .701 .362 r
.84561 .27369 m .83888 .26306 L .83839 .24835 L p F P
0 g
s
.694 .794 .926 r
.78191 .42015 m .74796 .43519 L .74023 .42543 L p F P
0 g
s
.638 .759 .936 r
.30185 .41419 m .27045 .42104 L .28052 .43321 L p F P
0 g
s
.638 .759 .936 r
.28052 .43321 m .31202 .42366 L .30185 .41419 L p F P
0 g
s
.738 .895 .95 r
.34418 .40914 m .31202 .42366 L .32217 .43146 L p F P
0 g
s
.738 .895 .95 r
.32217 .43146 m .35435 .41374 L .34418 .40914 L p F P
0 g
s
.599 .041 0 r
.577 .34211 m .55245 .33726 L .56828 .34693 L p F P
0 g
s
.599 .041 0 r
.58777 .35172 m .577 .34211 L p .56828 .34693 L F P
0 g
s
0 .108 .58 r
.63726 .37804 m .64328 .3831 L .64689 .38619 L p F P
0 g
s
.245 .233 .647 r
.20066 .31861 m .2078 .30587 L .21709 .3168 L p F P
0 g
s
.245 .233 .647 r
.20281 .32937 m .20066 .31861 L p .21709 .3168 L F P
0 g
s
.013 0 .369 r
.21021 .24869 m .21427 .24255 L .21351 .25762 L p F P
0 g
s
.013 0 .369 r
.21351 .25762 m .21021 .26257 L .21021 .24869 L p F P
0 g
s
.98 .692 .392 r
.83839 .24835 m .8307 .23787 L .83116 .25261 L p F P
0 g
s
.98 .692 .392 r
.83116 .25261 m .83888 .26306 L .83839 .24835 L p F P
0 g
s
.45 .533 .851 r
.22192 .38712 m .22274 .38506 L .24878 .39078 L p F P
0 g
s
.381 .442 .799 r
.22274 .38506 m .22192 .38712 L .22066 .38433 L closepath p F P
0 g
s
.126 .543 .92 r
.64881 .38687 m .67224 .39471 L .66154 .38558 L p F P
0 g
s
.126 .543 .92 r
.64328 .3831 m .64881 .38687 L p .66154 .38558 L F P
0 g
s
.388 .438 .791 r
.22066 .38433 m .21157 .36121 L p .23016 .36894 L F P
0 g
s
.388 .438 .791 r
.23016 .36894 m .22274 .38506 L .22066 .38433 L p F P
0 g
s
.178 .131 .564 r
.20188 .2939 m .21313 .27552 L p .2162 .29227 L F P
0 g
s
.178 .131 .564 r
.2162 .29227 m .2078 .30587 L .20188 .2939 L p F P
0 g
s
.245 .233 .647 r
.21709 .3168 m .20719 .33434 L .20281 .32937 L p F P
0 g
s
.227 .229 .652 r
.20719 .33434 m .20494 .33877 L .20281 .32937 L closepath p F P
0 g
s
.975 .822 .629 r
.8409 .30527 m .84673 .31598 L .8413 .33288 L p F P
0 g
s
.991 .802 .554 r
.84673 .31598 m .8409 .30527 L .84425 .2891 L p F P
0 g
s
.319 .339 .725 r
.20494 .33877 m .20719 .33434 L .22043 .34403 L p F P
0 g
s
.319 .339 .725 r
.21138 .36064 m .20494 .33877 L p .22043 .34403 L F P
0 g
s
.427 .493 .825 r
.22274 .38506 m .23016 .36894 L p .24947 .38917 L F P
0 g
s
.427 .493 .825 r
.24947 .38917 m .24878 .39078 L .22274 .38506 L p F P
0 g
s
.519 .695 .949 r
.69778 .41734 m .73242 .41556 L .74023 .42543 L p F P
0 g
s
.513 .694 .951 r
.73242 .41556 m .69778 .41734 L .68975 .40724 L p F P
0 g
s
.916 .858 .77 r
.83217 .35104 m .83681 .36188 L .82407 .38118 L p F P
0 g
s
.947 .862 .723 r
.83681 .36188 m .83217 .35104 L .83941 .33732 L p F P
0 g
s
.388 .438 .791 r
.21157 .36121 m .21172 .36086 L .23016 .36894 L p F P
0 g
s
.306 .34 .733 r
.21172 .36086 m .21157 .36121 L .21138 .36064 L closepath p F P
0 g
s
.319 .339 .725 r
.22043 .34403 m .21172 .36086 L .21138 .36064 L p F P
0 g
s
.367 .404 .767 r
.21172 .36086 m .22043 .34403 L p .23508 .35918 L F P
0 g
s
.367 .404 .767 r
.23508 .35918 m .23016 .36894 L .21172 .36086 L p F P
0 g
s
.545 .06 .056 r
.55245 .33726 m .56828 .34693 L .53946 .34338 L p F P
0 g
s
.545 .06 .056 r
.54284 .33618 m .55245 .33726 L p .53946 .34338 L F P
0 g
s
.126 .543 .92 r
.66154 .38558 m .63871 .3791 L .64328 .3831 L p F P
0 g
s
.131 .584 .924 r
.64861 .37703 m .63307 .37376 L p .63871 .3791 L F P
0 g
s
.131 .584 .924 r
.63307 .37376 m .63048 .37322 L .63871 .3791 L p F P
0 g
s
0 .165 .637 r
.63871 .3791 m .63726 .37804 L .64026 .38056 L p F P
0 g
s
0 .165 .637 r
.64026 .38056 m .64328 .3831 L .63871 .3791 L p F P
0 g
s
.466 .014 .093 r
.50065 .33661 m .51688 .33603 L p .49535 .34487 L F P
0 g
s
.466 .014 .093 r
.49535 .34487 m .49478 .34479 L .50065 .33661 L p F P
0 g
s
.4 0 .113 r
.50065 .33661 m .49478 .34479 L .4621 .34951 L p F P
0 g
s
.284 0 0 r
.45898 .35275 m .4621 .34951 L .49478 .34479 L p F P
0 g
s
.48 .567 .866 r
.26043 .40705 m .2436 .40591 L .24878 .39078 L p F P
0 g
s
.517 0 0 r
.60893 .35941 m .58979 .35283 L .60838 .36187 L p F P
0 g
s
.393 0 0 r
.58979 .35283 m .60101 .35829 L p .58786 .3556 L F P
0 g
s
.393 0 0 r
.60101 .35829 m .60838 .36187 L .58786 .3556 L p F P
0 g
s
.393 0 0 r
.58655 .35201 m .58979 .35283 L p .58786 .3556 L F P
0 g
s
.393 0 0 r
.58786 .3556 m .57931 .35288 L .58655 .35201 L p F P
0 g
s
.372 0 0 r
.57486 .35309 m .57931 .35288 L .58786 .3556 L closepath p F P
0 g
s
.166 0 0 r
.59282 .35618 m .57936 .35387 L .58786 .3556 L F
.57486 .35309 m .58786 .3556 L p .57936 .35387 L F P
0 g
s
0 .474 .824 r
.60838 .36187 m .58786 .3556 L .59987 .35916 L p F P
0 g
s
.517 0 0 r
.61676 .36454 m .60893 .35941 L p .60838 .36187 L F P
0 g
s
0 .474 .824 r
.59987 .35916 m .61246 .3629 L p .60838 .36187 L F P
0 g
s
.517 0 0 r
.60838 .36187 m .62435 .36952 L .61676 .36454 L p F P
0 g
s
.545 .06 .056 r
.53946 .34338 m .53694 .34245 L .54284 .33618 L p F P
0 g
s
.525 .039 .043 r
.53694 .34245 m .51688 .33603 L .54284 .33618 L closepath p F P
0 g
s
.466 .014 .093 r
.51688 .33603 m .53694 .34245 L p .49535 .34487 L F P
0 g
s
.738 .967 .935 r
.37675 .3921 m .34418 .40914 L .35435 .41374 L p F P
0 g
s
.738 .967 .935 r
.38184 .39266 m .37675 .3921 L p .35435 .41374 L F P
0 g
s
.738 .967 .935 r
.35435 .41374 m .37251 .40228 L .38184 .39266 L p F P
0 g
s
.981 .784 .567 r
.83748 .27851 m .84425 .2891 L .8409 .30527 L p F P
0 g
s
.99 .752 .478 r
.84425 .2891 m .83748 .27851 L .83888 .26306 L p F P
0 g
s
.14 .002 .418 r
.21427 .24255 m .22655 .22802 L .22695 .24182 L p F P
0 g
s
.14 .002 .418 r
.22695 .24182 m .21351 .25762 L .21427 .24255 L p F P
0 g
s
.887 .853 .803 r
.82407 .38118 m .81509 .39256 L .80786 .38459 L p F P
0 g
s
.887 .853 .803 r
.80786 .38459 m .81921 .37048 L .82407 .38118 L p F P
0 g
s
.916 .858 .77 r
.82407 .38118 m .81921 .37048 L .83217 .35104 L p F P
0 g
s
.178 .518 .917 r
.68975 .40724 m .68114 .40428 L .67224 .39471 L p F P
0 g
s
.803 .832 .873 r
.80369 .40289 m .78191 .42015 L .77441 .41131 L p F P
0 g
s
.694 .794 .926 r
.74023 .42543 m .77441 .41131 L .78191 .42015 L p F P
0 g
s
.31 .315 .703 r
.20719 .33434 m .21709 .3168 L p .22602 .33419 L F P
0 g
s
.31 .315 .703 r
.22602 .33419 m .22043 .34403 L .20719 .33434 L p F P
0 g
s
.601 .707 .919 r
.2917 .40279 m .26043 .40705 L .27045 .42104 L p F P
0 g
s
.601 .707 .919 r
.27045 .42104 m .30185 .41419 L .2917 .40279 L p F P
0 g
s
.803 .832 .873 r
.77441 .41131 m .7993 .39212 L .80369 .40289 L p F P
0 g
s
.836 .85 .856 r
.80786 .38459 m .7993 .39212 L .80369 .40289 L p F P
0 g
s
.836 .85 .856 r
.80369 .40289 m .81509 .39256 L .80786 .38459 L p F P
0 g
s
.687 .781 .923 r
.77441 .41131 m .74023 .42543 L .73242 .41556 L p F P
0 g
s
.955 .832 .683 r
.8413 .33288 m .83941 .33732 L .83235 .32933 L p F P
0 g
s
.955 .832 .683 r
.83235 .32933 m .83541 .32223 L .8413 .33288 L p F P
0 g
s
.975 .822 .629 r
.8413 .33288 m .83541 .32223 L .8409 .30527 L p F P
0 g
s
.98 .737 .496 r
.83888 .26306 m .83116 .25261 L .82972 .26811 L p F P
0 g
s
.98 .737 .496 r
.82972 .26811 m .83748 .27851 L .83888 .26306 L p F P
0 g
s
.738 .97 .932 r
.38184 .39266 m .38689 .39309 L .37251 .40228 L closepath p F P
0 g
s
.117 .034 .477 r
.21021 .26257 m .21351 .25762 L .21407 .27412 L p F P
0 g
s
.117 .034 .477 r
.21407 .27412 m .21313 .27552 L .21021 .26257 L p F P
0 g
s
.465 0 0 r
.63871 .3791 m .63726 .37804 L .62435 .36952 L p F P
0 g
s
.938 .842 .723 r
.83217 .35104 m .83941 .33732 L .83235 .32933 L p F P
0 g
s
.7 .843 .951 r
.33397 .40251 m .30185 .41419 L .31202 .42366 L p F P
0 g
s
.7 .843 .951 r
.31202 .42366 m .34418 .40914 L .33397 .40251 L p F P
0 g
s
.567 .002 0 r
.58655 .35201 m .58777 .35172 L .58979 .35283 L closepath p F P
0 g
s
.599 .041 0 r
.56828 .34693 m .58655 .35201 L .58777 .35172 L p F P
0 g
s
.971 .68 .417 r
.8307 .23787 m .82201 .22759 L .82243 .24236 L p F P
0 g
s
.971 .68 .417 r
.82243 .24236 m .83116 .25261 L .8307 .23787 L p F P
0 g
s
.131 .584 .924 r
.63871 .3791 m .66154 .38558 L .64861 .37703 L p F P
0 g
s
.465 0 0 r
.62435 .36952 m .63048 .37322 L .63871 .3791 L p F P
0 g
s
.654 .953 .947 r
.38689 .39309 m .41958 .37329 L p .40169 .37946 L F P
0 g
s
.654 .953 .947 r
.40169 .37946 m .38184 .39266 L .38689 .39309 L p F P
0 g
s
.186 0 0 r
.45898 .35275 m .49465 .34491 L p .47173 .35443 L F P
0 g
s
.186 0 0 r
.47173 .35443 m .45237 .3586 L .45898 .35275 L p F P
0 g
s
.284 0 0 r
.49478 .34479 m .49465 .34491 L .45898 .35275 L p F P
0 g
s
.255 .228 .634 r
.2078 .30587 m .2162 .29227 L .22001 .31214 L p F P
0 g
s
.255 .228 .634 r
.22001 .31214 m .21709 .3168 L .2078 .30587 L p F P
0 g
s
.513 .694 .951 r
.68975 .40724 m .72453 .40568 L .73242 .41556 L p F P
0 g
s
.511 .697 .953 r
.71656 .39582 m .68168 .39779 L .68975 .40724 L p F P
0 g
s
.511 .697 .953 r
.68975 .40724 m .72453 .40568 L .71656 .39582 L p F P
0 g
s
.178 .518 .917 r
.67224 .39471 m .68168 .39779 L .68975 .40724 L p F P
0 g
s
.544 0 0 r
.57931 .35288 m .56828 .34693 L .58655 .35201 L closepath p F P
0 g
s
.963 .803 .635 r
.83409 .29473 m .8409 .30527 L .83541 .32223 L p F P
0 g
s
.981 .784 .567 r
.8409 .30527 m .83409 .29473 L .83748 .27851 L p F P
0 g
s
.906 .839 .768 r
.82643 .3404 m .83217 .35104 L .81921 .37048 L p F P
0 g
s
.938 .842 .723 r
.83235 .32933 m .82643 .3404 L .83217 .35104 L p F P
0 g
s
.225 .115 .512 r
.21351 .25762 m .22695 .24182 L .23097 .25444 L p F P
0 g
s
.225 .115 .512 r
.23097 .25444 m .21407 .27412 L .21351 .25762 L p F P
0 g
s
.566 .654 .895 r
.28159 .38924 m .25048 .391 L .26043 .40705 L p F P
0 g
s
.566 .654 .895 r
.26043 .40705 m .2917 .40279 L .28159 .38924 L p F P
0 g
s
.48 .567 .866 r
.24878 .39078 m .25048 .391 L .26043 .40705 L p F P
0 g
s
.968 .766 .576 r
.83748 .27851 m .82972 .26811 L .82628 .28437 L p F P
0 g
s
.968 .766 .576 r
.82628 .28437 m .83409 .29473 L .83748 .27851 L p F P
0 g
s
.142 .523 .917 r
.68168 .39779 m .67224 .39471 L .66154 .38558 L p F P
0 g
s
.654 .953 .947 r
.41958 .37329 m .40956 .37543 L .40169 .37946 L p F P
0 g
s
.797 .819 .869 r
.7993 .39212 m .77441 .41131 L .7668 .40197 L p F P
0 g
s
.687 .781 .923 r
.73242 .41556 m .7668 .40197 L .77441 .41131 L p F P
0 g
s
.878 .836 .801 r
.81921 .37048 m .80786 .38459 L .80048 .37572 L p F P
0 g
s
.878 .836 .801 r
.80048 .37572 m .8133 .35995 L .81921 .37048 L p F P
0 g
s
.906 .839 .768 r
.81921 .37048 m .8133 .35995 L .82643 .3404 L p F P
0 g
s
.372 0 0 r
.56828 .34693 m .53946 .34338 L .56275 .35075 L p F P
0 g
s
.372 0 0 r
.57931 .35288 m .56828 .34693 L p .56275 .35075 L F P
0 g
s
.684 .773 .918 r
.7668 .40197 m .73242 .41556 L .72453 .40568 L p F P
0 g
s
.465 0 0 r
.63048 .37322 m .62435 .36952 L .60838 .36187 L p F P
0 g
s
.967 .721 .511 r
.83116 .25261 m .82243 .24236 L .82096 .25789 L p F P
0 g
s
.967 .721 .511 r
.82096 .25789 m .82972 .26811 L .83116 .25261 L p F P
0 g
s
.658 .951 .951 r
.37675 .3921 m .40169 .37946 L .38184 .39266 L closepath p F P
0 g
s
.718 .914 .962 r
.36657 .38825 m .33397 .40251 L .34418 .40914 L p F P
0 g
s
.718 .914 .962 r
.34418 .40914 m .37675 .3921 L .36657 .38825 L p F P
0 g
s
.198 .137 .558 r
.21452 .27837 m .21313 .27552 L .21407 .27412 L closepath p F P
0 g
s
.178 .131 .564 r
.21313 .27552 m .21452 .27837 L .2162 .29227 L p F P
0 g
s
.944 .813 .685 r
.83541 .32223 m .83235 .32933 L .82507 .31976 L p F P
0 g
s
.944 .813 .685 r
.82507 .31976 m .82854 .31175 L .83541 .32223 L p F P
0 g
s
.963 .803 .635 r
.83541 .32223 m .82854 .31175 L .83409 .29473 L p F P
0 g
s
.412 .458 .798 r
.24071 .37192 m .23016 .36894 L .23508 .35918 L closepath p F P
0 g
s
.427 .493 .825 r
.23016 .36894 m .24071 .37192 L .24947 .38917 L p F P
0 g
s
.797 .819 .869 r
.7668 .40197 m .79369 .38157 L .7993 .39212 L p F P
0 g
s
.824 .831 .853 r
.80048 .37572 m .79369 .38157 L .7993 .39212 L p F P
0 g
s
.824 .831 .853 r
.7993 .39212 m .80786 .38459 L .80048 .37572 L p F P
0 g
s
.527 .004 0 r
.536 .34313 m .53694 .34245 L .53946 .34338 L closepath p F P
0 g
s
.466 .014 .093 r
.53694 .34245 m .536 .34313 L .49535 .34487 L p F P
0 g
s
.416 0 0 r
.49465 .34491 m .49478 .34479 L .49535 .34487 L closepath p F P
0 g
s
.167 .021 .425 r
.22655 .22802 m .23429 .21941 L .23357 .23451 L p F P
0 g
s
.167 .021 .425 r
.23357 .23451 m .22695 .24182 L .22655 .22802 L p F P
0 g
s
.368 0 0 r
.48628 .35084 m .49465 .34491 L .49535 .34487 L p F P
0 g
s
.186 0 0 r
.49465 .34491 m .48628 .35084 L .47173 .35443 L p F P
0 g
s
.368 0 0 r
.49535 .34487 m .52799 .34774 L p .48628 .35084 L F P
0 g
s
.332 0 0 r
.52799 .34774 m .49535 .34487 L .536 .34313 L closepath p F P
0 g
s
.959 .667 .437 r
.82201 .22759 m .81231 .2175 L .8127 .23231 L p F P
0 g
s
.959 .667 .437 r
.8127 .23231 m .82243 .24236 L .82201 .22759 L p F P
0 g
s
.664 .786 .939 r
.32376 .39368 m .2917 .40279 L .30185 .41419 L p F P
0 g
s
.664 .786 .939 r
.30185 .41419 m .33397 .40251 L .32376 .39368 L p F P
0 g
s
.294 .209 .586 r
.21407 .27412 m .23097 .25444 L p .23604 .26905 L F P
0 g
s
.294 .209 .586 r
.21452 .27837 m .21407 .27412 L p .23604 .26905 L F P
0 g
s
.364 .382 .746 r
.23119 .34925 m .22043 .34403 L .22602 .33419 L closepath p F P
0 g
s
.367 .404 .767 r
.22043 .34403 m .23119 .34925 L .23508 .35918 L p F P
0 g
s
.459 .53 .843 r
.25048 .391 m .24878 .39078 L .24947 .38917 L closepath p F P
0 g
s
.367 0 0 r
.53946 .34338 m .56275 .35075 L .53076 .34811 L p F P
0 g
s
.367 0 0 r
.536 .34313 m .53946 .34338 L p .53076 .34811 L F P
0 g
s
.925 .82 .724 r
.82643 .3404 m .83235 .32933 L .82507 .31976 L p F P
0 g
s
.367 0 0 r
.53076 .34811 m .52799 .34774 L .536 .34313 L p F P
0 g
s
.294 .209 .586 r
.23604 .26905 m .22045 .28703 L .21452 .27837 L p F P
0 g
s
.279 .204 .59 r
.22045 .28703 m .2162 .29227 L .21452 .27837 L closepath p F P
0 g
s
.51 .557 .84 r
.27157 .37328 m .28159 .38924 L .25048 .391 L p F P
0 g
s
.51 .557 .84 r
.26038 .37322 m .27157 .37328 L p .25048 .391 L F P
0 g
s
.51 .557 .84 r
.25048 .391 m .24947 .38917 L .26038 .37322 L p F P
0 g
s
.492 .532 .826 r
.26038 .37322 m .24947 .38917 L .24071 .37192 L closepath p F P
0 g
s
.515 .701 .954 r
.7085 .38594 m .67354 .38892 L .68168 .39779 L p F P
0 g
s
.515 .701 .954 r
.68168 .39779 m .71656 .39582 L .7085 .38594 L p F P
0 g
s
.142 .523 .917 r
.66154 .38558 m .67354 .38892 L .68168 .39779 L p F P
0 g
s
.951 .784 .639 r
.83409 .29473 m .82628 .28437 L .82068 .30145 L p F P
0 g
s
.951 .784 .639 r
.82068 .30145 m .82854 .31175 L .83409 .29473 L p F P
0 g
s
.188 .645 .941 r
.63048 .37322 m .64861 .37703 L .63254 .36937 L p F P
0 g
s
.188 .645 .941 r
.63254 .36937 m .62215 .36813 L .63048 .37322 L p F P
0 g
s
.465 0 0 r
.60838 .36187 m .62215 .36813 L .63048 .37322 L p F P
0 g
s
.897 .821 .764 r
.81957 .32996 m .82643 .3404 L .8133 .35995 L p F P
0 g
s
.925 .82 .724 r
.82507 .31976 m .81957 .32996 L .82643 .3404 L p F P
0 g
s
.313 .301 .686 r
.22218 .32075 m .21709 .3168 L .22001 .31214 L closepath p F P
0 g
s
.31 .315 .703 r
.21709 .3168 m .22218 .32075 L .22602 .33419 L p F P
0 g
s
.339 .286 .651 r
.2162 .29227 m .22045 .28703 L .23239 .29706 L p F P
0 g
s
.339 .286 .651 r
.23239 .29706 m .22001 .31214 L .2162 .29227 L p F P
0 g
s
.131 .547 .921 r
.67354 .38892 m .66154 .38558 L .64861 .37703 L p F P
0 g
s
.955 .747 .583 r
.82972 .26811 m .82096 .25789 L .81747 .2742 L p F P
0 g
s
.955 .747 .583 r
.81747 .2742 m .82628 .28437 L .82972 .26811 L p F P
0 g
s
0 .474 .824 r
.62215 .36813 m .60838 .36187 L p .61246 .3629 L F P
0 g
s
.67 .948 .958 r
.3995 .37381 m .36657 .38825 L .37675 .3921 L p F P
0 g
s
.67 .948 .958 r
.40791 .37519 m .3995 .37381 L p .37675 .3921 L F P
0 g
s
.67 .948 .958 r
.37675 .3921 m .40169 .37946 L .40791 .37519 L p F P
0 g
s
.372 0 0 r
.56275 .35075 m .57486 .35309 L .57931 .35288 L p F P
0 g
s
.493 .529 .823 r
.24071 .37192 m .23508 .35918 L p .26673 .3643 L F P
0 g
s
.493 .529 .823 r
.26673 .3643 m .26038 .37322 L .24071 .37192 L p F P
0 g
s
.268 .099 .458 r
.23429 .21941 m .25214 .20356 L .25319 .21723 L p F P
0 g
s
.268 .099 .458 r
.25319 .21723 m .23357 .23451 L .23429 .21941 L p F P
0 g
s
.792 .807 .864 r
.79369 .38157 m .7668 .40197 L .75907 .39218 L p F P
0 g
s
.684 .773 .918 r
.72453 .40568 m .75907 .39218 L .7668 .40197 L p F P
0 g
s
.87 .82 .796 r
.8133 .35995 m .80048 .37572 L .79295 .36599 L p F P
0 g
s
.87 .82 .796 r
.79295 .36599 m .80632 .34961 L .8133 .35995 L p F P
0 g
s
.897 .821 .764 r
.8133 .35995 m .80632 .34961 L .81957 .32996 L p F P
0 g
s
.953 .704 .522 r
.82243 .24236 m .8127 .23231 L .81117 .24788 L p F P
0 g
s
.953 .704 .522 r
.81117 .24788 m .82096 .25789 L .82243 .24236 L p F P
0 g
s
.684 .766 .913 r
.75124 .38197 m .71656 .39582 L .72453 .40568 L p F P
0 g
s
.684 .766 .913 r
.72453 .40568 m .75907 .39218 L .75124 .38197 L p F P
0 g
s
.244 .125 .512 r
.22695 .24182 m .23357 .23451 L .2341 .25101 L p F P
0 g
s
.244 .125 .512 r
.2341 .25101 m .23097 .25444 L .22695 .24182 L p F P
0 g
s
.493 .529 .823 r
.23508 .35918 m .24065 .35151 L p .26673 .3643 L F P
0 g
s
.441 .453 .776 r
.24065 .35151 m .23508 .35918 L .23119 .34925 L closepath p F P
0 g
s
.395 .366 .708 r
.22001 .31214 m .23239 .29706 L p .24515 .31054 L F P
0 g
s
.395 .366 .708 r
.22218 .32075 m .22001 .31214 L p .24515 .31054 L F P
0 g
s
.932 .794 .685 r
.82507 .31976 m .82854 .31175 L .82068 .30145 L p F P
0 g
s
.945 .653 .453 r
.81231 .2175 m .80159 .20763 L .80193 .22246 L p F P
0 g
s
.945 .653 .453 r
.80193 .22246 m .8127 .23231 L .81231 .2175 L p F P
0 g
s
.629 .726 .917 r
.31357 .38248 m .28159 .38924 L .2917 .40279 L p F P
0 g
s
.629 .726 .917 r
.2917 .40279 m .32376 .39368 L .31357 .38248 L p F P
0 g
s
.395 .366 .708 r
.24515 .31054 m .23255 .32574 L .22218 .32075 L p F P
0 g
s
.389 .369 .716 r
.23255 .32574 m .22602 .33419 L .22218 .32075 L closepath p F P
0 g
s
.445 .449 .769 r
.23119 .34925 m .22602 .33419 L p .25342 .335 L F P
0 g
s
.445 .449 .769 r
.25342 .335 m .24065 .35151 L .23119 .34925 L p F P
0 g
s
.792 .807 .864 r
.75907 .39218 m .78674 .3713 L .79369 .38157 L p F P
0 g
s
.815 .813 .848 r
.79295 .36599 m .78674 .3713 L .79369 .38157 L p F P
0 g
s
.815 .813 .848 r
.79369 .38157 m .80048 .37572 L .79295 .36599 L p F P
0 g
s
.445 .449 .769 r
.22602 .33419 m .23255 .32574 L p .25342 .335 L F P
0 g
s
.349 .286 .644 r
.22045 .28703 m .23604 .26905 L .23963 .28881 L p F P
0 g
s
.349 .286 .644 r
.23963 .28881 m .23239 .29706 L .22045 .28703 L p F P
0 g
s
.692 .85 .959 r
.35638 .38175 m .32376 .39368 L .33397 .40251 L p F P
0 g
s
.692 .85 .959 r
.33397 .40251 m .36657 .38825 L .35638 .38175 L p F P
0 g
s
.932 .794 .685 r
.82068 .30145 m .81758 .30861 L .82507 .31976 L p F P
0 g
s
.912 .798 .721 r
.82507 .31976 m .81957 .32996 L .81157 .31976 L p F P
0 g
s
.912 .798 .721 r
.81157 .31976 m .81758 .30861 L .82507 .31976 L p F P
0 g
s
.666 .951 .953 r
.40791 .37519 m .40956 .37543 L .40169 .37946 L closepath p F P
0 g
s
.166 0 0 r
.58786 .3556 m .61246 .3629 L .59282 .35618 L p F P
0 g
s
.938 .765 .641 r
.82628 .28437 m .81747 .2742 L .81182 .29133 L p F P
0 g
s
.938 .765 .641 r
.81182 .29133 m .82068 .30145 L .82628 .28437 L p F P
0 g
s
.531 .709 .953 r
.70036 .37596 m .66533 .38048 L .67354 .38892 L p F P
0 g
s
.531 .709 .953 r
.67354 .38892 m .7085 .38594 L .70036 .37596 L p F P
0 g
s
.131 .547 .921 r
.64861 .37703 m .66533 .38048 L .67354 .38892 L p F P
0 g
s
0 0 0 r
.47173 .35443 m .48538 .35139 L p .44257 .36201 L F P
0 g
s
.068 0 0 r
.48538 .35139 m .47173 .35443 L .48628 .35084 L closepath p F P
0 g
s
.581 .925 .958 r
.40791 .37519 m .40956 .37543 L .44257 .36201 L p F P
0 g
s
.888 .803 .76 r
.81957 .32996 m .81157 .31976 L .79825 .33948 L p F P
0 g
s
.888 .803 .76 r
.79825 .33948 m .80632 .34961 L .81957 .32996 L p F P
0 g
s
.141 .588 .928 r
.66533 .38048 m .64861 .37703 L .63254 .36937 L p F P
0 g
s
.166 0 0 r
.59282 .35618 m .57069 .35302 L .57486 .35309 L p F P
0 g
s
.317 0 0 r
.57069 .35302 m .56275 .35075 L .57486 .35309 L closepath p F P
0 g
s
.33 .19 .535 r
.2341 .25101 m .23357 .23451 L .25319 .21723 L p F P
0 g
s
.941 .73 .588 r
.82096 .25789 m .81117 .24788 L .80763 .26423 L p F P
0 g
s
.941 .73 .588 r
.80763 .26423 m .81747 .2742 L .82096 .25789 L p F P
0 g
s
.578 .921 .963 r
.3995 .37381 m .40791 .37519 L .43861 .36178 L p F P
0 g
s
.581 .925 .958 r
.44257 .36201 m .43861 .36178 L .40791 .37519 L p F P
0 g
s
.17 .641 .932 r
.61497 .364 m .62215 .36813 L .63254 .36937 L closepath p F P
0 g
s
0 .474 .824 r
.61246 .3629 m .61497 .364 L .62215 .36813 L p F P
0 g
s
.474 .49 .794 r
.26171 .35428 m .24065 .35151 L .25342 .335 L closepath p F P
0 g
s
.493 .529 .823 r
.24065 .35151 m .26171 .35428 L .26673 .3643 L p F P
0 g
s
.323 0 0 r
.48538 .35139 m .48628 .35084 L .52705 .34796 L p F P
0 g
s
.368 0 0 r
.52799 .34774 m .52705 .34796 L .48628 .35084 L p F P
0 g
s
.447 0 0 r
.57069 .35302 m .56275 .35075 L .53076 .34811 L p F P
0 g
s
.939 .687 .53 r
.8127 .23231 m .80193 .22246 L .80035 .23807 L p F P
0 g
s
.939 .687 .53 r
.80035 .23807 m .81117 .24788 L .8127 .23231 L p F P
0 g
s
.598 .668 .888 r
.30344 .36871 m .27157 .37328 L .28159 .38924 L p F P
0 g
s
.598 .668 .888 r
.28159 .38924 m .31357 .38248 L .30344 .36871 L p F P
0 g
s
.788 .795 .858 r
.77841 .36133 m .75124 .38197 L .75907 .39218 L p F P
0 g
s
.788 .795 .858 r
.75907 .39218 m .78674 .3713 L .77841 .36133 L p F P
0 g
s
.271 0 0 r
.52705 .34796 m .52799 .34774 L .53076 .34811 L closepath p F P
0 g
s
.863 .804 .791 r
.79295 .36599 m .80632 .34961 L .79825 .33948 L p F P
0 g
s
.514 .558 .838 r
.27157 .37328 m .26038 .37322 L .26673 .3643 L closepath p F P
0 g
s
.931 .638 .466 r
.80159 .20763 m .78983 .19797 L .79012 .21283 L p F P
0 g
s
.931 .638 .466 r
.79012 .21283 m .80193 .22246 L .80159 .20763 L p F P
0 g
s
.434 .42 .744 r
.25209 .3315 m .23255 .32574 L .24515 .31054 L closepath p F P
0 g
s
.445 .449 .769 r
.23255 .32574 m .25209 .3315 L .25342 .335 L p F P
0 g
s
.686 .759 .907 r
.74329 .37131 m .7085 .38594 L .71656 .39582 L p F P
0 g
s
.686 .759 .907 r
.71656 .39582 m .75124 .38197 L .74329 .37131 L p F P
0 g
s
0 0 0 r
.48538 .35139 m .51886 .34939 L p .48387 .35212 L F P
0 g
s
0 0 0 r
.47585 .35335 m .44257 .36201 L p .46392 .35672 L F P
0 g
s
0 0 0 r
.48538 .35139 m .47585 .35335 L p .46392 .35672 L F P
0 g
s
0 0 0 r
.48387 .35212 m .47585 .35335 L .48538 .35139 L p F P
0 g
s
.307 .788 .91 r
.47585 .35335 m .48387 .35212 L .47821 .35269 L p F P
0 g
s
.307 .788 .91 r
.47821 .35269 m .47427 .35309 L .47585 .35335 L p F P
0 g
s
.064 0 0 r
.53382 .34899 m .51886 .34939 L .52705 .34796 L p F P
0 g
s
.116 .663 .82 r
.51886 .34939 m .53382 .34899 L .52876 .34893 L p F P
0 g
s
.323 0 0 r
.52705 .34796 m .51886 .34939 L p .49813 .35034 L F P
0 g
s
.116 .663 .82 r
.52876 .34893 m .51424 .34877 L .51886 .34939 L p F P
0 g
s
.323 0 0 r
.51886 .34939 m .48538 .35139 L p .49813 .35034 L F P
0 g
s
.304 .209 .579 r
.23505 .26045 m .23097 .25444 L .2341 .25101 L closepath p F P
0 g
s
.294 .209 .586 r
.23097 .25444 m .23505 .26045 L .23604 .26905 L p F P
0 g
s
.921 .776 .684 r
.81758 .30861 m .82068 .30145 L .81182 .29133 L p F P
0 g
s
.679 .89 .975 r
.3894 .36901 m .35638 .38175 L .36657 .38825 L p F P
0 g
s
.679 .89 .975 r
.36657 .38825 m .3995 .37381 L .3894 .36901 L p F P
0 g
s
.447 0 0 r
.53076 .34811 m .5619 .35163 L .57069 .35302 L p F P
0 g
s
.064 0 0 r
.53076 .34811 m .54965 .35025 L p .53382 .34899 L F P
0 g
s
.064 0 0 r
.52705 .34796 m .53076 .34811 L p .53382 .34899 L F P
0 g
s
.145 .682 .842 r
.53382 .34899 m .55295 .34834 L p .52264 .3481 L F P
0 g
s
.145 .682 .842 r
.50958 .348 m .53382 .34899 L .52264 .3481 L F
.064 0 0 r
.54965 .35025 m .5619 .35163 L p .53382 .34899 L F P
0 g
s
.81 .798 .841 r
.79295 .36599 m .78674 .3713 L .77841 .36133 L p F P
0 g
s
.863 .804 .791 r
.79825 .33948 m .78527 .35541 L .79295 .36599 L p F P
0 g
s
.81 .798 .841 r
.77841 .36133 m .78527 .35541 L .79295 .36599 L p F P
0 g
s
.664 .783 .937 r
.34619 .37257 m .31357 .38248 L .32376 .39368 L p F P
0 g
s
.664 .783 .937 r
.32376 .39368 m .35638 .38175 L .34619 .37257 L p F P
0 g
s
.921 .776 .684 r
.81182 .29133 m .80987 .29584 L .81758 .30861 L p F P
0 g
s
.901 .778 .716 r
.81758 .30861 m .81157 .31976 L .8024 .30978 L p F P
0 g
s
.901 .778 .716 r
.8024 .30978 m .80987 .29584 L .81758 .30861 L p F P
0 g
s
.381 .267 .597 r
.2341 .25101 m .25763 .23046 L .25957 .24854 L p F P
0 g
s
.381 .267 .597 r
.23505 .26045 m .2341 .25101 L p .25957 .24854 L F P
0 g
s
.33 .19 .535 r
.25746 .2262 m .25763 .23046 L .2341 .25101 L p F P
0 g
s
.33 .19 .535 r
.25319 .21723 m .25746 .2262 L p .2341 .25101 L F P
0 g
s
.2 .656 .944 r
.63254 .36937 m .65703 .37223 L p .61372 .36325 L F P
0 g
s
.2 .656 .944 r
.61372 .36325 m .61497 .364 L .63254 .36937 L p F P
0 g
s
.141 .588 .928 r
.63254 .36937 m .65703 .37223 L .66533 .38048 L p F P
0 g
s
.284 .11 .461 r
.25214 .20356 m .25774 .19879 L .25708 .21394 L p F P
0 g
s
.284 .11 .461 r
.25708 .21394 m .25319 .21723 L .25214 .20356 L p F P
0 g
s
.084 .638 .81 r
.57069 .35302 m .59282 .35618 L .56623 .35166 L p F P
0 g
s
.084 .638 .81 r
.56623 .35166 m .5619 .35163 L .57069 .35302 L p F P
0 g
s
.927 .749 .641 r
.81747 .2742 m .81182 .29133 L .80199 .28147 L p F P
0 g
s
.927 .749 .641 r
.80763 .26423 m .81747 .2742 L p .80199 .28147 L F P
0 g
s
.393 .348 .689 r
.24297 .30261 m .23239 .29706 L .23963 .28881 L closepath p F P
0 g
s
.395 .366 .708 r
.23239 .29706 m .24297 .30261 L .24515 .31054 L p F P
0 g
s
.381 .84 .9 r
.43861 .36178 m .44257 .36201 L .47585 .35335 L p F P
0 g
s
.879 .787 .755 r
.81157 .31976 m .8024 .30978 L .78909 .32956 L p F P
0 g
s
.879 .787 .755 r
.78909 .32956 m .79825 .33948 L .81157 .31976 L p F P
0 g
s
.548 .576 .834 r
.29341 .35219 m .30344 .36871 L .27157 .37328 L p F P
0 g
s
.548 .576 .834 r
.27726 .35358 m .29341 .35219 L p .27157 .37328 L F P
0 g
s
.548 .576 .834 r
.27157 .37328 m .26673 .3643 L .27726 .35358 L p F P
0 g
s
.557 .718 .948 r
.69212 .36572 m .65703 .37223 L .66533 .38048 L p F P
0 g
s
.557 .718 .948 r
.66533 .38048 m .70036 .37596 L .69212 .36572 L p F P
0 g
s
.381 .267 .597 r
.25957 .24854 m .24012 .26535 L .23505 .26045 L p F P
0 g
s
.372 .266 .603 r
.24012 .26535 m .23604 .26905 L .23505 .26045 L closepath p F P
0 g
s
.927 .712 .591 r
.81117 .24788 m .80035 .23807 L .79676 .25447 L p F P
0 g
s
.927 .712 .591 r
.79676 .25447 m .80763 .26423 L .81117 .24788 L p F P
0 g
s
.364 .173 .483 r
.25708 .21394 m .25774 .19879 L .28432 .18058 L p F P
0 g
s
.924 .671 .537 r
.80193 .22246 m .79012 .21283 L .78849 .22848 L p F P
0 g
s
.924 .671 .537 r
.78849 .22848 m .80035 .23807 L .80193 .22246 L p F P
0 g
s
.535 .554 .821 r
.27726 .35358 m .26673 .3643 L .26171 .35428 L closepath p F P
0 g
s
.916 .624 .476 r
.78983 .19797 m .77701 .18855 L .77724 .20344 L p F P
0 g
s
.916 .624 .476 r
.77724 .20344 m .79012 .21283 L .78983 .19797 L p F P
0 g
s
.414 .331 .653 r
.23604 .26905 m .24012 .26535 L .25619 .27394 L p F P
0 g
s
.414 .331 .653 r
.25619 .27394 m .23963 .28881 L .23604 .26905 L p F P
0 g
s
0 .501 .849 r
.61372 .36325 m .61246 .3629 L .61497 .364 L closepath p F P
0 g
s
.786 .784 .851 r
.7687 .35165 m .74329 .37131 L .75124 .38197 L p F P
0 g
s
.786 .784 .851 r
.75124 .38197 m .77841 .36133 L .7687 .35165 L p F P
0 g
s
.856 .79 .785 r
.78527 .35541 m .79825 .33948 L .78909 .32956 L p F P
0 g
s
0 .452 .767 r
.61372 .36325 m .61246 .3629 L .59282 .35618 L p F P
0 g
s
.629 .893 .987 r
.42276 .35706 m .3894 .36901 L .3995 .37381 L p F P
0 g
s
.629 .893 .987 r
.3995 .37381 m .43269 .36128 L .42276 .35706 L p F P
0 g
s
.578 .921 .963 r
.43861 .36178 m .43269 .36128 L .3995 .37381 L p F P
0 g
s
.692 .753 .898 r
.73524 .36014 m .70036 .37596 L .7085 .38594 L p F P
0 g
s
.692 .753 .898 r
.7085 .38594 m .74329 .37131 L .73524 .36014 L p F P
0 g
s
.91 .759 .681 r
.80987 .29584 m .81182 .29133 L .80199 .28147 L closepath p F P
0 g
s
.427 .694 .975 r
.64012 .35509 m .60516 .35785 L .61372 .36325 L p F P
0 g
s
.427 .694 .975 r
.61372 .36325 m .64863 .36387 L .64012 .35509 L p F P
0 g
s
.2 .656 .944 r
.65703 .37223 m .64863 .36387 L .61372 .36325 L p F P
0 g
s
0 .452 .767 r
.59282 .35618 m .60516 .35785 L .61372 .36325 L p F P
0 g
s
.403 .85 .914 r
.43269 .36128 m .43861 .36178 L .47427 .35309 L p F P
0 g
s
.381 .84 .9 r
.47585 .35335 m .47427 .35309 L .43861 .36178 L p F P
0 g
s
.536 .546 .813 r
.26171 .35428 m .25342 .335 L p .28858 .34282 L F P
0 g
s
.536 .546 .813 r
.28858 .34282 m .27726 .35358 L .26171 .35428 L p F P
0 g
s
.807 .783 .831 r
.78527 .35541 m .77841 .36133 L .7687 .35165 L p F P
0 g
s
.89 .761 .713 r
.80987 .29584 m .80199 .28147 L p .79209 .30004 L F P
0 g
s
.89 .761 .713 r
.79209 .30004 m .8024 .30978 L .80987 .29584 L p F P
0 g
s
.856 .79 .785 r
.78909 .32956 m .77746 .34395 L .78527 .35541 L p F P
0 g
s
.807 .783 .831 r
.7687 .35165 m .77746 .34395 L .78527 .35541 L p F P
0 g
s
.637 .718 .907 r
.33603 .36061 m .30344 .36871 L .31357 .38248 L p F P
0 g
s
.637 .718 .907 r
.31357 .38248 m .34619 .37257 L .33603 .36061 L p F P
0 g
s
.42 .328 .646 r
.24012 .26535 m .25957 .24854 L .26295 .26817 L p F P
0 g
s
.42 .328 .646 r
.26295 .26817 m .25619 .27394 L .24012 .26535 L p F P
0 g
s
.458 .399 .704 r
.23963 .28881 m .25619 .27394 L p .26827 .28982 L F P
0 g
s
.458 .399 .704 r
.24297 .30261 m .23963 .28881 L p .26827 .28982 L F P
0 g
s
.34 .194 .532 r
.25746 .2262 m .25319 .21723 L .25708 .21394 L closepath p F P
0 g
s
.67 .819 .955 r
.37928 .36122 m .34619 .37257 L .35638 .38175 L p F P
0 g
s
.67 .819 .955 r
.35638 .38175 m .3894 .36901 L .37928 .36122 L p F P
0 g
s
.913 .73 .641 r
.80194 .28138 m .80763 .26423 L .79676 .25447 L p F P
0 g
s
.927 .749 .641 r
.80199 .28147 m .80194 .28138 L .80763 .26423 L p F P
0 g
s
.536 .546 .813 r
.25342 .335 m .25661 .33189 L p .28858 .34282 L F P
0 g
s
.495 .48 .77 r
.25661 .33189 m .25342 .335 L .25209 .3315 L closepath p F P
0 g
s
.458 .399 .704 r
.26827 .28982 m .25127 .30482 L .24297 .30261 L p F P
0 g
s
.454 .405 .713 r
.25127 .30482 m .24515 .31054 L .24297 .30261 L closepath p F P
0 g
s
.497 .473 .76 r
.25209 .3315 m .24515 .31054 L p .27613 .31405 L F P
0 g
s
.497 .473 .76 r
.27613 .31405 m .25661 .33189 L .25209 .3315 L p F P
0 g
s
.497 .473 .76 r
.24515 .31054 m .25127 .30482 L p .27613 .31405 L F P
0 g
s
.87 .771 .75 r
.8024 .30978 m .79209 .30004 L .77882 .31986 L p F P
0 g
s
.87 .771 .75 r
.77882 .31986 m .78909 .32956 L .8024 .30978 L p F P
0 g
s
.915 .697 .593 r
.80035 .23807 m .79676 .25447 L .78612 .24594 L p F P
0 g
s
.915 .697 .593 r
.78849 .22848 m .80035 .23807 L p .78612 .24594 L F P
0 g
s
.409 .247 .548 r
.25708 .21394 m .28377 .19578 L .2844 .21236 L p F P
0 g
s
.409 .247 .548 r
.25746 .2262 m .25708 .21394 L p .2844 .21236 L F P
0 g
s
.364 .173 .483 r
.28432 .18058 m .28377 .19578 L .25708 .21394 L p F P
0 g
s
0 0 0 r
.51886 .34939 m .51424 .34877 L .48387 .35212 L p F P
0 g
s
0 .538 .772 r
.60516 .35785 m .59282 .35618 L .56623 .35166 L p F P
0 g
s
.911 .657 .541 r
.79012 .21283 m .78849 .22848 L .77741 .22046 L p F P
0 g
s
.911 .657 .541 r
.77724 .20344 m .79012 .21283 L p .77741 .22046 L F P
0 g
s
.517 .506 .783 r
.28354 .33225 m .25661 .33189 L .27613 .31405 L closepath p F P
0 g
s
.536 .546 .813 r
.25661 .33189 m .28354 .33225 L .28858 .34282 L p F P
0 g
s
.589 .725 .938 r
.68376 .35504 m .64863 .36387 L .65703 .37223 L p F P
0 g
s
.589 .725 .938 r
.65703 .37223 m .69212 .36572 L .68376 .35504 L p F P
0 g
s
.901 .611 .484 r
.77701 .18855 m .77003 .18394 L .77239 .20026 L p F P
0 g
s
.901 .611 .484 r
.77239 .20026 m .77724 .20344 L .77701 .18855 L p F P
0 g
s
.194 .696 .91 r
.56013 .35102 m .5619 .35163 L .56623 .35166 L closepath p F P
0 g
s
.064 0 0 r
.5619 .35163 m .56013 .35102 L .53382 .34899 L p F P
0 g
s
.549 .569 .827 r
.29341 .35219 m .27726 .35358 L .28858 .34282 L closepath p F P
0 g
s
.785 .774 .843 r
.75771 .34225 m .73524 .36014 L .74329 .37131 L p F P
0 g
s
.785 .774 .843 r
.74329 .37131 m .7687 .35165 L .75771 .34225 L p F P
0 g
s
.85 .775 .778 r
.77746 .34395 m .78909 .32956 L .77882 .31986 L p F P
0 g
s
.89 .761 .713 r
.80199 .28147 m .80193 .28141 L .79209 .30004 L p F P
0 g
s
.91 .749 .67 r
.80193 .28141 m .80199 .28147 L .80194 .28138 L closepath p F P
0 g
s
.913 .73 .641 r
.79676 .25447 m .7937 .26378 L .80194 .28138 L p F P
0 g
s
.898 .729 .664 r
.80194 .28138 m .80193 .28141 L .79047 .27187 L p F P
0 g
s
.898 .729 .664 r
.79047 .27187 m .7937 .26378 L .80194 .28138 L p F P
0 g
s
.326 .797 .922 r
.46621 .35153 m .47427 .35309 L .48387 .35212 L p F P
0 g
s
.403 .85 .914 r
.47427 .35309 m .46621 .35153 L .43269 .36128 L p F P
0 g
s
.881 .744 .706 r
.80193 .28141 m .79047 .27187 L .78065 .29054 L p F P
0 g
s
.881 .744 .706 r
.78065 .29054 m .79209 .30004 L .80193 .28141 L p F P
0 g
s
.484 .442 .735 r
.27394 .30796 m .25127 .30482 L .26827 .28982 L closepath p F P
0 g
s
.497 .473 .76 r
.25127 .30482 m .27394 .30796 L .27613 .31405 L p F P
0 g
s
.579 .862 .995 r
.45648 .34651 m .42276 .35706 L .43269 .36128 L p F P
0 g
s
.579 .862 .995 r
.43269 .36128 m .46621 .35153 L .45648 .34651 L p F P
0 g
s
.612 .66 .872 r
.32593 .34572 m .29341 .35219 L .30344 .36871 L p F P
0 g
s
.612 .66 .872 r
.30344 .36871 m .33603 .36061 L .32593 .34572 L p F P
0 g
s
.701 .746 .887 r
.72706 .34834 m .69212 .36572 L .70036 .37596 L p F P
0 g
s
.701 .746 .887 r
.70036 .37596 m .73524 .36014 L .72706 .34834 L p F P
0 g
s
.326 .797 .922 r
.48387 .35212 m .50958 .348 L p .46621 .35153 L F P
0 g
s
.306 .789 .905 r
.50958 .348 m .48387 .35212 L .51424 .34877 L closepath p F P
0 g
s
.409 .247 .548 r
.2844 .21236 m .2597 .22902 L .25746 .2262 L p F P
0 g
s
.403 .246 .551 r
.2597 .22902 m .25763 .23046 L .25746 .2262 L closepath p F P
0 g
s
.221 .71 .925 r
.56623 .35166 m .59645 .35169 L p .55295 .34834 L F P
0 g
s
.221 .71 .925 r
.55295 .34834 m .56013 .35102 L .56623 .35166 L p F P
0 g
s
0 .538 .772 r
.56623 .35166 m .59645 .35169 L .60516 .35785 L p F P
0 g
s
.805 .769 .819 r
.77746 .34395 m .7687 .35165 L .75771 .34225 L p F P
0 g
s
.85 .775 .778 r
.77882 .31986 m .76949 .33156 L .77746 .34395 L p F P
0 g
s
.805 .769 .819 r
.75771 .34225 m .76949 .33156 L .77746 .34395 L p F P
0 g
s
.89 .603 .494 r
.77003 .18394 m .76274 .17949 L .7628 .19445 L p F P
0 g
s
.89 .603 .494 r
.7628 .19445 m .77239 .20026 L .77003 .18394 L p F P
0 g
s
.257 .733 .937 r
.55295 .34834 m .53382 .34899 L .56013 .35102 L closepath p F P
0 g
s
.901 .713 .639 r
.7937 .26378 m .79676 .25447 L .78612 .24594 L closepath p F P
0 g
s
.441 .31 .606 r
.25763 .23046 m .2597 .22902 L .27541 .2376 L p F P
0 g
s
.441 .31 .606 r
.27541 .2376 m .25957 .24854 L .25763 .23046 L p F P
0 g
s
.653 .828 .967 r
.41277 .3497 m .37928 .36122 L .3894 .36901 L p F P
0 g
s
.653 .828 .967 r
.3894 .36901 m .42276 .35706 L .41277 .3497 L p F P
0 g
s
.51 .719 .967 r
.63147 .34558 m .59645 .35169 L .60516 .35785 L p F P
0 g
s
.51 .719 .967 r
.60516 .35785 m .64012 .35509 L .63147 .34558 L p F P
0 g
s
.145 .682 .842 r
.50958 .348 m .51424 .34877 L .53382 .34899 L p F P
0 g
s
.653 .75 .921 r
.36917 .35044 m .33603 .36061 L .34619 .37257 L p F P
0 g
s
.653 .75 .921 r
.34619 .37257 m .37928 .36122 L .36917 .35044 L p F P
0 g
s
.445 .308 .6 r
.2597 .22902 m .2844 .21236 L .28626 .23036 L p F P
0 g
s
.445 .308 .6 r
.28626 .23036 m .27541 .2376 L .2597 .22902 L p F P
0 g
s
.431 .226 .499 r
.28377 .19578 m .28432 .18058 L .30986 .16659 L p F P
0 g
s
.9 .68 .594 r
.78518 .24342 m .78849 .22848 L .77741 .22046 L closepath p F P
0 g
s
.915 .697 .593 r
.78612 .24594 m .78518 .24342 L .78849 .22848 L p F P
0 g
s
.863 .756 .744 r
.79209 .30004 m .78065 .29054 L .76747 .31037 L p F P
0 g
s
.863 .756 .744 r
.76747 .31037 m .77882 .31986 L .79209 .30004 L p F P
0 g
s
.876 .589 .499 r
.76274 .17949 m .74698 .17084 L .74697 .18581 L p F P
0 g
s
.876 .589 .499 r
.74697 .18581 m .7628 .19445 L .76274 .17949 L p F P
0 g
s
.896 .641 .545 r
.77599 .21509 m .77724 .20344 L .77239 .20026 L closepath p F P
0 g
s
.911 .657 .541 r
.77741 .22046 m .77599 .21509 L .77724 .20344 L p F P
0 g
s
.885 .712 .662 r
.7937 .26378 m .78612 .24594 L p .77787 .26258 L F P
0 g
s
.885 .712 .662 r
.77787 .26258 m .79047 .27187 L .7937 .26378 L p F P
0 g
s
.451 .379 .684 r
.26488 .27664 m .25619 .27394 L .26295 .26817 L closepath p F P
0 g
s
.458 .399 .704 r
.25619 .27394 m .26488 .27664 L .26827 .28982 L p F P
0 g
s
.574 .582 .823 r
.31594 .32775 m .32593 .34572 L .29341 .35219 L p F P
0 g
s
.574 .582 .823 r
.30698 .32916 m .31594 .32775 L p .29341 .35219 L F P
0 g
s
.574 .582 .823 r
.29341 .35219 m .28858 .34282 L .30698 .32916 L p F P
0 g
s
.473 .365 .651 r
.26295 .26817 m .25957 .24854 L .27541 .2376 L p F P
0 g
s
.622 .727 .922 r
.67529 .34371 m .64012 .35509 L .64863 .36387 L p F P
0 g
s
.622 .727 .922 r
.64863 .36387 m .68376 .35504 L .67529 .34371 L p F P
0 g
s
.884 .635 .558 r
.77239 .20026 m .7628 .19445 L .76068 .21028 L p F P
0 g
s
.884 .635 .558 r
.77599 .21509 m .77239 .20026 L p .76068 .21028 L F P
0 g
s
.871 .728 .701 r
.79047 .27187 m .77787 .26258 L .76809 .28126 L p F P
0 g
s
.871 .728 .701 r
.76809 .28126 m .78065 .29054 L .79047 .27187 L p F P
0 g
s
.845 .762 .771 r
.76949 .33156 m .77882 .31986 L .76747 .31037 L p F P
0 g
s
.785 .764 .834 r
.74554 .33309 m .72706 .34834 L .73524 .36014 L p F P
0 g
s
.785 .764 .834 r
.73524 .36014 m .75771 .34225 L .74554 .33309 L p F P
0 g
s
.564 .561 .809 r
.30698 .32916 m .28858 .34282 L .28354 .33225 L closepath p F P
0 g
s
.804 .754 .807 r
.76949 .33156 m .75771 .34225 L .74554 .33309 L p F P
0 g
s
.845 .762 .771 r
.76747 .31037 m .76139 .31815 L .76949 .33156 L p F P
0 g
s
.804 .754 .807 r
.74554 .33309 m .76139 .31815 L .76949 .33156 L p F P
0 g
s
.885 .712 .662 r
.78612 .24594 m .78477 .24494 L .77787 .26258 L p F P
0 g
s
.9 .693 .613 r
.78477 .24494 m .78612 .24594 L .78518 .24342 L closepath p F P
0 g
s
.711 .738 .873 r
.71877 .33579 m .68376 .35504 L .69212 .36572 L p F P
0 g
s
.711 .738 .873 r
.69212 .36572 m .72706 .34834 L .71877 .33579 L p F P
0 g
s
.887 .676 .613 r
.78518 .24342 m .77741 .22046 L p .77107 .23585 L F P
0 g
s
.887 .676 .613 r
.77107 .23585 m .78477 .24494 L .78518 .24342 L p F P
0 g
s
.884 .635 .558 r
.76068 .21028 m .77545 .21915 L .77599 .21509 L p F P
0 g
s
.898 .651 .556 r
.77545 .21915 m .77741 .22046 L .77599 .21509 L closepath p F P
0 g
s
.875 .696 .656 r
.78477 .24494 m .77107 .23585 L .76416 .25352 L p F P
0 g
s
.875 .696 .656 r
.76416 .25352 m .77787 .26258 L .78477 .24494 L p F P
0 g
s
.512 .78 .993 r
.5346 .33577 m .50016 .34373 L .50958 .348 L p F P
0 g
s
.512 .78 .993 r
.50958 .348 m .54384 .34309 L .5346 .33577 L p F P
0 g
s
.145 .682 .842 r
.55295 .34834 m .54384 .34309 L .50958 .348 L p F P
0 g
s
.326 .797 .922 r
.50958 .348 m .50016 .34373 L .46621 .35153 L p F P
0 g
s
.887 .676 .613 r
.77741 .22046 m .77545 .21915 L .77107 .23585 L p F P
0 g
s
.564 .548 .796 r
.28354 .33225 m .27613 .31405 L p .31424 .32417 L F P
0 g
s
.564 .548 .796 r
.31424 .32417 m .30698 .32916 L .28354 .33225 L p F P
0 g
s
.568 .813 .991 r
.49062 .33677 m .45648 .34651 L .46621 .35153 L p F P
0 g
s
.568 .813 .991 r
.46621 .35153 m .50016 .34373 L .49062 .33677 L p F P
0 g
s
.503 .419 .694 r
.26295 .26817 m .28961 .25001 L .29476 .27158 L p F P
0 g
s
.503 .419 .694 r
.26488 .27664 m .26295 .26817 L p .29476 .27158 L F P
0 g
s
.473 .365 .651 r
.28796 .24088 m .28961 .25001 L .26295 .26817 L p F P
0 g
s
.473 .365 .651 r
.27541 .2376 m .28796 .24088 L p .26295 .26817 L F P
0 g
s
.467 .29 .558 r
.2844 .21236 m .28377 .19578 L .31322 .17977 L p F P
0 g
s
.431 .226 .499 r
.31332 .17618 m .31322 .17977 L .28377 .19578 L p F P
0 g
s
.431 .226 .499 r
.30986 .16659 m .31332 .17618 L p .28377 .19578 L F P
0 g
s
.517 .746 .978 r
.57862 .33566 m .54384 .34309 L .55295 .34834 L p F P
0 g
s
.517 .746 .978 r
.55295 .34834 m .58761 .3444 L .57862 .33566 L p F P
0 g
s
.221 .71 .925 r
.59645 .35169 m .58761 .3444 L .55295 .34834 L p F P
0 g
s
.875 .66 .609 r
.77545 .21915 m .76068 .21028 L .75626 .22702 L p F P
0 g
s
.875 .66 .609 r
.75626 .22702 m .77107 .23585 L .77545 .21915 L p F P
0 g
s
.636 .688 .882 r
.35909 .33659 m .32593 .34572 L .33603 .36061 L p F P
0 g
s
.636 .688 .882 r
.33603 .36061 m .36917 .35044 L .35909 .33659 L p F P
0 g
s
.862 .577 .504 r
.74698 .17084 m .73007 .16246 L .72998 .17746 L p F P
0 g
s
.862 .577 .504 r
.72998 .17746 m .74697 .18581 L .74698 .17084 L p F P
0 g
s
.503 .419 .694 r
.29476 .27158 m .28476 .27828 L .26488 .27664 L p F P
0 g
s
.502 .427 .704 r
.28476 .27828 m .26827 .28982 L .26488 .27664 L closepath p F P
0 g
s
.871 .621 .559 r
.7628 .19445 m .74697 .18581 L .74478 .20167 L p F P
0 g
s
.871 .621 .559 r
.74478 .20167 m .76068 .21028 L .7628 .19445 L p F P
0 g
s
.855 .742 .737 r
.78065 .29054 m .76809 .28126 L .75502 .30111 L p F P
0 g
s
.855 .742 .737 r
.75502 .30111 m .76747 .31037 L .78065 .29054 L p F P
0 g
s
.631 .808 .968 r
.44667 .33848 m .41277 .3497 L .42276 .35706 L p F P
0 g
s
.631 .808 .968 r
.42276 .35706 m .45648 .34651 L .44667 .33848 L p F P
0 g
s
.564 .548 .796 r
.27613 .31405 m .28522 .3075 L p .31424 .32417 L F P
0 g
s
.533 .494 .758 r
.28522 .3075 m .27613 .31405 L .27394 .30796 L closepath p F P
0 g
s
.534 .483 .746 r
.26827 .28982 m .28476 .27828 L p .30245 .29579 L F P
0 g
s
.534 .483 .746 r
.27394 .30796 m .26827 .28982 L p .30245 .29579 L F P
0 g
s
.534 .483 .746 r
.30245 .29579 m .28522 .3075 L .27394 .30796 L p F P
0 g
s
.654 .76 .928 r
.40277 .33926 m .36917 .35044 L .37928 .36122 L p F P
0 g
s
.654 .76 .928 r
.37928 .36122 m .41277 .3497 L .40277 .33926 L p F P
0 g
s
.576 .728 .946 r
.6227 .33503 m .58761 .3444 L .59645 .35169 L p F P
0 g
s
.576 .728 .946 r
.59645 .35169 m .63147 .34558 L .6227 .33503 L p F P
0 g
s
.435 .228 .498 r
.31332 .17618 m .30986 .16659 L .31367 .16454 L closepath p F P
0 g
s
.862 .713 .696 r
.77787 .26258 m .76416 .25352 L .75441 .27223 L p F P
0 g
s
.862 .713 .696 r
.75441 .27223 m .76809 .28126 L .77787 .26258 L p F P
0 g
s
.84 .748 .762 r
.76139 .31815 m .76747 .31037 L .75502 .30111 L p F P
0 g
s
.473 .358 .642 r
.28796 .24088 m .27541 .2376 L .28626 .23036 L closepath p F P
0 g
s
.786 .755 .825 r
.73228 .32416 m .71877 .33579 L .72706 .34834 L p F P
0 g
s
.786 .755 .825 r
.72706 .34834 m .74554 .33309 L .73228 .32416 L p F P
0 g
s
.49 .272 .509 r
.31367 .16454 m .34577 .15081 L .34545 .16607 L p F P
0 g
s
.49 .272 .509 r
.31332 .17618 m .31367 .16454 L p .34545 .16607 L F P
0 g
s
.84 .748 .762 r
.75502 .30111 m .75313 .30358 L .76139 .31815 L p F P
0 g
s
.803 .739 .793 r
.76139 .31815 m .74554 .33309 L .73228 .32416 L p F P
0 g
s
.803 .739 .793 r
.73228 .32416 m .75313 .30358 L .76139 .31815 L p F P
0 g
s
.495 .344 .605 r
.28626 .23036 m .2844 .21236 L .31397 .19642 L p F P
0 g
s
.467 .29 .558 r
.31322 .17977 m .31397 .19642 L .2844 .21236 L p F P
0 g
s
.651 .724 .902 r
.6667 .3315 m .63147 .34558 L .64012 .35509 L p F P
0 g
s
.651 .724 .902 r
.64012 .35509 m .67529 .34371 L .6667 .3315 L p F P
0 g
s
.864 .681 .653 r
.77107 .23585 m .75626 .22702 L .74933 .24471 L p F P
0 g
s
.864 .681 .653 r
.74933 .24471 m .76416 .25352 L .77107 .23585 L p F P
0 g
s
.547 .51 .766 r
.30615 .30566 m .28522 .3075 L .30245 .29579 L closepath p F P
0 g
s
.564 .548 .796 r
.28522 .3075 m .30615 .30566 L .31424 .32417 L p F P
0 g
s
.848 .565 .508 r
.73007 .16246 m .71197 .15438 L .71179 .16941 L p F P
0 g
s
.848 .565 .508 r
.71179 .16941 m .72998 .17746 L .73007 .16246 L p F P
0 g
s
.722 .729 .856 r
.71034 .32232 m .67529 .34371 L .68376 .35504 L p F P
0 g
s
.722 .729 .856 r
.68376 .35504 m .71877 .33579 L .71034 .32232 L p F P
0 g
s
.618 .634 .845 r
.34908 .31955 m .31594 .32775 L .32593 .34572 L p F P
0 g
s
.618 .634 .845 r
.32593 .34572 m .35909 .33659 L .34908 .31955 L p F P
0 g
s
.863 .646 .607 r
.76068 .21028 m .74478 .20167 L .74031 .21844 L p F P
0 g
s
.863 .646 .607 r
.74031 .21844 m .75626 .22702 L .76068 .21028 L p F P
0 g
s
.858 .608 .56 r
.74697 .18581 m .72998 .17746 L .72773 .19335 L p F P
0 g
s
.858 .608 .56 r
.72773 .19335 m .74478 .20167 L .74697 .18581 L p F P
0 g
s
.852 .73 .729 r
.76809 .28126 m .75502 .30111 L .75007 .29783 L p F P
0 g
s
.852 .73 .729 r
.75441 .27223 m .76809 .28126 L p .75007 .29783 L F P
0 g
s
.573 .567 .809 r
.31594 .32775 m .30698 .32916 L .31424 .32417 L closepath p F P
0 g
s
.646 .7 .885 r
.39277 .32568 m .35909 .33659 L .36917 .35044 L p F P
0 g
s
.646 .7 .885 r
.36917 .35044 m .40277 .33926 L .39277 .32568 L p F P
0 g
s
.52 .394 .648 r
.28626 .23036 m .31595 .21452 L .31926 .23415 L p F P
0 g
s
.52 .394 .648 r
.28796 .24088 m .28626 .23036 L p .31926 .23415 L F P
0 g
s
.495 .344 .605 r
.31397 .19642 m .31595 .21452 L .28626 .23036 L p F P
0 g
s
.49 .272 .509 r
.34545 .16607 m .31701 .17815 L .31332 .17618 L p F P
0 g
s
.489 .272 .511 r
.31701 .17815 m .31322 .17977 L .31332 .17618 L closepath p F P
0 g
s
.596 .762 .958 r
.52523 .32621 m .49062 .33677 L .50016 .34373 L p F P
0 g
s
.596 .762 .958 r
.50016 .34373 m .5346 .33577 L .52523 .32621 L p F P
0 g
s
.625 .77 .95 r
.48099 .32709 m .44667 .33848 L .45648 .34651 L p F P
0 g
s
.625 .77 .95 r
.45648 .34651 m .49062 .33677 L .48099 .32709 L p F P
0 g
s
.522 .454 .721 r
.29669 .27826 m .28476 .27828 L .29476 .27158 L closepath p F P
0 g
s
.534 .483 .746 r
.28476 .27828 m .29669 .27826 L .30245 .29579 L p F P
0 g
s
.648 .749 .923 r
.43681 .32744 m .40277 .33926 L .41277 .3497 L p F P
0 g
s
.648 .749 .923 r
.41277 .3497 m .44667 .33848 L .43681 .32744 L p F P
0 g
s
.853 .699 .691 r
.76416 .25352 m .74933 .24471 L .73962 .26344 L p F P
0 g
s
.853 .699 .691 r
.73962 .26344 m .75441 .27223 L .76416 .25352 L p F P
0 g
s
.593 .74 .946 r
.5695 .32521 m .5346 .33577 L .54384 .34309 L p F P
0 g
s
.593 .74 .946 r
.54384 .34309 m .57862 .33566 L .5695 .32521 L p F P
0 g
s
.835 .734 .753 r
.75313 .30358 m .75502 .30111 L .75007 .29783 L closepath p F P
0 g
s
.517 .329 .564 r
.31397 .19642 m .31322 .17977 L .31701 .17815 L p F P
0 g
s
.597 .579 .804 r
.34364 .30848 m .34908 .31955 L .31594 .32775 L p F P
0 g
s
.597 .579 .804 r
.31594 .32775 m .31424 .32417 L .34364 .30848 L p F P
0 g
s
.804 .741 .794 r
.75313 .30358 m .75007 .29783 L p .71798 .31543 L F P
0 g
s
.804 .741 .794 r
.71798 .31543 m .73228 .32416 L .75313 .30358 L p F P
0 g
s
.52 .394 .648 r
.31926 .23415 m .30689 .24067 L .28796 .24088 L p F P
0 g
s
.521 .401 .657 r
.30689 .24067 m .28961 .25001 L .28796 .24088 L closepath p F P
0 g
s
.788 .746 .814 r
.71798 .31543 m .71034 .32232 L .71877 .33579 L p F P
0 g
s
.788 .746 .814 r
.71877 .33579 m .73228 .32416 L .71798 .31543 L p F P
0 g
s
.835 .553 .511 r
.71197 .15438 m .70227 .1505 L .70392 .16628 L p F P
0 g
s
.835 .553 .511 r
.70392 .16628 m .71179 .16941 L .71197 .15438 L p F P
0 g
s
.586 .558 .79 r
.33921 .29874 m .34364 .30848 L .31424 .32417 L p F P
0 g
s
.586 .558 .79 r
.31424 .32417 m .30615 .30566 L .33921 .29874 L p F P
0 g
s
.854 .667 .649 r
.75626 .22702 m .74031 .21844 L .73336 .23616 L p F P
0 g
s
.854 .667 .649 r
.73336 .23616 m .74933 .24471 L .75626 .22702 L p F P
0 g
s
.625 .723 .917 r
.61379 .32316 m .57862 .33566 L .58761 .3444 L p F P
0 g
s
.625 .723 .917 r
.58761 .3444 m .6227 .33503 L .61379 .32316 L p F P
0 g
s
.516 .325 .56 r
.3459 .1757 m .31701 .17815 L .34545 .16607 L closepath p F P
0 g
s
.517 .329 .564 r
.31701 .17815 m .3459 .1757 L p .31397 .19642 L F P
0 g
s
.845 .595 .56 r
.72998 .17746 m .71179 .16941 L .70946 .18532 L p F P
0 g
s
.845 .595 .56 r
.70946 .18532 m .72773 .19335 L .72998 .17746 L p F P
0 g
s
.851 .632 .606 r
.74478 .20167 m .72773 .19335 L .72319 .21015 L p F P
0 g
s
.851 .632 .606 r
.72319 .21015 m .74031 .21844 L .74478 .20167 L p F P
0 g
s
.541 .442 .691 r
.29476 .27158 m .28961 .25001 L .30689 .24067 L p F P
0 g
s
.804 .741 .794 r
.75007 .29783 m .74042 .29242 L .71798 .31543 L p F P
0 g
s
.852 .73 .729 r
.75007 .29783 m .74469 .28729 L .75441 .27223 L p F P
0 g
s
.817 .721 .758 r
.74042 .29242 m .75007 .29783 L .74469 .28729 L closepath p F P
0 g
s
.676 .715 .878 r
.65797 .31815 m .6227 .33503 L .63147 .34558 L p F P
0 g
s
.676 .715 .878 r
.63147 .34558 m .6667 .3315 L .65797 .31815 L p F P
0 g
s
.731 .717 .837 r
.70178 .30774 m .6667 .3315 L .67529 .34371 L p F P
0 g
s
.731 .717 .837 r
.67529 .34371 m .71034 .32232 L .70178 .30774 L p F P
0 g
s
.536 .309 .517 r
.3804 .13931 m .34577 .15081 L .34545 .16607 L p F P
0 g
s
.577 .526 .762 r
.33195 .27997 m .33921 .29874 L .30615 .30566 L p F P
0 g
s
.577 .526 .762 r
.30615 .30566 m .30245 .29579 L .33195 .27997 L p F P
0 g
s
.84 .711 .722 r
.74469 .28729 m .75441 .27223 L .73962 .26344 L p F P
0 g
s
.818 .54 .517 r
.70227 .1505 m .69188 .1469 L .69147 .162 L p F P
0 g
s
.818 .54 .517 r
.69147 .162 m .70392 .16628 L .70227 .1505 L p F P
0 g
s
.557 .475 .719 r
.29669 .27826 m .29476 .27158 L .32445 .25583 L p F P
0 g
s
.541 .442 .691 r
.32043 .23945 m .32445 .25583 L .29476 .27158 L p F P
0 g
s
.541 .442 .691 r
.30689 .24067 m .32043 .23945 L p .29476 .27158 L F P
0 g
s
.563 .497 .74 r
.32958 .27303 m .33195 .27997 L .30245 .29579 L p F P
0 g
s
.563 .497 .74 r
.30245 .29579 m .29669 .27826 L .32958 .27303 L p F P
0 g
s
.557 .475 .719 r
.32445 .25583 m .32958 .27303 L .29669 .27826 L p F P
0 g
s
.635 .647 .845 r
.38281 .30887 m .34908 .31955 L .35909 .33659 L p F P
0 g
s
.635 .647 .845 r
.35909 .33659 m .39277 .32568 L .38281 .30887 L p F P
0 g
s
.539 .376 .609 r
.31595 .21452 m .31397 .19642 L .34627 .18273 L p F P
0 g
s
.517 .329 .564 r
.3459 .1757 m .34627 .18273 L .31397 .19642 L p F P
0 g
s
.848 .688 .683 r
.74933 .24471 m .73962 .26344 L .73171 .25922 L p F P
0 g
s
.848 .688 .683 r
.73336 .23616 m .74933 .24471 L p .73171 .25922 L F P
0 g
s
.84 .711 .722 r
.73962 .26344 m .73606 .2691 L .74469 .28729 L p F P
0 g
s
.813 .704 .744 r
.74469 .28729 m .74042 .29242 L .72416 .28416 L p F P
0 g
s
.813 .704 .744 r
.72416 .28416 m .73606 .2691 L .74469 .28729 L p F P
0 g
s
.807 .53 .519 r
.69188 .1469 m .66979 .14003 L .66928 .15514 L p F P
0 g
s
.807 .53 .519 r
.66928 .15514 m .69147 .162 L .69188 .1469 L p F P
0 g
s
.803 .73 .783 r
.74042 .29242 m .72416 .28416 L .70266 .30692 L p F P
0 g
s
.803 .73 .783 r
.70266 .30692 m .71798 .31543 L .74042 .29242 L p F P
0 g
s
.847 .656 .644 r
.74031 .21844 m .73336 .23616 L .7203 .22987 L p F P
0 g
s
.847 .656 .644 r
.72319 .21015 m .74031 .21844 L p .7203 .22987 L F P
0 g
s
.833 .582 .56 r
.71179 .16941 m .70392 .16628 L .70721 .18444 L p F P
0 g
s
.833 .582 .56 r
.70721 .18444 m .70946 .18532 L .71179 .16941 L p F P
0 g
s
.651 .694 .878 r
.42693 .31331 m .39277 .32568 L .40277 .33926 L p F P
0 g
s
.651 .694 .878 r
.40277 .33926 m .43681 .32744 L .42693 .31331 L p F P
0 g
s
.79 .736 .803 r
.70266 .30692 m .70178 .30774 L .71034 .32232 L p F P
0 g
s
.79 .736 .803 r
.71034 .32232 m .71798 .31543 L .70266 .30692 L p F P
0 g
s
.842 .62 .602 r
.72773 .19335 m .72319 .21015 L .71257 .20552 L p F P
0 g
s
.842 .62 .602 r
.70946 .18532 m .72773 .19335 L p .71257 .20552 L F P
0 g
s
.648 .722 .903 r
.47128 .31459 m .43681 .32744 L .44667 .33848 L p F P
0 g
s
.648 .722 .903 r
.44667 .33848 m .48099 .32709 L .47128 .31459 L p F P
0 g
s
.639 .729 .913 r
.51575 .31422 m .48099 .32709 L .49062 .33677 L p F P
0 g
s
.639 .729 .913 r
.49062 .33677 m .52523 .32621 L .51575 .31422 L p F P
0 g
s
.537 .429 .678 r
.32043 .23945 m .30689 .24067 L .31926 .23415 L closepath p F P
0 g
s
.639 .72 .907 r
.56025 .31277 m .52523 .32621 L .5346 .33577 L p F P
0 g
s
.639 .72 .907 r
.5346 .33577 m .5695 .32521 L .56025 .31277 L p F P
0 g
s
.816 .571 .568 r
.70392 .16628 m .69147 .162 L .6886 .17809 L p F P
0 g
s
.816 .571 .568 r
.6886 .17809 m .70721 .18444 L .70392 .16628 L p F P
0 g
s
.557 .356 .564 r
.3459 .1757 m .3761 .15597 L .34545 .16607 L closepath p F P
0 g
s
.536 .309 .517 r
.38027 .15101 m .3804 .13931 L p .34545 .16607 L F P
0 g
s
.536 .309 .517 r
.34545 .16607 m .3761 .15597 L .38027 .15101 L p F P
0 g
s
.833 .696 .712 r
.73606 .2691 m .73962 .26344 L .73171 .25922 L closepath p F P
0 g
s
.558 .418 .647 r
.31926 .23415 m .31595 .21452 L .34837 .20091 L p F P
0 g
s
.539 .376 .609 r
.34627 .18273 m .34837 .20091 L .31595 .21452 L p F P
0 g
s
.659 .709 .884 r
.60475 .30967 m .5695 .32521 L .57862 .33566 L p F P
0 g
s
.659 .709 .884 r
.57862 .33566 m .61379 .32316 L .60475 .30967 L p F P
0 g
s
.74 .705 .818 r
.68298 .29972 m .65797 .31815 L .6667 .3315 L p F P
0 g
s
.74 .705 .818 r
.70084 .30603 m .68298 .29972 L p .6667 .3315 L F P
0 g
s
.74 .705 .818 r
.6667 .3315 m .70178 .30774 L .70084 .30603 L p F P
0 g
s
.622 .6 .807 r
.37608 .29523 m .38281 .30887 L .34908 .31955 L p F P
0 g
s
.622 .6 .807 r
.34908 .31955 m .34364 .30848 L .37608 .29523 L p F P
0 g
s
.796 .52 .52 r
.66979 .14003 m .66928 .15514 L .64618 .1488 L p F P
0 g
s
.796 .52 .52 r
.64635 .13354 m .66979 .14003 L p .64618 .1488 L F P
0 g
s
.696 .703 .853 r
.64911 .30341 m .61379 .32316 L .6227 .33503 L p F P
0 g
s
.696 .703 .853 r
.6227 .33503 m .65797 .31815 L .64911 .30341 L p F P
0 g
s
.81 .698 .741 r
.73606 .2691 m .73171 .25922 L p .7069 .27611 L F P
0 g
s
.81 .698 .741 r
.7069 .27611 m .72416 .28416 L .73606 .2691 L p F P
0 g
s
.577 .341 .522 r
.38027 .15101 m .38514 .13814 L .3804 .13931 L closepath p F P
0 g
s
.834 .669 .678 r
.72722 .24821 m .73336 .23616 L .7203 .22987 L closepath p F P
0 g
s
.848 .688 .683 r
.73171 .25922 m .72722 .24821 L .73336 .23616 L p F P
0 g
s
.581 .345 .523 r
.38514 .13814 m .41763 .13031 L p .38024 .15462 L F P
0 g
s
.581 .345 .523 r
.38024 .15462 m .38027 .15101 L .38514 .13814 L p F P
0 g
s
.806 .561 .568 r
.69147 .162 m .66928 .15514 L .66632 .17126 L p F P
0 g
s
.806 .561 .568 r
.66632 .17126 m .6886 .17809 L .69147 .162 L p F P
0 g
s
.808 .722 .769 r
.72416 .28416 m .70266 .30692 L .70084 .30603 L p F P
0 g
s
.808 .722 .769 r
.7069 .27611 m .72416 .28416 L p .70084 .30603 L F P
0 g
s
.616 .582 .793 r
.37294 .28837 m .37608 .29523 L .34364 .30848 L p F P
0 g
s
.616 .582 .793 r
.34364 .30848 m .33921 .29874 L .37294 .28837 L p F P
0 g
s
.561 .362 .569 r
.34627 .18273 m .3459 .1757 L .3761 .15597 L p F P
0 g
s
.81 .698 .741 r
.73171 .25922 m .72284 .25519 L .7069 .27611 L p F P
0 g
s
.821 .677 .704 r
.72284 .25519 m .73171 .25922 L .72722 .24821 L closepath p F P
0 g
s
.833 .639 .64 r
.71808 .22324 m .72319 .21015 L .71257 .20552 L closepath p F P
0 g
s
.847 .656 .644 r
.7203 .22987 m .71808 .22324 L .72319 .21015 L p F P
0 g
s
.828 .605 .6 r
.70839 .1893 m .70946 .18532 L .70721 .18444 L closepath p F P
0 g
s
.842 .62 .602 r
.71257 .20552 m .70839 .1893 L .70946 .18532 L p F P
0 g
s
.572 .452 .677 r
.32043 .23945 m .31926 .23415 L .3518 .22065 L p F P
0 g
s
.558 .418 .647 r
.34837 .20091 m .3518 .22065 L .31926 .23415 L p F P
0 g
s
.789 .723 .79 r
.70178 .30774 m .70266 .30692 L .70084 .30603 L closepath p F P
0 g
s
.813 .598 .612 r
.70721 .18444 m .6886 .17809 L .68311 .19523 L p F P
0 g
s
.813 .598 .612 r
.70839 .1893 m .70721 .18444 L p .68311 .19523 L F P
0 g
s
.572 .452 .677 r
.3518 .22065 m .35394 .23021 L .32043 .23945 L p F P
0 g
s
.577 .467 .693 r
.32445 .25583 m .32043 .23945 L .35394 .23021 L p F P
0 g
s
.606 .549 .764 r
.36444 .26657 m .37294 .28837 L .33921 .29874 L p F P
0 g
s
.606 .549 .764 r
.33921 .29874 m .33195 .27997 L .36444 .26657 L p F P
0 g
s
.646 .647 .836 r
.41705 .29596 m .38281 .30887 L .39277 .32568 L p F P
0 g
s
.646 .647 .836 r
.39277 .32568 m .42693 .31331 L .41705 .29596 L p F P
0 g
s
.808 .722 .769 r
.70084 .30603 m .69306 .29144 L .7069 .27611 L p F P
0 g
s
.764 .706 .798 r
.68298 .29972 m .70084 .30603 L .69306 .29144 L closepath p F P
0 g
s
.813 .598 .612 r
.68311 .19523 m .70421 .20238 L .70839 .1893 L p F P
0 g
s
.822 .61 .615 r
.70421 .20238 m .71257 .20552 L .70839 .1893 L closepath p F P
0 g
s
.814 .667 .7 r
.72722 .24821 m .7203 .22987 L p .70413 .24748 L F P
0 g
s
.814 .667 .7 r
.70413 .24748 m .72284 .25519 L .72722 .24821 L p F P
0 g
s
.578 .404 .61 r
.34837 .20091 m .34627 .18273 L .38126 .17138 L p F P
0 g
s
.561 .362 .569 r
.38024 .15462 m .38126 .17138 L .34627 .18273 L p F P
0 g
s
.561 .362 .569 r
.3761 .15597 m .38024 .15462 L p .34627 .18273 L F P
0 g
s
.784 .51 .521 r
.64588 .14512 m .64635 .13354 L .64494 .1332 L closepath p F P
0 g
s
.796 .52 .52 r
.64618 .1488 m .64588 .14512 L .64635 .13354 L p F P
0 g
s
.59 .5 .721 r
.32958 .27303 m .32445 .25583 L .35699 .24237 L p F P
0 g
s
.577 .467 .693 r
.35394 .23021 m .35699 .24237 L .32445 .25583 L p F P
0 g
s
.765 .495 .526 r
.64494 .1332 m .61925 .1283 L .61832 .14351 L p F P
0 g
s
.765 .495 .526 r
.64588 .14512 m .64494 .1332 L p .61832 .14351 L F P
0 g
s
.597 .524 .743 r
.36325 .26311 m .36444 .26657 L .33195 .27997 L p F P
0 g
s
.597 .524 .743 r
.33195 .27997 m .32958 .27303 L .36325 .26311 L p F P
0 g
s
.59 .5 .721 r
.35699 .24237 m .36325 .26311 L .32958 .27303 L p F P
0 g
s
.807 .686 .731 r
.72284 .25519 m .70413 .24748 L .6886 .26829 L p F P
0 g
s
.807 .686 .731 r
.6886 .26829 m .7069 .27611 L .72284 .25519 L p F P
0 g
s
.656 .678 .859 r
.46153 .29913 m .42693 .31331 L .43681 .32744 L p F P
0 g
s
.656 .678 .859 r
.43681 .32744 m .47128 .31459 L .46153 .29913 L p F P
0 g
s
.538 .311 .518 r
.3761 .15597 m .38024 .15462 L .38027 .15101 L closepath p F P
0 g
s
.815 .634 .657 r
.71257 .20552 m .70421 .20238 L .69588 .2206 L p F P
0 g
s
.815 .634 .657 r
.71808 .22324 m .71257 .20552 L p .69588 .2206 L F P
0 g
s
.814 .667 .7 r
.7203 .22987 m .71583 .22803 L .70413 .24748 L p F P
0 g
s
.824 .645 .661 r
.71583 .22803 m .7203 .22987 L .71808 .22324 L closepath p F P
0 g
s
.815 .634 .657 r
.69588 .2206 m .71583 .22803 L .71808 .22324 L p F P
0 g
s
.659 .692 .87 r
.50618 .29962 m .47128 .31459 L .48099 .32709 L p F P
0 g
s
.659 .692 .87 r
.48099 .32709 m .51575 .31422 L .50618 .29962 L p F P
0 g
s
.795 .55 .566 r
.66928 .15514 m .64618 .1488 L .64892 .16652 L p F P
0 g
s
.795 .55 .566 r
.64892 .16652 m .66632 .17126 L .66928 .15514 L p F P
0 g
s
.754 .714 .815 r
.66266 .29263 m .64911 .30341 L .65797 .31815 L p F P
0 g
s
.754 .714 .815 r
.65797 .31815 m .68298 .29972 L .66266 .29263 L p F P
0 g
s
.616 .373 .526 r
.41767 .14566 m .41763 .13031 L .45733 .12383 L p F P
0 g
s
.581 .345 .523 r
.41763 .13031 m .41767 .14566 L .38024 .15462 L p F P
0 g
s
.597 .389 .57 r
.38126 .17138 m .38024 .15462 L .41767 .14566 L p F P
0 g
s
.664 .694 .867 r
.55089 .29811 m .51575 .31422 L .52523 .32621 L p F P
0 g
s
.664 .694 .867 r
.52523 .32621 m .56025 .31277 L .55089 .29811 L p F P
0 g
s
.809 .654 .69 r
.71583 .22803 m .69588 .2206 L .68434 .24001 L p F P
0 g
s
.809 .654 .69 r
.68434 .24001 m .70413 .24748 L .71583 .22803 L p F P
0 g
s
.681 .689 .851 r
.59558 .29432 m .56025 .31277 L .5695 .32521 L p F P
0 g
s
.681 .689 .851 r
.5695 .32521 m .60475 .30967 L .59558 .29432 L p F P
0 g
s
.803 .587 .609 r
.6886 .17809 m .66632 .17126 L .66077 .18842 L p F P
0 g
s
.803 .587 .609 r
.66077 .18842 m .68311 .19523 L .6886 .17809 L p F P
0 g
s
.709 .687 .826 r
.64011 .28704 m .60475 .30967 L .61379 .32316 L p F P
0 g
s
.709 .687 .826 r
.61379 .32316 m .64911 .30341 L .64011 .28704 L p F P
0 g
s
.796 .698 .758 r
.69306 .29144 m .7069 .27611 L .6886 .26829 L p F P
0 g
s
.808 .621 .65 r
.70421 .20238 m .68311 .19523 L .6748 .21345 L p F P
0 g
s
.808 .621 .65 r
.6748 .21345 m .69588 .2206 L .70421 .20238 L p F P
0 g
s
.755 .486 .526 r
.61925 .1283 m .59297 .12397 L .59394 .13952 L p F P
0 g
s
.755 .486 .526 r
.59394 .13952 m .61832 .14351 L .61925 .1283 L p F P
0 g
s
.766 .689 .778 r
.69306 .29144 m .68298 .29972 L .66266 .29263 L p F P
0 g
s
.592 .442 .647 r
.3518 .22065 m .34837 .20091 L .38348 .18963 L p F P
0 g
s
.578 .404 .61 r
.38126 .17138 m .38348 .18963 L .34837 .20091 L p F P
0 g
s
.796 .698 .758 r
.6886 .26829 m .68419 .27342 L .69306 .29144 L p F P
0 g
s
.766 .689 .778 r
.66266 .29263 m .68419 .27342 L .69306 .29144 L p F P
0 g
s
.642 .613 .805 r
.41165 .28471 m .41705 .29596 L .38281 .30887 L p F P
0 g
s
.642 .613 .805 r
.38281 .30887 m .37608 .29523 L .41165 .28471 L p F P
0 g
s
.765 .495 .526 r
.61832 .14351 m .64569 .14869 L .64588 .14512 L p F P
0 g
s
.775 .504 .525 r
.64569 .14869 m .64618 .1488 L .64588 .14512 L closepath p F P
0 g
s
.808 .678 .72 r
.70413 .24748 m .6886 .26829 L .68042 .26516 L p F P
0 g
s
.808 .678 .72 r
.68434 .24001 m .70413 .24748 L p .68042 .26516 L F P
0 g
s
.776 .536 .573 r
.64618 .1488 m .64569 .14869 L .64204 .16504 L p F P
0 g
s
.776 .536 .573 r
.64204 .16504 m .64892 .16652 L .64618 .1488 L p F P
0 g
s
.767 .527 .571 r
.64569 .14869 m .61832 .14351 L .61457 .15987 L p F P
0 g
s
.767 .527 .571 r
.61457 .15987 m .64204 .16504 L .64569 .14869 L p F P
0 g
s
.732 .468 .529 r
.59297 .12397 m .59022 .12368 L .58891 .139 L p F P
0 g
s
.732 .468 .529 r
.58891 .139 m .59394 .13952 L .59297 .12397 L p F P
0 g
s
.648 .398 .527 r
.46714 .12292 m .45733 .12383 L .45755 .1392 L p F P
0 g
s
.616 .373 .526 r
.45733 .12383 m .45755 .1392 L .41767 .14566 L p F P
0 g
s
.723 .46 .528 r
.59022 .12368 m .5562 .12084 L .55474 .13616 L p F P
0 g
s
.723 .46 .528 r
.55474 .13616 m .58891 .139 L .59022 .12368 L p F P
0 g
s
.648 .398 .527 r
.45755 .1392 m .46437 .13857 L .46714 .12292 L p F P
0 g
s
.654 .404 .529 r
.49969 .12031 m .46714 .12292 L .46437 .13857 L p F P
0 g
s
.64 .598 .79 r
.40724 .27483 m .41165 .28471 L .37608 .29523 L p F P
0 g
s
.64 .598 .79 r
.37608 .29523 m .37294 .28837 L .40724 .27483 L p F P
0 g
s
.657 .638 .82 r
.45176 .28054 m .41705 .29596 L .42693 .31331 L p F P
0 g
s
.657 .638 .82 r
.42693 .31331 m .46153 .29913 L .45176 .28054 L p F P
0 g
s
.611 .428 .61 r
.38348 .18963 m .38126 .17138 L .41882 .16246 L p F P
0 g
s
.597 .389 .57 r
.41767 .14566 m .41882 .16246 L .38126 .17138 L p F P
0 g
s
.603 .473 .676 r
.35394 .23021 m .3518 .22065 L .387 .20944 L p F P
0 g
s
.592 .442 .647 r
.38348 .18963 m .387 .20944 L .3518 .22065 L p F P
0 g
s
.807 .647 .683 r
.69588 .2206 m .68434 .24001 L .66792 .23442 L p F P
0 g
s
.807 .647 .683 r
.6748 .21345 m .69588 .2206 L p .66792 .23442 L F P
0 g
s
.793 .575 .606 r
.66632 .17126 m .64892 .16652 L .65317 .18636 L p F P
0 g
s
.793 .575 .606 r
.65317 .18636 m .66077 .18842 L .66632 .17126 L p F P
0 g
s
.803 .612 .644 r
.68311 .19523 m .6748 .21345 L .65931 .20875 L p F P
0 g
s
.803 .612 .644 r
.66077 .18842 m .68311 .19523 L p .65931 .20875 L F P
0 g
s
.631 .565 .761 r
.39995 .2558 m .40724 .27483 L .37294 .28837 L p F P
0 g
s
.631 .565 .761 r
.37294 .28837 m .36444 .26657 L .39995 .2558 L p F P
0 g
s
.63 .414 .571 r
.45755 .1392 m .41767 .14566 L .41882 .16246 L p F P
0 g
s
.759 .705 .801 r
.64176 .28563 m .64011 .28704 L .64911 .30341 L p F P
0 g
s
.759 .705 .801 r
.64911 .30341 m .66266 .29263 L .64176 .28563 L p F P
0 g
s
.715 .453 .528 r
.5562 .12084 m .5448 .12012 L .54547 .13559 L p F P
0 g
s
.715 .453 .528 r
.54547 .13559 m .55474 .13616 L .5562 .12084 L p F P
0 g
s
.603 .473 .676 r
.387 .20944 m .38821 .2148 L .35394 .23021 L p F P
0 g
s
.61 .49 .691 r
.35699 .24237 m .35394 .23021 L .38821 .2148 L p F P
0 g
s
.682 .426 .528 r
.51652 .12007 m .49969 .12031 L .50013 .13574 L p F P
0 g
s
.654 .404 .529 r
.46437 .13857 m .50013 .13574 L .49969 .12031 L p F P
0 g
s
.793 .684 .745 r
.68419 .27342 m .6886 .26829 L .68042 .26516 L closepath p F P
0 g
s
.69 .433 .529 r
.5448 .12012 m .51652 .12007 L .51452 .13553 L p F P
0 g
s
.69 .433 .529 r
.51452 .13553 m .54547 .13559 L .5448 .12012 L p F P
0 g
s
.668 .657 .831 r
.49654 .2822 m .46153 .29913 L .47128 .31459 L p F P
0 g
s
.668 .657 .831 r
.47128 .31459 m .50618 .29962 L .49654 .2822 L p F P
0 g
s
.682 .426 .528 r
.50013 .13574 m .51452 .13553 L .51652 .12007 L p F P
0 g
s
.769 .696 .782 r
.64176 .28563 m .66266 .29263 L .68419 .27342 L p F P
0 g
s
.769 .696 .782 r
.68419 .27342 m .68042 .26516 L p .64176 .28563 L F P
0 g
s
.618 .518 .719 r
.36325 .26311 m .35699 .24237 L .39235 .23136 L p F P
0 g
s
.61 .49 .691 r
.38821 .2148 m .39235 .23136 L .35699 .24237 L p F P
0 g
s
.758 .517 .569 r
.61832 .14351 m .59394 .13952 L .5962 .15689 L p F P
0 g
s
.758 .517 .569 r
.5962 .15689 m .61457 .15987 L .61832 .14351 L p F P
0 g
s
.678 .666 .831 r
.54143 .281 m .50618 .29962 L .51575 .31422 L p F P
0 g
s
.678 .666 .831 r
.51575 .31422 m .55089 .29811 L .54143 .281 L p F P
0 g
s
.719 .672 .803 r
.61519 .28045 m .59558 .29432 L .60475 .30967 L p F P
0 g
s
.719 .672 .803 r
.63899 .28483 m .61519 .28045 L p .60475 .30967 L F P
0 g
s
.719 .672 .803 r
.60475 .30967 m .64011 .28704 L .63899 .28483 L p F P
0 g
s
.626 .542 .74 r
.39756 .24877 m .39995 .2558 L .36444 .26657 L p F P
0 g
s
.626 .542 .74 r
.36444 .26657 m .36325 .26311 L .39756 .24877 L p F P
0 g
s
.618 .518 .719 r
.39235 .23136 m .39756 .24877 L .36325 .26311 L p F P
0 g
s
.694 .668 .82 r
.58629 .27682 m .55089 .29811 L .56025 .31277 L p F P
0 g
s
.694 .668 .82 r
.56025 .31277 m .59558 .29432 L .58629 .27682 L p F P
0 g
s
.775 .564 .613 r
.64892 .16652 m .64204 .16504 L .63537 .18258 L p F P
0 g
s
.775 .564 .613 r
.63537 .18258 m .65317 .18636 L .64892 .16652 L p F P
0 g
s
.808 .678 .72 r
.68042 .26516 m .67513 .25278 L .68434 .24001 L p F P
0 g
s
.769 .696 .782 r
.68042 .26516 m .66737 .26135 L .64176 .28563 L p F P
0 g
s
.776 .665 .74 r
.66737 .26135 m .68042 .26516 L .67513 .25278 L closepath p F P
0 g
s
.795 .657 .711 r
.67513 .25278 m .68434 .24001 L .66792 .23442 L closepath p F P
0 g
s
.767 .554 .61 r
.64204 .16504 m .61457 .15987 L .60784 .17742 L p F P
0 g
s
.767 .554 .61 r
.60784 .17742 m .63537 .18258 L .64204 .16504 L p F P
0 g
s
.622 .463 .646 r
.42116 .18075 m .38348 .18963 L .387 .20944 L p F P
0 g
s
.611 .428 .61 r
.41882 .16246 m .42116 .18075 L .38348 .18963 L p F P
0 g
s
.736 .502 .574 r
.59394 .13952 m .58891 .139 L .58425 .15566 L p F P
0 g
s
.736 .502 .574 r
.58425 .15566 m .5962 .15689 L .59394 .13952 L p F P
0 g
s
.659 .618 .797 r
.45007 .27684 m .45176 .28054 L .41705 .29596 L p F P
0 g
s
.659 .618 .797 r
.41705 .29596 m .41165 .28471 L .45007 .27684 L p F P
0 g
s
.794 .628 .676 r
.66588 .22871 m .6748 .21345 L .65931 .20875 L closepath p F P
0 g
s
.807 .647 .683 r
.66792 .23442 m .66588 .22871 L .6748 .21345 L p F P
0 g
s
.658 .435 .569 r
.45852 .15171 m .46437 .13857 L .45755 .1392 L closepath p F P
0 g
s
.63 .414 .571 r
.45852 .15171 m .45755 .1392 L p .41882 .16246 L F P
0 g
s
.728 .494 .572 r
.58891 .139 m .55474 .13616 L .54996 .15283 L p F P
0 g
s
.728 .494 .572 r
.54996 .15283 m .58425 .15566 L .58891 .139 L p F P
0 g
s
.79 .596 .639 r
.65633 .19826 m .66077 .18842 L .65317 .18636 L closepath p F P
0 g
s
.803 .612 .644 r
.65931 .20875 m .65633 .19826 L .66077 .18842 L p F P
0 g
s
.666 .444 .573 r
.46437 .13857 m .50013 .13574 L p .45889 .15606 L F P
0 g
s
.666 .444 .573 r
.45889 .15606 m .45852 .15171 L .46437 .13857 L p F P
0 g
s
.772 .659 .737 r
.67513 .25278 m .66792 .23442 L p .64402 .25503 L F P
0 g
s
.772 .659 .737 r
.64402 .25503 m .66737 .26135 L .67513 .25278 L p F P
0 g
s
.64 .448 .608 r
.4557 .15654 m .41882 .16246 L .42116 .18075 L p F P
0 g
s
.63 .414 .571 r
.41882 .16246 m .4557 .15654 L .45852 .15171 L p F P
0 g
s
.778 .686 .762 r
.66737 .26135 m .64176 .28563 L .63899 .28483 L p F P
0 g
s
.778 .686 .762 r
.64402 .25503 m .66737 .26135 L p .63899 .28483 L F P
0 g
s
.76 .689 .783 r
.64011 .28704 m .64176 .28563 L .63899 .28483 L closepath p F P
0 g
s
.772 .59 .652 r
.65317 .18636 m .63537 .18258 L .62543 .20138 L p F P
0 g
s
.772 .59 .652 r
.65633 .19826 m .65317 .18636 L p .62543 .20138 L F P
0 g
s
.778 .686 .762 r
.63899 .28483 m .63096 .26819 L .64402 .25503 L p F P
0 g
s
.741 .671 .782 r
.61519 .28045 m .63899 .28483 L .63096 .26819 L closepath p F P
0 g
s
.72 .485 .569 r
.55474 .13616 m .54547 .13559 L .54732 .15267 L p F P
0 g
s
.72 .485 .569 r
.54732 .15267 m .54996 .15283 L .55474 .13616 L p F P
0 g
s
.663 .606 .781 r
.44202 .25778 m .45007 .27684 L .41165 .28471 L p F P
0 g
s
.663 .606 .781 r
.41165 .28471 m .40724 .27483 L .44202 .25778 L p F P
0 g
s
.671 .628 .799 r
.46137 .27545 m .45176 .28054 L .46153 .29913 L p F P
0 g
s
.671 .628 .799 r
.49183 .27238 m .46137 .27545 L p .46153 .29913 L F P
0 g
s
.671 .628 .799 r
.46153 .29913 m .49654 .2822 L .49183 .27238 L p F P
0 g
s
.69 .461 .57 r
.51452 .13553 m .50013 .13574 L .5017 .15269 L p F P
0 g
s
.666 .444 .573 r
.50013 .13574 m .5017 .15269 L .45889 .15606 L p F P
0 g
s
.697 .468 .573 r
.54547 .13559 m .51452 .13553 L .50849 .15259 L p F P
0 g
s
.697 .468 .573 r
.50849 .15259 m .54732 .15267 L .54547 .13559 L p F P
0 g
s
.69 .461 .57 r
.5017 .15269 m .50849 .15259 L .51452 .13553 L p F P
0 g
s
.772 .659 .737 r
.66792 .23442 m .66276 .23306 L .64402 .25503 L p F P
0 g
s
.78 .634 .699 r
.66276 .23306 m .66792 .23442 L .66588 .22871 L closepath p F P
0 g
s
.772 .59 .652 r
.62543 .20138 m .65165 .20693 L .65633 .19826 L p F P
0 g
s
.78 .599 .656 r
.65165 .20693 m .65931 .20875 L .65633 .19826 L closepath p F P
0 g
s
.758 .544 .607 r
.61457 .15987 m .5962 .15689 L .59982 .17613 L p F P
0 g
s
.758 .544 .607 r
.59982 .17613 m .60784 .17742 L .61457 .15987 L p F P
0 g
s
.629 .489 .672 r
.38821 .2148 m .40258 .2058 L .387 .20944 L closepath p F P
0 g
s
.622 .463 .646 r
.42309 .19147 m .42116 .18075 L p .387 .20944 L F P
0 g
s
.622 .463 .646 r
.387 .20944 m .40258 .2058 L .42309 .19147 L p F P
0 g
s
.774 .625 .695 r
.66588 .22871 m .65931 .20875 L p .63786 .22715 L F P
0 g
s
.774 .625 .695 r
.63786 .22715 m .66276 .23306 L .66588 .22871 L p F P
0 g
s
.774 .625 .695 r
.65931 .20875 m .65165 .20693 L .63786 .22715 L p F P
0 g
s
.638 .506 .686 r
.39235 .23136 m .38821 .2148 L .40258 .2058 L p F P
0 g
s
.735 .684 .801 r
.58827 .2753 m .58629 .27682 L .59558 .29432 L p F P
0 g
s
.735 .684 .801 r
.59558 .29432 m .61519 .28045 L .58827 .2753 L p F P
0 g
s
.779 .654 .724 r
.66276 .23306 m .64402 .25503 L .6229 .24975 L p F P
0 g
s
.779 .654 .724 r
.63786 .22715 m .66276 .23306 L p .6229 .24975 L F P
0 g
s
.685 .641 .8 r
.5144 .27169 m .49654 .2822 L .50618 .29962 L p F P
0 g
s
.685 .641 .8 r
.53676 .27142 m .5144 .27169 L p .50618 .29962 L F P
0 g
s
.685 .641 .8 r
.50618 .29962 m .54143 .281 L .53676 .27142 L p F P
0 g
s
.652 .574 .754 r
.43829 .24765 m .44202 .25778 L .40724 .27483 L p F P
0 g
s
.652 .574 .754 r
.40724 .27483 m .39995 .2558 L .43829 .24765 L p F P
0 g
s
.635 .421 .574 r
.4557 .15654 m .45889 .15606 L .45852 .15171 L closepath p F P
0 g
s
.702 .65 .794 r
.55415 .27254 m .54143 .281 L .55089 .29811 L p F P
0 g
s
.702 .65 .794 r
.58533 .27483 m .55415 .27254 L p .55089 .29811 L F P
0 g
s
.702 .65 .794 r
.55089 .29811 m .58629 .27682 L .58533 .27483 L p F P
0 g
s
.77 .582 .645 r
.63537 .18258 m .62543 .20138 L .60511 .19758 L p F P
0 g
s
.77 .582 .645 r
.60784 .17742 m .63537 .18258 L p .60511 .19758 L F P
0 g
s
.776 .619 .685 r
.65165 .20693 m .63786 .22715 L .61242 .22165 L p F P
0 g
s
.776 .619 .685 r
.62543 .20138 m .65165 .20693 L p .61242 .22165 L F P
0 g
s
.642 .531 .713 r
.39756 .24877 m .39235 .23136 L .4304 .22282 L p F P
0 g
s
.638 .506 .686 r
.42493 .20078 m .4304 .22282 L .39235 .23136 L p F P
0 g
s
.638 .506 .686 r
.40258 .2058 m .42493 .20078 L p .39235 .23136 L F P
0 g
s
.738 .531 .613 r
.5962 .15689 m .58425 .15566 L .57608 .1737 L p F P
0 g
s
.738 .531 .613 r
.57608 .1737 m .59982 .17613 L .5962 .15689 L p F P
0 g
s
.64 .448 .608 r
.42116 .18075 m .43725 .17819 L .4557 .15654 L p F P
0 g
s
.645 .456 .613 r
.45889 .15606 m .4557 .15654 L .43725 .17819 L p F P
0 g
s
.652 .555 .732 r
.4324 .22967 m .43829 .24765 L .39995 .2558 L p F P
0 g
s
.652 .555 .732 r
.39995 .2558 m .39756 .24877 L .4324 .22967 L p F P
0 g
s
.741 .673 .784 r
.58827 .2753 m .61519 .28045 L .63096 .26819 L p F P
0 g
s
.642 .531 .713 r
.4304 .22282 m .4324 .22967 L .39756 .24877 L p F P
0 g
s
.627 .472 .653 r
.40258 .2058 m .42493 .20078 L .42309 .19147 L closepath p F P
0 g
s
.672 .475 .611 r
.5017 .15269 m .45889 .15606 L .46154 .17459 L p F P
0 g
s
.645 .456 .613 r
.43725 .17819 m .46154 .17459 L .45889 .15606 L p F P
0 g
s
.648 .478 .64 r
.42309 .19147 m .43725 .17819 L .42116 .18075 L closepath p F P
0 g
s
.764 .661 .748 r
.63096 .26819 m .64402 .25503 L .6229 .24975 L closepath p F P
0 g
s
.734 .524 .609 r
.58425 .15566 m .57608 .1737 L .55056 .17161 L p F P
0 g
s
.734 .524 .609 r
.54996 .15283 m .58425 .15566 L p .55056 .17161 L F P
0 g
s
.741 .673 .784 r
.63096 .26819 m .6229 .24975 L p .58827 .2753 L F P
0 g
s
.676 .619 .784 r
.45176 .28054 m .46137 .27545 L .45007 .27684 L closepath p F P
0 g
s
.657 .492 .649 r
.43725 .17819 m .46154 .17459 L p .42493 .20078 L F P
0 g
s
.657 .492 .649 r
.42493 .20078 m .42309 .19147 L .43725 .17819 L p F P
0 g
s
.723 .512 .604 r
.54804 .15709 m .54996 .15283 L .54732 .15267 L closepath p F P
0 g
s
.734 .524 .609 r
.55056 .17161 m .54804 .15709 L .54996 .15283 L p F P
0 g
s
.695 .49 .605 r
.50315 .16244 m .50849 .15259 L .5017 .15269 L closepath p F P
0 g
s
.672 .475 .611 r
.50315 .16244 m .5017 .15269 L p .46154 .17459 L F P
0 g
s
.705 .502 .611 r
.54732 .15267 m .54804 .15709 L p .50457 .17133 L F P
0 g
s
.705 .502 .611 r
.50849 .15259 m .54732 .15267 L p .50457 .17133 L F P
0 g
s
.705 .502 .611 r
.50457 .17133 m .50315 .16244 L .50849 .15259 L p F P
0 g
s
.757 .566 .638 r
.60254 .18756 m .60784 .17742 L .59982 .17613 L closepath p F P
0 g
s
.77 .582 .645 r
.60511 .19758 m .60254 .18756 L .60784 .17742 L p F P
0 g
s
.765 .631 .712 r
.62167 .24671 m .63786 .22715 L .61242 .22165 L closepath p F P
0 g
s
.779 .654 .724 r
.6229 .24975 m .62167 .24671 L .63786 .22715 L p F P
0 g
s
.684 .608 .765 r
.48687 .26131 m .46137 .27545 L .45007 .27684 L p F P
0 g
s
.684 .608 .765 r
.47944 .24233 m .48687 .26131 L p .45007 .27684 L F P
0 g
s
.684 .608 .765 r
.46475 .24406 m .47944 .24233 L p .45007 .27684 L F P
0 g
s
.684 .608 .765 r
.45007 .27684 m .44202 .25778 L .46475 .24406 L p F P
0 g
s
.763 .599 .676 r
.61222 .22104 m .62543 .20138 L .60511 .19758 L closepath p F P
0 g
s
.776 .619 .685 r
.61242 .22165 m .61222 .22104 L .62543 .20138 L p F P
0 g
s
.739 .559 .65 r
.59982 .17613 m .57608 .1737 L .56409 .19321 L p F P
0 g
s
.739 .559 .65 r
.60254 .18756 m .59982 .17613 L p .56409 .19321 L F P
0 g
s
.705 .502 .611 r
.54804 .15709 m .54022 .17141 L .50457 .17133 L p F P
0 g
s
.709 .508 .615 r
.54022 .17141 m .55056 .17161 L .54804 .15709 L closepath p F P
0 g
s
.736 .665 .78 r
.58629 .27682 m .58827 .2753 L .58533 .27483 L closepath p F P
0 g
s
.659 .519 .681 r
.46552 .19479 m .42493 .20078 L .4304 .22282 L p F P
0 g
s
.657 .492 .649 r
.46154 .17459 m .46552 .19479 L .42493 .20078 L p F P
0 g
s
.681 .62 .781 r
.46137 .27545 m .49183 .27238 L .48687 .26131 L closepath p F P
0 g
s
.753 .66 .759 r
.61915 .24913 m .58827 .2753 L .58533 .27483 L p F P
0 g
s
.741 .673 .784 r
.6229 .24975 m .61915 .24913 L .58827 .2753 L p F P
0 g
s
.695 .64 .79 r
.49654 .2822 m .5144 .27169 L .49183 .27238 L closepath p F P
0 g
s
.753 .66 .759 r
.5894 .24483 m .61915 .24913 L p .58533 .27483 L F P
0 g
s
.753 .66 .759 r
.58533 .27483 m .57688 .2562 L .5894 .24483 L p F P
0 g
s
.72 .646 .774 r
.55415 .27254 m .58533 .27483 L .57688 .2562 L closepath p F P
0 g
s
.747 .639 .74 r
.61915 .24913 m .6229 .24975 L .62167 .24671 L closepath p F P
0 g
s
.715 .655 .788 r
.54143 .281 m .55415 .27254 L .53676 .27142 L closepath p F P
0 g
s
.677 .503 .643 r
.49682 .17183 m .46154 .17459 L .46552 .19479 L p F P
0 g
s
.672 .475 .611 r
.46154 .17459 m .49682 .17183 L .50315 .16244 L p F P
0 g
s
.743 .632 .736 r
.62167 .24671 m .61242 .22165 L p .5894 .24483 L F P
0 g
s
.743 .632 .736 r
.5894 .24483 m .61915 .24913 L .62167 .24671 L p F P
0 g
s
.678 .483 .615 r
.49682 .17183 m .50457 .17133 L .50315 .16244 L closepath p F P
0 g
s
.739 .559 .65 r
.56409 .19321 m .5969 .19657 L .60254 .18756 L p F P
0 g
s
.745 .568 .654 r
.5969 .19657 m .60511 .19758 L .60254 .18756 L closepath p F P
0 g
s
.671 .579 .743 r
.44202 .25778 m .46475 .24406 L .43829 .24765 L closepath p F P
0 g
s
.732 .547 .642 r
.57608 .1737 m .55056 .17161 L .55529 .19249 L p F P
0 g
s
.732 .547 .642 r
.55529 .19249 m .56409 .19321 L .57608 .1737 L p F P
0 g
s
.663 .54 .704 r
.4324 .22967 m .44545 .22061 L .4304 .22282 L closepath p F P
0 g
s
.659 .519 .681 r
.46765 .20354 m .46552 .19479 L p .4304 .22282 L F P
0 g
s
.659 .519 .681 r
.4304 .22282 m .44545 .22061 L .46765 .20354 L p F P
0 g
s
.675 .562 .72 r
.47721 .23599 m .46475 .24406 L .43829 .24765 L p F P
0 g
s
.675 .562 .72 r
.47131 .21718 m .47721 .23599 L p .43829 .24765 L F P
0 g
s
.675 .562 .72 r
.44545 .22061 m .47131 .21718 L p .43829 .24765 L F P
0 g
s
.675 .562 .72 r
.43829 .24765 m .4324 .22967 L .44545 .22061 L p F P
0 g
s
.731 .65 .768 r
.57688 .2562 m .55415 .27254 L .53676 .27142 L p F P
0 g
s
.708 .633 .771 r
.53188 .26076 m .5144 .27169 L .49183 .27238 L p F P
0 g
s
.708 .633 .771 r
.52364 .24034 m .53188 .26076 L p .49183 .27238 L F P
0 g
s
.708 .633 .771 r
.51711 .24053 m .52364 .24034 L p .49183 .27238 L F P
0 g
s
.708 .633 .771 r
.49183 .27238 m .48687 .26131 L .51711 .24053 L p F P
0 g
s
.743 .595 .693 r
.60511 .19758 m .5969 .19657 L .5804 .21775 L p F P
0 g
s
.743 .595 .693 r
.61222 .22104 m .60511 .19758 L p .5804 .21775 L F P
0 g
s
.7 .636 .781 r
.5144 .27169 m .53676 .27142 L .53188 .26076 L closepath p F P
0 g
s
.677 .503 .643 r
.46552 .19479 m .47769 .19385 L .49682 .17183 L p F P
0 g
s
.683 .512 .648 r
.50457 .17133 m .49682 .17183 L .47769 .19385 L p F P
0 g
s
.743 .632 .736 r
.61242 .22165 m .61179 .22156 L .5894 .24483 L p F P
0 g
s
.749 .604 .697 r
.61179 .22156 m .61242 .22165 L .61222 .22104 L closepath p F P
0 g
s
.743 .595 .693 r
.5804 .21775 m .61179 .22156 L .61222 .22104 L p F P
0 g
s
.75 .624 .719 r
.61179 .22156 m .5894 .24483 L .57131 .24251 L p F P
0 g
s
.75 .624 .719 r
.5804 .21775 m .61179 .22156 L p .57131 .24251 L F P
0 g
s
.731 .65 .768 r
.57131 .24251 m .57688 .2562 L p .53676 .27142 L F P
0 g
s
.731 .65 .768 r
.55622 .24167 m .57131 .24251 L p .53676 .27142 L F P
0 g
s
.731 .65 .768 r
.53676 .27142 m .53188 .26076 L .55622 .24167 L p F P
0 g
s
.745 .586 .679 r
.5969 .19657 m .5804 .21775 L .56196 .21584 L p F P
0 g
s
.745 .586 .679 r
.56409 .19321 m .5969 .19657 L p .56196 .21584 L F P
0 g
s
.711 .534 .648 r
.55056 .17161 m .54022 .17141 L .52536 .19192 L p F P
0 g
s
.711 .534 .648 r
.52536 .19192 m .55529 .19249 L .55056 .17161 L p F P
0 g
s
.705 .526 .644 r
.54022 .17141 m .50457 .17133 L .50893 .19188 L p F P
0 g
s
.705 .526 .644 r
.50893 .19188 m .52536 .19192 L .54022 .17141 L p F P
0 g
s
.683 .512 .648 r
.47769 .19385 m .50893 .19188 L .50457 .17133 L p F P
0 g
s
.665 .529 .689 r
.44545 .22061 m .47131 .21718 L .46765 .20354 L closepath p F P
0 g
s
.738 .633 .743 r
.57688 .2562 m .5894 .24483 L .57131 .24251 L closepath p F P
0 g
s
.694 .602 .749 r
.48687 .26131 m .51711 .24053 L .47944 .24233 L closepath p F P
0 g
s
.681 .527 .671 r
.46765 .20354 m .47769 .19385 L .46552 .19479 L closepath p F P
0 g
s
.675 .574 .734 r
.46475 .24406 m .47944 .24233 L .47721 .23599 L closepath p F P
0 g
s
.692 .545 .682 r
.47769 .19385 m .50893 .19188 L p .47131 .21718 L F P
0 g
s
.692 .545 .682 r
.47131 .21718 m .46765 .20354 L .47769 .19385 L p F P
0 g
s
.716 .62 .749 r
.53188 .26076 m .55622 .24167 L .52364 .24034 L closepath p F P
0 g
s
.732 .568 .67 r
.55775 .2016 m .56409 .19321 L .55529 .19249 L closepath p F P
0 g
s
.745 .586 .679 r
.56196 .21584 m .55775 .2016 L .56409 .19321 L p F P
0 g
s
.736 .601 .706 r
.56737 .23189 m .5804 .21775 L .56196 .21584 L closepath p F P
0 g
s
.75 .624 .719 r
.57131 .24251 m .56737 .23189 L .5804 .21775 L p F P
0 g
s
.721 .609 .731 r
.55622 .24167 m .57131 .24251 L .56737 .23189 L closepath p F P
0 g
s
.719 .568 .683 r
.55529 .19249 m .55775 .2016 L p .51503 .2146 L F P
0 g
s
.719 .568 .683 r
.52536 .19192 m .55529 .19249 L p .51503 .2146 L F P
0 g
s
.702 .589 .726 r
.52228 .23664 m .51711 .24053 L .47944 .24233 L p F P
0 g
s
.702 .589 .726 r
.51503 .2146 m .52228 .23664 L p .47944 .24233 L F P
0 g
s
.702 .589 .726 r
.503 .21517 m .51503 .2146 L p .47944 .24233 L F P
0 g
s
.702 .589 .726 r
.47944 .24233 m .47721 .23599 L .503 .21517 L p F P
0 g
s
.689 .564 .709 r
.47721 .23599 m .503 .21517 L .47131 .21718 L closepath p F P
0 g
s
.692 .545 .682 r
.51267 .20629 m .503 .21517 L .47131 .21718 L p F P
0 g
s
.692 .545 .682 r
.50893 .19188 m .51267 .20629 L p .47131 .21718 L F P
0 g
s
.707 .549 .672 r
.51267 .20629 m .52536 .19192 L .50893 .19188 L closepath p F P
0 g
s
.719 .568 .683 r
.51503 .2146 m .51267 .20629 L .52536 .19192 L p F P
0 g
s
.727 .609 .725 r
.56737 .23189 m .55622 .24167 L .52364 .24034 L p F P
0 g
s
.719 .568 .683 r
.55775 .2016 m .54524 .21522 L .51503 .2146 L p F P
0 g
s
.718 .572 .689 r
.54524 .21522 m .56196 .21584 L .55775 .2016 L closepath p F P
0 g
s
.727 .609 .725 r
.56196 .21584 m .56737 .23189 L p .52364 .24034 L F P
0 g
s
.727 .609 .725 r
.54524 .21522 m .56196 .21584 L p .52364 .24034 L F P
0 g
s
.699 .594 .736 r
.51711 .24053 m .52364 .24034 L .52228 .23664 L closepath p F P
0 g
s
.727 .609 .725 r
.52364 .24034 m .52228 .23664 L .54524 .21522 L p F P
0 g
s
.713 .585 .71 r
.52228 .23664 m .54524 .21522 L .51503 .2146 L closepath p F P
0 g
s
.693 .552 .691 r
.503 .21517 m .51503 .2146 L .51267 .20629 L closepath p F P
0 g
s
.25 Mabswid
.69411 0 m
.98374 .43282 L
s
.98374 .43282 m
1 .5519 L
s
1 .5519 m
.70165 .13026 L
s
.70165 .13026 m
.69411 0 L
s
.01972 .25737 m
0 .38187 L
s
0 .38187 m
.70165 .13026 L
s
.70165 .13026 m
.69411 0 L
s
.69411 0 m
.01972 .25737 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00811284 0.97619 0.332627 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00438134 1.00438 -0.159037 1.00438 [
[ 0 0 0 0 ]
[ 1 .62907 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01777 .2799 m
0 .42775 L
s
0 .42775 m
.23984 .62907 L
s
.23984 .62907 m
.2482 .48847 L
s
.2482 .48847 m
.01777 .2799 L
s
.80741 0 m
.98192 .26089 L
s
.98192 .26089 m
1 .40932 L
s
1 .40932 m
.82037 .15537 L
s
.82037 .15537 m
.80741 0 L
s
.01777 .2799 m
0 .42775 L
s
0 .42775 m
.82037 .15537 L
s
.82037 .15537 m
.80741 0 L
s
.80741 0 m
.01777 .2799 L
s
.2482 .48847 m
.98192 .26089 L
s
.98192 .26089 m
1 .40932 L
s
1 .40932 m
.23984 .62907 L
s
.23984 .62907 m
.2482 .48847 L
s
0 0 m
1 0 L
1 .62907 L
0 .62907 L
closepath
clip
newpath
.5 Mabswid
.686 .436 .539 r
.41366 .40592 m .43077 .40571 L .42993 .42177 L p F P
0 g
s
.686 .436 .539 r
.42993 .42177 m .4153 .42195 L .41366 .40592 L p F P
0 g
s
.691 .44 .539 r
.3849 .40587 m .41366 .40592 L .4153 .42195 L p F P
0 g
s
.691 .44 .539 r
.4153 .42195 m .38382 .42189 L .3849 .40587 L p F P
0 g
s
.712 .459 .54 r
.37325 .40526 m .3849 .40587 L .38382 .42189 L p F P
0 g
s
.662 .416 .538 r
.43077 .40571 m .46393 .40349 L .46635 .41935 L p F P
0 g
s
.662 .416 .538 r
.46635 .41935 m .42993 .42177 L .43077 .40571 L p F P
0 g
s
.712 .459 .54 r
.38382 .42189 m .37436 .4214 L .37325 .40526 L p F P
0 g
s
.719 .464 .539 r
.33835 .40283 m .37325 .40526 L .37436 .4214 L p F P
0 g
s
.657 .413 .538 r
.46393 .40349 m .47395 .40271 L .47332 .41881 L p F P
0 g
s
.657 .413 .538 r
.47332 .41881 m .46635 .41935 L .46393 .40349 L p F P
0 g
s
.719 .464 .539 r
.37436 .4214 m .33931 .41898 L .33835 .40283 L p F P
0 g
s
.726 .469 .539 r
.33552 .40259 m .33835 .40283 L .33931 .41898 L p F P
0 g
s
.631 .391 .536 r
.47332 .41881 m .47395 .40271 L .51486 .39713 L p F P
0 g
s
.726 .469 .539 r
.33931 .41898 m .33413 .41853 L .33552 .40259 L p F P
0 g
s
.745 .486 .54 r
.30816 .39887 m .33552 .40259 L .33413 .41853 L p F P
0 g
s
.745 .486 .54 r
.33413 .41853 m .30875 .41511 L .30816 .39887 L p F P
0 g
s
.753 .493 .538 r
.28112 .39462 m .30816 .39887 L .30875 .41511 L p F P
0 g
s
.602 .367 .533 r
.5144 .41325 m .51486 .39713 L .54891 .39029 L p F P
0 g
s
.631 .391 .536 r
.51486 .39713 m .5144 .41325 L .47332 .41881 L p F P
0 g
s
.677 .404 .5 r
.4153 .42195 m .42993 .42177 L .4279 .43678 L p F P
0 g
s
.677 .404 .5 r
.4279 .43678 m .42098 .43686 L .4153 .42195 L p F P
0 g
s
.683 .406 .497 r
.38382 .42189 m .4153 .42195 L .42098 .43686 L p F P
0 g
s
.683 .406 .497 r
.42098 .43686 m .38145 .4368 L .38382 .42189 L p F P
0 g
s
.706 .428 .501 r
.37436 .4214 m .38382 .42189 L .38145 .4368 L p F P
0 g
s
.652 .38 .495 r
.4279 .43678 m .42993 .42177 L .46635 .41935 L p F P
0 g
s
.706 .428 .501 r
.38145 .4368 m .37875 .43666 L .37436 .4214 L p F P
0 g
s
.713 .432 .498 r
.33931 .41898 m .37436 .4214 L .37875 .43666 L p F P
0 g
s
.753 .493 .538 r
.27983 .4068 m .28112 .39462 L p .30875 .41511 L F P
0 g
s
.769 .508 .539 r
.27983 .4068 m .27961 .39432 L .28112 .39462 L closepath p F P
0 g
s
.778 .515 .538 r
.27961 .39432 m .27983 .4068 L .27942 .41052 L p F P
0 g
s
.778 .515 .538 r
.25436 .38863 m .27961 .39432 L p .27942 .41052 L F P
0 g
s
.647 .379 .498 r
.47204 .43005 m .46635 .41935 L .47332 .41881 L closepath p F P
0 g
s
.652 .38 .495 r
.46635 .41935 m .47204 .43005 L p .4279 .43678 L F P
0 g
s
.713 .432 .498 r
.37875 .43666 m .34356 .43424 L .33931 .41898 L p F P
0 g
s
.72 .436 .495 r
.33413 .41853 m .33931 .41898 L .34356 .43424 L p F P
0 g
s
.618 .353 .493 r
.47332 .41881 m .5144 .41325 L .51287 .42837 L p F P
0 g
s
.618 .353 .493 r
.47204 .43005 m .47332 .41881 L p .51287 .42837 L F P
0 g
s
.72 .436 .495 r
.34356 .43424 m .33124 .43318 L .33413 .41853 L p F P
0 g
s
.741 .457 .499 r
.30875 .41511 m .33413 .41853 L .33124 .43318 L p F P
0 g
s
.6 .366 .534 r
.55373 .40163 m .54891 .39029 L .55393 .38926 L closepath p F P
0 g
s
.602 .367 .533 r
.54891 .39029 m .55373 .40163 L p .5144 .41325 L F P
0 g
s
.741 .457 .499 r
.33124 .43318 m .3121 .43062 L .30875 .41511 L p F P
0 g
s
.749 .462 .495 r
.27994 .41062 m .30875 .41511 L .3121 .43062 L p F P
0 g
s
.753 .493 .538 r
.30875 .41511 m .27994 .41062 L .27983 .4068 L p F P
0 g
s
.568 .341 .53 r
.55393 .38926 m .59124 .37904 L .59114 .39524 L p F P
0 g
s
.568 .341 .53 r
.55373 .40163 m .55393 .38926 L p .59114 .39524 L F P
0 g
s
.778 .515 .538 r
.27942 .41052 m .25454 .40497 L .25436 .38863 L p F P
0 g
s
.787 .523 .537 r
.23015 .38254 m .25436 .38863 L .25454 .40497 L p F P
0 g
s
.586 .325 .488 r
.51287 .42837 m .5144 .41325 L .55366 .40543 L p F P
0 g
s
.602 .367 .533 r
.55373 .40163 m .55366 .40543 L .5144 .41325 L p F P
0 g
s
.761 .499 .537 r
.27994 .41062 m .27942 .41052 L .27983 .4068 L closepath p F P
0 g
s
.666 .365 .453 r
.42618 .44413 m .42098 .43686 L .4279 .43678 L closepath p F P
0 g
s
.671 .363 .444 r
.42098 .43686 m .42618 .44413 L .42451 .45061 L p F P
0 g
s
.671 .363 .444 r
.38145 .4368 m .42098 .43686 L p .42451 .45061 L F P
0 g
s
.671 .363 .444 r
.38058 .44006 m .38145 .4368 L p .42451 .45061 L F P
0 g
s
.697 .392 .455 r
.38058 .44006 m .37875 .43666 L .38145 .4368 L closepath p F P
0 g
s
.636 .333 .441 r
.4279 .43678 m .47157 .4339 L .4685 .44781 L p F P
0 g
s
.636 .333 .441 r
.42618 .44413 m .4279 .43678 L p .4685 .44781 L F P
0 g
s
.652 .38 .495 r
.47204 .43005 m .47157 .4339 L .4279 .43678 L p F P
0 g
s
.704 .392 .446 r
.37875 .43666 m .38058 .44006 L .37754 .45037 L p F P
0 g
s
.704 .392 .446 r
.34356 .43424 m .37875 .43666 L p .37754 .45037 L F P
0 g
s
.618 .353 .493 r
.51287 .42837 m .47484 .43349 L .47204 .43005 L p F P
0 g
s
.622 .353 .489 r
.47484 .43349 m .47157 .4339 L .47204 .43005 L closepath p F P
0 g
s
.749 .462 .495 r
.3121 .43062 m .28318 .42613 L .27994 .41062 L p F P
0 g
s
.757 .467 .492 r
.27942 .41052 m .27994 .41062 L .28318 .42613 L p F P
0 g
s
.757 .467 .492 r
.28318 .42613 m .27587 .42484 L .27942 .41052 L p F P
0 g
s
.776 .486 .496 r
.25454 .40497 m .27942 .41052 L .27587 .42484 L p F P
0 g
s
.704 .392 .446 r
.37754 .45037 m .35131 .44857 L .34356 .43424 L p F P
0 g
s
.71 .394 .441 r
.33124 .43318 m .34356 .43424 L .35131 .44857 L p F P
0 g
s
.671 .363 .444 r
.42451 .45061 m .38812 .45054 L .38058 .44006 L p F P
0 g
s
.676 .364 .437 r
.38812 .45054 m .37754 .45037 L .38058 .44006 L closepath p F P
0 g
s
.603 .303 .433 r
.47157 .4339 m .47484 .43349 L .49352 .44469 L p F P
0 g
s
.603 .303 .433 r
.49352 .44469 m .4685 .44781 L .47157 .4339 L p F P
0 g
s
.601 .306 .441 r
.47484 .43349 m .51287 .42837 L .51019 .44247 L p F P
0 g
s
.601 .306 .441 r
.51019 .44247 m .49352 .44469 L .47484 .43349 L p F P
0 g
s
.787 .523 .537 r
.25454 .40497 m .23023 .39889 L .23015 .38254 L p F P
0 g
s
.796 .53 .536 r
.21858 .37931 m .23015 .38254 L .23023 .39889 L p F P
0 g
s
.71 .394 .441 r
.35131 .44857 m .32675 .44648 L .33124 .43318 L p F P
0 g
s
.734 .419 .449 r
.3121 .43062 m .33124 .43318 L .32675 .44648 L p F P
0 g
s
.568 .341 .53 r
.59114 .39524 m .55808 .40424 L .55373 .40163 L p F P
0 g
s
.569 .34 .529 r
.55808 .40424 m .55366 .40543 L .55373 .40163 L closepath p F P
0 g
s
.549 .293 .481 r
.55231 .42057 m .55366 .40543 L .55808 .40424 L p F P
0 g
s
.586 .325 .488 r
.55366 .40543 m .55231 .42057 L .51287 .42837 L p F P
0 g
s
.636 .333 .441 r
.4685 .44781 m .43241 .45018 L .42618 .44413 L p F P
0 g
s
.64 .333 .434 r
.43241 .45018 m .42451 .45061 L .42618 .44413 L closepath p F P
0 g
s
.734 .419 .449 r
.32675 .44648 m .31838 .44536 L .3121 .43062 L p F P
0 g
s
.742 .422 .441 r
.28318 .42613 m .3121 .43062 L .31838 .44536 L p F P
0 g
s
.776 .486 .496 r
.27587 .42484 m .25711 .42068 L .25454 .40497 L p F P
0 g
s
.785 .493 .492 r
.23023 .39889 m .25454 .40497 L .25711 .42068 L p F P
0 g
s
.796 .53 .536 r
.23023 .39889 m .21636 .39506 L .21858 .37931 L p F P
0 g
s
.809 .543 .536 r
.2076 .37581 m .21858 .37931 L .21636 .39506 L p F P
0 g
s
.533 .312 .526 r
.62703 .36654 m .59124 .37904 L .59114 .39524 L p F P
0 g
s
.55 .297 .485 r
.59052 .4041 m .55808 .40424 L .59114 .39524 L closepath p F P
0 g
s
.549 .293 .481 r
.55808 .40424 m .59052 .4041 L p .55231 .42057 L F P
0 g
s
.564 .273 .431 r
.51019 .44247 m .51287 .42837 L .55231 .42057 L p F P
0 g
s
.809 .543 .536 r
.21636 .39506 m .20744 .39224 L .2076 .37581 L p F P
0 g
s
.82 .552 .534 r
.18669 .36846 m .2076 .37581 L .20744 .39224 L p F P
0 g
s
.742 .422 .441 r
.31838 .44536 m .28938 .44087 L .28318 .42613 L p F P
0 g
s
.75 .426 .435 r
.27587 .42484 m .28318 .42613 L .28938 .44087 L p F P
0 g
s
.618 .272 .362 r
.42451 .45061 m .43241 .45018 L .45156 .46134 L p F P
0 g
s
.618 .272 .362 r
.45156 .46134 m .41953 .46304 L .42451 .45061 L p F P
0 g
s
.652 .308 .377 r
.38812 .45054 m .42451 .45061 L .41953 .46304 L p F P
0 g
s
.652 .308 .377 r
.41953 .46304 m .40268 .46301 L .38812 .45054 L p F P
0 g
s
.657 .306 .366 r
.37754 .45037 m .38812 .45054 L .40268 .46301 L p F P
0 g
s
.657 .306 .366 r
.40268 .46301 m .37197 .46252 L .37754 .45037 L p F P
0 g
s
.688 .34 .38 r
.35131 .44857 m .37754 .45037 L .37197 .46252 L p F P
0 g
s
.75 .426 .435 r
.28938 .44087 m .27041 .43755 L .27587 .42484 L p F P
0 g
s
.77 .45 .444 r
.25711 .42068 m .27587 .42484 L .27041 .43755 L p F P
0 g
s
.615 .277 .374 r
.43241 .45018 m .4685 .44781 L .46407 .46052 L p F P
0 g
s
.615 .277 .374 r
.46407 .46052 m .45156 .46134 L .43241 .45018 L p F P
0 g
s
.785 .493 .492 r
.25711 .42068 m .2327 .41462 L .23023 .39889 L p F P
0 g
s
.795 .499 .489 r
.21636 .39506 m .23023 .39889 L .2327 .41462 L p F P
0 g
s
.688 .34 .38 r
.37197 .46252 m .36289 .4619 L .35131 .44857 L p F P
0 g
s
.692 .332 .36 r
.32675 .44648 m .35131 .44857 L .36289 .4619 L p F P
0 g
s
.577 .238 .359 r
.46407 .46052 m .4685 .44781 L .49352 .44469 L p F P
0 g
s
.692 .332 .36 r
.32342 .45292 m .32675 .44648 L p .36289 .4619 L F P
0 g
s
.722 .374 .388 r
.32342 .45292 m .31838 .44536 L .32675 .44648 L closepath p F P
0 g
s
.51 .264 .478 r
.59052 .4041 m .62281 .38427 L .59114 .39524 L closepath p F P
0 g
s
.533 .312 .526 r
.62708 .37897 m .62703 .36654 L p .59114 .39524 L F P
0 g
s
.533 .312 .526 r
.59114 .39524 m .62281 .38427 L .62708 .37897 L p F P
0 g
s
.77 .45 .444 r
.27041 .43755 m .2622 .43574 L .25711 .42068 L p F P
0 g
s
.78 .454 .436 r
.2327 .41462 m .25711 .42068 L .2622 .43574 L p F P
0 g
s
.795 .499 .489 r
.2327 .41462 m .21193 .40892 L .21636 .39506 L p F P
0 g
s
.809 .515 .493 r
.20744 .39224 m .21636 .39506 L .21193 .40892 L p F P
0 g
s
.522 .235 .42 r
.54983 .43466 m .55231 .42057 L .59002 .41046 L p F P
0 g
s
.549 .293 .481 r
.59052 .4041 m .59002 .41046 L .55231 .42057 L p F P
0 g
s
.564 .273 .431 r
.55231 .42057 m .54983 .43466 L .51019 .44247 L p F P
0 g
s
.729 .37 .37 r
.31838 .44536 m .32342 .45292 L .32027 .4581 L p F P
0 g
s
.729 .37 .37 r
.28938 .44087 m .31838 .44536 L p .32027 .4581 L F P
0 g
s
.82 .552 .534 r
.20744 .39224 m .18645 .3849 L .18669 .36846 L p F P
0 g
s
.83 .562 .532 r
.16667 .3607 m .18669 .36846 L .18645 .3849 L p F P
0 g
s
.578 .249 .376 r
.5081 .44951 m .49352 .44469 L .51019 .44247 L closepath p F P
0 g
s
.577 .238 .359 r
.49352 .44469 m .5081 .44951 L p .46407 .46052 L F P
0 g
s
.809 .515 .493 r
.21193 .40892 m .20939 .40812 L .20744 .39224 L p F P
0 g
s
.82 .524 .488 r
.18645 .3849 m .20744 .39224 L .20939 .40812 L p F P
0 g
s
.494 .282 .52 r
.62708 .37897 m .63142 .36464 L .62703 .36654 L closepath p F P
0 g
s
.532 .201 .352 r
.51019 .44247 m .54983 .43466 L .54612 .44763 L p F P
0 g
s
.532 .201 .352 r
.5081 .44951 m .51019 .44247 L p .54612 .44763 L F P
0 g
s
.489 .277 .518 r
.63142 .36464 m .66125 .35153 L p .62708 .38278 L F P
0 g
s
.489 .277 .518 r
.62708 .38278 m .62708 .37897 L .63142 .36464 L p F P
0 g
s
.729 .37 .37 r
.32027 .4581 m .29882 .45477 L .28938 .44087 L p F P
0 g
s
.734 .364 .35 r
.27041 .43755 m .28938 .44087 L .29882 .45477 L p F P
0 g
s
.506 .257 .472 r
.59002 .41046 m .59052 .4041 L .62281 .38427 L p F P
0 g
s
.78 .454 .436 r
.2622 .43574 m .23772 .42968 L .2327 .41462 L p F P
0 g
s
.789 .458 .427 r
.21193 .40892 m .2327 .41462 L .23772 .42968 L p F P
0 g
s
.692 .332 .36 r
.36289 .4619 m .32885 .45898 L .32342 .45292 L p F P
0 g
s
.698 .331 .349 r
.32885 .45898 m .32027 .4581 L .32342 .45292 L closepath p F P
0 g
s
.83 .562 .532 r
.18645 .3849 m .16634 .37718 L .16667 .3607 L p F P
0 g
s
.841 .571 .53 r
.14748 .35257 m .16667 .3607 L .16634 .37718 L p F P
0 g
s
.734 .364 .35 r
.26637 .44353 m .27041 .43755 L p .29882 .45477 L F P
0 g
s
.761 .405 .38 r
.26637 .44353 m .2622 .43574 L .27041 .43755 L closepath p F P
0 g
s
.57 .166 .236 r
.41953 .46304 m .45156 .46134 L p .45777 .47157 L F P
0 g
s
.57 .166 .236 r
.41531 .47018 m .41953 .46304 L p .45777 .47157 L F P
0 g
s
.625 .238 .291 r
.41531 .47018 m .40268 .46301 L .41953 .46304 L closepath p F P
0 g
s
.617 .208 .244 r
.40268 .46301 m .41531 .47018 L .41264 .47382 L p F P
0 g
s
.617 .208 .244 r
.37197 .46252 m .40268 .46301 L p .41264 .47382 L F P
0 g
s
.617 .208 .244 r
.36908 .46682 m .37197 .46252 L p .41264 .47382 L F P
0 g
s
.666 .278 .3 r
.36908 .46682 m .36289 .4619 L .37197 .46252 L closepath p F P
0 g
s
.531 .31 .524 r
.62281 .38427 m .62708 .38278 L .62708 .37897 L closepath p F P
0 g
s
.664 .256 .261 r
.36289 .4619 m .36908 .46682 L .36415 .47274 L p F P
0 g
s
.664 .256 .261 r
.32885 .45898 m .36289 .4619 L p .36415 .47274 L F P
0 g
s
.82 .524 .488 r
.20939 .40812 m .1883 .4008 L .18645 .3849 L p F P
0 g
s
.831 .532 .483 r
.16634 .37718 m .18645 .3849 L .1883 .4008 L p F P
0 g
s
.474 .193 .406 r
.58774 .42456 m .59002 .41046 L .62608 .39797 L p F P
0 g
s
.506 .257 .472 r
.62708 .38278 m .62608 .39797 L .59002 .41046 L p F P
0 g
s
.506 .257 .472 r
.62281 .38427 m .62708 .38278 L p .59002 .41046 L F P
0 g
s
.522 .235 .42 r
.59002 .41046 m .58774 .42456 L .54983 .43466 L p F P
0 g
s
.77 .403 .362 r
.2622 .43574 m .26637 .44353 L .26253 .44824 L p F P
0 g
s
.77 .403 .362 r
.23772 .42968 m .2622 .43574 L p .26253 .44824 L F P
0 g
s
.585 .207 .292 r
.46175 .46513 m .45156 .46134 L .46407 .46052 L closepath p F P
0 g
s
.57 .166 .236 r
.45156 .46134 m .46175 .46513 L .45777 .47157 L p F P
0 g
s
.532 .201 .352 r
.54612 .44763 m .52961 .45086 L .5081 .44951 L p F P
0 g
s
.528 .187 .334 r
.52961 .45086 m .50612 .4553 L .5081 .44951 L closepath p F P
0 g
s
.577 .238 .359 r
.5081 .44951 m .50612 .4553 L .46407 .46052 L p F P
0 g
s
.528 .137 .244 r
.46407 .46052 m .50612 .4553 L .50035 .46658 L p F P
0 g
s
.528 .137 .244 r
.46175 .46513 m .46407 .46052 L p .50035 .46658 L F P
0 g
s
.485 .159 .339 r
.54612 .44763 m .54983 .43466 L .58774 .42456 L p F P
0 g
s
.789 .458 .427 r
.21035 .41175 m .21193 .40892 L p .23772 .42968 L F P
0 g
s
.806 .482 .441 r
.21035 .41175 m .20939 .40812 L .21193 .40892 L closepath p F P
0 g
s
.459 .22 .463 r
.62608 .39797 m .62708 .38278 L .66143 .3678 L p F P
0 g
s
.489 .277 .518 r
.66125 .35153 m .66143 .3678 L .62708 .38278 L p F P
0 g
s
.817 .487 .431 r
.20939 .40812 m .21035 .41175 L .20467 .42038 L p F P
0 g
s
.817 .487 .431 r
.1883 .4008 m .20939 .40812 L p .20467 .42038 L F P
0 g
s
.664 .256 .261 r
.36415 .47274 m .34493 .47106 L .32885 .45898 L p F P
0 g
s
.653 .219 .204 r
.32027 .4581 m .32885 .45898 L .34493 .47106 L p F P
0 g
s
.653 .219 .204 r
.31156 .46742 m .32027 .4581 L p .34493 .47106 L F P
0 g
s
.705 .299 .275 r
.31156 .46742 m .29882 .45477 L .32027 .4581 L closepath p F P
0 g
s
.789 .458 .427 r
.23772 .42968 m .21416 .42324 L .21035 .41175 L p F P
0 g
s
.799 .463 .419 r
.21416 .42324 m .20467 .42038 L .21035 .41175 L closepath p F P
0 g
s
.617 .208 .244 r
.41264 .47382 m .38145 .47329 L .36908 .46682 L p F P
0 g
s
.618 .198 .223 r
.38145 .47329 m .36415 .47274 L .36908 .46682 L closepath p F P
0 g
s
.841 .571 .53 r
.16634 .37718 m .14707 .36906 L .14748 .35257 L p F P
0 g
s
.853 .581 .527 r
.13838 .34833 m .14748 .35257 L .14707 .36906 L p F P
0 g
s
.77 .403 .362 r
.26253 .44824 m .24552 .44403 L .23772 .42968 L p F P
0 g
s
.778 .403 .346 r
.21416 .42324 m .23772 .42968 L .24552 .44403 L p F P
0 g
s
.734 .364 .35 r
.29882 .45477 m .27081 .44986 L .26637 .44353 L p F P
0 g
s
.741 .364 .338 r
.27081 .44986 m .26253 .44824 L .26637 .44353 L closepath p F P
0 g
s
.478 .089 .224 r
.50035 .46658 m .50612 .4553 L .52961 .45086 L p F P
0 g
s
.528 .137 .244 r
.50035 .46658 m .48462 .46854 L .46175 .46513 L p F P
0 g
s
.522 .116 .212 r
.48462 .46854 m .45777 .47157 L .46175 .46513 L closepath p F P
0 g
s
.708 .286 .241 r
.29882 .45477 m .31156 .46742 L .31132 .46762 L p F P
0 g
s
.708 .286 .241 r
.27081 .44986 m .29882 .45477 L p .31132 .46762 L F P
0 g
s
.443 .242 .511 r
.66143 .3678 m .66125 .35153 L .694 .33394 L p F P
0 g
s
.831 .532 .483 r
.1883 .4008 m .16811 .3931 L .16634 .37718 L p F P
0 g
s
.842 .54 .478 r
.14707 .36906 m .16634 .37718 L .16811 .3931 L p F P
0 g
s
.57 .166 .236 r
.45777 .47157 m .42504 .47333 L .41531 .47018 L p F P
0 g
s
.568 .15 .209 r
.42504 .47333 m .41264 .47382 L .41531 .47018 L closepath p F P
0 g
s
.817 .487 .431 r
.20467 .42038 m .19238 .41614 L .1883 .4008 L p F P
0 g
s
.828 .493 .421 r
.16811 .3931 m .1883 .4008 L .19238 .41614 L p F P
0 g
s
.853 .581 .527 r
.14707 .36906 m .13507 .36353 L .13838 .34833 L p F P
0 g
s
.861 .591 .528 r
.12949 .34391 m .13838 .34833 L .13507 .36353 L p F P
0 g
s
.494 .125 .268 r
.54488 .4506 m .52961 .45086 L .54612 .44763 L closepath p F P
0 g
s
.478 .089 .224 r
.52961 .45086 m .54488 .4506 L p .50035 .46658 L F P
0 g
s
.429 .108 .319 r
.58423 .43752 m .58774 .42456 L .62399 .41209 L p F P
0 g
s
.474 .193 .406 r
.62608 .39797 m .62399 .41209 L .58774 .42456 L p F P
0 g
s
.485 .159 .339 r
.58774 .42456 m .58423 .43752 L .54612 .44763 L p F P
0 g
s
.708 .286 .241 r
.31132 .46762 m .28407 .46272 L .27081 .44986 L p F P
0 g
s
.701 .255 .19 r
.26253 .44824 m .27081 .44986 L .28407 .46272 L p F P
0 g
s
.42 .148 .392 r
.62399 .41209 m .62608 .39797 L .6606 .38303 L p F P
0 g
s
.459 .22 .463 r
.66143 .3678 m .6606 .38303 L .62608 .39797 L p F P
0 g
s
.778 .403 .346 r
.24552 .44403 m .22197 .43756 L .21416 .42324 L p F P
0 g
s
.784 .396 .321 r
.20467 .42038 m .21416 .42324 L .22197 .43756 L p F P
0 g
s
.701 .255 .19 r
.25402 .45473 m .26253 .44824 L p .28407 .46272 L F P
0 g
s
.748 .336 .267 r
.25402 .45473 m .24552 .44403 L .26253 .44824 L closepath p F P
0 g
s
.446 0 0 r
.41264 .47382 m .42504 .47333 L p .44895 .48036 L F P
0 g
s
.446 0 0 r
.40448 .48122 m .41264 .47382 L p .44895 .48036 L F P
0 g
s
.561 .094 .104 r
.40448 .48122 m .38145 .47329 L .41264 .47382 L closepath p F P
0 g
s
.437 .071 .243 r
.54488 .4506 m .54612 .44763 L .58423 .43752 L p F P
0 g
s
.513 .055 .104 r
.45137 .47855 m .42504 .47333 L .45777 .47157 L closepath p F P
0 g
s
.446 0 0 r
.42504 .47333 m .45137 .47855 L .44895 .48036 L p F P
0 g
s
.512 0 0 r
.38145 .47329 m .40448 .48122 L .40296 .48213 L p F P
0 g
s
.512 0 0 r
.36415 .47274 m .38145 .47329 L p .40296 .48213 L F P
0 g
s
.861 .591 .528 r
.13507 .36353 m .12888 .36048 L .12949 .34391 L p F P
0 g
s
.873 .602 .525 r
.11264 .33475 m .12949 .34391 L .12888 .36048 L p F P
0 g
s
.512 0 0 r
.3578 .47777 m .36415 .47274 L p .40296 .48213 L F P
0 g
s
.616 .153 .13 r
.3578 .47777 m .34493 .47106 L .36415 .47274 L closepath p F P
0 g
s
.842 .54 .478 r
.16811 .3931 m .14877 .385 L .14707 .36906 L p F P
0 g
s
.854 .549 .471 r
.13507 .36353 m .14707 .36906 L .14877 .385 L p F P
0 g
s
.784 .396 .321 r
.19713 .42703 m .20467 .42038 L p .22197 .43756 L F P
0 g
s
.808 .439 .359 r
.19713 .42703 m .19238 .41614 L .20467 .42038 L closepath p F P
0 g
s
.404 0 0 r
.45777 .47157 m .48462 .46854 L p .4921 .47558 L F P
0 g
s
.404 0 0 r
.45137 .47855 m .45777 .47157 L p .4921 .47558 L F P
0 g
s
.407 .178 .451 r
.69433 .35026 m .66143 .3678 L .6606 .38303 L p F P
0 g
s
.443 .242 .511 r
.694 .33394 m .69433 .35026 L .66143 .3678 L p F P
0 g
s
.592 .093 .039 r
.34493 .47106 m .3578 .47777 L .35315 .4802 L p F P
0 g
s
.592 .093 .039 r
.31198 .4677 m .34493 .47106 L p .35315 .4802 L F P
0 g
s
.653 .219 .204 r
.34493 .47106 m .31198 .4677 L .31156 .46742 L p F P
0 g
s
.828 .493 .421 r
.19238 .41614 m .17213 .40844 L .16811 .3931 L p F P
0 g
s
.84 .5 .411 r
.14877 .385 m .16811 .3931 L .17213 .40844 L p F P
0 g
s
.437 .071 .243 r
.58423 .43752 m .58209 .44281 L .54488 .4506 L p F P
0 g
s
.407 .015 .18 r
.54064 .45894 m .54488 .4506 L .58209 .44281 L p F P
0 g
s
.478 .089 .224 r
.54488 .4506 m .54064 .45894 L .50035 .46658 L p F P
0 g
s
.753 .324 .231 r
.24552 .44403 m .25402 .45473 L .25137 .45616 L p F P
0 g
s
.753 .324 .231 r
.22197 .43756 m .24552 .44403 L p .25137 .45616 L F P
0 g
s
.475 .038 .128 r
.49825 .46943 m .48462 .46854 L .50035 .46658 L closepath p F P
0 g
s
.404 0 0 r
.48462 .46854 m .49825 .46943 L .4921 .47558 L p F P
0 g
s
.656 .209 .18 r
.31198 .4677 m .31132 .46762 L .31156 .46742 L closepath p F P
0 g
s
.819 .441 .34 r
.19238 .41614 m .19713 .42703 L .19406 .42903 L p F P
0 g
s
.819 .441 .34 r
.17213 .40844 m .19238 .41614 L p .19406 .42903 L F P
0 g
s
.592 .093 .039 r
.35315 .4802 m .33404 .47811 L .31198 .4677 L p F P
0 g
s
.531 0 0 r
.31132 .46762 m .31198 .4677 L .33404 .47811 L p F P
0 g
s
.531 0 0 r
.29987 .47328 m .31132 .46762 L p .33404 .47811 L F P
0 g
s
.654 .169 .088 r
.29987 .47328 m .28407 .46272 L .31132 .46762 L closepath p F P
0 g
s
.854 .549 .471 r
.12983 .37244 m .13507 .36353 L p .14877 .385 L F P
0 g
s
.863 .563 .478 r
.12983 .37244 m .12888 .36048 L .13507 .36353 L closepath p F P
0 g
s
.408 0 .088 r
.49825 .46943 m .50035 .46658 L .54064 .45894 L p F P
0 g
s
.873 .602 .525 r
.12888 .36048 m .11196 .35135 L .11264 .33475 L p F P
0 g
s
.885 .613 .521 r
.09659 .32519 m .11264 .33475 L .11196 .35135 L p F P
0 g
s
.875 .573 .472 r
.12888 .36048 m .12983 .37244 L .12773 .37526 L p F P
0 g
s
.875 .573 .472 r
.11196 .35135 m .12888 .36048 L p .12773 .37526 L F P
0 g
s
.363 .049 .292 r
.6587 .39717 m .62399 .41209 L .6207 .42505 L p F P
0 g
s
.42 .148 .392 r
.6606 .38303 m .6587 .39717 L .62399 .41209 L p F P
0 g
s
.429 .108 .319 r
.62399 .41209 m .6207 .42505 L .58423 .43752 L p F P
0 g
s
.392 .204 .502 r
.70127 .32924 m .694 .33394 L .69433 .35026 L p F P
0 g
s
.753 .324 .231 r
.25137 .45616 m .23297 .45106 L .22197 .43756 L p F P
0 g
s
.757 .313 .198 r
.19924 .43075 m .22197 .43756 L .23297 .45106 L p F P
0 g
s
.784 .396 .321 r
.22197 .43756 m .19924 .43075 L .19713 .42703 L p F P
0 g
s
.37 .006 .21 r
.58209 .44281 m .58423 .43752 L .6207 .42505 L p F P
0 g
s
.84 .5 .411 r
.17213 .40844 m .15273 .40036 L .14877 .385 L p F P
0 g
s
.851 .506 .4 r
.13025 .37653 m .14877 .385 L .15273 .40036 L p F P
0 g
s
.854 .549 .471 r
.14877 .385 m .13025 .37653 L .12983 .37244 L p F P
0 g
s
.636 .121 .004 r
.28407 .46272 m .29987 .47328 L .29833 .47368 L p F P
0 g
s
.636 .121 .004 r
.25702 .4574 m .28407 .46272 L p .29833 .47368 L F P
0 g
s
.701 .255 .19 r
.28407 .46272 m .25702 .4574 L .25402 .45473 L p F P
0 g
s
.408 0 .088 r
.54064 .45894 m .53536 .46593 L .49825 .46943 L p F P
0 g
s
.342 0 0 r
.4921 .47558 m .49825 .46943 L .53536 .46593 L p F P
0 g
s
.512 0 0 r
.40296 .48213 m .36895 .48095 L .3578 .47777 L p F P
0 g
s
.502 0 0 r
.36895 .48095 m .35315 .4802 L .3578 .47777 L closepath p F P
0 g
s
.36 .099 .376 r
.69103 .36692 m .6606 .38303 L .6587 .39717 L p F P
0 g
s
.407 .178 .451 r
.69383 .36162 m .69433 .35026 L p .6606 .38303 L F P
0 g
s
.407 .178 .451 r
.6606 .38303 m .69103 .36692 L .69383 .36162 L p F P
0 g
s
.819 .441 .34 r
.19406 .42903 m .17858 .42316 L .17213 .40844 L p F P
0 g
s
.829 .443 .322 r
.15273 .40036 m .17213 .40844 L .17858 .42316 L p F P
0 g
s
.704 .248 .166 r
.25702 .4574 m .25137 .45616 L .25402 .45473 L closepath p F P
0 g
s
.793 .398 .305 r
.19924 .43075 m .19406 .42903 L .19713 .42703 L closepath p F P
0 g
s
.392 .204 .502 r
.69433 .35026 m .69938 .34702 L .70127 .32924 L p F P
0 g
s
.38 .194 .498 r
.72505 .31329 m .70127 .32924 L .69938 .34702 L p F P
0 g
s
.313 0 .012 r
.53536 .46593 m .54064 .45894 L .57907 .44889 L p F P
0 g
s
.407 .015 .18 r
.58209 .44281 m .57907 .44889 L .54064 .45894 L p F P
0 g
s
.404 0 0 r
.4921 .47558 m .4643 .47881 L .45137 .47855 L p F P
0 g
s
.371 0 0 r
.4643 .47881 m .44895 .48036 L .45137 .47855 L closepath p F P
0 g
s
.446 0 0 r
.44895 .48036 m .40974 .48196 L .40448 .48122 L p F P
0 g
s
.425 0 0 r
.40974 .48196 m .40296 .48213 L .40448 .48122 L closepath p F P
0 g
s
.636 .121 .004 r
.29833 .47368 m .2753 .46887 L .25702 .4574 L p F P
0 g
s
.589 .04 0 r
.25137 .45616 m .25702 .4574 L .2753 .46887 L p F P
0 g
s
.867 .559 .464 r
.13025 .37653 m .12773 .37526 L .12983 .37244 L closepath p F P
0 g
s
.37 .006 .21 r
.6207 .42505 m .61957 .42802 L .58209 .44281 L p F P
0 g
s
.323 0 .134 r
.57907 .44889 m .58209 .44281 L .61957 .42802 L p F P
0 g
s
.757 .313 .198 r
.23297 .45106 m .2104 .44417 L .19924 .43075 L p F P
0 g
s
.751 .286 .143 r
.19406 .42903 m .19924 .43075 L .2104 .44417 L p F P
0 g
s
.589 .04 0 r
.24187 .45887 m .25137 .45616 L p .2753 .46887 L F P
0 g
s
.706 .219 .088 r
.24187 .45887 m .23297 .45106 L .25137 .45616 L closepath p F P
0 g
s
.096 0 0 r
.40296 .48213 m .40974 .48196 L p .43546 .48482 L F P
0 g
s
.096 0 0 r
.39362 .48539 m .40296 .48213 L p .43546 .48482 L F P
0 g
s
.39 0 0 r
.39362 .48539 m .36895 .48095 L .40296 .48213 L closepath p F P
0 g
s
.328 0 0 r
.44088 .48409 m .40974 .48196 L .44895 .48036 L closepath p F P
0 g
s
.096 0 0 r
.40974 .48196 m .44088 .48409 L .43546 .48482 L p F P
0 g
s
.875 .573 .472 r
.12773 .37526 m .11317 .36745 L .11196 .35135 L p F P
0 g
s
.888 .583 .465 r
.09583 .34182 m .11196 .35135 L .11317 .36745 L p F P
0 g
s
.885 .613 .521 r
.11196 .35135 m .09583 .34182 L .09659 .32519 L p F P
0 g
s
.897 .625 .517 r
.08131 .31523 m .09659 .32519 L .09583 .34182 L p F P
0 g
s
.751 .286 .143 r
.18439 .43223 m .19406 .42903 L p .2104 .44417 L F P
0 g
s
.797 .372 .237 r
.18439 .43223 m .17858 .42316 L .19406 .42903 L closepath p F P
0 g
s
.197 0 0 r
.36895 .48095 m .39362 .48539 L .38804 .4857 L p F P
0 g
s
.197 0 0 r
.35315 .4802 m .36895 .48095 L p .38804 .4857 L F P
0 g
s
.851 .506 .4 r
.15273 .40036 m .13417 .39189 L .13025 .37653 L p F P
0 g
s
.862 .51 .383 r
.12773 .37526 m .13025 .37653 L .13417 .39189 L p F P
0 g
s
.349 .134 .439 r
.69383 .36162 m .69938 .34702 L .69433 .35026 L closepath p F P
0 g
s
.078 0 0 r
.44895 .48036 m .4643 .47881 L p .47973 .4807 L F P
0 g
s
.078 0 0 r
.44088 .48409 m .44895 .48036 L p .47973 .4807 L F P
0 g
s
.197 0 0 r
.34654 .48214 m .35315 .4802 L p .38804 .4857 L F P
0 g
s
.484 0 0 r
.34654 .48214 m .33404 .47811 L .35315 .4802 L closepath p F P
0 g
s
.862 .51 .383 r
.11606 .38163 m .12773 .37526 L p .13417 .39189 L F P
0 g
s
.874 .534 .405 r
.11606 .38163 m .11317 .36745 L .12773 .37526 L closepath p F P
0 g
s
.303 0 0 r
.48818 .47814 m .4643 .47881 L .4921 .47558 L closepath p F P
0 g
s
.078 0 0 r
.4643 .47881 m .48818 .47814 L .47973 .4807 L p F P
0 g
s
.829 .443 .322 r
.17858 .42316 m .15917 .41507 L .15273 .40036 L p F P
0 g
s
.839 .445 .301 r
.13417 .39189 m .15273 .40036 L .15917 .41507 L p F P
0 g
s
.359 0 0 r
.33404 .47811 m .34654 .48214 L .33641 .48256 L p F P
0 g
s
.359 0 0 r
.30235 .47424 m .33404 .47811 L p .33641 .48256 L F P
0 g
s
.531 0 0 r
.33404 .47811 m .30235 .47424 L .29987 .47328 L p F P
0 g
s
.327 .112 .427 r
.69938 .34702 m .7255 .32964 L p .69363 .3655 L F P
0 g
s
.327 .112 .427 r
.69363 .3655 m .69383 .36162 L .69938 .34702 L p F P
0 g
s
.38 .194 .498 r
.69938 .34702 m .7255 .32964 L .72505 .31329 L p F P
0 g
s
.299 0 .184 r
.61957 .42802 m .63507 .41892 L .6207 .42505 L closepath p F P
0 g
s
.363 .049 .292 r
.65706 .40422 m .6587 .39717 L p .6207 .42505 L F P
0 g
s
.363 .049 .292 r
.6207 .42505 m .63507 .41892 L .65706 .40422 L p F P
0 g
s
.69 .175 .004 r
.23297 .45106 m .24187 .45887 L .23482 .4595 L p F P
0 g
s
.69 .175 .004 r
.2104 .44417 m .23297 .45106 L p .23482 .4595 L F P
0 g
s
.52 0 0 r
.30235 .47424 m .29833 .47368 L .29987 .47328 L closepath p F P
0 g
s
.207 0 0 r
.48818 .47814 m .4921 .47558 L .53294 .46816 L p F P
0 g
s
.342 0 0 r
.53536 .46593 m .53294 .46816 L .4921 .47558 L p F P
0 g
s
.3 .001 .279 r
.65706 .40422 m .67196 .3902 L .6587 .39717 L closepath p F P
0 g
s
.36 .099 .376 r
.6587 .39717 m .67196 .3902 L .69103 .36692 L p F P
0 g
s
.802 .361 .197 r
.17858 .42316 m .18439 .43223 L .17802 .43311 L p F P
0 g
s
.802 .361 .197 r
.15917 .41507 m .17858 .42316 L p .17802 .43311 L F P
0 g
s
.213 0 0 r
.57291 .45711 m .57907 .44889 L .6157 .43633 L p F P
0 g
s
.323 0 .134 r
.61957 .42802 m .6157 .43633 L .57907 .44889 L p F P
0 g
s
.313 0 .012 r
.57907 .44889 m .57291 .45711 L .53536 .46593 L p F P
0 g
s
.359 0 0 r
.33641 .48256 m .33324 .48213 L .30235 .47424 L p F P
0 g
s
.15 0 0 r
.29833 .47368 m .30235 .47424 L .33324 .48213 L p F P
0 g
s
.235 0 .1 r
.6157 .43633 m .61957 .42802 L .63507 .41892 L p F P
0 g
s
.15 0 0 r
.28821 .47454 m .29833 .47368 L p .33324 .48213 L F P
0 g
s
.515 0 0 r
.28821 .47454 m .2753 .46887 L .29833 .47368 L closepath p F P
0 g
s
.207 0 0 r
.53294 .46816 m .53536 .46593 L .57291 .45711 L p F P
0 g
s
.394 .164 .443 r
.69103 .36692 m .69363 .3655 L .69383 .36162 L closepath p F P
0 g
s
.888 .583 .465 r
.11317 .36745 m .09697 .35795 L .09583 .34182 L p F P
0 g
s
.9 .594 .457 r
.08049 .33189 m .09583 .34182 L .09697 .35795 L p F P
0 g
s
.897 .625 .517 r
.09583 .34182 m .08049 .33189 L .08131 .31523 L p F P
0 g
s
.91 .637 .512 r
.06681 .30486 m .08131 .31523 L .08049 .33189 L p F P
0 g
s
.886 .542 .393 r
.11317 .36745 m .11606 .38163 L .11462 .38204 L p F P
0 g
s
.886 .542 .393 r
.09697 .35795 m .11317 .36745 L p .11462 .38204 L F P
0 g
s
.342 .077 .36 r
.69363 .3655 m .69103 .36692 L .67196 .3902 L p F P
0 g
s
.235 0 .1 r
.63507 .41892 m .65548 .41 L p .6157 .43633 L F P
0 g
s
.34 .017 .263 r
.63507 .41892 m .65548 .41 L .65706 .40422 L closepath p F P
0 g
s
.839 .445 .301 r
.15917 .41507 m .14059 .4066 L .13417 .39189 L p F P
0 g
s
.849 .446 .279 r
.11642 .38303 m .13417 .39189 L .14059 .4066 L p F P
0 g
s
.862 .51 .383 r
.13417 .39189 m .11642 .38303 L .11606 .38163 L p F P
0 g
s
.32 .149 .486 r
.73609 .30441 m .72505 .31329 L .7255 .32964 L p F P
0 g
s
.69 .175 .004 r
.23482 .4595 m .22543 .45657 L .2104 .44417 L p F P
0 g
s
.671 .135 0 r
.18857 .43693 m .2104 .44417 L .22543 .45657 L p F P
0 g
s
.751 .286 .143 r
.2104 .44417 m .18857 .43693 L .18439 .43223 L p F P
0 g
s
.197 0 0 r
.38804 .4857 m .3696 .48467 L .34654 .48214 L p F P
0 g
s
.18 0 0 r
.3696 .48467 m .33641 .48256 L .34654 .48214 L closepath p F P
0 g
s
.268 .017 .335 r
.72489 .34484 m .69363 .3655 L .69174 .37948 L p F P
0 g
s
.327 .112 .427 r
.7255 .32964 m .72489 .34484 L .69363 .3655 L p F P
0 g
s
.342 .077 .36 r
.67196 .3902 m .69174 .37948 L .69363 .3655 L p F P
0 g
s
.399 0 0 r
.2753 .46887 m .28821 .47454 L .27794 .47324 L p F P
0 g
s
.399 0 0 r
.24946 .46304 m .2753 .46887 L p .27794 .47324 L F P
0 g
s
.589 .04 0 r
.2753 .46887 m .24946 .46304 L .24187 .45887 L p F P
0 g
s
.581 .024 0 r
.24946 .46304 m .23482 .4595 L .24187 .45887 L closepath p F P
0 g
s
.252 0 .23 r
.67196 .3902 m .69174 .37948 L p .65548 .41 L F P
0 g
s
.252 0 .23 r
.65548 .41 m .65706 .40422 L .67196 .3902 L p F P
0 g
s
.207 0 0 r
.53294 .46816 m .52556 .47246 L .48818 .47814 L p F P
0 g
s
0 0 0 r
.47973 .4807 m .48818 .47814 L .52556 .47246 L p F P
0 g
s
.047 0 0 r
.52556 .47246 m .53294 .46816 L .57174 .45818 L p F P
0 g
s
.207 0 0 r
.57291 .45711 m .57174 .45818 L .53294 .46816 L p F P
0 g
s
.755 .279 .114 r
.18857 .43693 m .17802 .43311 L .18439 .43223 L closepath p F P
0 g
s
.802 .361 .197 r
.17802 .43311 m .16837 .42908 L .15917 .41507 L p F P
0 g
s
.807 .354 .161 r
.14059 .4066 m .15917 .41507 L .16837 .42908 L p F P
0 g
s
.096 0 0 r
.43546 .48482 m .41164 .48545 L .39362 .48539 L p F P
0 g
s
.046 0 0 r
.41164 .48545 m .38804 .4857 L .39362 .48539 L closepath p F P
0 g
s
.078 0 0 r
.47973 .4807 m .46771 .48199 L .44088 .48409 L p F P
0 g
s
0 0 0 r
.46771 .48199 m .43546 .48482 L .44088 .48409 L closepath p F P
0 g
s
.9 .594 .457 r
.09697 .35795 m .08156 .34805 L .08049 .33189 L p F P
0 g
s
.913 .605 .448 r
.06592 .32155 m .08049 .33189 L .08156 .34805 L p F P
0 g
s
.91 .637 .512 r
.08049 .33189 m .06592 .32155 L .06681 .30486 L p F P
0 g
s
.671 .135 0 r
.22543 .45657 m .20403 .44917 L .18857 .43693 L p F P
0 g
s
.634 .076 0 r
.17802 .43311 m .18857 .43693 L .20403 .44917 L p F P
0 g
s
.886 .542 .393 r
.11462 .38204 m .1001 .37357 L .09697 .35795 L p F P
0 g
s
.898 .551 .379 r
.08156 .34805 m .09697 .35795 L .1001 .37357 L p F P
0 g
s
.399 0 0 r
.27794 .47324 m .27486 .47249 L .24946 .46304 L p F P
0 g
s
.248 0 0 r
.23482 .4595 m .24946 .46304 L .27486 .47249 L p F P
0 g
s
.875 .518 .369 r
.11642 .38303 m .11462 .38204 L .11606 .38163 L closepath p F P
0 g
s
.121 0 0 r
.61079 .44327 m .6157 .43633 L .65065 .4212 L p F P
0 g
s
.235 0 .1 r
.65548 .41 m .65065 .4212 L .6157 .43633 L p F P
0 g
s
.213 0 0 r
.6157 .43633 m .61079 .44327 L .57291 .45711 L p F P
0 g
s
.923 .65 .507 r
.05309 .29407 m .06681 .30486 L .06592 .32155 L p F P
0 g
s
.155 0 .069 r
.6886 .39218 m .65548 .41 L .65065 .4212 L p F P
0 g
s
.252 0 .23 r
.69174 .37948 m .6886 .39218 L .65548 .41 L p F P
0 g
s
.32 .149 .486 r
.7255 .32964 m .73493 .32211 L .73609 .30441 L p F P
0 g
s
.301 .134 .48 r
.75424 .28909 m .73609 .30441 L .73493 .32211 L p F P
0 g
s
.849 .446 .279 r
.14059 .4066 m .12284 .39773 L .11642 .38303 L p F P
0 g
s
.856 .442 .246 r
.11462 .38204 m .11642 .38303 L .12284 .39773 L p F P
0 g
s
.264 .065 .412 r
.73493 .32211 m .7255 .32964 L .72489 .34484 L p F P
0 g
s
.856 .442 .246 r
.10291 .38173 m .11462 .38204 L p .12284 .39773 L F P
0 g
s
.875 .489 .302 r
.10291 .38173 m .1001 .37357 L .11462 .38204 L closepath p F P
0 g
s
.073 0 0 r
.57174 .45818 m .57291 .45711 L .61079 .44327 L p F P
0 g
s
.15 0 0 r
.30402 .47735 m .28821 .47454 L p .32725 .48112 L F P
0 g
s
.161 0 0 r
.30402 .47735 m .27794 .47324 L .28821 .47454 L closepath p F P
0 g
s
0 .56 .788 r
.30402 .47735 m .32393 .47935 L p .27783 .47311 L F P
0 g
s
0 .56 .788 r
.27651 .47293 m .30402 .47735 L .27783 .47311 L F
.15 0 0 r
.33324 .48213 m .30402 .47735 L p .32725 .48112 L F P
0 g
s
.248 0 0 r
.22976 .45923 m .23482 .4595 L p .27486 .47249 L F P
0 g
s
.591 .025 0 r
.22976 .45923 m .22543 .45657 L .23482 .4595 L closepath p F P
0 g
s
.634 .076 0 r
.17179 .4329 m .17802 .43311 L p .20403 .44917 L F P
0 g
s
.755 .261 .055 r
.17179 .4329 m .16837 .42908 L .17802 .43311 L closepath p F P
0 g
s
.11 .661 .802 r
.38268 .4853 m .38804 .4857 L .41164 .48545 L p F P
0 g
s
0 .563 .729 r
.38268 .4853 m .3696 .48467 L .38804 .4857 L closepath p F P
0 g
s
.807 .354 .161 r
.16837 .42908 m .14984 .42057 L .14059 .4066 L p F P
0 g
s
.81 .345 .123 r
.12284 .39773 m .14059 .4066 L .14984 .42057 L p F P
0 g
s
.063 .627 .75 r
.43028 .48476 m .41164 .48545 L .43546 .48482 L closepath p F P
0 g
s
.11 .661 .802 r
.41164 .48545 m .43028 .48476 L p .38268 .4853 L F P
0 g
s
.185 0 .215 r
.71753 .36255 m .69174 .37948 L .6886 .39218 L p F P
0 g
s
.268 .017 .335 r
.724 .35223 m .72489 .34484 L p .69174 .37948 L F P
0 g
s
.268 .017 .335 r
.69174 .37948 m .71753 .36255 L .724 .35223 L p F P
0 g
s
.166 .704 .805 r
.43028 .48476 m .43546 .48482 L .46771 .48199 L p F P
0 g
s
.176 0 0 r
.33525 .48247 m .33324 .48213 L .33641 .48256 L closepath p F P
0 g
s
0 .559 .728 r
.3696 .48467 m .38268 .4853 L p .33525 .48247 L F P
0 g
s
0 .559 .728 r
.33525 .48247 m .33641 .48256 L .3696 .48467 L p F P
0 g
s
0 0 0 r
.56339 .46287 m .57174 .45818 L .60853 .44547 L p F P
0 g
s
.073 0 0 r
.61079 .44327 m .60853 .44547 L .57174 .45818 L p F P
0 g
s
.047 0 0 r
.57174 .45818 m .56339 .46287 L .52556 .47246 L p F P
0 g
s
.519 0 0 r
.22543 .45657 m .22976 .45923 L .21765 .45673 L p F P
0 g
s
.519 0 0 r
.21765 .45673 m .20403 .44917 L .22543 .45657 L p F P
0 g
s
.05 .599 .835 r
.33324 .48213 m .33525 .48247 L .32393 .47935 L p F P
0 g
s
.05 .599 .835 r
.32393 .47935 m .30402 .47735 L .33324 .48213 L p F P
0 g
s
0 0 0 r
.47795 .48092 m .46771 .48199 L .47973 .4807 L closepath p F P
0 g
s
.166 .704 .805 r
.46771 .48199 m .47795 .48092 L p .43028 .48476 L F P
0 g
s
.741 .226 0 r
.16837 .42908 m .17179 .4329 L .15923 .43058 L p F P
0 g
s
.741 .226 0 r
.15923 .43058 m .14984 .42057 L .16837 .42908 L p F P
0 g
s
0 .559 .728 r
.38268 .4853 m .37168 .48178 L .33525 .48247 L p F P
0 g
s
.469 .786 .999 r
.37168 .48178 m .33525 .48247 L .32393 .47935 L p F P
0 g
s
0 0 0 r
.52556 .47246 m .52108 .47336 L .47973 .4807 L p F P
0 g
s
.212 .733 .729 r
.52108 .47336 m .52556 .47246 L .56339 .46287 L p F P
0 g
s
.172 .708 .747 r
.47795 .48092 m .47973 .4807 L .52108 .47336 L p F P
0 g
s
.264 .065 .412 r
.72489 .34484 m .72934 .34131 L .73493 .32211 L p F P
0 g
s
.238 .041 .399 r
.75479 .30547 m .73493 .32211 L .72934 .34131 L p F P
0 g
s
.301 .134 .48 r
.73493 .32211 m .75479 .30547 L .75424 .28909 L p F P
0 g
s
.898 .551 .379 r
.1001 .37357 m .08463 .36369 L .08156 .34805 L p F P
0 g
s
.91 .559 .364 r
.06693 .33774 m .08156 .34805 L .08463 .36369 L p F P
0 g
s
.913 .605 .448 r
.08156 .34805 m .06693 .33774 L .06592 .32155 L p F P
0 g
s
.926 .616 .437 r
.05213 .3108 m .06592 .32155 L .06693 .33774 L p F P
0 g
s
.923 .65 .507 r
.06592 .32155 m .05213 .3108 L .05309 .29407 L p F P
0 g
s
.248 0 0 r
.27486 .47249 m .25114 .46586 L .22976 .45923 L p F P
0 g
s
.276 0 0 r
.25114 .46586 m .22976 .45923 L .21765 .45673 L p F P
0 g
s
.885 .49 .276 r
.1001 .37357 m .10291 .38173 L .08986 .37874 L p F P
0 g
s
.885 .49 .276 r
.08986 .37874 m .08463 .36369 L .1001 .37357 L p F P
0 g
s
.935 .664 .5 r
.04015 .28285 m .05309 .29407 L .05213 .3108 L p F P
0 g
s
.11 .661 .802 r
.43028 .48476 m .41959 .48158 L .38268 .4853 L p F P
0 g
s
.534 .811 .997 r
.41959 .48158 m .38268 .4853 L .37168 .48178 L p F P
0 g
s
.634 .076 0 r
.20403 .44917 m .18337 .44142 L .17179 .4329 L p F P
0 g
s
.626 .064 0 r
.18337 .44142 m .17179 .4329 L .15923 .43058 L p F P
0 g
s
.172 .708 .747 r
.52108 .47336 m .51556 .47353 L .47795 .48092 L p F P
0 g
s
.491 .861 .984 r
.51556 .47353 m .47795 .48092 L .46758 .47909 L p F P
0 g
s
.166 .704 .805 r
.47795 .48092 m .46758 .47909 L .43028 .48476 L p F P
0 g
s
0 .56 .788 r
.27651 .47293 m .27794 .47324 L .30402 .47735 L p F P
0 g
s
.539 .836 .999 r
.46758 .47909 m .43028 .48476 L .41959 .48158 L p F P
0 g
s
.81 .345 .123 r
.14984 .42057 m .13215 .41166 L .12284 .39773 L p F P
0 g
s
.81 .334 .08 r
.10592 .38846 m .12284 .39773 L .13215 .41166 L p F P
0 g
s
.856 .442 .246 r
.12284 .39773 m .10592 .38846 L .10291 .38173 L p F P
0 g
s
.193 0 .317 r
.724 .35223 m .72934 .34131 L .72489 .34484 L closepath p F P
0 g
s
.121 0 0 r
.65065 .4212 m .64886 .42401 L .61079 .44327 L p F P
0 g
s
0 0 0 r
.60853 .44547 m .61079 .44327 L .64886 .42401 L p F P
0 g
s
.41 0 0 r
.20403 .44917 m .21765 .45673 L .20683 .45289 L p F P
0 g
s
.41 0 0 r
.18337 .44142 m .20403 .44917 L p .20683 .45289 L F P
0 g
s
.231 .082 .463 r
.76077 .28248 m .75424 .28909 L .75479 .30547 L p F P
0 g
s
.039 0 0 r
.64886 .42401 m .66297 .41462 L .65065 .4212 L closepath p F P
0 g
s
.155 0 .069 r
.68684 .39674 m .6886 .39218 L p .65065 .4212 L F P
0 g
s
.155 0 .069 r
.65065 .4212 m .66297 .41462 L .68684 .39674 L p F P
0 g
s
.139 0 .281 r
.72934 .34131 m .75424 .32059 L p .72309 .35874 L F P
0 g
s
.139 0 .281 r
.72309 .35874 m .724 .35223 L .72934 .34131 L p F P
0 g
s
.238 .041 .399 r
.72934 .34131 m .75424 .32059 L .75479 .30547 L p F P
0 g
s
.72 .189 0 r
.14984 .42057 m .15923 .43058 L .15126 .42799 L p F P
0 g
s
.72 .189 0 r
.13215 .41166 m .14984 .42057 L p .15126 .42799 L F P
0 g
s
.343 .822 .858 r
.51556 .47353 m .52108 .47336 L .5603 .46336 L p F P
0 g
s
.212 .733 .729 r
.56339 .46287 m .5603 .46336 L .52108 .47336 L p F P
0 g
s
.865 .444 .219 r
.10592 .38846 m .10291 .38173 L .08986 .37874 L p F P
0 g
s
.212 0 0 r
.27651 .47293 m .27486 .47249 L .27794 .47324 L closepath p F P
0 g
s
0 .529 .818 r
.27486 .47249 m .27651 .47293 L .26479 .46859 L p F P
0 g
s
0 .529 .818 r
.26479 .46859 m .25114 .46586 L .27486 .47249 L p F P
0 g
s
0 0 0 r
.60159 .44966 m .60853 .44547 L .6435 .43002 L p F P
0 g
s
0 0 0 r
.64886 .42401 m .6435 .43002 L .60853 .44547 L p F P
0 g
s
0 0 0 r
.60853 .44547 m .60159 .44966 L .56339 .46287 L p F P
0 g
s
.08 0 .065 r
.68684 .39674 m .69748 .38637 L .6886 .39218 L closepath p F P
0 g
s
.185 0 .215 r
.6886 .39218 m .69748 .38637 L .71753 .36255 L p F P
0 g
s
0 .56 .788 r
.32393 .47935 m .31255 .47388 L .27651 .47293 L p F P
0 g
s
.46 .754 .993 r
.31255 .47388 m .27651 .47293 L .26479 .46859 L p F P
0 g
s
.239 0 .314 r
.71753 .36255 m .72309 .35874 L .724 .35223 L closepath p F P
0 g
s
.91 .559 .364 r
.08463 .36369 m .06995 .3534 L .06693 .33774 L p F P
0 g
s
.921 .568 .346 r
.05308 .32701 m .06693 .33774 L .06995 .3534 L p F P
0 g
s
.926 .616 .437 r
.06693 .33774 m .05308 .32701 L .05213 .3108 L p F P
0 g
s
.938 .628 .425 r
.03914 .29961 m .05213 .3108 L .05308 .32701 L p F P
0 g
s
.935 .664 .5 r
.05213 .3108 m .03914 .29961 L .04015 .28285 L p F P
0 g
s
.894 .494 .251 r
.08463 .36369 m .08986 .37874 L .08979 .37871 L p F P
0 g
s
.894 .494 .251 r
.06995 .3534 m .08463 .36369 L p .08979 .37871 L F P
0 g
s
0 0 0 r
.6435 .43002 m .64886 .42401 L .66297 .41462 L p F P
0 g
s
.144 0 .178 r
.72309 .35874 m .71753 .36255 L .69748 .38637 L p F P
0 g
s
.359 .831 .807 r
.5603 .46336 m .56339 .46287 L .60159 .44966 L p F P
0 g
s
.231 .082 .463 r
.75479 .30547 m .7601 .30014 L .76077 .28248 L p F P
0 g
s
.202 .06 .454 r
.77964 .26213 m .76077 .28248 L .7601 .30014 L p F P
0 g
s
.81 .334 .08 r
.13215 .41166 m .11529 .40236 L .10592 .38846 L p F P
0 g
s
.807 .321 .032 r
.08987 .37877 m .10592 .38846 L .11529 .40236 L p F P
0 g
s
.865 .444 .219 r
.08986 .37874 m .08987 .37877 L .10592 .38846 L p F P
0 g
s
.41 0 0 r
.20683 .45289 m .20463 .45202 L .18337 .44142 L p F P
0 g
s
.31 0 0 r
.1634 .43335 m .18337 .44142 L .20463 .45202 L p F P
0 g
s
.626 .064 0 r
.15923 .43058 m .1634 .43335 L .18337 .44142 L p F P
0 g
s
0 0 0 r
.66297 .41462 m .68375 .40308 L p .6435 .43002 L F P
0 g
s
.097 0 .002 r
.66297 .41462 m .68375 .40308 L .68684 .39674 L closepath p F P
0 g
s
.469 .786 .999 r
.32393 .47935 m .36062 .47552 L .37168 .48178 L p F P
0 g
s
.58 .773 .971 r
.36062 .47552 m .32393 .47935 L .31255 .47388 L p F P
0 g
s
0 0 0 r
.69748 .38637 m .71988 .37112 L p .68375 .40308 L F P
0 g
s
0 0 0 r
.68375 .40308 m .68684 .39674 L .69748 .38637 L p F P
0 g
s
.144 0 .178 r
.69748 .38637 m .71988 .37112 L .72309 .35874 L p F P
0 g
s
.129 .622 .911 r
.25114 .46586 m .26479 .46859 L .25302 .46245 L p F P
0 g
s
.129 .622 .911 r
.25302 .46245 m .22771 .45904 L .25114 .46586 L p F P
0 g
s
.276 0 0 r
.21765 .45673 m .22771 .45904 L .25114 .46586 L p F P
0 g
s
.042 0 .14 r
.7459 .33986 m .72309 .35874 L .71988 .37112 L p F P
0 g
s
.139 0 .281 r
.75384 .32388 m .7459 .33986 L .72309 .35874 L p F P
0 g
s
.139 0 .281 r
.75424 .32059 m .75384 .32388 L p .72309 .35874 L F P
0 g
s
0 .494 .789 r
.22771 .45904 m .20683 .45289 L .21765 .45673 L closepath p F P
0 g
s
.158 0 .375 r
.7601 .30014 m .75479 .30547 L .75424 .32059 L p F P
0 g
s
.72 .189 0 r
.15126 .42799 m .14482 .42471 L .13215 .41166 L p F P
0 g
s
.699 .159 0 r
.11529 .40236 m .13215 .41166 L .14482 .42471 L p F P
0 g
s
.343 .822 .858 r
.5603 .46336 m .55362 .4633 L .51556 .47353 L p F P
0 g
s
.554 .879 .991 r
.55362 .4633 m .51556 .47353 L .50539 .47036 L p F P
0 g
s
.491 .861 .984 r
.46758 .47909 m .50539 .47036 L .51556 .47353 L p F P
0 g
s
.534 .811 .997 r
.37168 .48178 m .40882 .47527 L .41959 .48158 L p F P
0 g
s
.621 .776 .955 r
.40882 .47527 m .37168 .48178 L .36062 .47552 L p F P
0 g
s
.548 0 0 r
.1634 .43335 m .15126 .42799 L .15923 .43058 L closepath p F P
0 g
s
.451 .881 .9 r
.55362 .4633 m .5603 .46336 L .59734 .45048 L p F P
0 g
s
.359 .831 .807 r
.60159 .44966 m .59734 .45048 L .5603 .46336 L p F P
0 g
s
.539 .836 .999 r
.41959 .48158 m .45709 .47376 L .46758 .47909 L p F P
0 g
s
.627 .79 .961 r
.45709 .47376 m .41959 .48158 L .40882 .47527 L p F P
0 g
s
.609 .828 .984 r
.50539 .47036 m .46758 .47909 L .45709 .47376 L p F P
0 g
s
.921 .568 .346 r
.06995 .3534 m .05605 .34269 L .05308 .32701 L p F P
0 g
s
.932 .576 .327 r
.04003 .31586 m .05308 .32701 L .05605 .34269 L p F P
0 g
s
.938 .628 .425 r
.05308 .32701 m .04003 .31586 L .03914 .29961 L p F P
0 g
s
.158 0 .375 r
.75424 .32059 m .75575 .31909 L .7601 .30014 L p F P
0 g
s
.118 0 .355 r
.77903 .27987 m .7601 .30014 L .75575 .31909 L p F P
0 g
s
.202 .06 .454 r
.7601 .30014 m .77903 .27987 L .77964 .26213 L p F P
0 g
s
.894 .494 .251 r
.08979 .37871 m .07514 .36849 L .06995 .3534 L p F P
0 g
s
.901 .497 .224 r
.05605 .34269 m .06995 .3534 L .07514 .36849 L p F P
0 g
s
.31 0 0 r
.20463 .45202 m .18565 .44358 L .1634 .43335 L p F P
0 g
s
0 .354 .725 r
.15126 .42799 m .1634 .43335 L .18307 .44239 L p F P
0 g
s
0 .354 .725 r
.17906 .44059 m .15126 .42799 L .18307 .44239 L F
.699 .159 0 r
.14482 .42471 m .12811 .41534 L .11529 .40236 L p F P
0 g
s
0 .354 .725 r
.14667 .42617 m .15126 .42799 L p .18565 .44358 L F P
0 g
s
.601 .031 0 r
.14667 .42617 m .14482 .42471 L .15126 .42799 L closepath p F P
0 g
s
.542 0 0 r
.14482 .42471 m .14667 .42617 L .1341 .41982 L p F P
0 g
s
.542 0 0 r
.1341 .41982 m .12811 .41534 L .14482 .42471 L p F P
0 g
s
0 .35 .718 r
.16743 .43478 m .15001 .42755 L p .1341 .41982 L F P
0 g
s
0 .35 .718 r
.15001 .42755 m .14667 .42617 L .14464 .42514 L p F P
0 g
s
0 .35 .718 r
.14464 .42514 m .1341 .41982 L p .15001 .42755 L F P
0 g
s
0 .354 .725 r
.18307 .44239 m .18565 .44358 L p .17906 .44059 L F P
0 g
s
.065 .583 .877 r
.22771 .45904 m .25302 .46245 L p .2055 .45234 L F P
0 g
s
.065 .583 .877 r
.2055 .45234 m .20683 .45289 L .22771 .45904 L p F P
0 g
s
.869 .437 .174 r
.08987 .37877 m .08979 .37871 L .08986 .37874 L closepath p F P
0 g
s
.807 .321 .032 r
.11529 .40236 m .09929 .39264 L .08987 .37877 L p F P
0 g
s
.795 .299 0 r
.08979 .37871 m .08987 .37877 L .09929 .39264 L p F P
0 g
s
.795 .299 0 r
.07699 .37214 m .08979 .37871 L p .09929 .39264 L F P
0 g
s
.858 .409 .118 r
.07699 .37214 m .07514 .36849 L .08979 .37871 L closepath p F P
0 g
s
0 0 0 r
.6435 .43002 m .64004 .43247 L .60159 .44966 L p F P
0 g
s
.452 .882 .817 r
.59734 .45048 m .60159 .44966 L .64004 .43247 L p F P
0 g
s
.46 .754 .993 r
.26479 .46859 m .30112 .46632 L .31255 .47388 L p F P
0 g
s
.556 .754 .97 r
.30112 .46632 m .26479 .46859 L .25302 .46245 L p F P
0 g
s
0 0 0 r
.64004 .43247 m .66498 .41826 L .6435 .43002 L closepath p F P
0 g
s
0 0 0 r
.6786 .40985 m .66498 .41826 L .6435 .43002 L p F P
0 g
s
0 0 0 r
.68375 .40308 m .6786 .40985 L p .6435 .43002 L F P
0 g
s
0 0 0 r
.6786 .40985 m .70652 .38768 L .68375 .40308 L closepath p F P
0 g
s
0 0 0 r
.71691 .37814 m .70652 .38768 L .68375 .40308 L p F P
0 g
s
0 0 0 r
.71988 .37112 m .71691 .37814 L p .68375 .40308 L F P
0 g
s
.672 .126 0 r
.09929 .39264 m .11529 .40236 L .12811 .41534 L p F P
0 g
s
.068 0 .265 r
.75384 .32388 m .75575 .31909 L .75424 .32059 L closepath p F P
0 g
s
.58 .773 .971 r
.31255 .47388 m .3495 .46677 L .36062 .47552 L p F P
0 g
s
.639 .748 .927 r
.3495 .46677 m .31255 .47388 L .30112 .46632 L p F P
0 g
s
0 .36 .696 r
.2055 .45234 m .20463 .45202 L .20683 .45289 L closepath p F P
0 g
s
0 0 .217 r
.75575 .31909 m .77469 .29892 L p .75236 .33422 L F P
0 g
s
0 0 .217 r
.75236 .33422 m .75384 .32388 L .75575 .31909 L p F P
0 g
s
.118 0 .355 r
.75575 .31909 m .77469 .29892 L .77903 .27987 L p F P
0 g
s
.451 .881 .9 r
.59734 .45048 m .59208 .45055 L .55362 .4633 L p F P
0 g
s
.574 .895 .986 r
.59208 .45055 m .55362 .4633 L .54365 .45961 L p F P
0 g
s
.554 .879 .991 r
.50539 .47036 m .54365 .45961 L .55362 .4633 L p F P
0 g
s
0 .455 .809 r
.20463 .45202 m .2055 .45234 L .19332 .44604 L p F P
0 g
s
0 .455 .809 r
.19332 .44604 m .18565 .44358 L .20463 .45202 L p F P
0 g
s
.621 .776 .955 r
.36062 .47552 m .39798 .46601 L .40882 .47527 L p F P
0 g
s
.664 .736 .904 r
.39798 .46601 m .36062 .47552 L .3495 .46677 L p F P
0 g
s
0 0 0 r
.71691 .37814 m .73038 .36247 L .71988 .37112 L closepath p F P
0 g
s
.042 0 .14 r
.71988 .37112 m .73038 .36247 L .7459 .33986 L p F P
0 g
s
.065 .583 .877 r
.25302 .46245 m .24119 .45478 L .2055 .45234 L p F P
0 g
s
.431 .715 .984 r
.24119 .45478 m .2055 .45234 L .19332 .44604 L p F P
0 g
s
.112 0 .259 r
.7459 .33986 m .75236 .33422 L .75384 .32388 L closepath p F P
0 g
s
.627 .79 .961 r
.40882 .47527 m .44651 .4651 L .45709 .47376 L p F P
0 g
s
.664 .739 .906 r
.44651 .4651 m .40882 .47527 L .39798 .46601 L p F P
0 g
s
.51 .911 .9 r
.59208 .45055 m .59734 .45048 L .63247 .43477 L p F P
0 g
s
.452 .882 .817 r
.64004 .43247 m .63247 .43477 L .59734 .45048 L p F P
0 g
s
.631 .824 .975 r
.54365 .45961 m .50539 .47036 L .49508 .46357 L p F P
0 g
s
.609 .828 .984 r
.45709 .47376 m .49508 .46357 L .50539 .47036 L p F P
0 g
s
.653 .766 .932 r
.49508 .46357 m .45709 .47376 L .44651 .4651 L p F P
0 g
s
.901 .497 .224 r
.07514 .36849 m .06121 .3578 L .05605 .34269 L p F P
0 g
s
.906 .499 .194 r
.04295 .33156 m .05605 .34269 L .06121 .3578 L p F P
0 g
s
.932 .576 .327 r
.05605 .34269 m .04295 .33156 L .04003 .31586 L p F P
0 g
s
0 .354 .725 r
.18565 .44358 m .16743 .43478 L .14667 .42617 L p F P
0 g
s
.17 .036 .443 r
.78111 .26043 m .77964 .26213 L .77903 .27987 L p F P
0 g
s
.511 .906 .781 r
.63247 .43477 m .64004 .43247 L .66498 .41826 L p F P
0 g
s
.857 .402 .076 r
.07514 .36849 m .07699 .37214 L .06416 .36361 L p F P
0 g
s
.857 .402 .076 r
.06416 .36361 m .06121 .3578 L .07514 .36849 L p F P
0 g
s
.08 0 .416 r
.79333 .24317 m .78111 .26043 L .78172 .27679 L p F P
0 g
s
.17 .036 .443 r
.77903 .27987 m .78172 .27679 L .78111 .26043 L p F P
0 g
s
0 0 .095 r
.75236 .33422 m .7459 .33986 L .73038 .36247 L p F P
0 g
s
.672 .126 0 r
.12811 .41534 m .11224 .40556 L .09929 .39264 L p F P
0 g
s
.639 .093 0 r
.08417 .38249 m .09929 .39264 L .11224 .40556 L p F P
0 g
s
.795 .299 0 r
.09929 .39264 m .08417 .38249 L .07699 .37214 L p F P
0 g
s
.785 .286 0 r
.08417 .38249 m .07699 .37214 L .06416 .36361 L p F P
0 g
s
0 0 0 r
.66498 .41826 m .67661 .41157 L .6786 .40985 L closepath p F P
0 g
s
.511 .906 .781 r
.66498 .41826 m .67661 .41157 L p .63247 .43477 L F P
0 g
s
.556 .754 .97 r
.25302 .46245 m .28964 .45696 L .30112 .46632 L p F P
0 g
s
.614 .744 .939 r
.28964 .45696 m .25302 .46245 L .24119 .45478 L p F P
0 g
s
.03 .521 .878 r
.18565 .44358 m .19332 .44604 L .18108 .43852 L p F P
0 g
s
.03 .521 .878 r
.18108 .43852 m .16743 .43478 L .18565 .44358 L p F P
0 g
s
0 0 0 r
.67661 .41157 m .6786 .40985 L .70652 .38768 L p F P
0 g
s
0 0 0 r
.73038 .36247 m .74905 .34626 L p .71497 .38169 L F P
0 g
s
0 0 0 r
.71497 .38169 m .71691 .37814 L .73038 .36247 L p F P
0 g
s
0 0 .095 r
.73038 .36247 m .74905 .34626 L .75236 .33422 L p F P
0 g
s
.48 0 0 r
.12811 .41534 m .1341 .41982 L .12149 .4122 L p F P
0 g
s
.48 0 0 r
.12149 .4122 m .11224 .40556 L .12811 .41534 L p F P
0 g
s
0 0 .049 r
.76642 .31932 m .75236 .33422 L .74905 .34626 L p F P
0 g
s
0 0 .217 r
.77469 .29892 m .76642 .31932 L .75236 .33422 L p F P
0 g
s
.639 .748 .927 r
.30112 .46632 m .33835 .45577 L .3495 .46677 L p F P
0 g
s
.675 .725 .888 r
.33835 .45577 m .30112 .46632 L .28964 .45696 L p F P
0 g
s
.51 .911 .9 r
.63247 .43477 m .63086 .43493 L .59208 .45055 L p F P
0 g
s
.575 .917 .967 r
.63086 .43493 m .59208 .45055 L .58233 .44719 L p F P
0 g
s
.574 .895 .986 r
.54365 .45961 m .58233 .44719 L .59208 .45055 L p F P
0 g
s
0 0 0 r
.70652 .38768 m .71497 .38169 L .71691 .37814 L closepath p F P
0 g
s
0 0 0 r
.70652 .38768 m .71497 .38169 L p .67661 .41157 L F P
0 g
s
.076 0 .334 r
.78172 .27679 m .77903 .27987 L .77469 .29892 L p F P
0 g
s
.664 .736 .904 r
.3495 .46677 m .3871 .45397 L .39798 .46601 L p F P
0 g
s
.689 .705 .859 r
.3871 .45397 m .3495 .46677 L .33835 .45577 L p F P
0 g
s
.906 .499 .194 r
.06121 .3578 m .04806 .34668 L .04295 .33156 L p F P
0 g
s
.664 .739 .906 r
.39798 .46601 m .43586 .45319 L .44651 .4651 L p F P
0 g
s
.683 .697 .857 r
.43586 .45319 m .39798 .46601 L .3871 .45397 L p F P
0 g
s
.852 .394 .033 r
.06121 .3578 m .06416 .36361 L .05137 .35321 L p F P
0 g
s
.852 .394 .033 r
.05137 .35321 m .04806 .34668 L .06121 .3578 L p F P
0 g
s
0 0 0 r
.70877 .38871 m .70311 .39287 L .67661 .41157 L p F P
0 g
s
0 0 0 r
.71497 .38169 m .70877 .38871 L p .67661 .41157 L F P
0 g
s
.486 .875 .688 r
.66983 .41495 m .70311 .39287 L .67661 .41157 L closepath p F P
0 g
s
.511 .906 .781 r
.67661 .41157 m .66983 .41495 L p .63247 .43477 L F P
0 g
s
.431 .715 .984 r
.19332 .44604 m .22929 .44585 L .24119 .45478 L p F P
0 g
s
.501 .725 .973 r
.22929 .44585 m .19332 .44604 L .18108 .43852 L p F P
0 g
s
0 0 .299 r
.79305 .26089 m .78172 .27679 L .78107 .29166 L p F P
0 g
s
.08 0 .416 r
.78172 .27679 m .79305 .26089 L .79333 .24317 L p F P
0 g
s
.076 0 .334 r
.77469 .29892 m .78107 .29166 L .78172 .27679 L p F P
0 g
s
.634 .836 .978 r
.58233 .44719 m .54365 .45961 L .53352 .45223 L p F P
0 g
s
.631 .824 .975 r
.49508 .46357 m .53352 .45223 L .54365 .45961 L p F P
0 g
s
.653 .766 .932 r
.44651 .4651 m .48466 .45326 L .49508 .46357 L p F P
0 g
s
.669 .711 .879 r
.48466 .45326 m .44651 .4651 L .43586 .45319 L p F P
0 g
s
.654 .755 .924 r
.53352 .45223 m .49508 .46357 L .48466 .45326 L p F P
0 g
s
0 .35 .718 r
.1341 .41982 m .14998 .42561 L .16743 .43478 L p F P
0 g
s
0 .438 .82 r
.14998 .42561 m .1341 .41982 L .12149 .4122 L p F P
0 g
s
.639 .093 0 r
.11224 .40556 m .09723 .39535 L .08417 .38249 L p F P
0 g
s
.601 .06 0 r
.06997 .37188 m .08417 .38249 L .09723 .39535 L p F P
0 g
s
.785 .286 0 r
.06416 .36361 m .06997 .37188 L .08417 .38249 L p F P
0 g
s
0 0 0 r
.70877 .38871 m .73369 .36541 L .71497 .38169 L closepath p F P
0 g
s
0 0 0 r
.74716 .35045 m .73369 .36541 L .71497 .38169 L p F P
0 g
s
0 0 0 r
.74905 .34626 m .74716 .35045 L p .71497 .38169 L F P
0 g
s
.122 .568 .921 r
.16743 .43478 m .18108 .43852 L .16876 .42997 L p F P
0 g
s
.122 .568 .921 r
.16876 .42997 m .14998 .42561 L .16743 .43478 L p F P
0 g
s
.546 .929 .87 r
.63086 .43493 m .64154 .42966 L .63247 .43477 L closepath p F P
0 g
s
.511 .906 .781 r
.66983 .41495 m .64154 .42966 L .63247 .43477 L p F P
0 g
s
0 0 .188 r
.78107 .29166 m .77469 .29892 L .76642 .31932 L p F P
0 g
s
.759 .258 0 r
.06997 .37188 m .06416 .36361 L .05137 .35321 L p F P
0 g
s
.614 .744 .939 r
.24119 .45478 m .27811 .4461 L .28964 .45696 L p F P
0 g
s
.652 .736 .911 r
.27811 .4461 m .24119 .45478 L .22929 .44585 L p F P
0 g
s
.415 0 0 r
.11224 .40556 m .12149 .4122 L .10882 .40342 L p F P
0 g
s
.415 0 0 r
.10882 .40342 m .09723 .39535 L .11224 .40556 L p F P
0 g
s
.033 0 .398 r
.80467 .22558 m .79333 .24317 L .79305 .26089 L p F P
0 g
s
.575 .936 .924 r
.64154 .42966 m .63086 .43493 L .62138 .43271 L p F P
0 g
s
.575 .917 .967 r
.58233 .44719 m .62138 .43271 L .63086 .43493 L p F P
0 g
s
.675 .725 .888 r
.28964 .45696 m .32715 .44278 L .33835 .45577 L p F P
0 g
s
.7 .709 .855 r
.32715 .44278 m .28964 .45696 L .27811 .4461 L p F P
0 g
s
.575 .936 .924 r
.66518 .41542 m .64154 .42966 L p .62138 .43271 L F P
0 g
s
.562 .937 .866 r
.64154 .42966 m .66518 .41542 L .66983 .41495 L closepath p F P
0 g
s
.689 .705 .859 r
.33835 .45577 m .37618 .43931 L .3871 .45397 L p F P
0 g
s
.707 .681 .823 r
.37618 .43931 m .33835 .45577 L .32715 .44278 L p F P
0 g
s
.683 .697 .857 r
.3871 .45397 m .42515 .43812 L .43586 .45319 L p F P
0 g
s
.695 .665 .816 r
.42515 .43812 m .3871 .45397 L .37618 .43931 L p F P
0 g
s
.669 .711 .879 r
.43586 .45319 m .47414 .43945 L .48466 .45326 L p F P
0 g
s
.677 .667 .833 r
.47414 .43945 m .43586 .45319 L .42515 .43812 L p F P
0 g
s
0 0 .049 r
.74905 .34626 m .75389 .34115 L .76642 .31932 L p F P
0 g
s
0 0 0 r
.77909 .30498 m .76642 .31932 L .75389 .34115 L p F P
0 g
s
0 0 .188 r
.76642 .31932 m .77909 .30498 L .78107 .29166 L p F P
0 g
s
0 0 0 r
.74716 .35045 m .75389 .34115 L .74905 .34626 L closepath p F P
0 g
s
0 0 .144 r
.7896 .27976 m .78107 .29166 L .77909 .30498 L p F P
0 g
s
0 0 .299 r
.78107 .29166 m .7896 .27976 L .79305 .26089 L p F P
0 g
s
.634 .868 .986 r
.62138 .43271 m .58233 .44719 L .57238 .44018 L p F P
0 g
s
.634 .836 .978 r
.53352 .45223 m .57238 .44018 L .58233 .44719 L p F P
0 g
s
.654 .755 .924 r
.48466 .45326 m .52323 .44125 L .53352 .45223 L p F P
0 g
s
.659 .697 .874 r
.52323 .44125 m .48466 .45326 L .47414 .43945 L p F P
0 g
s
.601 .06 0 r
.09723 .39535 m .08308 .3847 L .06997 .37188 L p F P
0 g
s
.558 .03 0 r
.05671 .36079 m .06997 .37188 L .08308 .3847 L p F P
0 g
s
.759 .258 0 r
.05137 .35321 m .05671 .36079 L .06997 .37188 L p F P
0 g
s
.501 .725 .973 r
.18108 .43852 m .21732 .43591 L .22929 .44585 L p F P
0 g
s
.547 .73 .96 r
.21732 .43591 m .18108 .43852 L .16876 .42997 L p F P
0 g
s
.647 .764 .934 r
.57238 .44018 m .53352 .45223 L .52323 .44125 L p F P
0 g
s
.194 .598 .945 r
.14998 .42561 m .16876 .42997 L .15636 .42059 L p F P
0 g
s
.194 .598 .945 r
.15636 .42059 m .13337 .41603 L .14998 .42561 L p F P
0 g
s
0 .438 .82 r
.12149 .4122 m .13337 .41603 L .14998 .42561 L p F P
0 g
s
.694 .46 .564 r
.40648 .23465 m .41322 .23463 L .41379 .2529 L p F P
0 g
s
.694 .46 .564 r
.41379 .2529 m .40302 .25293 L .40648 .23465 L p F P
0 g
s
.72 .479 .56 r
.36692 .23246 m .40648 .23465 L .40302 .25293 L p F P
0 g
s
.615 .398 .563 r
.41379 .2529 m .41322 .23463 L .45565 .22637 L p F P
0 g
s
.035 .497 .883 r
.13337 .41603 m .12149 .4122 L .10882 .40342 L p F P
0 g
s
.676 .977 .869 r
.66518 .41542 m .66983 .41495 L .70311 .39287 L p F P
0 g
s
0 0 .265 r
.80513 .24229 m .79305 .26089 L .7896 .27976 L p F P
0 g
s
.033 0 .398 r
.80519 .23811 m .80467 .22558 L p .79305 .26089 L F P
0 g
s
.033 0 .398 r
.79305 .26089 m .80513 .24229 L .80519 .23811 L p F P
0 g
s
0 0 0 r
.75389 .34115 m .77126 .32146 L p .74381 .35613 L F P
0 g
s
0 0 0 r
.74381 .35613 m .74716 .35045 L .75389 .34115 L p F P
0 g
s
0 0 0 r
.77726 .31131 m .77909 .30498 L p .75389 .34115 L F P
0 g
s
0 0 0 r
.75389 .34115 m .77126 .32146 L .77726 .31131 L p F P
0 g
s
.72 .479 .56 r
.40302 .25293 m .36421 .25044 L .36692 .23246 L p F P
0 g
s
.759 .516 .565 r
.36041 .23136 m .36692 .23246 L .36421 .25044 L p F P
0 g
s
0 .178 .63 r
.09723 .39535 m .10882 .40342 L .0961 .39358 L p F P
0 g
s
0 .178 .63 r
.0961 .39358 m .08308 .3847 L .09723 .39535 L p F P
0 g
s
.759 .516 .565 r
.36421 .25044 m .36102 .24991 L .36041 .23136 L p F P
0 g
s
.779 .532 .562 r
.33858 .22637 m .36041 .23136 L .36102 .24991 L p F P
0 g
s
0 0 0 r
.73369 .36541 m .74381 .35613 L .74716 .35045 L closepath p F P
0 g
s
.652 .736 .911 r
.22929 .44585 m .26652 .43403 L .27811 .4461 L p F P
0 g
s
.679 .732 .89 r
.26652 .43403 m .22929 .44585 L .21732 .43591 L p F P
0 g
s
.695 .665 .816 r
.37618 .43931 m .41441 .41988 L .42515 .43812 L p F P
0 g
s
.705 .639 .78 r
.41441 .41988 m .37618 .43931 L .36524 .42221 L p F P
0 g
s
.707 .681 .823 r
.32715 .44278 m .36524 .42221 L .37618 .43931 L p F P
0 g
s
.676 .977 .869 r
.70311 .39287 m .70758 .38954 L p .66518 .41542 L F P
0 g
s
.439 .824 .591 r
.70311 .39287 m .70758 .38954 L .70877 .38871 L closepath p F P
0 g
s
.6 .905 .632 r
.70758 .38954 m .70877 .38871 L .73369 .36541 L p F P
0 g
s
.6 .905 .632 r
.73369 .36541 m .74381 .35613 L p .70758 .38954 L F P
0 g
s
.721 .663 .792 r
.36524 .42221 m .32715 .44278 L .31592 .42809 L p F P
0 g
s
.7 .709 .855 r
.27811 .4461 m .31592 .42809 L .32715 .44278 L p F P
0 g
s
.719 .699 .83 r
.31592 .42809 m .27811 .4461 L .26652 .43403 L p F P
0 g
s
.677 .667 .833 r
.42515 .43812 m .46356 .42209 L .47414 .43945 L p F P
0 g
s
.682 .633 .794 r
.46356 .42209 m .42515 .43812 L .41441 .41988 L p F P
0 g
s
.659 .697 .874 r
.47414 .43945 m .51283 .42666 L .52323 .44125 L p F P
0 g
s
.658 .65 .831 r
.51283 .42666 m .47414 .43945 L .46356 .42209 L p F P
0 g
s
.471 .284 .545 r
.45625 .24453 m .45565 .22637 L .49008 .20847 L p F P
0 g
s
.615 .398 .563 r
.45565 .22637 m .45625 .24453 L .41379 .2529 L p F P
0 g
s
.779 .532 .562 r
.36102 .24991 m .3361 .24425 L .33858 .22637 L p F P
0 g
s
.835 .582 .558 r
.31702 .21783 m .33858 .22637 L .3361 .24425 L p F P
0 g
s
.639 .955 .767 r
.70011 .39224 m .72701 .37149 L .70758 .38954 L closepath p F P
0 g
s
.6 .905 .632 r
.74381 .35613 m .73927 .36079 L p .70758 .38954 L F P
0 g
s
.6 .905 .632 r
.73927 .36079 m .72701 .37149 L .70758 .38954 L p F P
0 g
s
.676 .977 .869 r
.70758 .38954 m .70011 .39224 L p .66518 .41542 L F P
0 g
s
.575 .936 .924 r
.62138 .43271 m .6607 .41509 L .66518 .41542 L p F P
0 g
s
.634 .913 .981 r
.6607 .41509 m .62138 .43271 L .61166 .42697 L p F P
0 g
s
.634 .868 .986 r
.57238 .44018 m .61166 .42697 L .62138 .43271 L p F P
0 g
s
.7 .494 .606 r
.40302 .25293 m .41379 .2529 L .41608 .27318 L p F P
0 g
s
.7 .494 .606 r
.41608 .27318 m .39396 .27323 L .40302 .25293 L p F P
0 g
s
.728 .527 .619 r
.36421 .25044 m .40302 .25293 L .39396 .27323 L p F P
0 g
s
.628 .442 .612 r
.41608 .27318 m .41379 .2529 L .45625 .24453 L p F P
0 g
s
0 0 .366 r
.80519 .23811 m .8052 .22455 L .80467 .22558 L closepath p F P
0 g
s
.249 .616 .957 r
.13337 .41603 m .15636 .42059 L .14387 .41051 L p F P
0 g
s
.249 .616 .957 r
.14387 .41051 m .1177 .406 L .13337 .41603 L p F P
0 g
s
.035 .497 .883 r
.10882 .40342 m .1177 .406 L .13337 .41603 L p F P
0 g
s
0 0 .144 r
.77909 .30498 m .7828 .29981 L .7896 .27976 L p F P
0 g
s
0 0 .087 r
.80168 .26126 m .7896 .27976 L .7828 .29981 L p F P
0 g
s
0 0 .265 r
.7896 .27976 m .80168 .26126 L .80513 .24229 L p F P
0 g
s
.663 .966 .922 r
.6607 .41509 m .68064 .40392 L .66518 .41542 L closepath p F P
0 g
s
.676 .977 .869 r
.70011 .39224 m .68064 .40392 L .66518 .41542 L p F P
0 g
s
.558 .03 0 r
.08308 .3847 m .06983 .3736 L .05671 .36079 L p F P
0 g
s
0 0 .337 r
.8052 .22455 m .81323 .20694 L p .80534 .24195 L F P
0 g
s
0 0 .337 r
.80534 .24195 m .80519 .23811 L .8052 .22455 L p F P
0 g
s
.647 .764 .934 r
.52323 .44125 m .56225 .42963 L .57238 .44018 L p F P
0 g
s
.643 .701 .889 r
.56225 .42963 m .52323 .44125 L .51283 .42666 L p F P
0 g
s
.642 .795 .956 r
.61166 .42697 m .57238 .44018 L .56225 .42963 L p F P
0 g
s
0 0 0 r
.77726 .31131 m .7828 .29981 L .77909 .30498 L closepath p F P
0 g
s
.728 .527 .619 r
.36198 .25694 m .36421 .25044 L p .39396 .27323 L F P
0 g
s
.759 .547 .61 r
.36198 .25694 m .36421 .25044 L .36102 .24991 L closepath p F P
0 g
s
.547 .73 .96 r
.16876 .42997 m .20526 .42524 L .21732 .43591 L p F P
0 g
s
.577 .733 .949 r
.20526 .42524 m .16876 .42997 L .15636 .42059 L p F P
0 g
s
.754 .543 .611 r
.36102 .24991 m .3361 .24425 L p .35728 .26999 L F P
0 g
s
.754 .543 .611 r
.35728 .26999 m .36198 .25694 L .36102 .24991 L p F P
0 g
s
.705 .639 .78 r
.40905 .4091 m .41441 .41988 L p .36524 .42221 L F P
0 g
s
.705 .639 .78 r
.36524 .42221 m .38669 .40886 L .40905 .4091 L p F P
0 g
s
.715 .662 .796 r
.36524 .42221 m .38669 .40886 L .35648 .40668 L closepath p F P
0 g
s
.721 .663 .792 r
.35648 .40668 m .36524 .42221 L p .31592 .42809 L F P
0 g
s
.12 .533 .916 r
.1177 .406 m .10882 .40342 L .0961 .39358 L p F P
0 g
s
0 .208 .677 r
.08308 .3847 m .0961 .39358 L .08332 .38273 L p F P
0 g
s
0 .208 .677 r
.08332 .38273 m .06983 .3736 L .08308 .3847 L p F P
0 g
s
.682 .633 .794 r
.4547 .40445 m .46356 .42209 L p .41441 .41988 L F P
0 g
s
.682 .633 .794 r
.41441 .41988 m .4437 .40549 L .4547 .40445 L p F P
0 g
s
.68 .628 .79 r
.41441 .41988 m .4437 .40549 L .40905 .4091 L closepath p F P
0 g
s
.728 .527 .619 r
.39396 .27323 m .36396 .27106 L .36198 .25694 L p F P
0 g
s
.757 .547 .612 r
.36396 .27106 m .36198 .25694 L .35728 .26999 L closepath p F P
0 g
s
0 0 0 r
.77126 .32146 m .75346 .34512 L .74381 .35613 L p F P
0 g
s
.559 .843 .508 r
.73927 .36079 m .75346 .34512 L .74381 .35613 L closepath p F P
0 g
s
.721 .663 .792 r
.31592 .42809 m .34943 .40599 L .35648 .40668 L p F P
0 g
s
.739 .659 .771 r
.34943 .40599 m .31592 .42809 L .30465 .41206 L p F P
0 g
s
.719 .699 .83 r
.26652 .43403 m .30465 .41206 L .31592 .42809 L p F P
0 g
s
.703 .517 .633 r
.39396 .27323 m .41608 .27318 L .41972 .29502 L p F P
0 g
s
.703 .517 .633 r
.41972 .29502 m .38049 .2951 L .39396 .27323 L p F P
0 g
s
.728 .55 .65 r
.36396 .27106 m .39396 .27323 L .38049 .2951 L p F P
0 g
s
.629 .466 .643 r
.41608 .27318 m .45832 .26445 L p .44069 .29053 L F P
0 g
s
.629 .466 .643 r
.44069 .29053 m .41972 .29502 L .41608 .27318 L p F P
0 g
s
.628 .442 .612 r
.45625 .24453 m .45832 .26445 L .41608 .27318 L p F P
0 g
s
.658 .65 .831 r
.46356 .42209 m .50233 .40834 L .51283 .42666 L p F P
0 g
s
.655 .62 .802 r
.49603 .39497 m .50233 .40834 L .46356 .42209 L p F P
0 g
s
.655 .62 .802 r
.46356 .42209 m .4547 .40445 L .49603 .39497 L p F P
0 g
s
.679 .732 .89 r
.21732 .43591 m .25486 .42112 L .26652 .43403 L p F P
0 g
s
.699 .731 .875 r
.25486 .42112 m .21732 .43591 L .20526 .42524 L p F P
0 g
s
0 0 0 r
.7828 .29981 m .7948 .28143 L p .77544 .31636 L F P
0 g
s
0 0 0 r
.77544 .31636 m .77726 .31131 L .7828 .29981 L p F P
0 g
s
0 0 .087 r
.7828 .29981 m .7948 .28143 L .80168 .26126 L p F P
0 g
s
.68 .625 .787 r
.4437 .40549 m .40905 .4091 L .40368 .39815 L p F P
0 g
s
.706 .637 .777 r
.40905 .4091 m .40368 .39815 L .38669 .40886 L closepath p F P
0 g
s
.835 .582 .558 r
.3361 .24425 m .31476 .23564 L .31702 .21783 L p F P
0 g
s
.888 .634 .548 r
.30025 .2075 m .31702 .21783 L .31476 .23564 L p F P
0 g
s
.736 .695 .812 r
.30465 .41206 m .26652 .43403 L .25486 .42112 L p F P
0 g
s
.715 .66 .793 r
.39409 .37542 m .40368 .39815 L .38669 .40886 L p F P
0 g
s
.715 .66 .793 r
.38978 .37526 m .39409 .37542 L p .38669 .40886 L F P
0 g
s
.715 .66 .793 r
.3543 .40276 m .38978 .37526 L p .38669 .40886 L F P
0 g
s
.715 .66 .793 r
.38669 .40886 m .35648 .40668 L .3543 .40276 L p F P
0 g
s
.504 .345 .599 r
.45832 .26445 m .45625 .24453 L .49096 .22685 L p F P
0 g
s
.471 .284 .545 r
.49008 .20847 m .49096 .22685 L .45625 .24453 L p F P
0 g
s
0 0 .378 r
.80513 .24229 m .80534 .24195 L .80519 .23811 L closepath p F P
0 g
s
.754 .543 .611 r
.3361 .24425 m .33035 .26339 L .35728 .26999 L p F P
0 g
s
.838 .617 .603 r
.31476 .23564 m .3361 .24425 L .33035 .26339 L p F P
0 g
s
.728 .55 .65 r
.38049 .2951 m .36877 .29427 L .36396 .27106 L p F P
0 g
s
.756 .568 .641 r
.35728 .26999 m .36396 .27106 L .36877 .29427 L p F P
0 g
s
.643 .953 .942 r
.68064 .40392 m .6607 .41509 L .65127 .41131 L p F P
0 g
s
.634 .913 .981 r
.61166 .42697 m .65127 .41131 L .6607 .41509 L p F P
0 g
s
.756 .568 .641 r
.36877 .29427 m .34694 .29081 L .35728 .26999 L p F P
0 g
s
.796 .601 .638 r
.33035 .26339 m .35728 .26999 L .34694 .29081 L p F P
0 g
s
.721 .662 .79 r
.35648 .40668 m .3543 .40276 L .34943 .40599 L closepath p F P
0 g
s
0 0 .228 r
.80534 .24195 m .80513 .24229 L .80168 .26126 L p F P
0 g
s
.68 .625 .787 r
.40368 .39815 m .44232 .37511 L p .4437 .40549 L F P
0 g
s
.689 .605 .757 r
.44132 .37224 m .44232 .37511 L .40368 .39815 L p F P
0 g
s
.689 .605 .757 r
.40368 .39815 m .39409 .37542 L .44132 .37224 L p F P
0 g
s
0 0 .18 r
.81325 .22473 m .80534 .24195 L .80451 .25645 L p F P
0 g
s
0 0 .337 r
.81323 .20694 m .81325 .22473 L .80534 .24195 L p F P
0 g
s
0 0 .228 r
.80168 .26126 m .80451 .25645 L .80534 .24195 L p F P
0 g
s
.287 .623 .96 r
.1177 .406 m .14387 .41051 L .13128 .39984 L p F P
0 g
s
.287 .623 .96 r
.13128 .39984 m .10311 .39547 L .1177 .406 L p F P
0 g
s
.12 .533 .916 r
.0961 .39358 m .10311 .39547 L .1177 .406 L p F P
0 g
s
.739 .659 .771 r
.30465 .41206 m .31839 .40109 L .34943 .40599 L p F P
0 g
s
.712 .641 .776 r
.34336 .38097 m .31839 .40109 L .34943 .40599 L p F P
0 g
s
.712 .641 .776 r
.34943 .40599 m .3543 .40276 L .34336 .38097 L p F P
0 g
s
0 0 0 r
.77126 .32146 m .77544 .31636 L .77726 .31131 L closepath p F P
0 g
s
.643 .701 .889 r
.51283 .42666 m .55197 .41555 L .56225 .42963 L p F P
0 g
s
.633 .649 .848 r
.55197 .41555 m .51283 .42666 L .50233 .40834 L p F P
0 g
s
.682 .63 .791 r
.4547 .40445 m .45294 .4009 L .4437 .40549 L closepath p F P
0 g
s
.68 .625 .787 r
.44232 .37511 m .45294 .4009 L .4437 .40549 L p F P
0 g
s
.728 .608 .724 r
.38978 .37526 m .3543 .40276 L .34336 .38097 L p F P
0 g
s
.709 .561 .685 r
.38049 .2951 m .41972 .29502 L p .406 .31953 L F P
0 g
s
.709 .561 .685 r
.37192 .30686 m .38049 .2951 L p .406 .31953 L F P
0 g
s
.728 .565 .669 r
.37192 .30686 m .38049 .2951 L .36877 .29427 L closepath p F P
0 g
s
.634 .486 .663 r
.42135 .30303 m .44069 .29053 L .41972 .29502 L closepath p F P
0 g
s
.709 .561 .685 r
.41972 .29502 m .42135 .30303 L .406 .31953 L p F P
0 g
s
.657 .619 .799 r
.49177 .3858 m .49603 .39497 L .4547 .40445 L p F P
0 g
s
.657 .619 .799 r
.4547 .40445 m .45294 .4009 L .49177 .3858 L p F P
0 g
s
.643 .953 .942 r
.69554 .39219 m .68064 .40392 L p .65127 .41131 L F P
0 g
s
.664 .971 .899 r
.68064 .40392 m .69554 .39219 L .70011 .39224 L closepath p F P
0 g
s
.731 .566 .668 r
.36877 .29427 m .34694 .29081 L p .36387 .31811 L F P
0 g
s
.731 .566 .668 r
.36387 .31811 m .37192 .30686 L .36877 .29427 L p F P
0 g
s
0 0 0 r
.77544 .31636 m .77126 .32146 L .75346 .34512 L p F P
0 g
s
.651 .575 .756 r
.49177 .3858 m .45294 .4009 L .44232 .37511 L p F P
0 g
s
.647 .51 .682 r
.42516 .31885 m .42135 .30303 L .44069 .29053 L p F P
0 g
s
.695 .54 .672 r
.42516 .31885 m .42135 .30303 L .406 .31953 L closepath p F P
0 g
s
.709 .61 .745 r
.4319 .34413 m .44132 .37224 L .39409 .37542 L p F P
0 g
s
.709 .61 .745 r
.43108 .34418 m .4319 .34413 L p .39409 .37542 L F P
0 g
s
.709 .61 .745 r
.39409 .37542 m .39298 .37272 L .43108 .34418 L p F P
0 g
s
.716 .613 .742 r
.39409 .37542 m .39298 .37272 L .38978 .37526 L closepath p F P
0 g
s
.642 .795 .956 r
.56225 .42963 m .60173 .41783 L .61166 .42697 L p F P
0 g
s
.631 .727 .917 r
.60173 .41783 m .56225 .42963 L .55197 .41555 L p F P
0 g
s
.647 .848 .977 r
.65127 .41131 m .61166 .42697 L .60173 .41783 L p F P
0 g
s
.728 .608 .724 r
.34336 .38097 m .35245 .37233 L .38978 .37526 L p F P
0 g
s
.702 .588 .725 r
.37941 .34586 m .35245 .37233 L .38978 .37526 L p F P
0 g
s
.702 .588 .725 r
.38349 .34614 m .37941 .34586 L p .38978 .37526 L F P
0 g
s
.702 .588 .725 r
.38978 .37526 m .39298 .37272 L .38349 .34614 L p F P
0 g
s
.709 .561 .685 r
.406 .31953 m .37532 .31935 L .37192 .30686 L p F P
0 g
s
.74 .579 .675 r
.37532 .31935 m .37192 .30686 L .36387 .31811 L closepath p F P
0 g
s
.696 .585 .727 r
.39298 .37272 m .43108 .34418 L .38349 .34614 L closepath p F P
0 g
s
.77 .685 .769 r
.31839 .40109 m .30465 .41206 L .29332 .39509 L p F P
0 g
s
.736 .695 .812 r
.25486 .42112 m .29332 .39509 L .30465 .41206 L p F P
0 g
s
.577 .733 .949 r
.15636 .42059 m .1931 .41408 L .20526 .42524 L p F P
0 g
s
.596 .737 .942 r
.1931 .41408 m .15636 .42059 L .14387 .41051 L p F P
0 g
s
.695 .577 .719 r
.406 .31953 m .42516 .31885 L p .43108 .34418 L F P
0 g
s
.695 .577 .719 r
.38236 .34281 m .406 .31953 L p .43108 .34418 L F P
0 g
s
.709 .571 .698 r
.38236 .34281 m .406 .31953 L .37532 .31935 L closepath p F P
0 g
s
.714 .574 .696 r
.37532 .31935 m .36387 .31811 L p .37941 .34586 L F P
0 g
s
.714 .574 .696 r
.37941 .34586 m .38236 .34281 L .37532 .31935 L p F P
0 g
s
.54 .396 .633 r
.45832 .26445 m .49352 .24728 L p .47955 .27768 L F P
0 g
s
.54 .396 .633 r
.47955 .27768 m .46013 .27637 L .45832 .26445 L p F P
0 g
s
.504 .345 .599 r
.49096 .22685 m .49352 .24728 L .45832 .26445 L p F P
0 g
s
.629 .466 .643 r
.45832 .26445 m .46013 .27637 L .44069 .29053 L p F P
0 g
s
.641 .517 .696 r
.43175 .34365 m .42516 .31885 L .4672 .30982 L p F P
0 g
s
.695 .577 .719 r
.42516 .31885 m .43175 .34365 L .43108 .34418 L p F P
0 g
s
.647 .51 .682 r
.46197 .28622 m .4672 .30982 L .42516 .31885 L p F P
0 g
s
.647 .51 .682 r
.44069 .29053 m .46197 .28622 L p .42516 .31885 L F P
0 g
s
.77 .685 .769 r
.29332 .39509 m .29474 .39374 L .31839 .40109 L p F P
0 g
s
.729 .638 .757 r
.32263 .36692 m .29474 .39374 L .31839 .40109 L p F P
0 g
s
.729 .638 .757 r
.3381 .36973 m .32263 .36692 L p .31839 .40109 L F P
0 g
s
.729 .638 .757 r
.31839 .40109 m .34336 .38097 L .3381 .36973 L p F P
0 g
s
.695 .577 .719 r
.43108 .34418 m .38349 .34614 L .38236 .34281 L p F P
0 g
s
.727 .594 .708 r
.38349 .34614 m .38236 .34281 L .37941 .34586 L closepath p F P
0 g
s
.764 .992 .88 r
.69554 .39219 m .70011 .39224 L .72701 .37149 L p F P
0 g
s
.751 .643 .741 r
.34526 .34183 m .37941 .34586 L .35245 .37233 L p F P
0 g
s
.714 .574 .696 r
.36387 .31811 m .34526 .34183 L .37941 .34586 L p F P
0 g
s
.796 .601 .638 r
.34694 .29081 m .32202 .28353 L .33035 .26339 L p F P
0 g
s
.844 .647 .636 r
.3098 .25452 m .33035 .26339 L .32202 .28353 L p F P
0 g
s
.838 .617 .603 r
.33035 .26339 m .3098 .25452 L .31476 .23564 L p F P
0 g
s
.731 .566 .668 r
.34694 .29081 m .33426 .3125 L .36387 .31811 L p F P
0 g
s
.81 .634 .664 r
.32202 .28353 m .34694 .29081 L .33426 .3125 L p F P
0 g
s
.293 .155 .516 r
.49383 .20489 m .49008 .20847 L .49096 .22685 L p F P
0 g
s
.776 .642 .714 r
.33426 .3125 m .36387 .31811 L .34526 .34183 L p F P
0 g
s
.635 .477 .651 r
.46197 .28622 m .46013 .27637 L .44069 .29053 L closepath p F P
0 g
s
.885 .665 .598 r
.29808 .22528 m .31476 .23564 L .3098 .25452 L p F P
0 g
s
.888 .634 .548 r
.31476 .23564 m .29808 .22528 L .30025 .2075 L p F P
0 g
s
.18 .551 .93 r
.10311 .39547 m .0961 .39358 L .08332 .38273 L p F P
0 g
s
0 0 0 r
.76989 .32516 m .77544 .31636 L p .75346 .34512 L F P
0 g
s
0 0 0 r
.75346 .34512 m .76942 .32575 L .76989 .32516 L p F P
0 g
s
.727 .957 .672 r
.75346 .34512 m .76942 .32575 L p .73582 .3629 L F P
0 g
s
.727 .957 .672 r
.73582 .3629 m .73927 .36079 L .75346 .34512 L p F P
0 g
s
.651 .575 .756 r
.4829 .36282 m .49177 .3858 L p .44232 .37511 L F P
0 g
s
.651 .575 .756 r
.44232 .37511 m .45827 .36824 L .4829 .36282 L p F P
0 g
s
.643 .552 .737 r
.44232 .37511 m .45827 .36824 L .44132 .37224 L closepath p F P
0 g
s
.751 .643 .741 r
.33244 .35725 m .34526 .34183 L p .35245 .37233 L F P
0 g
s
.751 .643 .741 r
.35245 .37233 m .3381 .36973 L .33244 .35725 L p F P
0 g
s
.75 .646 .746 r
.34336 .38097 m .35245 .37233 L .3381 .36973 L closepath p F P
0 g
s
.642 .546 .731 r
.45827 .36824 m .44132 .37224 L .4319 .34413 L p F P
0 g
s
.934 .683 .534 r
.28698 .19578 m .30025 .2075 L .29808 .22528 L p F P
0 g
s
0 0 .303 r
.82 .18952 m .81323 .20694 L .81325 .22473 L p F P
0 g
s
.69 .566 .711 r
.4319 .34413 m .43175 .34365 L .43108 .34418 L closepath p F P
0 g
s
.65 .544 .721 r
.4319 .34413 m .43175 .34365 L .47059 .32363 L p F P
0 g
s
.641 .517 .696 r
.4672 .30982 m .47059 .32363 L .43175 .34365 L p F P
0 g
s
.642 .546 .731 r
.4319 .34413 m .47399 .33517 L p .45827 .36824 L F P
0 g
s
.65 .544 .721 r
.47059 .32363 m .47399 .33517 L .4319 .34413 L p F P
0 g
s
.764 .992 .88 r
.72701 .37149 m .73582 .3629 L p .69554 .39219 L F P
0 g
s
.591 .91 .658 r
.72701 .37149 m .73582 .3629 L .73927 .36079 L closepath p F P
0 g
s
0 0 0 r
.76989 .32516 m .78421 .30289 L .77544 .31636 L closepath p F P
0 g
s
0 0 0 r
.7948 .28143 m .78421 .30289 L .77544 .31636 L p F P
0 g
s
.752 .695 .796 r
.29332 .39509 m .25486 .42112 L .2431 .4077 L p F P
0 g
s
.699 .731 .875 r
.20526 .42524 m .2431 .4077 L .25486 .42112 L p F P
0 g
s
0 0 .034 r
.80451 .25645 m .80168 .26126 L .7948 .28143 L p F P
0 g
s
.54 .412 .655 r
.46197 .28622 m .46013 .27637 L .47955 .27768 L closepath p F P
0 g
s
.633 .649 .848 r
.50233 .40834 m .54156 .3979 L .55197 .41555 L p F P
0 g
s
.62 .593 .802 r
.53278 .38 m .54156 .3979 L .50233 .40834 L p F P
0 g
s
.62 .593 .802 r
.50233 .40834 m .49603 .39497 L .53278 .38 L p F P
0 g
s
.716 .736 .867 r
.2431 .4077 m .20526 .42524 L .1931 .41408 L p F P
0 g
s
.293 .155 .516 r
.49096 .22685 m .49695 .22117 L .49383 .20489 L p F P
0 g
s
.189 .076 .484 r
.51281 .18242 m .49383 .20489 L .49695 .22117 L p F P
0 g
s
.751 .643 .741 r
.3381 .36973 m .33244 .35725 L .32263 .36692 L closepath p F P
0 g
s
.773 .648 .723 r
.33244 .35725 m .34526 .34183 L .32311 .33602 L closepath p F P
0 g
s
.776 .642 .714 r
.32153 .33222 m .33426 .3125 L p .34526 .34183 L F P
0 g
s
.776 .642 .714 r
.34526 .34183 m .32311 .33602 L .32153 .33222 L p F P
0 g
s
.552 .438 .678 r
.4672 .30982 m .46197 .28622 L .47955 .27768 L p F P
0 g
s
.65 .568 .75 r
.4829 .36282 m .48117 .3582 L .45827 .36824 L closepath p F P
0 g
s
.642 .546 .731 r
.47399 .33517 m .48117 .3582 L .45827 .36824 L p F P
0 g
s
.312 .623 .959 r
.10311 .39547 m .13128 .39984 L .11859 .38865 L p F P
0 g
s
.312 .623 .959 r
.11859 .38865 m .0897 .38439 L .10311 .39547 L p F P
0 g
s
.18 .551 .93 r
.08332 .38273 m .0897 .38439 L .10311 .39547 L p F P
0 g
s
.807 .641 .677 r
.33426 .3125 m .32153 .33222 L .3106 .30654 L p F P
0 g
s
.807 .641 .677 r
.3106 .30654 m .31175 .30444 L .33426 .3125 L p F P
0 g
s
.81 .634 .664 r
.33426 .3125 m .31175 .30444 L .32202 .28353 L p F P
0 g
s
.618 .589 .799 r
.53104 .37639 m .53278 .38 L .49603 .39497 L p F P
0 g
s
.618 .589 .799 r
.49603 .39497 m .49177 .3858 L .53104 .37639 L p F P
0 g
s
.748 .637 .737 r
.32263 .36692 m .33244 .35725 L .32311 .33602 L p F P
0 g
s
.782 .702 .776 r
.29767 .35984 m .32263 .36692 L .29474 .39374 L p F P
0 g
s
.748 .637 .737 r
.31917 .33508 m .29767 .35984 L .32263 .36692 L p F P
0 g
s
.748 .637 .737 r
.32311 .33602 m .31917 .33508 L p .32263 .36692 L F P
0 g
s
0 0 0 r
.81046 .24356 m .80451 .25645 L .80212 .26907 L p F P
0 g
s
0 0 .18 r
.80451 .25645 m .81046 .24356 L .81325 .22473 L p F P
0 g
s
0 0 .034 r
.7948 .28143 m .80212 .26907 L .80451 .25645 L p F P
0 g
s
.78 .704 .78 r
.29332 .39509 m .29474 .39374 L .29165 .39253 L closepath p F P
0 g
s
.782 .702 .776 r
.28194 .37745 m .29767 .35984 L p .29474 .39374 L F P
0 g
s
.782 .702 .776 r
.29474 .39374 m .29165 .39253 L .28194 .37745 L p F P
0 g
s
.752 .695 .796 r
.29165 .39253 m .29332 .39509 L p .2431 .4077 L F P
0 g
s
.838 .671 .676 r
.30266 .27427 m .32202 .28353 L .31175 .30444 L p F P
0 g
s
.844 .647 .636 r
.32202 .28353 m .30266 .27427 L .3098 .25452 L p F P
0 g
s
.631 .727 .917 r
.55197 .41555 m .59161 .40542 L .60173 .41783 L p F P
0 g
s
.612 .669 .88 r
.59161 .40542 m .55197 .41555 L .54156 .3979 L p F P
0 g
s
.602 .547 .765 r
.52043 .35027 m .53104 .37639 L .49177 .3858 L p F P
0 g
s
.602 .547 .765 r
.5042 .35362 m .52043 .35027 L p .49177 .3858 L F P
0 g
s
.602 .547 .765 r
.49177 .3858 m .4829 .36282 L .5042 .35362 L p F P
0 g
s
.752 .695 .796 r
.2431 .4077 m .27027 .38656 L .29165 .39253 L p F P
0 g
s
.753 .694 .796 r
.29165 .39253 m .28194 .37745 L .27027 .38656 L closepath p F P
0 g
s
.643 .953 .942 r
.65127 .41131 m .69108 .39142 L .69554 .39219 L p F P
0 g
s
.664 .914 .977 r
.69108 .39142 m .65127 .41131 L .6416 .40433 L p F P
0 g
s
.647 .848 .977 r
.60173 .41783 m .6416 .40433 L .65127 .41131 L p F P
0 g
s
.565 .458 .692 r
.47059 .32363 m .4672 .30982 L .50303 .29338 L p F P
0 g
s
.552 .438 .678 r
.4991 .2774 m .50303 .29338 L .4672 .30982 L p F P
0 g
s
.552 .438 .678 r
.47955 .27768 m .4991 .2774 L p .4672 .30982 L F P
0 g
s
.88 .691 .643 r
.29351 .24404 m .3098 .25452 L .30266 .27427 L p F P
0 g
s
.885 .665 .598 r
.3098 .25452 m .29351 .24404 L .29808 .22528 L p F P
0 g
s
.734 .975 .924 r
.69108 .39142 m .70536 .38223 L .69554 .39219 L closepath p F P
0 g
s
.764 .992 .88 r
.73081 .36435 m .70536 .38223 L .69554 .39219 L p F P
0 g
s
.764 .992 .88 r
.73582 .3629 m .73081 .36435 L p .69554 .39219 L F P
0 g
s
.357 .248 .592 r
.49695 .22117 m .49096 .22685 L .49352 .24728 L p F P
0 g
s
0 0 0 r
.80212 .26907 m .7948 .28143 L .78421 .30289 L p F P
0 g
s
.769 .639 .718 r
.32311 .33602 m .32153 .33222 L .31917 .33508 L closepath p F P
0 g
s
.578 .491 .72 r
.47399 .33517 m .47059 .32363 L .50977 .31843 L p F P
0 g
s
.565 .458 .692 r
.50303 .29338 m .50977 .31843 L .47059 .32363 L p F P
0 g
s
.925 .709 .593 r
.2848 .21359 m .29808 .22528 L .29351 .24404 L p F P
0 g
s
.934 .683 .534 r
.29808 .22528 m .2848 .21359 L .28698 .19578 L p F P
0 g
s
.771 .643 .72 r
.31917 .33508 m .32153 .33222 L .3106 .30654 L p F P
0 g
s
.633 .778 .951 r
.6416 .40433 m .60173 .41783 L .59161 .40542 L p F P
0 g
s
.741 .988 .785 r
.73081 .36435 m .7447 .35174 L .73582 .3629 L closepath p F P
0 g
s
.727 .957 .672 r
.76942 .32575 m .7447 .35174 L .73582 .3629 L p F P
0 g
s
.6 .541 .76 r
.4829 .36282 m .48117 .3582 L .5042 .35362 L closepath p F P
0 g
s
.594 .508 .727 r
.47399 .33517 m .50992 .31891 L p .5042 .35362 L F P
0 g
s
.594 .508 .727 r
.5042 .35362 m .48117 .3582 L .47399 .33517 L p F P
0 g
s
.578 .491 .72 r
.50977 .31843 m .50992 .31891 L .47399 .33517 L p F P
0 g
s
.808 .688 .732 r
.29546 .32744 m .31917 .33508 L .29767 .35984 L p F P
0 g
s
.771 .643 .72 r
.3106 .30654 m .29546 .32744 L .31917 .33508 L p F P
0 g
s
0 0 .125 r
.82004 .20736 m .81325 .22473 L .81046 .24356 L p F P
0 g
s
0 0 .303 r
.81325 .22473 m .82004 .20736 L .82 .18952 L p F P
0 g
s
.596 .737 .942 r
.14387 .41051 m .18082 .40262 L .1931 .41408 L p F P
0 g
s
.607 .74 .939 r
.18082 .40262 m .14387 .41051 L .13128 .39984 L p F P
0 g
s
.776 .716 .797 r
.27027 .38656 m .2431 .4077 L .23123 .39416 L p F P
0 g
s
.716 .736 .867 r
.1931 .41408 m .23123 .39416 L .2431 .4077 L p F P
0 g
s
.552 .431 .669 r
.4991 .2774 m .47955 .27768 L .4974 .2693 L closepath p F P
0 g
s
.54 .396 .633 r
.49352 .24728 m .4974 .2693 L .47955 .27768 L p F P
0 g
s
.808 .688 .732 r
.29767 .35984 m .27751 .35107 L .29546 .32744 L p F P
0 g
s
.806 .691 .738 r
.29767 .35984 m .28194 .37745 L .27045 .36002 L p F P
0 g
s
.806 .691 .738 r
.27045 .36002 m .27751 .35107 L .29767 .35984 L p F P
0 g
s
.833 .678 .69 r
.3106 .30654 m .31175 .30444 L .30896 .30306 L closepath p F P
0 g
s
.838 .671 .676 r
.29959 .28138 m .30266 .27427 L p .31175 .30444 L F P
0 g
s
.838 .671 .676 r
.31175 .30444 m .30896 .30306 L .29959 .28138 L p F P
0 g
s
.357 .248 .592 r
.49352 .24728 m .50586 .23568 L .49695 .22117 L p F P
0 g
s
.294 .224 .605 r
.51511 .19907 m .49695 .22117 L .50586 .23568 L p F P
0 g
s
.189 .076 .484 r
.49695 .22117 m .51511 .19907 L .51281 .18242 L p F P
0 g
s
.729 .744 .864 r
.23123 .39416 m .1931 .41408 L .18082 .40262 L p F P
0 g
s
.799 .666 .717 r
.29546 .32744 m .3106 .30654 L .30896 .30306 L p F P
0 g
s
.776 .716 .797 r
.23123 .39416 m .24993 .37792 L .27027 .38656 L p F P
0 g
s
.755 .699 .799 r
.27045 .36002 m .24993 .37792 L .27027 .38656 L p F P
0 g
s
.755 .699 .799 r
.27027 .38656 m .28194 .37745 L .27045 .36002 L p F P
0 g
s
.799 .666 .717 r
.30896 .30306 m .29105 .29565 L p .29546 .32744 L F P
0 g
s
.815 .663 .694 r
.30896 .30306 m .29959 .28138 L .29105 .29565 L closepath p F P
0 g
s
0 0 0 r
.79996 .27483 m .80212 .26907 L p .78421 .30289 L F P
0 g
s
0 0 0 r
.78421 .30289 m .79488 .28479 L .79996 .27483 L p F P
0 g
s
.738 .9 .515 r
.78421 .30289 m .79488 .28479 L p .76973 .32534 L F P
0 g
s
.738 .9 .515 r
.76973 .32534 m .76989 .32516 L .78421 .30289 L p F P
0 g
s
.394 .305 .636 r
.50586 .23568 m .49352 .24728 L .4974 .2693 L p F P
0 g
s
.612 .669 .88 r
.54156 .3979 m .58132 .38979 L .59161 .40542 L p F P
0 g
s
.589 .588 .819 r
.5709 .37094 m .58132 .38979 L .54156 .3979 L p F P
0 g
s
.589 .588 .819 r
.54051 .37514 m .5709 .37094 L p .54156 .3979 L F P
0 g
s
.589 .588 .819 r
.54156 .3979 m .53278 .38 L .54051 .37514 L p F P
0 g
s
.872 .7 .667 r
.29959 .28138 m .30266 .27427 L .29197 .26709 L closepath p F P
0 g
s
.88 .691 .643 r
.28837 .25948 m .29351 .24404 L p .30266 .27427 L F P
0 g
s
.88 .691 .643 r
.30266 .27427 m .29197 .26709 L .28837 .25948 L p F P
0 g
s
.699 .967 .935 r
.70536 .38223 m .69108 .39142 L .68176 .38707 L p F P
0 g
s
.664 .914 .977 r
.6416 .40433 m .68176 .38707 L .69108 .39142 L p F P
0 g
s
0 0 .266 r
.82276 .18095 m .82 .18952 L .82004 .20736 L p F P
0 g
s
.835 .714 .731 r
.27635 .31816 m .29546 .32744 L .27751 .35107 L p F P
0 g
s
.799 .666 .717 r
.29105 .29565 m .27635 .31816 L .29546 .32744 L p F P
0 g
s
.836 .693 .705 r
.29105 .29565 m .29959 .28138 L .29197 .26709 L p F P
0 g
s
.914 .723 .631 r
.29351 .24404 m .28837 .25948 L .27675 .24326 L p F P
0 g
s
.914 .723 .631 r
.27675 .24326 m .28032 .23234 L .29351 .24404 L p F P
0 g
s
.925 .709 .593 r
.29351 .24404 m .28032 .23234 L .2848 .21359 L p F P
0 g
s
.699 .967 .935 r
.72288 .36394 m .70536 .38223 L p .68176 .38707 L F P
0 g
s
.732 .987 .892 r
.70536 .38223 m .72288 .36394 L .73081 .36435 L closepath p F P
0 g
s
0 0 0 r
.80212 .26907 m .80471 .26347 L .81046 .24356 L p F P
0 g
s
0 0 0 r
.81724 .22627 m .81046 .24356 L .80471 .26347 L p F P
0 g
s
0 0 .125 r
.81046 .24356 m .81724 .22627 L .82004 .20736 L p F P
0 g
s
.599 .527 .745 r
.52043 .35027 m .5042 .35362 L .51943 .34736 L closepath p F P
0 g
s
.594 .508 .727 r
.50992 .31891 m .51943 .34736 L .5042 .35362 L p F P
0 g
s
.603 .851 .49 r
.76942 .32575 m .76973 .32534 L .76989 .32516 L closepath p F P
0 g
s
.746 .984 .757 r
.76973 .32534 m .76942 .32575 L .7447 .35174 L p F P
0 g
s
.782 .968 .669 r
.76175 .33008 m .77971 .30788 L .76973 .32534 L closepath p F P
0 g
s
.738 .9 .515 r
.79488 .28479 m .77971 .30788 L .76973 .32534 L p F P
0 g
s
.746 .984 .757 r
.76175 .33008 m .76973 .32534 L p .7447 .35174 L F P
0 g
s
.479 .383 .668 r
.4974 .2693 m .5194 .24885 L p .51466 .28388 L F P
0 g
s
.479 .383 .668 r
.51466 .28388 m .4991 .2774 L .4974 .2693 L p F P
0 g
s
.394 .305 .636 r
.4974 .2693 m .5194 .24885 L .50586 .23568 L p F P
0 g
s
.587 .584 .816 r
.53278 .38 m .53104 .37639 L .54051 .37514 L closepath p F P
0 g
s
0 0 0 r
.79996 .27483 m .80471 .26347 L .80212 .26907 L closepath p F P
0 g
s
.633 .778 .951 r
.59161 .40542 m .63172 .39435 L .6416 .40433 L p F P
0 g
s
.608 .715 .921 r
.63172 .39435 m .59161 .40542 L .58132 .38979 L p F P
0 g
s
.821 .995 .859 r
.72288 .36394 m .73081 .36435 L .7447 .35174 L p F P
0 g
s
.821 .995 .859 r
.7447 .35174 m .75893 .3328 L p .72288 .36394 L F P
0 g
s
.746 .984 .757 r
.7447 .35174 m .75893 .3328 L .76175 .33008 L p F P
0 g
s
.586 .549 .779 r
.54051 .37514 m .53104 .37639 L .52043 .35027 L p F P
0 g
s
.656 .851 .975 r
.68176 .38707 m .6416 .40433 L .63172 .39435 L p F P
0 g
s
.852 .721 .717 r
.2741 .28546 m .29105 .29565 L .27635 .31816 L p F P
0 g
s
.836 .693 .705 r
.28628 .26385 m .2741 .28546 L .29105 .29565 L p F P
0 g
s
.836 .693 .705 r
.29197 .26709 m .28628 .26385 L p .29105 .29565 L F P
0 g
s
.832 .717 .737 r
.27751 .35107 m .27045 .36002 L .25881 .34348 L p F P
0 g
s
.832 .717 .737 r
.25881 .34348 m .26049 .34114 L .27751 .35107 L p F P
0 g
s
.835 .714 .731 r
.27751 .35107 m .26049 .34114 L .27635 .31816 L p F P
0 g
s
.466 .394 .691 r
.50303 .29338 m .4991 .2774 L .51466 .28388 L closepath p F P
0 g
s
.795 .737 .798 r
.24993 .37792 m .23123 .39416 L .21923 .38083 L p F P
0 g
s
.729 .744 .864 r
.18082 .40262 m .21923 .38083 L .23123 .39416 L p F P
0 g
s
.607 .74 .939 r
.13128 .39984 m .16841 .39105 L .18082 .40262 L p F P
0 g
s
.61 .744 .94 r
.16841 .39105 m .13128 .39984 L .11859 .38865 L p F P
0 g
s
.851 .684 .674 r
.29197 .26709 m .28837 .25948 L .28628 .26385 L closepath p F P
0 g
s
.795 .737 .798 r
.21923 .38083 m .23276 .36811 L .24993 .37792 L p F P
0 g
s
.776 .715 .795 r
.25881 .34348 m .23276 .36811 L .24993 .37792 L p F P
0 g
s
.776 .715 .795 r
.24993 .37792 m .27045 .36002 L .25881 .34348 L p F P
0 g
s
.004 0 .439 r
.51491 .17828 m .51281 .18242 L .51511 .19907 L p F P
0 g
s
.524 .443 .707 r
.50303 .29338 m .51466 .28388 L p .51045 .31852 L F P
0 g
s
.524 .443 .707 r
.51045 .31852 m .50977 .31843 L .50303 .29338 L p F P
0 g
s
.886 .732 .686 r
.28628 .26385 m .28837 .25948 L .27675 .24326 L p F P
0 g
s
.739 .755 .866 r
.21923 .38083 m .18082 .40262 L .16841 .39105 L p F P
0 g
s
0 0 .215 r
.8247 .17254 m .82276 .18095 L .82335 .19717 L p F P
0 g
s
0 0 .266 r
.82004 .20736 m .82335 .19717 L .82276 .18095 L p F P
0 g
s
.586 .549 .779 r
.52043 .35027 m .56034 .34857 L p .54051 .37514 L F P
0 g
s
.532 .488 .752 r
.55078 .32523 m .56034 .34857 L .52043 .35027 L p F P
0 g
s
.532 .488 .752 r
.52043 .35027 m .51943 .34736 L .55078 .32523 L p F P
0 g
s
.589 .584 .814 r
.5709 .37094 m .54051 .37514 L .56562 .35984 L closepath p F P
0 g
s
.586 .549 .779 r
.56034 .34857 m .56562 .35984 L .54051 .37514 L p F P
0 g
s
.524 .478 .746 r
.54968 .32246 m .55078 .32523 L .51943 .34736 L p F P
0 g
s
.524 .478 .746 r
.51045 .31852 m .54968 .32246 L p .51943 .34736 L F P
0 g
s
.524 .478 .746 r
.51943 .34736 m .50992 .31891 L .51045 .31852 L p F P
0 g
s
.88 .745 .709 r
.27244 .2524 m .28628 .26385 L .2741 .28546 L p F P
0 g
s
.886 .732 .686 r
.27675 .24326 m .27244 .2524 L .28628 .26385 L p F P
0 g
s
0 0 0 r
.80471 .26347 m .81143 .24629 L .81724 .22627 L p F P
0 g
s
0 0 0 r
.79488 .28479 m .79778 .2793 L .79996 .27483 L closepath p F P
0 g
s
.725 .807 .336 r
.80471 .26347 m .81143 .24629 L p .79778 .2793 L F P
0 g
s
.725 .807 .336 r
.79778 .2793 m .79996 .27483 L .80471 .26347 L p F P
0 g
s
.35 .3 .661 r
.51958 .21855 m .50586 .23568 L .5194 .24885 L p F P
0 g
s
.294 .224 .605 r
.51727 .2042 m .51511 .19907 L p .50586 .23568 L F P
0 g
s
.294 .224 .605 r
.50586 .23568 m .51958 .21855 L .51727 .2042 L p F P
0 g
s
.517 .465 .737 r
.50992 .31891 m .50977 .31843 L .51045 .31852 L closepath p F P
0 g
s
.522 .486 .758 r
.54968 .32246 m .51045 .31852 L .54008 .29522 L closepath p F P
0 g
s
.524 .443 .707 r
.53893 .29181 m .54008 .29522 L .51045 .31852 L p F P
0 g
s
.524 .443 .707 r
.51466 .28388 m .53893 .29181 L p .51045 .31852 L F P
0 g
s
0 0 .07 r
.82335 .19717 m .82004 .20736 L .81724 .22627 L p F P
0 g
s
.851 .74 .74 r
.26048 .30765 m .27635 .31816 L .26049 .34114 L p F P
0 g
s
.852 .721 .717 r
.27635 .31816 m .26048 .30765 L .2741 .28546 L p F P
0 g
s
0 0 .38 r
.52019 .16364 m .51491 .17828 L .51614 .19706 L p F P
0 g
s
.004 0 .439 r
.51511 .19907 m .51614 .19706 L .51491 .17828 L p F P
0 g
s
.608 .715 .921 r
.58132 .38979 m .62163 .38152 L .63172 .39435 L p F P
0 g
s
.576 .659 .893 r
.62163 .38152 m .58132 .38979 L .5709 .37094 L p F P
0 g
s
.699 .967 .935 r
.68176 .38707 m .72196 .36374 L .72288 .36394 L p F P
0 g
s
.699 .931 .966 r
.72196 .36374 m .68176 .38707 L .67218 .37991 L p F P
0 g
s
.656 .851 .975 r
.63172 .39435 m .67218 .37991 L .68176 .38707 L p F P
0 g
s
.876 .753 .724 r
.26052 .27397 m .2741 .28546 L .26048 .30765 L p F P
0 g
s
.88 .745 .709 r
.2741 .28546 m .26052 .27397 L .27244 .2524 L p F P
0 g
s
.847 .742 .747 r
.25881 .34348 m .26049 .34114 L .25223 .33515 L closepath p F P
0 g
s
.851 .74 .74 r
.24697 .32838 m .26048 .30765 L p .26049 .34114 L F P
0 g
s
.851 .74 .74 r
.26049 .34114 m .25223 .33515 L .24697 .32838 L p F P
0 g
s
.797 .737 .798 r
.23276 .36811 m .25881 .34348 L .25223 .33515 L p F P
0 g
s
.764 .932 .577 r
.79778 .2793 m .79488 .28479 L .77971 .30788 L p F P
0 g
s
.811 .755 .801 r
.23276 .36811 m .21923 .38083 L .20706 .368 L p F P
0 g
s
.811 .755 .801 r
.20706 .368 m .21779 .35743 L .23276 .36811 L p F P
0 g
s
.797 .737 .798 r
.24475 .33064 m .21779 .35743 L .23276 .36811 L p F P
0 g
s
.797 .737 .798 r
.25223 .33515 m .24475 .33064 L p .23276 .36811 L F P
0 g
s
.739 .755 .866 r
.16841 .39105 m .20706 .368 L .21923 .38083 L p F P
0 g
s
0 0 .215 r
.82335 .19717 m .82493 .19038 L .8247 .17254 L p F P
0 g
s
0 0 .16 r
.82732 .15602 m .8247 .17254 L .82493 .19038 L p F P
0 g
s
.468 .426 .728 r
.53893 .29181 m .51466 .28388 L .53167 .26782 L closepath p F P
0 g
s
.479 .383 .668 r
.52813 .25506 m .53167 .26782 L .51466 .28388 L p F P
0 g
s
.479 .383 .668 r
.5194 .24885 m .52813 .25506 L p .51466 .28388 L F P
0 g
s
.61 .744 .94 r
.11859 .38865 m .15586 .37948 L .16841 .39105 L p F P
0 g
s
.63 .788 .957 r
.67218 .37991 m .63172 .39435 L .62163 .38152 L p F P
0 g
s
.138 .112 .564 r
.51727 .2042 m .51511 .19907 L .51614 .19706 L closepath p F P
0 g
s
0 0 0 r
.8222 .21113 m .81724 .22627 L .81143 .24629 L p F P
0 g
s
0 0 .07 r
.81724 .22627 m .8222 .21113 L .82335 .19717 L p F P
0 g
s
0 0 .022 r
.82493 .19038 m .82335 .19717 L .8222 .21113 L p F P
0 g
s
.17 .135 .573 r
.51614 .19706 m .52218 .18046 L p .52183 .21439 L F P
0 g
s
.17 .135 .573 r
.52183 .21439 m .51727 .2042 L .51614 .19706 L p F P
0 g
s
0 0 .38 r
.51614 .19706 m .52218 .18046 L .52019 .16364 L p F P
0 g
s
.745 .769 .873 r
.20706 .368 m .16841 .39105 L .15586 .37948 L p F P
0 g
s
.788 .981 .904 r
.72196 .36374 m .7242 .36205 L .72288 .36394 L closepath p F P
0 g
s
.821 .995 .859 r
.75893 .3328 m .7242 .36205 L .72288 .36394 L p F P
0 g
s
.865 .994 .755 r
.77971 .30788 m .78901 .2901 L p .76064 .33034 L F P
0 g
s
.865 .994 .755 r
.76064 .33034 m .76175 .33008 L .77971 .30788 L p F P
0 g
s
.764 .932 .577 r
.79249 .28509 m .79778 .2793 L p .77971 .30788 L F P
0 g
s
.764 .932 .577 r
.77971 .30788 m .78901 .2901 L .79249 .28509 L p F P
0 g
s
.87 .756 .734 r
.26048 .30765 m .24697 .32838 L .23489 .31528 L p F P
0 g
s
.87 .756 .734 r
.23489 .31528 m .24717 .29611 L .26048 .30765 L p F P
0 g
s
.876 .753 .724 r
.26048 .30765 m .24717 .29611 L .26052 .27397 L p F P
0 g
s
.805 .736 .788 r
.25223 .33515 m .24697 .32838 L .24475 .33064 L closepath p F P
0 g
s
.804 .913 .519 r
.79249 .28509 m .80237 .26746 L .79778 .2793 L closepath p F P
0 g
s
.725 .807 .336 r
.81143 .24629 m .80237 .26746 L .79778 .2793 L p F P
0 g
s
.576 .659 .893 r
.5709 .37094 m .61137 .36603 L .62163 .38152 L p F P
0 g
s
.548 .562 .82 r
.60097 .34803 m .61137 .36603 L .5709 .37094 L p F P
0 g
s
.548 .562 .82 r
.57817 .34841 m .60097 .34803 L p .5709 .37094 L F P
0 g
s
.548 .562 .82 r
.5709 .37094 m .56562 .35984 L .57817 .34841 L p F P
0 g
s
.157 .128 .573 r
.51958 .21855 m .51727 .2042 L .52183 .21439 L closepath p F P
0 g
s
.786 .947 .927 r
.7242 .36205 m .72196 .36374 L .71278 .35958 L p F P
0 g
s
.699 .931 .966 r
.67218 .37991 m .71278 .35958 L .72196 .36374 L p F P
0 g
s
.786 .947 .927 r
.71278 .35958 m .73517 .34403 L .7242 .36205 L p F P
0 g
s
.801 .972 .907 r
.76064 .33034 m .75893 .3328 L .7242 .36205 L p F P
0 g
s
.801 .972 .907 r
.75314 .33022 m .76064 .33034 L p .7242 .36205 L F P
0 g
s
.801 .972 .907 r
.7242 .36205 m .73517 .34403 L .75314 .33022 L p F P
0 g
s
.777 .995 .787 r
.75893 .3328 m .76064 .33034 L .76175 .33008 L closepath p F P
0 g
s
.382 .345 .693 r
.52813 .25506 m .5194 .24885 L .5248 .24221 L closepath p F P
0 g
s
.35 .3 .661 r
.5194 .24885 m .5248 .24221 L .51958 .21855 L p F P
0 g
s
.546 .558 .818 r
.56562 .35984 m .56034 .34857 L .57817 .34841 L closepath p F P
0 g
s
0 0 .138 r
.52032 .14712 m .52019 .16364 L .52218 .18046 L p F P
0 g
s
.819 .765 .801 r
.24475 .33064 m .24697 .32838 L .23489 .31528 L p F P
0 g
s
.822 .772 .805 r
.23098 .31931 m .24475 .33064 L .21779 .35743 L p F P
0 g
s
.819 .765 .801 r
.23489 .31528 m .23098 .31931 L .24475 .33064 L p F P
0 g
s
.232 .22 .639 r
.52183 .21439 m .51958 .21855 L .5248 .24221 L p F P
0 g
s
.845 .997 .83 r
.75314 .33022 m .76791 .31524 L .76064 .33034 L closepath p F P
0 g
s
.865 .994 .755 r
.78901 .2901 m .76791 .31524 L .76064 .33034 L p F P
0 g
s
0 0 .022 r
.8222 .21113 m .82264 .2092 L .82493 .19038 L p F P
0 g
s
0 0 0 r
.82756 .17392 m .82493 .19038 L .82264 .2092 L p F P
0 g
s
0 0 .16 r
.82493 .19038 m .82756 .17392 L .82732 .15602 L p F P
0 g
s
0 0 0 r
.8215 .21389 m .8222 .21113 L p .81143 .24629 L F P
0 g
s
0 0 0 r
.81143 .24629 m .81697 .22925 L .8215 .21389 L p F P
0 g
s
.782 .851 .4 r
.81697 .22925 m .81143 .24629 L .80237 .26746 L p F P
0 g
s
.821 .772 .807 r
.21779 .35743 m .20706 .368 L .1947 .35588 L p F P
0 g
s
.821 .772 .807 r
.1947 .35588 m .20458 .346 L .21779 .35743 L p F P
0 g
s
.822 .772 .805 r
.21779 .35743 m .20458 .346 L .23098 .31931 L p F P
0 g
s
.745 .769 .873 r
.15586 .37948 m .1947 .35588 L .20706 .368 L p F P
0 g
s
.55 .531 .787 r
.57817 .34841 m .56034 .34857 L .55078 .32523 L p F P
0 g
s
.63 .788 .957 r
.62163 .38152 m .66238 .37018 L .67218 .37991 L p F P
0 g
s
.596 .73 .937 r
.66238 .37018 m .62163 .38152 L .61137 .36603 L p F P
0 g
s
.682 .877 .971 r
.71278 .35958 m .67218 .37991 L .66238 .37018 L p F P
0 g
s
.232 .22 .639 r
.5248 .24221 m .53218 .2287 L .52183 .21439 L p F P
0 g
s
.005 .082 .593 r
.52762 .19627 m .52183 .21439 L .53218 .2287 L p F P
0 g
s
.17 .135 .573 r
.52218 .18046 m .52762 .19627 L .52183 .21439 L p F P
0 g
s
.375 .34 .692 r
.5248 .24221 m .53218 .2287 L p .53637 .26112 L F P
0 g
s
.375 .34 .692 r
.53637 .26112 m .52813 .25506 L .5248 .24221 L p F P
0 g
s
.55 .531 .787 r
.55078 .32523 m .55301 .32295 L p .57817 .34841 L F P
0 g
s
.5 .497 .785 r
.55078 .32523 m .54968 .32246 L .55301 .32295 L closepath p F P
0 g
s
.358 .341 .703 r
.53167 .26782 m .52813 .25506 L .53637 .26112 L closepath p F P
0 g
s
.509 .478 .758 r
.55301 .32295 m .54968 .32246 L .54008 .29522 L p F P
0 g
s
0 0 .099 r
.82873 .13969 m .82732 .15602 L .82756 .17392 L p F P
0 g
s
.455 .418 .728 r
.53167 .26782 m .53637 .26112 L p .54199 .29296 L F P
0 g
s
.455 .418 .728 r
.54199 .29296 m .53893 .29181 L .53167 .26782 L p F P
0 g
s
.887 .954 .607 r
.80237 .26746 m .80773 .25058 L p .79076 .28628 L F P
0 g
s
.887 .954 .607 r
.79076 .28628 m .79249 .28509 L .80237 .26746 L p F P
0 g
s
.782 .851 .4 r
.80237 .26746 m .80773 .25058 L .81697 .22925 L p F P
0 g
s
.701 .708 .18 r
.8215 .21389 m .82264 .2092 L .8222 .21113 L closepath p F P
0 g
s
.509 .478 .758 r
.54008 .29522 m .54199 .29296 L p .55301 .32295 L F P
0 g
s
.441 .428 .748 r
.54008 .29522 m .53893 .29181 L .54199 .29296 L closepath p F P
0 g
s
.55 .531 .787 r
.55301 .32295 m .59042 .32765 L p .57817 .34841 L F P
0 g
s
.456 .456 .769 r
.55301 .32295 m .59042 .32765 L .57976 .30487 L p F P
0 g
s
.456 .456 .769 r
.57976 .30487 m .57016 .30206 L .55301 .32295 L p F P
0 g
s
.509 .478 .758 r
.54199 .29296 m .57016 .30206 L .55301 .32295 L p F P
0 g
s
0 0 0 r
.82264 .2092 m .82527 .19281 L .82756 .17392 L p F P
0 g
s
.801 .773 .266 r
.82264 .2092 m .82527 .19281 L p .8188 .2222 L F P
0 g
s
.801 .773 .266 r
.8188 .2222 m .8215 .21389 L .82264 .2092 L p F P
0 g
s
.418 .467 .804 r
.55561 .2729 m .54199 .29296 L .57016 .30206 L p F P
0 g
s
.455 .418 .728 r
.53637 .26112 m .55561 .2729 L .54199 .29296 L p F P
0 g
s
0 0 .331 r
.52198 .1641 m .52218 .18046 L .52762 .19627 L p F P
0 g
s
0 0 .331 r
.52652 .18026 m .52198 .1641 L p .52381 .17454 L F P
0 g
s
0 0 .331 r
.52762 .19627 m .52652 .18026 L p .52381 .17454 L F P
0 g
s
.654 .3 0 r
.52652 .18026 m .53338 .19581 L p .52926 .18604 L F P
0 g
s
.81 .493 0 r
.52198 .1641 m .52652 .18026 L p .52299 .16921 L F P
0 g
s
0 0 .138 r
.52218 .18046 m .52198 .1641 L p .52098 .15904 L F P
0 g
s
.81 .493 0 r
.52652 .18026 m .52065 .16566 L .51664 .14929 L p F P
0 g
s
.654 .3 0 r
.52065 .16566 m .52652 .18026 L p .52926 .18604 L F P
0 g
s
.81 .493 0 r
.51664 .14929 m .52198 .1641 L p .52299 .16921 L F P
0 g
s
0 0 .138 r
.52198 .1641 m .52032 .14712 L p .52098 .15904 L F P
0 g
s
.543 .582 .844 r
.60097 .34803 m .57817 .34841 L .59253 .33175 L closepath p F P
0 g
s
.55 .531 .787 r
.59042 .32765 m .59253 .33175 L .57817 .34841 L p F P
0 g
s
.723 .748 .237 r
.81697 .22925 m .8188 .2222 L .8215 .21389 L closepath p F P
0 g
s
.813 .958 .626 r
.78901 .2901 m .79076 .28628 L .79249 .28509 L closepath p F P
0 g
s
.753 .952 .941 r
.73517 .34403 m .71278 .35958 L .70334 .35298 L p F P
0 g
s
.682 .877 .971 r
.66238 .37018 m .70334 .35298 L .71278 .35958 L p F P
0 g
s
.858 .997 .798 r
.79076 .28628 m .78901 .2901 L .76791 .31524 L p F P
0 g
s
.596 .73 .937 r
.61137 .36603 m .65238 .35814 L .66238 .37018 L p F P
0 g
s
.556 .677 .919 r
.65238 .35814 m .61137 .36603 L .60097 .34803 L p F P
0 g
s
.298 .376 .775 r
.54508 .24237 m .53637 .26112 L .55561 .2729 L p F P
0 g
s
.375 .34 .692 r
.53218 .2287 m .54508 .24237 L .53637 .26112 L p F P
0 g
s
.913 .644 .149 r
.51517 .13222 m .52032 .14712 L .52198 .1641 L p F P
0 g
s
.753 .952 .941 r
.74531 .32785 m .73517 .34403 L p .70334 .35298 L F P
0 g
s
.799 .974 .906 r
.73517 .34403 m .74531 .32785 L .75314 .33022 L closepath p F P
0 g
s
.87 .969 .855 r
.76791 .31524 m .77544 .29789 L p .74531 .32785 L F P
0 g
s
.87 .969 .855 r
.74531 .32785 m .75314 .33022 L .76791 .31524 L p F P
0 g
s
.858 .997 .798 r
.78431 .28801 m .79076 .28628 L p .76791 .31524 L F P
0 g
s
.858 .997 .798 r
.76791 .31524 m .77544 .29789 L .78431 .28801 L p F P
0 g
s
0 0 .099 r
.82756 .17392 m .82898 .15765 L .82873 .13969 L p F P
0 g
s
.745 .671 .12 r
.82898 .15765 m .82756 .17392 L .82527 .19281 L p F P
0 g
s
.892 .985 .717 r
.78431 .28801 m .79475 .27319 L .79076 .28628 L closepath p F P
0 g
s
.887 .954 .607 r
.80773 .25058 m .79475 .27319 L .79076 .28628 L p F P
0 g
s
.653 .822 .965 r
.70334 .35298 m .66238 .37018 L .65238 .35814 L p F P
0 g
s
.849 .898 .48 r
.8188 .2222 m .81697 .22925 L .80773 .25058 L p F P
0 g
s
0 .126 .645 r
.53582 .21134 m .53218 .2287 L .54508 .24237 L p F P
0 g
s
.005 .082 .593 r
.53218 .2287 m .53582 .21134 L .52762 .19627 L p F P
0 g
s
.556 .677 .919 r
.60097 .34803 m .6422 .34405 L .65238 .35814 L p F P
0 g
s
.532 .576 .845 r
.63187 .32821 m .6422 .34405 L .60097 .34803 L p F P
0 g
s
.532 .576 .845 r
.59562 .32774 m .63187 .32821 L p .60097 .34803 L F P
0 g
s
.532 .576 .845 r
.60097 .34803 m .59253 .33175 L .59562 .32774 L p F P
0 g
s
0 0 .444 r
.52652 .18026 m .52762 .19627 L .53582 .21134 L p F P
0 g
s
0 0 .034 r
.82895 .12354 m .82873 .13969 L .82898 .15765 L p F P
0 g
s
.905 .965 .645 r
.81201 .23381 m .80773 .25058 L .79475 .27319 L p F P
0 g
s
.849 .898 .48 r
.81456 .22817 m .8188 .2222 L p .80773 .25058 L F P
0 g
s
.849 .898 .48 r
.80773 .25058 m .81201 .23381 L .81456 .22817 L p F P
0 g
s
.88 .881 .447 r
.81456 .22817 m .8203 .21271 L .8188 .2222 L closepath p F P
0 g
s
.801 .773 .266 r
.82527 .19281 m .8203 .21271 L .8188 .2222 L p F P
0 g
s
.863 .814 .331 r
.82666 .1766 m .82527 .19281 L .8203 .21271 L p F P
0 g
s
.745 .671 .12 r
.82527 .19281 m .82666 .1766 L .82898 .15765 L p F P
0 g
s
.913 .644 .149 r
.52198 .1641 m .51664 .14929 L .51517 .13222 L p F P
0 g
s
.753 .952 .941 r
.70334 .35298 m .7442 .32738 L .74531 .32785 L p F P
0 g
s
.734 .914 .955 r
.7442 .32738 m .70334 .35298 L .69368 .34422 L p F P
0 g
s
.653 .822 .965 r
.65238 .35814 m .69368 .34422 L .70334 .35298 L p F P
0 g
s
.528 .571 .842 r
.59253 .33175 m .59042 .32765 L .59562 .32774 L closepath p F P
0 g
s
.617 .771 .954 r
.69368 .34422 m .65238 .35814 L .6422 .34405 L p F P
0 g
s
.973 .663 .306 r
.50605 .11851 m .51517 .13222 L .51664 .14929 L p F P
0 g
s
.428 .479 .81 r
.57976 .30487 m .57016 .30206 L .57459 .29314 L closepath p F P
0 g
s
.418 .467 .804 r
.56901 .28013 m .55561 .2729 L p .57016 .30206 L F P
0 g
s
.418 .467 .804 r
.57016 .30206 m .57459 .29314 L .56901 .28013 L p F P
0 g
s
.534 .553 .821 r
.59562 .32774 m .59042 .32765 L .57976 .30487 L p F P
0 g
s
.923 .974 .757 r
.79475 .27319 m .79864 .25665 L p .77935 .28784 L F P
0 g
s
.923 .974 .757 r
.77935 .28784 m .78431 .28801 L .79475 .27319 L p F P
0 g
s
.905 .965 .645 r
.79475 .27319 m .79864 .25665 L .81201 .23381 L p F P
0 g
s
.322 .402 .789 r
.56901 .28013 m .55561 .2729 L .55977 .258 L closepath p F P
0 g
s
.298 .376 .775 r
.55819 .25404 m .54508 .24237 L p .55561 .2729 L F P
0 g
s
.298 .376 .775 r
.55561 .2729 m .55977 .258 L .55819 .25404 L p F P
0 g
s
0 0 .034 r
.82898 .15765 m .8292 .14154 L .82895 .12354 L p F P
0 g
s
.822 .72 .189 r
.8292 .14154 m .82898 .15765 L .82666 .1766 L p F P
0 g
s
.834 .957 .893 r
.7442 .32738 m .74609 .32578 L .74531 .32785 L closepath p F P
0 g
s
.87 .969 .855 r
.77544 .29789 m .74609 .32578 L .74531 .32785 L p F P
0 g
s
.48 .532 .834 r
.59562 .32774 m .63187 .32821 L .6214 .31098 L p F P
0 g
s
.48 .532 .834 r
.6214 .31098 m .60651 .30887 L .59562 .32774 L p F P
0 g
s
.534 .553 .821 r
.57976 .30487 m .60651 .30887 L .59562 .32774 L p F P
0 g
s
.053 .187 .686 r
.54508 .24237 m .55819 .25404 L .54732 .2273 L p F P
0 g
s
.053 .187 .686 r
.54732 .2273 m .54615 .22591 L .54508 .24237 L p F P
0 g
s
0 .126 .645 r
.54508 .24237 m .54615 .22591 L .53582 .21134 L p F P
0 g
s
.868 .994 .809 r
.77544 .29789 m .77935 .28784 L .78431 .28801 L closepath p F P
0 g
s
.937 .905 .514 r
.8203 .21271 m .82164 .19659 L p .81274 .22988 L F P
0 g
s
.937 .905 .514 r
.81274 .22988 m .81456 .22817 L .8203 .21271 L p F P
0 g
s
.863 .814 .331 r
.8203 .21271 m .82164 .19659 L .82666 .1766 L p F P
0 g
s
.847 .949 .884 r
.77935 .28784 m .77544 .29789 L .74609 .32578 L p F P
0 g
s
.822 .926 .903 r
.74609 .32578 m .7442 .32738 L .73496 .3217 L p F P
0 g
s
.734 .914 .955 r
.69368 .34422 m .73496 .3217 L .7442 .32738 L p F P
0 g
s
.822 .926 .903 r
.73496 .3217 m .75072 .30925 L .74609 .32578 L p F P
0 g
s
.847 .949 .884 r
.7757 .28698 m .77935 .28784 L p .74609 .32578 L F P
0 g
s
.847 .949 .884 r
.74609 .32578 m .75072 .30925 L .7757 .28698 L p F P
0 g
s
0 .054 .617 r
.53338 .19581 m .53582 .21134 L .54615 .22591 L p F P
0 g
s
0 0 .444 r
.53338 .19581 m .52652 .18026 L p .52938 .18983 L F P
0 g
s
.654 .3 0 r
.52548 .17815 m .52065 .16566 L p .52715 .18106 L F P
0 g
s
.654 .3 0 r
.53338 .19581 m .52548 .17815 L .52715 .18106 L F
.848 .448 0 r
.52065 .16566 m .52548 .17815 L .51451 .16097 L p F P
0 g
s
0 0 .415 r
.52548 .17815 m .51451 .16097 L p .52478 .17693 L F P
0 g
s
0 0 .415 r
.52754 .18122 m .52548 .17815 L p .52478 .17693 L F P
0 g
s
.654 .3 0 r
.53338 .19581 m .52902 .18609 L .52548 .17815 L p F P
0 g
s
0 0 .425 r
.53338 .19581 m .52902 .18609 L .53504 .19829 L p F P
0 g
s
0 0 .425 r
.53504 .19829 m .53641 .20107 L .53338 .19581 L p F P
0 g
s
0 0 .444 r
.53582 .21134 m .53338 .19581 L p .52938 .18983 L F P
0 g
s
.487 .513 .81 r
.60651 .30887 m .57976 .30487 L .57459 .29314 L p F P
0 g
s
.759 .602 .032 r
.82847 .11563 m .82895 .12354 L .8292 .14154 L p F P
0 g
s
.418 .467 .804 r
.57459 .29314 m .56901 .28013 L .57941 .28346 L closepath p F P
0 g
s
.487 .513 .81 r
.57459 .29314 m .57941 .28346 L p .60651 .30887 L F P
0 g
s
.897 .921 .531 r
.81201 .23381 m .81274 .22988 L .81456 .22817 L closepath p F P
0 g
s
.925 .561 .135 r
.50741 .13564 m .51664 .14929 L .52065 .16566 L p F P
0 g
s
.973 .663 .306 r
.51664 .14929 m .50741 .13564 L .50605 .11851 L p F P
0 g
s
.617 .771 .954 r
.6422 .34405 m .68381 .33359 L .69368 .34422 L p F P
0 g
s
.577 .726 .944 r
.68381 .33359 m .6422 .34405 L .63187 .32821 L p F P
0 g
s
.926 .971 .694 r
.81274 .22988 m .81201 .23381 L .79864 .25665 L p F P
0 g
s
.917 .843 .392 r
.82686 .16057 m .82666 .1766 L .82164 .19659 L p F P
0 g
s
.822 .72 .189 r
.82666 .1766 m .82686 .16057 L .8292 .14154 L p F P
0 g
s
.423 .463 .797 r
.57941 .28346 m .56901 .28013 L .55977 .258 L p F P
0 g
s
.708 .87 .958 r
.73496 .3217 m .69368 .34422 L .68381 .33359 L p F P
0 g
s
.897 .973 .817 r
.7757 .28698 m .7808 .28099 L .77935 .28784 L closepath p F P
0 g
s
.923 .974 .757 r
.79864 .25665 m .7808 .28099 L .77935 .28784 L p F P
0 g
s
.949 .947 .633 r
.80659 .23194 m .81368 .21766 L .81274 .22988 L closepath p F P
0 g
s
.937 .905 .514 r
.82164 .19659 m .81368 .21766 L .81274 .22988 L p F P
0 g
s
.926 .971 .694 r
.80659 .23194 m .81274 .22988 L p .79864 .25665 L F P
0 g
s
.808 .627 .07 r
.82754 .10772 m .82847 .11563 L .82857 .13119 L p F P
0 g
s
.759 .602 .032 r
.8292 .14154 m .82857 .13119 L .82847 .11563 L p F P
0 g
s
.423 .463 .797 r
.55977 .258 m .56066 .25539 L p .57941 .28346 L F P
0 g
s
.33 .396 .779 r
.55977 .258 m .55819 .25404 L .56066 .25539 L closepath p F P
0 g
s
.325 .397 .783 r
.56066 .25539 m .55819 .25404 L .54732 .2273 L p F P
0 g
s
.919 .968 .784 r
.80151 .2402 m .79864 .25665 L .7808 .28099 L p F P
0 g
s
.926 .971 .694 r
.79864 .25665 m .80151 .2402 L .80659 .23194 L p F P
0 g
s
.887 .759 .257 r
.82857 .13119 m .8292 .14154 L .82686 .16057 L p F P
0 g
s
.423 .463 .797 r
.56066 .25539 m .58334 .26633 L .57941 .28346 L p F P
0 g
s
.179 .359 .806 r
.56303 .23851 m .56066 .25539 L .58334 .26633 L p F P
0 g
s
.325 .397 .783 r
.54732 .2273 m .56303 .23851 L .56066 .25539 L p F P
0 g
s
.487 .513 .81 r
.57941 .28346 m .60929 .29235 L .60651 .30887 L p F P
0 g
s
.363 .507 .868 r
.58334 .26633 m .57941 .28346 L .60929 .29235 L p F P
0 g
s
0 .132 .674 r
.54732 .2273 m .54615 .22591 L .54571 .22366 L closepath p F P
0 g
s
0 .054 .617 r
.53641 .20107 m .53338 .19581 L p .54615 .22591 L F P
0 g
s
0 .054 .617 r
.54615 .22591 m .54571 .22366 L .53641 .20107 L p F P
0 g
s
.959 .913 .552 r
.82177 .18064 m .82164 .19659 L .81368 .21766 L p F P
0 g
s
.917 .843 .392 r
.82164 .19659 m .82177 .18064 L .82686 .16057 L p F P
0 g
s
.199 .337 .779 r
.56303 .23851 m .54732 .2273 L .54571 .22366 L p F P
0 g
s
.805 .905 .911 r
.75072 .30925 m .73496 .3217 L .72548 .31414 L p F P
0 g
s
.708 .87 .958 r
.68381 .33359 m .72548 .31414 L .73496 .3217 L p F P
0 g
s
.577 .726 .944 r
.63187 .32821 m .67377 .32138 L .68381 .33359 L p F P
0 g
s
.533 .684 .936 r
.67377 .32138 m .63187 .32821 L .6214 .31098 L p F P
0 g
s
.892 .954 .836 r
.7808 .28099 m .7757 .28698 L .76674 .28294 L p F P
0 g
s
.892 .954 .836 r
.76674 .28294 m .78293 .26489 L .7808 .28099 L p F P
0 g
s
.919 .968 .784 r
.7808 .28099 m .78293 .26489 L .80151 .2402 L p F P
0 g
s
.199 .337 .779 r
.54571 .22366 m .5451 .20993 L p .56303 .23851 L F P
0 g
s
.046 .218 .718 r
.54571 .22366 m .53641 .20107 L .5451 .20993 L closepath p F P
0 g
s
.805 .905 .911 r
.72548 .31414 m .75491 .29263 L .75072 .30925 L p F P
0 g
s
.845 .958 .884 r
.76674 .28294 m .75491 .29263 L .75072 .30925 L p F P
0 g
s
.845 .958 .884 r
.75072 .30925 m .7757 .28698 L .76674 .28294 L p F P
0 g
s
.395 .505 .853 r
.60651 .30887 m .6214 .31098 L .61082 .29278 L p F P
0 g
s
.395 .505 .853 r
.61082 .29278 m .60929 .29235 L .60651 .30887 L p F P
0 g
s
.848 .448 0 r
.51451 .16097 m .51124 .15208 L .52065 .16566 L p F P
0 g
s
.925 .561 .135 r
.52065 .16566 m .51124 .15208 L .50741 .13564 L p F P
0 g
s
.871 .663 .134 r
.82451 .09223 m .82754 .10772 L .82792 .12573 L p F P
0 g
s
.808 .627 .07 r
.82857 .13119 m .82792 .12573 L .82754 .10772 L p F P
0 g
s
0 .179 .71 r
.5451 .20993 m .53641 .20107 L .52902 .18609 L p F P
0 g
s
.678 .829 .956 r
.72548 .31414 m .68381 .33359 L .67377 .32138 L p F P
0 g
s
.955 .859 .442 r
.82587 .14471 m .82686 .16057 L .82177 .18064 L p F P
0 g
s
.887 .759 .257 r
.82649 .13981 m .82857 .13119 L p .82686 .16057 L F P
0 g
s
.887 .759 .257 r
.82686 .16057 m .82587 .14471 L .82649 .13981 L p F P
0 g
s
.967 .937 .667 r
.81368 .21766 m .81369 .20183 L p .80238 .23203 L F P
0 g
s
.967 .937 .667 r
.80238 .23203 m .80659 .23194 L .81368 .21766 L p F P
0 g
s
.959 .913 .552 r
.81368 .21766 m .81369 .20183 L .82177 .18064 L p F P
0 g
s
.909 .756 .263 r
.82649 .13981 m .82792 .12573 L .82857 .13119 L closepath p F P
0 g
s
0 .179 .71 r
.52902 .18609 m .52754 .18122 L p .5451 .20993 L F P
0 g
s
0 0 .562 r
.52902 .18609 m .52548 .17815 L .52754 .18122 L closepath p F P
0 g
s
.484 .646 .929 r
.66357 .30793 m .6214 .31098 L .61082 .29278 L p F P
0 g
s
.533 .684 .936 r
.6214 .31098 m .66357 .30793 L .67377 .32138 L p F P
0 g
s
.94 .965 .714 r
.80151 .2402 m .80238 .23203 L .80659 .23194 L closepath p F P
0 g
s
.951 .775 .32 r
.82792 .12573 m .82488 .11029 L p .82555 .14248 L F P
0 g
s
.951 .775 .32 r
.82555 .14248 m .82649 .13981 L .82792 .12573 L p F P
0 g
s
.871 .663 .134 r
.82792 .12573 m .82488 .11029 L .82451 .09223 L p F P
0 g
s
.916 .954 .803 r
.80238 .23203 m .80151 .2402 L .78293 .26489 L p F P
0 g
s
0 .179 .71 r
.52754 .18122 m .5398 .19517 L .5451 .20993 L p F P
0 g
s
0 0 .535 r
.51872 .16746 m .52754 .18122 L .5398 .19517 L p F P
0 g
s
0 0 .415 r
.51451 .16097 m .51872 .16746 L .52754 .18122 L p F P
0 g
s
.199 .337 .779 r
.5451 .20993 m .56025 .22313 L .56303 .23851 L p F P
0 g
s
0 .154 .696 r
.5398 .19517 m .5451 .20993 L .56025 .22313 L p F P
0 g
s
.179 .359 .806 r
.58334 .26633 m .5819 .25073 L .56303 .23851 L p F P
0 g
s
.001 .275 .776 r
.56025 .22313 m .56303 .23851 L .5819 .25073 L p F P
0 g
s
.977 .911 .586 r
.8207 .16487 m .82177 .18064 L .81369 .20183 L p F P
0 g
s
.955 .859 .442 r
.82177 .18064 m .8207 .16487 L .82587 .14471 L p F P
0 g
s
.785 .91 .926 r
.75491 .29263 m .72548 .31414 L .7158 .30497 L p F P
0 g
s
.678 .829 .956 r
.67377 .32138 m .7158 .30497 L .72548 .31414 L p F P
0 g
s
.363 .507 .868 r
.60015 .2739 m .58334 .26633 L p .60929 .29235 L F P
0 g
s
.204 .38 .817 r
.58334 .26633 m .60015 .2739 L .58939 .25519 L p F P
0 g
s
.204 .38 .817 r
.58939 .25519 m .5819 .25073 L .58334 .26633 L p F P
0 g
s
.919 .688 .194 r
.82028 .07694 m .82451 .09223 L .82488 .11029 L p F P
0 g
s
.89 .919 .836 r
.78293 .26489 m .78403 .2489 L p .75854 .27766 L F P
0 g
s
.89 .919 .836 r
.75854 .27766 m .76674 .28294 L .78293 .26489 L p F P
0 g
s
.916 .954 .803 r
.7981 .23097 m .80238 .23203 L p .78293 .26489 L F P
0 g
s
.916 .954 .803 r
.78293 .26489 m .78403 .2489 L .7981 .23097 L p F P
0 g
s
.647 .793 .952 r
.7158 .30497 m .67377 .32138 L .66357 .30793 L p F P
0 g
s
.785 .91 .926 r
.75854 .27766 m .75491 .29263 L p .7158 .30497 L F P
0 g
s
.829 .927 .897 r
.75491 .29263 m .75854 .27766 L .76674 .28294 L closepath p F P
0 g
s
.373 .517 .872 r
.61082 .29278 m .60929 .29235 L .60926 .29004 L closepath p F P
0 g
s
.363 .507 .868 r
.60929 .29235 m .60926 .29004 L .60015 .2739 L p F P
0 g
s
.936 .783 .316 r
.82587 .14471 m .82555 .14248 L .82649 .13981 L closepath p F P
0 g
s
.484 .646 .929 r
.61082 .29278 m .65323 .29359 L .66357 .30793 L p F P
0 g
s
.473 .573 .875 r
.64277 .27871 m .65323 .29359 L .61082 .29278 L p F P
0 g
s
.473 .573 .875 r
.61284 .27535 m .64277 .27871 L p .61082 .29278 L F P
0 g
s
.473 .573 .875 r
.61082 .29278 m .60926 .29004 L .61284 .27535 L p F P
0 g
s
.467 .566 .872 r
.60926 .29004 m .60015 .2739 L .61284 .27535 L closepath p F P
0 g
s
.949 .947 .738 r
.7981 .23097 m .80229 .22421 L .80238 .23203 L closepath p F P
0 g
s
.967 .937 .667 r
.81369 .20183 m .80229 .22421 L .80238 .23203 L p F P
0 g
s
.981 .867 .492 r
.82555 .14248 m .82587 .14471 L .8207 .16487 L p F P
0 g
s
.968 .929 .689 r
.81248 .18618 m .81369 .20183 L .80229 .22421 L p F P
0 g
s
.977 .911 .586 r
.81369 .20183 m .81248 .18618 L .8207 .16487 L p F P
0 g
s
.986 .845 .466 r
.81892 .14744 m .82292 .12929 L .82555 .14248 L closepath p F P
0 g
s
.951 .775 .32 r
.82488 .11029 m .82292 .12929 L .82555 .14248 L p F P
0 g
s
.981 .867 .492 r
.81892 .14744 m .82555 .14248 L p .8207 .16487 L F P
0 g
s
.977 .783 .365 r
.82064 .09504 m .82488 .11029 L .82292 .12929 L p F P
0 g
s
.919 .688 .194 r
.82488 .11029 m .82064 .09504 L .82028 .07694 L p F P
0 g
s
0 0 .535 r
.5398 .19517 m .5306 .18153 L .51872 .16746 L p F P
0 g
s
.464 .57 .877 r
.61284 .27535 m .60015 .2739 L .58939 .25519 L p F P
0 g
s
.945 .93 .755 r
.80229 .22421 m .7981 .23097 L .78924 .22684 L p F P
0 g
s
.945 .93 .755 r
.78924 .22684 m .80086 .20871 L .80229 .22421 L p F P
0 g
s
.968 .929 .689 r
.80229 .22421 m .80086 .20871 L .81248 .18618 L p F P
0 g
s
0 .154 .696 r
.56025 .22313 m .55371 .20879 L .5398 .19517 L p F P
0 g
s
0 .067 .608 r
.5306 .18153 m .5398 .19517 L .55371 .20879 L p F P
0 g
s
.785 .91 .926 r
.7158 .30497 m .75753 .27693 L .75854 .27766 L p F P
0 g
s
.764 .88 .93 r
.75753 .27693 m .7158 .30497 L .70593 .29447 L p F P
0 g
s
.647 .793 .952 r
.66357 .30793 m .70593 .29447 L .7158 .30497 L p F P
0 g
s
.615 .762 .949 r
.70593 .29447 m .66357 .30793 L .65323 .29359 L p F P
0 g
s
.001 .275 .776 r
.5819 .25073 m .57679 .23612 L .56025 .22313 L p F P
0 g
s
0 .245 .759 r
.55371 .20879 m .56025 .22313 L .57679 .23612 L p F P
0 g
s
.985 .903 .612 r
.81843 .14929 m .8207 .16487 L .81248 .18618 L p F P
0 g
s
.981 .867 .492 r
.8207 .16487 m .81843 .14929 L .81892 .14744 L p F P
0 g
s
.916 .946 .805 r
.78403 .2489 m .7981 .23097 L .78924 .22684 L p F P
0 g
s
.952 .703 .247 r
.81486 .06185 m .82028 .07694 L .82064 .09504 L p F P
0 g
s
.04 .308 .796 r
.5819 .25073 m .58939 .25519 L .57857 .2374 L p F P
0 g
s
.04 .308 .796 r
.57857 .2374 m .57679 .23612 L .5819 .25073 L p F P
0 g
s
.89 .919 .836 r
.78403 .2489 m .75856 .27595 L .75854 .27766 L p F P
0 g
s
.872 .904 .851 r
.78413 .233 m .78403 .2489 L .75856 .27595 L p F P
0 g
s
.916 .946 .805 r
.78924 .22684 m .78413 .233 L .78403 .2489 L p F P
0 g
s
.858 .911 .868 r
.75753 .27693 m .75856 .27595 L .75854 .27766 L closepath p F P
0 g
s
.845 .889 .871 r
.75856 .27595 m .75753 .27693 L .74805 .2689 L p F P
0 g
s
.845 .889 .871 r
.74805 .2689 m .75722 .26063 L .75856 .27595 L p F P
0 g
s
.872 .904 .851 r
.75856 .27595 m .75722 .26063 L .78413 .233 L p F P
0 g
s
.764 .88 .93 r
.70593 .29447 m .74805 .2689 L .75753 .27693 L p F P
0 g
s
.403 .553 .89 r
.61284 .27535 m .64277 .27871 L .6322 .26368 L p F P
0 g
s
.403 .553 .89 r
.6322 .26368 m .61166 .25965 L .61284 .27535 L p F P
0 g
s
.464 .57 .877 r
.58939 .25519 m .61166 .25965 L .61284 .27535 L p F P
0 g
s
.997 .84 .5 r
.82292 .12929 m .81864 .1141 L p .81805 .14765 L F P
0 g
s
.997 .84 .5 r
.81805 .14765 m .81892 .14744 L .82292 .12929 L p F P
0 g
s
.977 .783 .365 r
.82292 .12929 m .81864 .1141 L .82064 .09504 L p F P
0 g
s
.402 .551 .889 r
.61166 .25965 m .58939 .25519 L .57857 .2374 L p F P
0 g
s
.967 .914 .703 r
.81007 .17071 m .81248 .18618 L .80086 .20871 L p F P
0 g
s
.985 .903 .612 r
.81248 .18618 m .81007 .17071 L .81843 .14929 L p F P
0 g
s
.615 .762 .949 r
.65323 .29359 m .69589 .28291 L .70593 .29447 L p F P
0 g
s
.585 .737 .948 r
.69589 .28291 m .65323 .29359 L .64277 .27871 L p F P
0 g
s
.992 .783 .403 r
.81519 .08 m .82064 .09504 L .81864 .1141 L p F P
0 g
s
.952 .703 .247 r
.82064 .09504 m .81519 .08 L .81486 .06185 L p F P
0 g
s
0 .067 .608 r
.55371 .20879 m .54412 .19528 L .5306 .18153 L p F P
0 g
s
.743 .852 .931 r
.74805 .2689 m .70593 .29447 L .69589 .28291 L p F P
0 g
s
0 .245 .759 r
.56768 .22105 m .55371 .20879 L p .57679 .23612 L F P
0 g
s
0 .134 .667 r
.55371 .20879 m .56768 .22105 L .55672 .20673 L p F P
0 g
s
0 .134 .667 r
.55672 .20673 m .54412 .19528 L .55371 .20879 L p F P
0 g
s
.94 .904 .76 r
.80086 .20871 m .79821 .1934 L p .78345 .22304 L F P
0 g
s
.94 .904 .76 r
.78345 .22304 m .78924 .22684 L .80086 .20871 L p F P
0 g
s
.967 .914 .703 r
.80086 .20871 m .79821 .1934 L .81007 .17071 L p F P
0 g
s
.994 .862 .525 r
.81843 .14929 m .81805 .14765 L .81892 .14744 L closepath p F P
0 g
s
.973 .709 .293 r
.80823 .04698 m .81486 .06185 L .81519 .08 L p F P
0 g
s
.986 .891 .637 r
.81805 .14765 m .81843 .14929 L .81007 .17071 L p F P
0 g
s
0 .285 .786 r
.57857 .2374 m .57679 .23612 L .57252 .22837 L closepath p F P
0 g
s
0 .245 .759 r
.57679 .23612 m .57252 .22837 L .56768 .22105 L p F P
0 g
s
.993 .871 .596 r
.8104 .14553 m .81418 .13415 L .81805 .14765 L closepath p F P
0 g
s
.997 .84 .5 r
.81864 .1141 m .81418 .13415 L .81805 .14765 L p F P
0 g
s
.986 .891 .637 r
.8104 .14553 m .81805 .14765 L p .81007 .17071 L F P
0 g
s
.402 .551 .889 r
.57857 .2374 m .60673 .24495 L .61166 .25965 L p F P
0 g
s
.328 .535 .903 r
.60673 .24495 m .57857 .2374 L .57252 .22837 L p F P
0 g
s
.904 .922 .819 r
.78413 .233 m .78345 .22304 L .78924 .22684 L closepath p F P
0 g
s
.861 .887 .854 r
.78345 .22304 m .78413 .233 L .75722 .26063 L p F P
0 g
s
.832 .872 .873 r
.75722 .26063 m .74805 .2689 L .73838 .25957 L p F P
0 g
s
.743 .852 .931 r
.69589 .28291 m .73838 .25957 L .74805 .2689 L p F P
0 g
s
.832 .872 .873 r
.73838 .25957 m .75477 .24546 L .75722 .26063 L p F P
0 g
s
.861 .887 .854 r
.78007 .22049 m .78345 .22304 L p .75722 .26063 L F P
0 g
s
.861 .887 .854 r
.75722 .26063 m .75477 .24546 L .78007 .22049 L p F P
0 g
s
1 .831 .523 r
.81316 .09912 m .81864 .1141 L .81418 .13415 L p F P
0 g
s
.992 .783 .403 r
.81864 .1141 m .81316 .09912 L .81519 .08 L p F P
0 g
s
.333 .537 .903 r
.61166 .25965 m .6322 .26368 L .62154 .24885 L p F P
0 g
s
.333 .537 .903 r
.62154 .24885 m .60673 .24495 L .61166 .25965 L p F P
0 g
s
.963 .897 .713 r
.80641 .15543 m .81007 .17071 L .79821 .1934 L p F P
0 g
s
.986 .891 .637 r
.81007 .17071 m .80641 .15543 L .8104 .14553 L p F P
0 g
s
.585 .737 .948 r
.64277 .27871 m .6857 .27057 L .69589 .28291 L p F P
0 g
s
.558 .717 .947 r
.6857 .27057 m .64277 .27871 L .6322 .26368 L p F P
0 g
s
.328 .535 .903 r
.57252 .22837 m .57005 .22184 L p .60673 .24495 L F P
0 g
s
.279 .502 .892 r
.57252 .22837 m .56768 .22105 L .57005 .22184 L closepath p F P
0 g
s
.997 .777 .434 r
.80853 .06516 m .81519 .08 L .81316 .09912 L p F P
0 g
s
.973 .709 .293 r
.81519 .08 m .80853 .06516 L .80823 .04698 L p F P
0 g
s
.723 .828 .93 r
.73838 .25957 m .69589 .28291 L .6857 .27057 L p F P
0 g
s
.224 .509 .908 r
.57005 .22184 m .56768 .22105 L .55672 .20673 L p F P
0 g
s
.983 .708 .331 r
.80037 .03232 m .80823 .04698 L .80853 .06516 L p F P
0 g
s
.914 .903 .8 r
.78007 .22049 m .78236 .21749 L .78345 .22304 L closepath p F P
0 g
s
.94 .904 .76 r
.79821 .1934 m .78236 .21749 L .78345 .22304 L p F P
0 g
s
.931 .891 .769 r
.79432 .17828 m .79821 .1934 L .78236 .21749 L p F P
0 g
s
.963 .897 .713 r
.79821 .1934 m .79432 .17828 L .80641 .15543 L p F P
0 g
s
.989 .856 .613 r
.81418 .13415 m .8104 .14553 L .80147 .14034 L p F P
0 g
s
.989 .856 .613 r
.80147 .14034 m .80865 .11923 L .81418 .13415 L p F P
0 g
s
1 .831 .523 r
.81418 .13415 m .80865 .11923 L .81316 .09912 L p F P
0 g
s
.328 .535 .903 r
.57005 .22184 m .59908 .23095 L .60673 .24495 L p F P
0 g
s
.211 .512 .912 r
.56087 .20818 m .57005 .22184 L .59908 .23095 L p F P
0 g
s
.224 .509 .908 r
.55672 .20673 m .56087 .20818 L .57005 .22184 L p F P
0 g
s
.982 .874 .649 r
.80641 .15543 m .8104 .14553 L .80147 .14034 L p F P
0 g
s
.558 .717 .947 r
.6322 .26368 m .67538 .2577 L .6857 .27057 L p F P
0 g
s
.535 .703 .947 r
.67538 .2577 m .6322 .26368 L .62154 .24885 L p F P
0 g
s
.904 .884 .803 r
.78236 .21749 m .78007 .22049 L .77064 .2121 L p F P
0 g
s
.904 .884 .803 r
.77064 .2121 m .77811 .20257 L .78236 .21749 L p F P
0 g
s
.931 .891 .769 r
.78236 .21749 m .77811 .20257 L .79432 .17828 L p F P
0 g
s
.862 .89 .855 r
.75477 .24546 m .78007 .22049 L .77064 .2121 L p F P
0 g
s
.997 .817 .542 r
.80646 .08433 m .81316 .09912 L .80865 .11923 L p F P
0 g
s
.997 .777 .434 r
.81316 .09912 m .80646 .08433 L .80853 .06516 L p F P
0 g
s
.821 .857 .874 r
.75477 .24546 m .73838 .25957 L .72852 .24916 L p F P
0 g
s
.723 .828 .93 r
.6857 .27057 m .72852 .24916 L .73838 .25957 L p F P
0 g
s
.821 .857 .874 r
.72852 .24916 m .75118 .23044 L .75477 .24546 L p F P
0 g
s
.862 .89 .855 r
.77064 .2121 m .75118 .23044 L .75477 .24546 L p F P
0 g
s
.268 .523 .91 r
.60673 .24495 m .62154 .24885 L .61078 .23451 L p F P
0 g
s
.268 .523 .91 r
.61078 .23451 m .59908 .23095 L .60673 .24495 L p F P
0 g
s
.955 .878 .719 r
.80145 .14038 m .80641 .15543 L .79432 .17828 L p F P
0 g
s
.982 .874 .649 r
.80147 .14034 m .80145 .14038 L .80641 .15543 L p F P
0 g
s
.996 .766 .459 r
.80064 .05055 m .80853 .06516 L .80646 .08433 L p F P
0 g
s
.983 .708 .331 r
.80853 .06516 m .80064 .05055 L .80037 .03232 L p F P
0 g
s
.707 .808 .928 r
.72852 .24916 m .6857 .27057 L .67538 .2577 L p F P
0 g
s
.984 .702 .364 r
.79127 .01789 m .80037 .03232 L .80064 .05055 L p F P
0 g
s
.211 .512 .912 r
.59908 .23095 m .58921 .21748 L .56087 .20818 L p F P
0 g
s
.982 .837 .624 r
.80865 .11923 m .80188 .10451 L p .80142 .1403 L F P
0 g
s
.982 .837 .624 r
.80142 .1403 m .80147 .14034 L .80865 .11923 L p F P
0 g
s
.997 .817 .542 r
.80865 .11923 m .80188 .10451 L .80646 .08433 L p F P
0 g
s
.923 .873 .77 r
.78914 .16337 m .79432 .17828 L .77811 .20257 L p F P
0 g
s
.955 .878 .719 r
.79432 .17828 m .78914 .16337 L .80145 .14038 L p F P
0 g
s
.535 .703 .947 r
.62154 .24885 m .66493 .2445 L .67538 .2577 L p F P
0 g
s
.519 .695 .949 r
.66493 .2445 m .62154 .24885 L .61078 .23451 L p F P
0 g
s
.99 .801 .557 r
.79852 .06977 m .80646 .08433 L .80188 .10451 L p F P
0 g
s
.996 .766 .459 r
.80646 .08433 m .79852 .06977 L .80064 .05055 L p F P
0 g
s
.894 .867 .804 r
.77811 .20257 m .77064 .2121 L .76099 .20234 L p F P
0 g
s
.894 .867 .804 r
.76099 .20234 m .7726 .18786 L .77811 .20257 L p F P
0 g
s
.923 .873 .77 r
.77811 .20257 m .7726 .18786 L .78914 .16337 L p F P
0 g
s
.811 .843 .874 r
.75118 .23044 m .72852 .24916 L .7185 .23785 L p F P
0 g
s
.707 .808 .928 r
.67538 .2577 m .7185 .23785 L .72852 .24916 L p F P
0 g
s
.22 .518 .914 r
.59908 .23095 m .61078 .23451 L .59993 .22089 L p F P
0 g
s
.22 .518 .914 r
.59993 .22089 m .58921 .21748 L .59908 .23095 L p F P
0 g
s
.848 .867 .856 r
.75118 .23044 m .77064 .2121 L .76099 .20234 L p F P
0 g
s
.811 .843 .874 r
.7185 .23785 m .74636 .2156 L .75118 .23044 L p F P
0 g
s
.848 .867 .856 r
.76099 .20234 m .74636 .2156 L .75118 .23044 L p F P
0 g
s
.973 .854 .663 r
.80145 .14038 m .80142 .1403 L .80147 .14034 L closepath p F P
0 g
s
.945 .859 .724 r
.80142 .1403 m .80145 .14038 L .78914 .16337 L p F P
0 g
s
.963 .849 .681 r
.79211 .13134 m .79461 .12575 L .80142 .1403 L closepath p F P
0 g
s
.945 .859 .724 r
.79211 .13134 m .80142 .1403 L p .78914 .16337 L F P
0 g
s
.982 .837 .624 r
.80188 .10451 m .79461 .12575 L .80142 .1403 L p F P
0 g
s
.99 .752 .479 r
.7915 .03616 m .80064 .05055 L .79852 .06977 L p F P
0 g
s
.984 .702 .364 r
.80064 .05055 m .7915 .03616 L .79127 .01789 L p F P
0 g
s
.695 .793 .926 r
.7185 .23785 m .67538 .2577 L .66493 .2445 L p F P
0 g
s
.973 .821 .631 r
.79388 .09001 m .80188 .10451 L .79461 .12575 L p F P
0 g
s
.99 .801 .557 r
.80188 .10451 m .79388 .09001 L .79852 .06977 L p F P
0 g
s
.519 .695 .949 r
.61078 .23451 m .65436 .23116 L .66493 .2445 L p F P
0 g
s
.512 .694 .951 r
.65436 .23116 m .61078 .23451 L .59993 .22089 L p F P
0 g
s
.914 .855 .77 r
.78263 .14869 m .78914 .16337 L .7726 .18786 L p F P
0 g
s
.945 .859 .724 r
.78914 .16337 m .78263 .14869 L .79211 .13134 L p F P
0 g
s
.98 .784 .567 r
.78933 .05543 m .79852 .06977 L .79388 .09001 L p F P
0 g
s
.99 .752 .479 r
.79852 .06977 m .78933 .05543 L .7915 .03616 L p F P
0 g
s
.886 .85 .803 r
.7726 .18786 m .76099 .20234 L .75114 .19135 L p F P
0 g
s
.886 .85 .803 r
.75114 .19135 m .7658 .17336 L .7726 .18786 L p F P
0 g
s
.914 .855 .77 r
.7726 .18786 m .7658 .17336 L .78263 .14869 L p F P
0 g
s
.803 .831 .872 r
.74636 .2156 m .7185 .23785 L .70831 .22577 L p F P
0 g
s
.695 .793 .926 r
.66493 .2445 m .70831 .22577 L .7185 .23785 L p F P
0 g
s
.803 .831 .872 r
.70831 .22577 m .74015 .20101 L .74636 .2156 L p F P
0 g
s
.835 .847 .855 r
.75114 .19135 m .74015 .20101 L .74636 .2156 L p F P
0 g
s
.835 .847 .855 r
.74636 .2156 m .76099 .20234 L .75114 .19135 L p F P
0 g
s
.687 .781 .922 r
.70831 .22577 m .66493 .2445 L .65436 .23116 L p F P
0 g
s
.954 .83 .684 r
.79461 .12575 m .79211 .13134 L .78248 .12029 L p F P
0 g
s
.954 .83 .684 r
.78248 .12029 m .78652 .11133 L .79461 .12575 L p F P
0 g
s
.973 .821 .631 r
.79461 .12575 m .78652 .11133 L .79388 .09001 L p F P
0 g
s
.936 .84 .724 r
.78263 .14869 m .79211 .13134 L .78248 .12029 L p F P
0 g
s
.512 .694 .951 r
.59993 .22089 m .64367 .21778 L .65436 .23116 L p F P
0 g
s
.963 .802 .636 r
.78462 .07574 m .79388 .09001 L .78652 .11133 L p F P
0 g
s
.98 .784 .567 r
.79388 .09001 m .78462 .07574 L .78933 .05543 L p F P
0 g
s
.905 .838 .768 r
.77473 .13427 m .78263 .14869 L .7658 .17336 L p F P
0 g
s
.936 .84 .724 r
.78248 .12029 m .77473 .13427 L .78263 .14869 L p F P
0 g
s
.797 .818 .869 r
.74015 .20101 m .70831 .22577 L .69798 .21306 L p F P
0 g
s
.687 .781 .922 r
.65436 .23116 m .69798 .21306 L .70831 .22577 L p F P
0 g
s
.877 .835 .8 r
.7658 .17336 m .75114 .19135 L .7411 .1792 L p F P
0 g
s
.877 .835 .8 r
.7411 .1792 m .75767 .15909 L .7658 .17336 L p F P
0 g
s
.905 .838 .768 r
.7658 .17336 m .75767 .15909 L .77473 .13427 L p F P
0 g
s
.684 .773 .918 r
.69798 .21306 m .65436 .23116 L .64367 .21778 L p F P
0 g
s
.943 .812 .685 r
.78652 .11133 m .78248 .12029 L .77259 .10723 L p F P
0 g
s
.943 .812 .685 r
.77259 .10723 m .77718 .09713 L .78652 .11133 L p F P
0 g
s
.963 .802 .636 r
.78652 .11133 m .77718 .09713 L .78462 .07574 L p F P
0 g
s
.797 .818 .869 r
.69798 .21306 m .73239 .18673 L .74015 .20101 L p F P
0 g
s
.824 .829 .852 r
.7411 .1792 m .73239 .18673 L .74015 .20101 L p F P
0 g
s
.824 .829 .852 r
.74015 .20101 m .75114 .19135 L .7411 .1792 L p F P
0 g
s
.924 .819 .724 r
.77473 .13427 m .78248 .12029 L .77259 .10723 L p F P
0 g
s
.897 .82 .764 r
.76539 .12014 m .77473 .13427 L .75767 .15909 L p F P
0 g
s
.924 .819 .724 r
.77259 .10723 m .76539 .12014 L .77473 .13427 L p F P
0 g
s
.792 .806 .864 r
.73239 .18673 m .69798 .21306 L .6875 .19978 L p F P
0 g
s
.684 .773 .918 r
.64367 .21778 m .6875 .19978 L .69798 .21306 L p F P
0 g
s
.87 .819 .796 r
.75767 .15909 m .7411 .1792 L .73088 .16597 L p F P
0 g
s
.87 .819 .796 r
.73088 .16597 m .74817 .14508 L .75767 .15909 L p F P
0 g
s
.897 .82 .764 r
.75767 .15909 m .74817 .14508 L .76539 .12014 L p F P
0 g
s
.792 .806 .864 r
.6875 .19978 m .72292 .1728 L .73239 .18673 L p F P
0 g
s
.815 .813 .848 r
.73088 .16597 m .72292 .1728 L .73239 .18673 L p F P
0 g
s
.815 .813 .848 r
.73239 .18673 m .7411 .1792 L .73088 .16597 L p F P
0 g
s
.25 Mabswid
.80741 0 m
.98192 .26089 L
s
.98192 .26089 m
1 .40932 L
s
1 .40932 m
.82037 .15537 L
s
.82037 .15537 m
.80741 0 L
s
.01777 .2799 m
0 .42775 L
s
0 .42775 m
.82037 .15537 L
s
.82037 .15537 m
.80741 0 L
s
.80741 0 m
.01777 .2799 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{1095, 373.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000A70001MB000`400?l00000o`00003ooooonf[o
oookJ_oooo]ZoooonfY;oookJP00oooonf[ooookJ_oooo]ZoooonfY;oookJP00oooonf[ooookJ_oo
oo]ZoooonfY;oookJP00oooonf[ooookJ_oooo]ZoooonfY;oookJP00oooonf[ooookJ_oooo]Zoooo
nfY;oookJP00oooonf[ooookJ_oooo]ZoooonfY;oookJP00oooonf[ooookJ_oooo]ZoooonfY;oook
JP00oooonf[ooookJ_oooo]ZoooonfY;oookJP00oooonf[ooookJ_oooo]ZoooonfY;oookJP00oooo
nfYboookJP;o0000oooonf[ooookJ]Kooo]Z003ooookJVoooo]Z0ol000000ooonf[o0000oookJP3o
oookJ_oooo]ZeOoonfX00?oooo]ZK?oonfX3o`0000Cooo]Z0_l0003ooookJ_oooo]ZeOoonfX00?oo
oo]ZJ_oonfX2o`0000Oooo]Z00?o0000oookJ_l00000oooonf[ooookJ]Cooo]Z003ooookJVOooo]Z
0ol00009oookJP03o`000?oonf[o00000?oooo]Zoooonf[DoookJP00oooonfYUoookJP;o00003?oo
nfX01?l0003ooo]ZoookJ_l0003ooookJ_oooo]ZdooonfX00?oooo]ZH_oonfX3o`0000kooo]Z00Go
0000oookJ_oonf[ooo]Zo`00003ooookJ_oooo]Zd_oonfX00?oooo]ZGooonfX3o`00017ooo]Z00Go
0000oookJ_oonf[ooo]Zo`00003ooookJ_oooo]Zd_oonfX00?oooo]ZGOoonfX2o`0001Cooo]Z00?o
0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP3ooookJ_oooo]ZcooonfX00?oooo]ZF_oonfX3
o`0001Oooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP3ooookJ_oooo]Zc_oonfX0
0?oooo]ZF?oonfX2o`0001[ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP3ooook
J_oooo]Zc_oonfX00?oooo]ZEOoonfX3o`0001cooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003o
oo]ZoookJP3ooookJ_oooo]ZcOoonfX00?oooo]ZD_oonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP3ooookJ_oooo]Zc?oonfX00?oooo]ZD?oonfX2o`0002;ooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP3ooookJ_oooo]Zc?oonfX00?oooo]ZCOoonfX3
o`0002Cooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP3ooookJ_oooo]ZbooonfX0
0?oooo]ZBooonfX2o`0002Oooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP3ooook
J_oooo]Zb_oonfX00?oooo]ZB?oonfX3o`0002Wooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003o
oo]ZoookJP3ooookJ_oooo]Zb_oonfX00?oooo]ZAOoonfX3o`0002cooo]Z00?o0000oookJ_oonfX0
1ooonfX00ol0003ooo]ZoookJP3ooookJ_oooo]ZbOoonfX00?oooo]Z@ooonfX2o`0002oooo]Z00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP3ooookJ_oooo]Zb?oonfX00?oooo]Z@?oonfX3
o`00037ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP3ooookJ_oooo]Zb?oonfX0
0?oooo]Z?_oonfX2o`0003Cooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP3ooook
J_oooo]ZaooonfX00?oooo]Z>ooonfX3o`0003Kooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003o
oo]ZoookJP3ooookJ_oooo]Za_oonfX00?oooo]Z>?oonfX3o`0003Wooo]Z00?o0000oookJ_oonfX0
2_oonfX00ol0003ooo]ZoookJP3ooookJ_oooo]ZBOoonfX2o`0007_ooo]Z003ooookJSKooo]Z0_l0
000loookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0oooonf[ooookJTGooo]Z0ol0
00000ooonf[o0000oookJP1joookJP00oooonfXcoookJP?o0000?_oonfX00ol0003ooo]ZoookJP0<
oookJP03o`000?oonf[ooo]Z0?oooo]ZoooonfY1oookJP?o00001?oonfX2o`0007[ooo]Z003ooook
JS3ooo]Z0ol00012oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0oooonf[ooook
JSkooo]Z0ol00007oookJP03o`000?oonf[o000007Wooo]Z003ooookJRkooo]Z0_l00015oookJP03
o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0oooonf[ooookJS[ooo]Z0ol0000:oookJP03
o`000?oonf[o000007Wooo]Z003ooookJR_ooo]Z0ol00017oookJP03o`000?oonf[ooo]Z00gooo]Z
00?o0000oookJ_oonfX0oooonf[ooookJSKooo]Z0ol0000=oookJP04o`000?oonf[ooo]Zo`0007So
oo]Z003ooookJRWooo]Z0_l0001:oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0
oooonf[ooookJSCooo]Z0_l0000@oookJP05o`000?oonf[ooo]ZoookJ_l00000MooonfX00?oooo]Z
9_oonfX3o`0004cooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP3ooookJ_oooo]Z
<?oonfX3o`0001?ooo]Z00Co0000oookJ_oonf[o0000MooonfX00?oooo]Z8ooonfX3o`0004oooo]Z
00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP3ooookJ_oooo]Z;?oonfX3o`0001Kooo]Z
00Go0000oookJ_oonf[ooo]Zo`00001foookJP00oooonfXQoookJP;o0000D_oonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z0?oooo]ZoooonfXYoookJP?o00004?oonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0LooonfX00?oooo]Z7_oo
nfX3o`0005Cooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP3ooookJ_oooo]Z9Ooo
nfX3o`0001?ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oo
nf[ooo]Z07?ooo]Z003ooookJQcooo]Z0_l0001GoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000
oookJ_oonfX0oooonf[ooookJR7ooo]Z0ol0000FoookJP;o00001ooonfX00ol0003ooo]ZoookJP03
oookJP03o`000?oonf[ooo]Z07;ooo]Z003ooookJQWooo]Z0ol0001IoookJP03o`000?oonf[ooo]Z
017ooo]Z00?o0000oookJ_oonfX0oooonf[ooookJQoooo]Z0_l0000IoookJP03o`000?ok/ego0000
00Kooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP1aoookJP00oooonfXFoookJP?o
0000G?oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z0?oooo]ZoooonfXKoookJP?o
00006ooonfX01?l0003onk=Moo^cGOl00005oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX0LOoonfX00?oooo]Z5?oonfX2o`0005oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003o
oo]ZoookJP3ooookJ_oooo]Z5ooonfX3o`0001kooo]Z00Co0000oo^cGOok/ego00001OoonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z073ooo]Z003ooookJQ7ooo]Z0ol0001QoookJP03
o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0oooonf[ooookJQCooo]Z0ol0000QoookJP05
o`000?ok/egonk=Moo^cGOl000001?oonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z
06oooo]Z003ooookJPoooo]Z0_l0001ToookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX0oooonf[ooookJQ3ooo]Z0ol0000ToookJP03o`000?ok/egonk=M00;onk=M00Go0000oookJ_oo
nf[ooo]Zo`000008oookJP03o`000?oonf[ooo]Z06oooo]Z003ooookJPcooo]Z0ol0001VoookJP03
o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0oooonf[ooookJPcooo]Z0ol0000WoookJP03
o`000?ok/egonk=M00;onk=M00Go0000oookJ_oonf[ooo]Zo`000009oookJP03o`000?oonf[ooo]Z
06kooo]Z003ooookJPWooo]Z0ol0001YoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oo
nfX0oooonf[ooookJP[ooo]Z0_l0000ZoookJP03o`000?ok/egonk=M00;onk=M0_l00002oookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0KOoonfX00?oooo]Z1ooonfX2o`0006cooo]Z
00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP3ooookJ_oooo]Z1_oonfX3o`0002cooo]Z
00?o0000oo^cGOok/ed00_ok/ed2o`0000;ooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]Z
oookJP1]oookJP00oooonfX4oookJP?o0000KooonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oo
nf[ooo]Z0?oooo]ZoooonfX2oookJP?o0000;ooonfX2o`0000?onk=M00?o0000oo^eE?l000000_oo
nfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z06cooo]Z003ooookJP7ooo]Z0ol0001b
oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0oooonf[noookJP?o0000<_oonfX0
0ol0003ooL1jo`000002oo^cG@03o`000?ok]ECo000000;ooo]Z00?o0000oookJ_oonfX02OoonfX0
0ol0003ooo]ZoookJP1[oookJP00o_oonfX2o`0007Gooo]Z00?o0000oookJ_oonfX05ooonfX00ol0
003ooo]ZoookJP3ooookJ_[ooo]Z0ol0000eoookJP08o`000?om`7[ooL1jo`000?ok/ego0000oo^e
E?l00002oookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0JooonfX00?_ooo]Z0ol0
001goookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0oooonf[foookJP?o0000=ooo
nfX01ol0003ooL1joog0N_om`7[o0000oo^cGOl000000_ok]E@00ol0003ooo]Zo`00000<oookJP03
o`000?oonf[ooo]Z06[ooo]Z003ioookJP;o0000N_oonfX00ol0003ooo]ZoookJP0HoookJP03o`00
0?oonf[ooo]Z0?oooo]Zm?oonfX2o`0003[ooo]Z00?o0000oog0N_om`7X00_om`7X2o`0000;onkED
00?o0000oookJ_l000003OoonfX00ol0003ooo]ZoookJP1YoookJP00m_oonfX3o`0007cooo]Z00?o
0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP3ooookJ_3ooo]Z0ol0000loookJP03o`000?om
`7[ooL1j00?ooL1j00?o0000oo^eE?ok]E@00ol0000=oookJP03o`000?oonf[ooo]Z06Wooo]Z003c
oookJP?o0000OooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z0?oooo]Zk?oonfX3
o`0003oooo]Z00?o0000oog0N_om`7X00oom`7X00ol0003onkEDoo^eE003o`0000kooo]Z00?o0000
oookJ_oonfX0J?oonfX00?7ooo]Z0_l00022oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oook
J_oonfX0oooonf[YoookJP?o0000@_oonfX00ol0003ooL1joog0NP03oog0NP;o000000ConkEDo`00
0?oi]D_o00003ooonfX00ol0003ooo]ZoookJP1WoookJP00k_oonfX3o`0008Cooo]Z00?o0000oook
J_oonfX06ooonfX00ol0003ooo]ZoookJP3ooookJ^Gooo]Z0ol00015oookJP03o`000?om`7[ooL1j
00?ooL1j0_l00002oo^eE0?o00003_oonfX00ol0003ooo]ZoookJP1WoookJP00k?oonfX2o`0008Oo
oo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP3ooookJ^7ooo]Z0ol00018oookJP;o
00001?om`7X01?l0003oo/Aeo`000?ok]E@3o`0000oooo]Z00?o0000oookJ_oonfX0I_oonfX00>Wo
oo]Z0ol00029oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0oooonf[OoookJP;o
0000B_oonfX01?l0003on/RAoo[8TOl00002oog0NP04o`000?ona7Goo/Aeook4M@?o000000?onKE;
o`000?oonfX03_oonfX00ol0003ooo]ZoookJP1UoookJP00i_oonfX3o`0008cooo]Z00?o0000oook
J_oonfX07OoonfX00ol0003ooo]ZoookJP3ooookJ]_ooo]Z0ol0001<oookJP07o`000?ojb97on/RA
oo[8TOl0003ooL1jo`000003ook4M@?o000000?onKE;o`000?oonfX03_oonfX00ol0003ooo]Zoook
JP1UoookJP00i?oonfX2o`0008oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP3o
oookJ]Oooo]Z0ol0001?oookJP07o`000?ojb97on/RAoo[8TOl0003ooL1jo`000004ook4M@;o0000
00?onKE;o`000?oonfX03ooonfX00ol0003ooo]ZoookJP1ToookJP00hOoonfX3o`00097ooo]Z00?o
0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP3ooookJ]?ooo]Z0ol0001BoookJP03o`000?oj
b97on/RA00;on/RA0_l00004ook4M@03o`000?oi]D_o000000;o00004?oonfX00ol0003ooo]Zoook
JP1SoookJP00gooonfX2o`0009Cooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP3o
oookJ]3ooo]Z0ol0001EoookJP03o`000?ojb97on/RA00?on/RA00?o0000ook4MOona7D00_ona7D5
o`00013ooo]Z00?o0000oookJ_oonfX0HooonfX00=cooo]Z0ol0002FoookJP03o`000?oonf[ooo]Z
023ooo]Z00?o0000oookJ_oonfX0oooonf[<oookJP?o0000EooonfX00ol0003on/RAoo[8T@04oo[8
T@03o`000?ona7Goo/Ae00;oo/Ae1Ol0000AoookJP03o`000?oonf[ooo]Z06;ooo]Z003IoookJP?o
0000V_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z0?oooo]ZbOoonfX2o`0005[o
oo]Z00?o0000oo[8TOojb9401?ojb942o`0000?oo/Ae00?o0000ooo6Kol000000_l0000BoookJP03
o`000?oonf[ooo]Z067ooo]Z003GoookJP;o0000WOoonfX00ol0003ooo]ZoookJP0PoookJP03o`00
0?oonf[ooo]Z0?oooo]Za_oonfX3o`0005cooo]Z00?o0000oo[8TOojb9400oojb9400ol0003ooLf>
o`000003ook4M@06o`000?ooaVoo0000o`000?oc/coo00004OoonfX00ol0003ooo]ZoookJP1Qoook
JP00e?oonfX3o`0003?ooo]Z:Ol00013oookJP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oo
nfX0oooonf[2oookJP?o0000GooonfX00ol0003on/RAoo[8T@03oo[8T@06o`000?omcHkooLf>o`00
0?ona7Go00000_ooaVl2o`000003oo>c?ol0003ooo]Z017ooo]Z00?o0000oookJ_oonfX0H?oonfX0
0=;ooo]Z0_l0000/oookJP[o00002?nWIhL00ol0003o[Vf7oji]Q`05oji]Q`03o`000?n`KXOo/6j7
00_o/6j700?o0000okMcQongLhL00ongLhL00ol0003o^GF7okUeQ`02okUeQ`Wo0000>_oonfX00ol0
003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z0?oooo]Z__oonfX3o`00067ooo]Z00?o0000ooK=
X_l000001?ojb9401_l0003ooLf>oog=S_l0003oo/Aeo`0000;oolI_0_l000000ooc/coo0000oook
JP0BoookJP03o`000?oonf[ooo]Z05oooo]Z003?oookJP?o0000:?oonfX6o`0000;oYFF600?o0000
ojMWQonWIhL03OnWIhL00ol0003o[Vf7oji]Q`05oji]Q`03o`000?n`KXOo/6j700_o/6j700?o0000
okMcQongLhL00ongLhL00ol0003o^GF7okUeQ`0;okUeQ`So0000<_oonfX00ol0003ooo]ZoookJP0R
oookJP03o`000?oonf[ooo]Z0?oooo]Z^ooonfX3o`0006Cooo]Z00?o0000ooK=X_l000000oojb940
0ol0003ooLf>oog=SP02oog=SP;o00000_ooaVl2o`000003oo>c?ol0003o000001;ooo]Z00?o0000
oookJ_oonfX0GooonfX00<cooo]Z0ol0000ToookJPOo00000onMGhH00ol0003oYFF6ojEUQP02ojEU
QP03o`000?nWIhOoYfN700goYfN700?o0000oji]Qon^KHL01On^KHL00ol0003o/6j7ok1^Q`0;ok1^
Q`03o`000?ngLhOo]g>700?o]g>700?o0000okUeQoniMHL03_niMHL2o`0000?o`Gb61ol0000[oook
JP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0oooonfZgoookJP?o0000IooonfX01?l0
003om/fRooK=X_l00002oo[8T@03o`000?omcHkooLf>00;ooLf>0_l00002ooo6K`Go00004ooonfX0
0ol0003ooo]ZoookJP1NoookJP00b_oonfX2o`00023ooo]Z1ol0000:oieOQP05o`000?nUIHKoYFF6
ojEUQ_l000004?nWIhL00ol0003o[Vf7oji]Q`04oji]Q`03o`000?n`KXOo/6j700go/6j700?o0000
okMcQongLhL00_ngLhL00ol0003o^GF7okUeQ`0>okUeQ`;o00002_o1O8H6o`0002Gooo]Z00?o0000
oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP3ooookJ[Cooo]Z0_l0001YoookJP03o`000?ofcJ;o
m/fR00;om/fR00?o0000oo[8TOl000001OomcHh00ol0003oolI_ooo6K`04o`000003on^`<Ol0003o
oo]Z01;ooo]Z00?o0000oookJ_oonfX0GOoonfX00<Oooo]Z0ol0000MoookJPGo00004OnMGhH01Ol0
003oYFF6ojEUQ_nUIHKo0000013oYfN700?o0000oji]Qon^KHL01?n^KHL00ol0003o/6j7ok1^Q`0=
ok1^Q`05o`000?ngLhOo]g>7okMcQol000004OniMHL2o`0000co`Gb600Co0000ol=nQ_o3OXKo`gj6
1ol0000MoookJP;o00009_oonfX00ol0003ooo]ZoookJP3ooookJ[7ooo]Z0ol0001[oookJP03o`00
0?ofcJ;om/fR00;om/fR0_l00006oog=SP03o`000?ooaVooolI_00?o000000?olk<oo`000?l00000
4ooonfX00ol0003ooo]ZoookJP1MoookJP00a?oonfX3o`0001cooo]Z1?l00002oiAHQ@03o`000?nM
GhKoWEn6017oWEn600Go0000ojEUQ_nUIHKoYFF6o`00000@ojMWQ`03o`000?n^KHOo[Vf700Co[Vf7
00?o0000ok1^Qon`KXL03On`KXL01Ol0003o]g>7okMcQongLhOo0000013o^GF700Co0000ok]gQonk
MhOo00002oo1O8H00ol0003o`gj6ol=nQP08ol=nQPGo00005OoonfX3o`000003oookJ_l0003ooo]Z
02Kooo]Z00?o0000oookJ_oonfX0oooonfZ]oookJP?o0000K_oonfX00ol0003om/fRooK=XP03ooK=
XP03o`000?omcHkooLf>00?ooLf>00Co0000oooAR_l0003oolI_0_l000001?omb6Oo0000o`000?l0
000DoookJP03o`000?oonf[ooo]Z05cooo]Z0032oookJP;o00006ooonfX4o`0000KoU5R500?o0000
oieOQ_nMGhH04OnMGhH01Ol0003oYFF6ojEUQ_nUIHKo0000013oYfN700Co0000oji]Qon^KHOo[Vf7
5_l000000ongLhOo0000okUeQ`0?okUeQ`04o`000?nkMhOo^gN7o`0000_o`Gb600?o0000ol=nQ_o3
OXH02_o3OXH2o`000004ol^5QOl0003o0000o`0000oooo]Z0ol00005oookJP03o`000?oonf[ooo]Z
02Gooo]Z00?o0000oookJ_oonfX0oooonfZYoookJP?o0000L?oonfX00ol0003om/fRooK=XP04ooK=
XP03o`000?omcHkooLf>00?ooLf>00Go0000oooAR_l0003oolI_o`000002oog8I`;o000000?ojk0a
o`000?oonfX04ooonfX00ol0003ooo]ZoookJP1KoookJP00_ooonfX3o`0001Wooo]Z1?l0000:oiAH
Q@03o`000?nMGhKoWEn6017oWEn600Co0000ojEUQ_nUIHKo00002?nWIhL=o`0000?o/7JA00?o0000
ok9gT_nbMi803OnbMi800ol0003o^7bAokQlT@0;o`0000Oo^GF700Co0000ok]gQonkMhOo00002oo1
O8H00ol0003o`gj6ol=nQP0:ol=nQP;o00001?o;QHD3o`0000Wooo]Z0ol00009oookJP03o`000?oo
nf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0oooonfZVoookJP?o0000LooonfX00ol0003om/fRooK=
XP04ooK=XP;o00001?omcHh00ol0003oom6:oooARP03o`000005oog8Iol0003o0000on^`<Ol00000
5?oonfX00ol0003ooo]ZoookJP1KoookJP00_OoonfX2o`0001Oooo]Z1Ol0000>oiAHQ@03o`000?nM
GhKoWEn600koWEn63ol00009ojYaTP03o`000?n`MY7o/7JA00?o/7JA00?o0000ok9gT_nbMi803_nb
Mi801Ol0003o^7bAokQlTOnhO97o000000Wo^WjB3_l00008ol5lQP03o`000?o3OXKo`gj600[o`gj6
0_l00007ol^5Q@?o00000ooonfX3o`0000cooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP3ooookJZ;ooo]Z0ol0001foookJP03o`000?ofcJ;om/fR00?om/fR00?o0000ooWBXOl00000
0oomcHh01?l0003oom6:oooAR_oodHX3o`0000;ooLQW00?o0000on^`<Ol000005OoonfX00ol0003o
oo]ZoookJP1JoookJP00^_oonfX3o`0001Kooo]Z0ol000001?n9ChCo0000oi=GQOl0000?oiAHQ@03
o`000?nMGhKoWEn600OoWEn61ol00003oj5YTP04o`000?nXKi7oZ6nAo`00017oZW6B00?o0000ok1f
TOn`MY400on`MY400ol0003o/WNBok9gTP0>ok9gTP05o`000?nhO97o^7bAokQlTOl000004?njOY80
1?l0003o_82Bokb0T_l00003ol:4T@Ko00000_o1O8H00ol0003o`gj6ol=nQP0:ol=nQP03o`000?o;
QHGobhF500WobhF50ol0000@oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0oooo
nfZOoookJP;o0000N?oonfX00ol0003om/fRooK=XP04ooK=XP04o`000?oidZ7onM:Qo`0000;ooLf>
00Co0000oooAR_oodH[oom6:0ol00002oog8I`03o`000?o[/37o000001Kooo]Z00?o0000oookJ_oo
nfX0FOoonfX00;Oooo]Z0ol0000FoookJP?o00001?n9Ch@2o`00013oU5R500?o0000oieOQ_nMGhH0
1ol0000:oj5YTP03o`000?nXKi7o000001;oZW6B00?o0000ok1fTOn`MY400on`MY400ol0003o/WNB
ok9gTP0>ok9gTP04o`000?nhO97o^7bAo`00017o^WjB00Co0000okb0T_nlP9;o00002Oo2Q945o`00
00[o`gj600?o0000ol^5QOo;QHD01oo;QHD3o`0000;ocXN41?l0000=oookJP03o`000?oonf[ooo]Z
02Cooo]Z00?o0000oookJ_oonfX0oooonfZLoookJP?o0000N_oonfX00ol0003om/fRooK=XP04ooK=
XP07o`000?oidZ7onM:QooWBXOl0003ooLf>o`000004oooARP;o00000_omb6L00ol0003ojk0ao`00
000FoookJP03o`000?oonf[ooo]Z05Wooo]Z002eoookJP;o00005_oonfX3o`0000OoRDn40_l0000>
oiAHQ@Go00004OnQJI800ol0003oZ6nAo`00000BojYaTP03o`000?n`MY7o/7JA00;o/7JA00?o0000
ok9gT_nbMi804?nbMi800ol0003o^7bAo`00000@okYnTP05o`000?nlP9;o_82Bokb0T_l000002oo2
Q9400ol0003oa8JBolB6TP05o`0000Go`gj600?o0000ol^5QOo;QHD01?o;QHD3o`0000;obhF500?o
0000olj7Q?o>Qh@01?o>Qh@3o`0000_ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]Zoook
JP3ooookJYSooo]Z0ol0001loookJP03o`000?oacjoo000000Com/fR00?o0000ooWBXOoidZ400_oi
dZ42o`0000Goom6:0_l00002oog8I`Co00005_oonfX00ol0003ooo]ZoookJP1HoookJP00/_oonfX3
o`0001Gooo]Z0ol0000:ohU?Q0;o00002onDF8D3o`0000;oV6>A00?o0000oj5YT_nQJI804_nQJI82
o`0001?oZW6B00Go0000ok1fTOn`MY7o/7JAo`00000Bok9gTP03o`000?nhO97o0000013o^WjB00Go
0000okb0T_nlP9;o_82Bo`00000;ol:4T@03o`000?o4QY;oa8JB00Goa8JB1?l000000oo3OXKo0000
ol^5Q@02ol^5Q@?o00001Oo;QHD00ol0003ocXN4olj7Q007olj7Q0?o00002?oonfX00ol0003ooo]Z
oookJP0UoookJP03o`000?oonf[ooo]Z0?oooo]ZU?oonfX3o`0007oooo]Z00Co0000oo7?[ooacjoo
00000oofcJ800ol0003onM:QooWBX@03ooWBX@03o`000?oodH[oom6:00?oom6:0_l00002oog8I`Co
00005ooonfX00ol0003ooo]ZoookJP1GoookJP00/?oonfX2o`0001Gooo]Z0ol0000=ohU?Q003o`00
0?nDF8GoU5R500KoU5R51?l00005oiQST@03o`000?nQJI;oXFVB01;oXFVB00?o0000ojYaT_nZLI80
4_nZLI801Ol0003o/7JAok1fTOn`MY7o000001;o/WNB00?o0000okQlTOl000004?njOY800ol0003o
_82Bokb0TP02okb0TP03o`000?o2Q97o`XBA00Oo`XBA00?o0000olB6T_o4QY802_o4QY85o`0000So
bhF500?o0000olj7Q?o>Qh@02?o>Qh@00ol0003odHZ4o`000002o`0000Kooo]Z00?o0000oookJ_oo
nfX09?oonfX00ol0003ooo]ZoookJP3ooookJY7ooo]Z0ol00022oookJP05o`000?oacjoolLn_oo7?
[ol000000_ofcJ800ol0003onM:QooWBX@03ooWBX@03o`000?oodH[oom6:00;oom6:00Ko0000oooD
QOl0003ooLQWo`000?ojb5d3o`0001Oooo]Z00?o0000oookJ_oonfX0EooonfX00:gooo]Z0ol0000E
oookJP;o00004?n9Ch@00ol0003oU5R5oiAHQ@02oiAHQ@Co00002OnHHi400ol0003oXFVBoj5YTP0B
oj5YTP03o`000?nZLI;oZW6B01;oZW6B00Co0000ok1fTOn`MY7o00004onbMi82o`00017o^WjB00?o
0000okb0T_nlP9800_nlP9800ol0003o`XBAol:4T@07ol:4T@03o`000?o4QY;oa8JB00[oa8JB0_l0
0002ol^<T0Co00001Oo;QHD00ol0003ocXN4olj7Q008olj7Q003o`000?oARXCodHZ400;odHZ40_l0
0005oookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0oooonfZ=oookJP?o0000Q?oo
nfX00ol0003olLn_oo7?[`02oo7?[`04o`000?ofcJ;om/fRo`0000GonM:Q0_l00003oooARP03o`00
0?ooe8Go000000;o00000_ojb5d2o`0001Sooo]Z00?o0000oookJ_oonfX0E_oonfX00:[ooo]Z0ol0
000FoookJP;o000000?oODF2o`000?n9Ch@03on9Ch@00ol0003oU5R5o`000002o`0000goV6>A00?o
0000oj5YT_nQJI804_nQJI800ol0003oZW6BojYaTP0=ojYaTROo00001onjOY800ol0003o_82Bokb0
TP03okb0TP03o`000?o2Q97o`XBA00Oo`XBA00?o0000olB6T_o4QY801oo4QY83o`000003olB6T_l0
003obhb@00Gobhb@1?l000000oo;QHGo0000olj7Q009olj7Q003o`000?oARXCodHZ400;odHZ400?o
0000omF=P_l000000_l00002oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0oooo
nfZ:oookJP;o0000QooonfX00ol0003olLn_oo7?[`03oo7?[`;o00001OoidZ400ol0003onmJOo`00
0003oooARP03o`000?ooe8Go000000;o00000_ojb5d2o`0001Wooo]Z00?o0000oookJ_oonfX0EOoo
nfX00:Sooo]Z0_l0000FoookJP?o00000ommAH800ol0003oRDn4ohU?Q00=ohU?Q0?o00004OnHHi40
0ol0003oXFVBoj5YTP0@oj5YTP;o00001?nZLI8;o`0000Go[7VL00Co0000ok5mV_naOI[o00004ond
P9`2o`0000Wo^hJK2ol00002okb0TP03o`000?o2Q97o`XBA00Oo`XBA00?o0000olB6T_o4QY801?o4
QY83o`0000?oa8JB00?o0000olJ9T_l000002Oo;S903o`0000WocXN400?o0000om6:Q?oARX@00_oA
RX@00ol0003oeHf2omF=PP02omF=PP;o000000?ooo]Zo`000?oonfX09OoonfX00ol0003ooo]Zoook
JP3ooookJXOooo]Z0ol00028oookJP03o`000?o/dKWo000000GolLn_00?o0000ooWBXOoidZ400ooi
dZ401?l0003onmJOoo_FWol00002oooARP03o`000?ooe8Go000000;o00000_ojb5d2o`0001Wooo]Z
00?o0000oookJ_oonfX0EOoonfX00:Gooo]Z0ol0000FoookJP;o00001_mmAH800ol0003oRDn4ohU?
Q00;ohU?Q0;o000000?oSebAo`000?nHHi404OnHHi400ol0003oXFVBoj5YTP0<oj5YTP[o00004?n/
NI`00ol0003o/GfJo`00000DokB0W003o`000?nkQY_o^hJK00oo^hJK00Co0000okb7W?nlQico_8NL
2?l00003ol:4T@03o`000?o4QY;oa8JB00;oa8JB0ol00006olB6TP03o`000?o6RI;o000000[obhb@
00?o0000olj?TOl000000_l00006olj7Q003o`000?oARXCodHZ400;odHZ400?o0000omF=P_oESH80
0_oESH800ol0003ofI22o`000002o`0002Kooo]Z00?o0000oookJ_oonfX0oooonfZ3oookJP?o0000
R_oonfX01Ol0003ok=6ioncA^Oo/dKWo000000ColLn_00?o0000ooWBXOoidZ400ooidZ401?l0003o
nmJOoo_FWol00002oooARP05o`000?ooe8Go0000oooDQOl000000_ojb5d2o`0001[ooo]Z00?o0000
oookJ_oonfX0E?oonfX00:?ooo]Z0_l0000GoookJP;o00002?mmAH800ol0003oRDn4ohU?Q008ohU?
Q0?o00000on?G9400ol0003oV6>AoiQST@0@oiQST@03o`000?nQJI;oXFVB00KoXFVB1_l00003oj=b
V`03o`000?nUM9co000001Go[7VL0_l0000DokB0W003o`000?nkQY_o^hJK00ko^hJK00?o0000okb7
W?nlQi`01?nlQi`00ol0003o`X^Kol:;V`03ol:;V`So00002Oo4QY800ol0003oaXVBo`00000:ol^<
T003o`000?o>Si7ocXnA00;ocXnA0ol00003olj7Q003o`000?oARXCodHZ400;odHZ400?o0000omF=
P_oESH800_oESH801?l0003ofI22omV@P_oIT883o`0002Gooo]Z00?o0000oookJ_oonfX0oooonfYo
oookJP?o0000SOoonfX00ol0003ok=6ioncA^@02oncA^@06o`000?oacjoolLn_o`000?ode:oo0000
0ooidZ400ol0003onmJOoo_FW`02oo_FW`;o00000_ooe8D00ol0003oomB5o`000002oo[8G@;o0000
6ooonfX00ol0003ooo]ZoookJP1CoookJP00X?oonfX3o`0001Kooo]Z0ol0000:oge5PP03o`000?n9
ChCoRDn400GoRDn41?l00005ohmLT@03o`000?nHHi7oV6>A013oV6>A00?o0000oj5YT_nQJI801_l0
0008oj=bV`04o`000?nUM9coYGBLo`0001Go[7VL0_l0000CokB0W0;o00004?nkQY/00ol0003o_8NL
okb7W004okb7W003o`000?o2Ri_o`X^K00Ko`X^K0_l000000oo4SIco0000o`000003o`0000Koa8JB
00?o0000olJ9T_l000002Oo;S9000ol0003ocXnAolj?T@06olj?T@Co00001OoARX@01Ol0003oeHf2
omF=P_oESH;o000000CofI2200Co0000omV@P_l0003o00008ooonfX00ol0003ooo]ZoookJP3ooook
JWcooo]Z0ol0000>oookJP03o`000?oonf[ooo]Z07kooo]Z00?o0000oncA^Oo/dKT01?o/dKT01Ol0
003olLn_o`000?ode:oo000000?onM:Q00?o0000oo_FWookeYl00_okeYl2o`0000;oomB500?o0000
oooDQOl000000_ojb5d2o`0001_ooo]Z00?o0000oookJ_oonfX0DooonfX009gooo]Z0ol0000Goook
JP;o00003OmmAH800ol0003oRDn4ohU?Q002ohU?Q0?o000000?oSU^@o`000?l000001_n?G9400ol0
003oV6>AoiQST@0>oiQST@Go00003OnSLY/01Ol0003oYGBLojEdW?nUM9co000001Go[7VL00?o0000
okB0W?ndP9`04_ndP9`2o`0000oo^hJK00?o0000okb7W?nlQi`01_nlQi`00ol0003o`X^Kol:;V`02
ol:;V`?o00002?o4SI`4o`000005olB6T_l0003oaXVBolJ9T_l000002Oo;S9000ol0003ocXnAolj?
T@09olj?T@?o00000ooARX@01Ol0003oeHf2omF=P_oESH;o000000GofI2200?o0000omV@P_oIT880
0_l0000RoookJP03o`000?oonf[ooo]Z0?oooo]ZN?oonfX3o`00017ooo]Z00?o0000oookJ_oonfX0
OOoonfX00ol0003ok=6ioncA^@06oncA^@05o`000?ode:oom=B_ooCD[ol000000_oidZ400ol0003o
nmJOoo_FW`03oo_FW`08o`000?ooe8GoomB5oooDQOl0003oomMoo`000?ojb5d2o`0001cooo]Z00?o
0000oookJ_oonfX0D_oonfX009_ooo]Z0_l0000HoookJP;o00003ommAH800ol0003oRDn4o`000002
o`0000;oSU^@0_l00008ohmLT@03o`000?nHHi7oV6>A00WoV6>A1Ol00002oia]W003o`000?nSLY_o
Xg:K00coXg:K00?o0000ojEdW?nUM9`00_nUM9`00ol0003o[7VLojaiW00CojaiW003o`000?ndP9co
]82L017o]82L00Co0000okF2WOnePYgo00003_nkQY/00ol0003o_8NLokb7W006okb7W003o`000?o2
Ri_o000000;o00000_o2Ri/00ol0003oa8fLolB=W00:olB=W0Co000000?oaXVBo`000?o;S9001oo;
S9000ol0003ocXnAolj?T@09olj?T@03o`000?o@TY7od9:A00Co00000ooESH800ol0003ofI22omV@
PP04omV@PP04o`000?oIT8;o0000ombCP@;o00008OoonfX00ol0003ooo]ZoookJP3ooookJWGooo]Z
0_l0000DoookJP;o0000O_oonfX00ol0003ok=6ioncA^@06oncA^@03o`000?ode:oom=B_00;om=B_
00?o0000ooWBXOl000001OokeYl01_l0003oomB5oooDQOooe8Go0000oooGO`;o000000?ollIAo`00
0?l000007?oonfX00ol0003ooo]ZoookJP1AoookJP00V?oonfX3o`0001Sooo]Z0_l000000om_>Woo
0000oge5PP0=oge5PP?o00001?n>Fi000ol0003oSebAohmLT@08ohmLT@03o`000?nHHi7oV6>A00Co
V6>A1Ol00007oia]W003o`000?nSLY_oXg:K00_oXg:K00?o0000ojEdW?nUM9`01?nUM9`00ol0003o
[7VLojaiW00AojaiW0;o00004_ndP9`01Ol0003o]H:MokF2WOnePYgo000000ko^hJK00?o0000okb7
W?nlQi`01OnlQi`3o`0000Co`X^K00?o0000olB=W?o4SI`03?o4SI`00ol0003oaY2LolJ@W004o`00
00Kobhb@00?o0000olj?TOo>Si402Oo>Si400ol0003od9:Aom2BT@03om2BT@?o000000?oeHf2o`00
0?oIT8801OoIT8800ol0003ofI22o`000003ombCP@;o00007ooonfX00ol0003ooo]ZoookJP3ooook
JW;ooo]Z0ol0000FoookJP;o0000OOoonfX00ol0003oiM73o`000006oncA^@03o`000?o_ekWo0000
00?om=B_0_l00005oo_FW`;o00000oooe8D01Ol0003oomMoo`000?l0003ollIA00;o00007?oonfX0
0ol0003ooo]ZoookJP1AoookJP00U_oonfX2o`0001Wooo]Z0_l000001?m^>Goo0000ofljOol0000;
oge5PP?o000000?oQ5>?o`000?n>Fi000_n>Fi02o`0000_oSebA00?o0000oiQSTOl000001?l0000<
oia]W003o`000?nSLY_oXg:K00[oXg:K00?o0000ojEdW?nUM9`01OnUM9`00ol0003o[7VLojaiW00@
ojaiW003o`000?n]Nigo000001;o]82L00Go0000okF2WOnePYgo]H:Mo`00000=ok^6V`03o`000?nl
Qico_8NL00?o_8NL0ol000000onlQico0000ol:;V`04ol:;V`03o`000?o4SIcoa8fL00_oa8fL00?o
0000olJ@W?o6T9`00_o6T9`00ol0003obi>Kol^CV`04o`000003ol^<T?l0003ocXnA00[ocXnA00?o
0000om2BTOo@TY401?o@TY400ol0003oeIB?omFDS`03o`0000KofI220_l00005ombCP@;o00007_oo
nfX00ol0003ooo]ZoookJP3ooookJVkooo]Z0ol0000IoookJP03o`000?oiZDko000007_ooo]Z00Go
0000onGA`ooUdL?oiM73o`000005oncA^@04o`000?o_ekWokmNio`0000?om=B_00?o0000oo_FWook
eYl00ookeYl01?l0003ooM^Lo`000?ooe8D2o`000004oooGOol0003o0000oo?6D@;o00007OoonfX0
0ol0003ooo]ZoookJP1@oookJP00TooonfX3o`0001Wooo]Z0_l00004ofhiO`;o00002OmmAH82o`00
00CoQ5>?00Co0000ohiKT?l0003o00003?n?G943o`00017oW6fL00?o0000oj=bVonSLY/02_nSLY/0
0ol0003oYGBLojEdW005ojEdW003o`000?n/NIco[7VL00_o[7VL9_l00006ok^6V`04o`000?nlQico
_8NLokb7W0;o00001?nlQi`00ol0003o`X^Kol:;V`03ol:;V`03o`000?o4SIcoa8fL00_oa8fL00?o
0000olJ@W?o6T9`00_o6T9`00ol0003obi>Kol^CV`04ol^CV`?o00002_o>Si400ol0003od9:Aom2B
T@04om2BT@06o`000?oEU8ooeIB?omFDSol0003of9R?0_l00005omV@PP03o`000?oLTh7og9>100Go
g9>10_l0000MoookJP03o`000?oonf[ooo]Z0?oooo]ZJ_oonfX3o`0001gooo]Z00?o0000ooVYC_l0
0000N_oonfX00ol0003oiM73onGA``02onGA``05o`000?o/dKWok=6ioncA^Ol000000oo_ekT01Ol0
003om=B_ooCD[oode:oo000000GonmJO00Co0000oogKW?l0003oomB50_l00002oooGO`04o`000?oc
aU7o0000o`0001kooo]Z00?o0000oookJ_oonfX0CooonfX0093ooo]Z0ol0000JoookJP;o00001_m^
>Gl2o`0000KoODF20ol00006ohACS`;o00002on?G943o`000003oi=WW?l0003oW6fL01;oW6fL00?o
0000oj=bVonSLY/02?nSLY/00ol0003oYGBLojEdW006ojEdW003o`000?n/NIco[7VL00;o[7VL2Ol0
0004ojf0Y004o`000?n^PjGo[X>Uo`00017o]8JT00?o0000okJ8YOnfR:D00_nfR:D00ol0003o^hbT
ok^<Y005ok^<Y0[o00001onlQi`01Ol0003o`X^Kol:;Voo2Ri_o000000koa8fL00?o0000olJ@W?o6
T9`00oo6T9`00ol0003obi>Kol^CV`04ol^CV`03o`000?o=UY_o000000;o00001oo>Si400ol0003o
d9:Aom2BT@05om2BT@04o`000?oEU8ooeIB?o`0000?of9R?0ol00002omV@PP;o00001_oLTh401?l0
003oh9Ioo`000?l0000KoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX3o`00023ooo]Z00?o0000
ooVYC_l00000NOoonfX00ol0003oiM73onGA``03onGA``04o`000?o/dKWok=6io`0000GokmNi00Go
0000ooCD[ol0003om]V^o`000003oo_FW`05o`000?omficooM^Lo`000?ooe8D00_l00002oooGO`04
o`000?ocaU7o0000o`0001kooo]Z00?o0000oookJ_oonfX0CooonfX008kooo]Z0_l0000LoookJP03
o`000?m^>GooKSUo00KoKSUo0_l00004oge5PP;o00001On4Dhl5o`0000WoSebA0ol00004oi=WW003
o`000?nLKIcoW6fL017oW6fL00?o0000oj=bVonSLY/01onSLY/00ol0003oYGBLojEdW004ojEdW0So
00003?n]P:@01Ol0003o[X>Uojj3YOn^PjGo0000013o]8JT00?o0000okJ8YOnfR:D00onfR:D00ol0
003o^hbTok^<Y009ok^<Y0?o00000_nmSjH6o`0000;o_8NL00Go0000ol:;Voo2Ri_o`X^Ko`00000=
olB=W003o`000?o6T9coaY2L00CoaY2L00?o0000ol^CVoo;Ti/01?o;Ti/00ol0003ocIJKolfFV`02
olfFV`?o00001?o>Si400ol0003od9:Aom2BT@05om2BT@04o`000?oEU8ooeIB?o`0000Kof9R?1?l0
0006ombCP@04o`000?oPUWooh9Ioon2FO`;o00006_oonfX00ol0003ooo]ZoookJP3ooookJV?ooo]Z
0ol0000SoookJP04o`000?oiZDkonJU>o`0007Sooo]Z00?o0000onGA`ooUdL<01?oUdL<00ol0003o
k=6io`000006onoG^@;o000000?om]V^o`000?okeYl00_okeYl01ol0003ooM^LoogKW?omfico0000
oooGOol000000_ooegl01?l0003ollIAo`000?l0000OoookJP03o`000?oonf[ooo]Z04kooo]Z002;
oookJP?o00007?oonfX2o`0000[oKSUo00?o0000oge5P_l000002Ol00004ohADT003o`000?n?G97o
SebA00CoSebA0ol00007oi=WW003o`000?nLKIcoW6fL017oW6fL00?o0000oj=bVonSLY/01_nSLY/0
0ol0003oYGBLo`000005o`0000?oZ7fV00?o0000ojf0Y?n]P:@03On]P:@00ol0003o[X>Uojj3Y@03
ojj3Y@03o`000?ndQZCo]8JT00co]8JT00?o0000okJ8YOnfR:D01?nfR:D00ol0003o^hbTok^<Y006
ok^<Y0Co00002_nmSjH8o`0000coa8fL00?o0000olJ@W?o6T9`01?o6T9`00ol0003obi>Kol^CV`03
ol^CV`03o`000?o=UY_ocIJK00KocIJK1?l00008om2BT@04o`000?oEU8ooeIB?o`0000Sof9R?0ol0
0005ombCP@03o`000?oPUWooh9Io00?oh9Io0_l0000IoookJP03o`000?oonf[ooo]Z0?oooo]ZH?oo
nfX2o`0002Kooo]Z00Co0000ooVYC_oiZDko0000MooonfX00ol0003oiM73onGA``06onGA``03o`00
0?o_ekWokmNi00GokmNi00Oo0000oo7K^Ol0003om]V^o`000?okeYoo000000CooM^L00?o0000oooG
Ool000000_ooegl01?l0003ollIAo`000?l0000PoookJP03o`000?oonf[ooo]Z04gooo]Z0028oook
JP?o00007OoonfX2o`0000_oKSUo1_l0000;ohADT004o`000?n?G97oSebAohmLT@?o00002_nCIi`0
0ol0003oW6fLoia]W00Aoia]W004o`000?nSLY_oXg:Koj=bV`Oo00002OnXOJH00ol0003o[H2Tojf0
Y00<ojf0Y003o`000?n^PjGo[X>U00Co[X>U00?o0000okB6Y?ndQZ@03?ndQZ@00ol0003o]XRUokJ8
Y@05okJ8Y@03o`000?nkS:Co^hbT00;o^hbT0ol00002ok^<Y003o`000?nmSjKo_HnV00_o_HnV00Co
0000ol6@Xoo1T:?o00000_o5U:D5o`0000Ooa8fL00?o0000olJ@W?o6T9`01?o6T9`00ol0003obi>K
ol^CV`03ol^CV`03o`000?o=UY_ocIJK00WocIJK0ol00006om2BT@03o`000?oEU8oo000000Wof9R?
00Co0000om^KSol0003o00001?oLTh400ol0003oh9Ioon2FO`05on2FO`;o00005ooonfX00ol0003o
oo]ZoookJP3ooookJUgooo]Z0ol0000XoookJP03o`000?oiZDkonJU>00;o0000MOoonfX00ol0003o
iM73onGA``07onGA``03o`000?o_ekWokmNi00CokmNi00Co0000oo7K^OoafkWolM^i0_l000000ook
eYoo0000oogKW003oogKW004o`000?ooegoo0000oooGO`;o000000?ollIAo`000?l000008?oonfX0
0ol0003ooo]ZoookJP1=oookJP00Q_oonfX2o`0001kooo]Z0_l0000;ofhiO`;o000000?oMdZ>o`00
0?n4E9003_n4E904o`0000koTfNL00?o0000oia]W?nLKI`03_nLKI`6o`0000;oYGZS00?o0000ojQm
Y_nXOJH03?nXOJH00ol0003o[H2Tojf0Y00:ojf0Y003o`000?n^PjGo[X>U00Go[X>U00?o0000okB6
Y?ndQZ@02ondQZ@00ol0003o]XRUokJ8Y@06okJ8Y@03o`000?nkS:Co^hbT00;o00001OnkS:@00ol0
003o_HnVokf?YP0;okf?YP03o`000?o1T:?o000000SoaIBU1Ol000000oo4SIco0000olJ@W006olJ@
W003o`000?o;Ti_obi>K00?obi>K00?o0000olfFVoo=UY/02Oo=UY/00ol0003od9VLom2IW003o`00
00?od9:A00?o0000omFDSol000002OoHV8l00ol0003ofi^?om^KS`03o`0000;og9>100?o0000on2F
OooPUWl01OoPUWl01?l0003ohiYno`000?l0000FoookJP03o`000?oonf[ooo]Z0?oooo]ZFOoonfX3
o`0002_ooo]Z00?o0000ooVYC_oiZDh00_l0001eoookJP03o`000?oUdL?oiM7300KoiM7300?o0000
onOFa?l000001Oo_ekT00ol0003olM^ioo7K^@02oo7K^@03o`000?okeYoo000000CooM^L00Ko0000
oooGOol0003oomMoo`000?olf7L3o`00027ooo]Z00?o0000oookJ_oonfX0C?oonfX008?ooo]Z0ol0
000OoookJP03o`000?mM;7_o000000[oKSUo00Go0000ogM:S_mgBXkoMdZ>o`00000>ohADT0;o0000
4OnCIi`00ol0003oW6fLoia]W009oia]W0Go00000_nOMZD00ol0003oYGZSojEjX`02ojEjX`03o`00
0?nXOJKoZ7fV00goZ7fV00?o0000ojf0Y?n]P:@02On]P:@00ol0003o[X>Uojj3Y@07ojj3Y@03o`00
0?ndQZCo]8JT00Wo]8JT00?o0000okJ8YOnfR:D01onfR:D3o`0000Ko^hbT00?o0000okf?Y_nmSjH0
3OnmSjH2o`0000goaIBU1?l00006olJ@W003o`000?o;Ti_obi>K00;obi>K00?o0000olfFVoo=UY/0
2Oo=UY/00ol0003od9VLom2IW003om2IW0?o000000?od9:Ao`000?l000002OoHV8l01_l0003ofi^?
om^KSooKVhoo0000om^KS`?o00001ooPUWl01Ol0003ohiYnon>JO_oSVWko000001Kooo]Z00?o0000
oookJ_oonfX0oooonfYEoookJP?o0000;_oonfX2o`000003ooVYC_l0003o000007Cooo]Z00?o0000
onGA`ooUdL<01_oUdL<01?l0003oimK4onOFa?l00004onoG^@03o`000?oafkWolM^i00ColM^i0_l0
0004oogKW0?o000000?oomMoo`000?olf7L00ol0000RoookJP03o`000?oonf[ooo]Z04_ooo]Z0021
oookJP;o00008?oonfX2o`0000;oGBak00?o0000ofhiOom^>Gl01_m^>Gl00ol0003oMdZ>ogM:SP03
ogM:SP03o`000?n4E93oQ5B@00[oQ5B@0_l000000on9H9_o0000oi=WW00@oi=WW003o`000?nLKIco
W6fL00CoW6fL1Ol00007oimfY@05o`000?nUNZ?oYGZSojEjXol000004?nXOJH00ol0003o[H2Tojf0
Y008ojf0Y003o`000?n^PjGo[X>U00So[X>U00?o0000okB6Y?ndQZ@02?ndQZ@00ol0003o]XRUokJ8
Y@05okJ8Y@Co00002?nkS:@00ol0003o_HnVokf?YP0=okf?YP;o00003_o5U:D00ol0003oaINVolFG
YP05o`000003olJ@W?l0003obi>K00?obi>K00?o0000olfFVoo=UY/02?o=UY/00ol0003od9VLom2I
W007om2IW0Co00002?oHV8l00ol0003ofi^?om^KS`02om^KS`03o`000?oKVhoofi^?00;o00001_oP
UWl01?l0003ohiYnon>JO_oSVWh2o`0001Gooo]Z00?o0000oookJ_oonfX0oooonfYBoookJP?o0000
<OoonfX2o`0000;onJU>0_l0001coookJP03o`000?oUdL?oiM7300KoiM7300Go0000onOFa?oWe/Co
imK4o`000003onoG^@03o`000?oafkWolM^i00ColM^i00Oo0000oo_OY_l0003o0000oogKW?l0003o
o]jH00;o000000?oomMoo`000?olf7L00ol0000RoookJP03o`000?oonf[ooo]Z04_ooo]Z001noook
JP?o00008OoonfX00ol0003oGBakoed/N`02oed/N`03o`000?m^>GooKSUo00CoKSUo00?o0000ogM:
S_mgBXh01OmgBXh00ol0003oQ5B@ohADT007ohADT0?o00000on9H9/00ol0003oTfNLoi=WW00?oi=W
W003o`000?nLKIco000000Co00003OnOMZD00ol0003oYGZSo`00000AojQmYP03o`000?n]P:Co[H2T
00Oo[H2T00?o0000ojj3YOn^PjD02On^PjD00ol0003o]8JTokB6Y008okB6Y003o`000?nfR:Go]XRU
00;o]XRU0ol00003okJ8Y@03o`000?nkS:Co^hbT00Go^hbT00?o0000okf?Y_nmSjH03_nmSjH00ol0
003oaIBUolFDY@0<olFDY@03o`000?o5UjKoaINV00KoaINV1?l000000oo;Ti_o0000olfFV`0:olfF
V`03o`000?o@VIcod9VL00Sod9VL0_l000000ooGWY[o0000o`000005omRHS`03o`000?oKVhoofi^?
00?ofi^?00Ko0000om^KSooKVhoo0000omjNSol00005on2FO`07o`000?oSVWkohiYnon>JO_l0003o
iYako`00000EoookJP03o`000?oonf[ooo]Z0?oooo]ZC_oonfX3o`0003Cooo]Z00Co0000onb?8_l0
003onJU>0_l0001boookJP03o`000?oUdL?oiM7300KoiM7300?o0000onOFa?oWe/@00ooWe/@00ol0
003okmNio`000007oo7K^@04ooCP^?l0003onmnVoo_OYP;o000000Coo]jHo`000?l0003oomMo0ol0
00000ooS`T7o0000oookJP0RoookJP03o`000?oonf[ooo]Z04[ooo]Z001koookJP?o00008_oonfX2
o`0000GoGBak00?o0000ofhiOom^>Gl00om^>Gl00ol0003oMdZ>ogM:SP06ogM:SP03o`000?n4E93o
Q5B@00GoQ5B@0_l00006ohUPV`03o`000?nCIicoTfNL00koTfNL0ol0000BoimfY@;o00004_nXOJH0
0ol0003o[H2Tojf0Y006ojf0Y003o`000?n^PjGo[X>U00_o[X>U00?o0000okB6Y?ndQZ@01_ndQZ@0
0ol0003o]XRUokJ8Y@03o`0000Oo]XRU00?o0000ok^<Y?nkS:@00onkS:@00ol0003o_HnVokf?YP0?
okf?YP03o`000?o5U:GoaIBU00coaIBU00?o0000olFGY_o5UjH01oo5UjH00ol0003obYRSolZHX`04
o`0000WocIJK00?o0000om2IW?o@VI`02?o@VI`00ol0003oeijJomNNVP02omNNVP?o00000_oHV8l0
0ol0003ofi^?om^KS`04om^KS`03o`000?oKVhoo000000;ogYj?0_l00003on2FO`05o`000?oSVWko
hiYnon>JO_l000000_oVW7/2o`0001Cooo]Z00?o0000oookJ_oonfX0oooonfY;oookJP;o0000>?oo
nfX00ol0003ok8lRo`000002o`00077ooo]Z00?o0000onGA`ooUdL<01_oUdL<00ol0003oimK4onOF
a004onOFa003o`000?o_ekWo000000KolM^i00?o0000ooCP^?l000000ookgjH6o`000004oo_MOOl0
003ohl91o`0002Cooo]Z00?o0000oookJ_oonfX0BOoonfX007Wooo]Z0_l0000ToookJP03o`000?mM
;7_oGBak00GoGBak00Go0000ofhiOom^>GooKSUoo`00000:ogM:SPKoQ5B@0_l00008ohUPV`03o`00
0?nCIicoTfNL00_oTfNL0ol000000onGLJGo0000oimfY@0AoimfY@;o00005?nXOJH00ol0003o[H2T
ojf0Y004ojf0Y003o`000?n^PjGo[X>U00Co[X>U6?l00006okJ8Y@03o`000?nkS:Co^hbT00?o^hbT
00?o0000okf?Y_nmSjH03_nmSjH2o`0000goaIBU00?o0000olFGY_o5UjH02Oo5UjH01?l0003obYRS
olZHXol00002olfLY0Co00001Oo=UY/00ol0003od9VLom2IW008om2IW003o`000?oGWY[oeijJ00Go
eijJ0ol00007om^KS`;o00001?oNWXl2o`000003on2FOol0003ohiYn00;ohiYn00Go0000onJLNooV
W7_o0000onZON@02o`0001;ooo]Z00?o0000oookJ_oonfX0oooonfY8oookJP?o0000>_oonfX01_l0
003ok8lRo`000?l0003ojJ@Vo`00073ooo]Z00?o0000onGA`ooUdL<01OoUdL<00ol0003oimK4onOF
a006onOFa003o`000?oafkWolM^i00GolM^i0_odh;P01Ol0003onmnVoo_OY_okgjKo000000;oo>BS
0_l00002oo_MO@03o`000?oS`T7o000002Cooo]Z00?o0000oookJ_oonfX0BOoonfX007Kooo]Z0ol0
000UoookJP03o`000?mM;7_oGBak00KoGBak0ol0000<ogM:SP?oQ5B@0ol0000;ohUPV`03o`000?nC
IicoTfNL00OoTfNL0ol00004oiMaY@03o`000?nOMZGoWgJU00ooWgJU00?o0000oj1hYol000005?nX
OJH00ol0003o[H2Tojf0Y00;o`0000So/H^^00?o0000okB<[?ndS:`01?ndS:`3o`0000Ko^96^4?l0
000<okf?YP04o`000?nnTJOo_Y6Wo`0000_oaIBU00?o0000olFGY_o5UjH02_o5UjH00ol0003obYRS
o`000007olfLY0?o000000?ocIJKo`000?o@VI`02_o@VI`00ol0003oeijJomNNVP07omNNVP;o0000
1ooKVhl00ol0003ogYj?omjNS`04omjNS`;o00001?oSVWh00ol0003oiYako`000003onZON@03o`00
0?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0oooonfY4oookJP?o0000?OoonfX01_l0003ok8lR
onb?8_l0003ojJ@Vo`0006oooo]Z00?o0000omkAbol000001_oUdL<00ol0003oimK4onOFa006onOF
a003o`000?oafkWolM^i00ColM^i00Oo0000ooCP^?odh;Som>2ho`000?okgjKo000000Coo>BS00Ko
0000oo_MOOokgGgo0000on?2@Ol0000UoookJP03o`000?oonf[ooo]Z04Sooo]Z001doookJP;o0000
9_oonfX2o`0000SoGBak0_l0000>ogM:SP03ohADT?l0003o000000koRF2K00?o0000oi=WW?nCIi`0
1?nCIi`3o`0000SoUg6U00?o0000oimfYOnOMZD03?nOMZD2o`0000;oX7RW00?o0000ojQmY_nXOJH0
3onXOJH6o`0000;o[XJ[00?o0000ok6;[_naRjh03_naRjh01?l0003o]8b/okB<[?ndS:`3o`0000oo
^96^00?o0000ok^AZonkTJ/00_nkTJ/00ol0003o_YJ]okjF[@02okjF[@So00001?nmSjH01?l0003o
_Y6WokjAYol0000;olFDY@03o`000?o5UjKoaINV00[oaINV00?o0000olZHXol000002_o=W:@3o`00
00Wod9VL00?o0000om:LWOl000002?oGWYX01?l0003ofJ6Ko`000?l00004om^KS`;o00001ooNWXl2
o`0000?ohiYn00?o0000onJLNol000001?oZWgT2o`00017ooo]Z00?o0000oookJ_oonfX0oooonfY0
oookJP?o0000@?oonfX01_l0003ok8lRonb?8_l0003ojJ@Vo`0006kooo]Z00Co0000omkAbooNdL_o
00001OoUdL<00ol0003oimK4onOFa006onOFa003o`000?oYf/Go000000GolM^i1?odh;P00ol0003o
nmnVo`000004oocTX`03o`000?okgGgo000000?o00009_oonfX00ol0003ooo]ZoookJP17oookJP00
LOoonfX3o`0002Oooo]Z00?o0000oed/NomM;7/01omM;7/00ol0003oJ3n<o`00000=ogM:SP;o0000
4?n9H9/01?l0003oTfNLoi=WW?nCIi`3o`0000_oUg6U00?o0000oimfYOnOMZD02onOMZD00ol0003o
X7RWoj1hY`03oj1hY`03o`000?nXOJKoZ7fV00OoZ7fV1ol00003ojR4[P05o`000?n^QZ_o[XJ[ojj6
Zol000004OnaRjh4o`000003okB<[?l0003o^96^013o^96^00Co0000ok^AZonkTJ_o00003OnnUZd;
o`0000OoaIBU00?o0000olFGY_o5UjH03?o5UjH2o`0000_ocIbT00?o0000oljNY_l000000_l00006
om2IW003o`000?oBW9go000000SoeijJ00Co0000omVQVooIXI_ofJ6K0_l00002om^KS`03o`000?oN
WXoo000000KogYj?00?o0000on:RS_l000000ol000000ooVW7_o0000onZON@05onZON@03o`000?oo
nf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0oooonfXmoookJP?o0000@ooonfX00ol0003ok8lRonb?
8P03o`0006gooo]Z00?o0000omkAbooNdL/00_oNdL/01Ol0003oiM73onGA`ooUdL?o000000SoimK4
00Co0000onWJaOoYf/Go00001?oafkT00ol0003om>2hooCP^002ooCP^003o`000?okgjKo000000?o
o>BS0_l000000ookgGgo0000ooCKL@02o`0002Kooo]Z00?o0000oookJ_oonfX0AooonfX006kooo]Z
0ol0000XoookJP;o00002?mM;7/2o`0000;oJ3n<00?o0000ogM:S_mgBXh02OmgBXh2o`000003ogiH
V_l0003oRF2K00ooRF2K1?l0000>oiMaY@03o`000?nOMZGoWgJU00[oWgJU00?o0000oj1hYonPN:L0
1?nPN:L00ol0003oZ7fVojQmYP07o`0000[oZ8B^00Co0000ojj6Zon^QZ_o00004?naRjh4o`0000;o
]8b/00?o0000okRA[_nhTJh04?nhTJh00ol0003o^i6[o`00000AokjF[@05o`000?nnV;7o_YRaokjH
/Ol000000oo3VJd5o`0000;oaIBU00?o0000olFGY_o5UjH03?o5UjH00ol0003ocIbTolfLY009olfL
Y003o`000?o>WZKocYjV00?ocYjV0_l00004om2IW003o`000?oBW9go000000OoeijJ00?o0000omVQ
VooIXI/01?oIXI/3o`0000;ogYj?00?o0000omjNSooNWXl00ooNWXl00ol0003ohZ:>on:RSP02on:R
SP03o`000?oVW7_o000000KojYmi0_l0000@oookJP03o`000?oonf[ooo]Z0?oooo]Z>OoonfX3o`00
04Oooo]Z00?o0000onb?8_o/Sb800_l0001/oookJP03o`000?oNdL_og]7;00Cog]7;00Co0000onGA
`ooUdL?o00002?oWe/@01?l0003ojM[5onWJaOl00004oo7K^@Kom>2h00Co0000oocTXooli:?oo>BS
0ol000000ookgGgo0000ooCKL@02o`0002Oooo]Z00?o0000oookJ_oonfX0A_oonfX006cooo]Z0_l0
000ZoookJP03o`000?m877Ko000000OoGBak00?o0000ofPoS?mX?h`00_mX?h`00ol0003oMdZ>ogM:
SP07ogM:SP;o00000omnF9X00ol0003oRF2KohUPV`0=ohUPV`;o00004OnGLJD00ol0003oWgJUoimf
Y@08oimfY@;o00001?nPN:L6o`0001;oZ8B^0_l0000?ok6;[P;o00000onaRjh00ol0003o]8b/o`00
000DokRA[P03o`000?nnUZgo_YJ]00oo_YJ]00?o0000okjH/OnnV;400onnV;400ol0003o`iV]ol>I
[@05ol>I[@Co00003Oo5UjH00ol0003ocIbTolfLY009olfLY003o`000?o>WZKocYjV00GocYjV1?l0
0002om:LW@03o`000?oGWY[oeijJ00GoeijJ00?o0000omVQVooIXI/01_oIXI/2o`000003omjNSol0
003ogYj?00CogYj?00?o0000on:RS_oRXXh00_oRXXh3o`0000KojYmi00?o0000onjSMol000004?oo
nfX00ol0003ooo]ZoookJP3ooookJSKooo]Z0_l0001:oookJP;o000000Cok8lRo`000?l0003o0000
J_oonfX00ol0003og]7;omkAb`05omkAb`03o`000?oUdL?o000000SoimK400?o0000onWJaOoYf/D0
0_oYf/D01?l0003olM^ioo7K^Ol00006ooCP^0Go000000Goo>NLo`000?l0003o0000ooCKL@02o`00
02Sooo]Z00?o0000oookJ_oonfX0AOoonfX006Wooo]Z0ol0000[oookJP04o`000?m877KoB1afo`00
00GoGBak0_l00005ofPoS003o`000?mgBXkoMdZ>00CoMdZ>0ol00005ogiHVP03o`000?n9H9_oRF2K
00_oRF2K0_l000000on>JjGo0000oiMaY@0@oiMaY@03o`000?nOMZGoWgJU00OoWgJU00?o0000oj1h
Yol000001?l00003oj>1[`03o`000?nXQ:koZ8B^017oZ8B^0_l0000=ok6;[P?o00001OnaRjh2o`00
01Co^96^0_l0000@okjF[@03o`000?nnV;7o_YRa00Co_YRa00?o0000ol>I[Oo3VJd01_o3VJd00ol0
003oaYj_olJN[`05o`0000OoaINV0_l0000:olfLY003o`000?o>WZKocYjV00WocYjV0ol000000ooB
W9go0000omNNVP05omNNVP03o`000?oIXI_ofJ6K00KofJ6K00?o0000ombUVol000000_l00003omjN
S`03o`000?oRXXkohZ:>00?ohZ:>00Co0000onFTRol0003o00001OoZWgT01?l0003okZ=gonjSMol0
000?oookJP03o`000?oonf[ooo]Z0?oooo]Z<ooonfX3o`0004gooo]Z1Ol0001YoookJP03o`000?oN
dL_og]7;00Oog]7;00?o0000onOFa?oWe/@01_oWe/@00ol0003ojM[5onWJa@03onWJa@03o`000?oa
fkWolM^i00Gom>2h0ol00003oocTX`04o`000?oliicoo>NLo`0000;om=]a0_l0000XoookJP03o`00
0?oonf[ooo]Z04Gooo]Z001WoookJP;o0000;OoonfX2o`0000;oB1af00?o0000oed/NomM;7/00_mM
;7/00ol0003oJ3n<ofPoS005ofPoS003o`000?mgBXkoMdZ>00;oMdZ>0_l00008ogiHVP03o`000?n9
H9_oRF2K00SoRF2K0ol00003ohi[Y@03o`000?nGLJGoUg6U013oUg6U00?o0000oimfYOnOMZD00onO
MZD5o`0000SoXh6_00?o0000ojR4[_nXQ:h04?nXQ:h00ol0003oZXN`o`00000:ok6;[P?o00002?na
Rjh00ol0003o^96^okRA[P0BokRA[P03o`000?ngT[3o000000oo_YJ]00?o0000okjH/OnnV;401Onn
V;400ol0003o`iV]ol>I[@05ol>I[@03o`000?o6WZooaYj_00KoaYj_1?l00002olFGYP04o`000?o7
VJOoaiVWo`0000WocIbT00?o0000oljNY_o>WZH02Oo>WZH00ol0003od::Xom2RZ004o`0000CoeijJ
00?o0000omVQVooIXI/01_oIXI/01?l0003og:FKombUVooLYI/2o`0000;ogYj?00?o0000on:RS_oR
XXh01?oRXXh2o`000003onVXR_l0003ojYmi00?ojYmi00Go0000onjSMoo^XgOokZ=go`00000?oook
JP03o`000?oonf[ooo]Z0?oooo]Z;ooonfX3o`00053ooo]Z1Ol0001XoookJP03o`000?oNdL_og]7;
00Sog]7;00?o0000onOFa?oWe/@01OoWe/@00ol0003ojM[5onWJa@04onWJa@03o`000?oafkWo0000
00;om>2h0ol000000oodh;So0000o`000002oocTX`04o`000?oliicoo>NLoocWW0;o000000?om=]a
o`000?l00000:OoonfX00ol0003ooo]ZoookJP14oookJP00I?oonfX3o`0002kooo]Z00?o0000od@I
MOl000000_m877H01Ol0003oGBakoed/NomM;7_o000000SoJ3n<00?o0000ogM:S_mgBXh00_l0000;
ogiHVP03o`000?n9H9_oRF2K00GoRF2K0_l00007ohi[Y@03o`000?nGLJGoUg6U00ooUg6U00?o0000
oimfYOl000001?l0000=oj>1[`03o`000?nXQ:koZ8B^00koZ8B^00Co0000ojZ7/?nZQk3o00001ona
Rjh3o`0000_o/H^^00?o0000okRA[_nhTJh04OnhTJh01Ol0003o]i:`okNB/?ngT[3o000000go_YJ]
00?o0000okjH/OnnV;401onnV;400ol0003o`iV]ol>I[@03ol>I[@03o`000?o6WZooaYj_00_oaYj_
1?l000000oo7VJOo0000olfLY008olfLY003o`000?o>WZKocYjV00SocYjV00?o0000om2RZ?o@XZP0
0_o@XZP00ol0003oeJ>SomFSX`04o`0000SofJ6K00?o0000ombUVooLYI/01?oLYI/3o`0000KohZ:>
0_l00002onVXRP;o00000_oZWgT00ol0003okZ=gonjSM`02onjSM`;o00003_oonfX00ol0003ooo]Z
oookJP3ooookJR_ooo]Z0ol0001DoookJPCo0000IooonfX00ol0003og]7;omkAb`08omkAb`03o`00
0?oPeLco000000KoimK400?o0000onWJaOoYf/D01OoYf/D4o`0000?om>2h00Ko0000ooKU]_ofiKKo
0000oocTXol00003oocWW0;o000000?om=]ao`000?l00000:_oonfX00ol0003ooo]ZoookJP13oook
JP00HOoonfX3o`00033ooo]Z00Co0000od@IMOm46GGo00000_m877H01?l0003oGBako`000?l00009
ofPoS0?o00003OmnF9X00ol0003oRF2KohUPV`03ohUPV`;o00002On>JjD00ol0003oUg6UoiMaY@0>
oiMaY@?o00000_nQOJ`2o`0000koXh6_00?o0000ojR4[_nXQ:h03OnXQ:h00ol0003oZXN`ojZ7/002
ojZ7/004o`000?naRjko/H^^ok6;[P?o00003OnaRjh00ol0003o/Hf`o`00000AokRA[P03o`000?ng
T[3o]i:`00;o]i:`00?o0000okjF[OnnUZd02onnUZd00ol0003o_YRaokjH/@07okjH/@03o`000?o3
VJgo`iV]00?o`iV]00?o0000olJN[oo6WZl03?o6WZl00ol0003oaYnaolJO/@04o`0000KocIbT00?o
0000oljNY_o>WZH02Oo>WZH00ol0003od::Xom2RZ003om2RZ003o`000?oEXj?oeJ>S00;oeJ>S0_l0
0007omVQV`03o`000?oLYI_og:FK00Cog:FK00Co0000ombUVol0003o00001OoRXXh2o`0000CojJR:
00?o0000onZONOl000001?o^XgL00ol0003olJMco`00000=oookJP03o`000?oonf[ooo]Z0?oooo]Z
:?oonfX3o`0005Oooo]Z00Co0000omUb0?l0003o0000IOoonfX2o`0000[og]7;00Co0000on3Ec?oP
eLco00001OoWe/@00ol0003ojM[5onWJa@04onWJa@?o00001_odh;P00ol0003om^FfooKU]P02o`00
00Coo>NL00?o0000ooCKLOl000000_l0000ZoookJP03o`000?oonf[ooo]Z04?ooo]Z001OoookJP;o
0000<_oonfX00ol0003oA1Ueod@IM@02od@IM@04o`000?m877Ko0000o`0000[oJ3n<0_l0000?ogiH
VP03o`000?n9H9_oRF2K00?o00002on>JjD00ol0003oUg6UoiMaY@0;oiMaY@?o000000GoVWV]o`00
0?nQOJcoXGf/o`00000@oj>1[`03o`000?nXQ:koZ8B^00_oZ8B^0_l00005ojZ7/004o`000?naRjko
0000o`0000oo/H^^00Co0000ok6=/?naSK3o00004?nhTJh00ol0003o]i:`okNB/003okNB/003o`00
0?nnUZgo_YJ]00[o_YJ]00?o0000okjH/OnnV;402?nnV;400ol0003o`iV]ol>I[@02ol>I[@03o`00
0?o6WZooaYj_00coaYj_00?o0000olJO/Oo6Wk400_o6Wk400ol0003obj2]ol^P[@04o`0000;ocIbT
00?o0000oljNY_o>WZH02?o>WZH00ol0003od::Xom2RZ004om2RZ003o`000?oEXj?oeJ>S00;oeJ>S
00?o0000omRWY?l000001_oIXI/00ol0003og:FKombUV`05ombUV`;o000000?ogjRKo`000?oRXXh0
0ooRXXh2o`0000GojJR:0_l00004onjSM`04o`000?oaYg?olJMco`0000gooo]Z00?o0000oookJ_oo
nfX0oooonfXToookJP?o0000FooonfX3o`0006Cooo]Z00?o0000om3@fOl000002OoNdL/00ol0003o
h=G<on3Ec002on3Ec005o`000?oWe/CoimK4onOFa?l000001?oYf/D3o`000004onWJaOl0003ok=o5
o`0000Com>2h00Co0000ooKU]_ofiKKom^Ff0_l00003oocWW0;o000000?om=]ao`000?l00000;?oo
nfX00ol0003ooo]ZoookJP12oookJP00G?oonfX3o`0003?ooo]Z00?o0000od@IMOm46GD00om46GD0
0ol0003oB1afo`00000:ofPoS003o`000?maCYWo000000ooOURJ0ol0000>ohi[Y@03o`000?nGLJGo
Ug6U00SoUg6U0ol00005oiYi[@;o00004_nSPJl00ol0003oZ8B^ojR4[P09ojR4[P03o`000?nZQk3o
ZXN`00CoZXN`0ol0000@ok6;[P05o`000?naSK3o/Hf`ok6=/?l000003onhTJh00ol0003o]i:`okNB
/005okNB/003o`000?nnUZgo_YJ]00So_YJ]00?o0000okjH/OnnV;402_nnV;401Ol0003o`iV]ol>I
[Oo3VJgo000000goaYj_00?o0000olJO/Oo6Wk400oo6Wk400ol0003obj2]ol^P[@04ol^P[@?o0000
2_o>WZH00ol0003od::Xom2RZ004om2RZ005o`000?oEXj?oeJ>SomFSXol000000ooHYj@2o`0000Co
fJ6K00?o0000ombUVooLYI/01_oLYI/00ol0003ogjRKomnXV`02o`0000?ohZ:>00?o0000onVXR_oY
Z8X01?oYZ8X2o`0000?okZ=g00Go0000oo6WLooaYg?olJMco`00000=oookJP03o`000?oonf[ooo]Z
0?oooo]Z8OoonfX2o`0005kooo]Z1?l0001RoookJP05o`000?o@d=Wod=3Iom3@fOl000001ooNdL/0
0ol0003oh=G<on3Ec004on3Ec005o`000?oWe/CoimK4o`000?oYf/D00ol00003onWJa@04o`000?o/
glGok=o5o`0000?om>2h00?o0000ooKU]_ofiKH00_ofiKH00ol0003oo>NLoocWW002oocWW0;o0000
00Com=]ao`000?l0003o0000;?oonfX00ol0003ooo]ZoookJP11oookJP00FOoonfX3o`0003Gooo]Z
00?o0000od@IMOm46GD01?m46GD3o`0000WoJ3n<00Co0000og5>VOmaCYWo00003_mnF9X2o`00013o
SV^U00?o0000oiMaYOnGLJD01OnGLJD3o`0000OoVWV]0_l0000Coj>1[`03o`000?nXQ:koZ8B^00So
Z8B^00?o0000ojZ7/?nZQk000_nZQk03o`0000;oZXN`00?o0000ok6;[_naRjh01OnaRjh[o`0000Co
_YJ]00?o0000okjH/OnnV;402onnV;401?l0003o`iV]ol>I[Ol0000>olJN[`03o`000?o6Wk7oaYna
00CoaYna00?o0000ol^P[Oo;X:d01?o;X:d00ol0003ocZF^o`000002o`0000OocYjV00?o0000om2R
Z?o@XZP01Oo@XZP01?l0003oeJ>SomFSXol00005omRWY0;o00000_oIXI/00ol0003og:FKombUV`05
ombUV`;o00001?oOZ9/01?l0003ohZ:>on:RS_l00006onVXRP03o`000?o/ZhWo000000?okZ=g00Go
0000oo6WLooaYg?olJMco`00000<oookJP03o`000?oonf[ooo]Z0?oooo]Z7_oonfX3o`0005oooo]Z
00?o0000o`00HOl000000_l0001PoookJP;o00001Oo@d=T00ol0003og]7;omkAb`03omkAb`03o`00
0?oPeLcoh=G<00Goh=G<00?o0000onOFa?l000000_l00006onWJa@05o`000?o/glGok=o5oncOaOl0
00000_odh;P00ol0003om^FfooKU]P02ooKU]P03o`000?oliicoo>NL00;oo>NL0ol000000ooZefCo
0000o`00000/oookJP03o`000?oonf[ooo]Z047ooo]Z001GoookJP;o0000=ooonfX00ol0003oA1Ue
od@IM@04od@IM@;o000000?oEc68o`000?mX?h`01_mX?h`2o`0000?oLDjI00?o0000ogiHV_mnF9X0
2_mnF9X2o`000003ohETYOl0003oSV^U013oSV^U00Co0000oiMaYOnGLJGoUg6U0ol00007oiYi[@?o
000000?oW7f`o`000?nSPJl04_nSPJl00ol0003oZ8B^ojR4[P07ojR4[P03o`000?nZQk3oZXN`00?o
00000_nZQk04o`000003ok6;[_l0003o000000Co00001_n`T;D00ol0003o/iJiok>F^@05ok>F^@03
o`000?nfUKGo]YFe00[o]YFe00?o0000okZK^OnjVkT01onjVkT00ol0003o_9VdokbI]003okbI]0So
00002_nnV;400ol0003o`iV]o`00000>olJN[`03o`000?o6Wk7oaYna00GoaYna00?o0000ol^P[Oo;
X:d00oo;X:d00ol0003ocZF^oljU[P03oljU[P;o00001?o>WZH00ol0003od::Xom2RZ006om2RZ003
o`000?oEXj?o000000Sof:NT0_l00008ombUV`03o`000?oOZ9_o000000CogjRK00?o0000on:RS_l0
00001_oYZ8X00ol0003ok:^9onb[R@02o`000003onjSMol0003olJMc00?olJMc00?o0000oookJ_oo
nfX02_oonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z0ol0001RoookJP03o`000?l0067o001Q00;o
0000GooonfX00ol0003ob/kMo`000006om3@f@05o`000?oNdL_og]7;omkAbol000001ooPeL`3o`00
00SojM[500?o0000oncOaOo/glD00_o/glD00ol0003om>2ho`000004ooKU]P;o00000oolii`02?l0
003on^VFo`000?l0003oj]MTo`000?oonf[o0000;?oonfX00ol0003ooo]ZoookJP10oookJP00E?oo
nfX3o`0003Sooo]Z00?o0000od@IMOm46GD01?m46GD01Ol0003oE328o`000?mG<HSo000000KoJ3n<
00?o0000og5>VOmaCYT00omaCYT00ol0003oOURJogiHVP08ogiHVP;o00000on5I:D00ol0003oSV^U
ohi[Y@0?ohi[Y@Co00002?nJNJd2o`0000CoW7f`00?o0000oj>1[onSPJl04OnSPJl00ol0003oZ8B^
ojR4[P06ojR4[PWo00000on/SkP00ol0003o/92eok2@]@0:ok2@]@03o`000?ncU[Wo/iJi00Ko/iJi
00?o0000okJE]OnfUKD02OnfUKD00ol0003o^Y^iokZK^@08okZK^@03o`000?nlVKCo_9Vd00Go_9Vd
00?o0000oknO^?noWkP00onoWkP7o`0000Co_YRa0_l0000=olJN[`03o`000?o6Wk7oaYna00KoaYna
00?o0000ol^P[Oo;X:d00_o;X:d00ol0003ocZF^oljU[P06oljU[P?o000000?ocYjVo`000?o@XZP0
1oo@XZP00ol0003oeJ>So`000009omRWY0;o00001ooLYI/01?l0003ogjRKomnXVol00004omnXV`;o
00001_oYZ8X00ol0003ok:^9onb[R@02onb[R@;o00001?oaYg<2o`0000cooo]Z00?o0000oookJ_oo
nfX0oooonfXFoookJP?o0000IOoonfX00ol0003o001Qo`00H@02o`0005kooo]Z00Go0000ol[>gOo:
c]gob/kMo`000006om3@f@03o`000?oNdL_o000000Goh=G<0ol00002on3Ec003o`000?oYf/GojM[5
00GojM[500?o0000oncOaOo/glD00oo/glD00ol0003om>2ho`000004ooKU]P03o`000?ogjK?o0000
00;oo>NL00Ko0000oo[YU_l0003o0000on[GI?l00002oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o
0000oookJ_oonfX0?ooonfX005;ooo]Z0_l0000joookJP;o00001Om46GD01?l0003oE328oe@`R?mD
<8P2o`0000GoJ3n<00?o0000og5>VOmaCYT01OmaCYT00ol0003oOURJogiHVP04ogiHVP?o00001_n5
I:D00ol0003oSV^Uohi[Y@0=ohi[Y@;o00002?nJNJd3o`0000OoW7f`00?o0000oj>1[onSPJl04OnS
PJl01?l0003oZ8B^ojR4[_nXQ:h6o`0000_o[8nh00?o0000ok2@]On`T;D01on`T;D2o`0000[o/iJi
00?o0000okJE]OnfUKD01onfUKD00ol0003o^Y^iokZK^@0:okZK^@03o`000?nlVKCo_9Vd00?o_9Vd
00?o0000oknO^?noWkP02onoWkP7o`0000_oaYj_00?o0000olJO/Oo6Wk402?o6Wk401Ol0003obj2]
ol^P[Oo;X:go000000_ocZF^0ol00008om2RZ0;o00002OoHYj@01?l0003ofZZVo`000?l00005ombU
V`05o`000?oOZ9_ogjRKomnXVol000000ooOZ9/3o`0000CojJR:00?o0000onb[ROo/ZhT01?o/ZhT0
0ol0003olJMcoo6WL`02oo6WL`03o`000?oeZVoo000000_ooo]Z00?o0000oookJ_oonfX0oooonfXC
oookJP?o0000IooonfX01?l0003o001Qo`00HOl00643o`0005cooo]Z00?o0000ol[>gOo:c]d00oo:
c]d00ol0003od=3Iom3@f@04om3@f@04o`000?oPeLcoh=G<on3Ec0?o00001?oPeL`00ol0003oh]W=
o`000006onWJa@03o`000?o/glGok=o500Cok=o500?o0000ooKU]_ofiKH00oofiKH00ol0003omnVc
o`000002oocWW003o`000?ojjIKo000000;oj]MT00Co0000oookJ_oonf[o0000;?oonfX00ol0003o
oo]ZoookJP0ooookJP00CooonfX3o`0003_ooo]Z00?o0000obX5K?l000001?m46GD00ol0003oE328
oe@`R002oe@`R0;o00000omX?h`2o`0000SoLDjI00?o0000ogiHV_mnF9X00_mnF9X2o`0000WoQFBU
00?o0000ohi[YOn>JjD02_n>JjD3o`000003oi9c[Ol0003oVWV]00GoVWV]0_l0000:oiam/003o`00
0?nSPJooXh6_00ooXh6_2Ol0000>ojb?^003o`000?n`T;Go/92e00Ko/92e00?o0000ok>F^OncU[T0
2_ncU[T00ol0003o]YFeokJE]@06okJE]@03o`000?njVkWo^Y^i00_o^Y^i00?o0000okbI]?nlVK@0
0_nlVK@00ol0003o_inhoknO^00?oknO^0;o00000_o3XKH4o`0000OoaYj_00?o0000olJO/Oo6Wk40
2?o6Wk401?l0003obj2]ol^P[Ol0000<oljU[P03o`000?o?Yk3ocjN`00?o00001Oo@XZP00ol0003o
f:NTomRWY007omRWY003o`000?oJZZKofZZV00;ofZZV0_l00003ombUV`05o`000?oOZ9_ogjRKomnX
Vol000000ooOZ9/2o`000003onJ^V?l0003o000000;ojJR:00?o0000onb[ROo/ZhT01?o/ZhT2o`00
00?olJMc00Co0000ooFZKooeZVoo00002ooonfX00ol0003ooo]ZoookJP3ooookJPoooo]Z0ol0001Z
oookJP04o`000?l0067o001Qo`00H@Co0000F_oonfX00ol0003ob/kMol[>g@05ol[>g@03o`000?o@
d=Wod=3I00;od=3I1Ol00006on3Ec004o`000?oRfLgoh]W=o`0000GojM[500?o0000oncOaOo/glD0
1Oo/glD00ol0003om^FfooKU]P02ooKU]P06o`000?ogjK?omnVco`000?oliico00000_ojjIH01?l0
003oj]MTon[GI?l00003oookJP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0?_oonfX0
04cooo]Z0ol0000moookJP04o`000?lZ1Fco:PE/o`0000;oA1Ue0_l00006oe@`R004o`000?mX?hco
J3n<o`0000[oLDjI00?o0000ogiHV_mnF9X00_l0000;ohETY@03o`000?n>JjGoSV^U00OoSV^U0ol0
0004oi9c[@03o`000?nJNJgoVWV]00;oVWV]0_l0000<oiam/003o`000?nSPJooXh6_00[oXh6_1Ol0
0002ojB7]PGo00004?n/SkP00ol0003o/92eok2@]@05ok2@]@03o`000?ncU[Wo/iJi00_o/iJi00?o
0000okJE]OnfUKD01OnfUKD00ol0003o^Y^iokZK^@0<okZK^@05o`000?nlVKCo_9VdokbI]?l00000
4OnoWkP00ol0003o_Z6lo`000006ol>Q]PCo00000_o6WZl00ol0003oaYnaolJO/@09olJO/@04o`00
0?o;X:gobj2]o`0000_ocZF^00?o0000olnW/?o?Yk001?o?Yk03o`0000;od::X00?o0000omRWY?oH
Yj@01ooHYj@00ol0003ofZZVomZZYP04omZZYP?o00001OoOZ9/00ol0003ogjRKo`000002on>]W003
o`000?oV[YSoiZjH00?o00001_o/ZhT00ol0003ol:n7o`000002oo6WL`05o`000?oeZVoomJY_ooFZ
Kol000002ooonfX00ol0003ooo]ZoookJP3ooookJPcooo]Z0_l0001/oookJP;o00000ol006400ol0
003o001Do`0]]@03o`0005Kooo]Z0_l00008ol[>g@04o`000?o@d=Wod=3Iom3@f@Co00001ooPeL`0
0ol0003oh]W=on;Ic@02on;Ic@05o`000?oYf/GojM[5onWJaOl000001oo/glD2o`0000Com^Ff00Ko
0000ooOY/oogjK?o0000oocWW?l00002oo[YUP04o`000?oZefCo0000o`0000Cooo]Z00?o0000oook
J_oonfX0:_oonfX00ol0003ooo]ZoookJP0moookJP00B_oonfX2o`0003oooo]Z00Co0000obX5K?lZ
1Fco00000_m46GD00ol0003oE328oe@`R006oe@`R003o`000?mX?hco000000_oLDjI0ol0000=ohET
Y@03o`000?n>JjGoSV^U00GoSV^U0_l00008oi9c[@Co00003_nLOK000ol0003oXh6_oj>1[`05oj>1
[`Go00001OnTQkH5o`0001?o[8nh00?o0000ok2@]On`T;D00on`T;D00ol0003o/iJiok>F^@0=ok>F
^@03o`000?nfUKGo]YFe00?o]YFe00?o0000okZK^OnjVkT03OnjVkT01?l0003o_9VdokbI]?l0000A
oknO^005o`000?nnXKco_Z6lokjQ_?l000002Oo3XKH4o`0000_oaYna0_l0000;oljU[P03o`000?o?
Yk3ocjN`00SocjN`1?l00008omRWY003o`000?oJZZKofZZV00KofZZV0_l00005omnXV`;o00000_oS
[I`00ol0003oiZjHonJ^V002onJ^V0;o00001Oo/ZhT01_l0003ol:n7oo2_Qol0003olJMco`0000Co
mJY_00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP3ooookJPWooo]Z0ol0001^oookJP;o
00000_l006401Ol0003o:b:Bo`000?l0003o02fe00;o016K00?o0000oookJ_oonfX0D_oonfX00ol0
003ob/kMol[>g@09ol[>g@?o00001?oBe=X00ol0003oh=G<on3Ec003on3Ec003o`000?oRfLgoh]W=
00Coh]W=00Co0000onWJaOoYf/Go00001_o/glD01?l0003ok^C4onkTa?l00002ooKU]P03o`000?og
jK?omnVc00;omnVc0_l000001?ojjIKo0000o`000?oZef@2o`0000Gooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0moookJP00AooonfX3o`00047ooo]Z00Ko0000obX5K?lZ1Fco0000
od@IMOl00009oe@`R0?o00002_maCYT2o`0000ooQFBU00?o0000ohi[YOn>JjD00_n>JjD3o`0000So
TW>]0ol0000Boiam/003o`000?nSPJoo000000Co00001onTQkH3o`0000;oY8Nf0_l0000Dojb?^004
o`000?n`T;Go/92eok2@]@;o00004?ncU[T00ol0003o]YFeokJE]@02okJE]@03o`000?njVkWo^Y^i
00oo^Y^i0_l0000AoknO^003o`000?nnXKco_Z6l00;o_Z6l00?o0000ol>Q]_o3XKH02?o3XKH00ol0
003oajNiolNW^@05o`0000KoaYna00?o0000oljU[_o>YJh02_o>YJh00ol0003ocjN`olnW/009olnW
/004o`000?o@Z[?o0000o`0000Kof:NT00?o0000omZZY_oJZZH01ooJZZH01?l0003ogJjWo`000?l0
0003omnXV`;o00000_oS[I`00ol0003oiZjHonJ^V002onJ^V003o`000?oZ/YOo000000Cok:^900Co
0000oo2_Qoo`[hOol:n70_l00004ooFZK`03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
oooonfX5oookJP?o0000L?oonfX3o`0000;o001Q00?o0000ob/RT_l000000_l000001?l0;KGo016K
o`0AVol0001BoookJP03o`000?o:c]gob/kM00Oob/kM0ol000000oo:c]go0000om;DfP05om;DfP05
o`000?oPeLcoh=G<on3Ec?l000001ooRfLd00ol0003ojM[5o`000007oncOa@04o`000?o^i<Cok^C4
o`0000;om^Ff00?o0000ooOY/oogjK<00_ogjK<00ol0003on^VFoo[YUP02o`000003on[GI?l0003o
oo]Z00Gooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0loookJP00AOoonfX2o`00
04?ooo]Z0_l00002obX5K0;o00002OmD<8P01?mQA9So0000og1?Vom`Ci/2o`0000OoLDjI00?o0000
ogUKY?l000004?n5I:D4o`0000SoTW>]0ol00002oi=g/@03o`000?nLOK3oW7f`00koW7f`1?l0000:
ojB7]P;o00000onTQkH2o`000003ojJ>^ol0003o[8nh01?o[8nh00Co0000ok2@]On`T;Go00004_nc
U[T01Ol0003o]YFeokJE]OnfUKGo000001;o^Y^i00?o0000oknO^?noWkP03onoWkP00ol0003o_Z6l
okjQ_003okjQ_003o`000?o3XKKo`j6f00Oo`j6f00?o0000olNW^Oo7YkT01_o7YkT4o`0000;oaYna
00?o0000oljU[_o>YJh02Oo>YJh00ol0003ocjN`olnW/009olnW/005o`000?o@Z[?od:Zco`000?oE
Zjd00ol00003omRWY003o`000?oJZZKofZZV00KofZZV00?o0000omf^YooM[ZL00_oM[ZL01Ol0003o
gjRKomnXVooOZ9_o000000?ohjfL00Go0000onJ^V?oV[YSoiZjHo`000002onZbU`04o`000?o/ZhWo
k:^9o`0000Gol:n700?o0000ooFZKooeZVl00_oeZVl2o`0000_ooo]Z00?o0000oookJ_oonfX0oooo
nfX1oookJP?o0000L_oonfX02?l0003o<1=ko`000?l1073o0000o`00HOl0003o:b:B0_l00003o`0]
]@;o016K00?o0000oookJ_oonfX0C_oonfX00ol0003ob/kMol[>g@05ol[>g@?o00000_o:c]d00ol0
003oc=7No`000007om;DfP03o`000?oPeLco000000Woh]W=00?o0000oncOaOo/glD01Oo/glD01ol0
003ok^C4onkTa?o^i<Co0000ooKU]_l000001OogjK<00ol0003on^VFoo[YUP04o`0000Oooo]Z00?o
0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0koookJP00@_oonfX3o`0004Cooo]Z00?o0000
ob<0Jol000000_lZ1F`00ol0003oE328oe@`R007oe@`R0;oHDBH00?o0000og1?Vom`Ci/00_m`Ci/2
o`0000CoLDjI00Co0000ogUKY?miFjCo00003on5I:D2o`0000OoTW>]1?l00005oi=g/@03o`000?nL
OK3oW7f`00_oW7f`0ol00002oij4^003o`000?nTQkKoY8Nf00KoY8Nf0ol00003ojB7]P;o00001?nV
S[/00ol0003o[8nhojb?^00Bojb?^0;o00004oncU[T01?l0003o]YFeokJE]Ol0000BokZK^@;o0000
4?noWkP00ol0003o_Z6lokjQ_005okjQ_003o`000?o3XKKo`j6f00Go`j6f00?o0000olNW^Oo7YkT0
2oo7YkT5o`0000SocZF^00?o0000olnW/?o?Yk002Oo?Yk000ol0003od:Zcom2Z/`02om2Z/`04o`00
0?oEZjgoeJ^]omF[[@;o000000?of:NTo`000?oJZZH01ooJZZH00ol0003ogJjWomf^Y`03omf^Y`?o
000000GohjfLo`000?oS[IcohjfLo`000002onJ^V003o`000?oZ/YOoj[:G00;oj[:G00?o0000onb[
ROl000001Oo`[hL2o`0000?omJY_00?o0000ooR^J_l000002_oonfX00ol0003ooo]ZoookJP3moook
JP?o0000M?oonfX01Ol0003o<1=koc0CNol0003o0@1`00;o00000ol[8Y800ol005CoYd`0o`0]]@02
o`0]]@;o016K00?o0000oookJ_oonfX0BooonfX2o`0000Gob/kM0ol00004ol[>g@05o`000?o<dMko
c=7NolcAg_l000001ooBe=X00ol0003oh]W=on;Ic@08on;Ic@03o`000?o/glGok=o500Cok=o500?o
0000onkTa?o^i<@00_o^i<@00ol0003om^Ffo`000004ooOY/`;o000000?on^VFo`000?oejHd00ol0
0008oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0>ooonfX003oooo]Z0ol00016
oookJP04o`000?lS06_o8`1[o`0000;o:PE/00?o0000oe@`R?mD<8P01_mD<8P3of54V003o`000?m`
Ci_oL4nK00CoL4nK0_l000000omaCYWo0000ogUKY002ogUKY003o`000?n5I:GoQFBU00_oQFBU0_l0
00000on9KJgo0000oi9c[@03oi9c[@?o00002OnCMk400ol0003oW7f`oiam/007oiam/0Co00001OnN
Q;P00ol0003oY8NfojB7]P03ojB7]P?o00001OnTQkH00ol0003oYXjkojJ>^`04ojJ>^`03o`000?n/
SkSo[8nh017o[8nh0_l0000Eok>F^@;o00004_njVkT01?l0003o^9^kokRK^ol0000>oknO^003o`00
0?nnXKco_Z6l00Ko_Z6l00?o0000ol>Q]_o3XKH01?o3XKH00ol0003oajNiolNW^@0=olNW^@04o`00
0?o5Z;co0000ol^X]P?o00001Oo>YJh00ol0003ocjN`olnW/009olnW/003o`000?o@Z[?od:Zc00;o
d:Zc00?o0000omF[[OoEZjd00ooEZjd2o`0000SofZZV00?o0000omf^YooM[ZL01OoM[ZL3o`0000;o
hjfL00Co0000onJ^V?oV[YSo00001OoZ/YL2o`0000Gol:n700?o0000oo>dQOl000000_oeZVl01?l0
003on:iZooR^J_l0000:oookJP03o`000?oonf[ooo]Z0?Wooo]Z0ol0001foookJP03o`000?l`4g_o
<1=k00;o<1=k00?o0@1`o`00HOl000000ol[8Y800ol0003o001ao`000003o`0]]@;o016K00?o0000
oookJ_oonfX0BOoonfX00ol0003ob/kMol[>g@02ol[>g@?o00001Oo:c]d2o`0000Coc=7N00?o0000
om;Df_oBe=X01?oBe=X2o`0000Woh]W=00?o0000onCMcOl000001Oo/glD00ol0003ok^C4onkTa003
onkTa0;o00001?ogjK<2o`000003oo[YU_l0003omNV=00?o00002?oonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?oonf[ooo]Z03[ooo]Z000moookJP;o0000B?oonfX01_l0003o8`1[ob<0JolS06_o
0000obX5K0;o00001omD<8P4of54V003o`000?m`Ci_oL4nK00GoL4nK1?l00003ogUKY003o`000?n5
I:GoQFBU00WoQFBU00Ko0000ohU][On9KJgoRFf]o`000?nBLjd3o`0000goTgNa00?o0000oiam/?nL
OK000_nLOK04o`0000[oWXBh00?o0000ojB7]_l000000_l00006ojB7]P;o00001onVS[/00ol0003o
[8nhojb?^00@ojb?^003o`000?n/T[_o000001Co/iJi0_l0000BokZK^@05o`000?nhVk_o^9^kokRK
^ol000003OnoWkP00ol0003o_Z6lokjQ_007okjQ_003o`000?o3XKKo`j6f00?o`j6f00?o0000olNW
^Oo7YkT03Oo7YkT01Ol0003oaJRlolFX_?o5Z;co000000?objRf0ol000000oo>YJko0000olnW/00:
olnW/003o`000?o@Z[?od:Zc00Cod:Zc00?o0000omF[[OoEZjd00_oEZjd00ol0003ofK2^o`000006
omZZYP03o`000?oM[ZOogJjW00KogJjW00Co0000omnbYol0003o00000_oS[I`00ol0003oiZjHo`00
0006onZbU`03o`000?o`[hOol:n700?ol:n700Ko0000oo>dQOoc]8Go0000ooFZKol00003ooR^JP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0m_oonfX2o`0007Sooo]Z00?o0000oc0CNol`
4g/00ol`4g/00ol1073o001Qo`000003ob/RTP?o00001?l0;KD2o`0AV`03o`000?oonf[ooo]Z04Oo
oo]Z00?o0000ol[>gOo:c]d00ol00007ol[>g@03o`000?o<dMkoc=7N00Goc=7N00?o0000om;Df_oB
e=X00_oBe=X01?l0003oeMSJomGHf_l00007on;Ic@04o`000?oTgLgoi=g=o`0000Cok=o500?o0000
onkTa?o^i<@01?o^i<@00ol0003omnVcooOY/`02ooOY/`09o`000?ogkK3o0000oo[YU_l0003omNV=
o`000?oLd5Co000000Wooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0ioookJP00
>_oonfX3o`0004Wooo]Z00?o0000ob<0JolS06/00_lS06/2o`000003ochOPol0003oE32800GoE328
1_mQA9P00ol0003oL4nKog1?V`03og1?V`03o`000?miGJKoNEfV00;oNEfV1?l00009ohETY@;o0000
00?oRFf]o`000?l000000ol0000@oi=g/@03o`000?nLOK3o000000;o00003OnNQ;P3o`0000OoY8Nf
0_l0000:ojJ>^`03o`000?n/SkSo[8nh00go[8nh0_l00003ojbB^`03o`000?ncU[Wo/iJi00go/iJi
1ol00002okZK^@Ko00002?njVkT00ol0003o^9^kokRK^`02okRK^`03o`000?noWkSo_inh00[o_inh
00?o0000okjQ_?nnXK`02OnnXK`00ol0003o`j6fol>Q]P02ol>Q]P03o`000?o7YkWoajNi00coajNi
00?o0000olFX_?o5Z;`00_o5Z;`00ol0003objRfol^X]P04ol^X]P;o00002oo?Yk000ol0003od:Zc
om2Z/`04om2Z/`05o`000?oEZjgoeJ^]omF[[Ol000000ooI/:h2o`0000CofZZV00?o0000omf^YooM
[ZL01OoM[ZL01?l0003ogk:WomnbYooO/ZL2o`000004on>]W?l0003oiZjHo`0000Koj[:G0_l00004
oo2_Q`04o`000?oc]8GolkB5oo>dQ@;o00000ooh[VX00ol0003ooo]ZoookJP08oookJP03o`000?oo
nf[ooo]Z0??ooo]Z0ol0000?oookJP;o0000JOoonfX00ol0003o<1=koc0CN`03oc0CN`03o`40L?l0
003o:b:B00Co:b:B00?o0000o`00LOl000000ol0;KD01?l0003o016Ko`000?l00017oookJPCo0000
2Oo:c]d00ol0003oc=7NolcAgP07olcAgP04o`000?oBe=[od]CJo`0000CoeMSJ00?o0000on;IcOoR
fLd00ooRfLd00ol0003oi=g=onCMc@02onCMc@04o`000?o/glGok=o5o`0000Ook^C400?o0000ooOY
/oogjK<00_ogjK<01?l0003omnf`o`000?l00002ooGYS@03o`000?oLd5Co000000[ooo]Z00?o0000
oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0ioookJP00>?oonfX2o`0004_ooo]Z00?o0000ob<0
JolS06/00olS06/01?l0003o?Qn3ochOPol00005oe@`R0OoHDBH00Co0000og1?Vom`Ci_oL4nK0_l0
0008ogUMYPgo00000on:LK000ol0003oTgNaoi=g/@0>oi=g/@?o00003_nNQ;P2o`000003oij4^?l0
003oY8Nf00GoY8Nf0_l0000<ojJ>^`03o`000?n/SkSo[8nh00co[8nh00?o0000ojbB^on/T[/01?l0
0004ok>F^@Go00001onaV[l00ol0003o]J;5okFRa@02okFRa@03o`000?ngW[oo]ijo00Ko]ijo4Ol0
0008oknO^003o`000?nnXKco_Z6l00[o_Z6l00Go0000ol>Q]_o3XKKo`j6fo`00000>olNW^@03o`00
0?o5Z;coaJRl00?oaJRl00?o0000ol^X]_o;Z;H01?o;Z;H00ol0003ocZfho`000002o`0000OocjN`
00?o0000om2Z/oo@Z[<01Oo@Z[<01Ol0003oeJ^]omF[[OoEZjgo000000GofK2^0_l00002omZZYP03
o`000?oM[ZOogJjW00GogJjW00?o0000omnbYooO/ZL00ooO/ZL3o`0000Ooj[:G00?o0000onffUol0
00000_o`[hL00ol0003olkB5oo>dQ@03oo>dQ@04o`000?oh[V[on:iZooR^JP;o00002_oonfX00ol0
003ooo]ZoookJP3_oookJP?o00004_oonfX00ol0003okjj8o`00001WoookJP03o`000?l`4g_o<1=k
00Co<1=k0_l00005ob/RTP04o`000?l0077o00fMo`0000;o02fe00?o0000o`0AVol04I/00_l00014
oookJP?o00002_o:c]d2o`0000[oc=7N00?o0000om;Df_l000001_oEf=X01Ol0003oh]W=on;IcOoR
fLgo000000Goi=g=00Co0000oncOaOo/glGo00001_o^i<@2o`0000?omnVc00?o0000ooO]/?ogkK00
0_l00002ooGYS@?o00002ooonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z03Sooo]Z
000eoookJP?o0000COoonfX00ol0003o8`1[ob<0J`03ob<0J`04o`000?ln7h?o?Qn3o`0000CoE328
2?mQA9P01?l0003oL4nKo`000?l0000:ogUMYP03o`000?n5IZSoQFJX00?oQFJX0_l00008ohYa/003
o`000?nCMk7oTgNa00coTgNa0_l000000onGOkSo0000oij4^00;oij4^0?o00000onNQ;P00ol0003o
Y8NfojB7]P02ojB7]P;o00003_nVS[/00ol0003o[8nhojb?^008ojb?^0Oo00000on_Vl<00ol0003o
/IZook6J_`0=ok6J_`03o`000?neX/Go]J;500Co]J;500?o0000okNN_ongW[l02_ngW[l00ol0003o
^jK4ok^Va006ok^Va003o`000?nlX[ko_::n00Go00000_noWkP00ol0003o_Z6lokjQ_00;okjQ_004
o`000?o3XKKo`j6fo`0000koajNi00?o0000olFX_?o5Z;`01Oo5Z;`00ol0003objRfol^X]P02ol^X
]P03o`000?o>[KSocZfh00?ocZfh0_l00004olnW/003o`000?o@Z[?od:Zc00Ood:Zc00?o0000omF[
[Ol000002?oI/:h2o`0000SogJjW00?o0000omnbYooO/ZL00ooO/ZL3o`0000Koj[:G00Oo0000onff
Uoo]]YOokKJGo`000?o`[hOo000000GolkB500Oo0000ooR^J_oh[V[on:iZo`000?oj/FCo000000[o
oo]Z00?o0000oookJ_oonfX0jooonfX3o`0001Gooo]Z00?o0000onn^R?o_[XP00_l0001ToookJP03
o`000?l`4g_o<1=k00Go<1=k0_l00004ob/RTP05o`000?l159Oo0000o`000?l03Id00ol0;KD01Ol0
003o016Ko`000?l08Z[o0000043ooo]Z1?l0000;ol[>g@03o`000?o<dMkoc=7N00_oc=7N00?o0000
omGHf_oEf=X01_oEf=X00ol0003oh]W=o`000006onCMc@03o`000?o/glGo000000Kok^C400?o0000
oo3W`_l000000_ogjK<01?l0003omnf`ooO]/?ogkK02o`000003ooGYSOl0003o000000;o00002ooo
nfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z03Oooo]Z000boookJP?o0000CooonfX2
o`0000Co8`1[00Go0000ocTMPol0003o?Qn3o`000003oe@`R0WoHDBH0_l0000<ogUMYP04o`000?n5
IZSoQFJXohEVZ0;o00002on:LK000ol0003oTgNaoi=g/@08oi=g/@?o00000onGOkP00ol0003oWXBh
oij4^007oij4^0?o00001_nNQ;P01Ol0003oY8NfojB7]_nTQkKo0000017oYXjk00?o0000ojb?^?n/
SkP00_n/SkP7o`0000Wo[i_300?o0000ok6J_onaV[l02_naV[l2o`0000Oo]J;500?o0000okNN_ong
W[l02OngW[l00ol0003o^jK4ok^Va008ok^Va003o`000?nlX[ko_::n00Co_::n1_l0000;okjQ_0;o
00003_o7YkT00ol0003oaJRlolFX_006olFX_003o`000?o;Z;KobjRf00;objRf00?o0000olj]^?o>
[KP01Oo>[KP3o`000003olnW/?l0003od:Zc00Sod:Zc00?o0000omF[[Ol000002OoI/:h2o`0000Ko
gJjW00?o0000omnbYooO/ZL01OoO/ZL4o`0000Coj[:G00?o0000onffUoo]]YL00_o]]YL2o`0000Go
lkB50_l00002ooR^JP04o`000?oj/FCon[5To`0000Wooo]Z00?o0000oookJ_oonfX0j?oonfX3o`00
01Sooo]Z00?o0000onn^R?o_[XP00_o_[XP00ol0003ooo]ZoookJP1PoookJP03o`000?l`4g_o<1=k
00Go<1=k00?o0000od/iV_l000001?l[8Y801_l0003o0ABGo`000?l0077o00fMo`0000;o02fe00Ko
0000o`0W/_l04I_o0000o`0RZ_l0000loookJPGo000000?o[lG[o`000?o:c]d02Oo:c]d00ol0003o
c=7NolcAgP0:olcAgP03o`000?o=e=oo000000WoeMSJ00?o0000onCMcOoTgLd01_oTgLd00ol0003o
k^C4onkTa004onkTa007o`000?o`il;ol>O2oo3W`_l0003omnVco`000003ooO]/003o`000?oejHgo
mNV=00?o00003OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z03Oooo]Z000`oook
JP;o0000DOoonfX00ol0003o0`1No`000003ob<0J`06o`000?li7H?o>Af3o`000?ln7h?o00000_mD
<8P9of54V0;o00003_miGJH3o`0000goRW6`00?o0000oi=g/OnCMk401_nCMk42o`0000OoUgnh00?o
0000oij4^?nNQ;P00onNQ;P3o`0000[oWXBh0ol0000@ojJ>^`?o000000?o[8nho`000?n[U;h01On[
U;h00ol0003o[i_3ojnK``09ojnK``03o`000?naV[oo/IZo00Wo/IZo00?o0000okFRaOneX/D01one
X/D00ol0003o]ijookNN_`07okNN_`;o00002onkY/@00ol0003o_::nokbR_P03okbR_P03o`000?o0
Z<;o`:S200Co`:S21ol00004okjQ_003o`000?o7YkWoajNi00coajNi00?o0000olFX_?o5Z;`02?o5
Z;`01?l0003objRfol^X]_l0000;olj]^0;o00002_o@Z[<00ol0003ofK2^omV`[P08omV`[P04o`00
0?oJ/[3o0000o`0000CogJjW00?o0000omnbYooO/ZL01_oO/ZL2o`000003onJfXol0003oj[:G00;o
j[:G00?o0000onffUoo]]YL00oo]]YL00ol0003olkB5oo>dQ@03oo>dQ@05o`000?og^8;o0000ooR^
J_l000000ooj/F@00ol0003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z0>Cooo]Z0ol0000Koook
JP03o`000?o_[XSokjj800?okjj800?o0000oookJ_oonfX0G_oonfX00ol0003o<1=koc0CN`05oc0C
N`04o`000?m;>I[oBcVJo`0000Co:b:B00?o0000o`4DUol159L00_l000001?l03Igo0000o`0]]Ol0
0002o`0W/P04o`0AVol0003o02:Zo`0003Sooo]Z1Ol00005ojo5j`03o`000?o:c]gob/kM00Kob/kM
00?o0000olcAg_o<dMh02_o<dMh01Ol0003ocMCOolgDgoo=e=oo000000OoeMSJ00?o0000omWMfol0
00001ooTgLd00ol0003ok^C4onkTa004onkTa004o`000?o`il;ol>O2oo3W`P;o00001?ogkK000ol0
003omNV=ooGYS@03o`0000kooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0foook
JP00;OoonfX3o`0005?ooo]Z00?o0000o`<0G_l000000_lS06/02?l0003o>Af3ocTMPoli7H?o0000
ochOPol0003oE3282OmQA9P00ol0003oJe>Uo`00000=ogUMYP;o00003on:LK000ol0003oTgNaoi=g
/@04oi=g/@;o00002OnGOkP00ol0003oWXBhoij4^003o`0000coWXBh0_l0000=ojJ>^`Go00000_nV
T/400ol0003oZiBnoj^D_P04oj^D_P;o00003?n_Vl<00ol0003o/IZook6J_`07ok6J_`;o00002one
X/D00ol0003o]ijookNN_`05okNN_`03o`000?nkY/Co^jK400co^jK400Go0000okbR__nlX[ko_::n
o`00000>ol2X`PSo00002_o7YkT00ol0003oaJRlolFX_009olFX_003o`000?o;Z;Ko000000cocZfh
00Co0000olj_^ol0003o00002?o@Z[<00ol0003ofK2^omV`[P07omV`[P03o`000?oJ/[3of[:`00;o
f[:`00Go0000omf^YooM[ZOogJjWo`000007omnbY`;o000000Coh[JYo`000?oV]Z?o00000_oZ/YL0
0ol0003okKJGonffU`03onffU`;o00001?oc]8D00ol0003omkR2ooNhPP02o`0000?on[5T00?o0000
oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP3QoookJP;o00007OoonfX00ol0003okjj8onn^R005
onn^R0;o0000GOoonfX2o`0000Ko<1=k00Go0000od/iV_m;>I[oBcVJo`000003ob/RTP03o`000?l1
59Oo0ABG00;o0ABG00Go0000o`0=WOl0003o02feo`000003o`0W/P03o`000?l08Z[o02:Z00;o0000
<ooonfX6o`0000So[lG[00?o0000ol[>gOo:c]d00oo:c]d2o`0000coc=7N00?o0000olgDgoo=e=l0
0_o=e=l00ol0003oeMSJomGHfP04omGHfP05o`000?oIgM_ofMgKomWMfol000001OoTgLd2o`0000Go
k^C400?o0000oo3W`_o`il800_o`il82o`0000?omnf`0_l000000ooejHgo0000o`000002o`0000ko
oo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP0eoookJP00:ooonfX2o`0005Gooo]Z
0ol00002ob<0J`03o`000?li7H?o>Af300?o>Af30_l00009of54V004o`000?m[DjGoJe>Uo`0000co
NEfV00?o0000oh1[/Ol000003on:LK001?l0003oTgNaoi=g/OnCMk43o`0000_oUgnh0ol0000<oij4
^0?o000000?oX8Zmo`000?nVS[/01onVS[/5o`0000OoYY;100?o0000oj^D__n[U;h00_n[U;h2o`00
00oo[i_300?o0000ok6J_onaV[l01OnaV[l00ol0003o]J;5okFRa@0;okFRa@03o`000?ngW[oo]ijo
00Co]ijo00?o0000ok^Va?nkY/@03OnkY/@01?l0003o_::nokbR__l0000Aol2X`P?o_Jc800?o0000
ol>Y_oo3ZKl00ol00006olNW^@03o`000?o5Z;coaJRl00[oaJRl00?o0000ol^X]_l000002oo>[KP0
0ol0003ocZnkolj_^`02olj_^`?o00001?o@Z[<00ol0003odZfdo`000008omV`[P03o`000?oJ/[3o
f[:`00?of[:`0ol00008omnbY`04o`000?oR]ZWo0000o`0000;oi[JS0_l00006onffU`03o`000?o`
^YKo000000;olkB500?o0000ooNhP_og^8800_og^8801?l0003on[5TooZaI?oj/F@2o`0000Wooo]Z
00?o0000oookJ_oonfX0g_oonfX3o`0001oooo]Z00?o0000onn^R?o_[XP01Oo_[XP00ol0003ohj:<
o`00001JoookJP;o000000?oBbN4o`000?l`4g/01?l`4g/00ol0003oBcVJod/iVP02od/iVP;o0000
0_l[8Y800ol0003o0ABGo`4DU`02o`4DU`06o`00LOl0003o0000o`/g]ol0;KGo00000ol09k82o`00
00;o>H;X0ol0000]oookJP?o000000?ooo]Zo`000?l000003?n_aN/01Ol0003ob/kMol[>gOo:c]go
000000coc=7N0_l00005olgDg`03o`000?oEf=[oeMSJ00?oeMSJ00?o0000omWMfooIgM/00ooIgM/0
1Ol0003oi=g=onCMcOoTgLgo000000;oin;=00Go0000onkTa?o^i<Cok^C4o`000005oo3W`P03o`00
0?ogkK3omnf`00;omnf`0_l000000ooejHgo0000o`000002o`0000oooo]Z00?o0000oookJ_oonfX0
:OoonfX00ol0003ooo]ZoookJP0eoookJP00:?oonfX3o`0005Kooo]Z00Ko0000o`00F_l0003o0000
ob<0Jol00006ocTMP`;o00002?mQA9P00ol0003oJe>Uof]CY@02of]CY@03o`000?miGJKoNEfV00Oo
NEfV0_l00002oh1[/@03o`000?n:LK3oRW6`00koRW6`0ol0000<oiMo^0Co00002onNQ;P2o`0000Go
X8Zm00?o0000ojJ>^onVS[/01Ol0000=ojJB`@04o`000?n[U;koZiBno`00017o[i_300?o0000ok6J
_onaV[l01?naV[l00ol0003o]J;5okFRa@0=okFRa@04o`000?ngW[oo]ijookNN_`;o00004?nkY/@0
0ol0003o_::no`00000Aol2X`PGo_Jc800?o0000ol>Y_oo3ZKl00_o3ZKl3o`0000;oajNi00?o0000
olFX_?o5Z;`03?o5Z;`00ol0003ocZfholj]^009olj]^003o`000?o>[k_ocZnk00KocZnk0_l00000
1Oo@Z[?o0000om:]]?oB[KCo000000OofK2^00?o0000omZb/?oJ/[001_oJ/[02o`0000Oogk:W00?o
0000on:fZOoR]ZT00_l00002onJfX`03o`000?o]]YOokKJG00?okKJG00Oo0000oo2jU_o`^YKol;ZF
o`000?oc]8Go000000ComkR200Co0000ooZaI?oj/FCon[5T0_l0000:oookJP03o`000?oonf[ooo]Z
0=[ooo]Z0ol0000RoookJP03o`000?o_[XSokjj800Gokjj800Co0000on>RS?oSXXco0000EooonfX2
o`000004ogQ8Rol0003oBbN4o`0000Co<1=k00?o0000od/iV_m;>IX01?m;>IX2o`000003ob/RT_l0
003o0ABG00Co0ABG00Co0000o`0=WOl0003o2cNg0_l00002o`0W/P;o03k200?o0000ocV2j?l00000
0_lfPnT3o`0002Oooo]Z0ol00002oookJP;o00003on_aN/00ol0003ob/kMo`00000<olcAgP03o`00
0?o=e=oocMCO00KocMCO00Go0000omGHf_oEf=[oeMSJo`000007omWMf`03o`000?oTgLgo000000?o
in;=00Go0000onkTa?o^i<Cok^C4o`000005oo3W`P08o`000?ogkK3omnf`ooO]/?l0003omnnZo`00
0?oejHd2o`000003olg5A?l0003ooo]Z00oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Z
oookJP0doookJP009OoonfX3o`0005Wooo]Z00?o0000o`00F_l000000_l00007ocTMP`;o00001omQ
A9P00ol0003oJe>Uof]CY@03of]CY@03o`000?miGJKoNEfV00KoNEfV00?o0000oh1[/On0Jk400_n0
Jk400ol0003oRW6`ohYa/00=ohYa/0;o00002onGOkP3o`0000?oUgnh00?o0000oij4^?nNQ;P01_nN
Q;P3o`0000KoX8Zm1?l0000BojJB`@?o00004on_Vl<01?l0003o/IZook6J_onaV[l2o`00013o]J;5
00Co0000okNN_ongW[oo00004onkY/@00ol0003o`:S2ol2X`P0>ol2X`P03o`000?nm[<So_Jc800Co
_Jc800?o0000ol>Y_oo3ZKl01Oo3ZKl4o`0000coaJRl0_l0000:olj]^003o`000?o>[k_ocZnk00Wo
cZnk0_l00002om:]]003o`000?oI/:kofK2^00CofK2^00?o0000omZb/?oJ/[001ooJ/[001?l0003o
g;Jbo`000?l00004omnbY`03o`000?oR]ZWoh[JY00;oh[JY00?o0000onJfXooV]Z<00_l00004onff
U`03o`000?o`^YKol;ZF00;ol;ZF0_l00004ooNhPP;o00000_oj/F@00ol0003onk=Lo`00000:oook
JP03o`000?oonf[ooo]Z0=Kooo]Z0ol0000UoookJP03o`000?o_[XSokjj800Gokjj800Co0000on>R
S?oSXXcohj:<0_l0001CoookJP;o00000omhB8/00ol0003oBbN4o`000004oc0CN`03o`000?m;>I[o
BcVJ00CoBcVJ0ol00006o`4DU`04o`000?l03Igo0000o`/g]`;o<UK700?o0000o`0W/_l09k800_l0
?/800ol0003o>H;Xo`000004ocJ3j@Co00008?oonfX3o`0000;ooo]Z0ol0000Bojo5j`03o`000?o<
dMkoc=7N00[oc=7N00?o0000olgDgoo=e=l01oo=e=l01?l0003oeMSJomGHf_l00008omWMf`?o0000
0ooWh/d01?l0003ok^C4onkTa?l00005oo3W`P;o00000oogkK001Ol0003omnnZo`000?l0003oknN3
00;o00004_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z03?ooo]Z000ToookJP;o
0000F_oonfX00ol0003o001Jo`00FP02o`0000Oo>Af300Co0000od/eU_l0003o00001OmQA9P00ol0
003oJe>Uof]CY@04of]CY@03o`000?miGJKoNEfV00CoNEfV0_l00006oh1[/@03o`000?n:LK3oRW6`
00[oRW6`0_l000000on>NKSo0000oiMo^007oiMo^0?o00001_nGOkP00ol0003oWXBhoij4^004oij4
^0;o00001_nPR[d3o`0000;oXI3200?o0000ojJB`OnVT/404?nVT/42o`0001Go[i_300Co0000ok6J
_onaV[oo00004_neX/D00ol0003o]ijoo`00000Cok^Va003okRUa_l0003o`:S200ko`:S200?o0000
okf/b?nm[<P01_nm[<P00ol0003o`jVool>Y_`04ol>Y_`04o`000?o7[l?oajo3olN_``Co00001oo5
Z;`01?l0003oaZZmolJZ_Ol00008olj]^003o`000?o>[k_ocZnk00[ocZnk00?o0000olnb_Ol00000
0ol00005omV`[P03o`000?oJ/[3of[:`00Kof[:`00?o0000ombf/_oL][800_oL][801Ol0003ogk:W
omnbYooO/ZOo000000Coh[JY00Ko0000onJfXooV]Z?o0000onVjY?l00003onffU`03o`000?o`^YKo
l;ZF00?ol;ZF00?o0000ooNhP_og^8800_og^8801ol0003on[ano`000?oj/FCo0000oo^cG?l00000
2_oonfX00ol0003ooo]ZoookJP3CoookJP?o0000:?oonfX2o`0000Kokjj800?o0000on>RS?oSXX`0
0ooSXX`00ol0003ooo]ZoookJP1>oookJP;o00001OmhB8/01?l0003oBbN4od/WQ?l00002oc0CN`03
o`000?m;>I[oBcVJ00GoBcVJ00?o0000obPPT_l000001_l159L01Ol08:Go0000o`000?l;=kOo0000
00;o<UK700?o0000o`0W/_l000000_l0?/800ol0003o>H;Xo`000007ocJ3j@?o00006_oonfX3o`00
00?ooo]Z0_l0000Aojo5j`?o000000?o[lO/o`000?o<dMh02_o<dMh00ol0003ocMCOolgDg`08olgD
g`03o`000?oEf=[o000000SofMgK00Go0000omcSf_oLhm[og>?Jo`000003onORc@;o00001Oo`il80
0ol0003olNk1o`000002ooO]/003o`000?ogkj[omnnZ00;o000000?oknN3o`000?l000004_oonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z03?ooo]Z000ToookJP03o`000?oonf[o0000
05Wooo]Z00?o0000o`00F_l005X00_l00006ocTMP`05o`000?m;=IKoBcFFod/eU_l000001?mQA9P0
0ol0003oJe>Uof]CY@05of]CY@03o`000?miGJKoNEfV00?oNEfV00?o0000oh1[/On0Jk401_n0Jk40
0ol0003oRW6`ohYa/008ohYa/0;o00001?n>NKP00ol0003oUgnhoiMo^003oiMo^0;o00002OnGOkP0
0ol0003oWXBhoij4^002oij4^0;o00001?nPR[d4o`0000KoXI3200?o0000ojJB`OnVT/403OnVT/42
o`000003ojVKaol0003o[i_301Co[i_300?o0000ok6J_ol000004oneX/D2o`0001;o^jK400Go0000
okRUa_nhYLKo^:G6o`00000=ol2X`P03o`000?nm[<So_Jc800Oo_Jc800?o0000ol>Y_oo3ZKl00oo3
ZKl00ol0003oajo3olN_``06olN_``Co00000_o5Z;`01Ol0003oaZZmolJZ_Oo6Z[go000000SocZfh
00?o0000olj_^oo>[k/02Oo>[k/00ol0003ock:molnb_@03olnb_@;o00000ooI/:h00ol0003of[:`
omZb/007omZb/003o`000?oL][;og;Jb00?og;Jb0_l000000ooO/ZOo0000on:fZ@04on:fZ@;o0000
0ooY^Z@01?l0003okKJGonffUol00005oo2jUP03o`000?og^8;omkR200;omkR200Go0000ooZlO_l0
003on[5To`000002oo^cG003o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0cooonfX3o`00
02_ooo]Z00?o0000onbeUol000001?o_[XP00ol0003ohj:<on>RS005on>RS003o`000?oonf[ooo]Z
04_ooo]Z0_l00007ogQ8R`06o`000?m;9hCoBbN4o`000?l`4g_o00002Om;>IX2o`0000Go0ABG00Co
0000o`0PYOl08:Go00fM0_l00003oc9Fa`?o00000_l0?/800ol0003o>H;Xo`000009ocJ3j@?o0000
5?oonfX3o`0000?ooo]Z0ol0000Aojo5j`;o00001On_an`00ol0003oc=7NolcAgP07olcAgP03o`00
0?o=e=oocMCO00[ocMCO00?o0000omWMfooIgM/01_oIgM/00ol0003og>?JomcSfP03omcSfP04o`00
0?oWh/goin;=o`0000Kol>O200?o0000oo7^`Ol000000_ogkK000ol0003omnnZooO_ZP02o`000003
onoWPol0003o000001?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0boookJP00
9?oonfX01?l0003ooo]ZoookJ_l0001GoookJP04o`000?l005[o001Jo`00FP;o00001Oli7H<00ol0
003oBcFFod/eUP02od/eUP05o`000?mQA9SoHDBHof54V?l000002?m[DjD00ol0003oNEfVogUMYP02
ogUMYP03o`000?n0Jk7oP6^a00OoP6^a00?o0000ohYa/?n:LK001_n:LK02o`0000KoSWVh00?o0000
oiMo^?nGOkP00ol0000<oiMo^0Co00000_nPR[d4o`0000[oXI3200?o0000ojJB`OnVT/402onVT/42
o`0000CoZI_700?o0000ojnK`on_Vl<04_n_Vl<2o`0001?o]J;500?o0000ok>Raol000004?nkY/@2
o`0000Co^:G600?o0000ol2X`_o0Z<802Oo0Z<82o`0000[o_Jc800?o0000ol>Y_oo3ZKl00_o3ZKl0
0ol0003oajo3olN_``0;olN_``Co00000_o6Z[d00ol0003ocZfholj]^005olj]^003o`000?o>[k_o
cZnk00WocZnk00?o0000olnb_Oo?/[d01?o?/[d01_l0003oeK:fo`000?l0003ofK2^o`0000Sof[:`
00?o0000ombf/_oL][801_oL][82o`0000Goh[JY0_l00004onVjY0;o00001_o`^YH2o`0000;omkR2
00Co0000ooZlO_oj_7kon[an0_l00002oo^cG003o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oo
nfX0c?oonfX2o`0002kooo]Z00?o0000onbeUoo/]IL00_l00002onn^R003o`000?oSXXcohj:<00Ko
hj:<0_l0001:oookJP03o`000?mhB8_oN4R;00OoN4R;00?o0000od/WQ?m;9h@00_l0000:od/iVP03
o`000?lk>:?o000000Co0ABG00?o0000o`0PYOl08:D00ol00005oc9Fa`04o`0W/_l0003o03k2o`0n
`P;o00002_lfPnT00ol0003o>8CYo`000002o`0000_ooo]Z3?l0000Aojo5j`?o00002?n_an`00ol0
003oc=7NolcAgP04olcAgP;o00002oo=e=l00ol0003ocmOOo`000007omWMf`03o`000?oLhm[og>?J
00Gog>?J00?o0000onORcOl000001Oo`il801ol0003olNk1oo7^`Ooak/7o0000ooO]/?l000000_og
kjX00ol0003oknN3o`000002o`0001Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0aoookJP009?oonfX01Ol0003ooo]ZoookJ_oonf[o000005Gooo]Z00?o0000o`00F_l005X00_l0
05X2o`0000Co>Af300?o0000od/eU_m;=IH00om;=IH2o`000003of54V?l0003oJe>U00WoJe>U00Co
0000ogUMY_miGJKo00002_n0Jk400ol0003oRW6`ohYa/005ohYa/003o`000?n>NKSoSWVh00KoSWVh
0ol0000=oiMo^0?o00000onPR[d2o`0000koXI3200?o0000ojJB`OnVT/402OnVT/42o`0000KoZI_7
00?o0000ojnK`on_Vl<04?n_Vl<2o`000003ojjNaol0003o]J;5013o]J;50_l00003ok>Ra`03o`00
0?nkY/Co^jK400co^jK400?o0000okRUa_nhYLH01OnhYLH00ol0003o`:S2ol2X`P07ol2X`P03o`00
0?nm[<So_Jc800_o_Jc800Co0000ol>Y_oo3ZKoo00003_o7[l<4olBbb0Co00001Oo>[KP00ol0003o
cZnkolj_^`0:olj_^`03o`000?o?/[gock:m00Gock:m00?o0000omFb]_oE/[H00_l00007omZb/003
o`000?oL][;og;Jb00Oog;Jb00?o0000omjj/ol000001OoR]ZT00ol0003ojKZTonVjY003onVjY003
o`000?o`^YKol;ZF00?ol;ZF00Ko0000ooBoUOod_iGo0000ooNhP_l00004ooZlOP03o`000?ok/eco
nk=L00;o00002_oonfX00ol0003ooo]ZoookJP39oookJP?o0000;ooonfX00ol0003ok;FGonbeU`03
onbeU`03o`000?o_[XSo000000Sohj:<00?o0000omFDS_l000000_l00015oookJP;o00002_mhB8/0
1?l0003oBbN4od/WQ?l0000;od/iVP04o`000?lk>:?o>cRSo`0000?o0ABG00Co0000o`0PYOl08:Go
022U0_l00006oc9Fa`04o`000?l0?/;o03k2o`0n`P;o00002_lfPnT01?l0003o>8CYocR4jOlhQ>T>
o`0000SoPk7c00?o0000ojo5jon_aN/03On_aN/2o`0000co[lO/00?o0000olcAg_o<dMh00_o<dMh0
0ol0003ocMCOolgDg`0:olgDg`04o`000?o?emoocmOOo`0000KofMgK00?o0000omcSf_oLhmX01_oL
hmX3o`0000Col>O200?o0000oo7^`Ooak/400_oak/42o`0000?omnnZ00Co0000onoWPol0003o0000
5OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z037ooo]Z000SoookJP03o`000?oo
nf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0D_oonfX01?l0003o001Jo`00F_l005X3o`0000Co>Af3
00?o0000od/eU_m;=IH00om;=IH01?l0003oGdBJo`000?l0000:of]CY@03o`000?miGJKoP6^a00_o
P6^a00?o0000ohYa/?n:LK000on:LK02o`0000KoSWVh0ol000000on>NKSo0000oiMo^00:oiMo^0?o
00000_nHQ[h3o`0001;oXI3200?o0000ojJB`OnVT/401OnVT/43o`0000WoZI_700?o0000ojnK`on_
Vl<03On_Vl<2o`0000Co[Yk700?o0000okFRaOneX/D03OneX/D00ol0003o/j;7ok>Ra`03ok>Ra`03
o`000?nkY/Co^jK400[o^jK40_l00008okRUaP03o`000?o0Z<;o`:S200Ko`:S200?o0000okf/b?nm
[<P03?nm[<P00ol0003o`jVoo`00000>olN_``Soa;;80ol00002olj]^003o`000?o>[k_ocZnk00[o
cZnk00?o0000olnb_Oo?/[d01_o?/[d01Ol0003oeK:fomFb]_l0003oekJh00;o00001OoJ/[000ol0
003og;Jbombf/P06ombf/P05o`000?oN^[?og[Zcomjj/ol000001?oR]ZT2o`0000CojKZT0_l00004
oo2jUP04o`000?od_iGom;nEooBoU@;o00001?oj_7h01_l0003onk=Loo^cG?l0003onkABo`0000[o
oo]Z00?o0000oookJ_oonfX0aOoonfX3o`0003;ooo]Z00?o0000onbeUoo/]IL01?o/]IL2o`0000So
hj:<00?o0000omFDS_oEU8h00_oEU8h3o`00043ooo]Z0_l0000<ogQ8R`04o`000?m;9hCo0000o`00
00[oBcVJ0_l00003oc/hX`04o`000?l159Oo0ABGo`0000?o022U0_l00007oc9Fa`;o000000?o03k2
o`000?m7P>@00ol00008ocJ3j@04o`000?lhQ>Wo>8CYo`0000OoPk7c0ol0000<oh>al`03o`000?n_
aN_o[lG[00[o[lG[0_l0000>ojo7k005o`000?o<dMkoc=7NolcAg_l000003?o=e=l00ol0003ocmOO
oloGg`02oloGg`03o`000?oIgM_ofMgK00;ofMgK00?o0000omcSf_oLhmX01_oLhmX00ol0003og>?J
omcSfP02o`0000?ol>O200?o0000oo7^`Ooak/400_oak/42o`0000;omnnZ0_l000000oo_ih?o0000
o`00000FoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0<?oonfX002?ooo]Z00?o
0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP1@oookJP09o`000?l005[o001Jo`00F_l0003o
5@=ho`000?lM27[o000000;o>Af300?o0000od/eU_m;=IH01?m;=IH2o`0000;oJEBW0_l00007of]C
Y@;o00003_n0Jk400ol0003oRW6`ohYa/002o`0000GoSWVh0ol00004ohii^003o`000?nGOkSoUgnh
00KoUgnh0ol00003oiR6_P;o000000?oVhc3o`000?nQT<804_nQT<800ol0003oYY;1ojJB`@03ojJB
`@;o00003?nYVlL00ol0003o[i_3ojnK``0;ojnK``;o00001_n^W/L00ol0003o]J;5okFRa@0;okFR
a@;o00001_ncX/L00ol0003o^jK4ok^Va009ok^Va003o`000?nhYLKo^:G600So^:G600?o0000ol2X
`_o0Z<801Oo0Z<800ol0003o_Jc8okf/b00>okf/b003o`000?o7[l?oajo300coajo32Oo4//P00ol0
003objnnol^__P03o`0000_ocZnk00?o0000olnb_Oo?/[d01oo?/[d00ol0003oeK:fo`000004omNf
^005o`000?oJ/[3of[:`omZb/?l000002OoL][800ol0003og[Zcomjj/`02omjj/`05o`000?oR]ZWo
h[JYo`000?oU^ZT00_l00003onVjY003o`000?o]_jCo000000?ol;ZF00?o0000ooBoUOod_iD00_od
_iD00ol0003on[anooZlOP02ooZlOP;o000000Conk=Lo`000?ok]5;o00002ooonfX00ol0003ooo]Z
oookJP31oookJP?o0000=OoonfX00ol0003ok;FGonbeU`05onbeU`;o00001ooSXX`00ol0003oeIB>
omFDSP05omFDSP?o0000>ooonfX2o`0000koN4R;00GoBbN4o`000?mK?iOoFcnGo`000008od/iVP03
o`000?mIC:Wo000000?o>cRS00Co0000o`4DUol159Oo00001?l08:D00ol0003o<UK7oc9Fa`05oc9F
a`;o04K60_l0?/82o`0000;oDhSW0ol00006ocJ3j@04o`000?lhQ>Wo>8CYo`0000?oPk7c0ol0000@
oh>al`03o`000?n_aN_o[lG[00Ko[lG[0ol0000Aojo7k003o`000?o<dMko000000_ocMCO0_l00005
oloGg`05o`000?oIgM_ofMgKomWMfol000002?oLhmX02Ol0003og>?JomcSf_oLhm[o0000onO/dOl0
003ol>O2o`000005oo7^`@04o`000?ogkj[omnnZooO_ZP;o000000?oknN3o`000?l000005ooonfX0
0ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02oooo]Z000SoookJP03o`000?oonf[ooo]Z
00Gooo]Z00?o0000oookJ_oonfX0CooonfX01Ol0003o001Jo`00F_l005[o000000;o5@=h0_l00000
0oli7H?o0000od/eUP06od/eUP03o`000?mYE:OoJEBW00?oJEBW0_l00004of]CY@03o`000?mcHJoo
000000koP6^a00?o0000ohYa/?l000001On>NKP2o`0000OoSWVh00?o0000oiMo^?nGOkP00onGOkP3
o`0000?oV8Jn0ol00004oi^<``03o`000?nQT<;oXI32013oXI3200Co0000ojJB`OnVT/7oYY;10_l0
000>ojVKa`03o`000?n_Vl?o[i_300[o[i_300?o0000ojjNaon^W/L01_n^W/L00ol0003o]J;5okFR
a@0:okFRa@03o`000?ncX/Oo/j;700Oo/j;700?o0000ok^Va?nkY/@01onkY/@00ol0003o^:G6okRU
aP0:okRUaP03o`000?o0Z<;o`:S200?o`:S200?o0000okf/b?nm[<P03Onm[<P00ol0003o_J_8o`00
000=olN_``_oa;;800Go0000ol^___o;[kko0000ol^b`P03o`0000OocZnk00?o0000olnb_Oo?/[d0
2Oo?/[d00ol0003oekJhomNf^004omNf^0;o000000?of[:`o`000?oL][801ooL][800ol0003og[Zc
omjj/`04omjj/`09o`000?oR]ZWo0000onFjZOl0003ojKZTo`000?oY^ZCo000000?okKnT00Co0000
oo2jU_o`^YKo00001?od_iD00ol0003on[anooZlOP02ooZlOP04o`000?om`7[o0000o`0000;onkAB
00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP2noookJP?o0000>?oonfX00ol0003ok;FG
onbeU`05onbeU`03o`000?oRZYWo000000Kohj:<00?o0000omFDS_oEU8h02?oEU8h4o`0003?ooo]Z
1?l0000?ogQ8R`;o00001?mK?iL00ol0003oBcVJod/iVP04od/iVP04o`000?mIC:WoFDbYoeU<Z@Co
>cRS0_l00006o`0PY@;o00001OlbE/L00ol0003o04K6o`16aP02o`0n`P;o00001?mCR>L4o`0000;o
=X?Y00Co0000ocR4jOlhQ>Wo>8CY0ol0000Doh>al`03o`000?n_aN_o[lG[00?o[lG[0_l0000Eojo7
k003o`000?o=e=oocMCO00WocMCO00?o0000oloGgoo?eml01Oo?eml01?l0003ofMgKomWMfol00008
omcSfP03o`000?oLhm[og>?J00;og>?J00?o0000onO/dOoWk=400_l00004oo7^`@;o00000_ogkjX0
0ol0003ol_:Ro`000002o`0001Wooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0_
oookJP008ooonfX00ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z04gooo]Z0_l00002o`00
FP04o`000?lE0gSo5@=hoaD3N0?o00002?m;=IH00ol0003oJEBWofUDY`05ofUDY`;o000000GoJe>U
o`000?mcHJooLf6_o`00000=oh1[/@;o00001?n>NKP3o`0000[oSWVh00?o0000oiMo^?l000000_l0
0004oiR6_P;o00001onKS<<00ol0003oXI32oj6@`P0Aoj6@`P03o`000?nVT/7o0000017oZI_700?o
0000ojnK`on_Vl<01on_Vl<2o`0000Ko[Yk71Ol000000oneX/Go0000o`00000To`0000Go^:G600?o
0000ol2X`_o0Z<800_o0Z<800ol0003o_Jc8okf/b00=okf/b005o`000?nmZlSo_J_8okf[b?l00000
2_o7[l<00ol0003oa;;8olBbb00:olBbb003o`000?o;[kko000000Gobk;20_l00005olj_^`03o`00
0?o?/[gock:m00Wock:m00?o0000omNf^?oG][P01_oG][P2o`0000Sog;Jb00?o0000omjj/ooN^[<0
1OoN^[<2o`0000;oiKZY0_l000000ooY^ZCo0000onfoY003onfoY0;o00001Ood_iD2o`0000;on[an
00?o0000oog0N_om`7X00_l00002oo^dDP03o`000?oonf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0
^_oonfX3o`0003_ooo]Z00?o0000onbeUoo/]IL01Oo/]IL00ol0003ohZZIon:ZV@02o`0000?ohj:<
00?o0000omFDS_oEU8h02OoEU8h01?l0003oahR?olN8Soo7R8l5o`0002Wooo]Z1Ol00003oieUT003
o`000?mhB8_oN4R;00_oN4R;0_l000000on1F9Wo0000oe/oU`04oe/oU`03o`000?m;>I[oBcVJ00;o
BcVJ00?o0000oeU<ZOmIC:T00_mIC:T5oc/hX`03o`000?l08:Go022U00Co022U0_mCILP00ol0003o
<UK7oc9Fa`02oc9Fa`04o`000?l0A/Ko04K6o`16aP;o03k200?o0000oe>8iomCR>L01_mCR>L2o`00
0006ocJ3jOl0003o0000o`000?lhQ>Wo00005_n3/O<00ol0003o[lG[o`000002o`0001?o[lO/0ol0
00000onabngo0000olgDg`09olgDg`03o`000?o?emoocmOO00OocmOO0_l00008omcSfP03o`000?oL
hm[og>?J00Cog>?J00Co0000onO/dOl0003oj_;>0_l000001?oak/7o0000oo;b_?l00002ooO_ZP03
o`000?oblZ;o000000;o00006OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z02ko
oo]Z000SoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0C?oonfX2o`000003o`00
F_l0003o5@=h00?o5@=h0_l00008od/eUP;o00002?mYE:L5o`000003og=Q[ol0003oP6^a00[oP6^a
00Co0000ohEd^?l0003oSWVh0ol00009ohii^0Ko00001_nHQ[h00ol0003oVhc3oi^<``07oi^<``03
o`000?nQT<;oXI32013oXI320_l0000CojVKa`03o`000?n_Vl?o[i_300Go[i_30_l000000on^W/Oo
0000o`000005o`0000CoZj3<00?o0000ok6Sb_naXlX01OnaXlX2o`0000co[jC<00?o0000okNWbOng
YlT01?ngYlT00ol0003o/jK;ok>Vb`08ok>Vb`So000000?o`:S2o`000?nm[<P03Onm[<P2o`0000Co
_J_800?o0000olN_`oo7[l<01oo7[l<00ol0003oa;;8olBbb00<olBbb003o`000?o;//;obk;200Ko
bk;20ol000000oo>[k_o0000olnb_@0:olnb_@03o`000?o@];ko000000OoekJh00?o0000omZj^_l0
00001_oL][800ol0003og[Zcomjj/`06omjj/`06o`000?oQ_[Co0000onFjZOl0003ojKZT0_l00005
onfoY003o`000?od_iGom;nE00?om;nE00Go0000ooO4Tol0003on[ano`000003oog0NP03o`000?ok
]5;onkAB00;o00002ooonfX00ol0003ooo]ZoookJP2goookJP;o0000?OoonfX00ol0003ok;FGonbe
U`05onbeU`03o`000?oRZYWohZZI00?ohZZI0_l000000ooSXXco0000omFDSP0:omFDSP03o`000?o7
R8ooahR?00KoahR?1Ol0000OoookJPGo00002?nMII000ol0003oN4R;ogQ8R`09ogQ8R`;o00000on1
F9T00ol0003oFcnGoe/oU`03oe/oU`05o`000?m;>I[oBcVJod/iV_l000001OmIC:T00ol0003o>cRS
oc/hX`02oc/hX`03o`000?l08:Go022U00Co022U00Co0000oe=Ub?mCILSo00000olbE/L00ol0003o
04K6o`16aP02o`16aP03o`0n`_l0003oDhSW00OoDhSW1ol000000olhQ>Wo0000oh>al`0@oh>al`?o
00000_n3/O<00ol0003o[lO/ojo7k00Bojo7k0;o00001Onabnd00ol0003ocMCOolgDg`05olgDg`;o
00002_o?eml00ol0003og>?JomcSfP06omcSfP03o`000?oLhm[og>?J00Gog>?J0_l00004on[bcPCo
00000_ogkjX5o`0001[ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0]oookJP00
8ooonfX00ol0003ooo]ZoookJP08oookJP;o0000C?oonfX2o`000003o`00F_l0003o5@=h00?o5@=h
0_l00007od/eUP04o`000?mIBJCoFDVTo`0000KoJEBW00?o0000ogEV]?meI[@00omeI[@7o`0000Go
P6^a00?o0000ohEd^?l000000_l00003ohii^0Wo00001?n@Okd00ol0003oV8JnoiR6_P03oiR6_P03
o`000?nKS<?oVhc300[oVhc300?o0000oj6@`_nQT<803?nQT<83o`000003oj>Ib_l0003oZI_7017o
ZI_73?l0000<oj^Pc003o`000?naXl[o/J?:00;o/J?:0_l0000?ojnTc004o`000?ngYlWo]jO9okNW
b@;o00004OncY//3o`0000;o_Jc800?o0000okf/b?nm[<P02Onm[<P00ol0003o_J_8okf[b005okf[
b003o`000?o7[l?oajo300Goajo300?o0000olBbb?o4//P02oo4//P00ol0003oa;37o`00000;ol^b
`P;o00002_o?/[d01?l0003od;Bnom2d__l00006omNf^004o`000?oJ^[[of[ZjomZj^P;o00001?oL
][800ol0003og[Zcomjj/`05omjj/`04o`000?oQ_[CohKjdon6n]0;o00000_oY^Z@00ol0003okKnT
onfoY003onfoY0;o00001?od_iD00ol0003omlBCooO4T`02o`0000?ooL1j00?o0000oo^dD_ok]580
0_l0000;oookJP03o`000?oonf[ooo]Z0;Cooo]Z0ol0000ooookJP;o00001_o/]IL00ol0003ohZZI
on:ZV@05on:ZV@;o00002ooEU8h00ol0003oahR?olN8S`08olN8S`03o`000?o2Q93o`XB@00_o0000
3ooonfX5o`0000goWFF@00?o0000ogQ8RomhB8/01omhB8/2o`0000KoPERI00?o0000oe/oUomK?iL0
0omK?iL00ol0003oBcVJo`000006oeU<Z@07o`000?lk>:?o>cRSoc/hXol0003oGeNao`000005o`0P
Y@05o`000?mCILSoDfG8oe=Ub?l000000olbE/L00ol0003o04K6o`16aP02o`16aP03o`0n`_l0003o
DhSW00?oDhSW0ol00004oe>8i`03o`000?m4QNSoA8GX00?o00001On3/O<;o`0000GoQ;7b00?o0000
ojo7k?n_an`04?n_an`2o`0000So/L_]00?o0000olgDgoo=e=l00oo=e=l00ol0003ocmOOoloGg`08
oloGg`03o`000?oBfmoo000000Oog>?J00?o0000omcSf_oLhmX01_oLhmX00ol0003oj_;>on[bcP03
on[bcP03o`000?oZm<goj_C=00Co000000?okORao`000?l000007?oonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z02gooo]Z000SoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oook
J_oonfX0B?oonfX4o`0000Go5@=h00?o;B6@o`000?m;=IH01Om;=IH01Ol0003oFDVToeU9Y?mIBJCo
000000GoJEBW00?o0000ogEV]?meI[@01OmeI[@00ol0003oP6fdoh1]]003oh1]]0go00003_n@Okd0
0ol0003oV8JnoiR6_P0?oi^<``03o`000?nQT<;oXI3200[oXI320_l00005oj>IbP03o`000?nYVlOo
ZI_700[oZI_71Ol00002ojRNc003o`000?n]W/So000000;o00004On[X<`01Ol0003o/J?:ok6Sb_na
Xl[o000001;o[jC<00?o0000okNWbOl000004_ncY//00ol0003o/J_Ao`000004okb_c@Oo00000onm
[<P00ol0003o_J_8okf[b006okf[b003o`000?o7[l?oajo300Coajo300?o0000olBbb?o4//P02oo4
//P01Ol0003oa;37olB`aoo4/<Oo000000[obk;200Co0000oljha?l0003o00001oo?/[d00ol0003o
d;Bnom2d_P02om2d_P03o`000?oG][SoekJh00;oekJh00?o0000omZj^_oJ^[X01?oJ^[X01?l0003o
g;Jbombf/_l00008omjj/`03o`000?oQ_[CohKjd00;ohKjd0_l000000ooY^ZCo0000onfoY004onfo
Y003o`000?o``jCo000000;om;nE00?o0000ooO4Tooga9<00_oga9<01?l0003ooL1joog0N_om`7X2
o`000003oo^dD_l0003o000000cooo]Z00?o0000oookJ_oonfX0/?oonfX3o`0004;ooo]Z00?o0000
onViXOl000001Oo/]IL00ol0003ohZZIon:ZV@06on:ZV@;o00002_oEU8h00ol0003oahR?olN8S`08
olN8S`04o`000?o2Q93o`XB@o`0000[o^7Z?3ol0000BoieUT003o`000?mhB8_oN4R;00GoN4R;0_l0
0008oh5HV@03o`000?mK?iOoFcnG00CoFcnG00?o0000oeU<ZOmIC:T01OmIC:T01Ol0003o>cRSoc/h
Xolk>:?o000000;oGeNa00?o0000o`0PYOl08:D00_l08:D00ol0003o3Bn_oe=Ub003oe=Ub0;o<UK7
00?o0000o`16a_l0A/H00ol0A/H5o`0000SoDhSW00?o0000odB5j?m4QNP00_m4QNP5o`00017oQ;7b
00?o0000ojo7k?n_an`03?n_an`3o`0000_o/L_]00Go0000olgDgoo=e=oocMCOo`00000:oloGg`04
o`000?oBfmood]_Oo`0000Kog>?J00?o0000omcSf_oLhmX01_oLhmX2o`0000Coj_;>00Oo0000on[d
cOoZm<goj_C=o`000?o`mkKo000000;okORa00?ofNEjo`000?oonfX06ooonfX00ol0003ooo]Zoook
JP0YoookJP03o`000?oonf[ooo]Z02cooo]Z000RoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000
oookJ_oonfX0AooonfX3o`0000Go5@=h00?o0000obdQT?l000001Om;=IH00ol0003oFDVToeU9Y002
oeU9Y003o`000?mYE:OoJEBW00;oJEBW00?o0000ogEV]?meI[@01_meI[@00ol0003oP6fdoh1]]005
oh1]]0;o00001On8Nkh00ol0003oT7nmoi1o_@0>oi1o_@;o00004OnKS<<00ol0003oXI32oj6@`P07
oj6@`P?o00001onSVLX00ol0003oZI_7ojVKa`05ojVKa`Go00001onXW/`2o`0001CoZj3<00Co0000
ok6Sb_l0003o00004on_Y<`2o`00017o/jK;0_l00003ok6[d@03o`000?nl[lgo_:o=00So_:o=1_l0
0007okf[b003o`000?o7[l?oajo300;oajo300?o0000olBbb?o4//P02oo4//P00ol0003oa;37olB`
a`02olB`a`03o`000?o;//;obk;200Oobk;200?o0000oljha?o>^<@00_o>^<@2o`0000Cock:m00?o
0000om2d__o@];h00oo@];h00ol0003oekJhomNf^002omNf^003o`000?oJ^[[of[Zj00Gof[Zj00?o
0000ombf/_l000001ooN^[<00ol0003ohKjdon6n]004on6n]0;o000000?okKnTo`000?o]_j@00_o]
_j@01ol0003ol<>Too33Y?o``jCo0000ooBoUOl000001?oga9<01_l0003ooL1joog0N_om`7[o0000
ook4M0;o000000?omkA7o`000?oonfX02ooonfX00ol0003ooo]ZoookJP2/oookJP?o0000A?oonfX0
1Ol0003ojKVQonViXOoY^J7o000000Cok;FG00?o0000on:ZVOoRZYT01_oRZYT01?l0003oeYfJo`00
0?l00007omFDSP03o`000?o7R8ooahR?00WoahR?00Co0000ol:4T?o2Q93o00004onhNXl01?l0003o
/GF@ok5eT?l0000DoieUT003o`000?mhB8_oN4R;00CoN4R;00?o0000oh5HVOn1F9T02?n1F9T00ol0
003oFcnGoe/oU`03oe/oU`;o00001omIC:T01?l0003o>cRSoc/hXol00004oemG/@04o`000?l08:Go
022Uo`0000;o3Bn_1OmCILP00olbE/Oo0000o`16aP03o`16aPKo00002?mCR>L00ol0003oA8GXodB5
j002odB5j003o`000?n4/O;oQ;7b01CoQ;7b00?o0000ojo7k?n_an`02On_an`2o`0000oo/L_]00?o
0000olgDgol000002_o?eml00ol0003od]_Oom;Kg`02om;Kg`03o`000?oLhm[og>?J00;og>?J00?o
0000omcSf_oLhmX01_oLhmX00ol0003ognOIo`000003on[bcP03o`000?oZm<goj_C=00;oj_C=0_l0
0002ongh/@03o`000?oIiG[o000001gooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]Zoook
JP0[oookJP008_oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z04Kooo]Z0ol00004
oaD3N003o`000?l]8I3o;B6@00;o00000om;=IH00ol0003oFDVToeU9Y003oeU9Y005o`000?mYE:Oo
JEBWofUDYol000002OmeI[@00ol0003oP6fdoh1]]002oh1]]0?o00002?n8Nkh00ol0003oT7nmoi1o
_@0;oi1o_@;o000000?oThK3o`000?nKS<<04OnKS<<00ol0003oXI32oj6@`P04oj6@`P;o00002_nS
VLX00ol0003oZI_7ojVKa`05o`0000[oZ9k<0_l000000onXXm7o0000oj^Pc00Coj^Pc0;o00004on_
Y<`2o`000003ojfZe?l0003o/jK;00ko/jK;0_l00005ok6[d@03o`000?nl[lgo_:o=00So_:o=00?o
0000okR/cOnh[<d00onh[<d6o`000003okf[b?l0003oajo300;oajo300?o0000olBbb?o4//P02oo4
//P00ol0003oa;37olB`a`04olB`a`03o`000?o;//;obk;200Gobk;200?o0000oljha?o>^<@01Oo>
^<@2o`000003olnb_Ol0003od;Bn00God;Bn00Go0000omNf^?oG][SoekJho`000009omZj^P;o0000
1_oN^[<00ol0003ohKjdon6n]006on6n]004o`000?o]_jCokKnTo`0000;okKnT00?o0000oo33Y?o`
`j@00_o``j@2o`0000ComlBC0_l00002oog0NP06o`000?ona7Co0000o`000?og]4Oo00003?oonfX0
0ol0003ooo]ZoookJP2YoookJP?o0000AooonfX00ol0003ojKVQonViX@02onViX@05o`000?o/]IOo
k;FGonbeUol000002?oRZYT01?l0003oeYfJomJMV_oFWIX3o`0000CoeIB>00?o0000olN8Soo7R8l0
2Oo7R8l01?l0003o`XB@ol:4T?l0000CokQjS`04o`000?naMI3o/GF@o`0001CoWFF@00?o0000ogQ8
RomhB8/00_mhB8/2o`0000_oPERI00?o0000oe/oUomK?iL00_mK?iL01?l0003oI4jRofA>X_l00007
oeU<Z@03oc/hXol0003oGeNa00GoGeNa00?o0000o`0PYOl000000_l=;jl00ol0003oDfG8oe=Ub003
oe=Ub0Go00000_l0A/H2o`0000;oIXgS0ol00006oe>8i`03o`000?m4QNSoA8GX00;oA8GX00?o0000
ohBal_n4/O805?n4/O800ol0003o[lO/ojo7k006ojo7k0;o00004_nabnd00ol0003ocmOOoloGg`07
oloGg`;o00001OoBfml01Ol0003og>?JomcSf_oLhm[o000000Sog>?J00Co0000omoWfOoOimWo0000
0_oZl/h00ol0003oj_C=on[dc@02on[dc@;o00000oo]n;42o`0001oooo]Z00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP0[oookJP008_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oo
nf[ooo]Z04Cooo]Z00Co0000o`00@?l0003o00001?lE0gP02?l0003o;B6@obdQT?l0003oAcBGo`00
0?m;=IKo00001_mIBJ@01?l0003oJEBWofUDYol0000;ogEV]0Go00002_n8Nkh00ol0003oT7nmoi1o
_@09oi1o_@;o00001?nCQ/<00ol0003oVhc3oi^<``0?oi^<``03o`000?nQT<;oXI3200;oXI320_l0
000<oj>IbP?o00003OnXW/`2o`0000CoZ:?A00?o0000oj^Pc?n[X<`03on[X<`2o`000003oj^Xe?l0
003o[jC<013o[jC<0_l00004ojfZe003o`000?ncY/_o/jK;00_o/jK;00?o0000ok6[dOnaZm401_na
Zm48okb_c@;o00003?nh[<d3o`000003olN_`ol0003oa;;800coa;;800?o0000olB`aoo4/<L01_o4
/<L00ol0003obk;2ol^b`P03ol^b`P03o`000?o>^<Coc[S400Soc[S40_l00007om2d_P04o`000?oG
][SoekJho`0000Wof[Zj00?o0000omZm_?l000001OoN^[<00ol0003ohKjdon6n]006on6n]0;o0000
00GokKnTo`000?o]_jCokKnTo`000005oo33Y003o`000?oga9?omlBC00;omlBC00Go0000oo_8TOl0
003ooL1jo`000002ook4M004o`000?og]4Oo0000o`0000cooo]Z00?o0000oookJ_oonfX0YOoonfX3
o`0004[ooo]Z00?o0000onViXOoY^J400ooY^J400ol0003ok;FGo`000008on:ZV@03o`000?oFWI[o
eYfJ00GoeYfJ0_l00002omFDSP03o`000?o7R8ooahR?00WoahR?00Co0000ol:4T?o2Q93o00004_nh
NXl01Ol0003o/GF@ok5eT?naMI3o000001CoWFF@00?o0000ogQ8RomhB8/00_l0000=oh5HV@05o`00
0?mK?iOoFcnGoe/oUol000001?mTCZ800ol0003oFDbYoeU<Z@04oeU<Z@03oc/hXol0003oGeNa00Ko
GeNa0_l00003o`d_[`CoDfG81?l00004o`16aP03o`000?l:C/_o000000CoIXgS1?l00003oe>8i`03
o`000?m4QNSoA8GX00;oA8GX00?o0000ohBal_n4/O805?n4/O800ol0003o[lO/ojo7k002ojo7k0?o
00004?nabnd3o`0000;o]<k]00?o0000oloGgoo?eml01Oo?eml00ol0003od]_Oom;Kg`05om;Kg`04
o`000?oLhm[og>?Jo`0000Sog>?J00Oo0000omoWfOoOimWognOIo`000?oZl/ko000000Goj_C=00Oo
0000ongh/Oo]n;7okORao`000?oIiG[o0000023ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003o
oo]ZoookJP0ZoookJP008_oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z04?ooo]Z
00Co0000o`00@?l0003o00000olE0gP00ol0003o;B6@obdQT002obdQT004o`000?m7=9Oo0000o`00
00OoFDVT0_l0000:ogEV]0?o000000?oP6fdo`000?l000002on8Nkh00ol0003oT7nmoi1o_@07oi1o
_@;o00001_nCQ/<00ol0003oVhc3oi^<``0?oi^<``03o`000?nQT<;oXI3200;o00002onSVLX3o`00
0003ojBLc_l0003oZ9k<00_oZ9k<0_l00006ojRSd@03o`000?n[X<coZj3<00goZj3<0_l00004oj^X
e003o`000?n_Y<co[jC<00go[jC<00?o0000ojfZe?n]Z]@01?n]Z]@00ol0003o/jK;ok>Vb`09ok>V
b`;o00002OnaZm400ol0003o_:o=okb_c@04okb_c@03o`000?nh[<go^:c=00go^:c=0ol000000oo4
//So0000olBbb00:olBbb003o`000?o4/<Ooa;3700Ooa;3700?o0000ol^b`_o;//800_o;//800ol0
003oc[S4oljha009oljha0;ocK[80_l00005om2d_P03o`000?oG][So000000Wof[Zj00Co0000omZm
_?oJ_Kcof[fl0_l00002omjj/`03o`000?oQ_[CohKjd00KohKjd00So0000on?2]_l0003o0000onfo
Y?l0003okKnTo`0000Gol<>T00?o0000ooO4Tooga9<00_oga9<00ol0003onlRAoo_8T@02o`0000;o
o/Ad00Co0000ooNdAol0003o00003OoonfX00ol0003ooo]ZoookJP2RoookJP;o0000C?oonfX00ol0
003ojKVQonViX@05onViX@;o00002?oRZYT00ol0003oeYfJomJMVP07omJMVP?o00002oo7R8l00ol0
003o`XB@o`00000CokQjS`05o`000?naMI3o/GF@ok5eT?l000005?nMII03o`00013oPERI0_mK?iL0
0ol0003oI4jRofA>XP04ofA>XP03o`000?mIC:WoFDbY00?oFDbY00?o0000oemG/OmOEk401omOEk42
o`0000;o3Bn_1?l000001?mCILSo0000obeKc_l]Flh2o`0000?o04K60_l00008ofJ=h`;o000000?o
DhSWo`000?m4QNP01?m4QNP00ol0003oQ;7bohBalP0DohBalP04o`000?n_anco0000o`00017o/L_]
0_l00006okC>k@03o`000?o?emoocmOO00?ocmOO00?o0000om;KgooBfml01ooBfml2o`0000Sog>?J
00Go0000omoWfOoOimWognOIo`000002on[bcP03o`000?oZm<goj_C=00?oj_C=00Co0000ongh/Oo]
n;7okORa0ol0000PoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX0:OoonfX002;o
oo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP11oookJP;o000000Ko0010o`000?l<
07Oo0000oaD3N?l00005obdQT005o`000?m7=9Oo0000oeI9Y_l000001_mIBJ@00ol0003oMFJdogEV
]006ogEV]0?o00000_meI[@2o`0000koR7^n00?o0000oi1o_On@Okd01On@Okd00ol0003oThK3oi>6
``06oi>6``03o`000?nKS<?oVhc300koVhc30ol0000;oj>IbP?o00001OnTW<h00ol0003oZ9k<ojRN
c006ojRNc0?o00002OnXXm400ol0003oZj3<oj^Pc00:oj^Pc0;o00001_n[Z=@00ol0003o[jC<ojnT
c00;ojnTc0;o00002?n]Z]@00ol0003o/jK;ok>Vb`06ok>Vb`;o00002onaZm400ol0003o_:o=okb_
c@03okb_c@03o`000?nh[<go^:c=00go^:c=00?o0000okF_dol000000oo2]<d4o`0000Koa;;800?o
0000olB`aoo4/<L02Oo4/<L01?l0003obk;2ol^b`_l0000;oljha0GocK[80_l00004om2d_P03o`00
0?oJ^[[of[Zj00Oof[Zj00?o0000omZm_?oJ_K`01?oJ_K`00ol0003og[Zco`000008on6n]006o`00
0?oS`[Ko0000onS2[_l0003okKnT0_l00004oo33Y003o`000?ocb:?o000000;omlBC00?o0000oo_8
TOokb9400_okb9400ol0003oo/Adook4M004o`0000gooo]Z00?o0000oookJ_oonfX0WooonfX3o`00
04kooo]Z00?o0000onViXOoY^J401_oY^J42o`0000OohZZI00?o0000omJMV_oFWIX02OoFWIX4o`00
00SoahR?00?o0000ol:4T?l000004onhNXl01Ol0003o/GF@ok5eT?naMI3o0000017oWFF@1?l0000B
oh5HV@03oe/oUol0003oI4jR00OoI4jR00Co0000oeU<ZOmIC:WoFDbY0_l00009oemG/@;oC6360ol0
0004oe=Ub003o`000?l]Flko;E_>00;o;E_>00Ko0000o`16a_l0A/Ko0000o`Y>bol0000:ofJ=h`Co
00000_m4QNP00ol0003oQ;7bohBalP0@ohBalP?o00000_n4/O800ol0003o/L_]ok7;k@0?ok7;k@;o
00002Ondc^d01Ol0003ocmOOoloGgoo?emoo000000[od]_O00?o0000omcSf_oLhmX01_oLhmX00ol0
003ognOIomoWf@02omoWf@03o`000?oZl/ko000000Goj_C=0_l00002ongh/@?o00008_oonfX00ol0
003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z02Wooo]Z000RoookJP03o`000?oonf[ooo]Z017o
oo]Z00?o0000oookJ_oonfX0@?oonfX4o`000004o``0Mol0003o5@=ho`0000Go;B6@0_l00003oeI9
YP03o`000?mIBJCoFDVT00?oFDVT00?o0000ogEV]?meI[@01?meI[@2o`0000CoMFJd0_l0000?ohQk
_P03o`000?n@OkgoT7nm00?oT7nm0_l0000:oi>6``03o`000?nKS<?oVhc300[oVhc30ol00002oifD
b`03o`000?nSVL[oXiW:00KoXiW:0ol00008ojBLcP03o`000?nXW/coZ9k<00GoZ9k<00?o0000ojRS
dOnXXm402onXXm400ol0003oZj3<oj^Pc006oj^Pc0?o00002On[Z=@00ol0003o[jC<ojnTc008ojnT
c0;o00002_n]Z]@00ol0003o/jK;ok>Vb`05ok>Vb`03o`000?naZm7o/J_A00co/J_A0onl[ld2o`00
00ko^:c=0_l00003okF_d`03o`000?o2]<go`[C=00Co`[C=0ol00002olBbb003o`000?o4/<Ooa;37
00[oa;3700?o0000ol^b`_l000002oo>^<@8olfjb0;o000000?od;Bno`000?l000002?oJ^[X00ol0
003of[flomZm_006omZm_0;o00001ooQ_[@01_l0003ohl:fon?2]_oS`[Ko0000onS2[P?o00001?o`
`j@01_l0003ollRSoo?8Xol0003omlBCo`0000ConlRA00?o0000ook4M?ona7@00ol000000ooa/CWo
0000oookJP0<oookJP03o`000?oonf[ooo]Z09_ooo]Z0ol0001@oookJP03o`000?oR^joo000000Oo
jKVQ00?o0000on6`Y?l000001_oRZYT00ol0003oeYfJomJMVP09omJMVP04o`000?o1Rico`H^Lol6;
W0Ko00000_o7R8l00ol0003o`XB@o`00000CokQjS`05o`000?naMI3o/GF@ok5eT?l000003?nMII05
o`0000?oX76L00?o0000oh5HVOn1F9T03on1F9T2o`0000[oI4jR00?o0000oeU<ZOl000000_mQF;40
0ol0003oGeNaoemG/@05oemG/@?o000000CoC636o`000?l=;joo00000omCILP00ol0003o;E_>obeK
cP03obeKcP03o`000?l0A/Ko000000;o2Tk;00?o0000ofJ=homVSN<02?mVSN<00ol0003oEHWWoeF9
i`04o`0000KoQ;7b2ol00005ohRclP03o`000?nabngo/L_]00co/L_]0ol0000<okC>k@03o`000?o?
emoo000000Wod]_O00?o0000omCOgol000001ooLhmX00ol0003ognOIomoWf@03omoWf@;o00001OoZ
m<d01_l0003ojoO8o`000?o]n;7o0000onOgY@;o00008ooonfX00ol0003ooo]ZoookJP0XoookJP03
o`000?oonf[ooo]Z02Sooo]Z000RoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0
?_oonfX00ol0003o000ho`000002o`000003o``0Mol0003o000000Ko;B6@00?o0000oeI9Y_mFBJH0
0omFBJH01?l0003oFDVToeU9Y?mIBJ@2o`0000?oMFJd0ol00005ogEV]003o`000?mkLKco000000oo
R7^n00Co0000oi1o_On@OkgoT7nm0_l0000<oi>6``03o`000?nKS<?oVhc300KoVhc31?l00006oifD
b`03o`000?nSVL[oXiW:00;oXiW:0ol0000<ojBLcP03o`000?nXW/coZ9k<00;oZ9k<00?o0000ojRS
dOnXXm403OnXXm400ol0003oZj3<oj^Pc004oj^Pc0;o00003On[Z=@00ol0003o[jC<ojnTc005ojnT
c0;o00003?n]Z]@00ol0003o/jK;ok>Vb`03ok>Vb`;o00003onaZm400ol0003o_:o=o`00000?okR/
c@03o`000?ne[m?o]JoC00?o]JoC00?o0000ol:dcOo2]<d01oo2]<d2o`0000koa;3700?o0000oljh
a?o>^<@02Oo>^<@;olfjb0;o000000?odKS2o`000?oJ^[X01OoJ^[X00ol0003of[flomZm_007omZm
_003o`000?oL`Kko000000GohKjd00?o0000on?2]_oS`[H00ooS`[H01?l0003oj<:^o`000?l00004
oo33Y004o`000?ocb:?ollRSoo?8X`;o00001?okb942o`000006ook4M?l0003o0000o`000?oa/CWo
00003_oonfX00ol0003ooo]ZoookJP2GoookJP?o0000DooonfX01?l0003oh[^_on:k[ol00005onVi
X@04o`000?oQ/:CohK2Ton6`Y0;o00001?oRZYT00ol0003oeYfJomJMVP08omJMVP03o`000?o1Rico
`H^L00So`H^L1Ol0000CokQjS`05o`000?naMI3o/GF@ok5eT?l000001onMII05o`0000SoX76L00?o
0000oh5HVOn1F9T03On1F9T2o`000003ohYUX_l0003oI4jR00[oI4jR0_l00002of5H/@03o`000?mO
Ek7oGeNa00;oGeNa1?l00004odaPaP05o`000?l=;jooDfG8oe=Ub?l000002?l]Flh01?l0A/Ko0000
o`Y>bol0000:ofJ=h`03o`000?mERNOoEHWW00?oEHWW1ol0000AohRclP03o`000?nabngo/L_]00Wo
/L_]0_l0000@okC>k@03o`000?oBfmood]_O00Ood]_O00Co0000omCOgooDgmoo00001_oLhmX00ol0
003ognOIomoWf@04omoWf@03o`000?oZm<goj_C=00?oj_C=00Ko0000on_gb?o[mlSo0000ongh/OoW
mjD3o`0002?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0WoookJP008OoonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z03gooo]Z00Go0000o`00>?l0003o0000o`00
I`02o`0000Oo;B6@00?o0000oeI9Y_mFBJH01?mFBJH00ol0003oFDVTo`000002ofAI/0?o00001ome
I[@01Ol0003oNg6log]a_?mkLKco000000ooR7^n00?o0000oi1o_Ol000003_nCQ/<00ol0003oVhc3
oi^<``03oi^<``?o00002_nMU</00ol0003oXiW:oj>IbP02o`0000ooY9c>00Co0000ojRNc?nXW/co
00004_nXXm401?l0003oZj3<oj^Pc?n[X<`2o`0000ooZjSD00?o0000ojnTc?n_Y<`00on_Y<`2o`00
00oo[J[D00?o0000ok>VboncY//00_l0000Aok6[d@;o00003onh[<d00ol0003o]JoCokF_d`05okF_
d`03o`000?o2]<go`[C=00Go`[C=00Co0000ol6fd?o1]]3o`KK@0ol00008olB`a`03o`000?o3]<co
000000[oc[S43?o=^/P00ol0003ocKg;o`000002o`0000Gof[Zj00?o0000omZm_?oJ_K`01_oJ_K`0
1Ol0003og<6nomc1__oL`Kko000000CohKjd00?o0000on?2]_oS`[H00ooS`[H01Ol0003oj<:^o`00
0?o``jCo000000;ol<>T00?o0000oo?8Xoocb:<00oocb:<01_l0003onlRAoo_8TOokb97o0000oog=
S@;o00000_onaV`00ol0003olK4io`00000>oookJP03o`000?oonf[ooo]Z09Cooo]Z0ol0001Foook
JP05o`000?oR^jooh[^_on:k[ol000001?oY^J400ol0003ohK2Ton6`Y003on6`Y0;o000000?ohZZI
o`000?oFWIX02_oFWIX00ol0003o`H^Lol6;W00:ol6;W003o`000?o2S9co000000[o00002?nhNXl0
0ol0003o/GF@ok5eT002ok5eT003o`000?nMII3oWFF@00Go00003OnPLI`00ol0003oPERIoh5HV@0;
oh5HV@;o00000on:IJ800ol0003oI4jRofA>XP08ofA>XP03o`000?mjHZ_oNV:[00?o000000CoGeNa
o`000?l0003o00000_mOEk400ol0003oC636odaPaP04odaPaP;o000000?oDfG8o`000?l]Flh02?l]
Flh2o`000003o`Y>bol0003oIXgS00WoIXgS00?o0000oeF9iomERNL00omERNL00ol0003oR;?bohRc
lP0EohRclP03o`000?nabngo/L_]00Ko/L_]0_l0000?okC>k@;o00000_nidnh00ol0003od]_Oom;K
g`05om;Kg`05o`000?oDgmooe=oOomCOgol000001OoLhmX00ol0003ognOIomoWf@05omoWf@03o`00
0?oZm<goj_C=00?oj_C=00Ko0000on_gb?l0003okORao`000?oWmjD2o`0002Gooo]Z00?o0000oook
J_oonfX0:?oonfX00ol0003ooo]ZoookJP0WoookJP008OoonfX00ol0003ooo]ZoookJP0EoookJP;o
0000?OoonfX00ol0003o000ho`000002o`00I`;o00001_l]8I02o`0000OoETVV1Ol00008ogEV]003
o`000?mkLKcoNg6l00;oNg6l00?o0000ohQk__n8Nkh03?n8Nkh2o`00017oThK300?o0000oi^<`ol0
00000_l0000=oifDb`;o00004_nTW<h2o`0001CoZ:?A00Co0000oj^Pc?l0003o00004_n[Z=@01Ol0
003o[jC<ojnTc?n_Y<co0000017o[J[D00?o0000ok>Vbol000004OnaZm42o`000003ojj`fOl0003o
^:c=00co^:c=0_l00009okF_d`Ko`[C=00?o0000ol6fd?o1]]001Oo1]]02o`0000Goa;3700Go0000
ol>dc?o3]<co`kC<o`000008oljha0cocK[800?o0000olfmboo=_L/00_o=_L/00ol0003of[ZjomZj
^P02omZj^P03o`000?oJ_Kcof[fl00Kof[fl00?o0000omc1__oL`Kh00ooL`Kh01?l0003ohKjdon6n
]?l00007on?2]P07o`000?o[aZoo0000oo33Y?l0003ol<>To`000005oo?8X`06o`000?okb97onlRA
oo_8TOl0003ooLf=0_l00002ook6K004o`000?oa/CWo0000o`0000kooo]Z00?o0000oookJ_oonfX0
T?oonfX3o`0005Sooo]Z0_l00003on:k[`05o`000?oY^J7ojKVQonViXOl000002?oQ/:@2o`0000_o
eYfJ00?o0000ol6;W?o1Ri`02_o1Ri`00ol0003o`XbLo`00000:okZ6WQ3o00004_nPLI`00ol0003o
PERIoh5HV@09oh5HV@;o00001On:IJ800ol0003oI4jRofA>XP07ofA>XP03o`000?mjHZ_oNV:[00;o
NV:[0ol00005oemG/@03o`000?m<H<KoC63600GoC63600?o0000oe=Ub?l000002Ol]Flh01?l0003o
=67Ao`000?l0000:ofJ=h`03o`000?mERNOoEHWW00CoEHWW00?o0000ohRcl_n8/o805On8/o800ol0
003o/L_]ok7;k@02ok7;k@?o00003ondc^d2o`0000Go^M?^00?o0000om;KgooBfml00ooBfml00ol0
003oe=oOomCOg`02omCOg`03o`000?oLhm[og>?J00;og>?J00?o0000omoWfOoOimT01OoOimT2o`00
00Coj_C=00Go0000on_gb?o[mlSo0000ongh/@02onOgY@;o00009_oonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z02Kooo]Z000QoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oook
J_oonfX0>OoonfX01?l0003o000ho`00>?l00002o`00I`03o`000?lW7Y3o000000Co;B6@00?o0000
od4jX_l000001OmFBJH3o`000004ofEM]Ol0003o0000o`0000OoMFJd00?o0000og]a_?mkLK`00omk
LK`00ol0003oR7^nohQk_P0;ohQk_P03o`000?n<P/Co000000ooThK31?l0000=oifDb`?o000000?o
WiW>o`000?nTW<h03_nTW<h3o`000003ojFUe_l0003oZ:?A01?oZ:?A0_l0000Doj^Xe004o`000?n_
Y<co0000o`0001;o[J[D0_l0000@ok6[d@;o00001?n^/=T00ol0003o^:c=okR/c@09okR/c@03o`00
0?ne[m?o]JoC00Wo]JoC1Oo2]<d00ol0003o`KK@ol6fd008ol6fd0?o000000?oa;37o`000?o3]<`0
0oo3]<`00ol0003oc[S4oljha005oljha0cocK[800?o0000olfmboo=_L/01?o=_L/2o`000003omZj
^_l0003of[fl00Sof[fl00?o0000omc1__oL`Kh01?oL`Kh00ol0003ohKjdo`000007on?2]P03o`00
0?o[aZoojlJ_00;o000000?ol<>To`000?ocb:<00oocb:<00ol0003om/fRo`000002oo_8T@04o`00
0?omcHgooLf=o`0000;oo/I/00Co0000oo6a>Ol0003o00003ooonfX00ol0003ooo]ZoookJP2=oook
JP;o0000FooonfX00ol0003ohKjeo`000003on:k[`04o`000?oY^J7ojKVQo`0000WohK2T0_l00009
omJMVP03o`000?o1Rico`H^L00co`H^L00?o0000okZ6W_njQYh04OnjQYh00ol0003o/gjKok=nV`02
ok=nV`03o`000?nPLIcoX76L01;oX76L00?o0000oh5HVOn1F9T01on1F9T2o`0000SoRVFR00?o0000
ofA>X_mTCZ801OmTCZ800ol0003oNV:[ogYRZ`03o`0000;oNV:[0_l00004oemG/@03o`000?m<H<Ko
C63600KoC6360ol00008obeKcP04o`000?ldHM7o=67AocAQd@Co00001_mVSN<00ol0003oEHWWoeF9
i`05oeF9i`03o`000?n8/o;oR;?b01GoR;?b00Co0000ok7;kOl0003o00004?ndc^d2o`0000So^M?^
00Go0000om;KgooBfmood]_Oo`000006omCOg`04o`000?oLhm[og>?Jo`0000OognOI00?o0000on?[
e_l000000ooZm<d01?l0003ojoO8on_gb?o[mlP2o`000004onOgYOl0003o0000o`0002Oooo]Z00?o
0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0UoookJP008OoonfX00ol0003ooo]ZoookJP0H
oookJP03o`000?oonf[ooo]Z03Sooo]Z00Co0000o`00>?l003So00000_l006L00ol0003o9aj@o`00
0003obdQT004o`000?m1>Z;o@CZRo`0000?oETVV0_l000000omFBJKo0000ofEM]@03ofEM]@;o0000
1OmeI[@00ol0003oNg6log]a_005og]a_003o`000?n8NkkoR7^n00WoR7^n00Go0000ohb2a?n<P/Co
S8;4o`00000:oi>6``Co00000_nFS/X00ol0003oWIC;oifDb`09oifDb`?o00001OnOVLh00ol0003o
Y9c>ojBLcP09ojBLcP?o00001OnUYMH00ol0003oZ:?AojRSd@0>ojRSd@?o000000?oYjgKo`000?n[
Z=@04on[Z=@2o`0001;o[J[D0_l000000onY/Mgo0000ok6[d@0=ok6[d@;o00001on^/=T00ol0003o
^:c=okR/c@06okR/c@;o00003One[m<3ol:dc@03o`000?o1]]3o`KK@00_o`KK@1?l00004ol>dc003
o`000?o>^<Coc[S400?oc[S43?o=^/P00ol0003ocKg;olfmb`05olfmb`04o`000?oE^l3o0000o`00
00Sof[fl00?o0000omc1__oL`Kh01_oL`Kh00ol0003ohl:fon?2]P05on?2]P03o`000?oVakOo0000
00;ojlJ_0_l00005oo?8X`06o`000?ofcJ;om/fRo`000?okb97o00000_omcHd00ol0003oo/I/ook6
K004o`0000oooo]Z00?o0000oookJ_oonfX0R_oonfX3o`0005cooo]Z00Co0000on6n]OoQ_[GohKje
0_l00002on:k[`03o`000?oY^J7o000000WohK2T00?o0000omRUX_l000000_l00006omJMVP03o`00
0?o1Rico`H^L00co`H^L00?o0000okZ6W_njQYh04?njQYh00ol0003o/gjKok=nV`03ok=nV`03o`00
0?nPLIcoX76L01?oX76L00?o0000oh5HVOn1F9T01?n1F9T2o`0000[oRVFR00?o0000ofA>X_mTCZ80
1?mTCZ84o`0000GoNV:[00?o0000oe]G/ol000000_mOEk400ol0003oC636odaPaP07odaPaP03o`00
0?m/M/coK7K<00;o00001_l]Flh01Ol0003o=67AocAQdOldHM7o000000?oMY7P1Ol00002ofJ=h`03
o`000?mERNOoEHWW00GoEHWW00?o0000ohRcl_n8/o804On8/o82o`0000;oR;?b00?o0000okC>kOnd
c^d03_ndc^d2o`0000_o^M?^00?o0000om;Kgol000001ooDgml00ol0003og>?Jo`000007omoWf@04
o`000?oSjmKohn_Fo`0000;oj_C=00?o0000on_gb?o[mlP00_o[mlP00ol0003oioNUonOgY@02o`00
02Sooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0UoookJP008OoonfX00ol0003o
oo]ZoookJP0IoookJP03o`000?oonf[ooo]Z03Oooo]Z00Co0000o`00>?l0003o00000_l006L01?l0
003o9aj@obLNT?l00002obdQT003o`000?m1>Z;o@CZR00Co00000_mFBJH00ol0003oIEfeofEM]@04
ofEM]@?o00000_meI[@00ol0003oNg6log]a_006og]a_003o`000?n8NkkoR7^n00OoR7^n0_l00004
ohb2a003o`000?nCQ/?oThK300CoThK31?l00007oiJ>bP03o`000?nMU<_oWIC;00KoWIC;0_l00008
oinIcP03o`000?nTW<koY9c>00KoY9c>0ol00009ojFUeP03o`000?nXXm7oZ:?A00_oZ:?A0_l00005
ojN]f`03o`000?n[Z=CoZjSD00koZjSD0ol000000onX/Mko0000ojfZe00?ojfZe0;o00001?nY/Md0
0ol0003o/J_Aok6[d@09ok6[d@;o00002On^/=T00ol0003o^:c=okR/c@05okR/c@03o`000?ne[m?o
]JoC00go]JoC0_o2]<d00ol0003o`KK@ol6fd00;ol6fd003o`000?nm]=7o_KCA00;o_KCA0ol00002
ol>dc004o`000?o>^<Coc[S4oljha0cocK[800?o0000olfmboo=_L/01oo=_L/2o`000003omNo`ol0
003of[fl00Kof[fl00?o0000omc1__oL`Kh01_oL`Kh2o`0000Kohl:f00?o0000onK7]ol000000oo[
aZl2o`0000CollRS00?o0000ooK=X_ofcJ800_l00003oog=S@03o`000?onaVcoo/I/00?o000000?o
iZ/Xo`000?oonfX03_oonfX00ol0003ooo]ZoookJP26oookJP?o0000G_oonfX00ol0003ohKjeon6n
]@04on6n]@04o`000?oR^jooh[^_o`0000WohK2T00?o0000omRUX_oHYJ800ooHYJ82o`0000CoeYfJ
00?o0000ol6;W?o1Ri`03?o1Ri`00ol0003o^XJNokZ6WP0@okZ6WP03o`000?ncOY_o/gjK00?o/gjK
00?o0000oj1aW?nPLI`04onPLI`00ol0003oPERIoh5HV@02oh5HV@;o00003?n:IJ800ol0003oI4jR
ofA>XP02ofA>XP?o00002OmjHZ/01Ol0003oFeNco`000?mOEk7o000000WoC63600?o0000ofafc?m/
M/`00_m/M/`2o`0000Co;E_>00?o0000ocAQdOldHM400_ldHM400ol0003oMY7PogJAh005ogJAh0Ko
00001?mERNL00ol0003oR;?bohRclP0:ohRclPOo00001?n>]o800ol0003o]<k]okC>k@0<okC>k@;o
00003_nidnh00ol0003oe=oOomCOg`06omCOg`03o`000?oLhm[ognOI00KognOI00Go0000on?[e_oS
jmKohn_Fo`000002on[dc@03o`000?o[mlSojoO800;ojoO800?o0000onOgYOl000000_l0000Yoook
JP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX09?oonfX0027ooo]Z00?o0000oookJ_oo
nfX06_oonfX00ol0003ooo]ZoookJP0foookJP05o`000?l003So0000o`000?l006L00_l00002obLN
T004o`000?l]8I3o0000od4jXPCo00000omFBJH00ol0003oIEfeofEM]@05ofEM]@03o`000?mdIkKo
M6Nf00Go00001_mkLK`00ol0003oR7^nohQk_P06ohQk_P03o`000?n<P/CoS8;400CoS8;400?o0000
oi>6`onCQ/<01?l0000<oiJ>bP03o`000?nMU<_oWIC;00;oWIC;0ol0000;oinIcP03o`000?nTW<ko
Y9c>00;oY9c>0ol0000<ojFUeP03o`000?nXXm7oZ:?A00SoZ:?A0ol00008ojN]f`03o`000?n[Z=Co
ZjSD00_oZjSD0_l00005ojRagP03o`000?n]Z]Co[J[D00_o[J[D0_l00007ojVag@03o`000?naZm7o
/J_A00Oo/J_A00?o0000ojj`fOn^/=T02_n^/=T00ol0003o^:c=okR/c@03okR/c@03o`000?ne[m?o
]JoC00ko]JoC0_l0000<ol6fd0;o00002?nm]=43o`0000;oc[S43?o=^/P00ol0003ocKg;olfmb`08
olfmb`04o`000?oG_l?oeko3omNo``;o00001?oJ_K`00ol0003og<6nomc1_P06omc1_P04o`000?oN
aKoog/Foo`0000Cohl:f00Go0000onK7]ooVakOoi/Ngo`000002on_6[`03o`000?ocb:?o000000;o
llRS00?o0000ooK=X_ofcJ800_ofcJ801?l0003ooLf=oog=SOomcHd2o`000006ook6K?l0003o0000
o`000?oVZbSo00004?oonfX00ol0003ooo]ZoookJP22oookJP?o0000HOoonfX00ol0003ohKjeon6n
]@05on6n]@03o`000?oR^joo000000WohK2T00?o0000omRUX_oHYJ801OoHYJ84o`0000ko`H^L0_l0
000AokZ6WP03o`000?ncOY_o/gjK00Co/gjK00?o0000oj1aW?nPLI`04onPLI`00ol0003oPERIoh5H
V@02o`0000koRVFR00?o0000ofA>X_l000000ol0000;ogYRZ`03o`000?mKEk?oFeNc00;o00002Om<
H<H7ofafc003o`000?l]Flko;E_>00;o;E_>00Go0000ocAQdOldHM7o=67Ao`000009ogJAh004o`00
0?mWSN?oIhgSofN=h`Ko00001?n8/o87o`0000coS[Ob00?o0000okC>kOndc^d02_ndc^d00ol0003o
^M?^okWCkP0<okWCkP04o`000?nnf^ko_][^o`0000Ooe=oO00?o0000omoWfOoOimT01OoOimT00ol0
003ohn_Fon?[eP02on?[eP03o`000?oZm<go000000CojoO80_l000001?oWmjGo0000o`000?l0000Z
oookJP03o`000?oonf[ooo]Z02Kooo]Z0ol0000UoookJP008OoonfX00ol0003ooo]ZoookJP0Koook
JP03o`000?oonf[ooo]Z03Gooo]Z00Co0000o`00>?l0003o001S0ol00003obLNT0?o00000om1>Z80
1?l0003oETVVoeI9Y_l00008ofEM]@04o`000?mdIkKoM6Nfo`0000CoOgW21Ol00002og]a_003o`00
0?n8NkkoR7^n00CoR7^n00Co0000ohb2a?n<P/CoS8;41ol0000@oiJ>bP03o`000?nMU<_oWIC;00;o
00003_nOVLh00ol0003oY9c>ojBLcP02o`00013oYJGF00?o0000ojRSdOnXXm401OnXXm42o`0000_o
YjgK00?o0000oj^Xe?n[Z=@02?n[Z=@3o`0000SoZ;7N00?o0000ojfZe?n]Z]@01on]Z]@3o`0000[o
ZK7M00?o0000ok6[dOnaZm401?naZm42o`0000go[[3I00Co0000okR/cOnh[<go^:c=0_l0000?okF_
d`;o000000?o/[?Jo`000?o1]]002_o1]]000ol0003o_KCAokfdd@0;okfdd@;o00002oo=^/P00ol0
003ocKg;olfmb`08olfmb`;o00001OoG_l<01?l0003of[flomZm_?l00008omc1_P03o`000?oNaKoo
g/Fo00;og/Fo00Co0000on?2]_oS`[Ko00001?oVakL01?l0003ojlJ_o`000?o^bjl2o`0000;ollRS
00?o0000ooK=X_ofcJ800_ofcJ801_l0003ooLf=oog=SOomcHgo0000oooAR@;o000000Coo<MRo`00
0?oVZbSo00004?oonfX00ol0003ooo]ZoookJP1ooookJP?o0000HooonfX00ol0003ohKjeon6n]@07
on6n]@?o00002?oQ/:@00ol0003of:FRomRUXP08omRUXP?o00003?o1Ri`2o`00017o^XJN00?o0000
ok=nVoncOY/01?ncOY/00ol0003oX76Loj1aW00Coj1aW0?o00003on:IJ83o`0000;oI4jR00?o0000
ogYRZomjHZ/02_mjHZ/00ol0003oFeNcoe]G/`02ogA[^P03o`000?m<H<KoC63600KoC63600?o0000
ofafc?m/M/`01Om/M/`2o`0000;o;E_>00?o0000ocAQdOldHM400_ldHM400ol0003oMY7PogJAh006
ogJAh003o`000?mWSN?oIhgS00KoIhgS1Ol0000DohjglP03o`000?ndc^go]<k]00Oo]<k]0_l0000=
okWCkP03o`000?nnf^ko_][^00?o_][^00?o0000omCOgooDgml00ooDgml2o`0000KognOI00?o0000
on?[e_oSjmH00ooSjmH00ol0003oj_C=on_gb003on_gb0;o000000CoioNUo`000?oSm9_o0000:ooo
nfX00ol0003ooo]ZoookJP0SoookJP?o00000_oonfX00ol0003ooo]ZoookJP0SoookJP008?oonfX0
0ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z03?ooo]Z0ol00002o`00H`So00001?m1>Z80
0ol0003oETVVo`00000:ofEM]@;o00002_moNL8=o`0000GoT8c;00?o0000oiJ>b_nFS/X03onFS/X2
o`00017oWiW>0_l0000CojFUeP03o`000?nXXm7oZ:?A00?oZ:?A0_l0000>ojN]f`03o`000?n[Z=Co
ZjSD00GoZjSD0_l0000<ojRagP03o`000?n]Z]Co[J[D00Co[J[D0_l0000=ojVag@03o`000?naZm7o
/J_A00;o/J_A0_l0000@ojj`f@03o`000?nh[<go000000oo]JoC0_l00004ok:cfP03o`000?o1]]3o
`KK@00Ko`KK@0_l0000=okfdd@;o000000?ob[c=o`000?o=^/P02?o=^/P00ol0003ocKg;olfmb`08
olfmb`04o`000?o=_L_ocKg;o`0000Goeko300?o0000omZm_?l000002?oL`Kh00ol0003og/Foomk5
_`03omk5_`03o`000?oS`[Ko000000Goi/Ng00Co0000onk;[oo^bjook/^_0_l000000oocb:?o0000
ooK=XP02ooK=XP03o`000?oidZ7o000000;ooLf=00So0000oooAROl0003o0000ooc7H_l0003oiZ/X
o`00017ooo]Z00?o0000oookJ_oonfX0NooonfX3o`0006Kooo]Z00?o0000on6n]OoQ_[D01ooQ_[D0
0ol0003oe[6do`000007on6`Y003o`000?oHYJ;of:FR00Wof:FR00?o0000ol^IXoo;VJ<01Ol00006
ol6;W003o`000?o1S9co0000013o^XJN00?o0000ok=nVoncOY/01_ncOY/00ol0003oX76Loj1aW00?
oj1aW0Co00003_n:IJ83o`0000;oRVFR00?o0000ofA>X_l000003_mjHZ/2o`0000?oM6^j0_l00005
odaPaP03o`000?mBI/Wo000000SoK7K<00?o0000obeKc_l000001OldHM400ol0003oMY7PogJAh005
ogJAh003o`000?mWSN?oIhgS00OoIhgS00?o0000ohjgl_n>]o805_n>]o800ol0003o]<k]okC>k@04
okC>k@;o00003Onidnh2o`0000Oo_][^00Oo0000omCOgooDgmooe=oOo`000?oHhmko000000GognOI
00?o0000on?[e_oSjmH01?oSjmH00ol0003ojoO8on_gb002on_gb005o`000?o/nL7o0000o`000?oS
m9/00_l0000/oookJP03o`000?oonf[ooo]Z01oooo]Z0ol00005oookJP03o`000?oonf[ooo]Z02?o
oo]Z000PoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0<_oonfX3o`0000;o001S
1?l000001OlW7Y3o0000ochkYOln>jGo000000?o@CZR0_l0000;ofEM]@03o`000?moNL;oOgW200_o
OgW200?o0000ohQn`_n8O/800_l0000<oi2<b`03o`000?nFS/[oUXk:00coUXk:0_l000000onHU<go
0000oinIcP0=oinIcP?o000000?oXZGHo`000?nUYMH04onUYMH00ol0003oZ:?Ao`000002o`00013o
YjgK00?o0000oj^Xe?n[Z=@00on[Z=@2o`0000koZ;7N00?o0000ojfZe?n]Z]@00_n]Z]@2o`00013o
ZK7M00Co0000ok6[dOl0003o00004_n^/=T2o`0000ko]JoC0_l00006ok:cfP03o`000?o1]]3o`KK@
00Go`KK@00?o0000okfddOnm]=403?nm]=400ol0003o^kOFo`000002olZlc@;o00001_o=^/P00ol0
003ocKg;olfmb`08olfmb`03o`000?o=_L_ocKg;00;ocKg;00?o0000omNo`ooG_l<00ooG_l<00ol0
003og<6nomc1_P06omc1_P03o`000?oNaKoog/Fo00Gog/Fo00?o0000onK7]ooVakL01?oVakL00ol0
003ok/^_onk;[`02onk;[`;o00001?ofcJ801Ol0003onM:Qo`000?omcHgo000000?oom6900?o0000
ooc7H_l000000_l0000BoookJP03o`000?oonf[ooo]Z07Sooo]Z0_l0001XoookJP03o`000?oQ_[Go
hKje00OohKje00Co0000omJa]?oF/KCoe[6d0_l00005on6`Y003o`000?oHYJ;of:FR00Sof:FR00?o
0000ol^IXoo;VJ<01_o;VJ<4o`0000;o`H^L00?o0000ol6<W?l000004?njQYh00ol0003o/gjKok=n
V`06ok=nV`03o`000?nPLIcoX76L00[oX76L1Ol00003oj5gY003o`000?n:IJ;oRVFR00WoRVFR0ol0
0005ohYUXP;o00003_mjHZ/2o`0000KoM6^j00?o0000odaPa_m<H<H00_m<H<H01?l0003oDVK9oe9V
bOl00009ofafc0;o00001?ldHM400ol0003oMY7PogJAh005ogJAh003o`000?mWSN?oIhgS00SoIhgS
00?o0000ohjgl_n>]o805On>]o800ol0003o]<k]okC>k@02okC>k@;o00003Onidnh2o`0000[o_][^
00?o0000omCOgol000000_oHhmh00ol0003ognOIomoWf@02omoWf@03o`000?oSjmKohn_F00Gohn_F
00?o0000on_gb?o[mlP00_o[mlP01_l0003ok?W1o`000?l0003ohoBKo`0002kooo]Z00?o0000oook
J_oonfX06ooonfX3o`0000Sooo]Z00?o0000oookJ_oonfX08ooonfX0023ooo]Z00?o0000oookJ_oo
nfX07ooonfX00ol0003ooo]ZoookJP0aoookJPKo00000_l61hD00ol0003o9aj@o`000003ochkY@04
o`000?m1>Z;o@CZRo`0000coIEfe00?o0000ogmi`_moNL803?moNL82o`0000koT8c;00?o0000oiJ>
b_nFS/X02_nFS/X2o`0000CoV9C=00?o0000oinIc_nOVLh02?nOVLh3o`0000GoXZGH00?o0000ojFU
e_nUYMH04OnUYMH2o`0001CoYjgK00?o0000oj^Xe?l000000_l0000AojRagP04o`000?n]Z]Co0000
o`0001;oZK7M0_l0000Aojj`f@?o000000?oZ;GRo`000?ne[m<02one[m<2o`0000Wo/[?J00?o0000
ol6fd?o1]]000oo1]]000ol0003o_KCAokfdd@0;okfdd@;o00000onk]mH4olZlc@;o00000oo=^/P0
0ol0003ocKg;olfmb`08olfmb`03o`000?o=_L_ocKg;00CocKg;00?o0000omNo`ooG_l<00_oG_l<2
o`0000Kog<6n00?o0000omk5_ooNaKl01_oNaKl00ol0003oi/NgonK7]`03onK7]`03o`000?oYc;So
000000Cok/^_00?o0000ooK=X_ofcJ800_ofcJ800ol0003onM:QooWBX@02o`0000?oom6900?o0000
ooc7H_l000000_l0000BoookJP03o`000?oonf[ooo]Z07Gooo]Z0ol0001YoookJP03o`000?oQ_[Go
hKje00SohKje00Oo0000omJa]?oF/KCoe[6do`000?oO/j[o000000?ohK2T00?o0000omRUX_oHYJ80
2OoHYJ800ol0003obiVSol^IX`0:ol^IX`Go00003onjQYh00ol0003o/gjKok=nV`07ok=nV`03o`00
0?nPLIcoX76L00GoX76L1Ol00008oj5gY003o`000?n:IJ;oRVFR00KoRVFR0ol00007ohYUXP;o0000
3_mjHZ/00ol0003oMffjo`000007ogA[^P;o00000_m<H<H01?l0003oDVK9oe9VbOl00009ofafc003
o`000?mLPMko000000;o00000_ldHM400ol0003oMY7PogJAh005ogJAh003o`000?mWSN?oIhgS00So
IhgS00?o0000ohjgl_n>]o805On>]o801?l0003o]<k]o`000?l0000=okWCkP;o00003Onnf^h00ol0
003of>?NomSSgP02omSSgP04o`000?oOimWognOIo`0000Oohn_F0_l00003on_gb004o`000?o/nL7o
k?W1o`0000;ohoBK00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0GoookJP?o00002ooo
nfX00ol0003ooo]ZoookJP0SoookJP008?oonfX00ol0003ooo]ZoookJP0PoookJP;o0000<OoonfX3
o`000005o`00Hol0003o00:4o`000?l61hD00_l00005ochkY@03o`000?m1>Z;o000000_oIEfe0_l0
000>ogmi`P03o`000?n@S<_oT8c;00koT8c;00?o0000oiJ>b_nFS/X01onFS/X2o`0000KoV9C=00?o
0000oinIc_nOVLh01OnOVLh3o`0000SoXZGH00?o0000ojFUe_nUYMH03_nUYMH3o`000003ojJah?l0
003oYjgK01?oYjgK0_l0000DojRagP;o00004OnY/Md3o`000003oj>hj?l0003o[[3I00ko[[3I0_l0
0005ojRehP03o`000?ne[m?o]JoC00Oo]JoC0_l0000<ok:cfP03o`000?o1]]3o`KK@00;o00003Onm
]=400ol0003o^kOFok^geP03ok^geP03o`000?o:_<gob[c=00?ob[c=00?o0000olfjb?l000002_o=
_L/00ol0003ocKg;olfmb`05olfmb`05o`000?oG_l?oeko3omNo`ol000000_oH`lD00ol0003og<6n
omc1_P02omc1_P03o`000?oNaKoog/Fo00Kog/Fo00?o0000on79`Ol000001?oVakL01?l0003ojLbh
onW<^?l00003onk;[`;o00000_ofcJ801?l0003onM:QooWBXOoidZ42o`0000?oom691Ol0000Coook
JP03o`000?oonf[ooo]Z077ooo]Z0ol0001/oookJP03o`000?oQ_[GohKje00OohKje00?o0000omJa
]?oF/K@00ooF/K@00ol0003ogk>Zo`000002on6`Y003o`000?oHYJ;of:FR00Wof:FR00?o0000ol^I
Xoo;VJ<02oo;VJ<00ol0003o`I6Tol6AY009o`0000Oo^XJN00?o0000ok=nVoncOY/01oncOY/00ol0
003oX76Loj1aW005o`0000goXGNT00?o0000ohYUX_n:IJ800on:IJ83o`0000SoRVFR0_l000000on=
KZ_o0000ogYRZ`0<ogYRZ`04o`000?mgKK[oMffjo`0000WoM6^j0_l00004oe9Vb@03o`000?m/M/co
K7K<00KoK7K<00?o0000oeb1g_mLPMh00_mLPMh3o`0000OoMY7P00?o0000ofN=homWSN<02OmWSN<0
0ol0003oS[ObohjglP0BohjglP04o`000?n>]o;oS[Obo`0000ko^M?^00?o0000okkJk_nnf^h02onn
f^h01?l0003o`n7^ol?Qk_l00003omSSgP03o`000?oOimWo000000Oohn_F00?o0000onCde_l00000
0_o[mlP00ol0003ok?W1onci`@02o`000003on?dVol0003ooo]Z02oooo]Z00?o0000oookJ_oonfX0
4ooonfX4o`0000oooo]Z00?o0000oookJ_oonfX08_oonfX0023ooo]Z00?o0000oookJ_oonfX08_oo
nfX00ol0003ooo]ZoookJP0[oookJPGo00000_l006<01?l0003o00:4o`000?l61hD2o`0000Ko?S^U
0ol00009ofEM]@04o`000?m_JkkoKf^no`0000coOgW20_l0000@oi2<b`03o`000?nFS/[oUXk:00Ko
UXk:00?o0000oiRDcOnHU<d01_nHU<d00ol0003oWiW>oinIcP02oinIcP?o00003?nRYMP00ol0003o
YJGFojFUeP0;ojFUeP;o00001OnV/N000ol0003oYjgKojN]f`0>ojN]f`?o000000?oYKSWo`000?nX
/Mh04?nX/Mh3o`000003oj>jjOl0003oZK7M00koZK7M0_l00005oj>hj003o`000?n^/=Wo[[3I00Wo
[[3I0ol00008ojRehP03o`000?ne[m?o]JoC00Co]JoC0_l0000>ok:cfP03o`000?o1]]3o000000go
_KCA0_l00007ok^gePGob[c=0ol00009olfmb`03o`000?o=_L_ocKg;00OocKg;00?o0000omNo`ol0
00001?oH`lD01Ol0003og<6nomc1__oL`Kko000000Oog/Fo00Go0000on79`OoQbL7ohLW1o`000002
onK7]`05o`000?oYc;SojLbhonW<^?l000000_o^bjl01_l0003olM2_o`000?l0003om/fRo`0000Co
nM:Q00Go0000oooAROoodHWo0000oooDP`02o`000003ooO6Eol0003ooo]Z01?ooo]Z00?o0000oook
J_oonfX0KOoonfX3o`0006kooo]Z0_l00009on6n]@03o`000?oF/KCoe[6d00?oe[6d00Ko0000omnc
Z_oO/j[o0000on6`Y?l0000:omRUXP03o`000?o;VJ?obiVS00_obiVS00Go0000ol6AY?o1TJCo`I6T
o`000008okZ<YQCo00004onQMj@00ol0003oRVFRo`000002o`0000SoRVFR0ol00003ohe^Z`03o`00
0?mjHZ_oNV:[00[oNV:[00?o0000ogM]^_mgKKX00_mgKKX00ol0003oM6^jogA[^P07ogA[^P;o0000
0omBI/T00ol0003oK7K<ofafc005ofafc003o`000?mLPMkoG87N00KoG87N1Ol00002ogJAh003o`00
0?mWSN?oIhgS00WoIhgS00?o0000ohjgl_n>]o803On>]o85o`0000?oUKcb00?o0000okWCk_nidnh0
2_nidnh2o`0000co_][^0_l00004ol?QkP05o`000?oHhmkof>?No`000?oOimT01ooSjmH01_l0003o
i?CFonCde_l0003ojoO8o`0000?ok?W100Co0000on?dVooSm9_o0000<OoonfX00ol0003ooo]Zoook
JP0?oookJP?o00004ooonfX00ol0003ooo]ZoookJP0RoookJP008?oonfX00ol0003ooo]ZoookJP0S
oookJP03o`000?oonf[ooo]Z02Oooo]Z0ol00003oookJP;o00000_l006<01Ol0003o00:4o`000?l6
1hGo000000Oo?S^U0_m?D;<00ol0003oIEfeofEM]@06ofEM]@05o`000?m_JkkoKf^nofm[__l00000
2omoNL801?l0003oQ878ohB1b?l0000?oi2<b`03o`000?nFS/[oUXk:00CoUXk:0_l0000:oiRDc@04
o`000?nOVLko0000o`00013oXZGH00?o0000ojFUe_nUYMH01onUYMH3o`0000SoY[7P00?o0000ojN]
fonW[M/02_nW[M/3o`0000GoYKSW00?o0000ojRag_nX/Mh02onX/Mh3o`0000GoXk[Y00?o0000ojVa
gOnY/Md02OnY/Md3o`0000SoXkSX00?o0000ojj`fOn^/=T01_n^/=T2o`0000_oZ;GR00?o0000okF_
done[m<00_ne[m<2o`00013o/[?J0_l0000<okfdd@;o00002_nk]mH3olZlc@04o`000?o9_]3obKk@
olVnd0;o00001_o=_L/00ol0003ocKg;olfmb`09olfmb`03o`000?oH`lGof<?500Cof<?500?o0000
omc1__l000002?oNaKl00ol0003ohLW1on79`@02on79`@03o`000?oVakOo000000CojLbh00?o0000
onk;[ol000000_oad:l3o`0000ConM:Q00Go0000oooAROoodHWo0000oooDP`02o`000003ooO6Eol0
003o000001?ooo]Z00?o0000oookJ_oonfX0J_oonfX3o`00077ooo]Z00?o0000on30^Ol000001ooQ
_[D00ol0003oe[6domJa]005omJa]003o`000?oO/j[ogk>Z00;o00002_oHYJ800ol0003obiVSol^I
X`0;ol^IX`05o`000?o1TJCo`I6Tol6AY?l000003_njS:H00ol0003o/hBRok>4XP08ok>4XP03o`00
0?nQMjCoXGNT01;oXGNT0ol00009ohYUXP;o00001_n=KZ/00ol0003oNV:[ogYRZ`09ogYRZ`03o`00
0?mgKK[oMffj00?oMffj00?o0000ogA[^_mdJkX01omdJkX2of]gc@?o000000?oDVK9o`000?m/M/`0
1Om/M/`00ol0003oG87Noeb1gP06oeb1gP03o`000?mgT=ooMi3O00;oMi3O1ol00008ofN=h`03o`00
0?n>]o;oS[Ob00OoS[Ob1Ol00009oiFllP03o`000?nidnko^M?^00Oo^M?^0_l0000<okkJkP;o0000
1oo3hNh00ol0003of>?No`000007on?[eP04o`000?oTm=Koi?CFo`0000;ojoO800Oo0000onci`Oo/
nL7ok?W1o`000?oSm9_o000003?ooo]Z00?o0000oookJ_oonfX02ooonfX3o`0001Kooo]Z00?o0000
oookJ_oonfX08_oonfX001oooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]ZoookJP0Toook
JP;o00001_oonfX2o`000003o`00Hol0003o00:400;o00:40_l00006ochkY@04o`000?m?D;?oCe2c
odm@/`;o00001_mUGKD01Ol0003oKf^nofm[__m_Jkko000000[oOgW200Go0000ohB1b?n4PLSoQ878
o`00000@oi2<b`04o`000?nFS/[oUXk:oiJ>bP;o00002_nHU<d3o`0001?oXZGH00?o0000ojFUe_nU
YMH01OnUYMH2o`0000coY[7P00?o0000ojN]fonW[M/01_nW[M/3o`0000WoYKSW00?o0000ojRag_nX
/Mh01onX/Mh3o`0000WoXk[Y00?o0000ojVagOnY/Md01_nY/Md2o`0000coXkSX00?o0000ojj`fOn^
/=T00on^/=T2o`0000koZ;GR00Co0000okF_dol0003o00004?nb/mX2o`000003ojfgh?l0003o_KCA
00[o_KCA00?o0000ok^ge_nk]mH02_nk]mH2olZlc@03o`000?o9_]3obKk@00CobKk@00?o0000olfm
boo=_L/00_o=_L/00ol0003ocKg;olfmb`08olfmb`03o`000?o=`Lko000000Oof<?500?o0000omk5
_ooNaKl01_oNaKl00ol0003ohLW1on79`@04on79`@03o`000?oYc;SojLbh00CojLbh00Co0000oo7@
[ooad:oolM2_0_l00004ooWBX@05o`000?okeYko0000oooAROl000000_ooe8<01?l0003omlIGo`00
0?l0000DoookJP03o`000?oonf[ooo]Z06Kooo]Z0ol0001coookJP05o`000?oP`;Woh<2ion30^Ol0
00001OoQ_[D00ol0003oe[6domJa]007omJa]004o`000?oO/j[o0000omJ[[@?o00001_oHYJ800ol0
003obiVSol^IX`0;ol^IX`03o`000?o1TJCo`I6T00?o`I6T00?o0000okZ<Y_njS:H02_njS:H00ol0
003o/hBRok>4XP09ok>4XP03o`000?nQMjCoXGNT00ooXGNT6Ol00009ogYRZ`03o`000?mgKK[oMffj
00CoMffj00?o0000ogA[^_mdJkX01_mdJkX00ol0003oJgO=of]gc@03of]gc@;o00001_m/M/`00ol0
003oG87Noeb1gP07oeb1gP03o`000?mgT=ooMi3O00?oMi3O00?o0000ogVBgomiT]l00_miT]l7o`00
00;oIhgS00Co0000ohjgl_n>]o;oS[Ob1Ol0000?oiFllP03o`000?nidnko^M?^00Co^M?^0_l0000=
okkJkP03o`000?o3hNko`n7^00So`n7^0ol00005on?[eP07o`000?oTm=Koi?CFonCde_l0003ojoO8
o`000003onci`@Co0000<ooonfX00ol0003ooo]ZoookJP08oookJP?o00006OoonfX00ol0003ooo]Z
oookJP0RoookJP007ooonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z023ooo]Z0ol0
0008oookJPCo00000ol00X@2o`0000Ko?S^U00Ko0000odm@/om?D;?oCe2co`000?mSG[L2o`0000?o
IEfe00?o0000ofm[__m_Jkh00om_Jkh00ol0003oOgW2ogmi`P06ogmi`P03o`000?n4PLSoQ87800?o
Q87800?o0000oi2<bon@S</03On@S</01?l0003oUXk:oiJ>b_l00008oiRDc@Co00000_nNX]P00ol0
003oXZGHoj:Uf00Boj:Uf003o`000?nUYMKoYJGF00;oYJGF0_l0000>ojJah003o`000?nW[M_oYjgK
00?oYjgK0ol0000=ojFhi`03o`000?nX/MkoZ;7N00?oZ;7N0ol0000=oj>jj@03o`000?nY/MgoZK7M
00?oZK7M0_l0000?oj>hj003o`000?n^/=Wo000000;o00004?nX]N82o`00013o/[?J0_l00004ojfg
h003o`000?nm]=7o_KCA00Ko_KCA0_l0000=ok^geP;o00002?o9_]02o`000003olfmbol0003ocKg;
00WocKg;00Go0000olg1c_o=`LkocL7>o`000006omS3a@;o00001_oNaKl00ol0003ohLW1on79`@05
on79`@03o`000?oYc;SojLbh00CojLbh0_l00003oo7@[`;o00000ooidZ401Ol0003onmJNo`000?oo
dHWo000000;oomB300Co0000ooO6Eol0003o00005OoonfX00ol0003ooo]ZoookJP1ToookJP;o0000
MOoonfX00ol0003oh<2ion30^@02on30^@03o`000?oQ_[GohKje00;ohKje00?o0000omJa]?oF/K@0
1ooF/K@2o`0000GoeZ^]0_l00004omRUXP03o`000?o;VJ?obiVS00_obiVS00?o0000ol6AY?o1TJ@0
0oo1TJ@00ol0003o^XbVokZ<YP0:okZ<YP03o`000?ncQ:;o/hBR00Wo/hBR00?o0000oj5gY?nQMj@0
3?nQMj@3o`0000;oXGNT00?o0000oj9jY_l000001_n:JJL2o`0000[oSG2]00?o0000ogMT/?l00000
0_l00005ogYRZ`03o`000?mgKK[oMffj00GoMffj00?o0000ogA[^_mdJkX01OmdJkX00ol0003oJgO=
of]gc@06of]gc@;o00001?m/M/`00ol0003oG87Noeb1gP08oeb1gP03o`000?mgT=ooMi3O00;oMi3O
00?o0000ogVBgomiT]l02OmiT]l6o`0001GoUKcb00?o0000okWCk_nidnh00_nidnh00ol0003o_][^
okkJkP0;okkJkP;o00002_o3hNh2olSXk@03o`000?oDkNGo000000?ohn_F00?o0000onCde_oTm=H0
0_oTm=H2o`0000?ok?W10_l000000ooSm9_o0000oookJP0doookJP03o`000?oonf[ooo]Z00?ooo]Z
1?l0000LoookJP03o`000?oonf[ooo]Z02;ooo]Z000OoookJP03o`000?oonf[ooo]Z02Oooo]Z00?o
0000oookJ_oonfX07?oonfX3o`0000_ooo]Z00Co0000o`00A?l0003o00000ol00X@00ol0003o82BK
o`000004ochkY@03o`000?m?D;?oCe2c00;oCe2c00Oo0000of=N]omSG[OoHejgo`000?mUGKGo0000
00KoKf^n00?o0000ogmi`_moNL801OmoNL800ol0003oQ878ohB1b004ohB1b003o`000?n@S<_oT8c;
00goT8c;0_l00006oiRDc@Co00001onNX]P00ol0003oXZGHoj:Uf00Aoj:Uf003o`000?nUYMKo0000
00;o00004OnV/N000ol0003oYjgKo`000002o`00017oYKSW00?o0000ojRag_l000000_l0000Aoj>j
j@03o`000?nY/Mgo000000;o00004OnS^>P2o`00013oZ;GR0ol000000onO^N[o0000ok:cfP0=ok:c
fP;o00001on]]n000ol0003o_KCAokfdd@04okfdd@03o`000?nk]mKo^kOF00co^kOF00?o0000okRj
fol000002Oo9_]02o`0000[ocKg;00?o0000olg1c_o=`Lh00_o=`Lh00ol0003of<?5omS3a@03omS3
a@04o`000?oIa/OofLK7o`0000Cog/Fo00?o0000on79`OoQbL401OoQbL400ol0003ohlg2o`000004
onW<^004o`000?o/dKWok=6io`0000;olM2_00?o0000ooWBXOl000000_oidZ401?l0003onmJNo`00
0?l00003oooDP`04o`000?ogaUOo0000o`0001Gooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003o
oo]Zo`00001coookJP03o`000?oP`;Woh<2i00Coh<2i00Co0000on6n]OoQ_[Go00002ooF/K@00ol0
003oeZ^]omJ[[@05omJ[[@?o000000?of:FRo`000?o;VJ<02oo;VJ<00ol0003o`I6Tol6AY004ol6A
Y003o`000?njS:Ko^XbV00Wo^XbV00?o0000ok>4X_ncQ:802oncQ:800ol0003oXGNToj5gY008oj5g
Y0?o00000onQMj@2o`0000;oXWZV00Co0000ohYYYon:JJOoRVVW0ol0000<ohe`[@03o`000?mgI;3o
MfB`00;oMfB`0ol000000omjHZ_o0000ogM]^P08ogM]^P03o`000?mdJk[oM6^j00CoM6^j00?o0000
of]gcOm[Mld01_m[Mld01_l0003oJgO=o`000?l0003oK7K<o`0000_oG87N00Go0000ogN@gomgT=oo
Mi3Oo`00000?ogVBg`03o`000?nE_?;oUKcb01KoUKcb00Co0000okWCk_l0003o00003?nnf^h2o`00
00Wo`n7^0_l00003olSXk@06o`000?oDkNGoe>gUo`000?oSjmKo00001OoTm=H01_l0003ok?W1onci
`Oo/nL7o0000onCl]`?o0000=_oonfX00ol0003ooo]Zo`000002o`00023ooo]Z00?o0000oookJ_oo
nfX08_oonfX001oooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0HoookJP?o0000
3_oonfX00ol0003o0014o`000003o`02Q004o`000?lJ99go0000o`0000?o?S^U00?o0000odm@/om?
D;<00om?D;<00ol0003oHejgof=N]`02of=N]`?o00001Om_Jkh00ol0003oOgW2ogmi`P04ogmi`P03
o`000?n4PLSoQ87800GoQ87800?o0000oi2<bon@S</03?n@S</00ol0003oTY7?o`000002oiRDc@Co
00003?nNX]P00ol0003oXZGHoj:Uf00?oj:Uf0?o00005?nV/N02o`0001CoYKSW0_l0000Coj>jj@?o
00004OnS^>P3o`000003oiNml_l0003oZ;GR00goZ;GR0_l00005oinijP03o`000?nb/m[o/[?J00So
/[?J0ol0000:ojfgh004o`000?nm]=7o_KCAokfdd@;o00003Onk]mH2o`0000?o^;[K00?o0000olVn
d?o9_]001Oo9_]001?l0003obL7ColW1doo9`M<2o`0000KocKg;00?o0000olg1c_o=`Lh01?o=`Lh0
1Ol0003of<?5omS3aOoH`lGo000000CofLK700Go0000omk5_ooNaKoog/Foo`000006on79`@05o`00
0?oScL;ohlg2on?=`_l000000_oYc;P00ol0003ok=6ioncA^@02oncA^@;o000000Gom=B^o`000?l0
003onM:Qo`000003oo_FWP04o`000?ooe8?oomB3oooDP`;o000000?ok/98o`000?oonfX05OoonfX0
0ol0003ooo]ZoookJP1SoookJP04o`000?oonf[ooo]Zo`0000Oooo]Z0_l0001YoookJP03o`000?oP
`;Woh<2i00Goh<2i00?o0000on6n]Ol000002ooF/K@00ol0003oeZ^]omJ[[@08omJ[[@?o00002oo;
VJ<00ol0003o`I6Tol6AY005ol6AY003o`000?njS:Ko^XbV00So^XbV00?o0000ok>4X_ncQ:802onc
Q:800ol0003oXGNToj5gY005oj5gY0?o00001OnQMj@00ol0003oXWZVoj9jYP03oj9jYP?o00004?n=
L:d00ol0003oMfB`ogMT/003ogMT/004o`000?mjHZ_o0000o`0000SoMffj00?o0000ogA[^_mdJkX0
0omdJkX00ol0003oJgO=of]gc@08of]gc@04o`000?m[MlgoJgO=of]gc@?o00002_mLPMh01?l0003o
Mi3OogN@gol0000@ogVBg`03o`000?nE_?;oUKcb01KoUKcb00?o0000okkJk_nnf^h02onnf^h00ol0
003o`n7^ol?QkP08ol?QkP03o`000?o8j>gob>S]00;ob>S]00Co0000omC]iOoDkNGoe>gU0ol00004
onCdeP;o00000oo/nL400ol0003oi?bgo`000002o`0003Gooo]Z0ol0000SoookJP03o`000?oonf[o
oo]Z02;ooo]Z000OoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX05?oonfX3o`00
017ooo]Z00?o0000o`00A?l000000ol00X@01?l0003o6RBMoaXTWOl00003ochkY@03o`000?m?D;?o
Ce2c00CoCe2c00Co0000of=N]omSG[Oo00000omaL/@5o`000003ofm[__l0003oOgW200?oOgW200?o
0000ohB1b?n4PLP01on4PLP00ol0003oT8c;oi2<b`07oi2<b`Wo00004?nNX]P00ol0003oXZGHoj:U
f00<oj:Uf0?o00000_nU/n800ol0003oY[7PojJah00?ojJah0?o000000?oYKo/o`000?nU^>L04?nU
^>L3o`000003oio5lol0003oXk[Y00ooXk[Y0ol00002oiS3m@03o`000?nS^>SoXkSX00coXkSX0ol0
0005oiNmlP03o`000?nX]N;oZ;GR00SoZ;GR0ol00008oinijP03o`000?nb/m[o/[?J00Go/[?J0_l0
000>ojfgh003o`000?nm]=7o000000ko^kOF00?o0000okRjfonh^]/00onh^]/00ol0003obKk@olVn
d004olVnd003o`000?o9`M?obL7C00CobL7C00?o0000olfmboo=_L/00_o=_L/00ol0003ocL7>olg1
cP06olg1cP04o`000?oH`lGof<?5o`0000GofLK700?o0000omk5_ol000001ooQbL400ol0003ohlg2
on?=`P02on?=`P03o`000?oYc;So000000Gok=6i00?o0000ooCD[_ode:h00ol00003oo_FWP08o`00
0?ooe8?oomB3o`000?oneW_o0000onk2B?l0000GoookJP03o`000?oonf[ooo]Z06;ooo]Z00Go0000
oookJ_oonf[ooo]Zo`000006oookJP03o`000?o_ZGoo000006Oooo]Z00?o0000on30^OoP`;T01ooP
`;T2o`0000[oe[6d00?o0000om2Y/Ol000002OoFZjd00ol0003ocj:YolnRZ@03o`0000SobiVS00?o
0000ol6AY?o1TJ@01Oo1TJ@00ol0003o^XbVokZ<YP07okZ<YP03o`000?ncQ:;o/hBR00co/hBR00?o
0000oj5gY?nQMj@00_nQMj@3o`0000OoXGNT00?o0000oj9jY_nRNZH00_nRNZH3o`0001;oSG2]00?o
0000ogMT/?mgI;000_mgI;000ol0003oQW6dohIa]002ohIa]0?o00001OmgKKX00ol0003oM6^jogA[
^P03ogA[^P03o`000?m[MlgoJgO=00SoJgO=00Go0000of]gcOm[MlgoJgO=o`000002ogb3c`?o0000
1omLPMh01?l0003oMi3OogN@gol0000AogVBg`03o`000?nE_?;oUKcb00ooUKcb1?l00002oig3lP03
o`000?nnf^ko_][^00Wo_][^0_l0000:ol?QkP03o`000?o8j>gob>S]00?ob>S]00Co0000omC]iOoD
kNGo00000ooHmN82o`000003onCde_l0003o000000?ok?W100?o0000onCl]ol000000_l0000coook
JP?o00000_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z02;ooo]Z000OoookJP03
o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX04OoonfX2o`0001Cooo]Z00Co0000o`00A?l0
003o00000_l00X@01?l0003o6RBMoaXTWOl00002ochkY@03o`000?m?D;?oCe2c00GoCe2c00?o0000
of=N]ol000002OmaL/@4o`000003ogmi`_l0003oQ87800WoQ87800Co0000oi2<bon@S<_oT8c;1_l0
00000on@Sloo0000oi:DdP04oi:DdP03o`000?nNX]SoWZ;H013oWZ;H00?o0000oj:Uf?nRYMP01onR
YMP4o`0000KoYK?R00?o0000ojJah?nV/N002onV/N03o`0000GoYKo/00?o0000ojFhionU^>L02onU
^>L3o`0000GoWlGc00?o0000oj>jjOnS^^T02OnS^^T4o`0000KoV<?e00?o0000oj>hj?nS^>P02?nS
^>P3o`0000WoUkgb00?o0000ojReh_nX]N801OnX]N82o`0000coWkWZ00?o0000ok:cf_nb/mX00_nb
/mX2o`00013o[KOP0_l0000=ok^geP;o00001onh^]/00ol0003obKk@olVnd002olVnd003o`000?o9
`M?obL7C00KobL7C0_l000000oo=_L_o0000olg1cP08olg1cP03o`000?oH`lGo000000OofLK70_l0
0006on79`@03o`000?oScL;ohlg200Cohlg200?o0000oncA^Oo/dKT01?o/dKT01_l0003om=B^ooCD
[_l0003onM:Qo`0000?onmJN0_l000001_ooe8?o0000ookFNol0003ok/98o`0001Sooo]Z00?o0000
oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000
onnYOoo_ZGl00_l0001ToookJP03o`000?oP`;Woh<2i00Soh<2i00?o0000omZh]ol000002?oF/K@0
1?l0003od:Vaom2Y/Ol00008omJ[[@03o`000?o?XZWocj:Y00Cocj:Y0ol00004ol^IX`03o`000?o1
TJCo`I6T00Ko`I6T00?o0000okZ<Y_njS:H01_njS:H00ol0003o/hBRok>4XP0=ok>4XP03o`000?nQ
MjCo000000;o00002?nQMj@2o`000003oj9jY_l0003o000000;o00000_nUPZh00ol0003oSG2]ohe`
[@0@ohe`[@05o`000?mgI;3oMfB`ogMT/?l000002?n6LK@3o`0000;oMffj00?o0000ogA[^_mdJkX0
0_mdJkX00ol0003oJgO=of]gc@0:of]gc@03o`000?m[Mlgo000000KoO8??0ol00005oeb1gP;o0000
4omiT]l00ol0003oUKcboiFllP09oiFllPGo00001onM`o800ol0003o_][^okkJkP07okkJkP03o`00
0?o3hNko`n7^00So`n7^0_l00006olSXk@03o`000?oDkNGo000000Gof?GR2_l000000oo3kY?o0000
oookJP0_oookJP?o00001_oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z027ooo]Z
000OoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX03OoonfX3o`0001Kooo]Z00Ko
0000o`00A?l0003o0000o`02Q?l00003oaXTW@;o000000?o?S^Uo`000?m?D;<01_m?D;<2o`0000_o
LG;400?o0000ogijaOl000004?l00005oi2?c`;o00001onBU=800ol0003oWZ;HoijRf00?oijRf003
o`000?nRYMSoXZGH00CoXZGH0ol0000;ojFchP03o`000?nV/N3oY[7P00OoY[7P0ol00009ojFok003
o`000?nU^>OoYKSW00OoYKSW0ol00009oio5l`03o`000?nS^^WoXk[Y00CoXk[Y1?l0000;oiS3m@03
o`000?nS^>SoXkSX00CoXkSX0ol0000<oiNmlP03o`000?nX]N;oZ;GR00?oZ;GR0_l0000?oinijP04
o`000?nb/m[o0000o`0000oo[KOP0ol000000onV^NKo0000ok^geP0:ok^geP;o00002_nh^]/01?l0
003obKk@olVnd?l0000:olW1d`;o00002oo=`Lh00ol0003ofLK7omW6a`06omW6a`03o`000?oKb/So
000000CohLW100?o0000on?=`_oScL801OoScL800ol0003ok=6ioncA^@03oncA^@03o`000?o`ekWo
000000;om=B^0_l00002oo_FWP09o`000?omfi_o0000oooDPol0003oo]Iko`000?o^`TSo000001So
oo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00;o
oo]Z00?o0000onnYOoo_ZGl00_o_ZGl00ol0003ooo]ZoookJP1QoookJP03o`000?oP`;Woh<2i00Oo
h<2i00Co0000omZh]ooJ^;Oof[Rg0_l00005omJa]005o`000?o@ZK7od:Vaom2Y/Ol000002?oFZjd0
0ol0003ocj:YolnRZ@07olnRZ@?o000000?obiVSo`000?o1TJ@01oo1TJ@00ol0003o^XbVokZ<YP06
okZ<YP03o`000?ncQ:;o/hBR00co/hBR0ol0000:oj5gY0Co00001_nUPZh00ol0003oSG2]ohe`[@0@
ohe`[@04o`000?mgI;3oMfB`o`0000coQW6d1?l00002ogA[^P03o`000?m[MlgoJgO=00_oJgO=00?o
0000of]gcOl000002OmlPll3o`0000?oG87N00?o0000ogVBgomiT]l04OmiT]l00ol0003oUKcboiFl
lP05oiFllPCo00003OnM`o800ol0003o_][^okkJkP04okkJkP;o00002_o3hNh00ol0003ob>S]olSX
k@06olSXk@;o00001OoHmN801ol0003of?;RomSbh_oHl^;o0000omkncol000000ooKol`00oo3kY?o
0000oookJP0/oookJPCo00002_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z027o
oo]Z000NoookJP03o`000?oonf[ooo]Z02gooo]Z0_l0000:oookJP?o00006OoonfX01_l0003o0014
o`000?l0003o00:4o`0000Co6RBM0ol00007odm@/`03o`000?maL/CoLG;400_oLG;400?o0000ohV;
d?n9Rm003?n9Rm000ol0003oT8o?oi2?c`04oi2?c`03o`000?nBU=;oTYCB00OoTYCB00?o0000oijR
f?nNX]P04?nNX]P00ol0003oXZGHoj:Uf003o`0000ooYK?R00?o0000ojJah?nV/N000onV/N03o`00
00goYKo/00?o0000ojFhionU^>L00onU^>L3o`0000goWlGc00?o0000oj>jjOnS^^T00ol0000@oiS3
m@03o`000?nS^>SoXkSX00?o00004?nG_O800ol0003oZ;GRo`000002o`00013oWkWZ0ol0000?ojfg
h0;o00001OnV^NH00ol0003o^kOFok^geP07ok^geP03o`000?nh^]_o^;[K00[o^;[K00?o0000olVn
d?l000002_o9`M<01Ol0003ob<?EolS3eOo8`mGo000000OocL7>00?o0000olk4dOl000001ooIa/L0
1Ol0003ofl[8om_:b?oKb/So000000?ohLW100?o0000on?=`_oScL801?oScL800ol0003oiM;3o`00
0004oncA^@0Bo`000?o`ekWol=Nio`000?ode:ko0000oo_FW_l0003onmJNo`000?omfi_o0000oooD
Pol0003oo]Iko`000?o^`TSo00006OoonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z
00Gooo]Z00Go0000oookJ_oonf[ooo]Zo`000005onnYO`03o`000?oonf[ooo]Z05oooo]Z00?o0000
on30^OoP`;T01ooP`;T00ol0003of[RgomZh]`04omZh]`;o00000ooF/K@00ol0003od:Vaom2Y/@02
om2Y/@03o`000?oFZjgoeZ^]00CoeZ^]00?o0000olnRZOo?XZT02oo?XZT7o`0000Co`I6T00?o0000
okZ<Y_njS:H01?njS:H00ol0003o/hBRok>4XP0:ok>4XP?o00000_ncQ:800ol0003oXGNToj5gY005
oj5gY0Co00002_nUPZh00ol0003oSG2]ohe`[@0@ohe`[@;o00004?n6LK@2o`000003ogA[^_l0003o
JgO=00coJgO=00?o0000of]gcOl000003?mlPll2o`000003oeb1g_l0003oNI;O01?oNI;O00?o0000
oiFll_nE_?801?l0000Boig3lP04o`000?nnf^ko_][^okkJkP;o00002_o3hNh2o`0000Sob>S]0_l0
0005omSehP03o`000?oHl^;of?;R00;of?;R00?og_k?o`000?oKol`00ooKol`2o`0002[ooo]Z0ol0
000>oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX08OoonfX001kooo]Z00?o0000
oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP04oookJP?o00006ooonfX01Ol0003o000io`000?l0
003o002200;o00001?lJ99d2o`000003oe5F^Ol0003oCe2c00GoCe2c00?o0000og5ba?maL/@02oma
L/@00ol0003oRH_@ohV;d00=ohV;d003o`000?n@SlooT8o?00;oT8o?00?o0000oi:Dd_nBU=802OnB
U=800ol0003oWZ;HoijRf00>oijRf0Co00004onU/n800ol0003oY[7Po`000002o`00017oYKo/00?o
0000ojFhiol000000_l0000?oio5l`Co00004_nH`oD4o`00017oUkgb1?l0000@oinijP?o00000_nC
^_800ol0003o[KOPojfgh00:ojfgh0?o00001onV^NH00ol0003o^kOFok^geP05ok^geP;o00003Onh
^]/2o`0000[obL7C00?o0000olS3eOo8`mD00oo8`mD00ol0003ocL7>olg1cP03olg1cP05o`000?o>
a=7oc/CAolk4dOl000001OoIa/L00ol0003ofl[8om_:b003om_:b003o`000?oQbL7o000000Kohlg2
00Go0000onGB`ooUd/?oiM;3o`000002oncA^@03o`000?o`ekWol=Ni00;ol=Ni0ol000000ookeYko
0000o`000002oogKV`03o`000?oneW_oo]Ik00?o00006_oonfX00ol0003ooo]ZoookJP1NoookJP03
o`000?oonf[ooo]Z00Kooo]Z00Co0000oookJ_oonf[o00001_o_ZGl00ol0003ooo]ZoookJP1Noook
JP03o`000?oP`;Woh<2i00Ooh<2i00?o0000omZh]ooJ^;L01_oJ^;L00ol0003oe[6do`000005om2Y
/@03o`000?oFZjgoeZ^]00CoeZ^]00?o0000olnRZOo?XZT02oo?XZT00ol0003o^i2[ok^@Z`04ok^@
Z`So00000onjS:H00ol0003o/hBRok>4XP07ok>4XP?o00001OncQ:800ol0003oXGNToj5gY006o`00
00goYH:^00?o0000ohe`[On=L:d03on=L:d2o`00017oQW6d00?o0000og1]_ol000000_l0000=of]g
c@03o`000?mlPlooO8??00koO8??6?l0000Goig3lP03o`000?nnf^ko000000_o`n7^00?o0000olSX
kOo8j>d02?o8j>d00ol0003of?GRomSehP03omSehP03o`000?oHl^;of?;R00;of?;R0_l00004om_o
c0;o0000:?oonfX3o`0001;ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0Qoook
JP007_oonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z00?o00007_oonfX01_l0003o
000io`000?l0003o0022o`0000Go6RBM00Co0000oe5F^OmAE[WoDEJi0_l00003odm@/`03o`000?mM
HKko000000_oLG;400?o0000ogUmbol000003_n9Rm000ol0003oT8o?oi2?c`02o`0000goTYCB00?o
0000oijRf?nNX]P02_nNX]P3o`0000;oX[3Q00?o0000ojFch_nU/n804_nU/n82o`0001?oYKo/1?l0
000>oio5l`?o00001?nAd?d00ol0003oV<?eoiS3m@0;oiS3m@Co00001?n3aoh2o`0000WoUkgb1_l0
0004ohBnnP03o`000?nO^N[oWkWZ00WoWkWZ1?l00006oi>jlP03o`000?n]]n3o[KOP00Ko[KOP0ol0
000;ojJiiP03o`000?nk]mKo^kOF00?o^kOF00?o0000okRjfonh^]/02onh^]/2o`000003okJlgol0
003obL7C00SobL7C00?o0000olS3eOo8`mD01Oo8`mD01Ol0003ocL7>olg1c_o=`Lko000000Coc/CA
00?o0000omW6aooIa/L00_oIa/L00ol0003ofl[8om_:b005om_:b003o`000?oScL;ohlg200Gohlg2
00?o0000onGB`ooUd/<00_oUd/<00ol0003ok=6io`000004oo3G^@06o`000?obg;Wo0000o`000?ok
eYko00000_omfi/00ol0003oo]IkookFN`03o`0001[ooo]Z00?o0000oookJ_oonfX0G_oonfX00ol0
003ooo]ZoookJP07oookJP03o`000?oonf[o000000KokjUo0_l0001NoookJP03o`000?oP`;Woh<2i
00Ooh<2i00?o0000omZh]ooJ^;L02?oJ^;L2o`0000God:Va00?o0000omJ[[OoFZjd00ooFZjd00ol0
003ocj:YolnRZ@0;olnRZ@03o`000?nkT:_o^i2[00Wo^i2[00Co0000okZ@ZonjT:_o^Y2[6?l00003
oj9lZ@;o00003_nUPZh00ol0003oSG2]ohe`[@0=ohe`[@;o000000?oT7Fao`000?n6LK@04?n6LK@2
o`0000?oPW[20ol0000:of]gc@03o`000?mlPlooO8??00koO8??0_l0000Dog^Uk@03o`000?nM`o;o
WL?b01OoWL?b00?o0000ol?Qk_o3hNh02?o3hNh2o`0000Wob>S]00?o0000olkWjOl000001?oHmN80
0ol0003of?;RomSbhP03omSbhP03o`000?oKolcofoo<00;ofoo<0_l0000VoookJP?o00005_oonfX0
0ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z027ooo]Z000NoookJP03o`000?oonf[ooo]Z
037ooo]Z0_l0000QoookJP04o`000?l003Wo0000o`00KP;o00001OlJ99d00ol0003oDEJioe5F^@03
oe5F^@06o`000?m?D;?oCe2co`000?mMHKko00002_maL/@01?l0003oNGg;ogUmbol0000>ohV;d003
o`000?n@Sloo000000ooTYCB00?o0000oijRf?nNX]P01onNX]P3o`0000KoX[3Q00?o0000ojFch_nU
/n803_nU/n83o`0000;oYl;]00?o0000ojFok?nU_n`03OnU_n`3o`0000CoXLkg00?o0000oio5lonO
aO<02?nOaO<3o`0000SoTM3m00?o0000oiS3mOnH`oD01OnH`oD5o`0000[oPlOn00Co0000oiNml_nG
_O;oUkgb1Ol0000;ohBnnP03o`000?nO^N[oWkWZ00CoWkWZ1?l0000;oi>jlP03o`000?n]]n3o[KOP
00?o[KOP0_l0000?ojJiiP03o`000?nk]mKo^kOF00;o00003?nh^]/2o`0000Co][cO00?o0000olW1
doo9`M<01Oo9`M<00ol0003ob<?EolS3e@07olS3e@03o`000?o=`Lko000000Koc/CA00Co0000omW6
aooIa/Oo00002?oKb/P00ol0003ohlg2on?=`P04on?=`P03o`000?oUd/?oiM;300CoiM;300?o0000
oo3G^Oo`ekT00_o`ekT01ol0003ol]bioo;L^Oobg;Wo0000oo_FW_l000000_omfi/01?l0003oo]Ik
o`000?ojeg02o`0001_ooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP08oookJP;o
00001_o_ZGl00ol0003ok:J1o`00001MoookJP;o00001ooP`;T00ol0003of[RgomZh]`09omZh]`04
o`000?o<Z[Oo0000o`0000Cod:Va00?o0000omJ[[OoFZjd00_oFZjd00ol0003ocj:YolnRZ@0:olnR
Z@03o`000?nkT:_o^i2[00[o^i2[00?o0000okZ@ZonjT:/00onjT:/00ol0003o]Hn_okF?[`02okF?
[`?o00002oneSjl00ol0003oXWbYoj9lZ@02oj9lZ@03o`000?nUPZkoYH:^00koYH:^00?o0000ohe`
[On=L:d02on=L:d2o`0000CoT7Fa00?o0000ohIa]?n6LK@03On6LK@00ol0003oQGc2oh9j`P06oh9j
`PCo00001Om[Mld00ol0003oKG[?o`00000?ogb3c`03o`000?mUPM[o000001CoNjG]00?o0000oig3
l_nM`o804OnM`o83o`0000?oYL_c00?o0000ol?Qk_o3hNh01_o3hNh00ol0003ob>S]olSXk@07olSX
k@;o00000_o>inT01Ol0003of?GRomSeh_oHmN;o000000Gof?;R00?o0000om_oc?oKol`00_oKol`3
o`0002?ooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX08OoonfX0
01kooo]Z00?o0000oookJ_oonfX0;_oonfX3o`000003oookJ_l0003ooo]Z023ooo]Z00Co0000o`00
>Ol0003o001^0ol00003oaXTW@;o00001_mAE[T00ol0003oCe2co`000002oeeQ_P03o`000?maL/Co
LG;400KoLG;400Go0000ogUmbomiOL_oNGg;o`00000?ohV;d003o`000?nBU=;oTYCB00ooTYCB00?o
0000oijRf?nNX]P00onNX]P3o`0000[oX[3Q00?o0000ojFch_nU/n802_nU/n83o`0000KoYl;]00?o
0000ojFok?nU_n`02?nU_n`4o`0000SoXLkg00?o0000oio5lonOaO<01?nOaO<3o`0000coTM3m00?o
0000oiS3mOnH`oD01?l0000=oh?7oPKo00004On4__X00ol0003oWkWZoinijP03o`00013oTk[b00?o
0000ojfgh?l000000_l0000AojJiiP03o`000?nk]mKo000000co^;[K0_l00007okJlg`03o`000?o9
`M?obL7C00?obL7C00?o0000olS3eOo8`mD02?o8`mD2o`0000Ooc/CA00?o0000omW6aol000002?oK
b/P00ol0003og<g:o`000004on?=`P03o`000?oUd/?oiM;300GoiM;300?o0000oo3G^Oo`ekT00_o`
ekT00ol0003ol]bioo;L^@02oo;L^@08o`000?omfi_o0000oogKVol0003oo]Iko`000?ojeg02o`00
01cooo]Z00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?o_ZGookjUo
00CokjUo00Co0000onbVPOo/YX7o0000FooonfX01?l0003og/6komk1^ol00006on30^@03o`000?oJ
^;Oof[Rg00Sof[Rg00?o0000olbZ]oo<Z[L00_o<Z[L3o`000003om2Y/Ol0003oeZ^]00;oeZ^]00?o
0000olnRZOo?XZT02oo?XZT00ol0003o^i2[ok^@Z`0:ok^@Z`03o`000?njT:_o^Y2[00;o^Y2[00?o
0000okF?[oneSjl00ol0000>okF?[`03o`000?nRO:WoXWbY00;o00004_nUPZh00ol0003oSG2]ohe`
[@08ohe`[@;o00001_n@MK400ol0003oQW6dohIa]00<ohIa]004o`000?n5O<;oQGc2o`0000[oPW[2
0ol00002of]gc@03o`000?m]N/oo000000ooO8??00?o0000ofF1f_l000005OmkYNd00ol0003oWL?b
oig3lP0<oig3lPCo00001onUbo<00ol0003o`n7^ol?QkP04ol?QkP03o`000?o8j>gob>S]00Oob>S]
00Go0000olkWjOo>inWoc^OYo`000003omSehP03o`000?oHl^;of?;R00?of?;R0_l00003om_oc003
o`000?o3kY?o0000023ooo]Z1?l0000MoookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oo
nfX08OoonfX001kooo]Z00?o0000oookJ_oonfX0:ooonfX3o`0000Gooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0003o000io`000002o`0000;o5BBP00Ko0000oaXTWOlJ99go0000oc<o/?l00006oe5F
^@;o00000_mMHKh00ol0003oLG;4og5ba006og5ba003o`000?miOL_oNGg;00;oNGg;00?o0000ohV;
d?n9Rm002on9Rm02o`00017oTYCB00?o0000oijRf?nNX]P00ol0000>oj:`h@03o`000?nU/n;oYK?R
00KoYK?R0ol0000:ojO2k@03o`000?nU_ncoYKo/00CoYKo/0ol0000=oj7>m`03o`000?nOaO?oWlGc
00?o00003OnAd?d5o`0000_oPlOn1_l00005obF^e`03o`000?n4__[oQ;kj00coQ;kj1_l0000Aoi>j
lPCo00004onV^NH3o`0000_o^;[K0_l0000:okJlg`05o`000?o9`M?obL7ColW1dol000002_o8`mD0
1Ol0003ob<KGolS6eoo8a]Oo000000Koc/CA00?o0000om_:b?oKb/P01_oKb/P01Ol0003og<g:omc=
b_oLcL[o000000?ohlg200?o0000onGB`ooUd/<01?oUd/<00ol0003oimK4o`000002oo3G^@03o`00
0?obg;Wol]bi00?ol]bi1?l000000oongiGo0000o`000003o`0001cooo]Z00?o0000oookJ_oonfX0
G?oonfX00ol0003ooo]ZoookJP09oookJP;o00001Oo_ZGl01Ol0003ok:J1onbVPOo/YX7o000005Wo
oo]Z00?o0000omk1^ooN`K/00_oN`K/00ol0003oh<2ion30^@02on30^@03o`000?oJ^;Oof[Rg00So
f[Rg00?o0000olbZ]oo<Z[L01_o<Z[L2o`0000?oeZ^]00?o0000olnRZOo?XZT02_o?XZT00ol0003o
^i2[ok^@Z`0<ok^@Z`03o`000?njT:_o^Y2[00Co00004_neSjl2o`0001CoYH:^00?o0000ohe`[On=
L:d01On=L:d3o`0000SoT7Fa00?o0000ohIa]?n6LK@02_n6LK@2o`0000CoQGc23On2N/83o`000003
ofejcol0003oO8??00koO8??00Co0000ofF1f_mUPM[o00005OmkYNd00ol0003oWL?boig3lP08oig3
lP?o00003?nUbo<01?l0003o`n7^ol?Qk_o3hNh2o`0000Sob>S]0_l00004olkWj@04o`000?oHmN;o
f?GRo`0000Gof?;R0_l00004om_oc0?o00007OoonfX3o`0002;ooo]Z00?o0000oookJ_oonfX07?oo
nfX00ol0003ooo]ZoookJP0QoookJP007_oonfX00ol0003ooo]ZoookJP0XoookJP?o00002OoonfX0
0ol0003ooo]ZoookJP0MoookJP03o`000?l003Wo000000;o00000_lE9:001_l0003o6RBMoaXTWOl0
003o<cn`o`0000KoDEJi00?o0000oeeWa?l000000_l00007og5ba003o`000?miOL_oNGg;00?oNGg;
00?o0000ohV;d?n9Rm002_n9Rm001?l0003oS97CohbAdol0000>oi:DdPGo00004OnR/>400ol0003o
YK?RojFchP03ojFchP?o00003_nW`^d00ol0003oYKo/ojFok003o`0000ooXLkg1?l0000:oi7@o@Ko
00001OmCc>`3o`0000?oPlOn1Ol0000<obF^e`03o`000?n4__[oQ;kj00;oQ;kj2Ol00006ocRek0;o
00002OnC^_86o`0000?oP[Sg00?o0000ojJii_nV^NH03_nV^NH3o`0000;oWk[/00?o0000okRjfonh
^]/02?nh^]/00ol0003o][cOokJlg`0;okJlg`03o`000?o9`M?o000000[ob<?E00?o0000olS6eoo8
a]L00oo8a]L01ol0003oc/CAolk4dOo>a=7o0000olk8e?l000001ooKb/P00ol0003og<g:omc=bP03
omc=bP03o`000?oScL;o000000KoiM;300Oo0000onOFa?oWe/CoimK4o`000?o`ekWo000000Gol]bi
00?o0000oo_PY?okh:@01?l000000oohg7Oo0000o`00000MoookJP03o`000?oonf[ooo]Z05_ooo]Z
00?o0000oookJ_oonfX02OoonfX00ol0003ol:1/o`000003onnYO`03o`000?o/YX7ok:J100?ok:J1
00?o0000oookJ_oonfX0E_oonfX00ol0003og/6komk1^`03omk1^`05o`000?oP`;Woh<2ion30^Ol0
00002_oJ^;L00ol0003oc:ZgolbZ]`08olbZ]`Co00003?o?XZT00ol0003o^i2[ok^@Z`0<ok^@Z`Co
00005OneSjl00ol0003oYH:^ojF2[P0CojF2[P03o`000?n=L:goSG2]00?oSG2]0_l0000<oi1e/@03
o`000?n6LKCoQW6d00SoQW6d00?o0000ohEl`_n5O<801?n5O<800ol0003oPW[2oh9j`P0;oh9j`P03
o`000?mdM<Co000000;o00003OmlPll00ol0003oIH7JofF1fP02ofF1fP03o`000?mkYNgoNjG]01;o
NjG]00?o0000oig3l_nM`o801?nM`o84o`00013oYL_c00?o0000ol?Qk_l000002Oo8j>d00ol0003o
c^OYolkWj@04olkWj@03o`000?oHmN;o000000Gof?;R00?o0000omkhf_l000000ooKol`3o`0001_o
oo]Z0ol0000VoookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX08?oonfX001gooo]Z
00?o0000oookJ_oonfX09_oonfX3o`0000gooo]Z00?o0000oookJ_oonfX07?oonfX2o`000003o`00
J?l0003o000000?o5BBP0_l00002oc<o/003o`000?mAE[WoDEJi00?oDEJi00?o0000oeeWa?mMIl@0
0omMIl@4o`0000;oLG;400?o0000ogUmbomiOL/01OmiOL/00ol0003oRH_@ohV;d008ohV;d003o`00
0?n<TM?oS97C00;oS97C00?o0000oi:Dd_nBU=801_nBU=85o`0000?oW:SO00?o0000oj:`hOnR/>40
4OnR/>400ol0003oYK?Ro`000002o`00017oYl;]0ol0000?oj7>m`?o00001?nDg?h2o`0000?oTM3m
1Ol0000>oe?<k0?o00004_lU[]L4o`00017o>;G/00Co0000oi>jl_nC^_;oTk[b1Ol0000:oh:hm`03
o`000?nV^NKoY[WV00WoY[WV1?l00006oinjk003o`000?nh^]_o^;[K00Go^;[K0_l0000>okJlg`;o
00002_o8`mD00ol0003ob<KGolS6e`05olS6e`03o`000?o>a=7o000000?oc/SD00?o0000om_:b?oK
b/P00ooKb/P00ol0003og<g:omc=bP05omc=bP03o`000?oUd/?oiM;300GoiM;300Oo0000onOFa?oW
e/CoimK4o`000?o`ekWo000000Col]bi0_l00002oo_PY0Co000000?on=ago`000?l000007_oonfX0
0ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z00[ooo]Z00Co0000oo2PK?o`X6co00000_o_
ZGl00ol0003ok:J1onbVP@04onbVP@;o0000EOoonfX00ol0003og/6komk1^`05omk1^`03o`000?oP
`;Wo000000[of[Rg00?o0000olbZ]oo<Z[L02Oo<Z[L01?l0003oeJf`o`000?o>Y:d3o`0000Socj:Y
00?o0000ok^@ZonkT:/02onkT:/4o`0001Ko]Hn_0_l0000EojF2[P04o`000?n=L:goSG2]ohe`[@;o
00003_n@MK400ol0003oQW6dohIa]006ohIa]0;o00001on5O<800ol0003oPW[2oh9j`P0:oh9j`P03
o`000?mdM<CoM7C400;oM7C41Ol00009ogb3c`03o`000?mUPM[oIH7J00;oIH7J00?o0000og^UkOmk
YNd04omkYNd00ol0003oWL?boig3lP03o`0001GoYL_c00?o0000olSXkOo8j>d01_o8j>d2o`0000Oo
c^OY0_l00005omSbhP04o`000?oNn=[og_SJo`0000;ofoo<00CogOk1o`000?nliX?o00006?oonfX3
o`0002Wooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0PoookJP007OoonfX00ol0
003ooo]ZoookJP0ToookJP;o00004OoonfX00ol0003ooo]ZoookJP0KoookJP;o00000_l006P00ol0
003o5BBPoaDTX002oaDTX005o`000?lc?k3o<cn`oc<o/?l000000omAE[T00ol0003oGFO4oeeWa004
oeeWa004o`000?m`LlKoL7?6og1caPGo00001OmiOL/00ol0003oRH_@ohV;d007ohV;d003o`000?n<
TM?oS97C00?oS97C00Co0000oi:Dd_nBU=;oTYCB1Ol00009oibXg`03o`000?nR/>7oX[3Q00ooX[3Q
0ol0000AojO2k@?o00000onWdoL00ol0003oXLkgoj7>m`08oj7>m`Co00001onDg?h5o`0000WoDlc/
2_l000000omB003ooo]ZoookJP0=oookJP04o`000?l@003o4000oa0000go00002_lh]N`3o`00013o
P[Sg00?o0000ojJii_nV^NH01?nV^NH4o`0000_oWk[/00?o0000okRjfonh^]/00_nh^]/2o`0000ko
][cO0_l000000onc_^?o0000olS3e@07olS3e@;o00002?o8a]L2o`0000Goc/SD00Go0000om_:b?oK
b/Sofl[8o`000008omc=bP03o`000?oUd/?oiM;300CoiM;300?o0000onOFa?oWe/@00ooWe/@00ol0
003ol]bioo;L^@03oo;L^@04o`000?oeh[Oo0000o`0000;oo>FP1Ol0000NoookJP03o`000?oonf[o
oo]Z05Wooo]Z00?o0000oookJ_oonfX02_oonfX01ol0003ol:1/oo2PK?o`X6co0000onnYOol00000
1_o/YX400ol0003oj:>3o`00001DoookJP03o`000?oN`K_og/6k00Kog/6k0_l00009omZh]`03o`00
0?o<Z[Ooc:Zg00_oc:Zg00?o0000oljT[Oo>Y:d00oo>Y:d3o`0000Cocj:Y00?o0000ok^@ZonkT:/0
2OnkT:/3o`0000;o^i2[00?o0000okF?[oneSjl05?neSjl00ol0003o/HZ/o`00000FojF2[P03o`00
0?n=L:go0000013oT7Fa00?o0000ohIa]?n6LK@01On6LK@00ol0003oQGc2ohEl`P08ohEl`P_oPW[2
00?o0000ogAda?mdM<@00omdM<@5ohR=dPOo00000_mlPll00ol0003oIH7JofF1fP03ofF1fP03o`00
0?mkYNgoNjG]00koNjG]1?l000000omkYNgo0000o`00000DojG;l`?o00000_n]e?@00ol0003ob>S]
olSXk@04olSXk@03o`000?o>inWoc^OY00Koc^OY0_l00005omSbhP04o`000?oNn=[og_SJo`0000;o
foo<00CogOk1o`000?nliX?o00005_oonfX3o`0002gooo]Z00?o0000oookJ_oonfX06ooonfX00ol0
003ooo]ZoookJP0PoookJP007OoonfX00ol0003ooo]ZoookJP0QoookJP?o00005?oonfX2o`0001_o
oo]Z0_l00002o`00J003o`000?lE9:3o5BBP00;o5BBP0_l00002oc<o/005o`000?mAE[WoDEJioe5F
^Ol000001omMIl@01Ol0003oL7?6og1ca_m`LlKo000000?oOXOB1_l00004ohV;d0oo00003onLZ=l0
0ol0003oX[3Qoj:`h@0;oj:`h@?o00000onW_n/00ol0003oYl;]ojO2k@0;ojO2k@?o00001onWdoL0
0ol0003oXLkgoj7>m`04oj7>m`?o00002?nDg?h3o`0000GoImWY0ol00003oe?<k0Co00008ooonfX3
og8000;o00003Ol0RLD00ol0003oP[Sgoh:hm`0@oh:hm`03o`000?nV^NKoY[WV00?o00004?nO^^`0
1?l0003o^;[Ko`000?l0000=okJlg`?o00001?nc_^<00ol0003ob<?EolS3e@04olS3e@03o`000?o8
a]Oob<KG00Oob<KG00Co0000olW8fOo9b=Wo00001Oo>b=@00ol0003ofl[8o`000008omc=bP03o`00
0?oNdL_o000000CoiM;300?o0000onOFa?oWe/@01?oWe/@00ol0003ol]bioo;L^@02oo;L^@03o`00
0?oeh[OomN:g00;o00000_oliJ05o`0001oooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]Z
oookJP0:oookJP03o`000?o`X6col:1/00;ol:1/0_l00006onbVP@03o`000?oXXh?oj:>300;o0000
DOoonfX00ol0003og/6komk1^`07omk1^`03o`000?oI_Kgo000000Sof[Rg00?o0000olbZ]oo<Z[L0
2oo<Z[L00ol0003ocZB]oljT[@06oljT[@?o000000?ocj:Yo`000?nkT:/01onkT:/3o`0000Go^i2[
00?o0000okF?[oneSjl04oneSjl01Ol0003o/HZ/ok6:[?naRZco000001?oYH:^0ol0000Coi1e/@03
o`000?n6LKCoQW6d00?oQW6d00?o0000ohEl`_n5O<802On5O<800ol0003oPW[2oh9j`P07oh9j`P03
o`000?mdM<CoM7C400GoM7C42on8SM87o`000003ofF1f_l0003oNjG]00CoNjG]2ol00005ohR_k`03
o`000?nUbo?oYL_c013oYL_c0ol00006ojgDm004o`000?o8j>gob>S]olSXk@;o00002Oo>inT00ol0
003of?;RomSbhP03omSbhP05o`000?oNn=[og_SJomkhf_l000000_oKol`00ooMo/7o0000o`00000C
oookJPCo0000<OoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z023ooo]Z000Moook
JP03o`000?oonf[ooo]Z01kooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z01Sooo]Z0_l00002o`00
J003o`000?lE9:3o5BBP00;o5BBP00Go0000obi0/ol0003o<cn`o`000002oe5F^@03o`000?mMIlCo
GFO400KoGFO400Co0000og1ca_m`LlKo00002OmnQm85o`0000CoR8gB00?o0000ohbCeOn<TmD01On<
TmD00ol0003oW:SOoibXg`0@oibXg`03o`000?nR/>7oX[3Q00OoX[3Q0ol00007ojNoj`03o`000?nW
`^goYl;]00OoYl;]0ol0000;ojOCm`03o`000?nQc_OoXLkg00?o00002?nDg?h3o`0000OoImWY00?o
HMOVo`000?l00000<ooonfX2o`0000Wo08W500?o0000oh:hmon2^?L03?n2^?L6o`0001;oWk[/0ol0
000=okJlg`;o00002?nc_^<00ol0003ob<?EolS3e@02olS3e@03o`000?o8a]Oob<KG00Oob<KG00?o
0000olW8fOo9b=T00_o9b=T00ol0003oc/SDolk8e003olk8e003o`000?oLcL[og<g:00Kog<g:00Co
0000omkAbooNdL_o00000ooUd/<00ol0003oimK4onOFa004onOFa003o`000?oZflGo000000?ol]bi
0ooeh[L01?l0003oo>FPoocUX?oliJ05o`00023ooo]Z00?o0000oookJ_oonfX0EooonfX00ol0003o
oo]ZoookJP0:oookJP03o`000?o`X6col:1/00?ol:1/0_l00005onbVP@03o`000?oXXh?oj:>300;o
j:>30_l0001>oookJP03o`000?oN`K_og/6k00Oog/6k00Co0000omVm_OoI_KgofKfm0_l00005omZh
]`03o`000?o<Z[Ooc:Zg00_oc:Zg00?o0000olFT^?l000002_o>Y:d3o`0000Co^i2[0ol00007ok^@
Z`03o`000?nmU:co000001?o]Hn_00?o0000ok6:[?naRZ`00_naRZ`00ol0003oYH:^ojF2[P0=ojF2
[PCo00000_nTQ;800ol0003oT7Faoi1e/@0Aoi1e/@03o`000?n6LKCoQW6d00;oQW6d00?o0000ohEl
`_n5O<802_n5O<800ol0003oPW[2oh9j`P06oh9j`P03o`000?mdM<CoM7C400KoM7C400?o0000ohR=
d_n8SM802_n8SM800ol0003oNXSEogZ8e@02ogZ8e@Oo00004On8[nl00ol0003oYL_cojG;l`0=ojG;
l`;o00002_n]e?@00ol0003ob>S]o`000009olkWj@03o`000?oBkNOo000000Cof?;R00?o0000omkh
f_oNn=X00_oNn=X01Ol0003ofoo<omgn`Ol0003o_>J3017ooo]Z0ol0000eoookJP03o`000?oonf[o
oo]Z01[ooo]Z00?o0000oookJ_oonfX08?oonfX001gooo]Z00?o0000oookJ_oonfX06ooonfX3o`00
01gooo]Z00?o0000oookJ_oonfX05ooonfX2o`0000;o001X0_l00002oaDTX004o`000?l^@;?o;T2c
obi0/`;o00000_mAE[T00ol0003oGFO4oeeWa006oeeWa003o`000?m`LlKo000000_oOXOB00?o0000
ohR=d_n8SM801?n8SM800ol0003oS9?EohbCe@07ohbCe@03o`000?nLZ=ooW:SO00ooW:SO00?o0000
oj:`hOnR/>401?nR/>43o`0000_oYko[00?o0000ojO2kOnW`^d00onW`^d3o`0000koYm?g0ol00008
oiCLoP?o00001OmWfNT4o`0003cooo]Z0_l00005o`29a@03o`000?n2^?OoP[Sg00;oP[Sg2Ol00005
offan@03o`000?nO^^coWk[/00goWk[/0ol00002oiJil003o`000?nf_=oo][cO00Wo][cO0_l0000:
ok>nh`05o`000?o8`mGob<?EolS3eOl000002Oo8a]L00ol0003obLSIolW8f@04olW8f@04o`000?o>
b=Coc/SDolk8e0;o00001ooLcLX00ol0003og]7;omkAb`02omkAb`04o`000?oUd/?oiM;3o`0000Go
imK400Co0000on[KaOoZflGo00000_obg;T01Ol0003omN:gooGR]ooeh[Oo000000;oo>FP00?o0000
oo_WV?l000000ol0000PoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX02_oonfX0
0ol0003ol:1/oo2PK003oo2PK003o`000?o]WFoo000000Cok:J100?o0000onRSPooXXh<01?oXXh<0
0ol0003ooo]ZoookJP1;oookJP03o`000?oN`K_og/6k00Kog/6k00?o0000omVm_OoI_Kd01?oI_Kd2
o`0000?of[Rg00?o0000olbZ]oo<Z[L02_o<Z[L01?l0003oaJBholFT^?l0000:oljT[@03o`000?o6
Y;KoaZBf00Go00002?nkT:/01?l0003o_IB/okfD[?l0000BokF?[`03o`000?naRZco/HZ/00?o/HZ/
00?o0000ojF2[_nUPZh02?nUPZh5o`0000KoY8Bb00?o0000oi1e/On@MK404On@MK401?l0003oQW6d
ohIa]?n6LK@?ohEl`P03o`000?n2N/;oPW[200CoPW[200?o0000ogAda?mdM<@02?mdM<@00ol0003o
R8gBohR=dP08ohR=dP03o`000?mjR=GoNXSE00GoNXSE00?o0000ohR_kon8[nl05?n8[nl00ol0003o
YL_cojG;l`09ojG;l`?o00003On]e?@00ol0003oc^OYolkWj@07olkWj@04o`000?oBkNOod^gWo`00
00?of?;R00?o0000omkhf_oNn=X00_oNn=X00ol0003ofoo<omgn`@03o`0000kooo]Z0ol0000ioook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX08?oonfX001gooo]Z00?o0000oookJ_oo
nfX06?oonfX3o`00027ooo]Z00?o0000oookJ_oonfX05ooonfX2o`000003o`00J?l0003o000000;o
5BBP00?o0000obi0/ol^@;<00_l^@;<3o`0000[oGFO400?o0000ogj7d_mnQm802omnQm800ol0003o
R8gBohR=dP02ohR=dP03o`000?n<TmGoS9?E00WoS9?E00?o0000oibXgonLZ=l03onLZ=l00ol0003o
X[3Qoj:`h@03o`0000ooYko[00?o0000ojO2kOl000000_l0000>ojOCm`?o00000onQi?`3o`0000;o
U=cn0ol00003ofOIj@03o`000?mQenKo000000;o0000AOoonfX00ol0LlCo0000o`29a@04o`0000oo
KK7i00?o0000oinjk?nO^^`02?nO^^`4o`0000KoU[W`00?o0000okJlgonf_=l01_nf_=l2o`0000go
/kkS00?o0000olS3eOl000002Oo8a]L00ol0003obLSIolW8f@06olW8f@03o`000?o>b=Co000000;o
clcG00?o0000omc=b_oLcLX00ooLcLX00ol0003og]7;omkAb`03omkAb`03o`000?oUd/?o000000Ko
imK400Co0000on[KaOoZflGo00000_obg;T3ooGR]`;o00000_oliJ001?l0003onnNHo`000?o_f6L2
o`00027ooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP0:oookJP;o00001?o`X6`0
0ol0003okIe_onfMK`02o`0000;ok:J100?o0000onRSPooXXh<01OoXXh<2o`0004[ooo]Z00?o0000
omk1^ooN`K/01ooN`K/00ol0003ofKfmomVm_@06omVm_@03o`000?oJ^;Oo000000goc:Zg00Co0000
olFT^?o5Y;So00002Oo>Y:d00ol0003oaZBfo`000002o`0000CoaZBf1Ol00002ok^@Z`05o`000?nm
U:co_IB/okfD[?l000004OneSjl00ol0003o/HZ/ok6:[004ok6:[003o`000?nUPZkoYH:^00CoYH:^
1?l0000;ojB4/P03o`000?n@MK7oT7Fa01;oT7Fa0_n6LK@@ohEl`P03o`000?n2N/;oPW[200CoPW[2
00?o0000ogAda?mdM<@02?mdM<@00ol0003oR8gBohR=dP07ohR=dP03o`000?mjR=GoNXSE00OoNXSE
00?o0000ohR_kon8[nl05?n8[nl00ol0003oYL_cojG;l`06ojG;l`;o00003On]e?@2o`0000?o]Mke
00?o0000olkWjOo>inT00oo>inT2o`0000;od^gW00Go0000omSbh_oHl^;of?;Ro`000004omkhfP;o
000000CogOk1o`000?l0003o00003?oonfX3o`0003gooo]Z00?o0000oookJ_oonfX06?oonfX00ol0
003ooo]ZoookJP0PoookJP007OoonfX00ol0003ooo]ZoookJP0FoookJP;o00009OoonfX00ol0003o
oo]ZoookJP0FoookJP?o000000Go006>o`000?lE9:3o5BBPo`000005obi0/`;o00002_mMIl@00ol0
003oOXOBogj7dP0<ogj7dP04o`000?n8SM;oR8gBo`0000coS9?E00?o0000oibXgonLZ=l03_nLZ=l4
o`0001;oYko[0ol0000=ojOCm`?o00002?nQi?`3o`000003ofOIjOl0003o000000;oHMOV0ol0001:
oookJP03o`000?l0LlCo07?400;o00004?m]/OT00ol0003oWk[/oinjk004oinjk0?o00002onF^O00
0ol0003o][cOokJlg`02okJlg`?o00003onc_^<2o`0000Sob<KG0_l00009olW8f@;o00001?o?c=L0
0ol0003og<g:omc=bP02omc=bP03o`000?oNdL_og]7;00Cog]7;00?o0000onOFa?oWe/@01?oWe/@0
0ol0003oj]_5on[Ka@02on[Ka@;o00000ooeh[L2o`0000;oo>FP00Co0000oo_WV?l0003okmQW0_l0
000RoookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003okY=Co`00
0003oo2PK003o`000?o]WFookIe_00;okIe_00?o0000onbVPOl000001ooXXh<00ol0003oiIn4o`00
0018oookJP03o`000?oA`lgo000000Oog/6k00?o0000omVm_OoI_Kd02?oI_Kd2o`0000coc:Zg00?o
0000olFT^?o5Y;P00_o5Y;P00ol0003ocZB]oljT[@05oljT[@?o00003?o6Y;H5o`0000;o_IB/00?o
0000okF?[oneSjl03OneSjl00ol0003o/HZ/ok6:[006ok6:[003o`000?nUPZko000000?o00004?nT
Q;800ol0003oT7Faoi1e/@0>oi1e/@?o000000?oQW6do`000?l000000ol0000<ohEl`P03o`000?n2
N/;oPW[200?oPW[200?o0000ogAda?mdM<@02_mdM<@00ol0003oR8gBohR=dP06ohR=dP03o`000?mj
R=GoNXSE00SoNXSE00?o0000ohR_kon8[nl04on8[nl00ol0003oYL_cojG;l`03ojG;l`?o00003On]
e?@2o`0000Ko]Mke00Go0000olkWjOo>inWoc^OYo`000004om;]i`04o`000?oHl^;of?;RomSbhPCo
g_SJ00?o0000omSoe?l000000_l000000onliX?ooo]ZoookJP07oookJPCo0000@OoonfX00ol0003o
oo]ZoookJP0GoookJP03o`000?oonf[ooo]Z023ooo]Z000LoookJP03o`000?oonf[ooo]Z01Cooo]Z
0ol0000XoookJP03o`000?oonf[ooo]Z01Gooo]Z0ol000001?l00Hko0000o`000?l00006obi0/`04
o`000?mSL<[o0000o`0000OoGFO400?o0000ofUec?l000003OmnQm800ol0003oR8gBo`00000>ohbC
e@03o`000?nLZ=ooW:SO00WoW:SO1?l00002oj>gj003o`000?nW_n_oYko[00koYko[0ol00003oj_A
m003o`000?nWdoOoYm?g00OoYm?g0ol00008oj7To0?o00000_nCjoH01?l0003oU>ceoiC/mOnDk?D2
o`00053ooo]Z00?o0000o`1ca?l000002Ol00007offan@03o`000?nO^^coWk[/00?o00003onF^O00
1?l0003o][cOo`000?l0000@ok>nh`;o000000?o/L3Uo`000?o8a]L01_o8a]L00ol0003obLSIolW8
f@08olW8f@03o`000?o9bm_o000000CoclcG00Go0000omc=b_oLcL[og<g:o`000007omkAb`03o`00
0?oWe/CoimK400?oimK400?o0000on[KaOoZflD00ooZflD01Ol0003omN:gooGR]ooeh[Oo000000;o
mnJe0_l00002oo_WV0Co00008_oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z00[o
oo]Z00Co0000onjCDoo^Te?o00000_o`X6`00ol0003okIe_onfMK`03onfMK`;o00001ooXXh<00ol0
003oiIn4onFOQ002o`0004Gooo]Z0_l00002om73c@03o`000?oN`K_og/6k00Cog/6k00?o0000omVm
_OoI_Kd02?oI_Kd01?l0003oeKJko`000?l00009olbZ]`03o`000?o5Y;SoaJBh00?oaJBh00?o0000
oljT[Oo>Y:d00_o>Y:d4o`0000ooaZBf00Co0000okJB/_nfT[;o]Y:b7Ol0000DojB4/P03o`000?n@
MK7oT7Fa00OoT7Fa1ol00002oi=m^0;o00001On6N[h9o`0000CoQGc200Go0000oh9j`_n2N/;oPW[2
o`00000>ogAda003o`000?n8SM;oR8gB00CoR8gB00?o0000ogZ8eOmjR=D02OmjR=D00ol0003oR:o_
ohR_k`0DohR_k`03o`000?nUbo?o000000;o00003_n]e?@2o`0000Wo]Mke00?o0000olkWjOl00000
1OoBkNL00ol0003of?;RomSbhP04omkhfP05o`000?oHomCo0000omgn`Oo8mj/00_l00006oookJP?o
0000AOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z01oooo]Z000LoookJP03o`00
0?oonf[ooo]Z017ooo]Z0ol0000/oookJP03o`000?oonf[ooo]Z01Cooo]Z00Oo0000o`00Hol0003o
006>o`000?l=8J3o000000Ko;T2c0_l00002of=`bP?o00000omMIl@01?l0003oJGG<ofUec?l0000>
ogj7dP03o`000?n<TmGoS9?E00goS9?E00?o0000oibXgonLZ=l01OnLZ=l4o`0000OoXkOX00?o0000
ojNojonW_n/02_nW_n/3o`0000OoZm7d00?o0000ojOCmonWdoL00onWdoL3o`0000SoXNCl0ol00002
oi?[mP;o00001?nDk?EEoookJP?o00001olcYo4:o`00017oU[W`0ol0000?ok>nh`?o00001?na`>D0
0ol0003ob<KGolS6e`03olS6e`03o`000?o9b=WobLSI00SobLSI00Go0000olW;foo9bm_obL_Ko`00
0004olo<e`03o`000?oLcL[o000000Oog]7;00?o0000on3FcOl000000ooWe/@00ol0003oj]_5on[K
a@04on[Ka@05o`000?oeh[OomN:gooGR]ol000000_ogi[D2o`000003oo_WV?l0003o000000;o0000
00?ooo]Zo`000?oonfX08OoonfX00ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z00_ooo]Z
00Co0000onjCDoo^Te?o00000_o`X6`00ol0003okIe_onfMK`03onfMK`;o00001_oXXh<00ol0003o
iIn4onFOQ002onFOQ003o`000?oonf[ooo]Z047ooo]Z00Co0000om;5c_oBaLko00000_oA`ld00ol0
003og/6komk1^`02omk1^`03o`000?oI_KgofKfm00SofKfm00?o0000omFf^ooE][/00_oE][/2o`00
00Koc:Zg00?o0000olFT^?o5Y;P01Oo5Y;P4o`0000;ocZB]00?o0000olJT]_o6Y;H03Oo6Y;H00ol0
003o]Y:bokJB/P04okJB/P03o`000?neT[;o]I:b00_o]I:b00?o0000ok6C^?naTkP02?naTkP00ol0
003oY8BbojB4/P0CojB4/P03o`000?n@MK7oT7Fa00Oo00001onCOKP2o`000003oiR2^_l0003oQWZn
00goQWZn1Ol00002oh9j`P03o`000?mdM<CoM7C400goM7C400?o0000ohR=d_n8SM800on8SM800ol0
003oNXSEogZ8e@0;ogZ8e@03o`000?n8[nooR:o_017oR:o_00Co0000ohR_kon8[noo00003on]e?@2
o`0000co]Mke00?o0000om;]iooBkNL01?oBkNL00ol0003of?;RomkhfP03omkhfP03o`000?oHomCo
f?oD00Co00001?oonfX3o`0004Wooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0O
oookJP007?oonfX00ol0003ooo]ZoookJP0>oookJP?o0000<?oonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?l006?o000000;o006>0ol00004obi0/`03o`000?m4F<;o000000GoHg3:0_l000000omM
IlCo0000ofUec002ofUec003o`000?mnQm;oOXOB00[oOXOB0_l0000@ohbCe@03o`000?nLZ=ooW:SO
00Co00003?nS]nP00ol0003oYko[ojNoj`07ojNoj`;o00002on[dO@00ol0003oYm?go`000002o`00
00SoXNCl0ol00002oi?[mP;o00001?nDk?EJoookJP03ogL00?l0003o000000?o00002olcYo400ol0
003oU[W`oiJil00;oiJil0Co00000_n>]o800ol0003o/kkSok>nh`0;ok>nh`;o00002?na`>D01Ol0
003ob<KGolS6eoo8a]Oo000000WobLSI0_l00005olW;f`04o`000?o?c=OoclcGolo<e`;o00001ooN
dL/01Ol0003oh=K=on3FcOoPe/go000000;oimK400?o0000on[KaOoZflD00ooZflD00ol0003ok>35
o`000002ooGR]`04o`000?ogi[GomnJeo`0000;onnNH1?l000000ooonf[o0000oookJP0RoookJP03
o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX03?oonfX01ol0003okY=ConjCDoo^Te?o0000
oo2PK?l000001Oo]WFl00ol0003ojIYbo`000005onRSP`03o`000?oUWhCoiIn400?oiIn400?o0000
oookJ_oonfX0?ooonfX00ol0003od/G>om;5cP02om;5cP04o`000?oA`lgodL?=o`0000;og/6k00?o
0000omVm_OoI_Kd02?oI_Kd00ol0003oeKJkomFf^`05omFf^`;o00001?o<Z[L00ol0003oaJBholFT
^003olFT^0?o00001?o>Y:d00ol0003oaZBfolJT]P0=olJT]P03o`000?nfT[;o]Y:b00Ko]Y:b00?o
0000okFB/_neT[802OneT[800ol0003o/I>hok6C^009ok6C^003o`000?nTQ;;oY8Bb01;oY8Bb1?l0
000;oi=m^0?o00000onHP[X00ol0003oQWZnohIj_P0@ohIj_P03o`000?moOlSo000000Go00003?md
M<@00ol0003oR8gBohR=dP02ohR=dP03o`000?mjR=GoNXSE00_oNXSE00?o0000ohR_kon8[nl02_n8
[nl7o`0000?oTkWa00?o0000ojgDm?n]e?@02on]e?@2o`0000co]Mke00Go0000ok_Ym?nkjOCo^nWd
o`000003om;]i`03o`000?oHl^;og_SJ00?og_SJ00?o0000omSoe?oHom@00_l000001?o8mj_o0000
oookJ_oonfX3o`0004gooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP0OoookJP00
7?oonfX00ol0003ooo]ZoookJP0;oookJP?o0000=?oonfX00ol0003ooo]ZoookJP0BoookJP03o`00
0?l006?o000000;o006>00Co0000oc16^Ol`A[Wo00000ol^@;<00ol0003oA5S2o`000007of=`bP?o
00000_mYML`00ol0003oOXOBogj7dP09ogj7dP04o`000?n3S]KoPhkFo`0000coS9?E1_l0000Aoj>g
j003o`000?nW_n_oYko[00?oYko[0ol0000=oj_Am0?o00001onQi?`3o`0000?oTn_f0_l00003oiC/
m@03oekC_?oonf[ooo]Z05[ooo]Z00?o0000o`00Kol006l01ol00008oc>Wl@03o`000?nF^O3oU[W`
00GoU[W`1Ol00007ohjglP03o`000?nc_^?o/kkS00So/kkS0_l0000;ok70i@03o`000?o8a]Oo0000
00WobLSI00?o0000olW;foo9bm/01_o9bm/00ol0003oclcGo`000002om3@f@03o`000?oNdL_og]7;
00?og]7;00?o0000on3FcOoPe/d00_oPe/d00ol0003oimK4o`000005on[Ka@06o`000?o/h<Gok>35
o`000?oeh[Oo00000oogi[D00ol0003onnNHoo_WV004o`0000;ooo]Z00?o0000oookJ_oonfX08?oo
nfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000onjCDoo^Te<00_o^
Te<2o`0000GokIe_00?o0000onVJL_oYVW800_l00002onRSP`03o`000?oUWhCoiIn400GoiIn40_l0
000noookJP03o`000?oBaLkod/G>00Cod/G>00Ko0000om73cOoA`lgo0000omk1^ol0000:omVm_@03
o`000?oE][_oeKJk00OoeKJk0_l000000oo<Z[Oo0000olFT^002olFT^0?o00000oo5Y;P01?l0003o
cZB]oljT[Ol0000?olJT]P03o`000?nfT[;o]Y:b00Oo]Y:b00?o0000okFB/_neT[802?neT[800ol0
003o/I>hok6C^00;ok6C^003o`000?nTQ;;oY8Bb00ooY8Bb0_l000000onVRkSo0000oi=m^00:oi=m
^0;o00001onHP[X00ol0003oQWZnohIj_P0?ohIj_P;o00001_n<QlT9o`0000?oM7C400Go0000ohR=
d_n8SM;oR8gBo`00000?ogZ8e@03o`000?n8[nooR:o_00;oR:o_1ol0000;oi>il@03o`000?n]e?Co
[MCd00So[MCd0_l0000;okGNm@;o00001onkjO@00ol0003od^gWo`000004omkhfP03o`000?oHomCo
f?oD00Oo0000D?oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z01oooo]Z000Loook
JP03o`000?oonf[ooo]Z00Wooo]Z0_l0000hoookJP03o`000?oonf[ooo]Z017ooo]Z00Ko000ho`00
0?l0003o0000o`01S_l00003oc16^@04o`000?l^@;?o;T2co`0000;oA5S200?o0000of=`b_mSL<X0
1?mSL<X00ol0003oKGkCofend`03o`0000[oOXOB00Go0000oh>>e_n3S]KoPhkFo`000004ohbCe@So
00001?nIZn<00ol0003oXkOXoj>gj00Aoj>gj003o`000?nW_n_o000000;o00003On[dO@3o`0000?o
[N?i0ol000001?nQi?co0000o`000?l00003oi?[mP?o00000_nDk?D2oekC_0;oolM_00?o0000oook
J_oonfX0FOoonfX01?l0003o001_o`00Kol006l3o`0000?o<:G`0_lTU^d2o`0000Go<jOa00?o0000
oiJil?nF^O001?l0000=ohjglP03o`000?nc_^?o/kkS00Go/kkS0_l0000=ok70i@;o00002Oo9b=T0
0ol0003obL_KolW;f`07olW;f`;o00001?o@d=T01Ol0003og]7;omkAbooNdL_o000000Koh=K=00?o
0000on[KaOoZflD01?oZflD01_l0003ok>35oncPaOl0003omN:go`0000;omnJe0_l000001_okiiSo
0000ooSXT?l0003oh]5Go`0000?ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP1A
oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000onjCDoo^Te<00oo^Te<2o`0000CokIe_00?o0000
onVJL_oYVW800_oYVW800ol0003oj:>3o`000007onFOQ003o`000?oRW8Go000003cooo]Z00?o0000
om;5c_oBaLh01_oBaLh01?l0003odL?=o`000?l0000:omVm_@03o`000?oE][_oeKJk00[oeKJk1Ol0
0006olFT^004o`000?o>Y:gocZB]o`0000ooaZBf00?o0000okJB/_nfT[801onfT[800ol0003o]I:b
okFB/P07okFB/P03o`000?naTkSo/I>h00co/I>h00?o0000ojB4/_nTQ;803OnTQ;82o`0000CoYX^h
00?o0000oi=m^?nCOKP01_nCOKP2o`0000WoV8:j00?o0000ohIj__n6N[h03_n6N[h00ol0003oR7c0
o`00000?ohb7bAco00004onC^O400ol0003o[MCdojgDm005ojgDm0;o00003?neg_D00ol0003o^nWd
ok_Ym008ok_Ym0?o00000_oNn=X01?l0003of?oDomSoe?oHom@2o`000003okkk`Ol0003ooo]Z05?o
oo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0OoookJP007?oonfX00ol0003ooo]Z
oookJP06oookJP?o0000>ooonfX2o`00017ooo]Z00Go000ho`000?l0003o0000o`01SP02o`0000?o
<4Ji0_l00003odAH`P03o`000?mSL<[oHg3:00?oHg3:00?o0000ofendom]O]<01?m]O]<Co`0000go
VJ_S00?o0000oj>gj?nS]nP03onS]nP4o`0000coZm7d0ol00008ojgSn@;o000000CoTn_fo`000?nC
joKoTn_f0_l00002oiC/m@?o000000Go]OcHo`000?ooafooolM_o`00001JoookJP;o00000ol006l0
0ol0003o001So`000003o`0000;o<:G`00?o0000obBFkOlTU^d00olTU^d01?l0003o<jOao`000?l0
000AohjglP03o`000?nc_^?o/kkS00;o/kkS0ol0000<ok70i@?o000000?o[l;Xo`000?o9b=T01oo9
b=T00ol0003obL_KolW;f`07olW;f`03o`000?o:c]go000000God=3I00?o0000omkAbol000001ooP
e/d00ol0003oj]_5on[Ka@03on[Ka@03o`000?o/h<Gok>3500;ok>3500Ko0000ooOV]Oogi[GomnJe
o`000?ohjk82o`000004ooSXT?l0003oh]5Go`0000Cooo]Z00?o0000oookJ_oonfX08?oonfX00ol0
003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000onjCDoo^Te<00_o^Te<00ol0
003oji5Ho`000003onfMK`03o`000?oYVW;ojIYb00?ojIYb0_l00007onFOQ003o`000?oRW8GohYb5
00;o0000>OoonfX00ol0003od/G>om;5cP08om;5cP?o00002OoI_Kd00ol0003oeKJkomFf^`0:omFf
^`Ko00001_o5Y;P00ol0003ocZB]o`00000?olJT]P03o`000?nfT[;o]Y:b00Wo]Y:b00?o0000okFB
/_neT[801OneT[800ol0003o/I>hok6C^00=ok6C^003o`000?nTQ;;oY8Bb00_oY8Bb0_l00006ojJ;
^003o`000?nCOKSoTgfh00CoTgfh0_l0000;oiR2^P03o`000?n6N[koQWZn00coQWZn0_l00003ohQl
`003o`000?n<QlWoS8O9013oS8O900?o0000ohNBeol000004On8TmP00ol0003oTkWaoi>il@0Eoi>i
l@03o`000?n]e?Co[MCd00;o[MCd0_l0000<okGNm@;o00002OnkjO@00ol0003o`??`o`000002olci
i`Ko00000onnnl5FoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX07ooonfX001co
oo]Z00?o0000oookJ_oonfX00ooonfX3o`00043ooo]Z00?o0000oookJ_oonfX03_oonfX3o`000004
o`00S?l0003o0000o`0000Co<4Ji0_l00003odAH`P03o`000?mSL<[oHg3:00;oHg3:00?o0000ofen
dom]O]<01?m]O]<00ol0003oOHSCogf8d`06ogf8d`03o`000?n2S]OoPXkG00?oPXkG00?o0000oiV[
honIZn<03onIZn<00ol0003oXkOXoj>gj00;oj>gj0?o00001?nYb>l00ol0003oZm7doj_Am007oj_A
m0;o00002On]hoT2o`0000CoZo;e0_l000002OnDk?Go0000o`000?nWlo;o0000okGlf?l0003on]ai
o`000002ooo7K`;o0000F?oonfX00ol0003o?b:4o`000002o`00K`04o`000?li;YSo001So`00C`Wo
00001OlTU^d00ol0003oS[ObohjglP0@ohjglP04o`000?nc_^?o0000o`0000go/L3U0_l00005ojo2
j003o`000?o9b=WobLSI00?obLSI0_l00009olW;f`05o`000?o:c]gob/kMol[>gOl000001Oo@d=T0
0ol0003oh=K=on3Fc@05on3Fc@03o`000?oSf/go000000?oj]_500?o0000oncPaOo/h<D00oo/h<D0
1?l0003omnJeooOV]Ol00002ooS[/P;o000000Con>R@o`000?l0003o00001?oonfX00ol0003ooo]Z
oookJP0PoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX03OoonfX2o`0000?okY=C
00Co0000on^AF?o[TESo00000_o]WFl00ol0003ojIYbonVJLP04onVJLP;o00001_oUWh@00ol0003o
hYb5on:LQ@02on:LQ@;o0000=_oonfX00ol0003od/G>om;5cP09om;5cP04o`000?o<_<co0000o`00
00SofKfm00?o0000omFf^ooE][/01ooE][/4o`0000Goc[2k0ol00004olFT^003o`000?o6Y;KoaZBf
00goaZBf00?o0000okJB/_nfT[802_nfT[800ol0003o]I:bokFB/P04okFB/P03o`000?naTkSo/I>h
00ko/I>h00?o0000ojB4/_nTQ;802OnTQ;82o`0000SoYX^h00Co0000oi=m^?nCOKSoTgfh0ol0000>
oiR2^P03o`000?n6N[koQWZn00[oQWZn00?o0000ohQl`?n8O<000on8O<000ol0003oS8O9ohb7b@0A
ohb7b@03o`000?n8TmSoR9?H017oR9?H00?o0000oi>ilOnC^O405OnC^O401?l0003o[MCdo`000?l0
000<okGNm@;o00002OnkjO@2o`000005ol3cl?l0003oc?WWolciiol000001Oo=n>P00ol0003o___1
okkk`@1HoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX07ooonfX001_ooo]Z00Co
0000oookJ_oonf[ooo]Z0ol00014oookJP03o`000?oonf[ooo]Z00kooo]Z0_l000001?l008co0000
o`000?l00004oc16^@03o`000?m3G<Oo000000;oA5S200?o0000of=`b_mSL<X00_mSL<X00ol0003o
KGkCofend`05ofend`03o`000?mmR=?oOHSC00CoOHSC00?o0000oh:>eon2S]L01On2S]L00ol0003o
VJ_SoiV[h`0?oiV[h`03o`000?nS]nSoXkOX00OoXkOX0ol00008ojW8k`03o`000?n[dOCoZm7d00?o
Zm7d0ol00009ojgSn@;o00001On[l_D2o`0000;oYo?b0ol000001Oneo=So0000oo[LNOojg7Wo0000
00;oolM_00?o0000ooVkPOl00000E_oonfX00ol0003o?b:4oclRQ002o`000003o`00Kol0003o>BjH
00?o000000?o01:Mo`000?l000001?lQUN`3o`0000Co99K]00?o0000ohjgl_n>]o803?n>]o85o`00
00co/L3U0ol00008ojo2j005o`000?o9b=WobLSIolW8fOl000002_o9bm/00ol0003ob/kMol[>g@03
ol[>g@04o`000?o@d=Wod=3Iom3@f@;o00001_oPe/d01Ol0003ohm[=on?JcOoSf/go000000;oj]_5
00?o0000oncPaOo/h<D00_o/h<D2o`0000;omnJe00Go0000ooS[/_ohjk;o0000ooSXT003o`0000Ko
oo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z00go
oo]Z00?o0000onMo<Ol000000_o^Te<01ol0003oji5Hon^AF?o[TESo0000onfMKol000001_oYVW80
0ol0003oiYQdo`000005onFOQ003o`000?oRW8GohYb500CohYb500?o0000oookJ_oonfX0<_oonfX0
0ol0003od/G>om;5cP09om;5cP05o`000?o<_<coc;c<olblc?l000001ooI_Kd00ol0003oeKJkomFf
^`05omFf^`?o00000_oE][/00ol0003oc[2kolj`^`07olj`^`?o000000?oaJBho`000?o6Y;H03Oo6
Y;H00ol0003o]Y:bokJB/P0;okJB/P03o`000?neT[;o]I:b00?o]I:b00?o0000ok6C^?naTkP04?na
TkP00ol0003oY8BbojB4/P07ojB4/P03o`000?nVRkSoYX^h00WoYX^h0ol0000AoiR2^P03o`000?n6
N[koQWZn00SoQWZn0_l00007ohQl`003o`000?n<QlWoS8O9013oS8O900?o0000ohRCf?n8TmP04_n8
TmP00ol0003oTkWaoi>il@0Eoi>il@03o`000?neg_Go]Mke00[o]Mke0_l0000:ok_Ym004o`000?o0
lo3o`??`o`0000;oc?WW00?o0000olghj?o=n>P00_o=n>P2o`0000;o___1FOoonfX00ol0003ooo]Z
oookJP0CoookJP03o`000?oonf[ooo]Z01oooo]Z000KoookJPCo0000B?oonfX00ol0003ooo]Zoook
JP0=oookJP07o`00>?l0003o002<o`00S?l0003o12FXo`000003oc16^@03o`000?m3G<Oo@ec700;o
000000GoA5S2o`000?mSL<[oHg3:o`000008ofend`03o`000?mmR=?oOHSC00?oOHSC00?o0000oh:>
eon2S]L01on2S]L00ol0003oVJ_SoiV[h`0>oiV[h`03o`000?nS]nSoXkOX00CoXkOX0ol0000<ojW8
k`03o`000?n[dOCo000000;o00002_n]hoT2o`0000GoZo;e0_l00002ojOclPOo00000_ojg7T3o`00
00?onK^100?o0000oookJ_oonfX0D_oonfX00ol0003o?b:4oclRQ002oclRQ0;o00000_li;YP2o`00
00;o03>i00?o01:Mo`000?l000000_l00004ob6Ek003ob6<jol0003o000000;o99K]00?o0000ohjg
l_n>]o800_n>]o89o`0000GoQkGc00?o0000ok70iOna`>D01_na`>D3o`0000co[l;X00?o0000olW8
fOl000002Oo9bm/2o`0000Oob/kM00?o0000om3@fOl000000_oBe=X00ol0003oh=K=on3Fc@02on3F
c@03o`000?oSf/gohm[=00;ohm[=00?o0000on[KaOl000001?o/h<D00ol0003ok^G4o`000002ooOV
]@05o`000?ohjk;on>^bo`000?ohj9000ol00007oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000
oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP0=oookJP04o`000?oWOc7oiglao`0000;okY=C00Co
0000on^AF?o[TESoji5H0_l00006onVJLP03o`000?oVV7CoiYQd00;o00000ooUWh@00ol0003ohYb5
on:LQ@05on:LQ@;o0000<OoonfX00ol0003od/G>om;5cP09om;5cP03o`000?o<_<coc;c<00?oc;c<
0_l00004omVm_@03o`000?oE][_oeKJk00?oeKJk0ol00004omFf^`03o`000?o>/;_oc[2k00_oc[2k
1Ol0000;olJT]P03o`000?nfT[;o]Y:b00co]Y:b00Go0000okFB/_neT[;o]I:bo`00000Cok6C^003
o`000?nTQ;;oY8Bb00GoY8Bb0_l00009ojJ;^0Co00004onHP[X00ol0003oQWZnohIj_P07ohIj_P03
o`000?n8O<3oR7c000OoR7c000?o0000ohb7bOn<QlT03on<QlT00ol0003oRiCHo`00000CohRCf003
o`000?nC^O7oTkWa00ooTkWa1?l00003oig5m003o`000?neg_Go]Mke00Oo]Mke0_l0000:ok_Ym0;o
00000oo0lo03o`0000CocOSX00Co0000om;nfol0003o___1FooonfX00ol0003ooo]ZoookJP0Coook
JP03o`000?oonf[ooo]Z01kooo]Z000KoookJP;o0000BooonfX00ol0003ooo]ZoookJP0<oookJP07
o`00>?l0003o002<o`00S?l0003o12FXo`000003oc16^@03o`000?m3G<Oo@ec700;o@ec70_l00002
of=`bP03o`000?m]O]?oKGkC00OoKGkC00?o0000ogf8dommR=<00_mmR=<00ol0003oPXkGoh:>e`07
oh:>e`03o`000?nIZn?oVJ_S00ooVJ_S00?o0000oj>gj?nS]nP00ol0000?ojW8k`?o00002_n]hoT2
o`0000GoZo;e0_l00003ojOclP04o`000?oonf[o0000okGlf0Co000000?on]aio`000?onchh00_l0
0004ooVkP@;o0000DOoonfX00ol0003o?b:4oclRQ003oclRQ003o`00Kol0003o>BjH00;o>BjH00Co
0000o`00O?l0<kWo03>i0_l04Yd00ol0003o88_[o`000003o`000003ob6Ek?l0003o8Hc[00;o8Hc[
1Ol0000?ohNel`03o`000?na`>Go/L3U00?o/L3U0_l0000?ojo2j0;o00002Oo9bm/00ol0003ob/kM
ol[>g@08ol[>g@03o`000?oBe=[od]CJ00;od]CJ00Go0000on3FcOoPe/goh=K=o`000005on?Jc@03
o`000?o/h<Gok>3500;ok>3500Co0000onkUa?o^iLCok^G40_l00002ooS[/P;o000000Con>R@o`00
0?l0003o00001ooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000
oookJ_oonfX03_oonfX01_l0003oiglaonMo<Ol0003okY=Co`0000Coji5H0_l00005onVJLP03o`00
0?oVV7CoiYQd00;oiYQd0_l000000ooUWhCo0000on:LQ@06on:LQ@04o`000?oOVXKo0000o`0002ko
oo]Z00?o0000om;5c_oBaLh02OoBaLh00ol0003oc;c<olblc004olblc003o`000?oH_Koo000000?o
fKfm00?o0000omFf^ooE][/00ol00007omFf^`03o`000?o>/;_oc[2k00_oc[2k00?o0000oknS_?l0
00000_o5YKT4o`0000KoaZBf00?o0000okJB/_nfT[803OnfT[801?l0003o]I:bokFB/_l0000Dok6C
^003o`000?nTQ;;oY8Bb00?oY8Bb0_l00006ojJ;^0Go00000onTRk/00ol0003oV8:joiR2^P0AoiR2
^P03o`000?n6N[koQWZn00KoQWZn00?o0000ohQl`?n8O<002On8O<000ol0003oS8O9ohb7b@0=ohb7
b@04o`000?n;U=SoRiCHo`0001CoR9?H00?o0000oi>ilOnC^O402OnC^O45o`0000SoWLGd00?o0000
okGNmOneg_D01Oneg_D00ol0003o^nWdok_Ym009ok_Ym003o`000?o0lo3o`??`00;o`??`0_l00005
olghj005o`000?oBo]_o0000okkk`Ol00000G?oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oo
nf[ooo]Z01kooo]Z000MoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX02ooonfX2
o`0000;o002<0_l000001Ol49JSo0000oc16^Ol`A[Wo000000Go@ec700Co0000of=`b_mSL<[o0000
2Om]O]<01Ol0003oOHSCogf8dommR=?o000000_oPXkG00?o0000oiV[honIZn<03?nIZn<5o`0000oo
ZLS_0ol00003ok7Im@03o`000?n]hoWo[N?i00Go[N?i0_l00005oj_bm@?o00000_nWlo82o`000003
oj7fgOl0003oSnVd00Go000000?on]aio`000?onchh00_l00004ooVkP@03o`000?o^[XWo000004oo
oo]Z00?o0000oclRQ?lo8X@01?lo8X@00ol0003o>BjHocT^V002ocT^V003o`000?l007co001l00;o
03>i0_l04Yd00ol0003o88_[ob2;j`02ob2;j`Co00000olQS>/00ol0003oQkGcohNel`0@ohNel`03
o`000?na`>Go000000;o00003_n_`^P3o`000003ojo4jOl0003obL_K00OobL_K00?o0000ol[>gOo:
c]d02?o:c]d00oo<dMko0000om;DfP04om;DfP03o`000?oPe/go000000Kohm[=00Go0000oncPaOo/
h<Gok>35o`000004onkUa0;o00000_ohjk83o`000003oo7WQ?l0003o000000Sooo]Z00?o0000oook
J_oonfX08?oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z00oooo]Z00Co0000onMo
<OoWOc7oigla0_l00004on^AF003o`000?oXSego000000CojIYb00?o0000onJHM?oVV7@01?oVV7@2
o`0000OohYb500Co0000omnJQ_oOVXKogiZ60_l0000[oookJP03o`000?oBaLkod/G>00Wod/G>00?o
0000olblc?o<_<`01_o<_<`01?l0003of;foo`000?oI_Kd4o`0000WoeKJk00?o0000olj`^oo>/;/0
2oo>/;/01Ol0003o_j>loknS_?noXkco000000GoaJFi0ol00002olJT]P03o`000?nfT[;o]Y:b00ko
]Y:b00?o0000okFB/_l000005OnaTkP01?l0003oY8BbojB4/_nTQ;82o`0000?oYX^h1Ol00009ojB;
^`03o`000?nHP[[oV8:j017oV8:j00?o0000ohIj__n6N[h00on6N[h2o`0000coR7c000?o0000ohb7
bOn<QlT03?n<QlT00ol0003oRiCHoh^Df002oh^Df003o`000?n8TmSoR9?H017oR9?H00?o0000oi>i
lOnC^O401OnC^O44o`0000koWLGd00?o0000okGNmOneg_D00_neg_D2o`0000[o^nWd0_l00005ol3c
l003o`000?o=n>SocOSX00?ocOSX00Go0000om;nfol0003o___1o`00001MoookJP03o`000?oonf[o
oo]Z01;ooo]Z00?o0000oookJ_oonfX07_oonfX001kooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0
003ooo]ZoookJP0;oookJP;o000000?o002<o`000?l09JX00_l000000ol`A[Wo0000od=La`06od=L
a`Co00002Om]O]<01?l0003oOHSCogf8dol0000;oh:>e`03o`000?nIZn?oVJ_S00OoVJ_S1Ol00004
oj6ijP03o`000?nYb>ooZLS_00[oZLS_0ol00007ok7Im@03o`000?n]hoWo[N?i00;o[N?i0_l00005
oj_bm@Co00000_nWlo800ol0003ooo]Zo`000007o`000003oogQV_l0003o000000;oo/n>00?o0000
ooVkPOoi^h400_oi^h401?l0003okZj9onj^ROl0001=oookJP03o`000?lo8XCo?b:400Go?b:400?o
0000ocT^V?li;YP00_li;YP00ol0003o001lo`00O003o`0c^@;o01:M0_l00005ob2;j`?o00000_lQ
S>/00ol0003oQkGcohNel`0<ohNel`Go00003on_`^P2o`0000Go[lCY00?o0000olW;foo9bm/00oo9
bm/2o`0000Sob/kM0_l00003olcAgP03o`000?oBe=[od]CJ00;od]CJ0_l00006on?Jc@;o00000oo/
h<D00ol0003ok^G4onkUa002onkUa005o`000?ohjk;on>^bo`000?ogkjd00_l000000ooaihCo0000
o`000009oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oWOc7oigla00;oigla0_l00003on^AF003o`000?oXSegoj8mM00;o0000
0ooYVW800ol0003oiYQdonJHM004onJHM0;o00001_oRW8D00ol0003ogiZ6omnJQP03omnJQP;o0000
:?oonfX00ol0003od/G>om;5cP09om;5cP03o`000?o<_<coc;c<00Soc;c<1?l0000;omFf^`03o`00
0?o>/;_oc[2k00_oc[2k00?o0000oknS_?noXk`00_noXk`00ol0003oaJFiolFU^@06olFU^@Ko0000
3_nfT[800ol0003o/I>hok6C^00Eok6C^0So00003_nTRk/00ol0003oV8:joiR2^P0AoiR2^P03o`00
0?n6N[koQWZn00;oQWZn00?o0000ohQl`?n8O<003?n8O<000ol0003oS8O9ohb7b@0;ohb7b@03o`00
0?n;U=SoRiCH00?oRiCH00?o0000ohRCf?n8TmP04_n8TmP00ol0003oTkWaoi>il@04o`0001?oWLGd
00Co0000okGNmOl0003o00002_nkjO@2o`0000Ko`??`00?o0000olghj?o=n>P00oo=n>P01Ol0003o
d_kKo`000?nnnl7o000005oooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0Noook
JP007ooonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z00[ooo]Z0_l000001ol008co
0000o`0UZ_l09J[o0000oc16^Ol000001om3G<L01?l0003oLhSIog>8fOmcR=T5o`0000CoKGkC00?o
0000ogf8dol000003On2S]L01?l0003oVJ_SoiV[honIZn<5o`0000[oXKWZ00?o0000ojW8konYb>l0
1onYb>l2o`0000_o/MWe00Co0000ojgSnOl0003o00001On[l_D2o`000004ojSclol0003oYo?bojOc
lP;o000000?oXOKMo`000?neo=P00_l000001?n=fXWo0000o`000?l00002oogQVP05o`000?onchko
o/n>ook?S_l000001?oi^h401Ol0003okZj9onj^ROo^[XWo000004[ooo]Z0_l00007oclRQ003o`00
0?li;YSo000000;o>BjH00Go0000oa4PW_l0003o001lo`000002o`0c^@03o`0/]Ol04Ygo000000;o
00001_lPRn/01Ol0003o98GZo`000?lQS>_o000000CoQkGc2Ol00004oh>cm003o`000?n_`^So[l;X
00[o[l;X0ol00007ojo4j@03o`000?o9bm_obL_K00;obL_K00?o0000ol[>gOo:c]d01oo:c]d00ol0
003oc=7NolcAgP03olcAgP07o`000?oBe=[od]CJom;Df_l0003oe]WKo`000005on?Jc@06o`000?oU
g/goiMk=o`000?o/h<Go00001Oo^iL@01Ol0003on>^booS[/_l0003omnn]00;o000000?olNN4o`00
0?l000002_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oook
J_oonfX04?oonfX01ol0003oiglaonMo<OoWOc7o0000onIo>Ol000000oo[TEP01?l0003oj8mMonR?
GOoXSed2o`000003onVJL_l0003oiYQd00GoiYQd00?o0000on>EMol000001OoRW8D00ol0003ogiZ6
omnJQP05omnJQP;o00009OoonfX00ol0003od/G>om;5cP09om;5cP03o`000?o<_<coc;c<00Ooc;c<
1?l00002omBg_0;o00002?oE][/00ol0003oc[2kolj`^`0;olj`^`03o`000?noXkco_j>l00Co_j>l
00?o0000olFU^Oo5YKT01_o5YKT00ol0003o`:Bmol2T_@02ol2T_@Wo00001?nfT[82o`0000_o/I>h
3ol0000CojB;^`03o`000?nHP[[oV8:j017oV8:j00Go0000ohIj__n6N[koQWZno`00000@ohQl`003
o`000?n<QlWoS8O900WoS8O900?o0000oh^Df?n;U=P01On;U=P00ol0003oR9?HohRCf00=ohRCf0Oo
00006?nMaO@00ol0003o^nWdok_Ym009ok_Ym003o`000?o0lo3o`??`00Go`??`00?o0000olghj?o=
n>P00oo=n>P01Ol0003od_kKo`000?nnnl7o0000067ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0
003ooo]ZoookJP0NoookJP008?oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z00Wo
oo]Z1?l00003o`0UZP;o00001om3G<L00ol0003oLhSIog>8f@06og>8f@Co000000?oKGkCo`000?n2
S]L01on2S]L:o`00013oXKWZ00?o0000ojW8konYb>l00onYb>l3o`0000go/MWe1Ol00002oj_bm@;o
00000_nXlo<01?l0003oYo?bojOcl_l00002oj7fg@Co000000?oSMZ9o`000?l000000_l00002oogQ
VP04o`000?onchkoo/n>ook?SP;o00000_oi^h400ol0003okZj9onj^R@03onj^R@;o0000A_oonfX2
o`000003oeLcR_l0003o?b:400Go?b:400Co0000oeE2W_mE@Yko00000_li;YP01?l0003o4B2No`00
0?l007`2o`000004o`0c^Ol0003o02beo`0BW@Ko00000olPRn/01?l0003o98GZobB5j_lTQNX4o`00
00koPk?d00?o0000ojo2j?n_`^P01_n_`^P3o`0000_o[lCY00Co0000olW;foo9bm_o00002Oo:c]d0
0ol0003oc=7NolcAgP04olcAgP04o`000?oBe=[od]CJo`0000?oe]WK00Go0000on?JcOoSf/gohm[=
o`000003onGNc@;o00001Oo^iL@2o`0000;on>^b00Co0000ooO_[Ol0003olNN40_l0000;oookJP03
o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP0@oookJP;o
00000ooWOc400ol0003oiWlio`000002on^AF003o`000?oXSegoj8mM00?oj8mM0_l00006onJHM003
o`000?oSUGOohiEg00;o00000ooRW8D00ol0003ogiZ6omnJQP05omnJQP03o`000?oLUhOo000000;o
00008OoonfX00ol0003od/G>om;5cP09om;5cP03o`000?o<_<coc;c<00Goc;c<0ol00002olblc0;o
00001?oD]k`2o`0000KoeKJk00?o0000olj`^oo>/;/02_o>/;/00ol0003o_j>loknS_005oknS_003
o`000?o5YKWoaJFi00GoaJFi00?o0000ol2T_Oo0Y;d03?o0Y;dAo`0000[o/YFj00?o0000okFL__l0
00005_nTRk/00ol0003oV8:joiR2^P0AoiR2^P03o`000?n6N[koR7c0017oR7c000?o0000ohb7bOn<
QlT02?n<QlT00ol0003oRiCHoh^Df006oh^Df003o`000?n8TmSoR9?H00?oR9?H2_l00005ohj]j`03
o`000?nMaOCoWLGd01?oWLGd0ol00002ojOBm`03o`000?nkjOCo^nWd00Ko^nWd0_l00007ol3cl003
olWbkOl0003ocOSX00?ocOSX0ooBo]/2o`0006?ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP0NoookJP008OoonfX00ol0003ooo]ZoookJP19oookJP;o00002_oonfX3o`0000?o02FZ
0ol00006od=La`;o00002omcR=T:o`0000OoT:OU00?o0000oj6ij_nQ^NX04OnQ^NX00ol0003oZLS_
o`000002o`0000ko/MWe0_l00005okOYmPCo000000GoZ??co`000?nWlo;oYo?boookJP03o`000004
oi[^]ol0003o0000ohgJR@;o000000?omnnVo`000?l000000_omhIX02Ol0003oo/n>ook?S_onchko
0000ooG1U?l0003onK^1o`000005onj^R@03o`000?oRXXgo000004?ooo]Z0_l000001?mnD93o0000
oeLcR_l00005oclRQ007o`000?mE@YkoED:NoeE2W_l0003o>BjHo`000003oa4PWP03o`00O?l0003o
01JT00;o03>i00?o0000o`0/]Ol04Yd00ol00002obZ2j@?o000000?o88_[o`000?lTQNX00_lTQNX0
0ol0003oPk?doh>cm00?oh>cm003o`000?n_`^So[l;X00?o[l;X0_l0000>ojo4j@03o`000?o9bm_o
000000Sob/kM0_l00008olcAgP03om;Df_l0003oe]WK00Coe]WK00?o0000on?JcOl000001?oUg/d0
0ol0003ok^G4onkUa003onkUa003o`000?oaj<;olNS200;o00000_ogkjd01?l0003olNN4o`000?l0
000<oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]Zoook
JP0@oookJP03o`000?oJI0So000000;oigla00Ko0000onIo>OoVOcWo0000on^AF?l00006onR?G@;o
00001OoVV7@00ol0003ohiEgon>EM`02on>EM`;o000000?ohYb5o`000?oOVXH01_oOVXH00ol0003o
g9N7ombGQ`02ombGQ`;o00007_oonfX00ol0003od/G>o`000009om;5cP03o`000?o<_<coc;c<00?o
c;c<0ol00004olblc004o`000?o6]l_oa[O;o`0000Goe;Nl00?o0000omFf^ooE][/00_oE][/00ol0
003oc[2kolj`^`0:olj`^`03o`000?noXkco_j>l00Oo_j>l00?o0000olFU^Oo5YKT00oo5YKT00ol0
003o`:Bmol2T_@0?ol2T_@04o`000?ncU[Wo/iJio`0001Co/YFj00Go0000okFL__neW;ko]Ibno`00
000EojB;^`03o`000?nHP[[oV8:j013oV8:j0_l0000:ohQl`2?o00004?n>[N/00ol0003oWLGdoig5
m00?oig5m0?o00001_nWd_L00ol0003o^nWdok_Ym004ok_Ym003o`000?o0lo3o`??`00Go`??`00?o
0000olWbkOl000000oo=n>P01ol0003od_kKom;nfooBo]_o0000ok[d[?l00000HooonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z01kooo]Z000RoookJP;o0000BooonfX00ol0003ooo]Z
oookJP07oookJP03o`000?l008go000000?o02FZ00?o0000odQUcOm8ILd00_l00004od=La`03o`00
0?mEKm7o000000_oLhSI00?oNY7Mo`000?n@YnD03_n@YnD00ol0003oXKWZoj6ijP0?oj6ijP?o0000
3_nafOD3o`0000Go]nWf0_l00004okcgk`Go000000?o`o3`o`000?nJk[L00_l000001_n=fXWo0000
o`000?l0003omnnVo`0000;ooN6J00Go0000ooSBXol0003oo/n>o`000003ooG1U0;o00001Oo^[XT0
0ol0003ohZ:=on:RS@02o`0003oooo]Z0_l00003ogi@T003o`000?mG<h[o000000Co?b:400?o0000
oeE2W_mE@Yh00_mE@Yh00ol0003o>BjHo`000003oa4PWP;o000000Co01JTo`000?l0<kWo00000_l0
;;D01?l0003o02>/o`000?l00004obZ2j@?o00000olTQNX00ol0003oPk?doh>cm00?oh>cm003o`00
0?n_`^So000000;o00004?n_a>T2o`0000Sob/kM00?o0000olcAg_o<dMh02?o<dMh00ol0003oe]WK
omKIf`04omKIf`?o00001?oUg/d00ol0003ok^G4onkUa003onkUa003o`000?oaj<;olNS200;o0000
00Comnn]o`000?l0003olNN40_l0000=oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX0BOoonfX00ol0003ooo]ZoookJP0AoookJP05o`000?oJI0So0000onMo<Ol000000ooVOcT2o`00
00Koj8mM00?o0000onF=HOl000001?oVV7@00ol0003ohiEgon>EM`04on>EM`;o00001ooOVXH00ol0
003og9N7ombGQ`02ombGQ`04o`000?oJU8Ko0000o`0001_ooo]Z00Go0000om;5c_oBaLkod/G>o`00
0007om;5cP04o`000?o<_<coc;c<olblc0?o00001_o<_<`00ol0003oa[O;olJgb`02olJgb`03o`00
0?oD]kcoe;Nl00?oe;Nl0_l000000ooE][_o0000olj`^`0<olj`^`03o`000?noXkco_j>l00Oo_j>l
00?o0000olFU^Oo5YKT00_o5YKT00ol0003o`:Bmol2T_@0?ol2T_@03o`000?ncU[Wo/iJi00;o/iJi
00?o0000ok:E^_nbUKX03onbUKX2o`0000Co]Ibn00?o0000ojB;^onTRk/04onTRk/00ol0003oV8:j
oiR2^P0=oiR2^Poo00002_nFS<L00ol0003oRhkAoh^>d@04oh^>d@03o`000?n<Sm7oS8oA00[oS8oA
00?o0000ohj]jon>[N/04on>[N/00ol0003oWLGdoig5m00;oig5m0?o00002_nWd_L01?l0003o^nWd
ok_Ym?nkjO@2o`0000Ko`??`0_l00002olWbk@04o`000?o=n>SocOSXo`0000?od_kK00?o0000ok[d
[?l00000IOoonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z01kooo]Z000ToookJP03
o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX01_oonfX3o`0000?o02FZ00?o0000odQUcOm8
ILd00_m8ILd01?l0003o@ec7od=Laol00002oeE_d@03o`000?mcR=WoLhSI00SoLhSI00Co0000ogZA
gOmjTMgo00003on@YnD00ol0003oXKWZoj6ijP0;oj6ijP?o00000onYbO000ol0003o/MWeok7Im@09
ok7Im@;o00001ongjOH00ol0003o_?O_okcgk`03okcgk`;o00001?o3l?001?o3oLSo0000o`000?oK
nmX2o`000005onWibOl0003omnnVooO_Y_l000000_omhIX00ol0003on=:SooSBX`02o`0000ComL6D
0_l00004onj^R@03o`000?oRXXgohZ:=00;ohZ:=00?o0000oookJ_oonfX0>_oonfX2o`0000GoOU2@
00Co0000oeLcR_mG<h[o00000_lo8X@00ol0003oED:NoeE2WP03oeE2WP03o`000?li;YSo000000Co
4B2N00Co0000o`0FY?l0003o5Sjj0_l00002o`0/]@04o`000?l08jco0000o`0000Ko:X;Y1Ol00009
oh>cm0Wo00004?n_a>T3o`0000;o[lG[00?o0000ol[>gOo:c]d00oo:c]d2o`0000Woc=7N00?o0000
olgDgol000001OoFfM/01Ol0003ofMkKomWNfooIg]_o000000;oiMk=00?o0000onOScOl000000oo^
iL@01Ol0003olNS2oo7X`_oaj<;o000000;omnn]1Ol0000=oookJP03o`000?oonf[ooo]Z023ooo]Z
00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP0AoookJP06o`000?oJI0SofV@8o`000?oW
Oc7o00000ooVOcT2o`0000Goj8mM00?o0000onF=HOoUSF400_l00002onJHM003o`000?oSUGOohiEg
00GohiEg0_l00006omnJQP03o`000?oLUhOog9N700;og9N700Co0000omZDQ_oJU8KofYB60_l0000H
oookJP03o`000?oBaLkod/G>00?od/G>00?o0000om;5c_oBaLh00ooBaLh00ol0003oc;c<o`000002
o`0000Soc;c<00?o0000olJgboo6]l/01?o6]l/00ol0003oe;NlomBg_004omBg_0;o00003?o>/;/0
0ol0003o_j>loknS_008oknS_003o`000?o5YKWoaJFi00;oaJFi00?o0000ol2T_Oo0Y;d03_o0Y;d0
0ol0003o/iJiok>F^@03ok>F^@03o`000?nbUK[o/YFj00ko/YFj00?o0000okFL__neW;h01?neW;h0
0ol0003oY8^kojB;^`0DojB;^`03o`000?nHP[[oV8:j00[oV8:j1Ol00002oiZ<`aGoUXc700?o0000
oh^>dOn;S]400_n;S]400ol0003oS8oAohb?d@0<ohb?d@03o`000?n>[N_oSZg[01?oSZg[00?o0000
oig5m?nMaO@01onMaO@3o`0000koYm;g00?o0000ok_Ym?l000001oo0lo001Ol0003obO;]olWbkOo9
l^go000000;ocOSX00Oo0000om;nfooBo]_od_kKo`000?njm:co000006Oooo]Z00?o0000oookJ_oo
nfX03OoonfX00ol0003ooo]ZoookJP0NoookJP009OoonfX00ol0003ooo]ZoookJP19oookJP03o`00
0?oonf[ooo]Z00Gooo]Z1?l00002o`0UZP;o00001?m8ILd3o`0000?oEFoA00?o0000og>8fOmcR=T0
1omcR=T01?l0003oNY7MogZAgOl0000@oi2Wi@03o`000?nQ^N[oXKWZ00OoXKWZ0ol00007ojW9l003
o`000?nafOGo/MWe00Ko/MWe0_l00007okOYmP;o00001Onlmnl2o`0000?o`o3`00Go0000ol?mb?o3
oLSo0000om_kfP02o`0000;ojOW900Co0000ooO_Y_ogkjKo00000_omhIX00ol0003on=:SooSBX`02
o`0000ComL6D00?o0000onbeV?l000000_o^[XT00ol0003ohZ:=on:RS@04on:RS@;o0000>OoonfX0
0ol0003oOU2@ogi@T005ogi@T006o`000?mG<h[oEc>:o`000?lo8XCo00001_mE@Yh2o`0000Go4B2N
00Co0000o`0FY?l05ZCo00000_ljF/P01?l0003o02beo`11a?l0@L@2ocZ2j0;o00001OlZP^T00ol0
003o;HCZobf4jP0:o`0000SoP[;c00?o0000ojo4jOn_a>T02on_a>T3o`0000Ko[lG[00Go0000ol[>
gOo:c]gob/kMo`00000:olcAgP05o`000?o=e=oocMCOolgDgol000000ooFfM/00ol0003ofMkKomWN
f`03omWNf`05o`000?oUg/go0000onOScOl000000_o^iL@00ol0003olNS2oo7X`P02oo7X`P04o`00
0?ogkjgo0000ooK`YPCo00003_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z04Oo
oo]Z00?o0000oookJ_oonfX04_oonfX2o`000003omYT2?l0003o000000CoiWli0_l00004onR?G@03
o`000?oUSF7oiHeQ00;oiHeQ00?o0000onJHM?l000001ooSUGL01?l0003ogi9ho`000?l00004omnJ
QP05o`000?oLUhOog9N7ombGQol000001?oJU8H00ol0003oei:7o`000002o`0001Cooo]Z00?o0000
om;5c_oBaLh01OoBaLh01?l0003od/G>om;5c_oBaLh3o`0000[oc;c<00?o0000olJgboo6]l/01Oo6
]l/00ol0003oe;NlomBg_003omBg_003o`000?o>/;coc[2l00?o00002?o>/;/00ol0003o_j>loknS
_00:oknS_004o`000?o5YKWoaJFio`00013o`:Bm00?o0000ok>F^OncU[T01?ncU[T00ol0003o/YFj
ok:E^P0=ok:E^P03o`000?neW;ko]Ibn00Ko]Ibn00?o0000ojB;^onTRk/04onTRk/00ol0003oV8:j
oiR2^P06oiR2^PGo00001onJS<<DoiJ<a`05o`000?n;S]7oRhkAoh^>dOl000003on<Sm400ol0003o
SZg[ohj]j`0Cohj]j`03o`000?nMaOCoWLGd00CoWLGd0ol0000BojOBm`03o`000?o0lo3o`??`00Co
`??`0_l00003olWbk@03o`000?o=n>SocOSX00Cod_kK00?o_Oc8o`000?l00000J?oonfX00ol0003o
oo]ZoookJP0>oookJP03o`000?oonf[ooo]Z01gooo]Z000VoookJP03o`000?oonf[ooo]Z04Wooo]Z
00?o0000oookJ_oonfX01?oonfX3o`000003o`0TZol0003o02FZ00;o00001_m8ILd3o`000003oeE_
dOl0003oLhSI00OoLhSI00?o0000ogZAgOmjTMd00_mjTMd00ol0003oT:OUoi2Wi@0=oi2Wi@03o`00
0?nQ^N[oXKWZ00CoXKWZ0ol0000;ojW9l003o`000?nafOGo/MWe00;o/MWe0ol00007okOYmP;o0000
1_nlmnl00ol0003o`o3`ol?`l002ol?`l004o`000?o3oLSo`og8o`0000;ofo_J00Co0000onWibOoY
nLWo00000_ogkjH2o`000003oogQV_l0003on=:S00?on=:S00?o0000ooG1U?oe`I@00_oe`I@01_l0
003ok;FHonbeV?l0003okZj9o`0000KohZ:=00?o0000omBET?l000000_l0000doookJP;o00002Omn
D902oeLcRP;o00001omE@Yh00ol0003oAT6Wo`000004oa4PWP;o000000?o01JTo`000?l000000_lj
F/P01ol0003o02beo`11a?l0@LCo>X;Xo`000?lfPnT00ol00003obZ2j@04o`000?l]Q>[o;HCZo`00
017oP[;c00?o0000ojo4jOn_a>T01on_a>T3o`0000[o[lG[00?o0000ol[>gOl000002Oo<dMh2o`00
00CocMCO00Co0000omKIfooFfM_o00001_oIg]/2o`0000;oin?=00Co0000onkUa?o^iLCo00000ooa
j<82o`000003ooO_[Ol0003om_2V00Co00003ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oo
nf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX04ooonfX01Ol0003o`T80o`000?oJI0So000000CoiWli
00?o0000onAn@?l000000ooXSed00ol0003oiHeQonF=H@03onF=H@;o00001ooSUGL01?l0003ogi9h
omnBN?oOTWP2o`0000;ogiZ600Go0000ombGQooLUhOog9N7o`000004omZDQP03o`000?oGTXOoei:7
00;oei:70_l0000@oookJP;o00002OoBaLh3o`0000coc;c<00?o0000olJgboo6]l/01oo6]l/01Ol0
003oe;NlomBg_?oD]kco000000Koc[2l0_l00005olj`^`03o`000?noXkco_j>l00_o_j>l00?o0000
olFU^Ol000004?o0Y;d00ol0003o/iJiok>F^@06ok>F^@03o`000?nbUK[o/YFj00[o/YFj0_l00009
okFL_P03o`000?nTRk_oY8^k01?oY8^k00Co0000oiR2^_nHP[[oV8:j1ol0000:oiZ<``03o`000?nF
S<OoUXc7017oUXc700Co0000oh^>dOn;S]7o00004On<Sm400ol0003oSZg[ohj]j`0Cohj]j`03o`00
0?nMaOCoWLGd00?o00004OnWd_L3o`0000?o[^3h00Go0000ol3cl?o0lo3o`??`o`000005olWbk@03
o`000?o=n>Sod_kK00;od_kK00Co0000okglb?l0003o0000J_oonfX00ol0003ooo]ZoookJP0=oook
JP03o`000?oonf[ooo]Z01gooo]Z000WoookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oo
nfX01?oonfX2o`0000;o02B[0_l000000olLA;ko0000odQUc@04odQUc@03o`000?mHN=OoF7SG00?o
00001omcR=T00ol0003oNY7MogZAg@02ogZAg@03o`000?n@YnGoT:OU00koT:OU00?o0000oj6ij_nQ
^NX00ol0000?ojW9l004o`000?nafOGo0000o`0000So]nWf0_l00007okcgk`04o`000?o3l?3o`o3`
ol?`l0;o00000_o3oLP01?l0003ofo_Jom_kf_l00003onWib@05o`000?ogkjKomnnVo`000?ohhk40
0_l00004ooSBX`03o`000?oe`IComL6D00;omL6D00Co0000onbeV?o/]ISok;FH0_l00006on:RS@03
o`000?oDUI3oe9F@00;oe9F@0ol0000_oookJP;o00002omnD902oeLcRP03o`000?mE@YkoED:N00Ko
ED:N00Co0000odI1Yom6@JOo00000olA89h00ol0003o32VZo`000002o`0000Co>U[800Go02beo`11
a?l0@LCo>X;Xo`000003ocJ3j@?o000000Go:X;Yo`000?l]Q>[o;HCZo`00000Aoh:bl`03o`000?n_
a>Wo[lCY00?o[lCY0ol0000>ojo5j`03o`000?o<dMkoc=7N00Ooc=7N00?o0000olgDgoo=e=l01?o=
e=l00ol0003oe]WKo`000006omWNf`04o`000?oLiM_og>GKo`0000;oin?=0_l00003oo7X`P06o`00
0?obkkoo0000ooO_[Ol0003om_2V0ol0000AoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oook
J_oonfX0AOoonfX00ol0003ooo]ZoookJP0DoookJP04o`000?o2@P3o0000omYT20;o00000_oVOcT0
0ol0003oi7i0onAn@002o`0000;oj8mM00?o0000onF=HOoUSF400ooUSF42o`0000KohiEg00?o0000
omnBN?oOTWP00ooOTWP3o`0000?og9N700?o0000omZDQ_oJU8H00_oJU8H00ol0003oei:7omNBQ`04
omNBQ`?o00002ooonfX2o`0000;o_/CO00?o0000om;5c_oBaLh00ooBaLh3o`000003om;5c_l0003o
000000_oc;c<00?o0000olJgboo6]l/02Oo6]l/00ol0003oe;Nlo`000009olj`_0?o000000?oc[2k
o`000?noXk`03OnoXk`2o`00013o`:Bm00?o0000ok>F^OncU[T01oncU[T00ol0003o/YFjok:E^P09
ok:E^P03o`000?neW;ko]Ibn00Wo]Ibn00?o0000ojB;^onTRk/04onTRk/4o`000004oiV:`_l0003o
0000o`0000goVXc300?o0000oiJ<aonFS<L04_nFS<L2o`0001?oS8oA00?o0000ohj]jon>[N/04On>
[N/01?l0003oSZg[o`000?l0000AojOBm`?o00001on^h?P00ol0003o`??`o`000005olWbk@03o`00
0?o=n>Sod_kK00;od_kK00Co0000okglb?l0003o0000K?oonfX00ol0003ooo]ZoookJP0<oookJP03
o`000?oonf[ooo]Z01gooo]Z000XoookJP;o0000B_oonfX00ol0003ooo]ZoookJP03oookJP;o0000
0ol09:/3o`0000GoB6G=00?o0000oeQheomHN=L00omHN=L4o`0000?oLhSI00?o0000ogZAgOmjTMd0
0omjTMd00ol0003oT:OUoi2Wi@0:oi2Wi@Ko00004OnYbO04o`0000Oo]nWf0_l00007okcgk`;o0000
0oo3l?001Ol0003o`og8ol?mb?o3oLSo000000;ofo_J00Co0000onWibOoYnLWojOW90_l000001?og
kjKo0000ooSS/Oohhk42o`0000Con=:S0_l00002ooG1U003o`000?o/]ISok;FH00?ok;FH0_l00005
on:RS@03o`000?oDUI3oe9F@00Goe9F@0ol0000XoookJPCo00003OmnD9000omG<h[o0000o`000007
oeE2WP03o`000?mQDj_o000000;oAT6W00?o0000oa4PW_l000000ol<:JX2o`0000Go>U[800Go0000
o`11a?l0@LCo>X;Xo`000005ocJ3j@?o00000_l]Q>X00ol0003oP[;coh:bl`0?oh:bl`03o`000?n_
a>Wo000000;o00003On_aN/3o`000003ojo7k?l0003oc=7N00Ooc=7N00?o0000olgDgoo=e=l01_o=
e=l00ol0003ofMkKomWNf`04omWNf`03o`000?oLiM_og>GK00;og>GK00?o0000onOScOl000000ooa
j<800ol0003ol^nooo;__`02o`0000;om_2V0ol0000AoookJP03o`000?oonf[ooo]Z023ooo]Z00?o
0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0EoookJPCo000000GoffHCo`000?oVOcWoiWli
o`000003onAn@003o`000?oXSego000000GoiHeQ00?o0000on::I?l000001OoSUGL00ol0003ogi9h
omnBN005omnBN0;o00000_oLUhL00ol0003ofYB6omZDQP02omZDQP03o`000?oGTXOoei:700Ooei:7
0_l00008oookJP03o`000?nna=oo_/CO00?o_/CO00?o0000om;5c_l000000_l00003om;5cP04o`00
0?o?`Lgocl7=o`0000Woc;c<00?o0000olJgboo6]l/02_o6]l/2o`0000goc[2l0ol0000<oknS_003
o`000?o0Y;go000000oo`:Bm00?o0000ok>F^OncU[T02OncU[T00ol0003o/YFjok:E^P06ok:E^P;o
00003OneW;h00ol0003oY8^kojB;^`0?ojB;^`?o000000?oYY6oo`000?l000000_l0000AoiZ<``03
o`000?nFS<OoUXc7013oUXc70_l0000Dohb?d@03o`000?n>[N_oSZg[00coSZg[1Ol00002oiRjk`03
o`000?nWd_OoYm;g00koYm;g0_l0000;ojkPn003o`000?o9l^gobO;]00CobO;]00Ko0000om;nfooB
o]_od_kKo`000?nmo<P2o`0006kooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0M
oookJP00:_oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z00;ooo]Z0_l00003o`0T
Z`;o6DS30_l00004odQUc@03o`000?mHN=OoF7SG00?oF7SG00Co0000og>8fOmcR=WoLhSI1ol00002
ogZAg@03o`000?n@YnGoT:OU00;oT:OU2?l00005oiVdj`03o`000?nYbO3oZLW`00coZLW`0ol00004
ok?Gl`;o00001?ngjOH00ol0003o_?O_okcgk`05okcgk`;o000000Go`no`o`000?o3l?3o`o3`o`00
0003ol?mb005o`000?oKnm[ofo_Jom_kf_l000000_oYnLT01Ol0003om_6ao`000?ogkjKo000000;o
n>>a00?o0000ooSBXoohdZ<00_ohdZ<01_l0003ol/BPoo;4X?l0003omL6Do`0000Gok;FH00?o0000
on6YV_l000000ooRXXd00ol0003oe9F@omBET006omBET003o`000?o6R9;oaXRB00Go00007OoonfX6
o`0000?oWfVC00?o0000ogi@T?mnD9002_mnD902o`0000;oI4NK00?o0000oeE2W_mE@Yh00omE@Yh0
1?l0003oHE>[of5CZol00003odI1Y`;o00001?l<:JX00ol0003o>U[8ocYJb004ocYJb004o`000?l0
@LCo0474o`0000So=X?Y1?l00009oh:bl`Wo00003_n_aN/2o`0000Go[lO/00?o0000olcAg_o<dMh0
0oo<dMh2o`0000OocMCO00?o0000oloHgol000001OoIg]/00ol0003og>GKomcUf`04omcUf`;o0000
0ooaj<800ol0003ol^nooo;__`02o`000003ooK`Y_l0003o000000;o00004_oonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX05_oonfX4o`000004om]V
4ol0003oiWlio`0000Coi7i00_l00005onF=H@03o`000?oRRVCohXYT00;o00000ooSUGL00ol0003o
gi9homnBN005omnBN004o`000?oLT7[o0000o`0000GofYB600?o0000omNBQooGTXL01ooGTXL00ol0
003oe8n8o`000002o`0000?ooo]Z0_l00005okk4g`?o00001OoBaLh00ol0003ocl7=olo1c@02olo1
c@;o00001_o<_<`00ol0003oa[O;olJgb`0:olJgb`03o`000?o1//co000000goc[2l00?o0000olRc
a_o8/lH01?l00007oknS_005o`000?o0Y;go`:Bmol2T_Ol000003Oo0Y;d00ol0003o/iJiok>F^@0:
ok>F^@03o`000?nbUK[o/YFj00Go/YFj00?o0000okFL__neW;h03OneW;h00ol0003oY8^kojB;^`0=
ojB;^`;o00000_nVTKl3o`0001CoVXc300?o0000oiJ<aonFS<L03onFS<L00ol0003oUYG@o`00000E
ohb?d@03o`000?n>[N_oSZg[00KoSZg[1Ol00008oiRjk`03o`000?nWd_OoYm;g00[oYm;g0ol0000;
ojkPn004o`000?nbk_Oo/^kgok;^m`;o00000_o9l^d01?l0003od_kKom;nfooBo]/4o`0006oooo]Z
00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0MoookJP00:ooonfX00ol0003ooo]Zoook
JP18oookJP07o`000?oonf[ooo]ZoookJ_l0003o001Qo`000002o`0TZ`04o`000?lIB<?o6DS3o`00
00?oB6G=00?o0000oeQheomHN=L01OmHN=L00ol0003oLhSIog>8f@02og>8f@03o`000?miS]coNHkL
00;oNHkL1ol0000>oiVdj`03o`000?nYbO3oZLW`00SoZLW`0ol00009ok?Gl`04o`000?ngjOKo0000
o`0000Ko_?O_0_l00002ol?_l004o`000?o3l?3o`o3`o`0000?o`og800Co0000om_kf_oKnm[ofo_J
0_l00002onWib@04o`000?oflK7o0000o`0000?on>>a00?o0000ooSBXoohdZ<00_ohdZ<01?l0003o
l/BPoo;4X?oba:02o`0000Gok;FH00?o0000on6YV_oQZIX00_l000000ooRXXgo0000omBET007omBE
T003o`000?o6R9;oaXRB00GoaXRB3?l0000<oookJPGo00002OnOJI<00ol0003oOU2@ogi@T007ogi@
T0?o000000?oQEfLo`000?mTAi/00_mTAi/01Ol0003oED:NoeE2W_mE@Yko000000?oHE>[00?o0000
odI1Yom6@JL00_m6@JL00ol0003o32VZo``YZP03o``YZP03o`000?ljF/So>U[800?o>U[800?o1d[8
o`000?l0@L@01?l00005ocJ3j@03o`000?lhQ>[o>8CZ00[o00002?n3/O<00ol0003o[lG[ojo5j`09
ojo5j`?o00002?n_an`01Ol0003oc=7NolcAg_o<dMko000000SocMCO00Go0000oloHgoo?f=oocmSO
o`000003omWNf`03o`000?oLiM_og>GK00Cog>GK00Ko0000omcTf_l0003o0000oo7X`_l00003oo;_
_`04o`000?ofl:Ko0000onoaVP;o00005?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[o
oo]Z04?ooo]Z00?o0000oookJ_oonfX05ooonfX4o`000003om]V4ol0003o000000Goi7i00_l00005
onF=H@04o`000?oRRVCohXYTon::I0;o000000?ohiEgo`000?oOTWP01_oOTWP00ol0003og91jomb@
NP03o`0000?ofYB600?o0000omNBQooGTXL01ooGTXL00ol0003oe8n8omB?R002omB?R0?o00001?nn
a=l3o`0000?o_/CO00Go0000om;5c_oBaLkod/G>o`000007olo1c@;o00000oo<_<`00ol0003oa[O;
olJgb`0:olJgb`05o`000?o1//co`K;<ol6bc?l000002oo>/;`00ol0003ob;?6olRcaP05olRcaPCo
00000_noXk`00ol0003o`:Bmol2T_@02ol2T_@03o`000?o0Y;go`:Bm00[o`:Bm00?o0000ok>F^Onc
U[T02oncU[T00ol0003o/YFjok:E^P04ok:E^P03o`000?neW;ko]Ibn00ko]Ibn00?o0000ojB;^onT
Rk/02onTRk/6o`0000;oYY?100?o0000oiZ<`onJS<<04onJS<<00ol0003oUXc7oiJ<a`0<oiJ<a`;o
00000onFUM000ol0003oS8oAohb?d@0Bohb?d@04o`000?n>[N_oSZg[ohj]j`Go00003_nH^^l00ol0
003oYm;gojOBm`07ojOBm`;o00002on^h?P2o`0000So/^kg2?l0001aoookJP03o`000?oonf[ooo]Z
00[ooo]Z00?o0000oookJ_oonfX07OoonfX002cooo]Z00?o0000oookJ_oonfX0B?oonfX01?l0003o
oo]ZoookJ_oonfX3o`000003o`0TZol0003o6DS300;o6DS30_l000000om8ILgo0000oeQhe`06oeQh
e`03o`000?mcR=WoLhSI00;oLhSI00?o0000ogV>g?miS]`01OmiS]`00ol0003oVKC[oiVdj`0@oiVd
j`03o`000?nYbO3oZLW`00CoZLW`0ol0000<ok?Gl`?o00001_nlmnl01_l0003o`no`ol?_l?o3ko3o
0000ol?`l0;o00001?o3oLP3om_kfP05o`000?oWn<oo0000onWibOl000000_oflK42o`0000;on>>a
00?o0000ooCC[?l000000oohdZ<00ol0003ol/BPoo;4X002oo;4X003o`000?o/]ISok;FH00;ok;FH
00?o0000on6YV_oQZIX00ooQZIX2o`0000Soe9F@00?o0000olJ8T_o6R9801_o6R9800ol0003o`HFB
o`000008okQlT@co00003_nOJI<00ol0003oOU2@ogi@T005ogi@T0;o00001?n5GI`00ol0003oI4NK
ofA7V`02ofA7V`03o`000?mE@Yko000000GoHE>[1?m6@JL00ol0003o32VZo``YZP03o``YZP;oFFW8
1?ljF/P01Ol0003o1d[8o`11a?l0@LCo000000;oEXWV1?l00002ocJ3j@04o`000?lhQ>[o>8CZo`00
017oPk7c00?o0000ojo5jon_aN/01_n_aN/2o`0000co[lO/00?o0000olcAg_l000002?o=e=l00ol0
003ocmSOoloHg`02oloHg`04o`000?oIg]_ofMkKo`0000Kog>GK00Go0000omcTf_oLi=[o0000onO^
d@03o`000004oo;__ol0003o0000ooK`YPCo00005?oonfX00ol0003ooo]ZoookJP0PoookJP03o`00
0?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX06?oonfX2o`000003olQ90?l0003offHC00;o0000
1?oTOT000ol0003ohWe6o`000004onF=H@03o`000?oRRVCohXYT00?ohXYT0_l00007omnBN004o`00
0?oLT7[og91jo`0000;ofXah1?l00009omNBQ`03o`000?oDShSoe8n800;oe8n800Co0000okk4gonn
a=oo_/CO0ol00007okk4g`03o`000?oBaLko000000[ocl7=00?o0000olblc?l000003?o6]l/00ol0
003o`K;<ol6bc003ol6bc003o`000?o>/;coc[2l00Ooc[2l00?o0000olRca_o8/lH02_o8/lH4o`00
00Co`:Bm00?o0000ol2T_Oo0Y;d02?o0Y;d00ol0003o/iJiok>F^@0=ok>F^@04o`000?nbUK[o/YFj
ok:E^P;o00004_neW;h00ol0003oY8^kojB;^`07ojB;^`Go00001onVTl400ol0003oVXc3oiZ<``0B
oiZ<``03o`000?nFS<OoUXc700_oUXc700?o0000oiJEd?nFUM001?nFUM000ol0003oS8oAohb?d@0=
ohb?d@So00005?nH^^l00ol0003oYm;gojOBm`03ojOBm`?o00002on^h?P2o`0000So/^kg00Go0000
ok;gkol0003o^ocTo`000002ol?mh@;o0000LooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z01gooo]Z000]oookJP03o`000?oonf[ooo]Z04Sooo]Z0_l000000ooonf[o0000o`000002
o`000006o`0TZol0003o6DS3oaU8`ol0003oAFG>0_l00008oeQhe`04o`000?mcR=WoLhSIo`0000Wo
NHkL00?o0000oiVdjonI]>/04?nI]>/00ol0003oZLW`ojW9l003o`0000go/mOc0_l00003okcUl`?o
000000?o_?O_o`000?l000000oo3ko000ol0003o`o3`o`000005ol?mb006o`000?oKnm[ofo_Jo`00
0?oWn<oo00000_oYnLT01Ol0003om_6aooKa/Ol0003on>>a00Go00000_ohdZ<00ol0003ol/BPoo;4
X003oo;4X0;o00000oo/]IP00ol0003ohJVJon6YVP04on6YVP?o00001_oDUI000ol0003oaXRBolJ8
TP06olJ8TP03o`000?o1QI;o000000ko^7bA00Co0000ok9gTonbMi?o00004?nOJI<00ol0003oOU2@
ogi@T003ogi@T0;o00001_n5GI`00ol0003oI4NKofA7V`03ofA7V`03o`000?mQDj_oHE>[00CoHE>[
0om6@JL00ol0003oIebbo`000004o``YZP03o`000?mIJLSoFFW800?o>U[800?o0000o`M:b?l7B/P0
0_l0@L@00ol0003oEXWVoeJ9iP03oeJ9iP;o000000Go=X?Yo`000?lhQ>[o>8CZo`00000Aoh>al`03
o`000?n_aN_o[lG[00?o[lG[0_l0000?ojo7k003o`000?o=e=oocMCO00GocMCO0_l00005oloHg`03
o`000?oIg]_o000000Kog>GK00Oo0000omcTf_oLi=[og>CJo`000?oWk]7o000000;oj_C=1Ol00000
0ooYn:_o0000o`00000EoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0@_oonfX0
0ol0003ooo]ZoookJP0IoookJP;o000000?ob4T0o`000?l000000_l00004onAn@004o`000?oRODKo
0000o`0000;oiHeQ00?o0000on::I?oRRV@01?oRRV@2o`0000Oogi9h0_l00006omZ<N0;o00002?oG
TXL00ol0003oe8n8omB?R002o`000004okk4gol0003o0000o`0000_o_/CO00?o0000olo1cOo?`Ld0
2_o?`Ld00oo<_<co0000olJgb`0:olJgb`03o`000?o1//co`K;<00Co`K;<00?o0000olj`_?o>/;`0
1_o>/;`00ol0003ob;?6olRcaP0;olRcaP04o`000?njXl7o^Z?1okZS`@Go00002Oo0Y;d00ol0003o
/iJiok>F^@0>ok>F^@04o`000?nbUK[o/YFjo`0001Co]Ibn00?o0000ojB;^onTRk/01?nTRk/4o`00
00_oYY?100?o0000oiZ<`onJS<<04_nJS<<00ol0003oUXc7oiJ<a`09oiJ<a`;o00001onFUM000ol0
003oS8oAohb?d@03ohb?d@[o00001OnCZ>@00ol0003oV;[_oiRjk`0EoiRjk`03o`000?nWd_Oo0000
00;o00003?n^h?P2o`0000Oo/^kg0_l00002ok;gk`03o`000?nko>Co000000;o`ogQ00?o0000oook
J_oonfX0LooonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z01gooo]Z000^oookJP03
o`000?oonf[ooo]Z04Wooo]Z1?l000000ol0:;3o0000o`000003oaU8``04o`000?m5ILko0000o`00
00OoF7SG00Co0000og>8fOmcR=Wo00002_miS]`00ol0003oVKC[oiVdj`0>oiVdj`Co00003Onceo<3
o`0000Oo_>Gc1?l00002ol?_l003o`000?o3l?3o000000Go`og800[o0000om_kf_oKnm[ofo_Jo`00
0?oWn<oo0000onWibOl0003om_6a1?l00002ooC[_003o`000?o`g[kol=jn00Co00000ooba:001?l0
003ojKVQonViXOl00002onbeV003o`000?oQZI[ohJVJ00CohJVJ00?o0000omFMVooEWI/00ol00003
omBET003o`000?o6R9;oaXRB00KoaXRB00?o0000ol65T_l000003_nhO9401?l0003o/WNCok9gTol0
000@oimYT`03o`000?mnD93oOU2@00?o00002?n5GI`00ol0003oI4NKofA7V`02ofA7V`;o00001_mQ
Dj/00ol0003oAT6Wo`000003ofML/P05o`000?l<:J[o32VZo``YZ_l000000omIJLP2ocYJb006o`00
0?l7B/So1d[8o`M:b?l0@LCo00002?mFRNH3o`000003ocR4j_l0003oPk7c013oPk7c00?o0000ojo5
jol000000_l0000=ojo7k0?o00000_nabnd00ol0003ocMCOolgDg`03olgDg`03o`000?o?f=oocmSO
00KocmSO00?o0000omcUfooLiM/01?oLiM/00ol0003og>CJomcTfP02omcTfP;o00000ooZm<d01?l0
003oj_K<o`000?l00002onWhZ`03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX07ooonfX0
0ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z01[ooo]Z0_l00002olQ90003o`000?oKJ1ko
000000?oi7i000Co0000on9mA_oRODKohWe60ol00006on::I004o`000?oOR6Oo0000o`0000Gogi9h
0_l00006omZ<N004o`000?oGRW[o0000o`0000Koei:71_l0000<okk4g`04o`000?nm`Mgo_L7Mo`00
00Wocl7=00Go0000ol^lc?o;_<cobkc<o`000009olJgb`03o`000?o1//co`K;<00Ko`K;<00?o0000
olj`_?o>/;`01?o>/;`00ol0003ob;?6olRcaP0;olRcaP03o`000?njXl7o^Z?100Ko^Z?11_l00003
ol2T_@03o`000?ncU[Wo/iJi00oo/iJi00?o0000ok:E^_l000005OneW;h00ol0003oY8^kojB;^`05
o`0000koYY?100?o0000oiZ<`onJS<<04onJS<<00ol0003oUXc7oiJ<a`07oiJ<a`03o`000?nFUM3o
UYG@00KoUYG@1ol0000@oi>Xi003o`000?nH^^ooV;[_01GoV;[_00?o0000ojkPn?n^h?P02on^h?P2
o`0000So/^kg00Co0000ok;gkonbmnoo/_O_0ol00002ol?mh@03o`000?oonf[ooo]Z07Gooo]Z00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0LoookJP00;ooonfX2o`0004[ooo]Z0ol00002
o`0X/0;o00000_lIB<<01?l0003oAFG>o`000?mLP=d3o`0000GoF7SG00?o0000og>8fOl000002omi
S]`00ol0003oVKC[oiVdj`09oiVdj`Co00000onS`^l00ol0003o/mOcok?Gl`09ok?Gl`;o00002?nl
iO<2o`0000Coa_3_0_l000000oo3l?3o0000ol?mb004ol?mb004om[jgOl0003ofo_Jom_kfPOo0000
0_oVn/d01?l0003om>^looC[_?l00004oo3N_P03o`000?o]bk7okL^a00;o000000?ol/BPo`000?oY
^J400_oY^J42o`0000OohJVJ00?o0000omFMVooEWI/00ooEWI/4o`0000SoaXRB0_l0000?okQlT@04
o`000?nbMi?o/WNCo`00013oWfVC0ol0000<ohEMW0?oI4NK00Co0000ofaDYOm/E:Go00001_mQDj/0
0om6@JOo0000ofML/P03ofML/P05o`000?l<:J[o0000oaTh/ol000000omIJLP00oljF/So0000o`M:
b003o`M:b003o`11a?l0003oEXWV00OoEXWV00?o0000odJ6j?l000000_l00009oh>al`Ko00000_n3
/O<00ol0003o[lO/ojo7k00<ojo7k0;o00001_nabnd01Ol0003ocMCOolgDgoo=e=oo000000OocmSO
00?o0000om;Lh?l000001OoLiM/00ol0003og>CJomcTfP03omcTfP05o`000?oZm<goj_C=on[dcOl0
00000_oZm/`2o`000003onWhZol0003o000001Oooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003o
oo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01cooo]Z0ol000000oo8B@3o0000o`000002o`0000;o
i7i000?o0000on9mA_oRODH00_oRODH2o`0000GohXYT00Co0000omn8IooOR6OoghQW0_l00003omnB
N003o`000?oJS7SofXah00GofXah00Co0000omN:N_oGRW[oehYj0_l00004omNBQ`?o00003Onna=l0
0ol0003o_L7Mokg1g@03okg1g@03o`000?o?`Lgocl7=00Gocl7=00?o0000ol^lc?o;_<`00oo;_<`2
o`0000Koa[O;00?o0000ol6bc?o1//`02?o1//`00ol0003oc[2lolj`_002olj`_003o`000?o8/lKo
b;?600_ob;?600?o0000okZS`OnjXl402?njXl400ol0003o_jFnoknU_P02oknU_PSo00003_ncU[T0
0ol0003o]IbnokFL_P0?okFL_P[o00004_nVTl400ol0003oVXc3oiZ<``0BoiZ<``03o`000?nFS<Oo
UXc700GoUXc70_l00004oiJEd0Go00000_nFU]400ol0003oTjSToi>Xi00Coi>Xi003o`000?nH^^oo
V;[_00ooV;[_0ol00003oj79m003o`000?n^h?So[^3h00So[^3h0_l00008ok;^m`;o00000onbmnl2
o`0000?o`ogQ00?o0000oookJ_oonfX0MooonfX00ol0003ooo]ZoookJP08oookJP03o`000?oonf[o
oo]Z01cooo]Z000aoookJP03o`000?oonf[ooo]Z04Sooo]Z0ol000001?l0:;3o0000oaA:a_l00002
oaU8``;o00001?mLP=d3o`0000;oF7SG0_l0000<ogV>g003o`000?nI]>_oVKC[00GoVKC[1?l00008
oj?2k`03o`000?nceo?o/mOc00Ko/mOc0_l00009okcUl`03o`000?o6l>ooa_3_00Goa_3_3Ol00002
omWmf@03o`000?oVn/goi_[=00;oi_[=0_l00002ooC[_003o`000?o`g[kol=jn00;ol=jn00?o0000
ong;/Oo]bk400_o]bk400ol0003ojKVQonViX@03onViX@;o00001_oQZIX00ol0003oeIfKomFMV`06
omFMV`?o00001_o6R982o`0000ko^7bA00Go0000ok9gTonbMi?o/WNCo`00000=oimYT`Co00003_n5
GI`2ofA7V`03o`000?m/E:GoK5BU00;oK5BU00?o0000of5CZomQDj/00omQDj/00ol0003oIebbofML
/P04ofML/P;o00000_lI>;<4oeUYb0;o00001?l7B/P3o`0000OoEXWV00Co0000odJ6j?m6Q^SoAXKX
2Ol00008ohBalP03o`000?n_anco[lO/00Wo[lO/0ol00009ok7;k@03o`000?o=e=oo000000OocmSO
00Co0000om;Lh?oBg>3o00001?oLiM/00ol0003og>CJomcTfP03omcTfP;o00000_oZm<d01Ol0003o
j_K<on[fc?oZm/co000000;ojOR[00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0Ooook
JP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX07OoonfX4o`000003ol]<0?l0003o0000
00?o00001OoRODH2o`0000GohXYT00?o0000omn8IooOR6L00_oOR6L2o`000003omnBN?l0003ofXah
00KofXah00?o0000omN:N_oGRWX00ooGRWX4o`0000ko_/CO0_l00007okg1g@03o`000?o?`Lgocl7=
00?ocl7=00?o0000ol^lc?o;_<`01_o;_<`2o`0000?oa[O;00?o0000ol6bc?o1//`02Oo1//`01Ol0
003oc[2lolj`_?o>/;co000000gob;?600?o0000okZS`OnjXl402_njXl401Ol0003o_jFnoknU__no
YKko000000Oo^Y^i2Ol00004ok>F^@;o00001OneW;h<o`0000Go/9[10_l0000EojJC`@03o`000?nJ
S<?oVXc301;oVXc300?o0000oiJ<aonFS<L01?nFS<L00ol0003oUYG@o`000004o`0000SoUYKA00?o
0000oi>Xi?nCZ>@04_nCZ>@00ol0003oV;[_oiRjk`0<oiRjk`?o00001onQbO@00ol0003o[^3hojkP
n005ojkPn0;o00002?nbk_L2o`0000Co/_O_0_l00003ol?mh@03o`000?oonf[ooo]Z07Wooo]Z00?o
0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0LoookJP00<_oonfX00ol0003ooo]ZoookJP17
oookJP?o000000Ko02R`o`000?lDB/Ko54[6o`000?lIB<<2o`0000OoG83M1?l0000=ogV>g003o`00
0?nI]>_oVKC[00Co00003OnS`^l00ol0003o/mOcok?Gl`02ok?Gl`?o00002OnliO<2o`0000Koa_3_
0_l00004ol7hk@07o`000?o=o>CocOcTolgli?l0003ofo_Jo`000004omWmf@05o`000?oVn/goi_[=
onKjcOl000000_o]k/P2o`0000Col=jn00?o0000onS:^?l000000oo]bk400ol0003ojKVQonViX@03
onViX@04o`000?oP/:Go0000o`0000?ohJVJ00?o0000omFMVooEWI/01ooEWI/00ol0003o`8^Mol2;
W@05o`000003olJ8T_l0003o000000ko^7bA00Go0000ok9gTonbMi?o/WNCo`000007oimYT`Ko0000
0onRLih00ol0003oQEfLohEMW00<ohEMW003ofA7Vol0003oK5BU00GoK5BU00Co0000of5CZomQDj_o
HE>[0_l00007ofML/P04o`000?lI>;?o6CRco`0000?oFFW80_ldGll01?l0003o1d[8o`M:b?l7B/P2
o`000004ofV=hol0003o0000o`0000CoEXWV00Go0000odJ6j?m6Q^SoAXKXo`00000AohBalP03o`00
0?n_anco[lO/00Ko[lO/0_l0000=ok7;k@03o`000?o?f=oocmSO00CocmSO0_l00003om;Lh005o`00
0?oLiM_og>GKomcUfol000001OoLi=X01Ol0003ognWJo`000?oZm<go000000Coj_K<00Co0000onWh
Zol0003o00006_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000
oookJ_oonfX07ooonfX3o`0000?obd`00_l00005on9mAP04o`000?oOODgo0000o`0000?ohXYT00?o
0000omn8IooOR6L00ooOR6L4o`0000KofXah00Co0000omN:N_oGRW[oehYj1?l0000>okk4g`;o0000
2_nm`Md01Ol0003ocl7=olo1cOo?`Lgo000000_obkc<00?o0000olJgbol000003Oo1//`00ol0003o
c[2lo`00000=olRcaP03o`000?njXl7o^Z?100_o^Z?100Co0000oknU__noYKko00004OnjVkT;o`00
013o/9[100?o0000ojjObOl000005_nVTl400ol0003oVXc3oiZ<``0@oiZ<``[o00003OnFU]400ol0
003oTjSToi>Xi00Coi>Xi003o`000?nH^^ooV;[_00OoV;[_1?l0000;oj79m003o`000?n^h?So[^3h
00;o[^3h0_l00008ok;^m`;o00001Onbmnl2o`0000?o`ogQ00?o0000oookJ_oonfX0N_oonfX00ol0
003ooo]ZoookJP07oookJP03o`000?oonf[ooo]Z01cooo]Z000coookJP03o`000?oonf[ooo]Z04Oo
oo]Z0_l000000ol0:;3o0000oaA:aP02oaA:aP03o`000?lIB<?o000000[oG83M4Ol0000Boj?2k`04
o`000?nceo?o0000o`0000[o_>Gc0_l00007olK`k`03o`000?oAm>Oo000000?o`OS]00?o0000olgl
i?o=o>@00_o=o>@2o`0000CofOgI0_l00002onKjc@04o`000?o]k/SokNk8ong^b0;o00001?o`g[h0
1?l0003oj<ZhonS:^?l00002ong;/@;o00001?oY^J401Ol0003oh;2Uon2`YOoP/:Go000000;ohJVJ
00?o0000omFMVooEWI/01_oEWI/00ol0003o`8^Mol2;W@06ol2;W@_o00001_nhO9401Ol0003o/WNC
ok9gTonbMi?o000000;oWfVC1Ol00009oj9cWP03o`000?n5GIcoQEfL00_oQEfL0_l00008ofaDY@05
o`000?mQDj_o0000ofQM/_l000001omWG;801?mCI<Ko0000oaTh/ol00003oeUYb003o`000?ldGloo
=5o?00;o00000_l7B/P2o`0000?oJHgS0_l00003oeJ9iP05o`000?m6Q^SoAXKXodJ6j?l000004On4
/O800ol0003o[lO/ojo7k003ojo7k0;o00003?nabnd2o`000003okC?kOl0003ocmSO00CocmSO00?o
0000om;Lh?oBg>001?oBg>000ol0003og>GKo`000005omcTfP06o`000?oOjM[ognWJo`000?oZm<go
00001?oZm/`00ol0003ojOR[o`00000LoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX0?OoonfX00ol0003ooo]ZoookJP0PoookJP?o00001?o;C003o`0000;ohWe600Go0000ommmCOoO
ODgogge=o`000002on::I004o`000?oOR6OoghQWomn8I`;o00000_oLPV801?l0003ofH5Vo`000?l0
0005omZ<N0?o000000?oehYjo`000?nna=l03Onna=l2o`0000go_L7M00?o0000olo1cOl000003Oo;
_<`2o`0000go`K;<0_l0000=olRcaP03o`000?njXl7o^Z?100co^Z?100?o0000oknU__l000004onj
VkT01Ol0003o]jS;okNXbongZ<_o000001?o/9[10_l00003ojjOb@03o`000?nVTl7oYY?101?oYY?1
00?o0000oiZ<`onJS<<03?nJS<<4o`0000;oWYK<00Co0000oiJEd?l0003o00004_nFU]400ol0003o
TjSToi>Xi00Boi>Xi003o`000?nH^^ooV;[_00CoV;[_0ol0000@oj79m004o`000?n^h?So0000o`00
00So/^kg0_l00006ok;gk`04o`000?o3oN7o`ogQol?mh@;o0000O_oonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z01cooo]Z000doookJP03o`000?oonf[ooo]Z04Kooo]Z0_l00002o`0X
/004o`000?lDB/Ko54[6oaA:aP;o00002_mLP=d00ol0003oRJWZohVYjP0<ohVYjP03o`000?nS`^oo
Xl;_013oXl;_1?l00009okcUl`;o00001oo6l>l2o`000003om7diol0003o`OS]00;o`OS]00?o0000
olgli?o=o>@00_o=o>@2o`0000CofOgI00?o0000onWUc?l000000_oVn/d01Ol0003okNk8ong^b?o]
k/So000000Col=jn00?o0000onS:^?oXb[P00_oXb[P2o`0000;oh[^_00Go0000onViXOoY^J7ojKVQ
o`000004on2`Y@?o00002?oEWI/00ol0003o`8^Mol2;W@07ol2;W@;o00002?njQil=o`0000koXW>N
00?o0000ohEMW?n5GI`02?n5GI`3o`000003oheXXol0003oK5BU00OoK5BU0ol00002ofQM/P03o`00
0?mWG;;oIebb00?oIebb00Go0000oe=Ta_mCI<Ko0000oaTh/`03oeUYb003o`000?ldGloo=5o?00;o
=5o?00Co0000o`M:b?l0003o00001_mYSN<00ol0003oEXWVo`000004odJ6j003o`000?n4/O;oQ;7b
00ooQ;7b00?o0000ojo7k?l000000_l0000<ok7;k@;o00001?ndcnd01Ol0003ocmSOoloHgoo?f=oo
000000Ood]cP0_l00005omcTfP04o`000?oOjM[ognWJomoYfP;o00001?oZm/`01?l0003ojOR[o`00
0?l0000LoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]Z
oookJP0QoookJP?o00000oo;C0000ol0003ocU88o`000004o`0000?ogge=0_l000001?oRRVCo0000
o`000?l00004omb2HP04o`000?oIPFKofH5VomV1IPWo00003_nna=l00ol0003o_L7Mokg1g@0>okg1
g@03o`000?o;_<cobkc<00[obkc<00Co0000olJgc?o6]lcoa[O<0ol00009ol6bc003o`000?o0/L_o
000000cob;?600?o0000okZS`OnjXl403OnjXl42o`0001?o^Y^i00?o0000okNXbongZ</00ongZ</0
0ol0003o/9[1ok2J`@0?ok2J`@03o`000?n^WlWo[Yo900?o[Yo900?o0000ojJC`OnVTl405?nVTl40
0ol0003oVXc3oiZ<``07oiZ<``Co00001_nNU/`2o`0001CoUYKA00?o0000oi>Xi?nCZ>@04onCZ>@0
0ol0003oV;[_oiRjk`03o`0001CoXLWd00?o0000ok;^monbk_L01onbk_L00ol0003o/_O_ok;gk`05
ok;gk`06o`000?o3oN7o`ogQol?mhOnSm<Co0000P?oonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z01cooo]Z000eoookJP;o0000A_oonfX3o`000003o`0X/?l0003o54[600?o54[60_l0
0009oeb0g@;o00003_n9ZNX00ol0003oXl;_oj?2k`0<oj?2k`?o00001?n]c_400ol0003o_>GcokcU
l`04okcUl`;o00002?o6l>l01_l0003odOCWom7diooAm>Oo0000ol7hk@;o00001Oo=o>@00ol0003o
fOgIomWmf@02omWmf@06o`000?oYiLcojNG<o`000?oVn/go00001?o]k/P01Ol0003ol=jnoo3N__o`
g[ko000000Koj<Zh0_l00002on:k[`03o`000?oY^J7o000000Ooh;2U0_l00007omFMV`03o`000?o0
Rigo`8^M00Oo`8^M00?o0000okZ7WonjQil03OnjQil01Ol0003o/gnLok=oW?ncOico0000013oXW>N
00?o0000ohEMW?n5GI`01_n5GI`2o`0000CoSFRS00?o0000ofaDYOm/E:D01Om/E:D01?l0003oOfJ/
ogmV[?moIZ`3o`0000GoIebb00Co0000oe=Ta_mCI<KoDfC60_l000000omIJLSo0000ocAOc`06ocAO
c`03o`000?l@D/go000000SoJHgS1?l000000om6Q^So0000ohBalP08ohBalPKo00000_n4/O800ol0
003o/L_]ok7;k@0;ok7;k@;o00001ondcnd00ol0003ocmSOo`000008om;Lh003o`000?oLi=[og>CJ
00?og>CJ00?o0000omoYf_oOjMX00_oOjMX00ol0003oj_K<on[fc002on[fc0Co00007_oonfX00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX08_oonfX00ol0
003o03F]o`000002o`000003ol]<0?l0003ocU8800;o000000?ogG4ho`000?l000001ol00006omb2
HP03o`000?oIPFKo000000Ko00001?nL__000ol0003o_/COokk4g`08okk4g`;o00003onm`Md00ol0
003o^[kMo`00000;ol^lc003o`000?o6]lcoa[O<00Goa[O<0_l00005ol6bc0;o00000oo0/L/00ol0
003ob;?6olRcaP08olRcaP03o`000?njXl7o^Z?100go^Z?100?o0000okJTa_l000004OnjVkT2o`00
00Ko]jS;00?o0000ok2J`On`V/403On`V/400ol0003o[Yo9ojjOb@06ojjOb@03o`000?nVTl7oYY?1
01?oYY?100?o0000oiZ<`onJS<<01?nJS<<3o`0000OoWYK<0ol000000onNUlgo0000oiJFd@0DoiJF
d@03o`000?nCZ>CoTjST017oTjST00Co0000oi>Xi?l0003o00004onQbO@3o`0000?oYmWi0_l00004
ok;^m`;o00001onbmnl01_l0003o`ogQol?mhOl0003oXoC4o`00087ooo]Z00?o0000oookJ_oonfX0
1OoonfX00ol0003ooo]ZoookJP0LoookJP00=ooonfX00ol0003ooo]ZoookJP14oookJPCo00001?lD
B/H00oldI]Go0000oeb0g@08oeb0g@03o`000?mYS>;o000000koRJWZ00?o0000oj?2konS`^l02?nS
`^l3o`0000So[Lka00?o0000okcUlonliO<00_nliO<00ol0003oa_3_olK`k`06olK`k`;o00000ooA
m>L00ol0003o`OS]o`000006olgli0;o00000ooIoMT01?l0003ojNG<onWUc?oYiL`2o`0000CokNk8
00?o0000on_D__l000000_o`g[h00ol0003oj<ZhonS:^004onS:^007o`000?oQ_[Go0000on:k[ol0
003ojKVQo`000007on2`Y@04o`000?oGYJ?o0000o`0000CoeIfK00?o0000ol2;WOo0Rid02?o0Rid0
0ol0003o^XNOokZ7W`0<okZ7W`03o`000?ncOico/gnL00;o/gnL00?o0000oj9cW_nRLih03onRLih0
0ol0003oQEfLohEMW003ohEMW0;o00001on=J:<00ol0003oK5BUofaDY@03ofaDY@03o`000?moIZco
OfJ/00CoOfJ/00?o0000ofML/_mWG;800_mWG;800ol0003oDfC6oe=TaP03oe=TaP03o`000?mIJLSo
000000So=5o?0ol00007ofV=h`04o`000?mGR^KoEh[VoeN:iP_o00002?n8/o800ol0003o/L_]ok7;
k@08ok7;k@?o00002_ndcnd00ol0003od]cPom;Lh005om;Lh003o`000?oEh=oo000000Cog>CJ00?o
0000omoYf_oOjMX00ooOjMX02Ol0003oj_K<on[fc?oZm/co0000on[ia_l0003oh?BKo`00000Ooook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0Soook
JP?o000000?o;Xg^o`000?l000001Ol00006om]a?P04o`000?oILTOo0000o`0000?og89R1Ol0000:
oibnl0;o00001_nna=l2o`0000oo_L7M00?o0000okZngOnj_]d00_nj_]d00ol0003obkc<ol^lc007
ol^lc003o`000?o6]lcoa[O<00Soa[O<0ol000000oo1//co0000ol2ab`05ol2ab`03o`000?o8/lKo
b;?600Kob;?600?o0000okZS`OnjXl403OnjXl401Ol0003o]ZC6okJTa_nfY<Ko000000oo^Y^i00?o
0000okNXbongZ</01ongZ</00ol0003o/9[1ok2J`@0;ok2J`@03o`000?n^WlWo[Yo900Oo[Yo900?o
0000ojJC`OnVTl404onVTl400ol0003oVXc3oiZ<``04o`0000SoWYK<0_l00005oijGc@03o`000?nF
U]7oUYKA01;oUYKA00?o0000oi>Xi?nCZ>@03?nCZ>@5o`0000;oVkO[00?o0000oj79m?nQbO@03onQ
bO@3o`0000SoYmWi00Co0000ok;^mol0003o00001onbmnl2o`0000;o`ogQ00?o0000oj?da?l00000
PooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01cooo]Z000hoookJP03o`000?oo
nf[ooo]Z04?ooo]Z1Ol00003oaA:aP03o`000?ldI]Go000000;o00001_mLP=d01?l0003oJHcRofV<
h_l0000>ohVYjP03o`000?nS`^ooXl;_00CoXl;_0ol0000<ojg>l@04o`000?nliO?o0000o`0000Oo
a_3_0_l00005om7di`;o00001_o=o>@00ol0003ofn;Ko`000002omWmf@03o`000?oYiLcojNG<00;o
jNG<00?o0000ong^b?o]k/P00_o]k/P01_l0003ojmBnon_D__l0003ol=jno`0000Koj<Zh00Ko0000
on6n]OoQ_[GohKjeo`000?oR^jl2o`0000Koh;2U00?o0000omNUXooGYJ<00_oGYJ<01Ol0003oeIfK
omFMVooEWI_o000000[o`8^M00?o0000okZ7WonjQil03?njQil00ol0003o/gnLok=oW002ok=oW003
o`000?nRLikoXW>N00ooXW>N00?o0000ohEMW?n5GI`00ol00009oheXX`03o`000?m/E:GoK5BU00;o
K5BU00?o0000ogmV[?moIZ`01OmoIZ`2o`0000;oIebb00?o0000oe=Ta_mCI<H01OmCI<H3o`0000Oo
=5o?00?o0000ocYTdOl000002?mYSN<00ol0003oEh[VoeN:iP02oeN:iP03o`000?n8/o;oR;?b00oo
R;?b00?o0000ok7;kOnabnd01Onabnd2o`0000_o]<o]00Co0000okSDk_nhe>ko00001OoBg>001?l0
003oeN3OomGPgol00003omcTfP03o`000?oOjM[ognWJ00?ognWJ0_l00002on[fc003o`000?oZnLKo
000000?o00007ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000
oookJ_oonfX09OoonfX2o`000003obj=k_l0003oCioe00;oCioe1ol00002om]a?P03o`000?oILTOo
000000Co00004?nL__000ol0003o_/COokk4g`02okk4g`03o`000?nm`Mgo_L7M00go_L7M0_l00006
okZng@03o`000?o;_<cobkc<00Gobkc<00?o0000olJgc?o6]l`03?o6]l`3o`0000Ko`;7;00?o0000
olRca_o8/lH01?o8/lH00ol0003o^Z?1okZS`@0=okZS`@03o`000?nfY<Ko]ZC600;o]ZC600?o0000
okZK^OnjVkT03?njVkT00ol0003o]jS;okNXb`08okNXb`03o`000?n`V/7o/9[100Wo/9[100?o0000
ojjObOn^WlT02_n^WlT00ol0003oYY?1ojJC`@0CojJC`@;o00002OnNU/`3o`0000OoWYO=00?o0000
oiJFdOnFU]404onFU]400ol0003oTjSToi>Xi006oi>Xi0Go00002?nK]n/00ol0003oXLWdoj79m00;
oj79m0?o00003?nWfOT00ol0003o/_O_ok;gk`05ok;gk`?o000000Go`ogQo`000?l0003oXoC4o`00
0025oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX06ooonfX003Wooo]Z00?o0000
oookJ_oonfX0@ooonfX3o`000007oaE@bol0003o54[6oaA:a_l0003o=6KEo`000002oeiof`Go0000
00GoG83Mo`000?mYS>;oJHcRo`00000?ohVYjP03o`000?nS`^ooXl;_00?o00003on]c_43o`0000Oo
a_3_00?o0000om7diooAm>L01OoAm>L00ol0003ocOcTolgli004olgli006o`000?oKh]_ofn;Ko`00
0?oIoMWo00001OoYiL`00ol0003okNk8ong^b002ong^b006o`000?o[e;kojmBno`000?o`g[ko0000
1_oXb[P00ol0003ohKjeon6n]@02on6n]@03o`000?oR^joo000000Koh;2U00?o0000omNUXooGYJ<0
0ooGYJ<2o`000003omFMVol0003o`8^M00Wo`8^M00?o0000okZ7WonjQil03?njQil00ol0003o/gnL
ok=oW002ok=oW003o`000?nRLikoXW>N00ooXW>N0ol0000<oheXX`05o`000?m/E:GoK5BUofaDYOl0
00002?moIZ`01Ol0003oHebeo`000?mWG;;o000000SoDfC60_m`N</2o`0000Go=5o?00?o0000ocYT
dOljI=400ol00005ofV=h`03o`000?mGR^KoEh[V00?oEh[V00?o0000ohRcl_n8/o803on8/o800ol0
003o/L_]ok7;k@02ok7;k@;o00002ondcnd00ol0003o^=C^okSDkP03okSDkP05o`000?oBg>3od]cP
om;Lh?l000001?oEh=l00ol0003og>CJo`000005omoYfP05o`000?oTkMKo0000on[fc?l000000_oZ
nLH00ol0003oh?BKo`00000QoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0>Ooo
nfX00ol0003ooo]ZoookJP0WoookJP;o000000?o;Xg^o`000?m?WoD02?m?WoD5o`0001GoW;k`00Co
0000okk4gol0003o00003_nm`Md2o`0000Wo^[kM00?o0000ol^lc?o;_<`00oo;_<`00ol0003oa[O<
olJgc00;olJgc003o`000?o0/L_o`;7;00;o`;7;1?l00002ol2ab`03o`000?o8/lKob;?600?ob;?6
00?o0000okZS`OnjXl403OnjXl400ol0003o]ZC6okJTaP04okJTaP03o`000?njVkWo^Y^i00Wo^Y^i
0_l0000<okNXb`03o`000?n`V/7o/9[100Oo/9[100?o0000ojjObOn^WlT02on^WlT00ol0003oYY?1
ojJC`@0?ojJC`@?o000000?oZ9k<o`000?nNU/`01onNU/`2o`0000_oWYO=00?o0000oiJFdOnFU]40
4_nFU]401?l0003oTjSToi>Xi?nCZ>@5o`0000koVkO[00?o0000oj79m?nQbO@01onQbO@3o`0000co
YmWi0_l00003ojWYnP04o`000?nbmnoo/_O_ok;gk`;o000000Co^oW/o`000?o3oN7o00000_nSm<@0
0ol0003ooo]ZoookJP25oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX06ooonfX0
03[ooo]Z00?o0000oookJ_oonfX0@_oonfX3o`0000;o5E3;0_l000001?lDB/Ko0000ocAVeOl00006
oeiof`Ko00002?n9ZNX9o`0000oo[Lka0ol00003okOHl@;o00000oo6l>l2o`0000KodOCW0_l00006
olgli006o`000?oKh]_ofn;Ko`000?oIoMWo00001OoYiL`2o`0000?okNk800?o0000on_D__o[e;h0
0_o[e;h00ol0003oj<ZhonS:^004onS:^003o`000?oQ_[GohKje00CohKje0_l00006on2`Y@03o`00
0?oGYJ?oejFS00GoejFS1?l00007ol2;W@03o`000?o1S9ko000000co^XNO00?o0000ok=oW?ncOi`0
1?ncOi`00ol0003oXW>Noj9cWP0;oj9cWPCo00003_n=J:<01?l0003oK5BUofaDYOl0000:ogmV[004
o`000?mSG;Go0000o`0000SoDfC61?m`N</2o`0000?o=5o?00Co0000ocYTdOljI=7o00000_miT]l6
o`0000KoEh[V00?o0000ohRcl_n8/o803on8/o801?l0003o/L_]o`000?l0000;okC?k@;o00001onh
e>h00ol0003od]cPo`000005omGPg`03o`000?oLi=[ognWJ00CognWJ00Go0000onC]e_l0003oj_K<
o`000003on[iaP?o00008_oonfX00ol0003ooo]ZoookJP0MoookJP?o0000>_oonfX00ol0003ooo]Z
oookJP0XoookJP;o000000?o;Xg^o`000?m?WoD01_m?WoD3o`000003odnOmOl0003oW;k`01KoW;k`
00?o0000okg1gOnm`Md03?nm`Md2o`0000co^[kM00Go0000ol^lc?o;_<cobkc<o`00000=olJgc003
o`000?o0/L_o`;7;00Oo`;7;1?l00003olRcaP03o`000?njXl7o^Z?100co^Z?10_l00007okJTaP03
o`000?njVkWo^Y^i00So^Y^i00?o0000okNXbongZ</03?ngZ</00ol0003o/9[1ok2J`@06ok2J`@oo
[Yo900?o0000ojJC`OnVTl403?nVTl43o`0000GoZ9k<00?o0000oijFc?nNU/`00onNU/`00ol0003o
WYO=oijGc@0<oijGc@03o`000?nFU]7oUYKA017oUYKA1Ol0000Doi^gj`03o`000?nQbOCoXLWd00?o
XLWd0ol0000<ojOIn@?o00001_nYjOX00ol0003o/_O_o`000002ok_ik003o`000?o3oN7o000000?o
0000R?oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01_ooo]Z000koookJP03o`00
0?oonf[ooo]Z04;ooo]Z0_l00004oaE@b`;o00000_ldI]D00ol0003oGWoKoeiof`04oeiof`04o`00
0?maU>GoLICUog6Di@Wo00002?nC]>h00ol0003o[Lkaojg>l@0:ojg>l@?o00002?ngf?400ol0003o
a_3_o`000007om7di`03o`000?oKjMko000000GocOcT00Co0000om_RfooKh]_ofn;K0_l00005onWU
c003o`000?oYfLGo000000;okNk800?o0000on_D__o[e;h00oo[e;h00ol0003oj<ZhonS:^003onS:
^003o`000?oQ_[GohKje00GohKje0ol00004on2`Y@03o`000?oGYJ?oejFS00KoejFS00Co0000ol^I
Y?o;VJCobiVT1Ol00002ol2;W@03o`000?o1S9ko000000co^XNO00?o0000ok=oW?ncOi`01?ncOi`0
0ol0003oXW>Noj9cWP05oj9cWPKo00000onRNJD00ol0003oSFRSoheXX`0=oheXX`;o00002omoIZ`2
o`0000;oNFjj00?o0000oe=Ta_mCI<H01?mCI<H00ol0003oF6[:og1hb`04og1hb`04o`000?ldGloo
=5o?o`0000?o>VCA00?o0000ogVBgomiT]l01?miT]l4o`0000?oEh[V00?o0000ohRcl_n8/o803?n8
/o82o`0000;oR;?b00?o0000okC?kOndcnd02Ondcnd2o`0000[o^=C^00?o0000omGPgooEh=l01?oE
h=l00ol0003ognWJomoYfP03omoYfP05o`000?oTkMKoi>gFo`000?oZm/`00ooZnLH01?l0003oh?BK
o`000?l0000SoookJP03o`000?oonf[ooo]Z01Wooo]Z0ol00002oookJP03o`000?oonf[ooo]Z03So
oo]Z00?o0000oookJ_oonfX0:OoonfX2o`000003obj=k_l0003oCioe00;oCioe0ol00005odnOm@03
o`000?nL__3oW;k`00koW;k`1?l00003oi^ml003o`000?nm`Mgo_L7M00[o_L7M00?o0000okZngOnj
_]d03Onj_]d00ol0003obkc<o`00000=olJgc003o`000?o0/L_o`;7;00_o`;7;0_l000000oo8/lKo
0000okZS`@0=okZS`@03o`000?nfY<Ko]ZC600So]ZC600?o0000okZK^OnjVkT01_njVkT00ol0003o
]jS;okNXb`0=okNXb`03o`000?n`V/7o/9[100Co/9[100?o0000ojjObOn^WlT03on^WlT00ol0003o
YY?1ojJC`@08ojJC`@?o00002?nXW/`01Ol0003oWYK<oijFc?nNU/co0000013oWYO=00?o0000oiJF
dOnFU]403?nFU]45o`0000;oW:_Q00?o0000oi^gjonK]n/05OnK]n/00ol0003oXLWdo`000002o`00
00goYmWi0_l0000:ojWYnPOo000000?o[O[NoookJ_oonfX0ROoonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z01_ooo]Z000loookJP;o0000@_oonfX3o`0000Co5E3;0_l000000oldI]Go
0000oeiof`05oeiof`03o`000?maU>GoLICU00;oLICU00?o0000oi>dk_nC]>h03_nC]>h00ol0003o
[Lkaojg>l@07ojg>l@;o00002ongf?43o`0000KodOCW00Co0000om_Yg_oKjMko00001?o=o>@00ol0
003ofn;Kom_Rf`02om_Rf`03o`000?oYiLcojNG<00?ojNG<00Oo0000onWIaOoYfLGojMW5o`000?o]
k/So000000CojmBn00?o0000onG9^ol000001?oXb[P00ol0003ohKjeon6n]@04on6n]@03o`000?oE
/;CoeK2d00;o00000ooP/:D00ol0003oejFSomNUX`05omNUX`03o`000?o;VJCobiVT00OobiVT2ol0
0006okZ7W`03o`000?ncOico/gnL00Co/gnL00?o0000oj9cW_nRLih01Ol00009oj9iY@03o`000?n=
J:?oSFRS00coSFRS0_l0000;ogmV[0;o00001?miK[X2o`0000CoDfC600?o0000oeQZb_l000001Om`
N</00ol0003o=5o?o`000003ocYTd@03o`000?miT]ooNI;O00GoNI;O00?o0000ofV>homYS^<01Ol0
0004ohRclPWo00001?n>]o800ol0003o]<o]okC?k@07okC?k@;o00002_nhe>h00ol0003o_M_^o`00
0005omGPg`;o00001?oOjMX01Ol0003oi>gFonC]e_oTkMKo000000?oj_W61?l0000ToookJP03o`00
0?oonf[ooo]Z01Gooo]Z1?l00005oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0
:_oonfX6o`0000WoCioe00?o0000oibnl?nL__002OnL__04o`0000SoVkg`00?o0000okg1gOnm`Md0
1onm`Md2o`00017o^[kM00?o0000olJgc?o6]l`02oo6]l`00ol0003o`;7;ol2ab`0>ol2ab`?o0000
3?njXl400ol0003o]ZC6okJTaP0:okJTaP03o`000?njVkWo^Y^i00Co^Y^i00?o0000okNXbongZ</0
3ongZ</00ol0003o/9[1ok2J`@02ok2J`A?o[Yo900?o0000ojJC`OnVTl401_nVTl42o`0000[oZ9k<
0ol0000DoijGc@03o`000?nFU]7oUYKA00KoUYKA1Ol00008oib[h@03o`000?nK]n_oVkO[01GoVkO[
00?o0000ojOInOnWfOT03?nWfOT2o`0000[oZNWj00Co0000ojCclOnTlo7oY??a0_l00002ojgjgXko
oo]Z00Go0000oookJ_oonf[ooo]Zo`00000MoookJP00?_oonfX00ol0003ooo]ZoookJP10oookJP?o
00000olED</01Ol0003o=6gJo`000?ldI]Go000000GoGWoK00?o0000og6DiOmaU>D00omaU>D00ol0
003oTkC^oi>dkP0>oi>dkP03o`000?n]c_7o[Lka00?o[Lka0ol0000;okOHl@;o00000oo0gnl2o`00
00?odOCW00Go0000om_Yg_oKjMkofnWNo`000003olgli003o`000?oKh]_ofn;K00?ofn;K00?o0000
onWUc?oYiL`00_oYiL`00ol0003ojMW5onWIa@02onWIa@;o00001Oo[e;h01?l0003oiLVkonG9^ol0
0002onS:^003o`000?oQ_[GohKje00GohKje00Go0000omF`]?oE/;Co0000omjbZ`02o`000003on2`
YOl0003oejFS00KoejFS00?o0000ol^IY?o;VJ@02Oo;VJ@00ol0003o`I6Uo`000006okZ=Ya3o0000
3onRNJD00ol0003oSFRSoheXX`08oheXX`?o000000?oT76/o`000?moIZ`02OmoIZ`00ol0003oO72j
o`000006ogU^^P;o00000_mCI<H00ol0003oF6[:o`000007og1hb`;o00000oljI=400ol0003oNI;O
ogVBg`04ogVBg`03o`000?mYS^?oJHkS00CoJHkS1Ol0000>ohjglP03o`000?ndcngo]<o]00Co]<o]
0_l00009okSDkP;o00001?nmfnh01ol0003oeN3OomGPgooEh=oo0000omSTgol000000ooOjMX00ol0
003oi>gFonC]eP02onC]eP08o`000?oZnLKoj_W6o`000?oZn[go0000omW_S_l0000UoookJP03o`00
0?oonf[ooo]Z017ooo]Z0ol00009oookJP03o`000?oonf[ooo]Z03Sooo]Z00?o0000oookJ_oonfX0
:_oonfX3o`000003oaj8j_l0003o000000?o00001om?WoD00ol0003oW;k`oibnl005oibnl0?o0000
3OnK_O000ol0003o_L7Mokg1g@04okg1g@;o00004?nj_]d2o`000003okNlgOl0003oa[O<00[oa[O<
0_l0000?ol2ab`03o`000?nl/Loo000000;oaJo41?l00007okZS`@03o`000?nfY<Ko]ZC600_o]ZC6
00?o0000okZK^OnjVkT00_njVkT2o`0001;o]jS;00?o0000ok2J`On`V/405_n^WlT00ol0003oYY?1
ojJC`@02ojJC`@?o00002?nXW/`4o`0000;oYik=00?o0000oijGcOnNUld04_nNUld01?l0003oUYKA
oiJFdOnFU]45o`0000koW:_Q00?o0000oi^gjonK]n/03onK]n/3o`0000?oX/Oc00?o0000ojOInOnW
fOT02OnWfOT2o`0000WoZNWj0_l00003ojCcl@;o00000on]n]j?oookJP05o`000?oonf[ooo]Zoook
J_l000007OoonfX003oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003o01n/o`000003oaE@b`03
o`000?ldKM[o=6gJ00;o00001OmNOm/00ol0003oLICUog6Di@04og6Di@03o`000?nC]>koTkC^00ko
TkC^00?o0000ojg>lOl000000_l0000<okOHl@;o00001oo0gnl00ol0003odOCWo`000004om_YgP04
o`000?o=o>CocOcTo`0000Gofn;K0_l00004onWUc003o`000?oYfLGojMW500;ojMW500?o0000on_D
__o[e;h00oo[e;h00ol0003oiLVkonG9^`02onG9^`03o`000?oXb[So000000KohKje00?o0000omF`
]?oE/;@00_oE/;@00ol0003og[:[omjbZ`02o`0000OoejFS00?o0000ol^IY?o;VJ@02?o;VJ@01?l0
003o`I6Uol6AYOl0000;okZ=Y`03o`000?ncQJ?o/hFS00Go/hFS00?o0000oj9iYOnRNJD03onRNJD0
0ol0003oSFRSoheXX`05oheXX`?o00001?n@LJ`00ol0003oOfJ/ogmV[007ogmV[004o`000?mlL;[o
O72jo`0000SoNFjj0_l00003oeQZbP03o`000?m`N<_oL7S;00CoL7S;00?o0000of23gOl000000_l0
00000oljI=7o0000ogVBg`04ogVBg`03o`000?mYS^?oJHkS00GoJHkS00?o0000ohjgl_n>]o804?n>
]o800ol0003o]<o]okC?k@02okC?k@03o`000?nhe>ko^=C^00Oo^=C^0_l00007okgKkP03o`000?oE
h=oo000000;of>CO00Co0000omoYf_oOjM[o00001?oTkMH2o`000003on[ia_l0003oj_Zm00Co0000
9_oonfX00ol0003ooo]ZoookJP0=oookJP?o00003?oonfX00ol0003ooo]ZoookJP0hoookJP03o`00
0?oonf[ooo]Z02Oooo]Z0ol00003oookJP;o000000Co7XSZo`000?m9WoGoBIoe1ol000001?m?WoGo
0000oibnl?nL__04o`00017oVkg`00?o0000okg1gOnm`Md00_nm`Md00ol0003o^[kMokZng@0>okZn
g@;o00001?ng_=d00ol0003oa[O<olJgc007olJgc003o`000?o0/L_o`;7;00go`;7;0_l00003okba
c`03o`000?o5[lCoaJo400?oaJo41?l00002okZS`@03o`000?nfY<Ko]ZC600go]ZC600Co0000okZK
^OnjVkWo00005?ngZ</2o`0001Oo[Yo900?o0000ojJC`Ol000000_l00006ojRNc0Go00001onWW/d0
0ol0003oWYO=oijGc@0@oijGc@Go00004onLZn400ol0003oVkO[oi^gj`0<oi^gj`?o00001onRao<0
0ol0003oYmWiojOIn@06ojOIn@;o00002OnYjOX2o`0000?oY??a0ol00002ojgjgY;ooo]Z00Co0000
oookJ_oonf[o00007OoonfX0043ooo]Z00?o0000oookJ_oonfX0?ooonfX01_l0003o01n/o`000?l0
003o5E3;o`0000Co=6gJ00?o0000oeiofomNOm/00_mNOm/00ol0003oLICUog6Di@05og6Di@03o`00
0?nC]>koTkC^00coTkC^0ol0000=okOHl@;o00002Oo0gnl3o`0000CofnWN00?o0000olgli?l00000
1OoKh]/00ol0003oj>G>o`000003onWUc003o`000?oYfLGojMW500?ojMW500?o0000on_D__o[e;h0
0_o[e;h00ol0003oiLVkonG9^`04onG9^`;o00001OoQ_[D00ol0003oeK2domF`]004omF`]004o`00
0?oN/Z_o0000omF[[@;o00001?oGYJ<00ol0003obiVTol^IY009ol^IY005o`000?o1TJGo`I6Uol6A
YOl000002OnjSJL00ol0003o/hFSok>5X`06ok>5X`03o`000?nRNJGoXWVU00koXWVU4_l00007ogmV
[003o`000?mlL;[oO72j00;oO72j00?o0000ogU^^_miK[X01_miK[X2o`0000;oF6[:00?o0000og1h
bom`N</00om`N</00ol0003oH8?Mof23g@03of23g@;o00001OmiT]l00ol0003oJHkSofV>h`06ofV>
h`03o`000?n>]o;oS[Ob013oS[Ob00Co0000okC?kOl0003o00002?nhe>h2o`0000[o_M_^0_l00002
omSTg`03o`000?oOjM[o000000Coi>gF00Wo0000onCfeOl0003oj_W6o`000?oZn[go0000omW_S_l0
00009ooonfX00ol0003ooo]ZoookJP09oookJPCo00004?oonfX00ol0003ooo]ZoookJP0goookJP03
o`000?oonf[ooo]Z02Cooo]Z0ol00007oookJP;o000000?o7XSZo`000?l000001om9WoD4o`0001Ko
Vkg`00Co0000okg1gOl0003o00003onj_]d2o`0000Oo]kcM00?o0000olJgc?o6]l`01Oo6]l`00ol0
003o`;7;ol2ab`0=ol2ab`03o`000?nl/Loo_;7?00?o_;7?00?o0000olF_a?o5[l@01oo5[l@5o`00
00go]ZC600?o0000okZK^Ol000005?ngZ</00ol0003o]:?6o`00000GojjOb@;o00001OnXW/`4o`00
00coYik=00?o0000oijGcOnNUld03?nNUld4o`0000;oXZKI00?o0000oib[hOnLZn405?nLZn400ol0
003oVkO[oi^gj`07oi^gj`Co00002onRao<00ol0003oYmWiojOIn@02ojOIn@?o00002?nYjOX3o`00
00CoY??a0_l00002ojgjgP03o`000?oonf[ooo]Z09;ooo]Z00?o0000oookJ_l000007OoonfX0047o
oo]Z00?o0000oookJ_oonfX0?_oonfX3o`000004oa1?bol0003o5E3;o`0000Co=6gJ2?l00004og6D
i@03o`000?nC]>koTkC^00OoTkC^1Ol00003oibol003o`000?ngf?7o]mSa00So]mSa0_l00009ol3O
k`;o00000oo9hn/3o`000003om_Yg_l0003o000000Gofn;K00Oo0000onSUc_oXiLkoj>G>o`000?oY
iLco000000GojMW500?o0000onC@`ol000000oo[e;h00ol0003oiLVkonG9^`04onG9^`03o`000?oO
`;Wo000000CohKje00?o0000omF`]?oE/;@01?oE/;@2o`0000CoeJ^]00Go0000omNUXooGYJ?oejFS
o`00000:ol^IY003o`000?o1TJGo`I6U00;o`I6U00?o0000okZ=YonjSJL01onjSJL00ol0003o/hFS
ok>5X`07ok>5X`03o`000?nRNJGoXWVU00coXWVU00?o0000oj=kYol000001?n=K:P00ol0003oT7:^
oi1b[P07oi1b[P04o`000?mlJ;7o0000o`0000CoOfJ/00?o0000oga`^_mlL;X00omlL;X00ol0003o
NFjjogU^^P06ogU^^P;oKgW=0ol00005og1hb`03o`000?mPPmgoH8?M00GoH8?M1?l000000omiT]oo
0000ofV>h`08ofV>h`03o`000?n>]o;oS[Ob00coS[Ob0_l00002ohjglP03o`000?nhe>ko^=C^00Oo
^=C^00?o0000okgKk_nmfnh02?nmfnh01?l0003o`n;^ol?Rk_o3h^h3o`000003omoYf_oTkMKoi>gF
00;oi>gF00Go0000onCfeOl0003oj_W6o`000002on[j_@?o0000:?oonfX00ol0003ooo]ZoookJP05
oookJP?o00005?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z027ooo]Z0ol0000<
oookJP03o`000?lNR>[o7XSZ00;o00002Om9WoD00ol0003oVkg`oi^ml00Doi^ml003o`000?nj_]go
^[kM00go^[kM0_l0000:okNlg@03o`000?o6]lcoa[O<00?oa[O<00?o0000ol2aboo0/L/03?o0/L/2
o`0000Oo_;7?00?o0000olF_a?o5[l@01Oo5[l@00ol0003o_JS5okfXa@03okfXa@Go00002?nfY<H2
o`0001?o]jS;0_l00003okBSaP03o`000?n^WlWo[Yo901;o[Yo90_l000001?n^XL[o0000ojRNc?nX
W/`3o`00017oYik=00?o0000oijGcOnNUld01onNUld4o`0000OoXZKI00?o0000oib[hOnLZn404onL
Zn400ol0003oVkO[oi^gj`04oi^gj`?o00004?nRao<01?l0003oYmWio`000?l00009ojWYnP;o0000
1_nTlo401?l0003o[O[Nojgjg_l0002GoookJP03o`000?oonf[o000001cooo]Z0012oookJP;o0000
?_oonfX2o`000003o`0O[?l0003o44o;00;o00001?ldKMX01Ol0003oIHWQofF9hOmURN7o000000?o
KI3T1_l00003oi>dkPGo00002OnL_o000ol0003o]mSaokOHl@05okOHl@;o00002_o0gnl00ol0003o
bN?[olWSj`05olWSj`Co00001?oKh]/00ol0003oj>G>onSUcP02onSUcP;o00001OoYfLD01ol0003o
i=33onC@`ooTd<?o0000on_D__l000001_oUbK/01Ol0003ogl2iomo0^OoO`;Wo000000;ohKje00?o
0000omF`]?oE/;@01_oE/;@00ol0003oeJ^]omF[[@03omF[[@;o000000?oejFSo`000?o;VJ@02Oo;
VJ@00ol0003o`I6Uol6AY@02ol6AY@03o`000?njSJOo^XfW00Ko^XfW00?o0000ok>5XoncQJ<02?nc
QJ<00ol0003oXWVUoj9iY@0:oj9iY@;o00000_nSNjL00ol0003oSFbXohe/Z002o`0000[oT7:^00Co
0000ogaX/OmlJ;7oO6Ra0_l000000omoIZco0000oga`^P05oga`^P03o`000?miK[[oNFjj00GoNFjj
00?o0000ofmicOm_NLd00_m_NLd2o`0000CoL7S;00?o0000of23gOmPPmd01OmPPmd01?l0003oNI7N
ogVAg_miTMh8o`0000CoJHkS00?o0000ohjgl_n>]o800_n>]o89o`0000CoUKcb00?o0000okSDk_nh
e>h01Onhe>h2o`0000Wo_M_^00?o0000ol?Rk_o3h^h01Oo3h^h00ol0003oi>gFonC]eP02onC]eP03
o`000?oTm]Goi?KE00;o00000_oZn[d3o`0002[ooo]Z00?o0000oookJ_oonfX01?l0000GoookJP03
o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX07_oonfX3o`00013ooo]Z0ol000000olNR>[o
0000odVOm@08odVOm@03o`000?nK_O3oVkg`00coVkg`1Ol00003oiRll@03o`000?nj_]go^[kM00_o
^[kM00?o0000okNlgOng_=d02ong_=d01Ol0003oa[O<olJgc?o6]lco000000ko`;7;00?o0000okba
conl/Ll02?nl/Ll00ol0003oaJo4olF_a003olF_a003o`000?nmZ<Go_JS500Wo_JS51Ol00002okJT
aP03o`000?nhZL[o0000017o]jS;0_l00006okBSaP03o`000?n^WlWo[Yo9013o[Yo900?o0000ojjQ
b_l000000ol0000EojNNc@03o`000?nNUlgoWYO=00CoWYO=0ol0000<oj:Vf@03o`000?nLZn7oW:_Q
01?oW:_Q00?o0000oi^gjonK]n/00ol0000Doj;7l`03o`000?nYjO[oZNWj00OoZNWj0_l00007ojCc
l@04o`000?n]n]ko[O[No`0009Sooo]Z00?o0000oookJ_l000007?oonfX004Cooo]Z00?o0000oook
J_oonfX0??oonfX3o`0000;o44o;0_l00004ocA]fP04o`000?mURN7oIHWQo`0000SoKI3T1?l0000?
oibol003o`000?ngf?7o]mSa00;o]mSa0_l0000:ol3Ok`;o00001oo9hn/01Ol0003od>GUom3UiOl0
003odNGU00;o000000?ofn;Ko`000?oXiLh01?oXiLh00ol0003ojMW5onWIa@04onWIa@07o`000?oT
d<?oi=33onC@`ol0003ojmBno`000005onG9^`03o`000?oO`;Wogl2i00?ogl2i00?o0000on6n]Ol0
00002?oE/;@00ol0003oeJ^]omF[[@05omF[[@Co00001oo;VJ@00ol0003o`I6Uol6AY@03ol6AY@03
o`000?njSJOo^XfW00Go^XfW00?o0000ok>5XoncQJ<02OncQJ<00ol0003oXWVUoj9iY@08oj9iY@;o
00001OnSNjL2o`0000goT7:^00?o0000ogaX/OmlJ;400_mlJ;400omoIZco0000oga`^P06oga`^P03
o`000?miK[[oNFjj00?oNFjj00?o0000ofmicOm_NLd01?m_NLd3o`000003og1hbol0003oH8?M00So
H8?M00Go0000ogVAg_miTMkoNI7No`000006og^Cg`Wo00003_nE_?800ol0003o^=C^okSDkP02okSD
kP;o00002Onmfnh2o`0000Oo`n;^00Kob>[]o`000?l0003o0000onC]e_l00003onCfe@03o`000?oZ
n[goj_Zm00Co0000:_oonfX3o`0001_ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]Zoook
JP0LoookJP?o00005OoonfX2o`QohPGo00001_m9WoD00ol0003oVkg`oi^ml006oi^ml0Go00002OnH
_?400ol0003o^[kMokZng@08okZng@;o00003ong_=d00ol0003oa[O<o`00000=ol2ab`;o00002onl
/Ll00ol0003oaJo4olF_a002olF_a003o`000?nmZ<Go_JS500oo_JS53_l00007okNXb`03o`000?nd
XlKo]:?600Ko]:?600?o0000ojjObOn^WlT01on^WlT7o`000004ojjObOl0003o0000o`0000;o[Z;;
00?o0000ojNNcOnWW/d05?nWW/d00ol0003oWYO=oijGc@04o`0000ooXZKI00?o0000oib[hOnLZn40
5?nLZn42o`0001?oX/Oc0ol00003ojGInP;o00001?nYjOX2o`0000OoY??a00?o0000ojgjg_n]n]h0
0_l0002JoookJP;o00007?oonfX004Gooo]Z00?o0000oookJ_oonfX0>ooonfX01ol0003o001jo`0O
[?l0003o44o;o`000?ldL]h00_l00003ocA]fP03o`000?mURN7o000000[oKI3T00?o0000oibol?nL
_o003onL_o001?l0003o]mSao`000?l0000:ol3Ok`;o00001oo9hn/2o`0000?od>GU00?o0000om7U
iOoAiND00ol00005onSUcP03o`000?oYfLGojMW500?ojMW500?o0000onC@`ooTd<<00ooTd<<00ol0
003oiLVkonG9^`04onG9^`03o`000?oO`;Wogl2i00Cogl2i0_l00007omF`]003o`000?o?Z;7o0000
00KoeJ^]00Co0000oljQZ_o>XJ[ocZ6Z1Ol00002ol^IY003o`000?o1TJGo`I6U00?o`I6U00?o0000
okZ=YonjSJL01OnjSJL00ol0003o/hFSok>5X`09ok>5X`03o`000?nRNJGoXWVU00OoXWVU00Co0000
oj=kYonSNjOoXg^W1Ol0000>oi1b[P05o`000?mlJ;7oO6RaogaX/Ol000000_n9LkD3o`0000CoO72j
00?o0000ogU^^_miK[X00_miK[X00ol0003oKgW=ofmic@05ofmic@03o`000?m_NLgoKgW=00Co0000
1omPPmd01?l0003oNI7NogVAg_l0000<og^Cg`03o`000?nE_?;oUKcb013oUKcb00Co0000okSDk_l0
003o00002Onmfnh2o`0000Ko`n;^0_l00002olSZk@03o`000?oCknKodnoV00;o00000ooTm]D00ol0
003oj_Zmon[j_@02o`000003ok7QOooonf[ooo]Z02Gooo]Z1?l000000ooonf[o0000oookJP0Koook
JP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX06OoonfX3o`0001Wooo]Z00Ko0000o`Qo
h_l8On;o27oRo`000?loWO@6o`000004odVOmOl0003oVkg`oi^ml0Go00003onH_?400ol0003o^[kM
okZng@05okZng@;o00004_ng_=d00ol0003o`;7;ol2ab`0:ol2ab`;o00003_nl/Ll01?l0003oaJo4
olF_a?l0000AokfXa@03o`000?nhZL[o^:W:00?o^:W:00?o0000okNYbongZL/01_ngZL/Jo`0000Go
[Z3:0_l00007ojjRb`03o`000?nWW/goYik=01?oYik=0ol0000Doj:Vf@03o`000?nLZn7oW:_Q00go
W:_Q1?l00002oj6jjP03o`000?nRao?oX/Oc00ooX/Oc0ol00008ojGInP04o`000?nYjO[o0000o`00
00KoY??a0ol000000on]n]ko0000o`00002KoookJP?o00007?oonfX004Kooo]Z00?o0000oookJ_oo
nfX0>ooonfX3o`0000;o44o;00?o0000ocAbg_ldL]h00_l000001?ldKM[o0000ofF9hOl0000;off@
i003o`000?nL_o3oW;o`00goW;o`1?l00009ol3Ok`;o00002?o9hn/00ol0003od>GUom3Ui@03om3U
i@03o`000?oAiNGo000000?od>?U0ol000001?oXiLko0000onOIaol00003onWIa@03o`000?oTd<?o
i=3300Coi=330_l00004onG9^`03o`000?oO`;Wogl2i00Gogl2i00Co0000omVh]ol0003o00001OoE
/;@00ol0003ocjRao`000005omF[[@03o`000?o>XJ[ocZ6Z00OocZ6Z1?l00005ol6AY@03o`000?nj
SJOo^XfW00?o^XfW00?o0000ok>5XoncQJ<02_ncQJ<00ol0003oXWVUoj9iY@04oj9iY@Oo00001?nV
Pjl00ol0003oT7:^oi1b[P0<oi1b[P04o`000?mlJ;7oO6Rao`0000KoRG>e0_l00002oga`^P05o`00
0?miK[[oNFjjogU^^_l000002Om_NLd01?l0003oKgW=ofmicOl00002ogn4cP?o00001OmPPmd00ol0
003oNI7No`00000=og^Cg`03o`000?nE_?;oUKcb013oUKcb00?o0000okgKk_nmfnh01onmfnh2o`00
00Oo`n;^00?o0000olSZkOo8j^d00_o8j^d00ol0003odnoVo`000002omOgh@05o`000?oTm]Go0000
o`000?oZn[d01?l0000ToookJP?o00001_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[o
oo]Z03Kooo]Z00?o0000oookJ_oonfX05_oonfX3o`0001kooo]Z00?o0000o`Qoh_l8On800_l00005
ocnMm0Co00005OnH_?400ol0003o^[kMokZng@02okZng@;o00004?ng_=d3o`000003ok:kgol0003o
`;7;00[o`;7;00?o0000okbaconl/Ll03_nl/Ll00ol0003oaJo4o`00000@okfXa@;o00001onhZLX0
0ol0003o]jW;okNYb`09okNYb`03o`000?ndXlOo]:?700[o]:?700?o0000ojjPb_n^X<X02On^X<X2
o`0000Wo[Z;;00?o0000ojNNcOnWW/d04?nWW/d3o`000003ojRVe?l0003oXZKI01GoXZKI00?o0000
oib[hOnLZn402?nLZn44o`0000OoXK[Z00?o0000oj;7lonRao<02onRao<3o`0000coYMWj00?o0000
ojCclOnTlo401?nTlo43o`000004ojgjg_l0003o0000o`0009Wooo]Z0ol0000OoookJP00AooonfX0
0ol0003ooo]ZoookJP0koookJP?o000000?o44o;o`000?ldL]h00oldL]h01?l0003o=6gJo`000?l0
000<off@i003o`000?nL_o3oW;o`00OoW;o`1Ol00004ojK7l@03o`000?o0gnoo`=o_00Co`=o_0_l0
0008olWSj`;o00001Oo@iND00ol0003odNGUo`000007om3Si@;o00000_oWfLL01?l0003ojMW5onWI
aOl00005onC@``04o`000?oSb[kohlZno`0000?oiLVk00?o0000omo0^OoO`;T01?oO`;T00ol0003o
fKRgomVh]`02omVh]`05o`000?oE/;CoeK2domF`]?l000000_o?Z;400ol0003oeJ^]omF[[@03omF[
[@03o`000?o>XJ[ocZ6Z00SocZ6Z00?o0000okZAZonjTJ/01?l000000oo1TJGo0000okZ=Y`04okZ=
Y`03o`000?ncQJ?o/hFS00_o/hFS00?o0000oj9iYOl000001?l0000:ojJ3[`03o`000?n@LZkoT7:^
00goT7:^0_l00009ohUc]@Co000000?oNFjjo`000?m_NLd02Om_NLd00ol0003oKgW=o`000006ogn4
cP?o00000_mPPmd00ol0003oNI7No`00000>og^Cg`03o`000?nE_?;oUKcb00WoUKcb1?l00003oig3
l`03o`000?nmfnko_M_^00Co_M_^0_l00007ol?RkP;o00001?o8j^d00ol0003odnoVo`000003omOg
h@Ko000000?oe_o6o`000?oonfX08?oonfX4o`0000[ooo]Z00?o0000oookJ_oonfX06?oonfX00ol0
003ooo]ZoookJP0foookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0000RoookJP;o00000_l8On800ol0
003o?igdocnMm006ocnMm003o`000?nH_?7oV;ca01?oV;ca00Co0000okZngOl0003o00004?ng_=d2
o`0000Go/[_O00?o0000ol2aboo0/L/01_o0/L/2o`0001;o_;7?00?o0000okfXaOnmZ<D03_nmZ<D0
0ol0003o^:W:okRYbP07okRYbP03o`000?ngZL_o]jW;00Oo]jW;0_l0000>okBSa`03o`000?n^X<[o
[Z3:00Go[Z3:0ol0000<ojjRb`03o`000?nWW/goYik=00coYik=0ol00005ojRVe003o`000?nRY]Wo
XZKI01?oXZKI00?o0000oib[hOnLZn401OnLZn43o`0000coXK[Z00?o0000oj;7lonRao<01onRao<3
o`0000coYMWj0_l00003oj;Yn`;o000000KoY??ao`000?l0003oZOO/o`000?n]n]h3o`0009Kooo]Z
1?l0000RoookJP00B?oonfX00ol0003ooo]ZoookJP0joookJP?o000000?o44o;o`000?ldL]h01?ld
L]h3o`0000goKI3T00Co0000oibol?nL_o3oW;o`1Ol0000:ojK7l@03o`000?o0gnoo`=o_00;o`=o_
00?o0000olWSjoo9hn/01oo9hn/00ol0003od>GUom3Ui@05om3Ui@;o00001_o@hnD02Ol0003oeMgN
omGMg_oEgMko0000onOIaol0003ojMW5o`000005onC@``03o`000?oSb[kohlZn00;ohlZn00?o0000
onG9^ol000001ooO`;T00ol0003ofKRgomVh]`03omVh]`;o000000?oeK2do`000?o?Z;400_o?Z;40
1Ol0003oeJ^]omF[[OoEZjgo000000[ocZ6Z00?o0000okZAZonjTJ/01OnjTJ/Go`0000;oXgfZ0_l0
000<ojJ3[`03o`000?n@LZkoT7:^00_oT7:^0_l0000=ohUc]@Co00002Om_NLd00ol0003oKgW=o`00
0009ogn4cP;o000000?oH8?Mo`000?mkTml03_mkTml00ol0003oUKcboiFllP05oiFllPCo00002?nM
`o<00ol0003o_M_^okgKkP02okgKkP03o`000?o3h^ko`n;^00Ko`n;^00?o0000olSZkOo8j^d01?o8
j^d2o`0000?oeoOQ00Go0000omSeh_oHmN;of?GRo`000003omKoaQoooo]Z0ol0000>oookJP03o`00
0?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0@oookJP?o0000
9ooonfX01?l0L=7o0000o`Qoh_l00008ocnMm0;o00005?nH_?400ol0003o]kcMokNlg@0>okNlg@;o
00002?nb^ml00ol0003o`;7;ol2ab`04ol2ab`03o`000?nl/Loo_;7?00oo_;7?0_l000000onh/]Co
0000okfXa@0=okfXa@;o00002onhZLX00ol0003o]jW;okNYb`04okNYb`;o00004?ndXlL00ol0003o
[Z3:ojjPbP03ojjPbP;o00004?n^X//00ol0003oYik=ojNNc@08ojNNc@?o00002?nXY]@00ol0003o
XZKIoj:Vf@0Doj:Vf@03o`000?nLZn7oW:_Q00Co00004?nQ^^X00ol0003oX/Ocoj;7l`03oj;7l`?o
00003?nUfOX2o`0000SoX^Wk1ol0002EoookJP?o00009_oonfX004Wooo]Z0_l0000koookJP03o`00
0?l07J[o000000;o00001_ldL]hBo`00013oY/Oa00Co0000ol3Okol0003o00002Oo9hn/00ol0003o
d>GUom3Ui@05om3Ui@;o00001_o@hnD00ol0003oeMgNomGMgP03omGMgP03o`000?oWfLOo000000Ko
i=3300?o0000on?:__oSb[h00ooSb[h00ol0003ogl2iomo0^@05omo0^@03o`000?oI^;OofKRg00Ko
fKRg0ol00002olnX/@05o`000?oEZjgoeJ^]omF[[Ol000002_o>XJX00ol0003o^Y6[okZAZ`06okZA
Z`05o`000?njT:_o^Y2[okZ@Zol000003oneSjl01?l0003oXgfZoj=mZ_l0000>ojJ3[`03o`000?n@
LZkoT7:^00SoT7:^0ol000000onCMk7o0000ohUc]@0<ohUc]@04o`000?n5O<7oQGc1ohEl`@?o0000
1om_NLd00ol0003oOhC>ogn4cP0;ogn4cP_o00001_mkTml00ol0003oUKcboiFllP04o`0000goWL?c
00Co0000okgKk_l0003o00002?o3h^h00ol0003ob>[]olSZk@05olSZk@05o`000?oGmn7oeoOQomOg
hOl000001?oHmN83omKoaP03o`000?oonf[ooo]Z01[ooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z
01Sooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0=oookJP?o0000;?oonfX2o`1`
d@Co00001_loWO@00ol0003oV;caoiRll@08oiRll@Ko00001OnC^o800ol0003o]kcMokNlg@09okNl
g@?o00002onb^ml01?l0003o`;7;ol2aboo0/L/2o`00017o_;7?00?o0000okRbe?nh/]@00_nh/]@0
0ol0003o_JS5okfXa@0:okfXa@03o`000?nhZL[o^:W:00_o^:W:00?o0000okNYbongZL/00ongZL/0
0ol0003o]:?7okBSa`0@okBSa`04o`000?n^X<[o[Z3:ojjPbP;o00004_n^X//00ol0003oYik=ojNN
c@06ojNNc@;o00003?nXY]@00ol0003oXZKIoj:Vf@0Doj:Vf@;o00005OnQ^^X00ol0003oX/Oco`00
0002o`0000coYMWj0ol00008oj;Yn`04o`000?nCkncoTno/oi?_k0;o000000?oP^O7oookJ_oonfX0
TOoonfX4o`0002Wooo]Z001;oookJP03o`000?oonf[ooo]Z03Sooo]Z0ol000000olAEm3o0000o`00
0005ocAbgP03o`000?mmZO3oOJW`00coOJW`00?o0000ojK7lOnVao404?nVao43o`0000SobN?[0_l0
0007om3Ui@03o`000?oDg=ko000000Cod>?U0_l00007omGMgP?o00001?oTd<<00ol0003ohlZnon?:
_P04on?:_P;o00001OoO`;T00ol0003ofKRgomVh]`07omVh]`03o`000?o;ZKOobjVg00?o00000_oE
Zjd00ol0003ocZ6ZoljQZP08oljQZP03o`000?njTJ_o^Y6[00Oo^Y6[00Co0000okZ@ZonjT:_o0000
4OneSjl2o`0000ooYX>_00?o0000oi1b[_n@LZh01_n@LZh2o`0000CoTgNa00?o0000ohUc]On9LkD0
2_n9LkD00ol0003oR7g1ohEl`@05ohEl`@?o00001?m_NLd00ol0003oOhC>ogn4cP0;ogn4cP;o0000
2OmlYNd9o`0001;oWL?c00?o0000ol?Rk_o3h^h01_o3h^h2o`0000Oob>[]00GocNWYo`000?oGmn7o
eoOQo`000004omSehP?oe_o600?o0000oookJ_oonfX05ooonfX4o`0001Kooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0000`oookJP03
o`000?l0L=7o073A00So000000?o?igdo`000?nH_?400_nH_?46o`0000coTk_b00?o0000okNlgOng
_=d01_ng_=d2o`0000oo/[_O00?o0000ol2abol000004Onl/Ll2o`0000Ko^;;D00?o0000okfXaOnm
Z<D02?nmZ<D00ol0003o^:W:okRYbP0=okRYbP03o`000?ngZL_o]jW;00;o00005?ndXlL3o`0001Go
[Z;;00?o0000ojNNcOnWW/d00_nWW/d3o`0000ooZ:KD00?o0000oj:VfOnRY]T03OnRY]T4o`0000;o
Y;?S00?o0000oj6jj_nQ^^X05OnQ^^X00ol0003oYMWjojGInP0;ojGInP;o00002?nRjO/2o`0000;o
Tno/0ol000000on2ilOo0000oookJP2@oookJP?o0000;OoonfX004cooo]Z00?o0000oookJ_oonfX0
>?oonfX4o`000003ocMhh_l0003o000000Co=7;N00?o0000ogfYl?mmZO003?mmZO000ol0003oY/Oa
ojK7l@0<ojK7l@?o00000on^cO000ol0003obN?[olWSj`04olWSj`03o`000?o@iNGod>GU00Kod>GU
00Co0000omCLg_oDg=ko00000oo@hnD00ol0003oeMgNomGMgP05omGMgP03o`000?oFeMOoe]GG00;o
e]GG00Go0000onC@`ooTd<?oi=33o`000005on?:_P04o`000?oN`K_og/6ko`0000Cogl2i00?o0000
omVh]ooI^;L01_oI^;L00ol0003objVgol^Y]`04ol^Y]`03o`000?oEZjgo000000WocZ6Z00?o0000
okZAZonjTJ/02OnjTJ/2o`0001;o]Hn_00?o0000ojJ3[onVPjl03_nVPjl00ol0003oT7:^oi1b[P04
oi1b[P;o00001onCMk400ol0003oRG>eohUc]@08ohUc]@04o`000?n8OL7oR7g1o`0000SoQGc10_l0
00001?m_NLgo0000og5lc_l0000<ogn4cP03o`000?mXP]Wo000000ooO:G]00?o0000oig3lonM`o<0
3?nM`o<3o`0000?oYL_d00?o0000ol?Rk_o3h^h01?o3h^h00ol0003ob>[]olSZk@04olSZk@;o0000
00GocNWYo`000?oGmn7oeoOQo`000004omSehP04o`000?oFolKoe_o6o`0001Oooo]Z0ol0000Joook
JP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP07oook
JP?o0000=OoonfX2o`000003o`1`dOl0003o000000Co<IWa1Ol0000Coi>klP03o`000?ng_=go]kcM
00?o]kcM0_l0000Bok:kg`03o`000?nl/Loo_;7?00ko_;7?0_l00009okRbe003o`000?nmZ<Go_JS5
00Go_JS50_l0000@okRYbP03o`000?ngZL_o000001Ko]:?700?o0000ojjRbon^X//05On^X//00ol0
003oYik=ojNNc@02o`0001;oZ:KD00?o0000oj:VfOnRY]T02OnRY]T4o`0000OoY;?S00?o0000oj6j
j_nQ^^X03_nQ^^X4o`0000CoY<_d00?o0000ojGIn_nUfOX01_nUfOX3o`0000SoX^Wk0_l00003oi?_
k0?o000000?oP^O7oookJ_oonfX0S_oonfX3o`00033ooo]Z001=oookJP03o`000?oonf[ooo]Z03So
oo]Z1?l00002ocMhhP?o000000?o=7;No`000?l000003_mmZO000ol0003oY/OaojK7l@08ojK7l@?o
00001on^cO001?l0003obN?[olWSjoo9hn/2o`0000Ood>GU0_l00004omCLgP03o`000?o@hnGo0000
00OoeMgN00?o0000omKEeooFeML00ooFeML2o`000003onC@`ol0003ohlZn00CohlZn00?o0000omk1
^ooN`K/00_oN`K/01?l0003ogl2iomo0^Ol00008omVh]`03o`000?o;ZKOobjVg00GobjVg1?l00008
oljQZP03o`000?njTJ_o^Y6[00Wo^Y6[00?o0000okF?[oneSjl04?neSjl2o`00013oYX>_00Co0000
oi1b[_n@LZkoT7:^0ol00009oi=g/@03o`000?n9LkGoRG>e00KoRG>e0_l00004ohQm`@_oQGc10ol0
000<ogn4cP03o`000?mXP]Wo0000013oO:G]00?o0000oig3lonM`o<01onM`o<4o`0000OoYL_d00Co
0000ol?Rk_o3h^ko`n;^0_l00006olSZk@07o`000?o=jNWocNWYolgYjOl0003oeoOQo`000004omSe
hP03o`000?oFolKoe_o600;o00004ooonfX4o`0001kooo]Z00?o0000oookJ_oonfX05_oonfX00ol0
003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z00Gooo]Z0ol0000joookJP;o000000?o073Ao`00
0?laVO401_laVO400ol0003oTk_boi>klP0Boi>klP03o`000?ng_=go000000;o00004Onb^ml2o`00
0003ojfkhol0003o_;7?00go_;7?0_l0000;okRbe003o`000?nmZ<Go_JS500Co_JS500?o0000okRY
b_nhZLX04OnhZLX00ol0003o]:?7okBSa`0BokBSa`;o000000?o/J[@o`000?n^X//05on^X//00ol0
003oZ:KDojRVe00DojRVe003o`000?nRY]WoXZKI00CoXZKI1?l0000<ojBch`03o`000?nQ^^[oXK[Z
00WoXK[Z1?l00009ojC;m003o`000?nUfO[oYMWj00?oYMWj0_l00008oj;Yn`?o00000onCkn`3o`00
0003oh;Waooonf[ooo]Z08cooo]Z1?l0000coookJP00C_oonfX00ol0003ooo]ZoookJP0goookJPCo
00001OlgN>82o`000003odb4i_l0003oOJW`00goOJW`00?o0000ojK7lOnVao401?nVao43o`0000_o
[/g`00?o0000olWSjol000002?o@iND00ol0003oe=cNomCLgP04omCLgP;o00001ooEgMh00ol0003o
e]GGomKEe`05omKEe`;o00001_oSb[h00ol0003og/6komk1^`03omk1^`03o`000?oO`;Wo000000Oo
fKRg00?o0000ol^Y]oo;ZKL01oo;ZKL00ol0003ocJ>]olfS[@03o`0000CocZ6Z00?o0000okZAZonj
TJ/02_njTJ/00ol0003o]Hn_okF?[`0?okF?[`03o`000?nbRZco0000017oYX>_00?o0000oi1b[_l0
00003?nCMk400ol0003oRG>eohUc]@05ohUc]@03o`000?n8OL7oR7g100CoR7g100?o0000ohEl`On5
O<402?n5O<400ol0003oN7K4ogQfa004o`0000OoOhC>00Go0000ofR2fOmXP]WoJ8;Io`00000@ogbU
k@03o`000?nM`o?oWL?c00?oWL?c0ol0000<ojG;m003o`000?o3h^ko000000Kob>[]0_l00004olgY
j@;o00001?oHmN800ooMn]Wo0000omKoaP02o`00017ooo]Z0ol0000SoookJP03o`000?oonf[ooo]Z
01Gooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP02oookJP?o0000?ooonfX01?l0
FKOo0000o`000?l00006oc6Il@03o`000?nC^o;oTk_b01;oTk_b00?o0000ok:kgonb^ml03onb^ml3
o`0000Co[K_S00?o0000okbaconl/Ll02_nl/Ll00ol0003o^;;DokRbe00<okRbe004o`000?nmZ<Go
_JS5okfXa@;o00004OnhZLX2o`000003okB^d_l0003o]:?7017o]:?70_l00004ok6Zd003o`000?n^
X/_o[Z;;017o[Z;;0ol000000on]Z]Go0000ojRVe00EojRVe003o`000?nRY]WoXZKI00Co00004OnT
/n<00ol0003oXK[Zoj6jjP05oj6jjP?o00003_nTbo@00ol0003oYMWjo`000002o`0000SoX^Wk0_l0
0005oi?_k0;o000000?oP^O7oookJ_oonfX0RooonfX3o`0003Oooo]Z001?oookJP;o0000>?oonfX0
0ol0003o01ZUo`000007ocMhhP?o00003_mmZO000ol0003oY/OaojK7l@03o`0000ko[/g`0ol00006
om3Ui@;o00001ooDg=h00ol0003oeMgNomGMgP05omGMgP03o`000?oFeMOoe]GG00Koe]GG00?o0000
omG<dOl000001?oSb[h00ol0003og/6komk1^`05omk1^`;o00001ooI^;L00ol0003objVgol^Y]`07
ol^Y]`03o`000?o=XjgocJ>]00?ocJ>]0ol000000oo>XJ[o0000okZAZ`0:okZAZ`03o`000?nlU:go
000000oo]Hn_00Co0000ok::[?nbRZco00003_nVPjl3o`000003oi1b[_nCMk7oTgNa00coTgNa00?o
0000ohUc]On9LkD01?n9LkD00ol0003oR7g1ohQm`@05ohQm`@03o`000?n5O<7oQGc100OoQGc100Co
0000ogQfa?mhM/CoN7K41?n;S]45o`0000;oOhC>00?o0000ofR2fOmXP]T00_mXP]T00ol0003oO:G]
ogbUk@0=ogbUk@03o`000?nM`o?oWL?c00?o00004?nUbo@00ol0003ob>[]olSZk@04olSZk@03o`00
0?o=jNWocNWY00?ocNWY0_l00004omSehP05omgjfOl0003oe_o6omKoa_l000003_oonfX4o`0002Oo
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o000000;o
0000A?oonfX00ol0003o05Vgo`000002o`0000Co<IWa00?o0000oi>kl_nC^o802?nC^o86o`0000Co
S;[e00?o0000ok:kgonb^ml03?nb^ml2o`0000So[K_S00?o0000okbaconl/Ll01onl/Ll2o`00013o
^;;D00?o0000okfXaOl000004OnhZLX2o`0000Co]:kB00?o0000okBSaondXlL03OndXlL2o`0000Oo
/J[@00?o0000ojjRbon^X//03_n^X//2o`0000Go[J[E00?o0000ojRVe?nXY]@05?nXY]@2o`0001Ko
Y;?S00?o0000oj6jj_nQ^^X01?l0000BojC;m003o`000?nRjO_oX^Wk00OoX^Wk0_l00005oi?_k0;o
000000?oP^O7o`000?oonfX0ROoonfX4o`0003[ooo]Z001AoookJP03o`000?oonf[ooo]Z03Kooo]Z
00?o0000o`0JYOl000001_lgN>800ol0003oD8[Yoe2:j@0Ao`0000ko[/g`0ol00003okG@kP;o0000
0oo@iND00ol0003oe=cNomCLgP06omCLgP;o00001_oEgMh00ol0003oe]GGomKEe`06omKEe`05o`00
0?oDb]3o0000omG<dOl000000ooSb[h00ol0003og/6komk1^`05omk1^`04o`000?oI_;go0000o`00
00CofKRg00?o0000ol^Y]oo;ZKL01oo;ZKL00ol0003oa:Bho`000007olfS[@Co00002?njTJ/01?l0
003o_9B]okbD[Ol0000>okF?[`03o`000?nbRZco/XZ/00;o/XZ/00?o0000ojJ3[onVPjl01OnVPjl6
o`0000?oYHFb00?o0000oi=g/OnCMk403?nCMk400ol0003oRG>eohUc]@03ohUc]@03o`000?n8OL7o
R7g100OoR7g100?o0000ohEl`On5O<401On5O<400ol0003oN7K4ogQfa003ogQfa0SoRhkA1_l00000
0omXP]Wo0000ogbUk@07ogbUk@Oo000000?oO:G]o`000?l000003onUbo@3o`0000;o[=Ce00Co0000
olSZkOo8j^gob>[]0_l00006olgYj@03o`000?oHmN;of?GR00;of?GR0_oMn]T01?l0003oe_o6omKm
^Ol0000;oookJP?o0000:ooonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z03?ooo]Z
0_l00019oookJP03o`000?l0FKOo000000Ko00000onC^o86o`0000_oS;[e00?o0000ok:kgonb^ml0
2Onb^ml2o`0000_o[K_S00?o0000okbaconl/Ll01?nl/Ll2o`0001?o^;;D00?o0000okRYb_nhZLX0
3_nhZLX2o`0000Oo]:kB00?o0000okBSaondXlL02_ndXlL2o`0000Wo/J[@00?o0000ojjRbon^X//0
3?n^X//2o`0000So[J[E00?o0000ojRVe?nXY]@03_nXY]@3o`0000;oZ;;O00?o0000ojBchonT/n<0
5_nT/n<2o`0001;oY<_d0ol00003oj;No0;o00001?nRjO/2o`0000KoTno/0ol00029oookJP?o0000
?_oonfX005;ooo]Z00?o0000oookJ_oonfX0=OoonfX2o`000004o`13aOl0003o0000o`0000Co=gSR
00?o0000oe2:jOl000003on6/O800ol0003o[/g`ojk=l00:ojk=l0;o00002?ned>h00ol0003od>GU
o`000008omCLgP04o`000?oFeMSoe]GHo`0000CoeMgN00?o0000omKEeooFeML01_oFeML02Ol0003o
e<[@omC:d?oDb]3o0000omG<dOl0003ohlZno`000007omk1^`03o`000?oI_;gofKbm00;ofKbm0_l0
00000ooI^;Oo0000ol^Y]`08ol^Y]`04o`000?o4Y;Soa:Bho`0000OocJ>]00Co0000olJS]_o6XkKo
aZ>f1Ol00003okZAZ`04o`000?nlU:go_9B]o`0000go]Hn_00?o0000ok::[?nbRZ`00onbRZ`00ol0
003oYX>_ojJ3[`05o`0000WoYHFb00?o0000oi=g/OnCMk403OnCMk401?l0003oRG>eohUc]On9LkD;
ohQm`@03o`000?n5O<7oQGc100CoQGc100?o0000ogQfa?mhM/@01?mhM/@00ol0003oRhkAoh^>d@07
oh^>d@04o`000?mmRMCoOHWDogf9e0[o00002?n8[nl00ol0003oYL_dojG;m00;ojG;m0?o00001_n/
e?D00ol0003ob>[]o`000006olgYj@03o`000?oAknOo000000?of?GR0ooMn]T00ol0003oe_fio`00
0008oookJPCo0000;ooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX0B?oonfX01?l0F[Wo05Vgo`000?l00002oanAj`Co00004_n<^_D00ol0003o/[_O
ok:kg`06ok:kg`;o00003_n]^n<00ol0003o_;7?okbac`02okbac`03o`000?nh/]Co^;;D013o^;;D
0_l000000onc]M[o0000okRYbP0=okRYbP;o00002_nd[]800ol0003o]:?7okBSa`07okBSa`;o0000
3?naZ]000ol0003o[Z;;ojjRb`08ojjRb`?o00002_n]Z]D00ol0003oZ:KDojRVe00;ojRVe0?o0000
1_nX/]l00ol0003oY;?SojBch`0@ojBch`?o00000_nU`nl00ol0003oY<_dojC;m00>ojC;m0?o0000
2?nRg_`01?l0003oX^Wko`000?l00007oi?_k0;o0000QooonfX4o`00047ooo]Z001CoookJP03o`00
0?oonf[ooo]Z03Gooo]Z0ol00002ocMhhP?o00000_lgN>800ol0003oD8[Yo`00000?ohJalP03o`00
0?n^cO3o[/g`00Ko[/g`0ol0000:okG@kP?o00001ooDg=h00ol0003oe]GHomKEf002omKEf004o`00
0?oEgMkoeMgNo`0000Soe]GG00?o0000omC:d?oDb]000ooDb]000ol0003oeLcAo`000007omk1^`03
o`000?oI_;gofKbm00GofKbm0_l00008ol^Y]`03o`000?o4Y;Soa:Bh00;oa:Bh00?o0000olfS[Oo=
Xjd00oo=Xjd00ol0003oaZ>folJS]P07olJS]Qgo00003onUQK800ol0003oTgNaoi=g/@08oi=g/@Go
00000_n9LkD<ohQm`@03o`000?n5O<7oQGc100?oQGc100?o0000ogQfa?mhM/@01_mhM/@8oh^>d@03
o`000?mmRMCoOHWD00CoOHWD00?o0000ohR_kon8[nl03_n8[nl00ol0003oYL_dojG;m007ojG;m0?o
00002_n/e?D00ol0003ocNWYolgYj@04olgYj@03o`000?oAknOo000000?of?GR0ooMn]T00ol0003o
e_fio`000006oookJP?o0000=?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z03Ko
oo]Z00?o0000oookJ_oonfX0BOoonfX01?l0F[Wo0000o`000?l00003oanAj`03o`000?n<^_GoS;[e
017oS;[e00?o0000ok:kgonb^ml00_nb^ml3o`00017o[K_S00Co0000okbacol0003o00004Onh/]@2
o`0000Co/kGJ00?o0000okRYb_nhZLX02_nhZLX00ol0003o]:kBokB^dP0:okB^dP03o`000?ndXlOo
]:?700Go]:?70_l0000?ok6Zd003o`000?n^X/_o[Z;;00Go[Z;;0_l0000>ojfZe@03o`000?nXY]Co
Z:KD00OoZ:KD0ol0000:ojRbg`03o`000?nT/n?oY;?S00coY;?S0ol00006ojG3k`03o`000?nTboCo
Y<_d00[oY<_d0ol0000<oj;No003o`000?nCkncoTno/00?oTno/1?l00026oookJP?o0000AOoonfX0
05Cooo]Z00?o0000oookJ_oonfX0=OoonfX3o`0000Co=gSR0ol00002oe2:j@03o`000?n6/O;oQ[7b
00goQ[7b00?o0000ojk=l?n^cO000on^cO02o`0000_o]M3^0_l00003ok[@j`03o`000?oDg=koe=cN
00?oe=cN00?o0000omKEf?oFeMP00ooFeMP00ol0003oeMgNo`000008omKEe`03o`000?oDb]3oe<[@
00Goe<[@0ol00006omk1^`03o`000?oI_;gofKbm00GofKbm00Co0000omFf^ol0003o00001_o;ZKL0
0ol0003oa:BholBT^002olBT^003o`000?o=XjgocJ>]00;ocJ>]00?o0000olJS]_o6XkH02_o6XkH0
0ol0003o]Y:bokJB/P02okJB/P03o`000?neT[;o]I:b00So]I:b00?o0000ok:C]onbTkL01OnbTkL0
0ol0003oYHFbojF5/P0?ojF5/P04o`000?nCMk7oTgNaoi=g/@Oo00000onFOkP2o`000003ohUc]Ol0
003o000000Ko00001_n8OL401Ol0003oQGc1ohEl`On5O<7o000000WoN7K400?o0000oh^>dOn;S]40
1?n;S]400ol0003oOHWDogf9e006ogf9e003o`000?n8[nooR:o_00koR:o_00?o0000ojG;m?nUbo@0
0onUbo@3o`0000[o[=Ce0_l00003okCOmP05o`000?o=jNWocNWYolgYjOl000000_oAknL00ol0003o
f?GRomSehP03omgjf@Co00000ooonfX3o`0003Oooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003o
oo]ZoookJP0goookJP03o`000?oonf[ooo]Z04_ooo]Z00Go05Zio`000?l0003o0000oanAj`02o`00
01;oS;[e00Co0000ok:kgol0003o00005On]^n<00ol0003o^;;DokRbe00?okRbe0;o00001onc]MX0
0ol0003o^:W:okRYbP07okRYbP;o00003_nd[]800ol0003o]:?7okBSa`02okBSa`;o00004OnaZ]00
0ol0003o[Z;;ojjRb`03ojjRb`;o00004?n]Z]D00ol0003oZ:KDojRVe004ojRVe0?o00003_nX/]l0
0ol0003oY;?SojBch`07ojBch`Co00002_nU`nl00ol0003oY<_dojC;m007ojC;m0;o00003?nRg_`2
o`0000GoTn[g0ol000000omchM7ooo]ZoookJP22oookJPCo0000B?oonfX005Gooo]Z00?o0000oook
J_oonfX0=OoonfX3o`0000Ko=gSR0_l000000om@R^Wo0000ohJalP0>ohJalP03o`000?n^cO3o0000
00;o00002oned>h2o`0000Ko^]3[00Go0000omCLg_oDg=koe=cNo`000007omKEf003o`000?oFeMOo
e]GG00Koe]GG00?o0000omC:d?oDb]001_oDb]001?l0003od/G>o`000?l00004omk1^`03o`000?oI
_;gofKbm00GofKbm00?o0000omFf^ooE][/00_oE][/00ol0003objVgol^Y]`02ol^Y]`03o`000?o4
Y;Soa:Bh00?oa:Bh00Go0000olfS[Oo=XjgocJ>]o`00000<olJS]P03o`000?nfT[;o]Y:b00Co]Y:b
00?o0000okFB/_neT[801_neT[800ol0003o/Y>gok:C]`06ok:C]`03o`000?nUQK;oYHFb00koYHFb
1Ol00007oiIo^0?o000000?oVH>jo`000?n9O;h02?n9O;h7o`0000;oQGc100?o0000ogQfa?mhM/@0
2?mhM/@00ol0003oRhkAoh^>d@03oh^>d@03o`000?mmRMCoOHWD00SoOHWD00?o0000ohR_kon8[nl0
3_n8[nl00ol0003oYL_do`000002o`0000_o[=Ce0_l00006okCOmP03o`000?o=jNWo000000?odNoW
00?o0000omSeh_oMn]T00_oMn]T8o`0003_ooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]Z
oookJP0hoookJP03o`000?oonf[ooo]Z04cooo]Z00?o05Zio`000?l000000ol00009ohbjm@Ko0000
0on<^_D00ol0003o[K_Sojfkh`0Aojfkh`?o00000_nV_>T00ol0003o^;;DokRbe00;okRbe0?o0000
2_nc]MX00ol0003o^:W:okRYbP04okRYbP;o00004Ond[]801?l0003o]:?7o`000?l0000Dok6Zd003
o`000?n^X/_o000000;o00004on]Z]D00ol0003oZ:KDojRVe003o`00017oZ;;O00?o0000ojBchonT
/n<01?nT/n<3o`0000ooYL?_00?o0000ojC;m?nTbo@00onTbo@3o`0000[oX]kl0ol00007oi?Zm`03
o`000?mchM7ooo]Z08?ooo]Z0ol0001<oookJP00E_oonfX2o`0003Kooo]Z0ol00005ocMhhP03o`00
0?mDT>co000000;o00002?n6/O89o`0000[o]M3^0ol00009ok[@j`03o`000?oDg=ko000000Ooe]GH
0_l00007omKEe`03o`000?oDb]3oe<[@00Koe<[@00Co0000om;5c_oBaLkod/G>0_l00003omk1^`03
o`000?oI_;gofKbm00CofKbm00?o0000omFf^ooE][/01?oE][/2o`000003ol^Y]ol0003oa:Bh00Ko
a:Bh00Co0000olfS[Oo=Xjgo00002oo6XkH00ol0003o]Y:bokJB/P05okJB/P03o`000?neT[;o]I:b
00Go]I:b00?o0000ok:C]onbTkL02?nbTkL00ol0003oYHFbojF5/P0;ojF5/P;o000000?oYh^ho`00
0?nFOkP01onFOkP2o`0000GoVH>j00?o0000ohUl__n9O;h03?n9O;h00ol0003oPh38o`000004o`00
00SoN7K400?o0000oh^>dOn;S]400_n;S]400ol0003oOHWDogf9e008ogf9e003o`000?n8[nooR:o_
00_oR:o_0ol000000on8[noo0000ojcDm@0;ojcDm@;o00002OndgoH01_l0003odNoWom7_iooAknOo
0000omSehP?ogO[I0_l000000ooFoKWo0000o`000010oookJP03o`000?oonf[ooo]Z017ooo]Z00?o
0000oookJ_oonfX0>OoonfX2o`0004kooo]Z00?o05Zio`000?l000002_l0000;oh2in@03o`000?n]
^n?o[K_S00co[K_S0ol00006ojJlj@03o`000?nh/]Co^;;D00So^;;D0_l0000=ok>efP03o`000?nh
ZL[o^:W:00;o^:W:0_l0000DokB^dP03o`000?naZ]3o/J[@01Go/J[@00?o0000ojfZeOn]Z]D05On]
Z]D2o`0001GoZ;;O00?o0000ojBchonT/n<00ol0000CojG3k`03o`000?nTboCo000000;o00002_nR
g_`3o`0000KoTn[g0ol000000omchM7ooo]ZoookJP21oookJP?o0000CooonfX005Sooo]Z00?o0000
oookJ_oonfX0<ooonfX2o`000003o`14aOl0003o=gSR00Co=gSR00Co0000oeB@k?mDT>coE93/2?l0
0009ohfgl`03o`000?ned>ko]M3^00Go]M3^0_l0000<ok[@j`?o00001_oFeMP01?l0003oeLoComG?
dol00005omKEe`03o`000?oDb]3oe<[@00Koe<[@00?o0000om;5c_oBaLh00ooBaLh2o`000003omk1
^ol0003ofKbm00KofKbm00?o0000omFf^ooE][/01_oE][/3o`0000Koa:Bh00?o0000olfS[Ol00000
2oo6XkH00ol0003o]Y:bokJB/P06okJB/P03o`000?neT[;o]I:b00Co]I:b00?o0000ok:C]onbTkL0
2OnbTkL00ol0003oYHFbojF5/P09ojF5/P;o00000onWRkP00ol0003oUWnhoiIo^004oiIo^0;o0000
1onIPkX00ol0003oRGbnohUl_P0<ohUl_P;o00001On?R<P7o`000003ogQfa?l0003oRhkA00;oRhkA
00?o0000ogf9e?mmRM@02_mmRM@00ol0003oR:o_ohR_k`02ohR_k`So00001?nC^O400ol0003o[=Ce
ojcDm@08ojcDm@;o00002OndgoH01ol0003o^^ceok[/mOnjk?Go0000om7_iol000000ooMn]T01?l0
003odoo?o`000?n`m;=3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0>ooonfX0
0ol0003ooo]ZoookJP1>oookJP04o`1J^Ol0003o0000o`0001;oP;Wi00?o0000ojfkhon]^n<02?n]
^n<3o`0000[oY[cY00?o0000okRbe?nh/]@01Onh/]@2o`00013o/kGJ00Co0000okRYb_l0003o0000
4_nd[]83o`000003ok2dfol0003o/J[@01;o/J[@0ol000000on^/]_o0000ojfZe@0BojfZe@?o0000
00?oZkKQo`000?nX/]l05_nX/]l2o`0001OoYL?_00?o0000oj;No?nRg_`02OnRg_`2o`0000KoTn[g
1?l000000omchM7ooo]ZoookJP1ooookJPCo0000D_oonfX005Wooo]Z00?o0000oookJ_oonfX0<ooo
nfX2o`000004o`14aOl0003o0000o`0000;o=gSR00?o0000oeB@k?mDT>`00_mDT>`00ol0003oSKOc
ohfgl`0>ohfgl`03o`000?ned>ko]M3^00;o]M3^0_l0000<ok[@j`;o00000onncnL2o`0000?oe]GH
00?o0000omG?dooEcm<00_oEcm<01Ol0003oe]GGomKEeooFeMOo000000Soe<[@00?o0000om;5c_oB
aLh01OoBaLh2o`0000OofKbm00?o0000omFf^ooE][/01ooE][/00ol0003ocZnkolj_^`03o`0000Co
a:Bh00?o0000olJS]_o6XkH02Oo6XkH00ol0003o]Y:bokJB/P08okJB/P03o`000?neT[;o]I:b00;o
]I:b00?o0000ok:C]onbTkL02_nbTkL00ol0003oYHFbojF5/P07ojF5/P;o00001_nWRkP00ol0003o
UWnhoiIo^003o`0000WoVH>j00?o0000ohUl__n9O;h02on9O;h00ol0003oRgk0o`00000<ohn8b1Oo
00003OnC^O400ol0003o[=CeojcDm@05ojcDm@;o00002OndgoH00ol0003o^^ceok[/m@04ok[/m@?o
000000KogO[Io`000?l0003o0000ok3d/onWjIU3oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000
oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP1?oookJPCo00004On0^OT00ol0003o[K_Sojfkh`04
ojfkh`?o00003_nV_>T00ol0003o^;;DokRbe002okRbe0;o00004onc]MX00ol0003o]:kBokB^dP0@
okB^dP;o00001On`]=/00ol0003o/J[@ok6Zd00>ok6Zd0;o00001On^/]/00ol0003o[J[EojfZe@0=
ojfZe@?o00001On[]^400ol0003oZ;;OojRbg`0?ojRbg`?o00000_nW`N`00ol0003oYL?_ojG3k`0A
ojG3k`?o00001?nRe_X2o`0000GoX]kl0ol00006oi?Zm`Co0000POoonfX3o`0005Kooo]Z001Joook
JP03o`000?oonf[ooo]Z03?ooo]Z0ol00002ocYoiP?o00001OmDT>`00ol0003oSKOcohfgl`0>ohfg
l`04o`000?ned>ko0000o`0000co^]3[0_l00007okk?i`03o`000?oFeMSo000000KoeLoC00?o0000
omKEeol000002?oDb]000ol0003od/G>om;5cP06om;5cP03o`000?o;_<co000000GofKbm00?o0000
omFf^ooE][/01ooE][/00ol0003ocZnkolj_^`04olj_^`?o000000?oa:Bho`000?o6XkH02_o6XkH0
0ol0003o]Y:bokJB/P08okJB/P05o`000?neT[;o]I:bokFB/_l000003_nbTkL00ol0003oYHFbojF5
/P05ojF5/P03o`000?nWRkSoYh^h00KoYh^h0ol0000=oiV3^P03o`000?n9O;koRGbn00SoRGbn0_l0
0003oh]n`003o`000?n?R<SoShS800coShS800?o0000ohZCeon:TmL03On:TmL00ol0003oTkWaoi>i
l@0?oi>il@03o`000?n/e?Go[=Ce00;o[=Ce0_l00009okCOmP;o00001_njk?D00onnm_3o0000olWk
iP04o`000003ok3d/onWjIWooo]Z04Cooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]Zoook
JP0loookJP03o`000?oonf[ooo]Z057ooo]Z0_l0000Aoh2in@03o`000?n]^n?o[K_S00?o00004_nV
_>T01?l0003o^;;Do`000?l0000Aok>efP?o00000_n/^N<00ol0003o]:kBokB^dP0=okB^dP;o0000
2?n`]=/00ol0003o/J[@ok6Zd00;ok6Zd0;o00002?n^/]/00ol0003o[J[EojfZe@09ojfZe@?o0000
2On[]^400ol0003oZ;;OojRbg`0;ojRbg`?o00001_nW`N`00ol0003oYL?_ojG3k`0=ojG3k`?o0000
2OnRe_X00ol0003oX]klo`000002o`0000KoTn[g1?l000000omchM7ooo]ZoookJP1moookJPCo0000
FOoonfX005_ooo]Z00?o0000oookJ_oonfX0<ooonfX3o`0000Co>WoV0ol00003oeB@k003o`000?n=
]o?oSKOc00[oSKOc1Ol0000<ok[@j`;o00002OnncnL2o`0000OoeLoC0_l00008omC:d003o`000?oB
aLkod/G>00Kod/G>00Co0000ol^lc?o;_<cobkc<0_l00003omVl_@03o`000?oE][_oeKJk00KoeKJk
00?o0000olj_^oo>[k/02?o>[k/5o`0000OoaZ>f00?o0000okJB/_nfT[802OnfT[801?l0003o]I:b
okFB/_l0000?ok:C]`03o`000?nUQK;oYHFb00?oYHFb0_l00006ojN;^0Co00003onIPkX00ol0003o
RGbnohUl_P06ohUl_P;o00001On;O/000ol0003oShS8ohn8b00<ohn8b003o`000?n:TmOoRY?G00ko
RY?G00?o0000oi>ilOnC^O403onC^O401?l0003o[=Ceo`000?l00009okCOmP;o00001Onjk?D2o`00
0004okkfl?l0003obO_Vo`0000;ob__W00?ocOoGo`000?nWjIT0AooonfX00ol0003ooo]ZoookJP0?
oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0D_oonfX@o`0000;oP;Wi0_l0000F
ojJlj@03o`000?nc]M[o/kGJ00oo/kGJ0_l00006ojbih`03o`000?nd[];o]:kB00Wo]:kB0ol0000:
ok2df`03o`000?naZ]3o/J[@00So/J[@0ol0000;ojjbf`03o`000?n]Z]Go[J[E00Ko[J[E0_l0000=
oj^fh@03o`000?nX/]ooZ;;O00OoZ;;O0ol0000:ojO1k003o`000?nU`nooYL?_00SoYL?_1?l0000=
oj;FnP03o`000?nCj_OoTn[g00GoTn[g1?l000000omchM7ooo]ZoookJP1loookJP?o0000GOoonfX0
05cooo]Z0_l0000doookJP?o00000oljOnH00ol0003oEiG^oeNEkP05o`0000CoSKOc1ol00005oi>k
l`03o`000?njd>_o^]3[00So^]3[00?o0000okk?ionncnL01onncnL2o`0000;o_lcT00?o0000omG?
dooEcm<00ooEcm<00ol0003oe<[@o`000007omC:d003o`000?oBaLkod/G>00Kod/G>00?o0000ol^l
c?o;_<`00_o;_<`01Ol0003of;foo`000?oI_;go000000SoeKJk00?o0000olj_^oo>[k/02Oo>[k/0
0ol0003o_Z:lo`000002olFU^@Co00000_o6XkH00ol0003o]Y:bokJB/P0;okJB/P;o00004?nbTkL0
1?l0003oYHFbojF5/_nUQK82o`0000?oYh^h1Ol00003ojF<^P03o`000?nIPk[oVH>j00goVH>j00?o
0000ohUl__n9O;h01On9O;h00ol0003oRgk0oh]n`005oh]n`003o`000?n?R<SoShS800_oShS800?o
0000ohbEeol000004?n:TmL00ol0003oTkWaoi>il@0<oi>il@04o`000?nC^O7oTkWao`0000Wo]=of
0_l00005ok[/m@;o00000_nnm_03o`0000;ob__W00?ocOoGo`000?nWjIT0B?oonfX00ol0003ooo]Z
oookJP0?oookJP03o`000?oonf[ooo]Z03kooo]Z0_l0001DoookJP;o00004?m^]o/00ol0003oY[cY
ojJlj@0<ojJlj@Go00001?nM__000ol0003o/kGJok>efP0:ok>efP?o00002On/^N<00ol0003o]:kB
okB^dP06okB^dP;o00003_n`]=/00ol0003o/J[@ok6Zd005ok6Zd0;o00003_n^/]/00ol0003o[J[E
ojfZe@03ojfZe@?o00003on[]^400ol0003oZ;;OojRbg`04ojRbg`?o00003_nW`N`00ol0003oYL?_
ojG3k`04ojG3k`?o00003OnRe_X2o`0000CoT^Gl0_l000000onCj_Oo0000o`000003o`0007gooo]Z
1?l0001PoookJP00G_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?l0A<?o000000?o>WoV00?o
0000oeNEk_mGUNh00omGUNh5o`0000goTk_c00?o0000ok[@jonjd>/01Onjd>/2o`0000Wo_/oW00?o
0000oko<i?noc>@00onoc>@01Ol0003oeLoComG?dooEcm?o000000?oe<[@00?o0000omC:d?oDb]00
0ooDb]000ol0003od/G>om;5cP06om;5cP03o`000?o;_<cobkc<00Cobkc<00Co0000omRm_ol0003o
00001ooE][/00ol0003ocZnkolj_^`09olj_^`05o`000?nnX[co_Z:lokjR_?l000001Oo5YKT5o`00
00_o]Y:b00?o0000ok:C]onbTkL04?nbTkL8o`0000WoYHbj00?o0000oiV3^_nIPkX03OnIPkX00ol0
003oRGbnohUl_P02ohUl_P;o00002On;O/000ol0003oShS8ohn8b009ohn8b004o`000?n<UMOoS9GG
o`00013oRY?G00?o0000oi>ilOnC^O401onC^O45o`0000CoWLGd00?o0000okCOm_ndgoH01?ndgoH2
o`0000Ko^^ce00?o0000okkfl?nnm_000_nnm_001ol0003ob__Wol[kioo:nnOocOoGo`000?nWjIT0
B_oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0
DooonfX2o`0000ooK[Ok0_l00008ojJlj@Co00002_nM__000ol0003o/kGJok>efP06ok>efP?o0000
3On/^N<00ol0003o]:kBokB^dP03okB^dP;o00004?n`]=/00ol0003o/J[@ok6Zd003ok6Zd0;o0000
4On^/]/00ol0003o[J[Eo`000002o`0001?oZkKQ00?o0000ojRbgonX/]l00ol0000BojO1k003o`00
0?nU`nooYL?_00?o00003?nRe_X3o`0000WoT^Gl1?l0001loookJP?o0000I?oonfX005oooo]Z00?o
0000oookJ_oonfX0<_oonfX00ol0003o04C3o`000003ocYoiP03o`000?mGUNkoEiG^00CoEiG^00?o
0000oi>klonC^o<03_nC^o<00ol0003o^]3[ok[@j`02ok[@j`;o00002OnncnL2o`0000Oo_lcT00?o
0000omG?dol000001OoDb]001Ol0003oe<[@omC:d?oDb]3o000000Sod/G>00?o0000ol^lc?o;_<`0
1_o;_<`01?l0003oe;NlomBg_?l00006omFf^`03o`000?o>[k_ocZnk00SocZnk00?o0000okjR_?nn
X[`00_nnX[`00ol0003oaJFiolFU^@04olFU^@04o`000?noXkgo_j>moknS_@Oo00000onfT[82o`00
00So/Y>g3Ol0000>ojF<^P03o`000?nIPk[oVH>j00goVH>j00Go0000ohUl__n9O;koRGbno`00000;
oh]n`003o`000?n?R<SoShS800SoShS800?o0000ohbEeon<UML00_n<UML00ol0003oRY?GohZCe`0>
ohZCe`04o`000?nC^O7oTkWaoi>il@Go00002_nMaO@00ol0003o]=ofokCOmP02okCOmP03o`000?nj
k?Go^^ce00Co^^ce0_l00004okkfl007o`000?o:nnOob__Wol[kioo=omOo0000ojOYV@1<oookJP03
o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP1DoookJP[o
00001om^]o/00ol0003oY[cYojJlj@05o`0000ooWKk`00?o0000ok>ef_nc]MX00onc]MX2o`00017o
[;WS00?o0000okB^d_l000000_l0000Cok2df`03o`000?naZ]3o000000;o00005?n^/]/00ol0003o
ZkKQoj^fh@0Eoj^fh@;o00005_nW`N`2o`0000_oX]Kj1?l00009oi;Uo005o`000?mchNKoLn7Vog?Q
i_l00000N_oonfX4o`0006Oooo]Z001PoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000o`14`ol0
00000ol00007oeNEkP03o`000?nC^o?oTk_c00koTk_c00Co0000ok[@jol0003o00002OnncnL2o`00
00Wo_lcT0_l00007omC:d003o`000?oDb]3o000000Sod/G>00?o0000ol^lc?o;_<`01_o;_<`2o`00
00?oe;Nl0_l00003omFf^`03o`000?o>[k_ocZnk00SocZnk00?o0000okjR_?nnX[`00onnX[`00ol0
003oaJFiolFU^@03olFU^@03o`000?noXkgo_j>m00Wo_j>m3Ol00007ok:E^@04o`000?neVkko]I^n
o`00013oYHbj00?o0000oiV3^_nIPkX03OnIPkX00ol0003oRGbnohUl_P0=oh]n`003o`000?n?R<So
ShS800OoShS800?o0000ohbEeon<UML00on<UML00ol0003oRY?GohZCe`0;ohZCe`Oo00004?nMaO@0
1?l0003o]=ofo`000?l00006ok[/m@03o`000?nnm_3o__K`00?o__K`00Oo0000ol[kioo:nnOob__W
olgoeol0003oYnVI04kooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP12oookJP03
o`000?oonf[ooo]Z05Kooo]Z1ol@UN06o`0000;oK[Ok0_l0000Eoifnl003o`000?nc]M[o000000;o
00005?n/^N<00ol0003o/;CKok2df`0Eok2df`03o`000?n^/]_o[[;K017o[[;K0ol000000onY_NOo
0000oj^fh@0Aoj^fh@?o00000onWa>h00ol0003oYl7/ojO1k00>ojO1k0Co00001?nQd_T2o`0000Ko
X]Kj0ol00008oi;Uo0?o00000_mchNH2o`0007[ooo]Z0ol0001[oookJP00HOoonfX00ol0003ooo]Z
oookJP0boookJP;o00000_lkQNX5o`0000CoEiG^00?o0000oi>klonC^o<02_nC^o<5o`0000Wo_/oW
0_l00009oko<i0;o00000_nob>400ol0003oe<[@omC:d005omC:d0;o00001ooBaLh00ol0003obkc<
ol^lc006ol^lc004o`000?o6]/_oa[K;o`0000Coe;Nl00?o0000omFf^ol000002_o>[k/00ol0003o
_Z:lokjR_005okjR_005o`000?o5YKWoaJFiolFU^Ol000003OnoXkd01?l0003o/iJiok>F^Ol0000>
ok:E^@05o`000?neVkko]I^nokFK__l000004OnUS;X00ol0003oVH>joiV3^P0<oiV3^P;o00002?n;
O/0<o`0000?oShS800?o0000ohbEeon<UML01?n<UML00ol0003oRY?GohZCe`02ohZCe`Wo00001?n?
[NX00ol0003oWLGdoig5m00Aoig5m003o`000?njk?Go^^ce00Co^^ce0_l00005okkfl007olOdkOl0
003ob__Wol[kioo=omOo0000ojOYV@1?oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oo
nfX0@ooonfX00ol0003ooo]ZoookJP1FoookJP04o`000?oonf[o0000o`0000co49GP00?o0000oifn
l?nM__004onM__000ol0003o[;WSojbih`0@ojbih`?o00000_nS_nd00ol0003o/;CKok2df`0@ok2d
f`?o00000_nY_>L00ol0003o[[;Kojjbf`0>ojjbf`?o00001OnY_NL00ol0003oZkKQoj^fh@0<oj^f
h@?o00001onWa>h00ol0003oYl7/ojO1k009ojO1k0Co00002_nQd_T00ol0003oX]Kjoj;FnP03o`00
00SoT^Gl0ol00002og?QiP;o0000NOoonfX4o`0006kooo]Z001RoookJP03o`000?oonf[ooo]Z03;o
oo]Z0_l00002oc^5jP04o`000?mHVO7oF9WaoeRIl@Co000000?oEiG^o`000?nC^o<00onC^o<7o`00
00GoV;kb00?o0000okk?ionncnL01?nncnL2o`0000[o_lcT00?o0000oko8hOnob>400onob>400ol0
003oe<[@omC:d003omC:d004o`000?oBaLkod/G>o`0000God/G>00?o0000ol^lc?o;_<`01_o;_<`0
0ol0003oa[K;olJfb`02olJfb`03o`000?oD]kcoe;Nl00;oe;Nl0_l00009olj_^`03o`000?nnX[co
_Z:l00Ko_Z:l00Co0000olFU^Oo5YKWo00003OnoXkd00ol0003o/iJiok>F^@02ok>F^@03o`000?nb
UKWo/YFi00[o/YFi00?o0000okFK__neVkh00oneVkh00ol0003oYHbjojF<^P0>ojF<^P03o`000?nI
Pk[oVH>j00WoVH>j3Ol00007oiN<aP03o`000?n=Sm3oSHo@00;oSHo@3ol0000>ohn]jP03o`000?nM
aOCoWLGd00_oWLGd0ol00003ojKCm`04o`000?njk?Go^^ceok[/m@;o00001?nnm_02o`000007olOd
kOl0003ob__Wol[kioo=omOo0000ojOYV@1AoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX0@ooonfX2o`0005Oooo]Z00Go0000oookJ_oonf[ooo]ZodH00003o`0000So49GP0_l0000:
oifnl0Ko00001?n>`OP00ol0003o[;WSojbih`0<ojbih`?o00001_nS_nd00ol0003o/;CKok2df`0<
ok2df`?o00001_nY_>L00ol0003o[[;Kojjbf`0:ojjbf`?o00002OnY_NL00ol0003oZkKQoj^fh@08
oj^fh@?o00002onWa>h00ol0003oYl7/ojO1k005ojO1k0?o00003onQd_T2o`0000SoT^Gl0ol00000
1?mchNKo0000o`000?l0001ioookJP?o0000L_oonfX006?ooo]Z0_l0000coookJP;o00000_lkQNX0
0ol0003oF9WaoeRIl@05oeRIl@Go00003OnH__800ol0003o_/oWokk?i`02okk?i`03o`000?noc>Co
_lcT00So_lcT0_l00007oko8h@05o`000?oDb]3oe<[@omC:d?l000001?oBaLh01Ol0003od/G>om;5
c_oBaLko000000Sobkc<00?o0000olJfboo6]//01?o6]//01_l0003oe;NlomBg_?oD]kco0000olf`
_0?o00001Oo>[k/00ol0003o_Z:lokjR_007okjR_003o`000?o5YKWo000000go_j>m00?o0000ok>F
^OncU[T00oncU[T00ol0003o/YFiok:E^@08ok:E^@;o00001_neVkh00ol0003oYHbjojF<^P0>ojF<
^P03o`000?nIPk[oVH>j00GoVH>j1_l00003oi^<`a3oUhc600Go0000ohf?d?n=Sm3oSHo@o`00000:
ohj@d@03o`000?n?[N[oSjgZ00ooSjgZ00?o0000oig5m?nMaO@01onMaO@4o`0000OoY]?g00?o0000
ok[/mOl000001Onnm_001ol0003oaoC]olOdkOo7m>go0000ol[kioo=omL00_l0001CoookJP03o`00
0?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP1EoookJP03o`00
0?oonf[ooo]Z00Cooo]Z00?oAP00o`000?l000000_l00005oa2Eh004o`000?nM__3oWKk`oifnl0Ko
00002on>`OP00ol0003o[;WSojbih`08ojbih`?o00002_nS_nd00ol0003o/;CKok2df`08ok2df`?o
00002_nY_>L00ol0003o[[;Kojjbf`07ojjbf`;o00003OnY_NL00ol0003oZkKQoj^fh@04oj^fh@?o
00003onWa>h00ol0003oYl7/ojO1k004o`0000koXM;i0ol00003ohgQo@?o00000_nBiO`3o`000004
og?Qi_l0003o0000o`0007Wooo]Z0ol0001eoookJP00IOoonfX00ol0003ooo]ZoookJP0aoookJP;o
00000_lkQNX00ol0003oF9WaoeRIl@06oeRIl@03o`000?nH__;oV;kb00koV;kb00Co0000okk?iol0
003o00002Onoc>@2o`0000[o_lSQ00?o0000omC:d?l000001_oBaLh00ol0003od/G>o`000008ol^l
c003o`000?o6]/_oa[K;00Goa[K;00Co0000omBg_?oD]kco00001Oo=/;`3o`000003olj_^ol0003o
_Z:l00[o_Z:l00?o0000oknS_OnoXkd02onoXkd00ol0003o/iJiok>F^@04ok>F^@03o`000?nbUKWo
/YFi00Oo/YFi00?o0000okFK__neVkh01_neVkh00ol0003oYHbjojF<^P0?ojF<^P03o`000?nIPk[o
000000Go00002OnKS<<?oiN<aP04o`000?n=Sm3oSHo@o`0000coSY3A00?o0000ohn]j_n?[NX03on?
[NX00ol0003oWLGdoig5m003oig5m0?o00003?nVdoL00ol0003o__K`okkfl002okkfl0;o00000oo7
m>d00ol0003ob__Wolgoe`02o`0005Cooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]Zoook
JP16oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX02?oonfX5o`000004oa2Eh?l0
003o0000o`0001;oS/7h00?o0000ojbihon/^N<01?n/^N<3o`0000koXko]00?o0000ok2dfon`]=/0
1?n`]=/3o`0000koZKcW00?o0000ojjbfon^/]/00on^/]/3o`00013oZKgW00?o0000oj^fhOn[]^40
0ol0000CojO4kP;o00003onQd_T3o`0000WoSN7m1_l0001hoookJPCo0000N?oonfX006Kooo]Z00?o
0000oookJ_oonfX0<OoonfX5o`0000SoF9Wa00?o0000oiRnl_nH__803?nH__84o`0000Wo_lcT00?o
0000oko8hOnob>402_nob>43o`0000Ood/G>0_l00007ol^lc003o`000?o6]/_oa[K;00Ooa[K;00?o
0000omBg_?l000002?o=/;`3o`0000[o_Z:l00?o0000oknS_OnoXkd02_noXkd00ol0003o/iJiok>F
^@06ok>F^@03o`000?nbUKWo/YFi00Go/YFi00?o0000okFK__neVkh02?neVkh00ol0003oYHbjojF<
^P0=ojF<^PKo00003?nKS<<00ol0003oUhc6oiN<aP0<oiN<aP03o`000?n=Sm3o000000koSY3A00?o
0000ohn]j_n?[NX03_n?[NX00ol0003oWLGdoig5m003o`0000_oY]?g0ol00003ojgQn@03o`000?nn
m_3o000000CoaoC]00?o0000ol[kioo=omL00_l0001FoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
0000oookJ_oonfX0AooonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z00[ooo]Z00?o
?`00o`000?l000001?l0000Bohk1n003o`000?n/^N?o[;WS00?o00004_nS_nd00ol0003o/;CKok2d
f`03o`0001;oZKcW00?o0000ojjbfol000000_l0000DojVmi`;o00004OnWa>h3o`0000CoVm?k00?o
0000oj7BnOnQd_T02OnQd_T3o`0000WoSN7m00?o0000oeOBfomGd]/00_mGd]/00olf^k[ooo]Zoook
JP1foookJP?o0000O?oonfX006Oooo]Z00?o0000oookJ_oonfX0<OoonfX2o`000003ocZ:kOl0003o
000000?o00001OmHVO400ol0003oV;kboiRnlP06oiRnlPGo00001?nK_o400ol0003o_lcToko<i004
oko<i0;o00002onob>42o`0000?o_/CO00?o0000om;5c_oBaLh00ooBaLh01?l0003ocl7<olo1c?l0
0005ol^lc003o`000?o6]/_oa[K;00Soa[K;0_l00009olf`_003o`000?o7/lKoak?600?o00001_nn
X[`00ol0003o_j>mo`00000:oknS_@03o`000?ncU[Wo/iJi00Oo/iJi00?o0000ok:E^OnbUKT00onb
UKT2o`0000_o]I^n00?o0000ojF<^_nUS;X02_nUS;X6o`0000ooVhc300?o0000oiN<a_nGS<H03?nG
S<H2o`0000ooSY3A00?o0000ohn]j_n?[NX02on?[NX3o`000003ohn]j_l0003o000000_oY]?g0ol0
0007ojgQn@03o`000?o7m>goaoC]00?oaoC]00Co0000olgoeol0003o0000F?oonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]Z
oookJP0<oookJP03ocl00?l0003o000000;o00002On>`OP4o`0000GoS/7h0_l0000Foj>ok@;o0000
5_nY_>L00ol0003oZKgWojVmi`0@ojVmi`?o00001?nPb_H00ol0003oYlC^ojO4kP0:ojO4kPCo0000
2?nKdo/2o`0000KoXM;i0ol00006ohgQo@Co00000_mGd]/00ol0003o=[^jo`00001goookJPCo0000
OooonfX006Sooo]Z00?o0000oookJ_oonfX0<OoonfX2o`000003ocZ:kOl0003oF9cb00;oF9cb1Ol0
00001?mHVO7o0000oiRnl_nH__85o`0000[oVkoa00Co0000oko<i?noc>Co_lcT0_l0000<oko8h@03
o`000?nna=oo_/CO00Co_/CO00Go0000om;5c_oBaLkod/G>o`000004olo1c005o`000?o;_<cobkc<
ol^lc?l000002_o6]//00ol0003o`K;<o`000008olf`_003o`000?o7/lKoak?600Coak?60ol00002
okjR_004o`000?noXkgo_j>mo`0000Wo_j>m00?o0000ok>F^OncU[T02OncU[T01Ol0003o/YFiok:E
^OnbUKWo000000go]I^n00?o0000ojF<^_nUS;X01onUS;X6o`0000;oYi?100?o0000oi^<`onKS<<0
3_nKS<<00ol0003oUhc6oiN<aP09oiN<aP;o000000?oV9G?o`000?n>T=403on>T=400ol0003oSjgZ
ohn]jP02ohn]jPSo00001OnH^^l00ol0003oY]?gojKCm`07ojKCm`;o00002?n]hOT00ol0003o[nog
ojo_m`02ojo_m`03o`000?o7m>go000000?o0000FOoonfX00ol0003ooo]ZoookJP09oookJP03o`00
0?oonf[ooo]Z04Wooo]Z0_l0001FoookJP;o00003ooonfX00olo003o0000o`000008o`0000_oML7n
0_l0000;oj>ok@Ko00001OnDaOP00ol0003oZKcWojVli`0<ojVli`Go00001?nNa_@00ol0003oZKgW
ojVmi`0:ojVmi`Co00002?nPb_H2o`0000KoYlC^1?l0000>oi_Cn`03o`000?nQd_WoXM;i00?o0000
1On=hOd4o`0000;oEm;K0ol0001hoookJP?o0000PooonfX006Wooo]Z0_l0000boookJP;o000000?o
>X[]o`000?mHW?801_mHW?84o`00013oVkoa00?o0000oko<i?l000003?nob>42o`0000So_/CO00?o
0000om;5c_l000001_o?`L`00ol0003obkc<ol^lc00:olJfb`05o`000?o1//co`K;<ol6bc?l00000
1_o=/;`00ol0003oak?6olNcaP08olNcaPKo00002?noXkd00ol0003o/iJiok>F^@0:ok>F^@04o`00
0?nbUKWo/YFio`0000ko]I^n00?o0000ojF<^_nUS;X00onUS;X5o`0000SoYi?100?o0000oi^<`onK
S<<03OnKS<<00ol0003oUhc6oiN<aP07oiN<aP;o00001?nHULl00ol0003oSY3Aohj@d@0:ohj@d@So
00003_nH^^l00ol0003oY]?gojKCm`03ojKCm`?o00001on]hOT2o`0000Ko[nog00Go0000ok?kg_l0
003o_?gLo`00001KoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0BooonfX00ol0
003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z00oooo]Z00?o?`00o`000?l000000_l0000@ogG1
oP;o00000onS_nd6o`0000coU<Gh0_l00008ojVli`Co00002_nNa_@2o`0000KoZKgW1?l0000>oj3:
mP03o`000?nWa>koYlC^00?o00004onKdo/2o`000003ohgQoOl0003oSN7m00;oSN7m0ol00002oeOB
f`?o0000N?oonfX4o`0008Kooo]Z001[oookJP03o`000?oonf[ooo]Z033ooo]Z0_l000000oljR^go
0000oeRLlP08oeRLlP03o`000?nK_o7oVkoa00goVkoa0ol0000;oko8h@;o00002onna=l00ol0003o
cl7<olo1c006olo1c003ol^lc?l0003oa[K;00Ooa[K;0_l00005ol6bc003o`000?o=/;cocK2l00;o
cK2l00?o0000olNca_o7/lH02?o7/lH00ol0003o^Z;1okZR`@03okZR`@Go00000onoXkd00ol0003o
/iJiok>F^@0;ok>F^@03o`000?nbUKWo0000013o]I^n00?o0000ojF<^_l000000ol0000<ojNC`@03
o`000?nKS<?oVhc300koVhc300?o0000oiN<a_nGS<H01?nGS<H2o`0000KoV9G?00?o0000ohj@dOn>
T=400_n>T=48o`0000CoU:ST00?o0000oiRjkonH^^l04?nH^^l00ol0003oY]?go`000002o`0000So
[N7i0_l00005ojo_m`03o`000?n/mnco000000;o000000?o_?gLo`000?oonfX0G?oonfX00ol0003o
oo]ZoookJP07oookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003o
oo]ZoookJP0AoookJP03ocl00?l0003o000000co00001Ome`Oh3o`0001CoU<Gh00?o0000ojVlionY
_>L01Ol0000@oik6m003o`000?nY_NOoZKgW00?o00004onPb_H2o`0000ooVm?k1Ol00006oggLn`So
0000N?oonfX3o`0008[ooo]Z001/oookJP03o`000?oonf[ooo]Z033ooo]Z1?l00009oeRLlP03o`00
0?nK_o7oVkoa00OoVkoa1Ol00003oibnl@03o`000?nob>7o_lSQ00Oo_lSQ00?o0000okk4gonna=l0
2Onna=l00ol0003o_L7Mo`000007olo1c003o`000?o;_<cobkc<00?o00001?o6]//00ol0003o`K;<
ol6bc005ol6bc005o`000?o=/;cocK2lolf`_?l000002_o7/lH00ol0003o^Z;1okZR`@05okZR`@04
o`000?noY;ko_jBnoknT_P[o00001oncU[T2o`0000So]I^n3Ol0000>ojNC`@03o`000?nKS<?oVhc3
00koVhc300?o0000oiN<a_nGS<H00_nGS<H2o`0000?oV9G?2_l0000=oiBXi003o`000?nH^^ooV;[_
013oV;[_00?o0000ojgQnOn]hOT02?n]hOT00ol0003o[nogojo_m`03ojo_m`;o000000?o[?O/o`00
0?l000000_nloM`00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oook
J_oonfX0C?oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z01Oooo]Z3ol0SlT2o`00
01CoU<Gh0_l0000Foik6m0;o00003onPb_H5o`0000CoRMKo0_l00008oi_Cn`Go00002?mmg?/2o`00
0004obbe_ol0003o0000o`0007Wooo]Z1?l0002=oookJP00KOoonfX00ol0003ooo]ZoookJP0aoook
JPWo00000omHW?801?l0003oVkoaoi^olOnK_o45o`0000WoW;ka00?o0000oko8hOnob>401?nob>42
o`0000[o_/CO00?o0000okg1gOnm`Md00_nm`Md00ol0003ocl7<olo1c003olo1c003o`000?o;_<co
bkc<00Cobkc<0_l000000oo6]/_o0000ol6bc008ol6bc003o`000?o=/;co000000[oak?600?o0000
okZR`OnjX/401onjX/401?l0003o_jBnoknT__l00009okZK^A7o00002On`V/42o`00017oYi?100?o
0000oi^<`onKS<<03OnKS<<00ol0003oUhc6oiN<aP07o`0000KoV9K@00?o0000oiBXi?nDZ>@03onD
Z>@00ol0003oV;[_oiRjk`09oiRjk`Co00000onPbOD00ol0003o[N7iojgQn@05ojgQn@;o00001?n_
koL2o`0000;o[?O/0_l00002okcmg67ooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP1=oookJP03o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX05OoonfX3o`0000?ooo]Z00?o
9P00o`000?l000002Ol0SlT2o`0000GoU<Gh2Ol00006ogS9o`;o00002_nNa_@7o`0000GoR<oo0_l0
0008oj3:mPGo00002on9e_l00ol0003oVm?koi_Cn`05o`0000GoOMck1Ol000000ol/]Koo0000o`00
001loookJP?o0000TOoonfX006kooo]Z00?o0000oookJ_oonfX0<OoonfX3o`0000GoE9kd1ol0000?
oibnl@04o`000?nob>7o_lSQoko8h@;o00002_nna=l2o`0000Ko_L7M00Go0000olo1c?o?`Lcocl7<
o`000009ol^lc0;o00002Oo1//`2o`0000[oak?600?o0000okZR`OnjX/402?njX/400ol0003o_jBn
o`00000>okZK^@05o`000?ngZ<[o]jS:okNXb_l000003on`V/42o`000003ojjOb?l0003oYi?1013o
Yi?100?o0000oi^<`onKS<<02onKS<<5o`0000koV9K@00?o0000oiBXi?nDZ>@03_nDZ>@00ol0003o
V;[_oiRjk`05oiRjk`Co00002?nPbOD00ol0003o[N7iojgQn@02ojgQn@;o00001?n_koL2o`0000?o
[?O/0_l00002okcmg6?ooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP1>oookJP;o
0000E_oonfX00ol0003ooo]ZoookJP0@oookJPCo00003OoonfX2obH000;o00000ol0SlT5o`00017o
N<Wo00Co0000oik6m?nNa_CoW/Kd1_l0000>ohS?o`03o`000?nPb_KoX<[f00Go00004On9e_l2o`00
00GoOMck1Ol000000ol/]Koo0000o`00001noookJP?o0000U?oonfX006oooo]Z00?o0000oookJ_oo
nfX0<OoonfX3o`0000WoE9kd00?o0000oibnlOnL__403onL__400ol0003o_lSQo`00000:okk4g`;o
00002Onm`Md00ol0003ocl7<o`000008ol^lc004o`000?o6]/_oa[K;olJfb`;o00001_o1//`00ol0
003o`;7;o`000009olNcaP03o`000?njX/7o^Z;100Wo^Z;10_l0000>okZK^@03o`000?ngZ<[o]jS:
00?o]jS:00?o0000ok2J`On`V/402on`V/400ol0003o[Yo8ojjOb002ojjOb003o`000?nWTl7oYi?1
00koYi?100?o0000oi^<`onKS<<01_nKS<<5o`0000;oWiK;0_l0000?oiRFd003o`000?nDZ>CoU:ST
00ooU:ST00?o0000oiRjkonH^^l01?l0000=oj39m@04o`000?n]hOWo0000o`0000Co[nog0_l00004
ojcgk004o`000?nloMco_?gLo`0006Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zoook
JP1@oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX03?oonfX3o`0001Oooo]Z0olV
0003o`0001;oN<Wo0ol0000EohS?o`;o00003?n9e_l7o`0000Oo:[C>0ol000000ol/]Koo0000oook
JP1ooookJPCo0000UooonfX0073ooo]Z0_l0000boookJP?o00002OmDW_@00ol0003oW;kaoibnl@0=
oibnl@?o00002Onna=l2o`0000co_L7M00?o0000ol^lc?o;_<`01_o;_<`00ol0003oa[K;olJfb`04
olJfb`03o`000?o1//co`K;<00;o`K;<00Go0000ol2aboo0/L_o`;7;o`000007olNcaP03o`000?nj
X/7o^Z;100Wo^Z;100?o0000okJSa_l000003OnjVkT00ol0003o]jS:okNXbP04okNXbP03o`000?n`
V/7o/9[100Wo/9[10_l00005ojjOb003o`000?nWTl7oYi?100ooYi?100?o0000oi^<`onKS<<01Ol0
0005oinFb`;o000000?oWiO<o`000?nHU]003onHU]000ol0003oU:SToiBXi00<oiBXi0;o000000?o
U:STo`000?l000004_nPbOD2o`0000Co[nog00?o0000ojcgk?n/mn`00on/mn`01?l0003o_?gLokcm
g?l0001VoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]Z
oookJP1DoookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0000PoookJPWo00003?l0SkX3o`0000GoR<oo
2Ol00006oabYc@?o00000on9e_l6o`0000Wo:[C>QooonfX3o`0009_ooo]Z001boookJP03o`000?oo
nf[ooo]Z037ooo]Z1Ol00006oeBNm003o`000?nL__7oW;ka00OoW;ka1Ol00003oibnl003o`000?nn
a=oo_/CO00Co_/CO0_l0000<okg1g@03o`000?nj_Mco000000Oobkc<00?o0000olJfboo6]//01_o6
]//2o`000003ol6bc?l0003o`;7;00Co`;7;00?o0000olNca_o7/lH00oo7/lH00ol0003o^Z;1okZR
`@09okZR`@05o`000?nfXlKo]Z?6okJSa_l000002onjVkT00ol0003o]jS:okNXbP06okNXbP03o`00
0?n`V/7o/9[100Oo/9[100?o0000ojjOb?n^WlP01On^WlP00ol0003oYi?1ojNC`@0?ojNC`@?o0000
2?nOU//00ol0003oWiO<oinGc003oinGc003o`000?nHU]3oV9K@00koV9K@00?o0000oiBXi?nDZ>@0
1_nDZ>@5o`0000?oVkK[00?o0000oj39mOnPbOD03?nPbOD3o`0000CoY]_j00Co0000ojo_mol0003o
00001?n/mn`2o`000003okcmg?l0003o000006Sooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o
oo]ZoookJP1BoookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX01?oonfX3o`0002go
oo]Z0ol0000;o`2?^PGo00004_lLZLd3o`0000?o:[C>00?o0000oookJ_oonfX0S?oonfX4o`0009ko
oo]Z001coookJP03o`000?oonf[ooo]Z037ooo]Z00Co0000obf<k_l0003oCioe1Ol00002oeBNm004
o`000?nL__7oW;kaoibnl@Go00002OnL__000ol0003o_/COokk4g`02okk4g`03o`000?nm`Mgo_L7M
00Wo_L7M0_l00004okZmg003o`000?o;_<cobkc<00?obkc<00?o0000olJfboo6]//02Oo6]//3o`00
00Co`;7;00?o0000olNca_o7/lH00_o7/lH00ol0003o^Z;1okZR`@09okZR`@03o`000?nfXlKo]Z?6
00;o]Z?600?o0000okZK^OnjVkT01onjVkT2o`0000Wo]jS:00?o0000ok2J`On`V/401On`V/400ol0
003o[Yo8ojjOb008ojjOb003o`000?nWTl7oYi?100[oYi?10ol000000onXWL_o0000oinFb`07oinF
b`03o`000?nOUlcoWiO<00GoWiO<00?o0000oiRFd?nHU]003_nHU]001?l0003oU:SToiBXi?nDZ>@5
o`0000WoVkK[00?o0000oj39mOnPbOD02?nPbOD3o`0000SoY]_j00?o0000ojcgk?n/mn`00_n/mn`3
o`000003okcmg?l0003o000006[ooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP1C
oookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX00ol0003WoookJP?o0000X_oonfX0
07Cooo]Z00?o0000oookJ_oonfX0<_oonfX2o`0000KoCioe1Ol0000?oibnl004o`000?nna=oo0000
o`0000[o_L7M0_l00007okZmg005o`000?o;_<cobkc<ol^lc?l000002_o6]//00ol0003o`;7;ol2a
b`02ol2ab`Ko00000_o7/lH00ol0003o^Z;1okZR`@09okZR`@03o`000?nfXlKo]Z?600Co]Z?600?o
0000okZK^OnjVkT01OnjVkT00ol0003o]jS:okNXbP09okNXbP03o`000?n`V/7o/9[100Co/9[100?o
0000ojjOb?n^WlP02On^WlP00ol0003oYi?1ojNC`@08ojNC`@;o00001OnXWL/00ol0003oWiK;oinF
b`03oinFb`03o`000?nOUlcoWiO<00SoWiO<00?o0000oiRFd?nHU]003?nHU]05o`0000ooVkK[00?o
0000oj39mOnPbOD01?nPbOD3o`0000SoY]_j0_l00003ojK[nP07o`000?n/mnco0000okKjjOl0003o
_?gLo`00001]oookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0DooonfX2o`0005Go
oo]Z0_l0003VoookJPCo0000YOoonfX007Gooo]Z00?o0000oookJ_oonfX0<_oonfX2o`0000WoCioe
00?o0000oibnl?nL__003_nL__000ol0003o_L7Mokg1g@09okg1g@03o`000?nj_Mco^[gL00So^[gL
00?o0000ol^lc?l000002_o6]//00ol0003o`;7;ol2ab`08ol2ab`Go00002OnjX/400ol0003o]Z?6
okJSaP06okJSaP03o`000?njVkWo^Y^i00?o^Y^i00?o0000okNXb_ngZ<X02ongZ<X01Ol0003o/9[1
ok2J`On`V/7o000000ko[Yo800?o0000ojNC`OnWTl401?nWTl43o`0000OoZ9g;00Co0000oinFbonO
U/_oWiK;3_nOUl`00ol0003oV9K@oiRFd006oiRFd0Go00000_nMZ^000ol0003oVkK[oi^fj`0@oi^f
j`03o`000?nPbOGoX<We00?o00002?nVfoX3o`0000KoY^_j1Ol0001^oookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z
0>;ooo]Z0ol0002YoookJP00M_oonfX2o`0003?ooo]Z0_l000000om?WoGo0000o`000006odnOm@03
o`000?nL__3oW;k`00KoW;k`1Ol00004oi^ml003o`000?nm`Mgo_L7M00Go_L7M0_l0000<okZmg003
o`000?o6]/_oa[K;00Soa[K;00?o0000ol2aboo0/L/02_o0/L/01?l0003oa:k4olB^a?o4[/@3o`00
00Go^Z;100?o0000okJSa_nfXlH01onfXlH00ol0003o^Y^iokZK^@02okZK^@03o`000?ngZ<[o]jS:
00co]jS:00?o0000ok2J`On`V/404?n^WlP00ol0003oYi?1ojNC`@02ojNC`@;o00002?nXWL/4o`00
013oWiO<00Co0000oiRFd?nHU]3oV9K@1Ol00008oifZh003o`000?nK]^_oVkK[013oVkK[0_l00009
ojKKnP;o00001onVjoX00ol0003oW?;/oicbk002o`00077ooo]Z00?o0000oookJ_oonfX00_oonfX0
0ol0003ooo]ZoookJP1FoookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0g_oonfX4
o`000:cooo]Z001hoookJP03o`000?oonf[ooo]Z037ooo]Z00Co0000oab7jOl0003oB9oe1_l00000
1?m?WoGo0000oibnl?nL__05o`0000[oVkg`00?o0000okg1gOnm`Md00_nm`Md2o`0000_o^[gL0_l0
0002okNkg@03o`000?o6]/_oa[K;00Goa[K;0_l0000;ol2ab`03o`000?nl/Loo000000Koa:k40ol0
00000onjX/7o0000okJSaP0:okJSaP04o`000?njVkWo^Y^io`0000oo]jS:0_l0000AojjOb003o`00
0?nWTl7o000000;o00001OnXWL/5o`0000?oZ9k<00?o0000oinGc?nOUl`03OnOUl`5o`0000koWJ[P
00?o0000oi^fjonK]^/02OnK]^/4o`0000;oXLOc00?o0000ojKKn_nVfoX01_nVfoX2o`0000KoY^_j
0_l000001?nLl^co0000o`000?l0001doookJP05o`000?oonf[ooo]ZoookJ_l00000FOoonfX00ol0
003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z0=_ooo]Z0ol0002`oookJP00NOoonfX00ol0003o
oo]ZoookJP0aoookJP04o`000?lLQnWo0000o`0000GoB9oe1?l0000@oi^ml004o`000?nm`Mgo0000
o`0000_o^[gL0_l00005okNkg@03o`000?o6]/_oa[K;00?oa[K;00?o0000ol2aboo0/L/02Oo0/L/2
o`0000?o_;7?00?o0000olB^a?o4[/@01_o4[/@4o`0000Wo]Z?600?o0000okZK^Ol000003_ngZ<X2
o`000003okBRa_l0003o[Yo8013o[Yo80_l00003ojRMb`Go00002OnXW/`00ol0003oWiO<oinGc008
oinGc0Co00000_nRYMP00ol0003oWJ[PoifZh00>oifZh003o`000?nK]^_oVkK[00GoVkK[1?l00007
oj77l`03o`000?nVfo[oY]_j00;oY]_j0ol00005ojK[nP?o00000_nLl^`2o`000003oj7fe?oonf[o
oo]Z07?ooo]Z00Go0000oookJ_oonf[ooo]Zo`00001JoookJP03o`000?oonf[ooo]Z04oooo]Z00?o
0000oookJ_oonfX0eooonfX4o`000;?ooo]Z001joookJP03o`000?oonf[ooo]Z037ooo]Z1?l00007
odROm@03o`000?nK_O3oVkg`00ooVkg`00?o0000okZmg?nj_M`02Onj_M`2o`0000So]k_M00Go0000
olJfboo6]/_oa[K;o`00000;ol2ab`03o`000?nl/Loo_;7?00Co_;7?00?o0000olB^a?o4[/@00oo4
[/@00ol0003o_:O4okbWa003okbWa0Ko00000onfXlH2o`0000ko]jS:00?o0000okBRa_ndX/H00_nd
X/H00ol0003o[Yo8ojjOb00<ojjOb0Oo00003_nXW/`00ol0003oWiO<oinGc004oinGc0Co00001onR
YMP00ol0003oWJ[PoifZh00>oifZh003o`000?nK]^_oVkK[00Co00003?nQao<01?l0003oY]_jo`00
0?l00006ojK[nP;o00001?nLl^`00ol0003oXOKDoookJP1goookJP04o`000?oonf[ooo]Zo`0005_o
oo]Z0_l0001?oookJP03o`000?oonf[ooo]Z0=Cooo]Z0ol0002goookJP00NooonfX00ol0003ooo]Z
oookJP0boookJP04o`Amgol0003o0000odROm@;o00001?m8WoD00ol0003oVkg`oi^ml007oi^ml0Go
00001?nH_?400ol0003o^[gLokZmg005okZmg0;o00002ong^md00ol0003oa[K;o`00000:ol2ab`;o
00001onl/Ll01?l0003oa:k4olB^a?o4[/@2o`0000co_:O42ol00006okNXbP;o00001OndX/H00ol0
003o[Yo8ojjOb005ojjOb0Go000000Co[Yo8o`000?l0003o00000_n^XLX00ol0003oZ9k<ojRNc00>
ojRNc003o`000?nOUlcoWiO<00Co00002onRYMP00ol0003oWJ[PoifZh00?oifZh0;o00004OnQao<0
0ol0003oY^_jojK[nP04ojK[nP;o00001?nLl^`00ol0003oXOKDo`00001joookJP03o`000?oonf[o
000005gooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP3AoookJP?o0000^_oonfX0
07cooo]Z00?o0000oookJ_oonfX0<ooonfX2o`Amg`03o`000?lmW?Co000000Go00000onK_O05o`00
00[oV;ca00?o0000okZmg?nj_M`00_nj_M`2o`0000ko]k_M00?o0000ol2aboo0/L/02?o0/L/00ol0
003o_;7?okbac`08okbac`03o`000?o4[/Co000000ko_:O400Go0000okRXb_nhZ<[o^:S:o`000006
okNXbaGo00000on^X<T2o`0000Oo[Z7:00?o0000ojRNc?nXW/`03OnXW/`3o`00013oXZGH00?o0000
oifZh?nMZ^002?nMZ^04o`0000;oXKWZ00?o0000oj77lonQao<03?nQao<3o`0000?oY=[k0_l00000
0onVjo[o0000o`000003oicbk0Go0000O?oonfX00ol0003ooo]Zo`00001MoookJP03o`000?oonf[o
oo]Z04_ooo]Z00?o0000oookJ_oonfX0cOoonfX4o`000;gooo]Z001moookJP;o0000=?oonfX01?l0
003o17gOo`000?l00004ocfLm0Co00004?nH_?401?l0003o^[gLo`000?l0000<okNkg@?o000000?o
/k[Oo`000?o0/L/01oo0/L/2o`0000co_;7?00?o0000okbWa?nlYl@02onlYl@2o`0000Go^:S:00?o
0000okNXbongZ</01_ngZ</00ol0003o]:?6okBSaP08okBSaP03o`000?n^X<Wo[Z3900Co[Z390ol0
0009ojjQbP03o`000?nXW/coZ9k<00[oZ9k<0ol000000onXYM?o0000oj:Uf00@oj:Uf003o`000?nM
Z^3oWJ[P00CoWJ[P1?l00007oj6ijP03o`000?nQao?oXLOc00SoXLOc0ol00008ojCJn`04o`000?nL
l^co0000oicbk0?o000000?oXOKDo`000?oonfX0OOoonfX00ol0003ooo]Zo`00001NoookJP03o`00
0?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0b_oonfX3o`000<7ooo]Z001ooookJP03o`000?oo
nf[ooo]Z03?ooo]Z00?o0000o`Amgol000001_lmW?@00ol0003oV;caoiRll@0?oiRll@03o`000?ng
^mgo]k_M00[o]k_M0_l00005ok>jg`03o`000?o0/L_o`;7;00Co`;7;00?o0000okbaconl/Ll02_nl
/Ll00ol0003o^;;Co`00000;okbWa0;o00002?nhZ<X00ol0003o]jS;okNXb`03okNXb`;o00003?nd
XlH01?l0003o[Z39ojjPbOn^X<T2o`0000go[Z7:00?o0000ojRNc?nXW/`01_nXW/`3o`0000GoZ:GC
00?o0000oj:Uf?nRYMP03_nRYMP00ol0003oWJ[PoifZh004o`0000coXKWZ00?o0000oj77lonQao<0
1?nQao<3o`0000SoY=[k0_l00004oigZnPGo0000P?oonfX2o`0005oooo]Z00?o0000oookJ_oonfX0
BOoonfX00ol0003ooo]ZoookJP36oookJPCo0000a?oonfX0083ooo]Z00?o0000oookJ_oonfX0=?oo
nfX01?l0K<go0000o`000?l00004ocfLm003o`000?nH_?7oV;ca00OoV;ca1Ol00003oi>klP03o`00
0?ng^mgo]k_M00Ko]k_M0ol00008ok>jg`04o`000?o0/L_o`;7;ol2ab`;o00002onl/Ll2o`0000?o
^;;C00?o0000okbWa?nlYl@01onlYl@00ol0003o^:S:okRXbP08okRXbP04o`000?ngZ<_o]jS;okNX
b`;o00003_ndXlH01?l0003o[Z39o`000?l0000?ojjQbP03o`000?nXW/coZ9k<00?oZ9k<0ol00008
ojRUd`03o`000?nRYMSoXZGH00ooXZGH0_l0000Aoj6ijP03o`000?nQao?oXLOc00?o00001onTf_/3
o`0000GoWN[j00?o0000ohK[i?n6jn@00_l00021oookJP?o0000H?oonfX2o`0004Sooo]Z00?o0000
oookJ_oonfX0a?oonfX3o`000<Sooo]Z0021oookJP03o`000?oonf[ooo]Z03Cooo]Z2Ol00003oiRl
l@Go00002OnC^o800ol0003o]k_MokNkg@03okNkg@;o00003?nc^]l00ol0003o`;7;o`00000<okba
c`03o`000?nh/]?o^;;C00Co^;;C00?o0000okbWa?nlYl@01?nlYl@2o`0000co^:S:00?o0000okNX
bol000004OndXlH00ol0003o[Z7:ojjQbP0?ojjQbP03o`000?nXW/coZ9k<00?o00003?nXYM<00ol0
003oXZGHoj:Uf008oj:Uf0Co00000_nU/n800ol0003oXKWZoj6ijP0Aoj6ijP;o00002?nTf_/2o`00
00GoWN[j0_l000001?n6jnCo0000o`000?l0001ooookJPCo0000IOoonfX00ol0003ooo]ZoookJP15
oookJP03o`000?oonf[ooo]Z0<3ooo]Z1?l0003;oookJP00P_oonfX00ol0003ooo]ZoookJP0eoook
JP04o`1B/?l0003o0000o`0000;o;YO`1?l0000?oi>klP03o`000?ng^mgo000000;o00003onc^]l0
0ol0003o_;7?okbac`09okbac`;o00002?nh/]<01?l0003o_:O4okbWa?nlYl@2o`0000oo^:S:00?o
0000okBSa_ndXlH03OndXlH2o`000003ok:Yd?l0003o[Z7:017o[Z7:0_l0000@ojRUd`03o`000?nR
YMSoXZGH00CoXZGH0ol00007ojFchP03o`000?nQ^N[oXKWZ00[oXKWZ1?l00003oj?<m@03o`000?nT
f__oY=[k00?oY=[k0ol00004oigZnP?o00000_n6jn@2o`0007kooo]Z0ol0001ZoookJP03o`000?oo
nf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0_OoonfX3o`000<oooo]Z0023oookJP03o`000?oonf[o
oo]Z03Kooo]Z00Go0000o`1B/?l0003o;YO`o`000002objGl0;o00003onC^o800ol0003o/k[Ook>j
g`0<ok>jg`?o00000_n]^^<00ol0003o_;7?okbac`06okbac`;o00002onh/]<00ol0003o_:O4o`00
000>okRXbP;o000000?o]:gAo`000?ndXlH03?ndXlH2o`0000Co/ZW@00?o0000ojjQb_n^XLX02on^
XLX3o`000003ojfZe?l0003oZ:GC013oZ:GC00?o0000oj:Uf?nRYMP01?l0000;ojFchP03o`000?nQ
^N[oXKWZ00GoXKWZ1?l00008oj?<m@03o`000?nTf__o000000;o00001OnMj_X2o`0000?oQ^_T0ol0
001koookJPCo0000K_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0
003BoookJP00Q?oonfX2o`0003Sooo]Z00?o05Bao`000?l000001Ol00004oi>klPOo00001?n;^_D0
0ol0003o/k[Ook>jg`08ok>jg`?o00001_n]^^<00ol0003o_;7?okbac`04okbac`03o`000?nh/]?o
^;;C00co^;;C00?o0000okRXb_nhZ<X02onhZ<X2o`0000Co]:gA00?o0000okBSa_ndXlH01ondXlH3
o`0000Ko/ZW@00?o0000ojjQb_n^XLX02On^XLX2o`0000Go[J[D00?o0000ojRUdonXYM<03onXYM<2
o`00013oYK?R00?o0000oj6ij_nQ^NX01?l0000=oj?<m@03o`000?nMj_[oWN[j00CoWN[j0_l00004
ohK[i0;o0000NOoonfX4o`0007?ooo]Z00?o0000oookJ_oonfX0@_oonfX00ol0003ooo]ZoookJP2f
oookJP?o0000e_oonfX008Kooo]Z00?o0000oookJ_oonfX0=ooonfX2o`1D/@03o`1B/?l0003o0000
00Go00003?n;^_D00ol0003o/k[Ook>jg`04ok>jg`?o00002_n]^^<01?l0003o_;7?okbaconl/Ll2
o`0000co^;;C0_l000000onc]=[o0000okRXbP0:okRXbP;o00001ond[M400ol0003o]:?6okBSaP04
okBSaP;o00002_nbZM000ol0003o[Z7:ojjQbP05ojjQbP?o00001on]Z]@00ol0003oZ:GCojRUd`0;
ojRUd`?o000000?oZ;;Oo`000?nU/n804OnU/n82o`0000goXlce0ol00003oioOo@;o000000?oWN[j
o`000?l000001On6jn@00ol0003ooo]ZoookJP1foookJP?o0000N?oonfX2o`0004;ooo]Z00?o0000
oookJ_oonfX0/ooonfX3o`000=Wooo]Z0027oookJP03o`000?oonf[ooo]Z03Sooo]Z0ol0E;42o`00
0003oaZ?jOl0003oRk[e00goRk[e00?o0000ok>jgonc^]l00ol0000>ojfjh`03o`000?nl/Loo0000
00co^;;C0_l00004ok>dfP03o`000?nhZ<[o^:S:00Oo^:S:00?o0000okB]dOnd[M401ond[M400ol0
003o]:?6okBSaP02okBSaP;o00003OnbZM000ol0003o[Z7:ojjQbP02ojjQbP;o00002on]Z]@00ol0
003oZ:GCojRUd`07ojRUd`?o00001OnX/]l00ol0003oYK?RojFchP09ojFchPCo00000onU`nl00ol0
003oXlceoj?<m@08oj?<m@?o00002?nOgod01?l0003oQ^_TohK[i?n6jn@3o`0007Kooo]Z1?l0001m
oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0[ooonfX4o`000=cooo]Z0028oook
JP03o`000?oonf[ooo]Z03[ooo]Z0_l0E;43o`0000OoRk[e1?l00003oh^jm@;o00004_n]^^<00ol0
003o^;;CokRbd`08okRbd`?o00001onc]=X00ol0003o^:S:okRXbP04okRXbP;o00002ond[M401?l0
003o]:?6o`000?l0000?ok:Yd003o`000?n^XL[o000000;o00003_n]Z]@00ol0003oZ:GCojRUd`03
ojRUd`?o00002OnX/]l00ol0003oYK?RojFchP05ojFchP?o00002?nU`nl00ol0003oXlceoj?<m@04
oj?<m@?o00002?nOgod2o`0000CoR^Wc00?o0000oookJ_oonfX0LooonfX4o`0008;ooo]Z00?o0000
oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP2/oookJP?o0000h?oonfX008Wooo]Z00?o0000oook
J_oonfX0>ooonfX00ol0E;7o0000o`000007o`0000WoOkWi00?o0000ojfjhon]^^<02On]^^<4o`00
00?oY[cX00?o0000okRbdonh/]<01Onh/]<2o`0000[o/kCJ00?o0000okRXb_nhZ<X00_nhZ<X2o`00
00ko]:gA00?o0000ok:Yd?nbZM004?nbZM000ol0003o[J[DojfZe00?ojfZe003o`000?nXYM?oZ:GC
00?o00003OnX/]l00ol0003oYK?RojFchP04o`0000coYL?_00?o0000oj?<mOnSc?D00ol00007oioO
o@?o00001On:jO<00ol0003ooo]ZoookJP1boookJP?o0000QooonfX00ol0003ooo]ZoookJP0moook
JP03o`000?oonf[ooo]Z0:Sooo]Z1?l0003SoookJP00R_oonfX2o`0003gooo]Z00?o05Bao`000?l0
PM`00_l0000=ognin@03o`000?n]^^?o[K[S00Go[K[S0ol00008ojJlj003o`000?nh/]?o^;;C00;o
^;;C0_l0000=ok>dfP04o`000?nhZ<[o0000o`0000go]:gA0_l000000on`/m_o0000ok:Yd00=ok:Y
d0?o000000?o[k7Jo`000?n]Z]@04On]Z]@2o`00017oZ;;O0_l0000AojG3k`;o00001onOgod3o`00
00?oR^Wc0ol0001coookJPCo0000RooonfX2o`0003gooo]Z00?o0000oookJ_oonfX0YOoonfX3o`00
0>Oooo]Z002<oookJP03o`000?oonf[ooo]Z03cooo]Z1?l0000=ognin@03o`000?n]^^?o[K[S00Co
00003?nV_>P01?l0003o^;;Co`000?l0000@ok>dfP03o`000?nd[M7o]:gA00_o]:gA0_l00004ok2c
f`03o`000?nbZM3o/ZW@00Wo/ZW@0_l00005ojnafP03o`000?n]Z]Co[J[D00_o[J[D0ol000000on[
]N3o0000ojRbg`0=ojRbg`?o00000_nW`N`00ol0003oYL?_ojG3k`09ojG3k`Co00001?nQeo/2o`00
00;oWmom0ol00003oh[Yl`Co0000LOoonfX4o`00097ooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0
003ooo]ZoookJP2QoookJPCo0000j_oonfX008gooo]Z00?o0000oookJ_oonfX0?OoonfX>o`0000;o
OkWi0_l0000AojJlj003o`000?nc]=[o/kCJ00co/kCJ0ol000000on]^N;o0000okB]d@09okB]d@?o
00001on`/m/00ol0003o/ZW@ok:Yd005ok:Yd0?o00002?n_/MX00ol0003o[J[DojfZe007ojfZe0?o
00001On[]N000ol0003oZ;;OojRbg`08ojRbg`?o00001_nW`N`00ol0003oYL?_ojG3k`05ojG3k`?o
00002_nQeo/3o`0000;oR^Wc0ol000000omNdkko0000oookJP1_oookJP?o0000U_oonfX00ol0003o
oo]ZoookJP0ioookJP03o`000?oonf[ooo]Z09kooo]Z0ol0003^oookJP00S_oonfX00ol0003ooo]Z
oookJP0ooookJP?o00003?m/]_/00ol0003oY[cXojJlj007ojJlj0Go00000onM__000ol0003o/kCJ
ok>dfP08ok>dfP?o00001On]^N800ol0003o]:gAokB]d@05okB]d@;o00002_n`/m/00ol0003o/ZW@
ok:Yd003ok:Yd0;o00002on_/MX00ol0003o[J[DojfZe004ojfZe0?o00002On[]N000ol0003oZ;;O
ojRbg`04ojRbg`?o00002_nW`N`00ol0003oYL?_ojG3k`04o`0000SoXMOk0ol00005ohcUnPGo0000
K_oonfX4o`0009[ooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP2JoookJPCo0000
lOoonfX008oooo]Z00?o0000oookJ_oonfX0@OoonfX6o`0000OoK;Kk00Co0000ojJlj?nV_>SoY[cX
1Ol00009oifnl003o`000?nc]=[o/kCJ00Co/kCJ0ol00009ojfihP03o`000?nd[M7o]:gA00;o]:gA
0_l0000=ok2cf`03o`000?nbZM3o000000;o00003_n_/MX00ol0003o[J[DojfZe003o`0000goZkGP
00?o0000ojRbgonX/]l00ol0000>ojO1k0;o00002OnQeo/3o`0000KoS>Gj00Go0000of?If_l0003o
ALBjo`00001/oookJPCo0000WooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z09Oo
oo]Z0ol0003eoookJP00T?oonfX00ol0003ooo]ZoookJP12oookJP03o`000?l5S]Wo1HkI00?o1HkI
1?l00002ofbfn`?o00003onM__000ol0003o/kCJok>dfP03o`0000go[KWR00Co0000okB]dOl0003o
00004?n`/m/00ol0003o[k7JojnafP0@ojnafP;o00004On[]N02o`0000goYl7/0ol00002oj3CnP03
o`000?nQeo_oXMOk00CoXMOk0ol00004ohcUnP?o000000CoHmWJo`000?m5a;[o0000JooonfX4o`00
0:Cooo]Z0_l0000goookJP03o`000?oonf[ooo]Z09Cooo]Z0ol0003hoookJP00TOoonfX2o`0004?o
oo]Z0_l00002oookJP03o`000?l5S]Wo1HkI00Ko1HkI0_l0000?oifnl0;o00004On]^N800ol0003o
/;?Kok2cf`0<ok2cf`?o00000_nZ_>H00ol0003o[k7JojnafP09ojnafPCo00000onZ_>L00ol0003o
ZkGPoj^eh009oj^eh0Co00000onVa>h00ol0003oYl7/ojO1k008ojO1k0?o00001_nPdoX00ol0003o
XMOkoj7Gn`03o`0000CoS>Gj1ol0001[oookJP?o0000Z_oonfX00ol0003ooo]ZoookJP0doookJP03
o`000?oonf[ooo]Z093ooo]Z1?l0003koookJP00TooonfX00ol0003ooo]ZoookJP12oookJP03o`00
0?oonf[ooo]Z00;ooo]Z00?oE000o`000?l000001Ol5S]T00ol0003oWKk`oifnl002oifnl0Oo0000
1?n=`OP00ol0003o[KWRojfihP09ojfihPCo00000onS_nd00ol0003o/;?Kok2cf`08ok2cf`?o0000
1_nZ_>H00ol0003o[k7JojnafP05ojnafP?o00002?nZ_>L00ol0003oZkGPoj^eh005oj^eh0?o0000
2?nVa>h00ol0003oYl7/ojO1k004ojO1k0?o00002_nPdoX3o`0000?oS>Gj1ol0001ZoookJPCo0000
[_oonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z08gooo]Z0ol0003ooookJP00U?oo
nfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z00Cooo]Z00?oE000o`000?l000000_l0
00000ol5S]Wo0000o`000002o`0000coSL7h00?o0000ojfih_n]^N801On]^N83o`0000SoXko]00?o
0000ok2cfon`/m/01?n`/m/3o`0000[oZ[cV00?o0000ojnaf_n_/MX01?l0000<ojZli`03o`000?n[
]N3oZkGP00Co00003?nVa>h00ol0003oYl7/ojO1k003o`0000WoX=?j0_l00005ohOPo0Oo0000JOoo
nfX4o`000;?ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP2:oookJPCo0000oooo
nfX3oookJP00UOoonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z00Kooo]Z00?oE000
o`000?l000001?l0000=ohg1n003o`000?n]^N;o[KWR00Co00003?nS_nd00ol0003o/;?Kok2cf`03
o`0000koZ[cV0_l0000AojZli`;o00004OnVa>h2o`0000OoX=?j0ol00007ohOPo003o`000?m4aL_o
A<G;00;o0000J_oonfX3o`000;Sooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP27
oookJP?o0000oooonfX7oookJP00U_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z
00[ooo]Z3Ol00003ohg1n0;o00004OnS_nd2o`0000_oZ[cV1?l00003oik6m003o`000?nZ_>OoZ[cW
00WoZ[cW1?l00004oio:mP03o`000?nVa>koY/C^00OoY/C^1Ol00004oi[Do003o`000?nPdo[oX=?j
00Co00001?n7h?`3o`0000;oA<G;0_l0001ZoookJPCo0000_?oonfX2o`00033ooo]Z00?o0000oook
J_oonfX0PooonfX4o`000?oooo]Z2_oonfX009Oooo]Z0_l00013oookJP03o`000?oonf[ooo]Z00go
oo]Z0_l0000<og?0oP;o00001?nS_nd7o`0000KoTlKi00?o0000ojZli_nZ_>H01OnZ_>H3o`0000So
W/Kd00?o0000ojZlionZ_>L01OnZ_>L3o`0000WoWl[f00Co0000ojK4k_nVa>koY/C^1Ol0000:oi[D
o0;o00001?n7h?`6o`0006_ooo]Z1?l00032oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX0P?oonfX3o`000?oooo]Z3_oonfX009Wooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003o
oo]ZoookJP0=oookJPco00000omc`?h4o`0000koTlKi00?o0000ojZli_nZ_>H01?l0000<oik6m003
o`000?nZ_>OoZ[cW00Co00003OnOb_H3o`0000SoV]Cl1Ol00005ogCJn@Go0000K?oonfX3o`000<Oo
oo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1loookJPCo0000oooonfXAoookJP00
V_oonfX00ol0003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z00Wooo]Z0ol00007oookJP[o08>k
0ol0000>oi?6n@;o00004OnNa_@2o`0000[oWl[f1Ol00004ohGFo`04o`000?nJe?coV]Cloi[Do0Go
00001_mdf_T4o`0006gooo]Z1?l0003;oookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oo
nfX0NOoonfX3o`000?oooo]Z5OoonfX009_ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]Z
oookJP04oookJPCo00004OoonfX2ocL000Co08>k1ol00009ogC8o`;o00001?nNa_@7o`0000KoQLoo
0_l00003oio:mPGo00002_n5e_l3o`0000CoM=[i1Ol0001_oookJPCo0000d?oonfX00ol0003ooo]Z
oookJP0ZoookJP03o`000?oonf[ooo]Z07Gooo]Z1?l0003ooookJQSooo]Z002LoookJP03o`000?oo
nf[ooo]Z047ooo]Z00?o0000oookJ_oonfX00ol0000JoookJP;o=`002Ol00008ogC8o`Co00003on5
col3o`0000KoQMKo1_l00006oaFT^`Co0000LOoonfX3o`000=Gooo]Z0_l0000ZoookJP03o`000?oo
nf[ooo]Z07;ooo]Z0ol0003ooookJQcooo]Z002MoookJP03o`000?oonf[ooo]Z047ooo]Z0_l0000Z
oookJP;o00001olH0009o`0000[o29Zk1Ol00005oaFT^gWooo]Z1?l0003JoookJP03o`000?oonf[o
oo]Z02Oooo]Z00?o0000oookJ_oonfX0KooonfX3o`000?oooo]Z7ooonfX009kooo]Z0_l00011oook
JP03o`000?oonf[ooo]Z0<Cooo]Z1?l0003OoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oook
J_oonfX0JooonfX4o`000?oooo]Z8_oonfX00:3ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003o
oo]ZoookJP30oookJPCo0000i?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z06So
oo]Z0ol0003ooookJRKooo]Z002QoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0
_OoonfX3o`000>Wooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP1ToookJPCo0000
oooonfXYoookJP00X_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z0;Wooo]Z1?l0
003]oookJP;o00009?oonfX00ol0003ooo]ZoookJP1QoookJP?o0000oooonfX]oookJP00XooonfX0
0ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z0;Gooo]Z1?l0003coookJP03o`000?oonf[o
oo]Z027ooo]Z00?o0000oookJ_oonfX0GOoonfX4o`000?oooo]Z<?oonfX00:Cooo]Z0_l0000koook
JP03o`000?oonf[ooo]Z0;;ooo]Z0ol0003hoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oook
J_oonfX0F_oonfX3o`000?oooo]Z=?oonfX00:Kooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003o
oo]ZoookJP2^oookJPCo0000o?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z05Ko
oo]Z1?l0003ooookJSOooo]Z002WoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0
Z_oonfX4o`000?oooo]Z0_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z05?ooo]Z
0ol0003ooookJS_ooo]Z002XoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0Yooo
nfX3o`000?oooo]Z1ooonfX2o`0001gooo]Z00?o0000oookJ_oonfX0DOoonfX3o`000?oooo]Z?_oo
nfX00:Wooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP2SoookJPCo0000oooonfX<
oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0COoonfX4o`000?oooo]Z@OoonfX0
0:[ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP2OoookJPCo0000oooonfXAoook
JP03o`000?oonf[ooo]Z01Wooo]Z00?o0000oookJ_oonfX0B_oonfX3o`000?oooo]ZAOoonfX00:_o
oo]Z0_l0000doookJP03o`000?oonf[ooo]Z09cooo]Z0ol0003ooookJQKooo]Z00?o0000oookJ_oo
nfX06?oonfX00ol0003ooo]ZoookJP16oookJPCo0000oooonfY8oookJP00[OoonfX00ol0003ooo]Z
oookJP0aoookJP03o`000?oonf[ooo]Z09Sooo]Z1?l0003ooookJQ[ooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP13oookJP?o0000oooonfY<oookJP00[_oonfX00ol0003ooo]Zoook
JP0`oookJP03o`000?oonf[ooo]Z09Cooo]Z1?l0003ooookJQoooo]Z0_l0000GoookJP03o`000?oo
nf[ooo]Z03oooo]Z1?l0003ooookJToooo]Z002_oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000
oookJ_oonfX0TOoonfX4o`000?oooo]Z9OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z03cooo]Z0ol0003ooookJU?ooo]Z002`oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oook
J_oonfX0S_oonfX3o`000?oooo]Z:_oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z
03Sooo]Z1?l0003ooookJUKooo]Z002aoookJP;o0000;OoonfX00ol0003ooo]ZoookJP2:oookJPCo
0000oooonfX^oookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0=OoonfX3o`000?oo
oo]ZF_oonfX00;?ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP26oookJPCo0000
oooonfXcoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0<OoonfX4o`000?oooo]Z
GOoonfX00;Cooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP23oookJP?o0000oooo
nfXhoookJP;o00004OoonfX00ol0003ooo]ZoookJP0^oookJP?o0000oooonfYQoookJP00]OoonfX0
0ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z07oooo]Z1?l0003ooookJSgooo]Z00?o0000
oookJ_oonfX03_oonfX00ol0003ooo]ZoookJP0[oookJP?o0000oooonfYToookJP00]_oonfX00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z07_ooo]Z1?l0003ooookJT;ooo]Z00?o0000oook
J_oonfX03OoonfX00ol0003ooo]ZoookJP0WoookJPCo0000oooonfYWoookJP00]ooonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z07Sooo]Z0ol0003ooookJTOooo]Z00?o0000oookJ_oo
nfX03?oonfX00ol0003ooo]ZoookJP0ToookJP?o0000oooonfY[oookJP00^?oonfX2o`0002Kooo]Z
00?o0000oookJ_oonfX0M?oonfX4o`000?oooo]ZBooonfX00ol0003ooo]ZoookJP0;oookJP03o`00
0?oonf[ooo]Z023ooo]Z1?l0003ooookJVkooo]Z002joookJP03o`000?oonf[ooo]Z02?ooo]Z00?o
0000oookJ_oonfX0L?oonfX4o`000?oooo]ZD?oonfX2o`0000_ooo]Z00?o0000oookJ_oonfX07Ooo
nfX3o`000?oooo]ZL_oonfX00;_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP1]
oookJP?o0000oooonfYFoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX06OoonfX4
o`000?oooo]ZMOoonfX00;cooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP1Yoook
JPCo0000oooonfYJoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX05ooonfX3o`00
0?oooo]ZNOoonfX00;gooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP1UoookJPCo
0000oooonfYOoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX04ooonfX4o`000?oo
oo]ZO?oonfX00;kooo]Z0_l0000PoookJP03o`000?oonf[ooo]Z06;ooo]Z0ol0003ooookJVCooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0@oookJP?o0000oooonfZ0oookJP00`?oo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z05kooo]Z1?l0003ooookJVSooo]Z0_l0
0004oookJP03o`000?oonf[ooo]Z00gooo]Z0ol0003ooookJX?ooo]Z0031oookJP03o`000?oonf[o
oo]Z01cooo]Z00?o0000oookJ_oonfX0F_oonfX4o`000?oooo]ZK_oonfX01Ol0003ooo]ZoookJ_oo
nf[o000000_ooo]Z1?l0003ooookJXKooo]Z0032oookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000
oookJ_oonfX0E_oonfX4o`000?oooo]ZLooonfX01?l0003ooo]ZoookJ_l00008oookJP?o0000oooo
nfZ:oookJP00`ooonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z05?ooo]Z0ol0003o
oookJWSooo]Z00?o0000oookJ_l000001?oonfX4o`000?oooo]ZSOoonfX00<Cooo]Z00?o0000oook
J_oonfX06OoonfX00ol0003ooo]ZoookJP1?oookJPCo0000oooonfYloookJP;o000000Cooo]Zo`00
0?l0003o0000oooonfZAoookJP00aOoonfX2o`0001Wooo]Z00?o0000oookJ_oonfX0BooonfX4o`00
0?oooo]ZPOoonfX2o`000?oooo]ZU?oonfX00<Oooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP18oookJP?o0000oooonf[ooookJ_oooo]Z7?oonfX00<Sooo]Z00?o0000oookJ_oonfX0
5OoonfX00ol0003ooo]ZoookJP14oookJPCo0000oooonf[ooookJ_oooo]Z7ooonfX00<Wooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP10oookJPCo0000oooonf[ooookJ_oooo]Z8ooo
nfX00<[ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0moookJP?o0000oooonf[o
oookJ_oooo]Z9ooonfX00<_ooo]Z0_l0000CoookJP03o`000?oonf[ooo]Z03Wooo]Z1?l0003ooook
J_oooo]ZoooonfXZoookJP00cOoonfX00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z03Go
oo]Z1?l0003ooookJ_oooo]ZoooonfX^oookJP00c_oonfX00ol0003ooo]ZoookJP0?oookJP03o`00
0?oonf[ooo]Z03;ooo]Z0ol0003ooookJ_oooo]ZoooonfXboookJP00cooonfX00ol0003ooo]Zoook
JP0>oookJP03o`000?oonf[ooo]Z02kooo]Z1?l0003ooookJ_oooo]ZoooonfXeoookJP00d?oonfX0
0ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z02_ooo]Z1?l0003ooookJ_oooo]ZoooonfXi
oookJP00dOoonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z02Oooo]Z1?l0003ooook
J_oooo]ZoooonfXmoookJP00d_oonfX2o`0000_ooo]Z00?o0000oookJ_oonfX09?oonfX3o`000?oo
oo]Zoooonf[ooookJT7ooo]Z003DoookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
8?oonfX4o`000?oooo]Zoooonf[ooookJTCooo]Z003EoookJP03o`000?oonf[ooo]Z00Oooo]Z00?o
0000oookJ_oonfX07?oonfX4o`000?oooo]Zoooonf[ooookJTSooo]Z003FoookJP03o`000?oonf[o
oo]Z00Kooo]Z00?o0000oookJ_oonfX06OoonfX3o`000?oooo]Zoooonf[ooookJTcooo]Z003Goook
JP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX05OoonfX4o`000?oooo]Zoooonf[ooook
JToooo]Z003HoookJP;o00001OoonfX00ol0003ooo]ZoookJP0AoookJPCo0000oooonf[ooookJ_oo
oo]ZDooonfX00=[ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0>oookJP?o0000
oooonf[ooookJ_oooo]ZEooonfX00=_ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000<oookJPCo0000
oooonf[ooookJ_oooo]ZF_oonfX00=cooo]Z00Co0000oookJ_oonf[o00002?oonfX4o`000?oooo]Z
oooonf[ooookJUkooo]Z003MoookJP03o`000?oonf[o000000Gooo]Z0ol0003ooookJ_oooo]Zoooo
nfYRoookJP00g_oonfX2o`000003oookJ_l0003o000000;o0000oooonf[ooookJ_oooo]ZIOoonfX0
0=oooo]Z0_l0003ooookJ_oooo]ZoooonfYYoookJP00oooonf[ooookJ_oooo]ZoooonfY;oookJP00
oooonf[ooookJ_oooo]ZoooonfY;oookJP00oooonf[ooookJ_oooo]ZoooonfY;oookJP00oooonf[o
oookJ_oooo]ZoooonfY;oookJP00oooonf[ooookJ_oooo]ZoooonfY;oookJP00oooonf[ooookJ_oo
oo]ZoooonfY;oookJP00oooonf[ooookJ_oooo]ZoooonfY;oookJP00oooonf[ooookJ_oooo]Zoooo
nfY;oookJP00\
\>"],
  ImageRangeCache->{{{0, 1094}, {372.062, 0}} -> {-0.0519954, -0.017037, \
0.00192321, 0.00192321}, {{27, 522.188}, {363.188, 8.8125}} -> {-0.0519832, \
0.0929406, 0.00192513, 0.00192513}, {{571.75, 1066.94}, {363.188, 8.8125}} -> \
{-1.14523, 0.0974001, 0.00201065, 0.00201065}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(H531 = \ HAtomShow[5, 3, 1, 0.9]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47002 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0111908 0.47619 [
[ 0 0 0 0 ]
[ 1 .47002 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47002 L
0 .47002 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0111908 0.477324 0.458825 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0140957 1.07971 -1.66533e-16 1.07971 [
[ 0 0 0 0 ]
[ 1 .98703 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06979 .24949 m
0 .68989 L
s
0 .68989 m
.3994 .98703 L
s
.3994 .98703 m
.41332 .58901 L
s
.41332 .58901 m
.06979 .24949 L
s
.67831 0 m
.94247 .42094 L
s
.94247 .42094 m
1 .84185 L
s
1 .84185 m
.70509 .46146 L
s
.70509 .46146 m
.67831 0 L
s
.06979 .24949 m
0 .68989 L
s
0 .68989 m
.70509 .46146 L
s
.70509 .46146 m
.67831 0 L
s
.67831 0 m
.06979 .24949 L
s
.41332 .58901 m
.94247 .42094 L
s
.94247 .42094 m
1 .84185 L
s
1 .84185 m
.3994 .98703 L
s
.3994 .98703 m
.41332 .58901 L
s
0 0 m
1 0 L
1 .98703 L
0 .98703 L
closepath
clip
newpath
.5 Mabswid
.648 .759 .93 r
.41756 .82003 m .40981 .82211 L .40751 .82018 L p F P
0 g
s
.648 .759 .93 r
.40751 .82018 m .41526 .81809 L .41756 .82003 L p F P
0 g
s
.648 .759 .93 r
.41526 .81809 m .40751 .82018 L .4052 .81824 L p F P
0 g
s
.648 .759 .93 r
.42532 .81795 m .41756 .82003 L .41526 .81809 L p F P
0 g
s
.648 .759 .93 r
.4052 .81824 m .41296 .81615 L .41526 .81809 L p F P
0 g
s
.648 .759 .93 r
.41296 .81615 m .4052 .81824 L .40288 .8163 L p F P
0 g
s
.648 .759 .93 r
.41526 .81809 m .42303 .816 L .42532 .81795 L p F P
0 g
s
.648 .759 .93 r
.42303 .816 m .41526 .81809 L .41296 .81615 L p F P
0 g
s
.649 .759 .93 r
.43311 .81585 m .42532 .81795 L .42303 .816 L p F P
0 g
s
.648 .759 .93 r
.40288 .8163 m .41065 .8142 L .41296 .81615 L p F P
0 g
s
.648 .759 .93 r
.41065 .8142 m .40288 .8163 L .40056 .81435 L p F P
0 g
s
.648 .759 .93 r
.41296 .81615 m .42074 .81405 L .42303 .816 L p F P
0 g
s
.649 .759 .93 r
.42074 .81405 m .41296 .81615 L .41065 .8142 L p F P
0 g
s
.649 .759 .93 r
.42303 .816 m .43083 .8139 L .43311 .81585 L p F P
0 g
s
.649 .759 .93 r
.43083 .8139 m .42303 .816 L .42074 .81405 L p F P
0 g
s
.649 .759 .929 r
.44093 .81375 m .43311 .81585 L .43083 .8139 L p F P
0 g
s
.648 .759 .93 r
.40056 .81435 m .40833 .81224 L .41065 .8142 L p F P
0 g
s
.648 .758 .93 r
.40833 .81224 m .40056 .81435 L .39823 .81239 L p F P
0 g
s
.649 .759 .93 r
.41065 .8142 m .41844 .81209 L .42074 .81405 L p F P
0 g
s
.649 .758 .929 r
.41844 .81209 m .41065 .8142 L .40833 .81224 L p F P
0 g
s
.649 .759 .93 r
.42074 .81405 m .42854 .81194 L .43083 .8139 L p F P
0 g
s
.649 .758 .929 r
.42854 .81194 m .42074 .81405 L .41844 .81209 L p F P
0 g
s
.649 .759 .929 r
.43083 .8139 m .43865 .81179 L .44093 .81375 L p F P
0 g
s
.649 .758 .929 r
.43865 .81179 m .43083 .8139 L .42854 .81194 L p F P
0 g
s
.649 .758 .929 r
.44876 .81164 m .44093 .81375 L .43865 .81179 L p F P
0 g
s
.648 .758 .93 r
.39823 .81239 m .40601 .81028 L .40833 .81224 L p F P
0 g
s
.649 .758 .929 r
.40601 .81028 m .39823 .81239 L .39589 .81043 L p F P
0 g
s
.649 .758 .929 r
.40833 .81224 m .41613 .81013 L .41844 .81209 L p F P
0 g
s
.649 .758 .929 r
.41613 .81013 m .40833 .81224 L .40601 .81028 L p F P
0 g
s
.649 .758 .929 r
.41844 .81209 m .42625 .80998 L .42854 .81194 L p F P
0 g
s
.649 .758 .929 r
.42625 .80998 m .41844 .81209 L .41613 .81013 L p F P
0 g
s
.649 .758 .929 r
.42854 .81194 m .43637 .80983 L .43865 .81179 L p F P
0 g
s
.649 .758 .929 r
.43637 .80983 m .42854 .81194 L .42625 .80998 L p F P
0 g
s
.649 .758 .929 r
.43865 .81179 m .4465 .80967 L .44876 .81164 L p F P
0 g
s
.649 .758 .929 r
.4465 .80967 m .43865 .81179 L .43637 .80983 L p F P
0 g
s
.649 .758 .929 r
.45663 .80952 m .44876 .81164 L .4465 .80967 L p F P
0 g
s
.649 .758 .929 r
.39589 .81043 m .40368 .80831 L .40601 .81028 L p F P
0 g
s
.649 .758 .929 r
.40368 .80831 m .39589 .81043 L .39355 .80846 L p F P
0 g
s
.649 .758 .929 r
.40601 .81028 m .41381 .80816 L .41613 .81013 L p F P
0 g
s
.649 .758 .929 r
.41381 .80816 m .40601 .81028 L .40368 .80831 L p F P
0 g
s
.649 .758 .929 r
.41613 .81013 m .42395 .80801 L .42625 .80998 L p F P
0 g
s
.649 .758 .929 r
.42395 .80801 m .41613 .81013 L .41381 .80816 L p F P
0 g
s
.649 .758 .929 r
.42625 .80998 m .43408 .80786 L .43637 .80983 L p F P
0 g
s
.649 .758 .929 r
.43408 .80786 m .42625 .80998 L .42395 .80801 L p F P
0 g
s
.649 .758 .929 r
.43637 .80983 m .44422 .8077 L .4465 .80967 L p F P
0 g
s
.649 .758 .929 r
.44422 .8077 m .43637 .80983 L .43408 .80786 L p F P
0 g
s
.649 .758 .929 r
.4465 .80967 m .45437 .80755 L .45663 .80952 L p F P
0 g
s
.649 .758 .929 r
.45437 .80755 m .4465 .80967 L .44422 .8077 L p F P
0 g
s
.649 .758 .929 r
.46451 .80739 m .45663 .80952 L .45437 .80755 L p F P
0 g
s
.649 .758 .929 r
.39355 .80846 m .40134 .80634 L .40368 .80831 L p F P
0 g
s
.649 .758 .929 r
.40134 .80634 m .39355 .80846 L .3912 .80648 L p F P
0 g
s
.649 .758 .929 r
.40368 .80831 m .41149 .80619 L .41381 .80816 L p F P
0 g
s
.649 .758 .929 r
.41149 .80619 m .40368 .80831 L .40134 .80634 L p F P
0 g
s
.649 .758 .929 r
.41381 .80816 m .42164 .80603 L .42395 .80801 L p F P
0 g
s
.649 .758 .929 r
.42164 .80603 m .41381 .80816 L .41149 .80619 L p F P
0 g
s
.649 .758 .929 r
.42395 .80801 m .43179 .80588 L .43408 .80786 L p F P
0 g
s
.649 .758 .929 r
.43179 .80588 m .42395 .80801 L .42164 .80603 L p F P
0 g
s
.649 .758 .929 r
.43408 .80786 m .44194 .80573 L .44422 .8077 L p F P
0 g
s
.649 .758 .929 r
.44194 .80573 m .43408 .80786 L .43179 .80588 L p F P
0 g
s
.649 .758 .929 r
.44422 .8077 m .4521 .80557 L .45437 .80755 L p F P
0 g
s
.649 .758 .929 r
.4521 .80557 m .44422 .8077 L .44194 .80573 L p F P
0 g
s
.649 .758 .929 r
.45437 .80755 m .46226 .80541 L .46451 .80739 L p F P
0 g
s
.649 .758 .929 r
.46226 .80541 m .45437 .80755 L .4521 .80557 L p F P
0 g
s
.649 .758 .929 r
.47242 .80525 m .46451 .80739 L .46226 .80541 L p F P
0 g
s
.649 .758 .929 r
.3912 .80648 m .399 .80435 L .40134 .80634 L p F P
0 g
s
.649 .758 .929 r
.399 .80435 m .3912 .80648 L .38884 .8045 L p F P
0 g
s
.649 .758 .929 r
.40134 .80634 m .40916 .8042 L .41149 .80619 L p F P
0 g
s
.649 .758 .929 r
.40916 .8042 m .40134 .80634 L .399 .80435 L p F P
0 g
s
.649 .758 .929 r
.41149 .80619 m .41932 .80405 L .42164 .80603 L p F P
0 g
s
.649 .758 .929 r
.41932 .80405 m .41149 .80619 L .40916 .8042 L p F P
0 g
s
.649 .758 .929 r
.42164 .80603 m .42949 .8039 L .43179 .80588 L p F P
0 g
s
.649 .758 .929 r
.42949 .8039 m .42164 .80603 L .41932 .80405 L p F P
0 g
s
.649 .758 .929 r
.43179 .80588 m .43966 .80374 L .44194 .80573 L p F P
0 g
s
.649 .758 .929 r
.43966 .80374 m .43179 .80588 L .42949 .8039 L p F P
0 g
s
.649 .758 .929 r
.44194 .80573 m .44983 .80359 L .4521 .80557 L p F P
0 g
s
.649 .758 .929 r
.44983 .80359 m .44194 .80573 L .43966 .80374 L p F P
0 g
s
.649 .758 .929 r
.4521 .80557 m .46 .80343 L .46226 .80541 L p F P
0 g
s
.649 .758 .929 r
.46 .80343 m .4521 .80557 L .44983 .80359 L p F P
0 g
s
.649 .758 .929 r
.46226 .80541 m .47017 .80327 L .47242 .80525 L p F P
0 g
s
.649 .758 .929 r
.47017 .80327 m .46226 .80541 L .46 .80343 L p F P
0 g
s
.649 .758 .929 r
.48035 .80311 m .47242 .80525 L .47017 .80327 L p F P
0 g
s
.649 .758 .929 r
.38884 .8045 m .39665 .80237 L .399 .80435 L p F P
0 g
s
.649 .758 .929 r
.39665 .80237 m .38884 .8045 L .38648 .80252 L p F P
0 g
s
.649 .758 .929 r
.399 .80435 m .40683 .80222 L .40916 .8042 L p F P
0 g
s
.649 .758 .929 r
.40683 .80222 m .399 .80435 L .39665 .80237 L p F P
0 g
s
.649 .758 .929 r
.40916 .8042 m .417 .80206 L .41932 .80405 L p F P
0 g
s
.649 .758 .929 r
.417 .80206 m .40916 .8042 L .40683 .80222 L p F P
0 g
s
.649 .758 .929 r
.41932 .80405 m .42718 .80191 L .42949 .8039 L p F P
0 g
s
.649 .758 .929 r
.42718 .80191 m .41932 .80405 L .417 .80206 L p F P
0 g
s
.649 .758 .929 r
.42949 .8039 m .43736 .80175 L .43966 .80374 L p F P
0 g
s
.649 .758 .929 r
.43736 .80175 m .42949 .8039 L .42718 .80191 L p F P
0 g
s
.649 .758 .929 r
.43966 .80374 m .44755 .80159 L .44983 .80359 L p F P
0 g
s
.649 .758 .929 r
.44755 .80159 m .43966 .80374 L .43736 .80175 L p F P
0 g
s
.649 .758 .929 r
.44983 .80359 m .45773 .80144 L .46 .80343 L p F P
0 g
s
.649 .758 .929 r
.45773 .80144 m .44983 .80359 L .44755 .80159 L p F P
0 g
s
.649 .758 .929 r
.46 .80343 m .46792 .80128 L .47017 .80327 L p F P
0 g
s
.649 .758 .929 r
.46792 .80128 m .46 .80343 L .45773 .80144 L p F P
0 g
s
.649 .758 .929 r
.47017 .80327 m .47811 .80111 L .48035 .80311 L p F P
0 g
s
.649 .758 .929 r
.47811 .80111 m .47017 .80327 L .46792 .80128 L p F P
0 g
s
.649 .758 .929 r
.48831 .80095 m .48035 .80311 L .47811 .80111 L p F P
0 g
s
.649 .758 .929 r
.38648 .80252 m .3943 .80037 L .39665 .80237 L p F P
0 g
s
.649 .758 .929 r
.3943 .80037 m .38648 .80252 L .38411 .80052 L p F P
0 g
s
.649 .758 .929 r
.39665 .80237 m .40449 .80022 L .40683 .80222 L p F P
0 g
s
.649 .758 .929 r
.40449 .80022 m .39665 .80237 L .3943 .80037 L p F P
0 g
s
.649 .758 .929 r
.40683 .80222 m .41468 .80007 L .417 .80206 L p F P
0 g
s
.649 .758 .929 r
.41468 .80007 m .40683 .80222 L .40449 .80022 L p F P
0 g
s
.649 .758 .929 r
.417 .80206 m .42487 .79991 L .42718 .80191 L p F P
0 g
s
.649 .758 .929 r
.42487 .79991 m .417 .80206 L .41468 .80007 L p F P
0 g
s
.649 .758 .929 r
.42718 .80191 m .43507 .79976 L .43736 .80175 L p F P
0 g
s
.649 .758 .929 r
.43507 .79976 m .42718 .80191 L .42487 .79991 L p F P
0 g
s
.649 .758 .929 r
.43736 .80175 m .44526 .7996 L .44755 .80159 L p F P
0 g
s
.649 .758 .929 r
.44526 .7996 m .43736 .80175 L .43507 .79976 L p F P
0 g
s
.649 .758 .929 r
.44755 .80159 m .45546 .79944 L .45773 .80144 L p F P
0 g
s
.649 .758 .929 r
.45546 .79944 m .44755 .80159 L .44526 .7996 L p F P
0 g
s
.649 .758 .929 r
.45773 .80144 m .46567 .79928 L .46792 .80128 L p F P
0 g
s
.649 .758 .929 r
.46567 .79928 m .45773 .80144 L .45546 .79944 L p F P
0 g
s
.649 .758 .929 r
.46792 .80128 m .47587 .79912 L .47811 .80111 L p F P
0 g
s
.649 .758 .929 r
.47587 .79912 m .46792 .80128 L .46567 .79928 L p F P
0 g
s
.649 .758 .929 r
.47811 .80111 m .48608 .79895 L .48831 .80095 L p F P
0 g
s
.649 .758 .929 r
.48608 .79895 m .47811 .80111 L .47587 .79912 L p F P
0 g
s
.65 .758 .929 r
.49629 .79879 m .48831 .80095 L .48608 .79895 L p F P
0 g
s
.649 .758 .929 r
.38411 .80052 m .39194 .79837 L .3943 .80037 L p F P
0 g
s
.649 .758 .929 r
.39194 .79837 m .38411 .80052 L .38174 .79853 L p F P
0 g
s
.649 .758 .929 r
.3943 .80037 m .40214 .79822 L .40449 .80022 L p F P
0 g
s
.649 .758 .929 r
.40214 .79822 m .3943 .80037 L .39194 .79837 L p F P
0 g
s
.649 .758 .929 r
.40449 .80022 m .41234 .79807 L .41468 .80007 L p F P
0 g
s
.649 .758 .929 r
.41234 .79807 m .40449 .80022 L .40214 .79822 L p F P
0 g
s
.649 .758 .929 r
.41468 .80007 m .42255 .79791 L .42487 .79991 L p F P
0 g
s
.649 .758 .929 r
.42255 .79791 m .41468 .80007 L .41234 .79807 L p F P
0 g
s
.649 .758 .929 r
.42487 .79991 m .43276 .79775 L .43507 .79976 L p F P
0 g
s
.649 .758 .929 r
.43276 .79775 m .42487 .79991 L .42255 .79791 L p F P
0 g
s
.649 .758 .929 r
.43507 .79976 m .44297 .7976 L .44526 .7996 L p F P
0 g
s
.649 .758 .929 r
.44297 .7976 m .43507 .79976 L .43276 .79775 L p F P
0 g
s
.649 .758 .929 r
.44526 .7996 m .45319 .79744 L .45546 .79944 L p F P
0 g
s
.649 .758 .929 r
.45319 .79744 m .44526 .7996 L .44297 .7976 L p F P
0 g
s
.649 .758 .929 r
.45546 .79944 m .4634 .79727 L .46567 .79928 L p F P
0 g
s
.649 .758 .929 r
.4634 .79727 m .45546 .79944 L .45319 .79744 L p F P
0 g
s
.649 .758 .929 r
.46567 .79928 m .47362 .79711 L .47587 .79912 L p F P
0 g
s
.649 .758 .929 r
.47362 .79711 m .46567 .79928 L .4634 .79727 L p F P
0 g
s
.649 .758 .929 r
.47587 .79912 m .48384 .79695 L .48608 .79895 L p F P
0 g
s
.65 .758 .929 r
.48384 .79695 m .47587 .79912 L .47362 .79711 L p F P
0 g
s
.65 .758 .929 r
.48608 .79895 m .49407 .79679 L .49629 .79879 L p F P
0 g
s
.65 .758 .929 r
.49407 .79679 m .48608 .79895 L .48384 .79695 L p F P
0 g
s
.65 .758 .929 r
.50429 .79662 m .49629 .79879 L .49407 .79679 L p F P
0 g
s
.649 .758 .929 r
.38174 .79853 m .38957 .79637 L .39194 .79837 L p F P
0 g
s
.649 .758 .929 r
.38957 .79637 m .38174 .79853 L .37936 .79652 L p F P
0 g
s
.649 .758 .929 r
.39194 .79837 m .39979 .79621 L .40214 .79822 L p F P
0 g
s
.649 .758 .929 r
.39979 .79621 m .39194 .79837 L .38957 .79637 L p F P
0 g
s
.649 .758 .929 r
.40214 .79822 m .41 .79606 L .41234 .79807 L p F P
0 g
s
.649 .758 .929 r
.41 .79606 m .40214 .79822 L .39979 .79621 L p F P
0 g
s
.649 .758 .929 r
.41234 .79807 m .42022 .7959 L .42255 .79791 L p F P
0 g
s
.649 .758 .929 r
.42022 .7959 m .41234 .79807 L .41 .79606 L p F P
0 g
s
.649 .758 .929 r
.42255 .79791 m .43045 .79575 L .43276 .79775 L p F P
0 g
s
.649 .758 .929 r
.43045 .79575 m .42255 .79791 L .42022 .7959 L p F P
0 g
s
.649 .758 .929 r
.43276 .79775 m .44067 .79559 L .44297 .7976 L p F P
0 g
s
.649 .758 .929 r
.44067 .79559 m .43276 .79775 L .43045 .79575 L p F P
0 g
s
.649 .758 .929 r
.44297 .7976 m .4509 .79543 L .45319 .79744 L p F P
0 g
s
.649 .758 .929 r
.4509 .79543 m .44297 .7976 L .44067 .79559 L p F P
0 g
s
.649 .758 .929 r
.45319 .79744 m .46113 .79526 L .4634 .79727 L p F P
0 g
s
.649 .758 .929 r
.46113 .79526 m .45319 .79744 L .4509 .79543 L p F P
0 g
s
.649 .758 .929 r
.4634 .79727 m .47137 .7951 L .47362 .79711 L p F P
0 g
s
.65 .758 .929 r
.47137 .7951 m .4634 .79727 L .46113 .79526 L p F P
0 g
s
.65 .758 .929 r
.47362 .79711 m .4816 .79494 L .48384 .79695 L p F P
0 g
s
.65 .758 .929 r
.4816 .79494 m .47362 .79711 L .47137 .7951 L p F P
0 g
s
.65 .758 .929 r
.48384 .79695 m .49184 .79477 L .49407 .79679 L p F P
0 g
s
.65 .758 .929 r
.49184 .79477 m .48384 .79695 L .4816 .79494 L p F P
0 g
s
.65 .758 .929 r
.49407 .79679 m .50208 .79461 L .50429 .79662 L p F P
0 g
s
.65 .758 .929 r
.50208 .79461 m .49407 .79679 L .49184 .79477 L p F P
0 g
s
.649 .758 .929 r
.37936 .79652 m .38719 .79436 L .38957 .79637 L p F P
0 g
s
.649 .758 .929 r
.38719 .79436 m .37936 .79652 L .37697 .79451 L p F P
0 g
s
.65 .758 .929 r
.51232 .79444 m .50429 .79662 L .50208 .79461 L p F P
0 g
s
.649 .758 .929 r
.38957 .79637 m .39742 .7942 L .39979 .79621 L p F P
0 g
s
.649 .758 .929 r
.39742 .7942 m .38957 .79637 L .38719 .79436 L p F P
0 g
s
.649 .758 .929 r
.39979 .79621 m .40766 .79405 L .41 .79606 L p F P
0 g
s
.649 .758 .929 r
.40766 .79405 m .39979 .79621 L .39742 .7942 L p F P
0 g
s
.649 .758 .929 r
.41 .79606 m .41789 .79389 L .42022 .7959 L p F P
0 g
s
.649 .758 .929 r
.41789 .79389 m .41 .79606 L .40766 .79405 L p F P
0 g
s
.649 .758 .929 r
.42022 .7959 m .42813 .79373 L .43045 .79575 L p F P
0 g
s
.649 .758 .929 r
.42813 .79373 m .42022 .7959 L .41789 .79389 L p F P
0 g
s
.649 .758 .929 r
.43045 .79575 m .43837 .79357 L .44067 .79559 L p F P
0 g
s
.649 .758 .929 r
.43837 .79357 m .43045 .79575 L .42813 .79373 L p F P
0 g
s
.649 .758 .929 r
.44067 .79559 m .44861 .79341 L .4509 .79543 L p F P
0 g
s
.649 .758 .929 r
.44861 .79341 m .44067 .79559 L .43837 .79357 L p F P
0 g
s
.649 .758 .929 r
.4509 .79543 m .45886 .79325 L .46113 .79526 L p F P
0 g
s
.649 .758 .929 r
.45886 .79325 m .4509 .79543 L .44861 .79341 L p F P
0 g
s
.65 .758 .929 r
.46113 .79526 m .4691 .79309 L .47137 .7951 L p F P
0 g
s
.65 .758 .929 r
.4691 .79309 m .46113 .79526 L .45886 .79325 L p F P
0 g
s
.65 .758 .929 r
.47137 .7951 m .47935 .79292 L .4816 .79494 L p F P
0 g
s
.65 .758 .929 r
.47935 .79292 m .47137 .7951 L .4691 .79309 L p F P
0 g
s
.65 .758 .929 r
.4816 .79494 m .48961 .79276 L .49184 .79477 L p F P
0 g
s
.65 .758 .929 r
.48961 .79276 m .4816 .79494 L .47935 .79292 L p F P
0 g
s
.65 .758 .929 r
.49184 .79477 m .49986 .79259 L .50208 .79461 L p F P
0 g
s
.65 .758 .929 r
.49986 .79259 m .49184 .79477 L .48961 .79276 L p F P
0 g
s
.649 .758 .929 r
.38481 .79234 m .37697 .79451 L .37457 .79249 L p F P
0 g
s
.649 .758 .929 r
.37697 .79451 m .38481 .79234 L .38719 .79436 L p F P
0 g
s
.65 .758 .929 r
.50208 .79461 m .51012 .79242 L .51232 .79444 L p F P
0 g
s
.65 .758 .929 r
.51012 .79242 m .50208 .79461 L .49986 .79259 L p F P
0 g
s
.649 .758 .929 r
.38719 .79436 m .39506 .79218 L .39742 .7942 L p F P
0 g
s
.649 .758 .929 r
.39506 .79218 m .38719 .79436 L .38481 .79234 L p F P
0 g
s
.65 .758 .929 r
.52038 .79226 m .51232 .79444 L .51012 .79242 L p F P
0 g
s
.649 .758 .929 r
.39742 .7942 m .4053 .79203 L .40766 .79405 L p F P
0 g
s
.649 .758 .929 r
.4053 .79203 m .39742 .7942 L .39506 .79218 L p F P
0 g
s
.649 .758 .929 r
.40766 .79405 m .41555 .79187 L .41789 .79389 L p F P
0 g
s
.649 .758 .929 r
.41555 .79187 m .40766 .79405 L .4053 .79203 L p F P
0 g
s
.649 .758 .929 r
.41789 .79389 m .4258 .79171 L .42813 .79373 L p F P
0 g
s
.649 .758 .929 r
.4258 .79171 m .41789 .79389 L .41555 .79187 L p F P
0 g
s
.649 .758 .929 r
.42813 .79373 m .43606 .79155 L .43837 .79357 L p F P
0 g
s
.649 .758 .929 r
.43606 .79155 m .42813 .79373 L .4258 .79171 L p F P
0 g
s
.649 .758 .929 r
.43837 .79357 m .44632 .79139 L .44861 .79341 L p F P
0 g
s
.649 .758 .929 r
.44632 .79139 m .43837 .79357 L .43606 .79155 L p F P
0 g
s
.649 .758 .929 r
.44861 .79341 m .45657 .79123 L .45886 .79325 L p F P
0 g
s
.65 .758 .929 r
.45657 .79123 m .44861 .79341 L .44632 .79139 L p F P
0 g
s
.65 .758 .929 r
.45886 .79325 m .46684 .79106 L .4691 .79309 L p F P
0 g
s
.65 .758 .929 r
.46684 .79106 m .45886 .79325 L .45657 .79123 L p F P
0 g
s
.65 .758 .929 r
.4691 .79309 m .4771 .7909 L .47935 .79292 L p F P
0 g
s
.65 .758 .929 r
.4771 .7909 m .4691 .79309 L .46684 .79106 L p F P
0 g
s
.65 .758 .929 r
.47935 .79292 m .48737 .79073 L .48961 .79276 L p F P
0 g
s
.65 .758 .929 r
.48737 .79073 m .47935 .79292 L .4771 .7909 L p F P
0 g
s
.65 .758 .929 r
.48961 .79276 m .49764 .79057 L .49986 .79259 L p F P
0 g
s
.65 .758 .929 r
.49764 .79057 m .48961 .79276 L .48737 .79073 L p F P
0 g
s
.649 .758 .929 r
.37457 .79249 m .38243 .79031 L .38481 .79234 L p F P
0 g
s
.649 .758 .929 r
.38243 .79031 m .37457 .79249 L .37217 .79047 L p F P
0 g
s
.65 .758 .929 r
.49986 .79259 m .50791 .7904 L .51012 .79242 L p F P
0 g
s
.65 .758 .929 r
.50791 .7904 m .49986 .79259 L .49764 .79057 L p F P
0 g
s
.649 .758 .929 r
.39268 .79016 m .38481 .79234 L .38243 .79031 L p F P
0 g
s
.649 .758 .929 r
.38481 .79234 m .39268 .79016 L .39506 .79218 L p F P
0 g
s
.65 .758 .929 r
.51012 .79242 m .51818 .79023 L .52038 .79226 L p F P
0 g
s
.65 .758 .929 r
.51818 .79023 m .51012 .79242 L .50791 .7904 L p F P
0 g
s
.649 .758 .929 r
.39506 .79218 m .40294 .79 L .4053 .79203 L p F P
0 g
s
.649 .758 .929 r
.40294 .79 m .39506 .79218 L .39268 .79016 L p F P
0 g
s
.65 .758 .929 r
.52846 .79006 m .52038 .79226 L .51818 .79023 L p F P
0 g
s
.649 .758 .929 r
.4053 .79203 m .41321 .78984 L .41555 .79187 L p F P
0 g
s
.649 .758 .929 r
.41321 .78984 m .4053 .79203 L .40294 .79 L p F P
0 g
s
.649 .758 .929 r
.41555 .79187 m .42347 .78968 L .4258 .79171 L p F P
0 g
s
.649 .758 .929 r
.42347 .78968 m .41555 .79187 L .41321 .78984 L p F P
0 g
s
.649 .758 .929 r
.4258 .79171 m .43374 .78952 L .43606 .79155 L p F P
0 g
s
.649 .758 .929 r
.43374 .78952 m .4258 .79171 L .42347 .78968 L p F P
0 g
s
.649 .758 .929 r
.43606 .79155 m .44401 .78936 L .44632 .79139 L p F P
0 g
s
.649 .758 .929 r
.44401 .78936 m .43606 .79155 L .43374 .78952 L p F P
0 g
s
.65 .758 .929 r
.44632 .79139 m .45429 .7892 L .45657 .79123 L p F P
0 g
s
.65 .758 .929 r
.45429 .7892 m .44632 .79139 L .44401 .78936 L p F P
0 g
s
.65 .758 .929 r
.45657 .79123 m .46456 .78903 L .46684 .79106 L p F P
0 g
s
.65 .758 .929 r
.46456 .78903 m .45657 .79123 L .45429 .7892 L p F P
0 g
s
.65 .758 .929 r
.46684 .79106 m .47484 .78887 L .4771 .7909 L p F P
0 g
s
.65 .758 .929 r
.47484 .78887 m .46684 .79106 L .46456 .78903 L p F P
0 g
s
.65 .758 .929 r
.4771 .7909 m .48512 .7887 L .48737 .79073 L p F P
0 g
s
.65 .758 .929 r
.48512 .7887 m .4771 .7909 L .47484 .78887 L p F P
0 g
s
.65 .758 .929 r
.48737 .79073 m .4954 .78854 L .49764 .79057 L p F P
0 g
s
.65 .758 .929 r
.4954 .78854 m .48737 .79073 L .48512 .7887 L p F P
0 g
s
.649 .758 .929 r
.38003 .78828 m .37217 .79047 L .36976 .78844 L p F P
0 g
s
.649 .758 .929 r
.37217 .79047 m .38003 .78828 L .38243 .79031 L p F P
0 g
s
.65 .758 .929 r
.49764 .79057 m .50569 .78837 L .50791 .7904 L p F P
0 g
s
.65 .758 .929 r
.50569 .78837 m .49764 .79057 L .4954 .78854 L p F P
0 g
s
.649 .758 .929 r
.38243 .79031 m .3903 .78813 L .39268 .79016 L p F P
0 g
s
.649 .758 .929 r
.3903 .78813 m .38243 .79031 L .38003 .78828 L p F P
0 g
s
.65 .758 .929 r
.50791 .7904 m .51598 .7882 L .51818 .79023 L p F P
0 g
s
.65 .758 .929 r
.51598 .7882 m .50791 .7904 L .50569 .78837 L p F P
0 g
s
.649 .758 .929 r
.39268 .79016 m .40058 .78797 L .40294 .79 L p F P
0 g
s
.649 .758 .929 r
.40058 .78797 m .39268 .79016 L .3903 .78813 L p F P
0 g
s
.65 .758 .929 r
.51818 .79023 m .52627 .78803 L .52846 .79006 L p F P
0 g
s
.65 .758 .929 r
.52627 .78803 m .51818 .79023 L .51598 .7882 L p F P
0 g
s
.649 .758 .929 r
.40294 .79 m .41086 .78781 L .41321 .78984 L p F P
0 g
s
.649 .758 .929 r
.41086 .78781 m .40294 .79 L .40058 .78797 L p F P
0 g
s
.65 .758 .929 r
.53656 .78786 m .52846 .79006 L .52627 .78803 L p F P
0 g
s
.649 .758 .929 r
.41321 .78984 m .42114 .78765 L .42347 .78968 L p F P
0 g
s
.649 .758 .929 r
.42114 .78765 m .41321 .78984 L .41086 .78781 L p F P
0 g
s
.649 .758 .929 r
.42347 .78968 m .43142 .78749 L .43374 .78952 L p F P
0 g
s
.649 .758 .929 r
.43142 .78749 m .42347 .78968 L .42114 .78765 L p F P
0 g
s
.649 .758 .929 r
.43374 .78952 m .4417 .78733 L .44401 .78936 L p F P
0 g
s
.65 .758 .929 r
.4417 .78733 m .43374 .78952 L .43142 .78749 L p F P
0 g
s
.65 .758 .929 r
.44401 .78936 m .45199 .78716 L .45429 .7892 L p F P
0 g
s
.65 .758 .929 r
.45199 .78716 m .44401 .78936 L .4417 .78733 L p F P
0 g
s
.65 .758 .929 r
.45429 .7892 m .46228 .787 L .46456 .78903 L p F P
0 g
s
.65 .758 .929 r
.46228 .787 m .45429 .7892 L .45199 .78716 L p F P
0 g
s
.65 .758 .929 r
.46456 .78903 m .47257 .78683 L .47484 .78887 L p F P
0 g
s
.65 .758 .929 r
.47257 .78683 m .46456 .78903 L .46228 .787 L p F P
0 g
s
.65 .758 .929 r
.47484 .78887 m .48287 .78667 L .48512 .7887 L p F P
0 g
s
.65 .758 .929 r
.48287 .78667 m .47484 .78887 L .47257 .78683 L p F P
0 g
s
.65 .758 .929 r
.48512 .7887 m .49316 .7865 L .4954 .78854 L p F P
0 g
s
.65 .758 .929 r
.49316 .7865 m .48512 .7887 L .48287 .78667 L p F P
0 g
s
.649 .758 .929 r
.36976 .78844 m .37763 .78625 L .38003 .78828 L p F P
0 g
s
.649 .758 .929 r
.37763 .78625 m .36976 .78844 L .36735 .7864 L p F P
0 g
s
.65 .758 .929 r
.4954 .78854 m .50346 .78633 L .50569 .78837 L p F P
0 g
s
.65 .758 .929 r
.50346 .78633 m .4954 .78854 L .49316 .7865 L p F P
0 g
s
.649 .758 .929 r
.38792 .78609 m .38003 .78828 L .37763 .78625 L p F P
0 g
s
.649 .758 .929 r
.38003 .78828 m .38792 .78609 L .3903 .78813 L p F P
0 g
s
.65 .758 .929 r
.50569 .78837 m .51377 .78616 L .51598 .7882 L p F P
0 g
s
.65 .758 .929 r
.51377 .78616 m .50569 .78837 L .50346 .78633 L p F P
0 g
s
.649 .758 .929 r
.3903 .78813 m .39821 .78593 L .40058 .78797 L p F P
0 g
s
.649 .758 .929 r
.39821 .78593 m .3903 .78813 L .38792 .78609 L p F P
0 g
s
.65 .758 .929 r
.51598 .7882 m .52407 .78599 L .52627 .78803 L p F P
0 g
s
.65 .758 .929 r
.52407 .78599 m .51598 .7882 L .51377 .78616 L p F P
0 g
s
.649 .758 .929 r
.4085 .78577 m .40058 .78797 L .39821 .78593 L p F P
0 g
s
.649 .758 .929 r
.40058 .78797 m .4085 .78577 L .41086 .78781 L p F P
0 g
s
.65 .758 .929 r
.52627 .78803 m .53438 .78582 L .53656 .78786 L p F P
0 g
s
.65 .758 .929 r
.53438 .78582 m .52627 .78803 L .52407 .78599 L p F P
0 g
s
.649 .758 .929 r
.41086 .78781 m .41879 .78561 L .42114 .78765 L p F P
0 g
s
.649 .758 .929 r
.41879 .78561 m .41086 .78781 L .4085 .78577 L p F P
0 g
s
.65 .758 .929 r
.54469 .78565 m .53656 .78786 L .53438 .78582 L p F P
0 g
s
.649 .758 .929 r
.42114 .78765 m .42909 .78545 L .43142 .78749 L p F P
0 g
s
.649 .758 .929 r
.42909 .78545 m .42114 .78765 L .41879 .78561 L p F P
0 g
s
.65 .758 .929 r
.43142 .78749 m .43939 .78529 L .4417 .78733 L p F P
0 g
s
.65 .758 .929 r
.43939 .78529 m .43142 .78749 L .42909 .78545 L p F P
0 g
s
.65 .758 .929 r
.4417 .78733 m .44969 .78512 L .45199 .78716 L p F P
0 g
s
.65 .758 .929 r
.44969 .78512 m .4417 .78733 L .43939 .78529 L p F P
0 g
s
.65 .758 .929 r
.45199 .78716 m .45999 .78496 L .46228 .787 L p F P
0 g
s
.65 .758 .929 r
.45999 .78496 m .45199 .78716 L .44969 .78512 L p F P
0 g
s
.65 .758 .929 r
.46228 .787 m .4703 .78479 L .47257 .78683 L p F P
0 g
s
.65 .758 .929 r
.4703 .78479 m .46228 .787 L .45999 .78496 L p F P
0 g
s
.65 .758 .929 r
.47257 .78683 m .48061 .78463 L .48287 .78667 L p F P
0 g
s
.65 .758 .929 r
.48061 .78463 m .47257 .78683 L .4703 .78479 L p F P
0 g
s
.65 .758 .929 r
.48287 .78667 m .49092 .78446 L .49316 .7865 L p F P
0 g
s
.65 .758 .929 r
.49092 .78446 m .48287 .78667 L .48061 .78463 L p F P
0 g
s
.649 .758 .929 r
.36735 .7864 m .37522 .7842 L .37763 .78625 L p F P
0 g
s
.649 .758 .929 r
.37522 .7842 m .36735 .7864 L .36492 .78436 L p F P
0 g
s
.65 .758 .929 r
.49316 .7865 m .50123 .78429 L .50346 .78633 L p F P
0 g
s
.65 .758 .929 r
.50123 .78429 m .49316 .7865 L .49092 .78446 L p F P
0 g
s
.649 .758 .929 r
.37763 .78625 m .38552 .78405 L .38792 .78609 L p F P
0 g
s
.649 .758 .929 r
.38552 .78405 m .37763 .78625 L .37522 .7842 L p F P
0 g
s
.65 .758 .929 r
.50346 .78633 m .51155 .78412 L .51377 .78616 L p F P
0 g
s
.65 .758 .929 r
.51155 .78412 m .50346 .78633 L .50123 .78429 L p F P
0 g
s
.649 .758 .929 r
.38792 .78609 m .39583 .78389 L .39821 .78593 L p F P
0 g
s
.649 .758 .929 r
.39583 .78389 m .38792 .78609 L .38552 .78405 L p F P
0 g
s
.65 .758 .929 r
.51377 .78616 m .52187 .78395 L .52407 .78599 L p F P
0 g
s
.65 .758 .929 r
.52187 .78395 m .51377 .78616 L .51155 .78412 L p F P
0 g
s
.649 .758 .929 r
.39821 .78593 m .40613 .78373 L .4085 .78577 L p F P
0 g
s
.649 .758 .929 r
.40613 .78373 m .39821 .78593 L .39583 .78389 L p F P
0 g
s
.65 .758 .929 r
.52407 .78599 m .53219 .78378 L .53438 .78582 L p F P
0 g
s
.65 .758 .929 r
.53219 .78378 m .52407 .78599 L .52187 .78395 L p F P
0 g
s
.649 .758 .929 r
.41644 .78357 m .4085 .78577 L .40613 .78373 L p F P
0 g
s
.649 .758 .929 r
.4085 .78577 m .41644 .78357 L .41879 .78561 L p F P
0 g
s
.65 .758 .929 r
.53438 .78582 m .54251 .78361 L .54469 .78565 L p F P
0 g
s
.65 .758 .928 r
.54251 .78361 m .53438 .78582 L .53219 .78378 L p F P
0 g
s
.649 .758 .929 r
.41879 .78561 m .42675 .7834 L .42909 .78545 L p F P
0 g
s
.65 .758 .929 r
.42675 .7834 m .41879 .78561 L .41644 .78357 L p F P
0 g
s
.65 .758 .929 r
.55284 .78344 m .54469 .78565 L .54251 .78361 L p F P
0 g
s
.65 .758 .929 r
.42909 .78545 m .43706 .78324 L .43939 .78529 L p F P
0 g
s
.65 .758 .929 r
.43706 .78324 m .42909 .78545 L .42675 .7834 L p F P
0 g
s
.65 .758 .929 r
.43939 .78529 m .44738 .78308 L .44969 .78512 L p F P
0 g
s
.65 .758 .929 r
.44738 .78308 m .43939 .78529 L .43706 .78324 L p F P
0 g
s
.65 .758 .929 r
.44969 .78512 m .4577 .78291 L .45999 .78496 L p F P
0 g
s
.65 .758 .929 r
.4577 .78291 m .44969 .78512 L .44738 .78308 L p F P
0 g
s
.65 .758 .929 r
.45999 .78496 m .46802 .78274 L .4703 .78479 L p F P
0 g
s
.65 .758 .929 r
.46802 .78274 m .45999 .78496 L .4577 .78291 L p F P
0 g
s
.65 .758 .929 r
.4703 .78479 m .47834 .78258 L .48061 .78463 L p F P
0 g
s
.65 .758 .929 r
.47834 .78258 m .4703 .78479 L .46802 .78274 L p F P
0 g
s
.65 .758 .929 r
.48061 .78463 m .48867 .78241 L .49092 .78446 L p F P
0 g
s
.65 .758 .928 r
.48867 .78241 m .48061 .78463 L .47834 .78258 L p F P
0 g
s
.649 .758 .929 r
.36492 .78436 m .37281 .78215 L .37522 .7842 L p F P
0 g
s
.649 .758 .929 r
.37281 .78215 m .36492 .78436 L .36249 .78231 L p F P
0 g
s
.65 .758 .929 r
.49092 .78446 m .499 .78224 L .50123 .78429 L p F P
0 g
s
.65 .758 .928 r
.499 .78224 m .49092 .78446 L .48867 .78241 L p F P
0 g
s
.649 .758 .929 r
.37522 .7842 m .38312 .782 L .38552 .78405 L p F P
0 g
s
.649 .758 .929 r
.38312 .782 m .37522 .7842 L .37281 .78215 L p F P
0 g
s
.65 .758 .929 r
.50123 .78429 m .50933 .78207 L .51155 .78412 L p F P
0 g
s
.65 .758 .928 r
.50933 .78207 m .50123 .78429 L .499 .78224 L p F P
0 g
s
.649 .758 .929 r
.38552 .78405 m .39344 .78184 L .39583 .78389 L p F P
0 g
s
.649 .758 .929 r
.39344 .78184 m .38552 .78405 L .38312 .782 L p F P
0 g
s
.65 .758 .929 r
.51155 .78412 m .51966 .7819 L .52187 .78395 L p F P
0 g
s
.65 .758 .928 r
.51966 .7819 m .51155 .78412 L .50933 .78207 L p F P
0 g
s
.649 .758 .929 r
.40376 .78168 m .39583 .78389 L .39344 .78184 L p F P
0 g
s
.649 .758 .929 r
.39583 .78389 m .40376 .78168 L .40613 .78373 L p F P
0 g
s
.65 .758 .929 r
.52187 .78395 m .53 .78173 L .53219 .78378 L p F P
0 g
s
.65 .758 .928 r
.53 .78173 m .52187 .78395 L .51966 .7819 L p F P
0 g
s
.649 .758 .929 r
.40613 .78373 m .41408 .78152 L .41644 .78357 L p F P
0 g
s
.649 .758 .929 r
.41408 .78152 m .40613 .78373 L .40376 .78168 L p F P
0 g
s
.65 .758 .928 r
.53219 .78378 m .54034 .78156 L .54251 .78361 L p F P
0 g
s
.65 .758 .928 r
.54034 .78156 m .53219 .78378 L .53 .78173 L p F P
0 g
s
.65 .758 .929 r
.41644 .78357 m .42441 .78135 L .42675 .7834 L p F P
0 g
s
.65 .758 .929 r
.42441 .78135 m .41644 .78357 L .41408 .78152 L p F P
0 g
s
.65 .758 .929 r
.54251 .78361 m .55068 .78139 L .55284 .78344 L p F P
0 g
s
.65 .758 .928 r
.55068 .78139 m .54251 .78361 L .54034 .78156 L p F P
0 g
s
.65 .758 .929 r
.42675 .7834 m .43473 .78119 L .43706 .78324 L p F P
0 g
s
.65 .758 .929 r
.43473 .78119 m .42675 .7834 L .42441 .78135 L p F P
0 g
s
.65 .758 .928 r
.56102 .78121 m .55284 .78344 L .55068 .78139 L p F P
0 g
s
.65 .758 .929 r
.43706 .78324 m .44507 .78102 L .44738 .78308 L p F P
0 g
s
.65 .758 .929 r
.44507 .78102 m .43706 .78324 L .43473 .78119 L p F P
0 g
s
.65 .758 .929 r
.44738 .78308 m .4554 .78086 L .4577 .78291 L p F P
0 g
s
.65 .758 .929 r
.4554 .78086 m .44738 .78308 L .44507 .78102 L p F P
0 g
s
.65 .758 .929 r
.4577 .78291 m .46573 .78069 L .46802 .78274 L p F P
0 g
s
.65 .758 .928 r
.46573 .78069 m .4577 .78291 L .4554 .78086 L p F P
0 g
s
.65 .758 .929 r
.46802 .78274 m .47607 .78052 L .47834 .78258 L p F P
0 g
s
.65 .758 .928 r
.47607 .78052 m .46802 .78274 L .46573 .78069 L p F P
0 g
s
.65 .758 .928 r
.47834 .78258 m .48641 .78035 L .48867 .78241 L p F P
0 g
s
.65 .758 .928 r
.48641 .78035 m .47834 .78258 L .47607 .78052 L p F P
0 g
s
.649 .758 .929 r
.36249 .78231 m .37038 .7801 L .37281 .78215 L p F P
0 g
s
.649 .758 .929 r
.37038 .7801 m .36249 .78231 L .36006 .78026 L p F P
0 g
s
.65 .758 .928 r
.48867 .78241 m .49675 .78019 L .499 .78224 L p F P
0 g
s
.65 .758 .928 r
.49675 .78019 m .48867 .78241 L .48641 .78035 L p F P
0 g
s
.649 .758 .929 r
.37281 .78215 m .38071 .77994 L .38312 .782 L p F P
0 g
s
.649 .758 .929 r
.38071 .77994 m .37281 .78215 L .37038 .7801 L p F P
0 g
s
.65 .758 .928 r
.499 .78224 m .5071 .78002 L .50933 .78207 L p F P
0 g
s
.65 .758 .928 r
.5071 .78002 m .499 .78224 L .49675 .78019 L p F P
0 g
s
.649 .758 .929 r
.38312 .782 m .39105 .77978 L .39344 .78184 L p F P
0 g
s
.649 .758 .929 r
.39105 .77978 m .38312 .782 L .38071 .77994 L p F P
0 g
s
.65 .758 .928 r
.50933 .78207 m .51745 .77985 L .51966 .7819 L p F P
0 g
s
.65 .758 .928 r
.51745 .77985 m .50933 .78207 L .5071 .78002 L p F P
0 g
s
.649 .758 .929 r
.39344 .78184 m .40138 .77962 L .40376 .78168 L p F P
0 g
s
.649 .758 .929 r
.40138 .77962 m .39344 .78184 L .39105 .77978 L p F P
0 g
s
.65 .758 .928 r
.51966 .7819 m .5278 .77967 L .53 .78173 L p F P
0 g
s
.65 .758 .928 r
.5278 .77967 m .51966 .7819 L .51745 .77985 L p F P
0 g
s
.65 .758 .929 r
.41172 .77946 m .40376 .78168 L .40138 .77962 L p F P
0 g
s
.649 .758 .929 r
.40376 .78168 m .41172 .77946 L .41408 .78152 L p F P
0 g
s
.65 .758 .928 r
.53 .78173 m .53815 .7795 L .54034 .78156 L p F P
0 g
s
.65 .758 .928 r
.53815 .7795 m .53 .78173 L .5278 .77967 L p F P
0 g
s
.65 .758 .929 r
.41408 .78152 m .42206 .77929 L .42441 .78135 L p F P
0 g
s
.65 .758 .929 r
.42206 .77929 m .41408 .78152 L .41172 .77946 L p F P
0 g
s
.65 .758 .928 r
.54034 .78156 m .5485 .77933 L .55068 .78139 L p F P
0 g
s
.65 .758 .928 r
.5485 .77933 m .54034 .78156 L .53815 .7795 L p F P
0 g
s
.65 .758 .929 r
.4324 .77913 m .42441 .78135 L .42206 .77929 L p F P
0 g
s
.65 .758 .929 r
.42441 .78135 m .4324 .77913 L .43473 .78119 L p F P
0 g
s
.65 .758 .928 r
.55068 .78139 m .55886 .77916 L .56102 .78121 L p F P
0 g
s
.65 .758 .928 r
.55886 .77916 m .55068 .78139 L .5485 .77933 L p F P
0 g
s
.65 .758 .929 r
.43473 .78119 m .44274 .77896 L .44507 .78102 L p F P
0 g
s
.65 .758 .928 r
.44274 .77896 m .43473 .78119 L .4324 .77913 L p F P
0 g
s
.65 .758 .928 r
.56922 .77898 m .56102 .78121 L .55886 .77916 L p F P
0 g
s
.65 .758 .929 r
.44507 .78102 m .45309 .7788 L .4554 .78086 L p F P
0 g
s
.65 .758 .928 r
.45309 .7788 m .44507 .78102 L .44274 .77896 L p F P
0 g
s
.65 .758 .928 r
.4554 .78086 m .46344 .77863 L .46573 .78069 L p F P
0 g
s
.65 .758 .928 r
.46344 .77863 m .4554 .78086 L .45309 .7788 L p F P
0 g
s
.65 .758 .928 r
.46573 .78069 m .47379 .77846 L .47607 .78052 L p F P
0 g
s
.65 .758 .928 r
.47379 .77846 m .46573 .78069 L .46344 .77863 L p F P
0 g
s
.65 .758 .928 r
.47607 .78052 m .48415 .77829 L .48641 .78035 L p F P
0 g
s
.65 .758 .928 r
.48415 .77829 m .47607 .78052 L .47379 .77846 L p F P
0 g
s
.649 .758 .929 r
.36006 .78026 m .36796 .77804 L .37038 .7801 L p F P
0 g
s
.649 .758 .929 r
.36796 .77804 m .36006 .78026 L .35761 .7782 L p F P
0 g
s
.65 .758 .928 r
.48641 .78035 m .4945 .77812 L .49675 .78019 L p F P
0 g
s
.65 .758 .928 r
.4945 .77812 m .48641 .78035 L .48415 .77829 L p F P
0 g
s
.649 .758 .929 r
.37038 .7801 m .3783 .77788 L .38071 .77994 L p F P
0 g
s
.649 .758 .929 r
.3783 .77788 m .37038 .7801 L .36796 .77804 L p F P
0 g
s
.65 .758 .928 r
.49675 .78019 m .50486 .77795 L .5071 .78002 L p F P
0 g
s
.65 .758 .928 r
.50486 .77795 m .49675 .78019 L .4945 .77812 L p F P
0 g
s
.649 .758 .929 r
.38071 .77994 m .38865 .77772 L .39105 .77978 L p F P
0 g
s
.649 .758 .929 r
.38865 .77772 m .38071 .77994 L .3783 .77788 L p F P
0 g
s
.65 .758 .928 r
.5071 .78002 m .51523 .77778 L .51745 .77985 L p F P
0 g
s
.65 .758 .928 r
.51523 .77778 m .5071 .78002 L .50486 .77795 L p F P
0 g
s
.649 .758 .929 r
.39105 .77978 m .39899 .77756 L .40138 .77962 L p F P
0 g
s
.649 .758 .929 r
.39899 .77756 m .39105 .77978 L .38865 .77772 L p F P
0 g
s
.65 .758 .928 r
.51745 .77985 m .52559 .77761 L .5278 .77967 L p F P
0 g
s
.65 .758 .928 r
.52559 .77761 m .51745 .77985 L .51523 .77778 L p F P
0 g
s
.65 .758 .929 r
.40138 .77962 m .40935 .77739 L .41172 .77946 L p F P
0 g
s
.65 .758 .929 r
.40935 .77739 m .40138 .77962 L .39899 .77756 L p F P
0 g
s
.65 .758 .928 r
.5278 .77967 m .53596 .77744 L .53815 .7795 L p F P
0 g
s
.65 .758 .928 r
.53596 .77744 m .5278 .77967 L .52559 .77761 L p F P
0 g
s
.65 .758 .929 r
.41172 .77946 m .4197 .77723 L .42206 .77929 L p F P
0 g
s
.65 .758 .929 r
.4197 .77723 m .41172 .77946 L .40935 .77739 L p F P
0 g
s
.65 .758 .928 r
.53815 .7795 m .54633 .77727 L .5485 .77933 L p F P
0 g
s
.65 .758 .928 r
.54633 .77727 m .53815 .7795 L .53596 .77744 L p F P
0 g
s
.65 .758 .929 r
.42206 .77929 m .43006 .77707 L .4324 .77913 L p F P
0 g
s
.65 .758 .928 r
.43006 .77707 m .42206 .77929 L .4197 .77723 L p F P
0 g
s
.65 .758 .928 r
.5485 .77933 m .5567 .77709 L .55886 .77916 L p F P
0 g
s
.65 .758 .928 r
.5567 .77709 m .5485 .77933 L .54633 .77727 L p F P
0 g
s
.65 .758 .928 r
.44042 .7769 m .4324 .77913 L .43006 .77707 L p F P
0 g
s
.65 .758 .928 r
.4324 .77913 m .44042 .7769 L .44274 .77896 L p F P
0 g
s
.65 .758 .928 r
.55886 .77916 m .56707 .77692 L .56922 .77898 L p F P
0 g
s
.65 .758 .928 r
.56707 .77692 m .55886 .77916 L .5567 .77709 L p F P
0 g
s
.65 .758 .928 r
.44274 .77896 m .45078 .77673 L .45309 .7788 L p F P
0 g
s
.65 .758 .928 r
.45078 .77673 m .44274 .77896 L .44042 .7769 L p F P
0 g
s
.65 .758 .928 r
.57745 .77674 m .56922 .77898 L .56707 .77692 L p F P
0 g
s
.65 .758 .928 r
.45309 .7788 m .46114 .77656 L .46344 .77863 L p F P
0 g
s
.65 .758 .928 r
.46114 .77656 m .45309 .7788 L .45078 .77673 L p F P
0 g
s
.65 .758 .928 r
.46344 .77863 m .47151 .7764 L .47379 .77846 L p F P
0 g
s
.65 .758 .928 r
.47151 .7764 m .46344 .77863 L .46114 .77656 L p F P
0 g
s
.65 .758 .928 r
.47379 .77846 m .48188 .77623 L .48415 .77829 L p F P
0 g
s
.65 .758 .928 r
.48188 .77623 m .47379 .77846 L .47151 .7764 L p F P
0 g
s
.649 .758 .929 r
.35761 .7782 m .36552 .77597 L .36796 .77804 L p F P
0 g
s
.649 .758 .929 r
.36552 .77597 m .35761 .7782 L .35516 .77613 L p F P
0 g
s
.65 .758 .928 r
.48415 .77829 m .49225 .77606 L .4945 .77812 L p F P
0 g
s
.65 .758 .928 r
.49225 .77606 m .48415 .77829 L .48188 .77623 L p F P
0 g
s
.649 .758 .929 r
.36796 .77804 m .37588 .77581 L .3783 .77788 L p F P
0 g
s
.649 .758 .929 r
.37588 .77581 m .36796 .77804 L .36552 .77597 L p F P
0 g
s
.65 .758 .928 r
.4945 .77812 m .50262 .77589 L .50486 .77795 L p F P
0 g
s
.65 .758 .928 r
.50262 .77589 m .4945 .77812 L .49225 .77606 L p F P
0 g
s
.649 .758 .929 r
.3783 .77788 m .38624 .77565 L .38865 .77772 L p F P
0 g
s
.649 .758 .929 r
.38624 .77565 m .3783 .77788 L .37588 .77581 L p F P
0 g
s
.65 .758 .928 r
.50486 .77795 m .513 .77571 L .51523 .77778 L p F P
0 g
s
.65 .758 .928 r
.513 .77571 m .50486 .77795 L .50262 .77589 L p F P
0 g
s
.649 .758 .929 r
.38865 .77772 m .3966 .77549 L .39899 .77756 L p F P
0 g
s
.649 .758 .929 r
.3966 .77549 m .38865 .77772 L .38624 .77565 L p F P
0 g
s
.65 .758 .928 r
.51523 .77778 m .52338 .77554 L .52559 .77761 L p F P
0 g
s
.65 .758 .928 r
.52338 .77554 m .51523 .77778 L .513 .77571 L p F P
0 g
s
.65 .758 .929 r
.39899 .77756 m .40697 .77532 L .40935 .77739 L p F P
0 g
s
.65 .758 .929 r
.40697 .77532 m .39899 .77756 L .3966 .77549 L p F P
0 g
s
.65 .758 .928 r
.52559 .77761 m .53376 .77537 L .53596 .77744 L p F P
0 g
s
.65 .758 .928 r
.53376 .77537 m .52559 .77761 L .52338 .77554 L p F P
0 g
s
.65 .758 .929 r
.40935 .77739 m .41734 .77516 L .4197 .77723 L p F P
0 g
s
.65 .758 .928 r
.41734 .77516 m .40935 .77739 L .40697 .77532 L p F P
0 g
s
.65 .758 .928 r
.53596 .77744 m .54414 .7752 L .54633 .77727 L p F P
0 g
s
.65 .758 .928 r
.54414 .7752 m .53596 .77744 L .53376 .77537 L p F P
0 g
s
.65 .758 .928 r
.42771 .77499 m .4197 .77723 L .41734 .77516 L p F P
0 g
s
.65 .758 .928 r
.4197 .77723 m .42771 .77499 L .43006 .77707 L p F P
0 g
s
.65 .758 .928 r
.54633 .77727 m .55453 .77502 L .5567 .77709 L p F P
0 g
s
.65 .758 .928 r
.55453 .77502 m .54633 .77727 L .54414 .7752 L p F P
0 g
s
.65 .758 .928 r
.43006 .77707 m .43808 .77483 L .44042 .7769 L p F P
0 g
s
.65 .758 .928 r
.43808 .77483 m .43006 .77707 L .42771 .77499 L p F P
0 g
s
.65 .758 .928 r
.5567 .77709 m .56492 .77485 L .56707 .77692 L p F P
0 g
s
.65 .758 .928 r
.56492 .77485 m .5567 .77709 L .55453 .77502 L p F P
0 g
s
.65 .758 .928 r
.44042 .7769 m .44846 .77466 L .45078 .77673 L p F P
0 g
s
.65 .758 .928 r
.44846 .77466 m .44042 .7769 L .43808 .77483 L p F P
0 g
s
.65 .758 .928 r
.56707 .77692 m .57531 .77467 L .57745 .77674 L p F P
0 g
s
.65 .758 .928 r
.57531 .77467 m .56707 .77692 L .56492 .77485 L p F P
0 g
s
.65 .758 .928 r
.45078 .77673 m .45884 .77449 L .46114 .77656 L p F P
0 g
s
.65 .758 .928 r
.45884 .77449 m .45078 .77673 L .44846 .77466 L p F P
0 g
s
.65 .758 .928 r
.5857 .77449 m .57745 .77674 L .57531 .77467 L p F P
0 g
s
.65 .758 .928 r
.46114 .77656 m .46922 .77432 L .47151 .7764 L p F P
0 g
s
.65 .758 .928 r
.46922 .77432 m .46114 .77656 L .45884 .77449 L p F P
0 g
s
.65 .758 .928 r
.47151 .7764 m .4796 .77415 L .48188 .77623 L p F P
0 g
s
.65 .758 .928 r
.4796 .77415 m .47151 .7764 L .46922 .77432 L p F P
0 g
s
.649 .758 .929 r
.35516 .77613 m .36308 .7739 L .36552 .77597 L p F P
0 g
s
.649 .758 .929 r
.36308 .7739 m .35516 .77613 L .35271 .77406 L p F P
0 g
s
.65 .758 .928 r
.48188 .77623 m .48999 .77398 L .49225 .77606 L p F P
0 g
s
.65 .758 .928 r
.48999 .77398 m .48188 .77623 L .4796 .77415 L p F P
0 g
s
.649 .758 .929 r
.36552 .77597 m .37345 .77374 L .37588 .77581 L p F P
0 g
s
.649 .758 .929 r
.37345 .77374 m .36552 .77597 L .36308 .7739 L p F P
0 g
s
.65 .758 .928 r
.49225 .77606 m .50038 .77381 L .50262 .77589 L p F P
0 g
s
.65 .758 .928 r
.50038 .77381 m .49225 .77606 L .48999 .77398 L p F P
0 g
s
.649 .758 .929 r
.37588 .77581 m .38383 .77357 L .38624 .77565 L p F P
0 g
s
.649 .758 .929 r
.38383 .77357 m .37588 .77581 L .37345 .77374 L p F P
0 g
s
.65 .758 .928 r
.50262 .77589 m .51077 .77364 L .513 .77571 L p F P
0 g
s
.65 .758 .928 r
.51077 .77364 m .50262 .77589 L .50038 .77381 L p F P
0 g
s
.649 .758 .929 r
.38624 .77565 m .3942 .77341 L .3966 .77549 L p F P
0 g
s
.65 .758 .929 r
.3942 .77341 m .38624 .77565 L .38383 .77357 L p F P
0 g
s
.65 .758 .928 r
.513 .77571 m .52116 .77347 L .52338 .77554 L p F P
0 g
s
.65 .758 .928 r
.52116 .77347 m .513 .77571 L .51077 .77364 L p F P
0 g
s
.65 .758 .929 r
.3966 .77549 m .40458 .77325 L .40697 .77532 L p F P
0 g
s
.65 .758 .928 r
.40458 .77325 m .3966 .77549 L .3942 .77341 L p F P
0 g
s
.65 .758 .928 r
.52338 .77554 m .53156 .77329 L .53376 .77537 L p F P
0 g
s
.65 .758 .928 r
.53156 .77329 m .52338 .77554 L .52116 .77347 L p F P
0 g
s
.65 .758 .928 r
.40697 .77532 m .41497 .77308 L .41734 .77516 L p F P
0 g
s
.65 .758 .928 r
.41497 .77308 m .40697 .77532 L .40458 .77325 L p F P
0 g
s
.65 .758 .928 r
.53376 .77537 m .54195 .77312 L .54414 .7752 L p F P
0 g
s
.65 .758 .928 r
.54195 .77312 m .53376 .77537 L .53156 .77329 L p F P
0 g
s
.65 .758 .928 r
.41734 .77516 m .42535 .77292 L .42771 .77499 L p F P
0 g
s
.65 .758 .928 r
.42535 .77292 m .41734 .77516 L .41497 .77308 L p F P
0 g
s
.65 .758 .928 r
.54414 .7752 m .55235 .77294 L .55453 .77502 L p F P
0 g
s
.65 .758 .928 r
.55235 .77294 m .54414 .7752 L .54195 .77312 L p F P
0 g
s
.65 .758 .928 r
.43574 .77275 m .42771 .77499 L .42535 .77292 L p F P
0 g
s
.65 .758 .928 r
.42771 .77499 m .43574 .77275 L .43808 .77483 L p F P
0 g
s
.65 .758 .928 r
.55453 .77502 m .56276 .77277 L .56492 .77485 L p F P
0 g
s
.65 .758 .928 r
.56276 .77277 m .55453 .77502 L .55235 .77294 L p F P
0 g
s
.65 .758 .928 r
.43808 .77483 m .44613 .77258 L .44846 .77466 L p F P
0 g
s
.65 .758 .928 r
.44613 .77258 m .43808 .77483 L .43574 .77275 L p F P
0 g
s
.65 .758 .928 r
.56492 .77485 m .57316 .77259 L .57531 .77467 L p F P
0 g
s
.65 .758 .928 r
.57316 .77259 m .56492 .77485 L .56276 .77277 L p F P
0 g
s
.65 .758 .928 r
.44846 .77466 m .45652 .77241 L .45884 .77449 L p F P
0 g
s
.65 .758 .928 r
.45652 .77241 m .44846 .77466 L .44613 .77258 L p F P
0 g
s
.65 .758 .928 r
.57531 .77467 m .58357 .77242 L .5857 .77449 L p F P
0 g
s
.65 .758 .928 r
.58357 .77242 m .57531 .77467 L .57316 .77259 L p F P
0 g
s
.65 .758 .928 r
.45884 .77449 m .46692 .77224 L .46922 .77432 L p F P
0 g
s
.65 .758 .928 r
.46692 .77224 m .45884 .77449 L .45652 .77241 L p F P
0 g
s
.65 .758 .928 r
.59398 .77224 m .5857 .77449 L .58357 .77242 L p F P
0 g
s
.65 .758 .928 r
.46922 .77432 m .47732 .77207 L .4796 .77415 L p F P
0 g
s
.65 .758 .928 r
.47732 .77207 m .46922 .77432 L .46692 .77224 L p F P
0 g
s
.649 .758 .929 r
.35271 .77406 m .36063 .77182 L .36308 .7739 L p F P
0 g
s
.649 .758 .929 r
.36063 .77182 m .35271 .77406 L .35024 .77198 L p F P
0 g
s
.65 .758 .928 r
.4796 .77415 m .48772 .7719 L .48999 .77398 L p F P
0 g
s
.65 .758 .928 r
.48772 .7719 m .4796 .77415 L .47732 .77207 L p F P
0 g
s
.649 .758 .929 r
.36308 .7739 m .37101 .77166 L .37345 .77374 L p F P
0 g
s
.649 .758 .929 r
.37101 .77166 m .36308 .7739 L .36063 .77182 L p F P
0 g
s
.65 .758 .928 r
.48999 .77398 m .49812 .77173 L .50038 .77381 L p F P
0 g
s
.65 .758 .928 r
.49812 .77173 m .48999 .77398 L .48772 .7719 L p F P
0 g
s
.649 .758 .929 r
.37345 .77374 m .3814 .77149 L .38383 .77357 L p F P
0 g
s
.649 .758 .929 r
.3814 .77149 m .37345 .77374 L .37101 .77166 L p F P
0 g
s
.65 .758 .928 r
.50038 .77381 m .50853 .77156 L .51077 .77364 L p F P
0 g
s
.65 .758 .928 r
.50853 .77156 m .50038 .77381 L .49812 .77173 L p F P
0 g
s
.65 .758 .929 r
.38383 .77357 m .3918 .77133 L .3942 .77341 L p F P
0 g
s
.65 .758 .928 r
.3918 .77133 m .38383 .77357 L .3814 .77149 L p F P
0 g
s
.65 .758 .928 r
.51077 .77364 m .51893 .77139 L .52116 .77347 L p F P
0 g
s
.65 .758 .928 r
.51893 .77139 m .51077 .77364 L .50853 .77156 L p F P
0 g
s
.65 .758 .928 r
.3942 .77341 m .40219 .77117 L .40458 .77325 L p F P
0 g
s
.65 .758 .928 r
.40219 .77117 m .3942 .77341 L .3918 .77133 L p F P
0 g
s
.65 .758 .928 r
.52116 .77347 m .52935 .77121 L .53156 .77329 L p F P
0 g
s
.65 .758 .928 r
.52935 .77121 m .52116 .77347 L .51893 .77139 L p F P
0 g
s
.65 .758 .928 r
.40458 .77325 m .41259 .771 L .41497 .77308 L p F P
0 g
s
.65 .758 .928 r
.41259 .771 m .40458 .77325 L .40219 .77117 L p F P
0 g
s
.65 .758 .928 r
.53156 .77329 m .53976 .77104 L .54195 .77312 L p F P
0 g
s
.65 .758 .928 r
.53976 .77104 m .53156 .77329 L .52935 .77121 L p F P
0 g
s
.65 .758 .928 r
.41497 .77308 m .42299 .77083 L .42535 .77292 L p F P
0 g
s
.65 .758 .928 r
.42299 .77083 m .41497 .77308 L .41259 .771 L p F P
0 g
s
.65 .758 .928 r
.54195 .77312 m .55017 .77086 L .55235 .77294 L p F P
0 g
s
.65 .758 .928 r
.55017 .77086 m .54195 .77312 L .53976 .77104 L p F P
0 g
s
.65 .758 .928 r
.42535 .77292 m .43339 .77067 L .43574 .77275 L p F P
0 g
s
.65 .758 .928 r
.43339 .77067 m .42535 .77292 L .42299 .77083 L p F P
0 g
s
.65 .758 .928 r
.55235 .77294 m .56059 .77069 L .56276 .77277 L p F P
0 g
s
.65 .758 .928 r
.56059 .77069 m .55235 .77294 L .55017 .77086 L p F P
0 g
s
.65 .758 .928 r
.4438 .7705 m .43574 .77275 L .43339 .77067 L p F P
0 g
s
.65 .758 .928 r
.43574 .77275 m .4438 .7705 L .44613 .77258 L p F P
0 g
s
.65 .758 .928 r
.56276 .77277 m .57101 .77051 L .57316 .77259 L p F P
0 g
s
.65 .758 .928 r
.57101 .77051 m .56276 .77277 L .56059 .77069 L p F P
0 g
s
.65 .758 .928 r
.44613 .77258 m .4542 .77033 L .45652 .77241 L p F P
0 g
s
.65 .758 .928 r
.4542 .77033 m .44613 .77258 L .4438 .7705 L p F P
0 g
s
.65 .758 .928 r
.57316 .77259 m .58143 .77033 L .58357 .77242 L p F P
0 g
s
.65 .758 .928 r
.58143 .77033 m .57316 .77259 L .57101 .77051 L p F P
0 g
s
.65 .758 .928 r
.46461 .77016 m .45652 .77241 L .4542 .77033 L p F P
0 g
s
.65 .758 .928 r
.45652 .77241 m .46461 .77016 L .46692 .77224 L p F P
0 g
s
.65 .758 .928 r
.58357 .77242 m .59186 .77016 L .59398 .77224 L p F P
0 g
s
.65 .758 .928 r
.59186 .77016 m .58357 .77242 L .58143 .77033 L p F P
0 g
s
.65 .758 .928 r
.60229 .76998 m .59398 .77224 L .59186 .77016 L p F P
0 g
s
.65 .758 .928 r
.46692 .77224 m .47503 .76999 L .47732 .77207 L p F P
0 g
s
.65 .758 .928 r
.47503 .76999 m .46692 .77224 L .46461 .77016 L p F P
0 g
s
.649 .758 .929 r
.35024 .77198 m .35817 .76973 L .36063 .77182 L p F P
0 g
s
.649 .758 .929 r
.35817 .76973 m .35024 .77198 L .34777 .76989 L p F P
0 g
s
.65 .758 .928 r
.47732 .77207 m .48544 .76982 L .48772 .7719 L p F P
0 g
s
.65 .758 .928 r
.48544 .76982 m .47732 .77207 L .47503 .76999 L p F P
0 g
s
.649 .758 .929 r
.36063 .77182 m .36857 .76957 L .37101 .77166 L p F P
0 g
s
.649 .758 .929 r
.36857 .76957 m .36063 .77182 L .35817 .76973 L p F P
0 g
s
.65 .758 .928 r
.48772 .7719 m .49586 .76964 L .49812 .77173 L p F P
0 g
s
.65 .758 .928 r
.49586 .76964 m .48772 .7719 L .48544 .76982 L p F P
0 g
s
.649 .758 .929 r
.37101 .77166 m .37898 .76941 L .3814 .77149 L p F P
0 g
s
.649 .758 .928 r
.37898 .76941 m .37101 .77166 L .36857 .76957 L p F P
0 g
s
.65 .758 .928 r
.49812 .77173 m .50628 .76947 L .50853 .77156 L p F P
0 g
s
.65 .758 .928 r
.50628 .76947 m .49812 .77173 L .49586 .76964 L p F P
0 g
s
.65 .758 .928 r
.3814 .77149 m .38938 .76924 L .3918 .77133 L p F P
0 g
s
.65 .758 .928 r
.38938 .76924 m .3814 .77149 L .37898 .76941 L p F P
0 g
s
.65 .758 .928 r
.50853 .77156 m .5167 .7693 L .51893 .77139 L p F P
0 g
s
.65 .758 .928 r
.5167 .7693 m .50853 .77156 L .50628 .76947 L p F P
0 g
s
.65 .758 .928 r
.3918 .77133 m .39979 .76908 L .40219 .77117 L p F P
0 g
s
.65 .758 .928 r
.39979 .76908 m .3918 .77133 L .38938 .76924 L p F P
0 g
s
.65 .758 .928 r
.51893 .77139 m .52713 .76912 L .52935 .77121 L p F P
0 g
s
.65 .758 .928 r
.52713 .76912 m .51893 .77139 L .5167 .7693 L p F P
0 g
s
.65 .758 .928 r
.40219 .77117 m .41021 .76891 L .41259 .771 L p F P
0 g
s
.65 .758 .928 r
.41021 .76891 m .40219 .77117 L .39979 .76908 L p F P
0 g
s
.65 .758 .928 r
.52935 .77121 m .53756 .76895 L .53976 .77104 L p F P
0 g
s
.65 .758 .928 r
.53756 .76895 m .52935 .77121 L .52713 .76912 L p F P
0 g
s
.65 .758 .928 r
.41259 .771 m .42062 .76874 L .42299 .77083 L p F P
0 g
s
.65 .758 .928 r
.42062 .76874 m .41259 .771 L .41021 .76891 L p F P
0 g
s
.65 .758 .928 r
.53976 .77104 m .54799 .76877 L .55017 .77086 L p F P
0 g
s
.65 .758 .928 r
.54799 .76877 m .53976 .77104 L .53756 .76895 L p F P
0 g
s
.65 .758 .928 r
.42299 .77083 m .43104 .76858 L .43339 .77067 L p F P
0 g
s
.65 .758 .928 r
.43104 .76858 m .42299 .77083 L .42062 .76874 L p F P
0 g
s
.65 .758 .928 r
.55017 .77086 m .55842 .7686 L .56059 .77069 L p F P
0 g
s
.65 .758 .928 r
.55842 .7686 m .55017 .77086 L .54799 .76877 L p F P
0 g
s
.65 .758 .928 r
.43339 .77067 m .44146 .76841 L .4438 .7705 L p F P
0 g
s
.65 .758 .928 r
.44146 .76841 m .43339 .77067 L .43104 .76858 L p F P
0 g
s
.65 .758 .928 r
.56059 .77069 m .56885 .76842 L .57101 .77051 L p F P
0 g
s
.65 .758 .928 r
.56885 .76842 m .56059 .77069 L .55842 .7686 L p F P
0 g
s
.65 .758 .928 r
.45188 .76824 m .4438 .7705 L .44146 .76841 L p F P
0 g
s
.65 .758 .928 r
.4438 .7705 m .45188 .76824 L .4542 .77033 L p F P
0 g
s
.65 .758 .928 r
.57101 .77051 m .57929 .76824 L .58143 .77033 L p F P
0 g
s
.65 .758 .928 r
.57929 .76824 m .57101 .77051 L .56885 .76842 L p F P
0 g
s
.65 .758 .928 r
.4542 .77033 m .4623 .76807 L .46461 .77016 L p F P
0 g
s
.65 .758 .928 r
.4623 .76807 m .4542 .77033 L .45188 .76824 L p F P
0 g
s
.65 .758 .928 r
.58143 .77033 m .58973 .76807 L .59186 .77016 L p F P
0 g
s
.65 .758 .928 r
.58973 .76807 m .58143 .77033 L .57929 .76824 L p F P
0 g
s
.65 .758 .928 r
.59186 .77016 m .60017 .76789 L .60229 .76998 L p F P
0 g
s
.65 .758 .928 r
.60017 .76789 m .59186 .77016 L .58973 .76807 L p F P
0 g
s
.65 .758 .928 r
.47273 .76789 m .46461 .77016 L .4623 .76807 L p F P
0 g
s
.65 .758 .928 r
.46461 .77016 m .47273 .76789 L .47503 .76999 L p F P
0 g
s
.649 .758 .929 r
.34777 .76989 m .35571 .76764 L .35817 .76973 L p F P
0 g
s
.649 .758 .929 r
.35571 .76764 m .34777 .76989 L .34529 .7678 L p F P
0 g
s
.65 .758 .928 r
.61062 .76771 m .60229 .76998 L .60017 .76789 L p F P
0 g
s
.65 .758 .928 r
.47503 .76999 m .48316 .76772 L .48544 .76982 L p F P
0 g
s
.65 .758 .928 r
.48316 .76772 m .47503 .76999 L .47273 .76789 L p F P
0 g
s
.649 .758 .929 r
.35817 .76973 m .36612 .76748 L .36857 .76957 L p F P
0 g
s
.649 .758 .928 r
.36612 .76748 m .35817 .76973 L .35571 .76764 L p F P
0 g
s
.65 .758 .928 r
.48544 .76982 m .49359 .76755 L .49586 .76964 L p F P
0 g
s
.65 .758 .928 r
.49359 .76755 m .48544 .76982 L .48316 .76772 L p F P
0 g
s
.649 .758 .928 r
.36857 .76957 m .37654 .76731 L .37898 .76941 L p F P
0 g
s
.65 .758 .928 r
.37654 .76731 m .36857 .76957 L .36612 .76748 L p F P
0 g
s
.65 .758 .928 r
.49586 .76964 m .50403 .76738 L .50628 .76947 L p F P
0 g
s
.65 .758 .928 r
.50403 .76738 m .49586 .76964 L .49359 .76755 L p F P
0 g
s
.65 .758 .928 r
.37898 .76941 m .38696 .76715 L .38938 .76924 L p F P
0 g
s
.65 .758 .928 r
.38696 .76715 m .37898 .76941 L .37654 .76731 L p F P
0 g
s
.65 .758 .928 r
.50628 .76947 m .51447 .7672 L .5167 .7693 L p F P
0 g
s
.65 .758 .928 r
.51447 .7672 m .50628 .76947 L .50403 .76738 L p F P
0 g
s
.65 .758 .928 r
.38938 .76924 m .39739 .76698 L .39979 .76908 L p F P
0 g
s
.65 .758 .928 r
.39739 .76698 m .38938 .76924 L .38696 .76715 L p F P
0 g
s
.65 .758 .928 r
.5167 .7693 m .5249 .76703 L .52713 .76912 L p F P
0 g
s
.65 .758 .928 r
.5249 .76703 m .5167 .7693 L .51447 .7672 L p F P
0 g
s
.65 .758 .928 r
.39979 .76908 m .40782 .76682 L .41021 .76891 L p F P
0 g
s
.65 .758 .928 r
.40782 .76682 m .39979 .76908 L .39739 .76698 L p F P
0 g
s
.65 .758 .928 r
.52713 .76912 m .53535 .76685 L .53756 .76895 L p F P
0 g
s
.65 .758 .928 r
.53535 .76685 m .52713 .76912 L .5249 .76703 L p F P
0 g
s
.65 .758 .928 r
.41021 .76891 m .41824 .76665 L .42062 .76874 L p F P
0 g
s
.65 .758 .928 r
.41824 .76665 m .41021 .76891 L .40782 .76682 L p F P
0 g
s
.65 .758 .928 r
.53756 .76895 m .54579 .76668 L .54799 .76877 L p F P
0 g
s
.65 .758 .928 r
.54579 .76668 m .53756 .76895 L .53535 .76685 L p F P
0 g
s
.65 .758 .928 r
.42062 .76874 m .42868 .76648 L .43104 .76858 L p F P
0 g
s
.65 .758 .928 r
.42868 .76648 m .42062 .76874 L .41824 .76665 L p F P
0 g
s
.65 .758 .928 r
.54799 .76877 m .55624 .7665 L .55842 .7686 L p F P
0 g
s
.65 .758 .928 r
.55624 .7665 m .54799 .76877 L .54579 .76668 L p F P
0 g
s
.65 .758 .928 r
.43104 .76858 m .43911 .76631 L .44146 .76841 L p F P
0 g
s
.65 .758 .928 r
.43911 .76631 m .43104 .76858 L .42868 .76648 L p F P
0 g
s
.65 .758 .928 r
.55842 .7686 m .56669 .76633 L .56885 .76842 L p F P
0 g
s
.65 .758 .928 r
.56669 .76633 m .55842 .7686 L .55624 .7665 L p F P
0 g
s
.65 .758 .928 r
.44146 .76841 m .44955 .76614 L .45188 .76824 L p F P
0 g
s
.65 .758 .928 r
.44955 .76614 m .44146 .76841 L .43911 .76631 L p F P
0 g
s
.65 .758 .928 r
.56885 .76842 m .57714 .76615 L .57929 .76824 L p F P
0 g
s
.65 .758 .928 r
.57714 .76615 m .56885 .76842 L .56669 .76633 L p F P
0 g
s
.65 .758 .928 r
.45999 .76597 m .45188 .76824 L .44955 .76614 L p F P
0 g
s
.65 .758 .928 r
.45188 .76824 m .45999 .76597 L .4623 .76807 L p F P
0 g
s
.65 .758 .928 r
.57929 .76824 m .5876 .76597 L .58973 .76807 L p F P
0 g
s
.65 .758 .928 r
.5876 .76597 m .57929 .76824 L .57714 .76615 L p F P
0 g
s
.65 .758 .928 r
.58973 .76807 m .59805 .76579 L .60017 .76789 L p F P
0 g
s
.65 .758 .928 r
.59805 .76579 m .58973 .76807 L .5876 .76597 L p F P
0 g
s
.65 .758 .928 r
.4623 .76807 m .47043 .7658 L .47273 .76789 L p F P
0 g
s
.65 .758 .928 r
.47043 .7658 m .4623 .76807 L .45999 .76597 L p F P
0 g
s
.649 .758 .929 r
.34529 .7678 m .35324 .76554 L .35571 .76764 L p F P
0 g
s
.649 .758 .929 r
.35324 .76554 m .34529 .7678 L .34281 .7657 L p F P
0 g
s
.65 .758 .928 r
.60017 .76789 m .60851 .76561 L .61062 .76771 L p F P
0 g
s
.65 .758 .928 r
.60851 .76561 m .60017 .76789 L .59805 .76579 L p F P
0 g
s
.65 .758 .928 r
.48087 .76562 m .47273 .76789 L .47043 .7658 L p F P
0 g
s
.65 .758 .928 r
.47273 .76789 m .48087 .76562 L .48316 .76772 L p F P
0 g
s
.649 .758 .928 r
.35571 .76764 m .36367 .76538 L .36612 .76748 L p F P
0 g
s
.649 .758 .928 r
.36367 .76538 m .35571 .76764 L .35324 .76554 L p F P
0 g
s
.65 .758 .928 r
.61897 .76543 m .61062 .76771 L .60851 .76561 L p F P
0 g
s
.65 .758 .928 r
.48316 .76772 m .49132 .76545 L .49359 .76755 L p F P
0 g
s
.65 .758 .928 r
.49132 .76545 m .48316 .76772 L .48087 .76562 L p F P
0 g
s
.65 .758 .928 r
.36612 .76748 m .3741 .76521 L .37654 .76731 L p F P
0 g
s
.65 .758 .928 r
.3741 .76521 m .36612 .76748 L .36367 .76538 L p F P
0 g
s
.65 .758 .928 r
.49359 .76755 m .50177 .76528 L .50403 .76738 L p F P
0 g
s
.65 .758 .928 r
.50177 .76528 m .49359 .76755 L .49132 .76545 L p F P
0 g
s
.65 .758 .928 r
.37654 .76731 m .38454 .76505 L .38696 .76715 L p F P
0 g
s
.65 .758 .928 r
.38454 .76505 m .37654 .76731 L .3741 .76521 L p F P
0 g
s
.65 .758 .928 r
.50403 .76738 m .51222 .7651 L .51447 .7672 L p F P
0 g
s
.65 .758 .928 r
.51222 .7651 m .50403 .76738 L .50177 .76528 L p F P
0 g
s
.65 .758 .928 r
.38696 .76715 m .39498 .76488 L .39739 .76698 L p F P
0 g
s
.65 .758 .928 r
.39498 .76488 m .38696 .76715 L .38454 .76505 L p F P
0 g
s
.65 .758 .928 r
.51447 .7672 m .52268 .76493 L .5249 .76703 L p F P
0 g
s
.65 .758 .928 r
.52268 .76493 m .51447 .7672 L .51222 .7651 L p F P
0 g
s
.65 .758 .928 r
.39739 .76698 m .40542 .76471 L .40782 .76682 L p F P
0 g
s
.65 .758 .928 r
.40542 .76471 m .39739 .76698 L .39498 .76488 L p F P
0 g
s
.65 .758 .928 r
.5249 .76703 m .53313 .76475 L .53535 .76685 L p F P
0 g
s
.65 .758 .928 r
.53313 .76475 m .5249 .76703 L .52268 .76493 L p F P
0 g
s
.65 .758 .928 r
.40782 .76682 m .41586 .76455 L .41824 .76665 L p F P
0 g
s
.65 .758 .928 r
.41586 .76455 m .40782 .76682 L .40542 .76471 L p F P
0 g
s
.65 .758 .928 r
.53535 .76685 m .54359 .76458 L .54579 .76668 L p F P
0 g
s
.65 .758 .928 r
.54359 .76458 m .53535 .76685 L .53313 .76475 L p F P
0 g
s
.65 .758 .928 r
.41824 .76665 m .42631 .76438 L .42868 .76648 L p F P
0 g
s
.65 .758 .928 r
.42631 .76438 m .41824 .76665 L .41586 .76455 L p F P
0 g
s
.65 .758 .928 r
.54579 .76668 m .55405 .7644 L .55624 .7665 L p F P
0 g
s
.65 .758 .928 r
.55405 .7644 m .54579 .76668 L .54359 .76458 L p F P
0 g
s
.65 .758 .928 r
.42868 .76648 m .43676 .76421 L .43911 .76631 L p F P
0 g
s
.65 .758 .928 r
.43676 .76421 m .42868 .76648 L .42631 .76438 L p F P
0 g
s
.65 .758 .928 r
.55624 .7665 m .56452 .76422 L .56669 .76633 L p F P
0 g
s
.65 .758 .928 r
.56452 .76422 m .55624 .7665 L .55405 .7644 L p F P
0 g
s
.65 .758 .928 r
.43911 .76631 m .44721 .76404 L .44955 .76614 L p F P
0 g
s
.65 .758 .928 r
.44721 .76404 m .43911 .76631 L .43676 .76421 L p F P
0 g
s
.65 .758 .928 r
.56669 .76633 m .57498 .76404 L .57714 .76615 L p F P
0 g
s
.65 .758 .928 r
.57498 .76404 m .56669 .76633 L .56452 .76422 L p F P
0 g
s
.65 .758 .928 r
.44955 .76614 m .45766 .76386 L .45999 .76597 L p F P
0 g
s
.65 .758 .928 r
.45766 .76386 m .44955 .76614 L .44721 .76404 L p F P
0 g
s
.65 .758 .928 r
.57714 .76615 m .58545 .76387 L .5876 .76597 L p F P
0 g
s
.65 .758 .928 r
.58545 .76387 m .57714 .76615 L .57498 .76404 L p F P
0 g
s
.65 .758 .928 r
.46812 .76369 m .45999 .76597 L .45766 .76386 L p F P
0 g
s
.65 .758 .928 r
.45999 .76597 m .46812 .76369 L .47043 .7658 L p F P
0 g
s
.65 .758 .928 r
.5876 .76597 m .59593 .76369 L .59805 .76579 L p F P
0 g
s
.65 .758 .928 r
.59593 .76369 m .5876 .76597 L .58545 .76387 L p F P
0 g
s
.649 .758 .929 r
.34281 .7657 m .35076 .76343 L .35324 .76554 L p F P
0 g
s
.649 .758 .928 r
.35076 .76343 m .34281 .7657 L .34032 .7636 L p F P
0 g
s
.65 .758 .928 r
.59805 .76579 m .6064 .76351 L .60851 .76561 L p F P
0 g
s
.65 .758 .928 r
.6064 .76351 m .59805 .76579 L .59593 .76369 L p F P
0 g
s
.65 .758 .928 r
.47043 .7658 m .47858 .76352 L .48087 .76562 L p F P
0 g
s
.65 .758 .928 r
.47858 .76352 m .47043 .7658 L .46812 .76369 L p F P
0 g
s
.649 .758 .928 r
.35324 .76554 m .36121 .76327 L .36367 .76538 L p F P
0 g
s
.649 .758 .928 r
.36121 .76327 m .35324 .76554 L .35076 .76343 L p F P
0 g
s
.65 .758 .928 r
.60851 .76561 m .61688 .76333 L .61897 .76543 L p F P
0 g
s
.65 .758 .928 r
.61688 .76333 m .60851 .76561 L .6064 .76351 L p F P
0 g
s
.65 .758 .928 r
.48904 .76335 m .48087 .76562 L .47858 .76352 L p F P
0 g
s
.65 .758 .928 r
.48087 .76562 m .48904 .76335 L .49132 .76545 L p F P
0 g
s
.65 .758 .928 r
.36367 .76538 m .37165 .76311 L .3741 .76521 L p F P
0 g
s
.65 .758 .928 r
.37165 .76311 m .36367 .76538 L .36121 .76327 L p F P
0 g
s
.65 .758 .928 r
.62736 .76315 m .61897 .76543 L .61688 .76333 L p F P
0 g
s
.65 .758 .928 r
.49132 .76545 m .4995 .76317 L .50177 .76528 L p F P
0 g
s
.65 .758 .928 r
.4995 .76317 m .49132 .76545 L .48904 .76335 L p F P
0 g
s
.65 .758 .928 r
.3741 .76521 m .3821 .76294 L .38454 .76505 L p F P
0 g
s
.65 .758 .928 r
.3821 .76294 m .3741 .76521 L .37165 .76311 L p F P
0 g
s
.65 .758 .928 r
.50177 .76528 m .50997 .763 L .51222 .7651 L p F P
0 g
s
.65 .758 .928 r
.50997 .763 m .50177 .76528 L .4995 .76317 L p F P
0 g
s
.65 .758 .928 r
.38454 .76505 m .39256 .76277 L .39498 .76488 L p F P
0 g
s
.65 .758 .928 r
.39256 .76277 m .38454 .76505 L .3821 .76294 L p F P
0 g
s
.65 .758 .928 r
.51222 .7651 m .52044 .76282 L .52268 .76493 L p F P
0 g
s
.65 .758 .928 r
.52044 .76282 m .51222 .7651 L .50997 .763 L p F P
0 g
s
.65 .758 .928 r
.39498 .76488 m .40301 .76261 L .40542 .76471 L p F P
0 g
s
.65 .758 .928 r
.40301 .76261 m .39498 .76488 L .39256 .76277 L p F P
0 g
s
.65 .758 .928 r
.52268 .76493 m .53091 .76265 L .53313 .76475 L p F P
0 g
s
.65 .758 .928 r
.53091 .76265 m .52268 .76493 L .52044 .76282 L p F P
0 g
s
.65 .758 .928 r
.40542 .76471 m .41347 .76244 L .41586 .76455 L p F P
0 g
s
.65 .758 .928 r
.41347 .76244 m .40542 .76471 L .40301 .76261 L p F P
0 g
s
.65 .758 .928 r
.53313 .76475 m .54139 .76247 L .54359 .76458 L p F P
0 g
s
.65 .758 .928 r
.54139 .76247 m .53313 .76475 L .53091 .76265 L p F P
0 g
s
.65 .758 .928 r
.41586 .76455 m .42393 .76227 L .42631 .76438 L p F P
0 g
s
.65 .758 .928 r
.42393 .76227 m .41586 .76455 L .41347 .76244 L p F P
0 g
s
.65 .758 .928 r
.54359 .76458 m .55186 .76229 L .55405 .7644 L p F P
0 g
s
.65 .758 .928 r
.55186 .76229 m .54359 .76458 L .54139 .76247 L p F P
0 g
s
.65 .758 .928 r
.42631 .76438 m .4344 .7621 L .43676 .76421 L p F P
0 g
s
.65 .758 .928 r
.4344 .7621 m .42631 .76438 L .42393 .76227 L p F P
0 g
s
.65 .758 .928 r
.55405 .7644 m .56234 .76211 L .56452 .76422 L p F P
0 g
s
.65 .758 .928 r
.56234 .76211 m .55405 .7644 L .55186 .76229 L p F P
0 g
s
.65 .758 .928 r
.43676 .76421 m .44486 .76193 L .44721 .76404 L p F P
0 g
s
.65 .758 .928 r
.44486 .76193 m .43676 .76421 L .4344 .7621 L p F P
0 g
s
.65 .758 .928 r
.56452 .76422 m .57282 .76194 L .57498 .76404 L p F P
0 g
s
.65 .758 .928 r
.57282 .76194 m .56452 .76422 L .56234 .76211 L p F P
0 g
s
.65 .758 .928 r
.44721 .76404 m .45533 .76175 L .45766 .76386 L p F P
0 g
s
.65 .758 .928 r
.45533 .76175 m .44721 .76404 L .44486 .76193 L p F P
0 g
s
.65 .758 .928 r
.57498 .76404 m .58331 .76176 L .58545 .76387 L p F P
0 g
s
.65 .758 .928 r
.58331 .76176 m .57498 .76404 L .57282 .76194 L p F P
0 g
s
.65 .758 .928 r
.45766 .76386 m .4658 .76158 L .46812 .76369 L p F P
0 g
s
.65 .758 .928 r
.4658 .76158 m .45766 .76386 L .45533 .76175 L p F P
0 g
s
.65 .758 .928 r
.58545 .76387 m .59379 .76158 L .59593 .76369 L p F P
0 g
s
.65 .758 .928 r
.59379 .76158 m .58545 .76387 L .58331 .76176 L p F P
0 g
s
.649 .758 .928 r
.34032 .7636 m .34828 .76132 L .35076 .76343 L p F P
0 g
s
.649 .758 .928 r
.34828 .76132 m .34032 .7636 L .33782 .76148 L p F P
0 g
s
.65 .758 .928 r
.59593 .76369 m .60428 .7614 L .6064 .76351 L p F P
0 g
s
.65 .758 .928 r
.60428 .7614 m .59593 .76369 L .59379 .76158 L p F P
0 g
s
.65 .758 .928 r
.47628 .76141 m .46812 .76369 L .4658 .76158 L p F P
0 g
s
.65 .758 .928 r
.46812 .76369 m .47628 .76141 L .47858 .76352 L p F P
0 g
s
.649 .758 .928 r
.35076 .76343 m .35874 .76116 L .36121 .76327 L p F P
0 g
s
.65 .758 .928 r
.35874 .76116 m .35076 .76343 L .34828 .76132 L p F P
0 g
s
.65 .758 .928 r
.6064 .76351 m .61477 .76122 L .61688 .76333 L p F P
0 g
s
.65 .758 .928 r
.61477 .76122 m .6064 .76351 L .60428 .7614 L p F P
0 g
s
.65 .758 .928 r
.47858 .76352 m .48675 .76123 L .48904 .76335 L p F P
0 g
s
.65 .758 .928 r
.48675 .76123 m .47858 .76352 L .47628 .76141 L p F P
0 g
s
.65 .758 .928 r
.36121 .76327 m .3692 .76099 L .37165 .76311 L p F P
0 g
s
.65 .758 .928 r
.3692 .76099 m .36121 .76327 L .35874 .76116 L p F P
0 g
s
.65 .758 .928 r
.61688 .76333 m .62527 .76104 L .62736 .76315 L p F P
0 g
s
.65 .758 .928 r
.62527 .76104 m .61688 .76333 L .61477 .76122 L p F P
0 g
s
.65 .758 .928 r
.48904 .76335 m .49723 .76106 L .4995 .76317 L p F P
0 g
s
.65 .758 .928 r
.49723 .76106 m .48904 .76335 L .48675 .76123 L p F P
0 g
s
.65 .758 .928 r
.37165 .76311 m .37966 .76083 L .3821 .76294 L p F P
0 g
s
.65 .758 .928 r
.37966 .76083 m .37165 .76311 L .3692 .76099 L p F P
0 g
s
.65 .758 .928 r
.63576 .76085 m .62736 .76315 L .62527 .76104 L p F P
0 g
s
.65 .758 .928 r
.4995 .76317 m .50771 .76088 L .50997 .763 L p F P
0 g
s
.65 .758 .928 r
.50771 .76088 m .4995 .76317 L .49723 .76106 L p F P
0 g
s
.65 .758 .928 r
.3821 .76294 m .39013 .76066 L .39256 .76277 L p F P
0 g
s
.65 .758 .928 r
.39013 .76066 m .3821 .76294 L .37966 .76083 L p F P
0 g
s
.65 .758 .928 r
.50997 .763 m .5182 .76071 L .52044 .76282 L p F P
0 g
s
.65 .758 .928 r
.5182 .76071 m .50997 .763 L .50771 .76088 L p F P
0 g
s
.65 .758 .928 r
.39256 .76277 m .4006 .76049 L .40301 .76261 L p F P
0 g
s
.65 .758 .928 r
.4006 .76049 m .39256 .76277 L .39013 .76066 L p F P
0 g
s
.65 .758 .928 r
.52044 .76282 m .52868 .76053 L .53091 .76265 L p F P
0 g
s
.65 .758 .928 r
.52868 .76053 m .52044 .76282 L .5182 .76071 L p F P
0 g
s
.65 .758 .928 r
.40301 .76261 m .41108 .76032 L .41347 .76244 L p F P
0 g
s
.65 .758 .928 r
.41108 .76032 m .40301 .76261 L .4006 .76049 L p F P
0 g
s
.65 .758 .928 r
.53091 .76265 m .53917 .76035 L .54139 .76247 L p F P
0 g
s
.65 .758 .928 r
.53917 .76035 m .53091 .76265 L .52868 .76053 L p F P
0 g
s
.65 .758 .928 r
.41347 .76244 m .42155 .76015 L .42393 .76227 L p F P
0 g
s
.65 .758 .928 r
.42155 .76015 m .41347 .76244 L .41108 .76032 L p F P
0 g
s
.65 .758 .928 r
.54139 .76247 m .54966 .76018 L .55186 .76229 L p F P
0 g
s
.65 .758 .928 r
.54966 .76018 m .54139 .76247 L .53917 .76035 L p F P
0 g
s
.65 .758 .928 r
.42393 .76227 m .43203 .75998 L .4344 .7621 L p F P
0 g
s
.65 .758 .928 r
.43203 .75998 m .42393 .76227 L .42155 .76015 L p F P
0 g
s
.65 .758 .928 r
.55186 .76229 m .56016 .76 L .56234 .76211 L p F P
0 g
s
.65 .758 .928 r
.56016 .76 m .55186 .76229 L .54966 .76018 L p F P
0 g
s
.65 .758 .928 r
.4344 .7621 m .44251 .75981 L .44486 .76193 L p F P
0 g
s
.65 .758 .928 r
.44251 .75981 m .4344 .7621 L .43203 .75998 L p F P
0 g
s
.65 .758 .928 r
.56234 .76211 m .57065 .75982 L .57282 .76194 L p F P
0 g
s
.65 .758 .928 r
.57065 .75982 m .56234 .76211 L .56016 .76 L p F P
0 g
s
.65 .758 .928 r
.44486 .76193 m .45299 .75964 L .45533 .76175 L p F P
0 g
s
.65 .758 .928 r
.45299 .75964 m .44486 .76193 L .44251 .75981 L p F P
0 g
s
.65 .758 .928 r
.57282 .76194 m .58115 .75964 L .58331 .76176 L p F P
0 g
s
.65 .758 .928 r
.58115 .75964 m .57282 .76194 L .57065 .75982 L p F P
0 g
s
.65 .758 .928 r
.45533 .76175 m .46348 .75946 L .4658 .76158 L p F P
0 g
s
.65 .758 .928 r
.46348 .75946 m .45533 .76175 L .45299 .75964 L p F P
0 g
s
.65 .758 .928 r
.58331 .76176 m .59165 .75946 L .59379 .76158 L p F P
0 g
s
.65 .758 .928 r
.59165 .75946 m .58331 .76176 L .58115 .75964 L p F P
0 g
s
.649 .758 .928 r
.33782 .76148 m .34578 .7592 L .34828 .76132 L p F P
0 g
s
.649 .758 .928 r
.34578 .7592 m .33782 .76148 L .33531 .75937 L p F P
0 g
s
.65 .758 .928 r
.59379 .76158 m .60216 .75928 L .60428 .7614 L p F P
0 g
s
.65 .758 .928 r
.60216 .75928 m .59379 .76158 L .59165 .75946 L p F P
0 g
s
.65 .758 .928 r
.4658 .76158 m .47397 .75929 L .47628 .76141 L p F P
0 g
s
.65 .758 .928 r
.47397 .75929 m .4658 .76158 L .46348 .75946 L p F P
0 g
s
.65 .758 .928 r
.34828 .76132 m .35626 .75904 L .35874 .76116 L p F P
0 g
s
.65 .758 .928 r
.35626 .75904 m .34828 .76132 L .34578 .7592 L p F P
0 g
s
.65 .758 .928 r
.60428 .7614 m .61266 .7591 L .61477 .76122 L p F P
0 g
s
.65 .758 .928 r
.61266 .7591 m .60428 .7614 L .60216 .75928 L p F P
0 g
s
.65 .758 .928 r
.48446 .75911 m .47628 .76141 L .47397 .75929 L p F P
0 g
s
.65 .758 .928 r
.47628 .76141 m .48446 .75911 L .48675 .76123 L p F P
0 g
s
.65 .758 .928 r
.35874 .76116 m .36674 .75887 L .3692 .76099 L p F P
0 g
s
.65 .758 .928 r
.36674 .75887 m .35874 .76116 L .35626 .75904 L p F P
0 g
s
.65 .758 .928 r
.61477 .76122 m .62317 .75892 L .62527 .76104 L p F P
0 g
s
.65 .758 .928 r
.62317 .75892 m .61477 .76122 L .61266 .7591 L p F P
0 g
s
.65 .758 .928 r
.48675 .76123 m .49495 .75894 L .49723 .76106 L p F P
0 g
s
.65 .758 .928 r
.49495 .75894 m .48675 .76123 L .48446 .75911 L p F P
0 g
s
.65 .758 .928 r
.3692 .76099 m .37722 .75871 L .37966 .76083 L p F P
0 g
s
.65 .758 .928 r
.37722 .75871 m .3692 .76099 L .36674 .75887 L p F P
0 g
s
.65 .758 .928 r
.62527 .76104 m .63368 .75874 L .63576 .76085 L p F P
0 g
s
.65 .758 .928 r
.63368 .75874 m .62527 .76104 L .62317 .75892 L p F P
0 g
s
.65 .758 .928 r
.49723 .76106 m .50545 .75876 L .50771 .76088 L p F P
0 g
s
.65 .758 .928 r
.50545 .75876 m .49723 .76106 L .49495 .75894 L p F P
0 g
s
.65 .758 .928 r
.37966 .76083 m .3877 .75854 L .39013 .76066 L p F P
0 g
s
.65 .758 .928 r
.3877 .75854 m .37966 .76083 L .37722 .75871 L p F P
0 g
s
.65 .758 .928 r
.6442 .75855 m .63576 .76085 L .63368 .75874 L p F P
0 g
s
.65 .758 .928 r
.50771 .76088 m .51595 .75859 L .5182 .76071 L p F P
0 g
s
.65 .758 .928 r
.51595 .75859 m .50771 .76088 L .50545 .75876 L p F P
0 g
s
.65 .758 .928 r
.39013 .76066 m .39818 .75837 L .4006 .76049 L p F P
0 g
s
.65 .758 .928 r
.39818 .75837 m .39013 .76066 L .3877 .75854 L p F P
0 g
s
.65 .758 .928 r
.5182 .76071 m .52645 .75841 L .52868 .76053 L p F P
0 g
s
.65 .758 .928 r
.52645 .75841 m .5182 .76071 L .51595 .75859 L p F P
0 g
s
.65 .758 .928 r
.4006 .76049 m .40867 .7582 L .41108 .76032 L p F P
0 g
s
.65 .758 .928 r
.40867 .7582 m .4006 .76049 L .39818 .75837 L p F P
0 g
s
.65 .758 .928 r
.52868 .76053 m .53695 .75823 L .53917 .76035 L p F P
0 g
s
.65 .758 .928 r
.53695 .75823 m .52868 .76053 L .52645 .75841 L p F P
0 g
s
.65 .758 .928 r
.41108 .76032 m .41916 .75803 L .42155 .76015 L p F P
0 g
s
.65 .758 .928 r
.41916 .75803 m .41108 .76032 L .40867 .7582 L p F P
0 g
s
.65 .758 .928 r
.53917 .76035 m .54746 .75806 L .54966 .76018 L p F P
0 g
s
.65 .758 .928 r
.54746 .75806 m .53917 .76035 L .53695 .75823 L p F P
0 g
s
.65 .758 .928 r
.42155 .76015 m .42966 .75786 L .43203 .75998 L p F P
0 g
s
.65 .758 .928 r
.42966 .75786 m .42155 .76015 L .41916 .75803 L p F P
0 g
s
.65 .758 .928 r
.54966 .76018 m .55797 .75788 L .56016 .76 L p F P
0 g
s
.65 .758 .928 r
.55797 .75788 m .54966 .76018 L .54746 .75806 L p F P
0 g
s
.65 .758 .928 r
.43203 .75998 m .44015 .75769 L .44251 .75981 L p F P
0 g
s
.65 .758 .928 r
.44015 .75769 m .43203 .75998 L .42966 .75786 L p F P
0 g
s
.65 .758 .928 r
.56016 .76 m .56848 .7577 L .57065 .75982 L p F P
0 g
s
.65 .758 .928 r
.56848 .7577 m .56016 .76 L .55797 .75788 L p F P
0 g
s
.65 .758 .928 r
.44251 .75981 m .45065 .75751 L .45299 .75964 L p F P
0 g
s
.65 .758 .928 r
.45065 .75751 m .44251 .75981 L .44015 .75769 L p F P
0 g
s
.65 .758 .928 r
.57065 .75982 m .57899 .75752 L .58115 .75964 L p F P
0 g
s
.65 .758 .928 r
.57899 .75752 m .57065 .75982 L .56848 .7577 L p F P
0 g
s
.65 .758 .928 r
.45299 .75964 m .46115 .75734 L .46348 .75946 L p F P
0 g
s
.65 .758 .928 r
.46115 .75734 m .45299 .75964 L .45065 .75751 L p F P
0 g
s
.65 .758 .928 r
.58115 .75964 m .58951 .75734 L .59165 .75946 L p F P
0 g
s
.65 .758 .928 r
.58951 .75734 m .58115 .75964 L .57899 .75752 L p F P
0 g
s
.649 .758 .928 r
.33531 .75937 m .34328 .75708 L .34578 .7592 L p F P
0 g
s
.649 .758 .928 r
.34328 .75708 m .33531 .75937 L .3328 .75724 L p F P
0 g
s
.65 .758 .928 r
.59165 .75946 m .60003 .75716 L .60216 .75928 L p F P
0 g
s
.65 .758 .928 r
.60003 .75716 m .59165 .75946 L .58951 .75734 L p F P
0 g
s
.65 .758 .928 r
.46348 .75946 m .47165 .75716 L .47397 .75929 L p F P
0 g
s
.65 .758 .928 r
.47165 .75716 m .46348 .75946 L .46115 .75734 L p F P
0 g
s
.65 .758 .928 r
.34578 .7592 m .35377 .75692 L .35626 .75904 L p F P
0 g
s
.65 .758 .928 r
.35377 .75692 m .34578 .7592 L .34328 .75708 L p F P
0 g
s
.65 .758 .928 r
.60216 .75928 m .61055 .75698 L .61266 .7591 L p F P
0 g
s
.65 .758 .928 r
.61055 .75698 m .60216 .75928 L .60003 .75716 L p F P
0 g
s
.65 .758 .928 r
.47397 .75929 m .48216 .75699 L .48446 .75911 L p F P
0 g
s
.65 .758 .928 r
.48216 .75699 m .47397 .75929 L .47165 .75716 L p F P
0 g
s
.65 .758 .928 r
.35626 .75904 m .36427 .75675 L .36674 .75887 L p F P
0 g
s
.65 .758 .928 r
.36427 .75675 m .35626 .75904 L .35377 .75692 L p F P
0 g
s
.65 .758 .928 r
.61266 .7591 m .62107 .7568 L .62317 .75892 L p F P
0 g
s
.65 .758 .928 r
.62107 .7568 m .61266 .7591 L .61055 .75698 L p F P
0 g
s
.65 .758 .928 r
.49267 .75681 m .48446 .75911 L .48216 .75699 L p F P
0 g
s
.65 .758 .928 r
.48446 .75911 m .49267 .75681 L .49495 .75894 L p F P
0 g
s
.65 .758 .928 r
.36674 .75887 m .37476 .75658 L .37722 .75871 L p F P
0 g
s
.65 .758 .928 r
.37476 .75658 m .36674 .75887 L .36427 .75675 L p F P
0 g
s
.65 .758 .928 r
.62317 .75892 m .6316 .75661 L .63368 .75874 L p F P
0 g
s
.65 .758 .928 r
.6316 .75661 m .62317 .75892 L .62107 .7568 L p F P
0 g
s
.65 .758 .928 r
.49495 .75894 m .50318 .75664 L .50545 .75876 L p F P
0 g
s
.65 .758 .928 r
.50318 .75664 m .49495 .75894 L .49267 .75681 L p F P
0 g
s
.65 .758 .928 r
.37722 .75871 m .38526 .75641 L .3877 .75854 L p F P
0 g
s
.65 .758 .928 r
.38526 .75641 m .37722 .75871 L .37476 .75658 L p F P
0 g
s
.65 .758 .928 r
.63368 .75874 m .64213 .75643 L .6442 .75855 L p F P
0 g
s
.65 .758 .928 r
.64213 .75643 m .63368 .75874 L .6316 .75661 L p F P
0 g
s
.65 .758 .928 r
.51369 .75646 m .50545 .75876 L .50318 .75664 L p F P
0 g
s
.65 .758 .928 r
.50545 .75876 m .51369 .75646 L .51595 .75859 L p F P
0 g
s
.65 .758 .928 r
.3877 .75854 m .39576 .75624 L .39818 .75837 L p F P
0 g
s
.65 .758 .928 r
.39576 .75624 m .3877 .75854 L .38526 .75641 L p F P
0 g
s
.65 .758 .928 r
.65266 .75625 m .6442 .75855 L .64213 .75643 L p F P
0 g
s
.65 .758 .928 r
.51595 .75859 m .52421 .75628 L .52645 .75841 L p F P
0 g
s
.65 .758 .928 r
.52421 .75628 m .51595 .75859 L .51369 .75646 L p F P
0 g
s
.65 .758 .928 r
.39818 .75837 m .40626 .75607 L .40867 .7582 L p F P
0 g
s
.65 .758 .928 r
.40626 .75607 m .39818 .75837 L .39576 .75624 L p F P
0 g
s
.65 .758 .928 r
.52645 .75841 m .53473 .75611 L .53695 .75823 L p F P
0 g
s
.65 .758 .928 r
.53473 .75611 m .52645 .75841 L .52421 .75628 L p F P
0 g
s
.65 .758 .928 r
.40867 .7582 m .41677 .7559 L .41916 .75803 L p F P
0 g
s
.65 .758 .928 r
.41677 .7559 m .40867 .7582 L .40626 .75607 L p F P
0 g
s
.65 .758 .928 r
.53695 .75823 m .54525 .75593 L .54746 .75806 L p F P
0 g
s
.65 .758 .928 r
.54525 .75593 m .53695 .75823 L .53473 .75611 L p F P
0 g
s
.65 .758 .928 r
.41916 .75803 m .42728 .75573 L .42966 .75786 L p F P
0 g
s
.65 .758 .928 r
.42728 .75573 m .41916 .75803 L .41677 .7559 L p F P
0 g
s
.65 .758 .928 r
.54746 .75806 m .55577 .75575 L .55797 .75788 L p F P
0 g
s
.65 .758 .928 r
.55577 .75575 m .54746 .75806 L .54525 .75593 L p F P
0 g
s
.65 .758 .928 r
.42966 .75786 m .43779 .75556 L .44015 .75769 L p F P
0 g
s
.65 .758 .928 r
.43779 .75556 m .42966 .75786 L .42728 .75573 L p F P
0 g
s
.65 .758 .928 r
.55797 .75788 m .5663 .75557 L .56848 .7577 L p F P
0 g
s
.65 .758 .928 r
.5663 .75557 m .55797 .75788 L .55577 .75575 L p F P
0 g
s
.65 .758 .928 r
.44015 .75769 m .4483 .75538 L .45065 .75751 L p F P
0 g
s
.65 .758 .928 r
.4483 .75538 m .44015 .75769 L .43779 .75556 L p F P
0 g
s
.65 .758 .928 r
.56848 .7577 m .57683 .75539 L .57899 .75752 L p F P
0 g
s
.65 .758 .928 r
.57683 .75539 m .56848 .7577 L .5663 .75557 L p F P
0 g
s
.65 .758 .928 r
.45065 .75751 m .45881 .75521 L .46115 .75734 L p F P
0 g
s
.65 .758 .928 r
.45881 .75521 m .45065 .75751 L .4483 .75538 L p F P
0 g
s
.65 .758 .928 r
.57899 .75752 m .58736 .75521 L .58951 .75734 L p F P
0 g
s
.65 .758 .928 r
.58736 .75521 m .57899 .75752 L .57683 .75539 L p F P
0 g
s
.649 .758 .928 r
.3328 .75724 m .34078 .75495 L .34328 .75708 L p F P
0 g
s
.649 .758 .928 r
.34078 .75495 m .3328 .75724 L .33028 .75511 L p F P
0 g
s
.65 .758 .928 r
.46115 .75734 m .46933 .75503 L .47165 .75716 L p F P
0 g
s
.65 .758 .928 r
.46933 .75503 m .46115 .75734 L .45881 .75521 L p F P
0 g
s
.65 .758 .928 r
.58951 .75734 m .59789 .75503 L .60003 .75716 L p F P
0 g
s
.65 .758 .928 r
.59789 .75503 m .58951 .75734 L .58736 .75521 L p F P
0 g
s
.65 .758 .928 r
.34328 .75708 m .35128 .75478 L .35377 .75692 L p F P
0 g
s
.65 .758 .928 r
.35128 .75478 m .34328 .75708 L .34078 .75495 L p F P
0 g
s
.65 .758 .928 r
.60003 .75716 m .60843 .75485 L .61055 .75698 L p F P
0 g
s
.65 .758 .928 r
.60843 .75485 m .60003 .75716 L .59789 .75503 L p F P
0 g
s
.65 .758 .928 r
.47165 .75716 m .47985 .75486 L .48216 .75699 L p F P
0 g
s
.65 .758 .928 r
.47985 .75486 m .47165 .75716 L .46933 .75503 L p F P
0 g
s
.65 .758 .928 r
.35377 .75692 m .36179 .75462 L .36427 .75675 L p F P
0 g
s
.65 .758 .928 r
.36179 .75462 m .35377 .75692 L .35128 .75478 L p F P
0 g
s
.65 .758 .928 r
.61055 .75698 m .61897 .75467 L .62107 .7568 L p F P
0 g
s
.65 .758 .928 r
.61897 .75467 m .61055 .75698 L .60843 .75485 L p F P
0 g
s
.65 .758 .928 r
.48216 .75699 m .49038 .75468 L .49267 .75681 L p F P
0 g
s
.65 .758 .928 r
.49038 .75468 m .48216 .75699 L .47985 .75486 L p F P
0 g
s
.65 .758 .928 r
.36427 .75675 m .3723 .75445 L .37476 .75658 L p F P
0 g
s
.65 .758 .928 r
.3723 .75445 m .36427 .75675 L .36179 .75462 L p F P
0 g
s
.65 .758 .928 r
.62107 .7568 m .62951 .75448 L .6316 .75661 L p F P
0 g
s
.65 .758 .928 r
.62951 .75448 m .62107 .7568 L .61897 .75467 L p F P
0 g
s
.65 .758 .928 r
.49267 .75681 m .5009 .75451 L .50318 .75664 L p F P
0 g
s
.65 .758 .928 r
.5009 .75451 m .49267 .75681 L .49038 .75468 L p F P
0 g
s
.65 .758 .928 r
.37476 .75658 m .38281 .75428 L .38526 .75641 L p F P
0 g
s
.65 .758 .928 r
.38281 .75428 m .37476 .75658 L .3723 .75445 L p F P
0 g
s
.65 .758 .928 r
.6316 .75661 m .64005 .7543 L .64213 .75643 L p F P
0 g
s
.65 .758 .928 r
.64005 .7543 m .6316 .75661 L .62951 .75448 L p F P
0 g
s
.65 .758 .928 r
.50318 .75664 m .51143 .75433 L .51369 .75646 L p F P
0 g
s
.65 .758 .928 r
.51143 .75433 m .50318 .75664 L .5009 .75451 L p F P
0 g
s
.65 .758 .928 r
.38526 .75641 m .39333 .75411 L .39576 .75624 L p F P
0 g
s
.65 .758 .928 r
.39333 .75411 m .38526 .75641 L .38281 .75428 L p F P
0 g
s
.65 .758 .928 r
.64213 .75643 m .6506 .75412 L .65266 .75625 L p F P
0 g
s
.65 .758 .928 r
.6506 .75412 m .64213 .75643 L .64005 .7543 L p F P
0 g
s
.65 .758 .928 r
.52196 .75415 m .51369 .75646 L .51143 .75433 L p F P
0 g
s
.65 .758 .928 r
.51369 .75646 m .52196 .75415 L .52421 .75628 L p F P
0 g
s
.65 .758 .928 r
.39576 .75624 m .40384 .75394 L .40626 .75607 L p F P
0 g
s
.65 .758 .928 r
.40384 .75394 m .39576 .75624 L .39333 .75411 L p F P
0 g
s
.65 .758 .928 r
.66115 .75393 m .65266 .75625 L .6506 .75412 L p F P
0 g
s
.65 .758 .928 r
.52421 .75628 m .5325 .75397 L .53473 .75611 L p F P
0 g
s
.65 .758 .928 r
.5325 .75397 m .52421 .75628 L .52196 .75415 L p F P
0 g
s
.65 .758 .928 r
.40626 .75607 m .41436 .75377 L .41677 .7559 L p F P
0 g
s
.65 .758 .928 r
.41436 .75377 m .40626 .75607 L .40384 .75394 L p F P
0 g
s
.65 .758 .928 r
.53473 .75611 m .54303 .75379 L .54525 .75593 L p F P
0 g
s
.65 .758 .928 r
.54303 .75379 m .53473 .75611 L .5325 .75397 L p F P
0 g
s
.65 .758 .928 r
.41677 .7559 m .42489 .75359 L .42728 .75573 L p F P
0 g
s
.65 .758 .928 r
.42489 .75359 m .41677 .7559 L .41436 .75377 L p F P
0 g
s
.65 .758 .928 r
.54525 .75593 m .55357 .75362 L .55577 .75575 L p F P
0 g
s
.65 .758 .928 r
.55357 .75362 m .54525 .75593 L .54303 .75379 L p F P
0 g
s
.65 .758 .928 r
.42728 .75573 m .43541 .75342 L .43779 .75556 L p F P
0 g
s
.65 .758 .928 r
.43541 .75342 m .42728 .75573 L .42489 .75359 L p F P
0 g
s
.65 .758 .928 r
.55577 .75575 m .56411 .75344 L .5663 .75557 L p F P
0 g
s
.65 .758 .928 r
.56411 .75344 m .55577 .75575 L .55357 .75362 L p F P
0 g
s
.65 .758 .928 r
.43779 .75556 m .44594 .75325 L .4483 .75538 L p F P
0 g
s
.65 .758 .928 r
.44594 .75325 m .43779 .75556 L .43541 .75342 L p F P
0 g
s
.65 .758 .928 r
.5663 .75557 m .57465 .75326 L .57683 .75539 L p F P
0 g
s
.65 .758 .928 r
.57465 .75326 m .5663 .75557 L .56411 .75344 L p F P
0 g
s
.65 .758 .928 r
.4483 .75538 m .45647 .75307 L .45881 .75521 L p F P
0 g
s
.65 .758 .928 r
.45647 .75307 m .4483 .75538 L .44594 .75325 L p F P
0 g
s
.65 .758 .928 r
.57683 .75539 m .5852 .75308 L .58736 .75521 L p F P
0 g
s
.65 .758 .928 r
.5852 .75308 m .57683 .75539 L .57465 .75326 L p F P
0 g
s
.649 .758 .928 r
.33028 .75511 m .33826 .75281 L .34078 .75495 L p F P
0 g
s
.65 .758 .928 r
.33826 .75281 m .33028 .75511 L .32775 .75298 L p F P
0 g
s
.65 .758 .928 r
.45881 .75521 m .467 .7529 L .46933 .75503 L p F P
0 g
s
.65 .758 .928 r
.467 .7529 m .45881 .75521 L .45647 .75307 L p F P
0 g
s
.65 .758 .928 r
.58736 .75521 m .59575 .75289 L .59789 .75503 L p F P
0 g
s
.65 .758 .928 r
.59575 .75289 m .58736 .75521 L .5852 .75308 L p F P
0 g
s
.65 .758 .928 r
.34078 .75495 m .34878 .75265 L .35128 .75478 L p F P
0 g
s
.65 .758 .928 r
.34878 .75265 m .34078 .75495 L .33826 .75281 L p F P
0 g
s
.65 .758 .928 r
.59789 .75503 m .6063 .75271 L .60843 .75485 L p F P
0 g
s
.65 .758 .928 r
.6063 .75271 m .59789 .75503 L .59575 .75289 L p F P
0 g
s
.65 .758 .928 r
.46933 .75503 m .47754 .75272 L .47985 .75486 L p F P
0 g
s
.65 .758 .928 r
.47754 .75272 m .46933 .75503 L .467 .7529 L p F P
0 g
s
.65 .758 .928 r
.35128 .75478 m .35931 .75248 L .36179 .75462 L p F P
0 g
s
.65 .758 .928 r
.35931 .75248 m .35128 .75478 L .34878 .75265 L p F P
0 g
s
.65 .758 .928 r
.60843 .75485 m .61685 .75253 L .61897 .75467 L p F P
0 g
s
.65 .758 .928 r
.61685 .75253 m .60843 .75485 L .6063 .75271 L p F P
0 g
s
.65 .758 .928 r
.47985 .75486 m .48808 .75254 L .49038 .75468 L p F P
0 g
s
.65 .758 .928 r
.48808 .75254 m .47985 .75486 L .47754 .75272 L p F P
0 g
s
.65 .758 .928 r
.36179 .75462 m .36983 .75231 L .3723 .75445 L p F P
0 g
s
.65 .758 .928 r
.36983 .75231 m .36179 .75462 L .35931 .75248 L p F P
0 g
s
.65 .758 .928 r
.61897 .75467 m .62741 .75235 L .62951 .75448 L p F P
0 g
s
.65 .758 .928 r
.62741 .75235 m .61897 .75467 L .61685 .75253 L p F P
0 g
s
.65 .758 .928 r
.49038 .75468 m .49862 .75237 L .5009 .75451 L p F P
0 g
s
.65 .758 .928 r
.49862 .75237 m .49038 .75468 L .48808 .75254 L p F P
0 g
s
.65 .758 .928 r
.3723 .75445 m .38036 .75214 L .38281 .75428 L p F P
0 g
s
.65 .758 .928 r
.38036 .75214 m .3723 .75445 L .36983 .75231 L p F P
0 g
s
.65 .758 .928 r
.62951 .75448 m .63797 .75216 L .64005 .7543 L p F P
0 g
s
.65 .758 .928 r
.63797 .75216 m .62951 .75448 L .62741 .75235 L p F P
0 g
s
.65 .758 .928 r
.50916 .75219 m .5009 .75451 L .49862 .75237 L p F P
0 g
s
.65 .758 .928 r
.5009 .75451 m .50916 .75219 L .51143 .75433 L p F P
0 g
s
.65 .758 .928 r
.38281 .75428 m .39089 .75197 L .39333 .75411 L p F P
0 g
s
.65 .758 .928 r
.39089 .75197 m .38281 .75428 L .38036 .75214 L p F P
0 g
s
.65 .758 .928 r
.64005 .7543 m .64853 .75198 L .6506 .75412 L p F P
0 g
s
.65 .758 .928 r
.64853 .75198 m .64005 .7543 L .63797 .75216 L p F P
0 g
s
.65 .758 .928 r
.51143 .75433 m .51971 .75201 L .52196 .75415 L p F P
0 g
s
.65 .758 .928 r
.51971 .75201 m .51143 .75433 L .50916 .75219 L p F P
0 g
s
.65 .758 .928 r
.39333 .75411 m .40142 .7518 L .40384 .75394 L p F P
0 g
s
.65 .758 .928 r
.40142 .7518 m .39333 .75411 L .39089 .75197 L p F P
0 g
s
.65 .758 .928 r
.6506 .75412 m .65909 .75179 L .66115 .75393 L p F P
0 g
s
.65 .758 .928 r
.65909 .75179 m .6506 .75412 L .64853 .75198 L p F P
0 g
s
.65 .758 .928 r
.53026 .75183 m .52196 .75415 L .51971 .75201 L p F P
0 g
s
.65 .758 .928 r
.52196 .75415 m .53026 .75183 L .5325 .75397 L p F P
0 g
s
.65 .758 .928 r
.66966 .75161 m .66115 .75393 L .65909 .75179 L p F P
0 g
s
.65 .758 .928 r
.40384 .75394 m .41196 .75163 L .41436 .75377 L p F P
0 g
s
.65 .758 .928 r
.41196 .75163 m .40384 .75394 L .40142 .7518 L p F P
0 g
s
.65 .758 .928 r
.5325 .75397 m .54081 .75165 L .54303 .75379 L p F P
0 g
s
.65 .758 .928 r
.54081 .75165 m .5325 .75397 L .53026 .75183 L p F P
0 g
s
.65 .758 .928 r
.41436 .75377 m .42249 .75145 L .42489 .75359 L p F P
0 g
s
.65 .758 .928 r
.42249 .75145 m .41436 .75377 L .41196 .75163 L p F P
0 g
s
.65 .758 .928 r
.54303 .75379 m .55136 .75148 L .55357 .75362 L p F P
0 g
s
.65 .758 .928 r
.55136 .75148 m .54303 .75379 L .54081 .75165 L p F P
0 g
s
.65 .758 .928 r
.42489 .75359 m .43303 .75128 L .43541 .75342 L p F P
0 g
s
.65 .758 .928 r
.43303 .75128 m .42489 .75359 L .42249 .75145 L p F P
0 g
s
.65 .758 .928 r
.55357 .75362 m .56192 .7513 L .56411 .75344 L p F P
0 g
s
.65 .758 .928 r
.56192 .7513 m .55357 .75362 L .55136 .75148 L p F P
0 g
s
.65 .758 .928 r
.43541 .75342 m .44358 .75111 L .44594 .75325 L p F P
0 g
s
.65 .758 .928 r
.44358 .75111 m .43541 .75342 L .43303 .75128 L p F P
0 g
s
.65 .758 .928 r
.56411 .75344 m .57248 .75111 L .57465 .75326 L p F P
0 g
s
.65 .758 .928 r
.57248 .75111 m .56411 .75344 L .56192 .7513 L p F P
0 g
s
.65 .758 .928 r
.44594 .75325 m .45412 .75093 L .45647 .75307 L p F P
0 g
s
.65 .758 .928 r
.45412 .75093 m .44594 .75325 L .44358 .75111 L p F P
0 g
s
.65 .758 .928 r
.57465 .75326 m .58304 .75093 L .5852 .75308 L p F P
0 g
s
.65 .758 .928 r
.58304 .75093 m .57465 .75326 L .57248 .75111 L p F P
0 g
s
.65 .758 .928 r
.32775 .75298 m .33574 .75067 L .33826 .75281 L p F P
0 g
s
.65 .758 .928 r
.33574 .75067 m .32775 .75298 L .32521 .75084 L p F P
0 g
s
.65 .758 .928 r
.45647 .75307 m .46467 .75075 L .467 .7529 L p F P
0 g
s
.65 .758 .928 r
.46467 .75075 m .45647 .75307 L .45412 .75093 L p F P
0 g
s
.65 .758 .928 r
.5852 .75308 m .5936 .75075 L .59575 .75289 L p F P
0 g
s
.65 .758 .928 r
.5936 .75075 m .5852 .75308 L .58304 .75093 L p F P
0 g
s
.65 .758 .928 r
.33826 .75281 m .34628 .7505 L .34878 .75265 L p F P
0 g
s
.65 .758 .928 r
.34628 .7505 m .33826 .75281 L .33574 .75067 L p F P
0 g
s
.65 .758 .928 r
.59575 .75289 m .60417 .75057 L .6063 .75271 L p F P
0 g
s
.65 .758 .928 r
.60417 .75057 m .59575 .75289 L .5936 .75075 L p F P
0 g
s
.65 .758 .928 r
.467 .7529 m .47522 .75058 L .47754 .75272 L p F P
0 g
s
.65 .758 .928 r
.47522 .75058 m .467 .7529 L .46467 .75075 L p F P
0 g
s
.65 .758 .928 r
.34878 .75265 m .35682 .75034 L .35931 .75248 L p F P
0 g
s
.65 .758 .928 r
.35682 .75034 m .34878 .75265 L .34628 .7505 L p F P
0 g
s
.65 .758 .928 r
.6063 .75271 m .61474 .75039 L .61685 .75253 L p F P
0 g
s
.65 .758 .928 r
.61474 .75039 m .6063 .75271 L .60417 .75057 L p F P
0 g
s
.65 .758 .928 r
.47754 .75272 m .48577 .7504 L .48808 .75254 L p F P
0 g
s
.65 .758 .928 r
.48577 .7504 m .47754 .75272 L .47522 .75058 L p F P
0 g
s
.65 .758 .928 r
.35931 .75248 m .36735 .75017 L .36983 .75231 L p F P
0 g
s
.65 .758 .928 r
.36735 .75017 m .35931 .75248 L .35682 .75034 L p F P
0 g
s
.65 .758 .928 r
.61685 .75253 m .62531 .7502 L .62741 .75235 L p F P
0 g
s
.65 .758 .928 r
.62531 .7502 m .61685 .75253 L .61474 .75039 L p F P
0 g
s
.65 .758 .928 r
.48808 .75254 m .49633 .75022 L .49862 .75237 L p F P
0 g
s
.65 .758 .928 r
.49633 .75022 m .48808 .75254 L .48577 .7504 L p F P
0 g
s
.65 .758 .928 r
.36983 .75231 m .3779 .75 L .38036 .75214 L p F P
0 g
s
.65 .758 .928 r
.3779 .75 m .36983 .75231 L .36735 .75017 L p F P
0 g
s
.65 .758 .928 r
.62741 .75235 m .63588 .75002 L .63797 .75216 L p F P
0 g
s
.65 .758 .928 r
.63588 .75002 m .62741 .75235 L .62531 .7502 L p F P
0 g
s
.65 .758 .928 r
.49862 .75237 m .50689 .75005 L .50916 .75219 L p F P
0 g
s
.65 .758 .928 r
.50689 .75005 m .49862 .75237 L .49633 .75022 L p F P
0 g
s
.65 .758 .928 r
.38036 .75214 m .38844 .74982 L .39089 .75197 L p F P
0 g
s
.65 .758 .928 r
.38844 .74982 m .38036 .75214 L .3779 .75 L p F P
0 g
s
.65 .758 .928 r
.63797 .75216 m .64646 .74984 L .64853 .75198 L p F P
0 g
s
.65 .758 .928 r
.64646 .74984 m .63797 .75216 L .63588 .75002 L p F P
0 g
s
.65 .758 .928 r
.51745 .74987 m .50916 .75219 L .50689 .75005 L p F P
0 g
s
.65 .758 .928 r
.50916 .75219 m .51745 .74987 L .51971 .75201 L p F P
0 g
s
.65 .758 .928 r
.39089 .75197 m .39899 .74965 L .40142 .7518 L p F P
0 g
s
.65 .758 .928 r
.39899 .74965 m .39089 .75197 L .38844 .74982 L p F P
0 g
s
.65 .758 .928 r
.64853 .75198 m .65703 .74965 L .65909 .75179 L p F P
0 g
s
.65 .758 .928 r
.65703 .74965 m .64853 .75198 L .64646 .74984 L p F P
0 g
s
.65 .758 .928 r
.51971 .75201 m .52801 .74969 L .53026 .75183 L p F P
0 g
s
.65 .758 .928 r
.52801 .74969 m .51971 .75201 L .51745 .74987 L p F P
0 g
s
.65 .758 .928 r
.65909 .75179 m .66762 .74946 L .66966 .75161 L p F P
0 g
s
.65 .758 .928 r
.66762 .74946 m .65909 .75179 L .65703 .74965 L p F P
0 g
s
.65 .758 .928 r
.40142 .7518 m .40954 .74948 L .41196 .75163 L p F P
0 g
s
.65 .758 .928 r
.40954 .74948 m .40142 .7518 L .39899 .74965 L p F P
0 g
s
.65 .758 .928 r
.53858 .74951 m .53026 .75183 L .52801 .74969 L p F P
0 g
s
.65 .758 .928 r
.53026 .75183 m .53858 .74951 L .54081 .75165 L p F P
0 g
s
.65 .758 .928 r
.6782 .74928 m .66966 .75161 L .66762 .74946 L p F P
0 g
s
.65 .758 .928 r
.41196 .75163 m .42009 .74931 L .42249 .75145 L p F P
0 g
s
.65 .758 .928 r
.42009 .74931 m .41196 .75163 L .40954 .74948 L p F P
0 g
s
.65 .758 .928 r
.54081 .75165 m .54915 .74933 L .55136 .75148 L p F P
0 g
s
.65 .758 .928 r
.54915 .74933 m .54081 .75165 L .53858 .74951 L p F P
0 g
s
.65 .758 .928 r
.42249 .75145 m .43065 .74913 L .43303 .75128 L p F P
0 g
s
.65 .758 .928 r
.43065 .74913 m .42249 .75145 L .42009 .74931 L p F P
0 g
s
.65 .758 .928 r
.55136 .75148 m .55972 .74915 L .56192 .7513 L p F P
0 g
s
.65 .758 .928 r
.55972 .74915 m .55136 .75148 L .54915 .74933 L p F P
0 g
s
.65 .758 .928 r
.43303 .75128 m .44121 .74896 L .44358 .75111 L p F P
0 g
s
.65 .758 .928 r
.44121 .74896 m .43303 .75128 L .43065 .74913 L p F P
0 g
s
.65 .758 .928 r
.56192 .7513 m .57029 .74897 L .57248 .75111 L p F P
0 g
s
.65 .758 .928 r
.57029 .74897 m .56192 .7513 L .55972 .74915 L p F P
0 g
s
.65 .758 .928 r
.44358 .75111 m .45177 .74878 L .45412 .75093 L p F P
0 g
s
.65 .758 .928 r
.45177 .74878 m .44358 .75111 L .44121 .74896 L p F P
0 g
s
.65 .758 .928 r
.57248 .75111 m .58087 .74879 L .58304 .75093 L p F P
0 g
s
.65 .758 .928 r
.58087 .74879 m .57248 .75111 L .57029 .74897 L p F P
0 g
s
.65 .758 .928 r
.32521 .75084 m .33322 .74852 L .33574 .75067 L p F P
0 g
s
.65 .758 .928 r
.33322 .74852 m .32521 .75084 L .32267 .74869 L p F P
0 g
s
.65 .758 .928 r
.45412 .75093 m .46233 .7486 L .46467 .75075 L p F P
0 g
s
.65 .758 .928 r
.46233 .7486 m .45412 .75093 L .45177 .74878 L p F P
0 g
s
.65 .758 .928 r
.58304 .75093 m .59145 .7486 L .5936 .75075 L p F P
0 g
s
.65 .758 .928 r
.59145 .7486 m .58304 .75093 L .58087 .74879 L p F P
0 g
s
.65 .758 .928 r
.33574 .75067 m .34377 .74835 L .34628 .7505 L p F P
0 g
s
.65 .758 .928 r
.34377 .74835 m .33574 .75067 L .33322 .74852 L p F P
0 g
s
.65 .758 .928 r
.5936 .75075 m .60203 .74842 L .60417 .75057 L p F P
0 g
s
.65 .758 .928 r
.60203 .74842 m .5936 .75075 L .59145 .7486 L p F P
0 g
s
.65 .758 .928 r
.46467 .75075 m .47289 .74843 L .47522 .75058 L p F P
0 g
s
.65 .758 .928 r
.47289 .74843 m .46467 .75075 L .46233 .7486 L p F P
0 g
s
.65 .758 .928 r
.34628 .7505 m .35432 .74818 L .35682 .75034 L p F P
0 g
s
.65 .758 .928 r
.35432 .74818 m .34628 .7505 L .34377 .74835 L p F P
0 g
s
.65 .758 .928 r
.60417 .75057 m .61261 .74824 L .61474 .75039 L p F P
0 g
s
.65 .758 .928 r
.61261 .74824 m .60417 .75057 L .60203 .74842 L p F P
0 g
s
.65 .758 .928 r
.47522 .75058 m .48346 .74825 L .48577 .7504 L p F P
0 g
s
.65 .758 .928 r
.48346 .74825 m .47522 .75058 L .47289 .74843 L p F P
0 g
s
.65 .758 .928 r
.35682 .75034 m .36487 .74802 L .36735 .75017 L p F P
0 g
s
.65 .758 .928 r
.36487 .74802 m .35682 .75034 L .35432 .74818 L p F P
0 g
s
.65 .758 .928 r
.61474 .75039 m .6232 .74805 L .62531 .7502 L p F P
0 g
s
.65 .758 .928 r
.6232 .74805 m .61474 .75039 L .61261 .74824 L p F P
0 g
s
.65 .758 .928 r
.48577 .7504 m .49403 .74807 L .49633 .75022 L p F P
0 g
s
.65 .758 .928 r
.49403 .74807 m .48577 .7504 L .48346 .74825 L p F P
0 g
s
.65 .758 .928 r
.36735 .75017 m .37543 .74784 L .3779 .75 L p F P
0 g
s
.65 .758 .928 r
.37543 .74784 m .36735 .75017 L .36487 .74802 L p F P
0 g
s
.65 .758 .928 r
.62531 .7502 m .63379 .74787 L .63588 .75002 L p F P
0 g
s
.65 .758 .928 r
.63379 .74787 m .62531 .7502 L .6232 .74805 L p F P
0 g
s
.65 .758 .928 r
.49633 .75022 m .50461 .74789 L .50689 .75005 L p F P
0 g
s
.65 .758 .928 r
.50461 .74789 m .49633 .75022 L .49403 .74807 L p F P
0 g
s
.65 .758 .928 r
.3779 .75 m .38599 .74767 L .38844 .74982 L p F P
0 g
s
.65 .758 .928 r
.38599 .74767 m .3779 .75 L .37543 .74784 L p F P
0 g
s
.65 .758 .928 r
.63588 .75002 m .64438 .74769 L .64646 .74984 L p F P
0 g
s
.65 .758 .928 r
.64438 .74769 m .63588 .75002 L .63379 .74787 L p F P
0 g
s
.65 .758 .928 r
.50689 .75005 m .51518 .74771 L .51745 .74987 L p F P
0 g
s
.65 .758 .928 r
.51518 .74771 m .50689 .75005 L .50461 .74789 L p F P
0 g
s
.65 .758 .928 r
.38844 .74982 m .39655 .7475 L .39899 .74965 L p F P
0 g
s
.65 .758 .928 r
.39655 .7475 m .38844 .74982 L .38599 .74767 L p F P
0 g
s
.65 .758 .928 r
.64646 .74984 m .65497 .7475 L .65703 .74965 L p F P
0 g
s
.65 .758 .928 r
.65497 .7475 m .64646 .74984 L .64438 .74769 L p F P
0 g
s
.65 .758 .928 r
.52576 .74754 m .51745 .74987 L .51518 .74771 L p F P
0 g
s
.65 .758 .928 r
.51745 .74987 m .52576 .74754 L .52801 .74969 L p F P
0 g
s
.65 .758 .928 r
.65703 .74965 m .66557 .74731 L .66762 .74946 L p F P
0 g
s
.65 .758 .928 r
.66557 .74731 m .65703 .74965 L .65497 .7475 L p F P
0 g
s
.65 .758 .928 r
.39899 .74965 m .40712 .74733 L .40954 .74948 L p F P
0 g
s
.65 .758 .928 r
.40712 .74733 m .39899 .74965 L .39655 .7475 L p F P
0 g
s
.65 .758 .928 r
.52801 .74969 m .53634 .74736 L .53858 .74951 L p F P
0 g
s
.65 .758 .928 r
.53634 .74736 m .52801 .74969 L .52576 .74754 L p F P
0 g
s
.65 .758 .928 r
.66762 .74946 m .67617 .74713 L .6782 .74928 L p F P
0 g
s
.65 .758 .928 r
.67617 .74713 m .66762 .74946 L .66557 .74731 L p F P
0 g
s
.65 .758 .928 r
.40954 .74948 m .41768 .74715 L .42009 .74931 L p F P
0 g
s
.65 .758 .928 r
.41768 .74715 m .40954 .74948 L .40712 .74733 L p F P
0 g
s
.65 .758 .928 r
.53858 .74951 m .54693 .74717 L .54915 .74933 L p F P
0 g
s
.65 .758 .928 r
.54693 .74717 m .53858 .74951 L .53634 .74736 L p F P
0 g
s
.65 .758 .928 r
.68677 .74694 m .6782 .74928 L .67617 .74713 L p F P
0 g
s
.65 .758 .928 r
.42009 .74931 m .42825 .74698 L .43065 .74913 L p F P
0 g
s
.65 .758 .928 r
.42825 .74698 m .42009 .74931 L .41768 .74715 L p F P
0 g
s
.65 .758 .928 r
.54915 .74933 m .55751 .74699 L .55972 .74915 L p F P
0 g
s
.65 .758 .928 r
.55751 .74699 m .54915 .74933 L .54693 .74717 L p F P
0 g
s
.65 .758 .928 r
.43065 .74913 m .43883 .7468 L .44121 .74896 L p F P
0 g
s
.65 .758 .928 r
.43883 .7468 m .43065 .74913 L .42825 .74698 L p F P
0 g
s
.65 .758 .928 r
.55972 .74915 m .5681 .74681 L .57029 .74897 L p F P
0 g
s
.65 .758 .928 r
.5681 .74681 m .55972 .74915 L .55751 .74699 L p F P
0 g
s
.65 .758 .928 r
.44121 .74896 m .4494 .74662 L .45177 .74878 L p F P
0 g
s
.65 .758 .928 r
.4494 .74662 m .44121 .74896 L .43883 .7468 L p F P
0 g
s
.65 .758 .928 r
.57029 .74897 m .57869 .74663 L .58087 .74879 L p F P
0 g
s
.65 .758 .928 r
.57869 .74663 m .57029 .74897 L .5681 .74681 L p F P
0 g
s
.65 .758 .928 r
.32267 .74869 m .33068 .74636 L .33322 .74852 L p F P
0 g
s
.65 .758 .928 r
.33068 .74636 m .32267 .74869 L .32012 .74653 L p F P
0 g
s
.65 .758 .928 r
.45177 .74878 m .45998 .74645 L .46233 .7486 L p F P
0 g
s
.65 .758 .928 r
.45998 .74645 m .45177 .74878 L .4494 .74662 L p F P
0 g
s
.65 .758 .928 r
.58087 .74879 m .58928 .74645 L .59145 .7486 L p F P
0 g
s
.65 .758 .928 r
.58928 .74645 m .58087 .74879 L .57869 .74663 L p F P
0 g
s
.65 .758 .928 r
.33322 .74852 m .34125 .7462 L .34377 .74835 L p F P
0 g
s
.65 .758 .928 r
.34125 .7462 m .33322 .74852 L .33068 .74636 L p F P
0 g
s
.65 .758 .928 r
.59145 .7486 m .59988 .74627 L .60203 .74842 L p F P
0 g
s
.65 .758 .928 r
.59988 .74627 m .59145 .7486 L .58928 .74645 L p F P
0 g
s
.65 .758 .928 r
.46233 .7486 m .47056 .74627 L .47289 .74843 L p F P
0 g
s
.65 .758 .928 r
.47056 .74627 m .46233 .7486 L .45998 .74645 L p F P
0 g
s
.65 .758 .928 r
.34377 .74835 m .35181 .74603 L .35432 .74818 L p F P
0 g
s
.65 .758 .928 r
.35181 .74603 m .34377 .74835 L .34125 .7462 L p F P
0 g
s
.65 .758 .928 r
.60203 .74842 m .61048 .74608 L .61261 .74824 L p F P
0 g
s
.65 .758 .928 r
.61048 .74608 m .60203 .74842 L .59988 .74627 L p F P
0 g
s
.65 .758 .928 r
.47289 .74843 m .48114 .74609 L .48346 .74825 L p F P
0 g
s
.65 .758 .928 r
.48114 .74609 m .47289 .74843 L .47056 .74627 L p F P
0 g
s
.65 .758 .928 r
.35432 .74818 m .36238 .74586 L .36487 .74802 L p F P
0 g
s
.65 .758 .928 r
.36238 .74586 m .35432 .74818 L .35181 .74603 L p F P
0 g
s
.65 .758 .928 r
.61261 .74824 m .62108 .7459 L .6232 .74805 L p F P
0 g
s
.65 .758 .928 r
.62108 .7459 m .61261 .74824 L .61048 .74608 L p F P
0 g
s
.65 .758 .928 r
.48346 .74825 m .49173 .74591 L .49403 .74807 L p F P
0 g
s
.65 .758 .928 r
.49173 .74591 m .48346 .74825 L .48114 .74609 L p F P
0 g
s
.65 .758 .928 r
.36487 .74802 m .37295 .74569 L .37543 .74784 L p F P
0 g
s
.65 .758 .928 r
.37295 .74569 m .36487 .74802 L .36238 .74586 L p F P
0 g
s
.65 .758 .928 r
.6232 .74805 m .63168 .74571 L .63379 .74787 L p F P
0 g
s
.65 .758 .928 r
.63168 .74571 m .6232 .74805 L .62108 .7459 L p F P
0 g
s
.65 .758 .928 r
.49403 .74807 m .50232 .74574 L .50461 .74789 L p F P
0 g
s
.65 .758 .928 r
.50232 .74574 m .49403 .74807 L .49173 .74591 L p F P
0 g
s
.65 .758 .928 r
.37543 .74784 m .38353 .74551 L .38599 .74767 L p F P
0 g
s
.65 .758 .928 r
.38353 .74551 m .37543 .74784 L .37295 .74569 L p F P
0 g
s
.65 .758 .928 r
.63379 .74787 m .64229 .74553 L .64438 .74769 L p F P
0 g
s
.65 .758 .928 r
.64229 .74553 m .63379 .74787 L .63168 .74571 L p F P
0 g
s
.65 .758 .928 r
.50461 .74789 m .51291 .74556 L .51518 .74771 L p F P
0 g
s
.65 .758 .928 r
.51291 .74556 m .50461 .74789 L .50232 .74574 L p F P
0 g
s
.65 .758 .928 r
.38599 .74767 m .39411 .74534 L .39655 .7475 L p F P
0 g
s
.65 .758 .928 r
.39411 .74534 m .38599 .74767 L .38353 .74551 L p F P
0 g
s
.65 .758 .928 r
.64438 .74769 m .6529 .74534 L .65497 .7475 L p F P
0 g
s
.65 .758 .928 r
.6529 .74534 m .64438 .74769 L .64229 .74553 L p F P
0 g
s
.65 .758 .928 r
.51518 .74771 m .5235 .74538 L .52576 .74754 L p F P
0 g
s
.65 .758 .928 r
.5235 .74538 m .51518 .74771 L .51291 .74556 L p F P
0 g
s
.65 .758 .928 r
.39655 .7475 m .40469 .74517 L .40712 .74733 L p F P
0 g
s
.65 .758 .928 r
.40469 .74517 m .39655 .7475 L .39411 .74534 L p F P
0 g
s
.65 .758 .928 r
.65497 .7475 m .66351 .74516 L .66557 .74731 L p F P
0 g
s
.65 .758 .928 r
.66351 .74516 m .65497 .7475 L .6529 .74534 L p F P
0 g
s
.65 .758 .928 r
.5341 .7452 m .52576 .74754 L .5235 .74538 L p F P
0 g
s
.65 .758 .928 r
.52576 .74754 m .5341 .7452 L .53634 .74736 L p F P
0 g
s
.65 .758 .928 r
.66557 .74731 m .67413 .74497 L .67617 .74713 L p F P
0 g
s
.65 .758 .928 r
.67413 .74497 m .66557 .74731 L .66351 .74516 L p F P
0 g
s
.65 .758 .928 r
.40712 .74733 m .41527 .74499 L .41768 .74715 L p F P
0 g
s
.65 .758 .928 r
.41527 .74499 m .40712 .74733 L .40469 .74517 L p F P
0 g
s
.65 .758 .928 r
.53634 .74736 m .5447 .74501 L .54693 .74717 L p F P
0 g
s
.65 .758 .928 r
.5447 .74501 m .53634 .74736 L .5341 .7452 L p F P
0 g
s
.65 .758 .928 r
.67617 .74713 m .68474 .74478 L .68677 .74694 L p F P
0 g
s
.65 .758 .928 r
.68474 .74478 m .67617 .74713 L .67413 .74497 L p F P
0 g
s
.65 .758 .928 r
.41768 .74715 m .42585 .74482 L .42825 .74698 L p F P
0 g
s
.65 .758 .928 r
.42585 .74482 m .41768 .74715 L .41527 .74499 L p F P
0 g
s
.65 .758 .928 r
.5553 .74483 m .54693 .74717 L .5447 .74501 L p F P
0 g
s
.65 .758 .928 r
.54693 .74717 m .5553 .74483 L .55751 .74699 L p F P
0 g
s
.65 .758 .928 r
.69536 .74459 m .68677 .74694 L .68474 .74478 L p F P
0 g
s
.65 .758 .928 r
.42825 .74698 m .43644 .74464 L .43883 .7468 L p F P
0 g
s
.65 .758 .928 r
.43644 .74464 m .42825 .74698 L .42585 .74482 L p F P
0 g
s
.65 .758 .928 r
.55751 .74699 m .5659 .74465 L .5681 .74681 L p F P
0 g
s
.65 .758 .928 r
.5659 .74465 m .55751 .74699 L .5553 .74483 L p F P
0 g
s
.65 .758 .928 r
.43883 .7468 m .44703 .74446 L .4494 .74662 L p F P
0 g
s
.65 .758 .928 r
.44703 .74446 m .43883 .7468 L .43644 .74464 L p F P
0 g
s
.65 .758 .928 r
.5681 .74681 m .57651 .74447 L .57869 .74663 L p F P
0 g
s
.65 .758 .928 r
.57651 .74447 m .5681 .74681 L .5659 .74465 L p F P
0 g
s
.65 .758 .928 r
.32012 .74653 m .32814 .7442 L .33068 .74636 L p F P
0 g
s
.65 .758 .928 r
.32814 .7442 m .32012 .74653 L .31756 .74437 L p F P
0 g
s
.65 .758 .928 r
.4494 .74662 m .45763 .74429 L .45998 .74645 L p F P
0 g
s
.65 .758 .928 r
.45763 .74429 m .4494 .74662 L .44703 .74446 L p F P
0 g
s
.65 .758 .928 r
.57869 .74663 m .58712 .74429 L .58928 .74645 L p F P
0 g
s
.65 .758 .928 r
.58712 .74429 m .57869 .74663 L .57651 .74447 L p F P
0 g
s
.65 .758 .928 r
.33068 .74636 m .33872 .74403 L .34125 .7462 L p F P
0 g
s
.65 .758 .928 r
.33872 .74403 m .33068 .74636 L .32814 .7442 L p F P
0 g
s
.65 .758 .928 r
.45998 .74645 m .46822 .74411 L .47056 .74627 L p F P
0 g
s
.65 .758 .928 r
.46822 .74411 m .45998 .74645 L .45763 .74429 L p F P
0 g
s
.65 .758 .928 r
.58928 .74645 m .59773 .7441 L .59988 .74627 L p F P
0 g
s
.65 .758 .928 r
.59773 .7441 m .58928 .74645 L .58712 .74429 L p F P
0 g
s
.65 .758 .928 r
.34125 .7462 m .3493 .74386 L .35181 .74603 L p F P
0 g
s
.65 .758 .928 r
.3493 .74386 m .34125 .7462 L .33872 .74403 L p F P
0 g
s
.65 .758 .928 r
.59988 .74627 m .60834 .74392 L .61048 .74608 L p F P
0 g
s
.65 .758 .928 r
.60834 .74392 m .59988 .74627 L .59773 .7441 L p F P
0 g
s
.65 .758 .928 r
.47056 .74627 m .47882 .74393 L .48114 .74609 L p F P
0 g
s
.65 .758 .928 r
.47882 .74393 m .47056 .74627 L .46822 .74411 L p F P
0 g
s
.65 .758 .928 r
.35181 .74603 m .35988 .74369 L .36238 .74586 L p F P
0 g
s
.65 .758 .928 r
.35988 .74369 m .35181 .74603 L .3493 .74386 L p F P
0 g
s
.65 .758 .928 r
.61048 .74608 m .61896 .74374 L .62108 .7459 L p F P
0 g
s
.65 .758 .928 r
.61896 .74374 m .61048 .74608 L .60834 .74392 L p F P
0 g
s
.65 .758 .928 r
.48114 .74609 m .48942 .74375 L .49173 .74591 L p F P
0 g
s
.65 .758 .928 r
.48942 .74375 m .48114 .74609 L .47882 .74393 L p F P
0 g
s
.65 .758 .928 r
.36238 .74586 m .37047 .74352 L .37295 .74569 L p F P
0 g
s
.65 .758 .928 r
.37047 .74352 m .36238 .74586 L .35988 .74369 L p F P
0 g
s
.65 .758 .928 r
.62108 .7459 m .62958 .74355 L .63168 .74571 L p F P
0 g
s
.65 .758 .928 r
.62958 .74355 m .62108 .7459 L .61896 .74374 L p F P
0 g
s
.65 .758 .928 r
.49173 .74591 m .50002 .74357 L .50232 .74574 L p F P
0 g
s
.65 .758 .928 r
.50002 .74357 m .49173 .74591 L .48942 .74375 L p F P
0 g
s
.65 .758 .928 r
.37295 .74569 m .38106 .74335 L .38353 .74551 L p F P
0 g
s
.65 .758 .928 r
.38106 .74335 m .37295 .74569 L .37047 .74352 L p F P
0 g
s
.65 .758 .928 r
.63168 .74571 m .6402 .74337 L .64229 .74553 L p F P
0 g
s
.65 .758 .928 r
.6402 .74337 m .63168 .74571 L .62958 .74355 L p F P
0 g
s
.65 .758 .928 r
.50232 .74574 m .51063 .74339 L .51291 .74556 L p F P
0 g
s
.65 .758 .928 r
.51063 .74339 m .50232 .74574 L .50002 .74357 L p F P
0 g
s
.65 .758 .928 r
.38353 .74551 m .39165 .74317 L .39411 .74534 L p F P
0 g
s
.65 .758 .928 r
.39165 .74317 m .38353 .74551 L .38106 .74335 L p F P
0 g
s
.65 .758 .928 r
.64229 .74553 m .65082 .74318 L .6529 .74534 L p F P
0 g
s
.65 .758 .928 r
.65082 .74318 m .64229 .74553 L .6402 .74337 L p F P
0 g
s
.65 .758 .928 r
.51291 .74556 m .52124 .74321 L .5235 .74538 L p F P
0 g
s
.65 .758 .928 r
.52124 .74321 m .51291 .74556 L .51063 .74339 L p F P
0 g
s
.65 .758 .928 r
.39411 .74534 m .40225 .743 L .40469 .74517 L p F P
0 g
s
.65 .758 .928 r
.40225 .743 m .39411 .74534 L .39165 .74317 L p F P
0 g
s
.65 .758 .928 r
.6529 .74534 m .66145 .74299 L .66351 .74516 L p F P
0 g
s
.65 .758 .928 r
.66145 .74299 m .6529 .74534 L .65082 .74318 L p F P
0 g
s
.65 .758 .928 r
.5235 .74538 m .53185 .74303 L .5341 .7452 L p F P
0 g
s
.65 .758 .928 r
.53185 .74303 m .5235 .74538 L .52124 .74321 L p F P
0 g
s
.65 .758 .928 r
.66351 .74516 m .67208 .74281 L .67413 .74497 L p F P
0 g
s
.65 .758 .928 r
.67208 .74281 m .66351 .74516 L .66145 .74299 L p F P
0 g
s
.65 .758 .928 r
.40469 .74517 m .41285 .74282 L .41527 .74499 L p F P
0 g
s
.65 .758 .928 r
.41285 .74282 m .40469 .74517 L .40225 .743 L p F P
0 g
s
.65 .758 .928 r
.5341 .7452 m .54246 .74285 L .5447 .74501 L p F P
0 g
s
.65 .758 .928 r
.54246 .74285 m .5341 .7452 L .53185 .74303 L p F P
0 g
s
.65 .758 .928 r
.67413 .74497 m .68271 .74262 L .68474 .74478 L p F P
0 g
s
.65 .758 .928 r
.68271 .74262 m .67413 .74497 L .67208 .74281 L p F P
0 g
s
.65 .758 .928 r
.41527 .74499 m .42345 .74265 L .42585 .74482 L p F P
0 g
s
.65 .758 .928 r
.42345 .74265 m .41527 .74499 L .41285 .74282 L p F P
0 g
s
.65 .758 .928 r
.5447 .74501 m .55308 .74267 L .5553 .74483 L p F P
0 g
s
.65 .758 .928 r
.55308 .74267 m .5447 .74501 L .54246 .74285 L p F P
0 g
s
.65 .758 .928 r
.68474 .74478 m .69334 .74243 L .69536 .74459 L p F P
0 g
s
.65 .758 .928 r
.69334 .74243 m .68474 .74478 L .68271 .74262 L p F P
0 g
s
.65 .758 .928 r
.42585 .74482 m .43405 .74247 L .43644 .74464 L p F P
0 g
s
.65 .758 .928 r
.43405 .74247 m .42585 .74482 L .42345 .74265 L p F P
0 g
s
.65 .758 .928 r
.5637 .74248 m .5553 .74483 L .55308 .74267 L p F P
0 g
s
.65 .758 .928 r
.5553 .74483 m .5637 .74248 L .5659 .74465 L p F P
0 g
s
.65 .758 .928 r
.70398 .74224 m .69536 .74459 L .69334 .74243 L p F P
0 g
s
.65 .758 .928 r
.43644 .74464 m .44466 .74229 L .44703 .74446 L p F P
0 g
s
.65 .758 .928 r
.44466 .74229 m .43644 .74464 L .43405 .74247 L p F P
0 g
s
.65 .758 .928 r
.5659 .74465 m .57432 .7423 L .57651 .74447 L p F P
0 g
s
.65 .758 .928 r
.57432 .7423 m .5659 .74465 L .5637 .74248 L p F P
0 g
s
.65 .758 .928 r
.31756 .74437 m .32559 .74203 L .32814 .7442 L p F P
0 g
s
.65 .758 .928 r
.32559 .74203 m .31756 .74437 L .315 .7422 L p F P
0 g
s
.65 .758 .928 r
.44703 .74446 m .45526 .74212 L .45763 .74429 L p F P
0 g
s
.65 .758 .928 r
.45526 .74212 m .44703 .74446 L .44466 .74229 L p F P
0 g
s
.65 .758 .928 r
.57651 .74447 m .58494 .74212 L .58712 .74429 L p F P
0 g
s
.65 .758 .928 r
.58494 .74212 m .57651 .74447 L .57432 .7423 L p F P
0 g
s
.65 .758 .928 r
.32814 .7442 m .33618 .74186 L .33872 .74403 L p F P
0 g
s
.65 .758 .928 r
.33618 .74186 m .32814 .7442 L .32559 .74203 L p F P
0 g
s
.65 .758 .928 r
.45763 .74429 m .46587 .74194 L .46822 .74411 L p F P
0 g
s
.65 .758 .928 r
.46587 .74194 m .45763 .74429 L .45526 .74212 L p F P
0 g
s
.65 .758 .928 r
.58712 .74429 m .59557 .74194 L .59773 .7441 L p F P
0 g
s
.65 .758 .928 r
.59557 .74194 m .58712 .74429 L .58494 .74212 L p F P
0 g
s
.65 .758 .928 r
.33872 .74403 m .34678 .74169 L .3493 .74386 L p F P
0 g
s
.65 .758 .928 r
.34678 .74169 m .33872 .74403 L .33618 .74186 L p F P
0 g
s
.65 .758 .928 r
.59773 .7441 m .6062 .74175 L .60834 .74392 L p F P
0 g
s
.65 .758 .928 r
.6062 .74175 m .59773 .7441 L .59557 .74194 L p F P
0 g
s
.65 .758 .928 r
.46822 .74411 m .47649 .74176 L .47882 .74393 L p F P
0 g
s
.65 .758 .928 r
.47649 .74176 m .46822 .74411 L .46587 .74194 L p F P
0 g
s
.65 .758 .928 r
.3493 .74386 m .35738 .74152 L .35988 .74369 L p F P
0 g
s
.65 .758 .928 r
.35738 .74152 m .3493 .74386 L .34678 .74169 L p F P
0 g
s
.65 .758 .928 r
.60834 .74392 m .61683 .74157 L .61896 .74374 L p F P
0 g
s
.65 .758 .928 r
.61683 .74157 m .60834 .74392 L .6062 .74175 L p F P
0 g
s
.65 .758 .928 r
.47882 .74393 m .4871 .74158 L .48942 .74375 L p F P
0 g
s
.65 .758 .928 r
.4871 .74158 m .47882 .74393 L .47649 .74176 L p F P
0 g
s
.65 .758 .928 r
.35988 .74369 m .36798 .74135 L .37047 .74352 L p F P
0 g
s
.65 .758 .928 r
.36798 .74135 m .35988 .74369 L .35738 .74152 L p F P
0 g
s
.65 .758 .928 r
.61896 .74374 m .62746 .74138 L .62958 .74355 L p F P
0 g
s
.65 .758 .928 r
.62746 .74138 m .61896 .74374 L .61683 .74157 L p F P
0 g
s
.65 .758 .928 r
.48942 .74375 m .49772 .7414 L .50002 .74357 L p F P
0 g
s
.65 .758 .928 r
.49772 .7414 m .48942 .74375 L .4871 .74158 L p F P
0 g
s
.65 .758 .928 r
.37047 .74352 m .37859 .74118 L .38106 .74335 L p F P
0 g
s
.65 .758 .928 r
.37859 .74118 m .37047 .74352 L .36798 .74135 L p F P
0 g
s
.65 .758 .928 r
.62958 .74355 m .6381 .7412 L .6402 .74337 L p F P
0 g
s
.65 .758 .928 r
.6381 .7412 m .62958 .74355 L .62746 .74138 L p F P
0 g
s
.65 .758 .928 r
.50002 .74357 m .50834 .74122 L .51063 .74339 L p F P
0 g
s
.65 .758 .928 r
.50834 .74122 m .50002 .74357 L .49772 .7414 L p F P
0 g
s
.65 .758 .928 r
.38106 .74335 m .38919 .741 L .39165 .74317 L p F P
0 g
s
.65 .758 .928 r
.38919 .741 m .38106 .74335 L .37859 .74118 L p F P
0 g
s
.65 .758 .928 r
.6402 .74337 m .64874 .74101 L .65082 .74318 L p F P
0 g
s
.65 .758 .928 r
.64874 .74101 m .6402 .74337 L .6381 .7412 L p F P
0 g
s
.65 .758 .928 r
.51063 .74339 m .51897 .74104 L .52124 .74321 L p F P
0 g
s
.65 .758 .928 r
.51897 .74104 m .51063 .74339 L .50834 .74122 L p F P
0 g
s
.65 .758 .928 r
.39165 .74317 m .3998 .74083 L .40225 .743 L p F P
0 g
s
.65 .758 .928 r
.3998 .74083 m .39165 .74317 L .38919 .741 L p F P
0 g
s
.65 .758 .928 r
.65082 .74318 m .65938 .74082 L .66145 .74299 L p F P
0 g
s
.65 .758 .928 r
.65938 .74082 m .65082 .74318 L .64874 .74101 L p F P
0 g
s
.65 .758 .928 r
.52124 .74321 m .52959 .74086 L .53185 .74303 L p F P
0 g
s
.65 .758 .928 r
.52959 .74086 m .52124 .74321 L .51897 .74104 L p F P
0 g
s
.65 .758 .928 r
.66145 .74299 m .67003 .74064 L .67208 .74281 L p F P
0 g
s
.65 .758 .928 r
.67003 .74064 m .66145 .74299 L .65938 .74082 L p F P
0 g
s
.65 .758 .928 r
.40225 .743 m .41042 .74065 L .41285 .74282 L p F P
0 g
s
.65 .758 .928 r
.41042 .74065 m .40225 .743 L .3998 .74083 L p F P
0 g
s
.65 .758 .928 r
.53185 .74303 m .54022 .74068 L .54246 .74285 L p F P
0 g
s
.65 .758 .928 r
.54022 .74068 m .53185 .74303 L .52959 .74086 L p F P
0 g
s
.65 .758 .928 r
.67208 .74281 m .68067 .74045 L .68271 .74262 L p F P
0 g
s
.65 .758 .928 r
.68067 .74045 m .67208 .74281 L .67003 .74064 L p F P
0 g
s
.65 .758 .928 r
.41285 .74282 m .42103 .74047 L .42345 .74265 L p F P
0 g
s
.65 .758 .928 r
.42103 .74047 m .41285 .74282 L .41042 .74065 L p F P
0 g
s
.65 .758 .928 r
.55085 .74049 m .54246 .74285 L .54022 .74068 L p F P
0 g
s
.65 .758 .928 r
.54246 .74285 m .55085 .74049 L .55308 .74267 L p F P
0 g
s
.65 .758 .928 r
.68271 .74262 m .69132 .74026 L .69334 .74243 L p F P
0 g
s
.65 .758 .928 r
.69132 .74026 m .68271 .74262 L .68067 .74045 L p F P
0 g
s
.65 .758 .928 r
.42345 .74265 m .43165 .7403 L .43405 .74247 L p F P
0 g
s
.65 .758 .928 r
.43165 .7403 m .42345 .74265 L .42103 .74047 L p F P
0 g
s
.65 .758 .928 r
.55308 .74267 m .56149 .74031 L .5637 .74248 L p F P
0 g
s
.65 .758 .928 r
.56149 .74031 m .55308 .74267 L .55085 .74049 L p F P
0 g
s
.65 .758 .928 r
.69334 .74243 m .70197 .74007 L .70398 .74224 L p F P
0 g
s
.65 .758 .928 r
.70197 .74007 m .69334 .74243 L .69132 .74026 L p F P
0 g
s
.65 .758 .928 r
.43405 .74247 m .44227 .74012 L .44466 .74229 L p F P
0 g
s
.65 .758 .928 r
.44227 .74012 m .43405 .74247 L .43165 .7403 L p F P
0 g
s
.65 .758 .928 r
.57212 .74013 m .5637 .74248 L .56149 .74031 L p F P
0 g
s
.65 .758 .928 r
.5637 .74248 m .57212 .74013 L .57432 .7423 L p F P
0 g
s
.65 .758 .928 r
.315 .7422 m .32303 .73986 L .32559 .74203 L p F P
0 g
s
.65 .758 .928 r
.32303 .73986 m .315 .7422 L .31242 .74003 L p F P
0 g
s
.651 .758 .928 r
.71263 .73988 m .70398 .74224 L .70197 .74007 L p F P
0 g
s
.65 .758 .928 r
.44466 .74229 m .45289 .73994 L .45526 .74212 L p F P
0 g
s
.65 .758 .928 r
.45289 .73994 m .44466 .74229 L .44227 .74012 L p F P
0 g
s
.65 .758 .928 r
.57432 .7423 m .58276 .73994 L .58494 .74212 L p F P
0 g
s
.65 .758 .928 r
.58276 .73994 m .57432 .7423 L .57212 .74013 L p F P
0 g
s
.65 .758 .928 r
.32559 .74203 m .33364 .73969 L .33618 .74186 L p F P
0 g
s
.65 .758 .928 r
.33364 .73969 m .32559 .74203 L .32303 .73986 L p F P
0 g
s
.65 .758 .928 r
.45526 .74212 m .46352 .73976 L .46587 .74194 L p F P
0 g
s
.65 .758 .928 r
.46352 .73976 m .45526 .74212 L .45289 .73994 L p F P
0 g
s
.65 .758 .928 r
.58494 .74212 m .59341 .73976 L .59557 .74194 L p F P
0 g
s
.65 .758 .928 r
.59341 .73976 m .58494 .74212 L .58276 .73994 L p F P
0 g
s
.65 .758 .928 r
.33618 .74186 m .34425 .73952 L .34678 .74169 L p F P
0 g
s
.65 .758 .928 r
.34425 .73952 m .33618 .74186 L .33364 .73969 L p F P
0 g
s
.65 .758 .928 r
.59557 .74194 m .60405 .73958 L .6062 .74175 L p F P
0 g
s
.65 .758 .928 r
.60405 .73958 m .59557 .74194 L .59341 .73976 L p F P
0 g
s
.65 .758 .928 r
.46587 .74194 m .47415 .73958 L .47649 .74176 L p F P
0 g
s
.65 .758 .928 r
.47415 .73958 m .46587 .74194 L .46352 .73976 L p F P
0 g
s
.65 .758 .928 r
.34678 .74169 m .35487 .73935 L .35738 .74152 L p F P
0 g
s
.65 .758 .928 r
.35487 .73935 m .34678 .74169 L .34425 .73952 L p F P
0 g
s
.65 .758 .928 r
.6062 .74175 m .6147 .73939 L .61683 .74157 L p F P
0 g
s
.65 .758 .928 r
.6147 .73939 m .6062 .74175 L .60405 .73958 L p F P
0 g
s
.65 .758 .928 r
.47649 .74176 m .48478 .7394 L .4871 .74158 L p F P
0 g
s
.65 .758 .928 r
.48478 .7394 m .47649 .74176 L .47415 .73958 L p F P
0 g
s
.65 .758 .928 r
.35738 .74152 m .36548 .73917 L .36798 .74135 L p F P
0 g
s
.65 .758 .928 r
.36548 .73917 m .35738 .74152 L .35487 .73935 L p F P
0 g
s
.65 .758 .928 r
.61683 .74157 m .62535 .73921 L .62746 .74138 L p F P
0 g
s
.65 .758 .928 r
.62535 .73921 m .61683 .74157 L .6147 .73939 L p F P
0 g
s
.65 .758 .928 r
.4871 .74158 m .49541 .73922 L .49772 .7414 L p F P
0 g
s
.65 .758 .928 r
.49541 .73922 m .4871 .74158 L .48478 .7394 L p F P
0 g
s
.65 .758 .928 r
.36798 .74135 m .3761 .739 L .37859 .74118 L p F P
0 g
s
.65 .758 .928 r
.3761 .739 m .36798 .74135 L .36548 .73917 L p F P
0 g
s
.65 .758 .928 r
.62746 .74138 m .636 .73902 L .6381 .7412 L p F P
0 g
s
.65 .758 .928 r
.636 .73902 m .62746 .74138 L .62535 .73921 L p F P
0 g
s
.65 .758 .928 r
.49772 .7414 m .50605 .73904 L .50834 .74122 L p F P
0 g
s
.65 .758 .928 r
.50605 .73904 m .49772 .7414 L .49541 .73922 L p F P
0 g
s
.65 .758 .928 r
.37859 .74118 m .38673 .73882 L .38919 .741 L p F P
0 g
s
.65 .758 .928 r
.38673 .73882 m .37859 .74118 L .3761 .739 L p F P
0 g
s
.65 .758 .928 r
.6381 .7412 m .64665 .73883 L .64874 .74101 L p F P
0 g
s
.65 .758 .928 r
.64665 .73883 m .6381 .7412 L .636 .73902 L p F P
0 g
s
.65 .758 .928 r
.50834 .74122 m .51669 .73886 L .51897 .74104 L p F P
0 g
s
.65 .758 .928 r
.51669 .73886 m .50834 .74122 L .50605 .73904 L p F P
0 g
s
.65 .758 .928 r
.38919 .741 m .39735 .73865 L .3998 .74083 L p F P
0 g
s
.65 .758 .928 r
.39735 .73865 m .38919 .741 L .38673 .73882 L p F P
0 g
s
.65 .758 .928 r
.64874 .74101 m .65731 .73865 L .65938 .74082 L p F P
0 g
s
.65 .758 .928 r
.65731 .73865 m .64874 .74101 L .64665 .73883 L p F P
0 g
s
.65 .758 .928 r
.51897 .74104 m .52733 .73868 L .52959 .74086 L p F P
0 g
s
.65 .758 .928 r
.52733 .73868 m .51897 .74104 L .51669 .73886 L p F P
0 g
s
.65 .758 .928 r
.65938 .74082 m .66797 .73846 L .67003 .74064 L p F P
0 g
s
.65 .758 .928 r
.66797 .73846 m .65938 .74082 L .65731 .73865 L p F P
0 g
s
.65 .758 .928 r
.3998 .74083 m .40798 .73847 L .41042 .74065 L p F P
0 g
s
.65 .758 .928 r
.40798 .73847 m .3998 .74083 L .39735 .73865 L p F P
0 g
s
.65 .758 .928 r
.52959 .74086 m .53798 .7385 L .54022 .74068 L p F P
0 g
s
.65 .758 .928 r
.53798 .7385 m .52959 .74086 L .52733 .73868 L p F P
0 g
s
.65 .758 .928 r
.67003 .74064 m .67863 .73827 L .68067 .74045 L p F P
0 g
s
.65 .758 .928 r
.67863 .73827 m .67003 .74064 L .66797 .73846 L p F P
0 g
s
.65 .758 .928 r
.41042 .74065 m .41861 .73829 L .42103 .74047 L p F P
0 g
s
.65 .758 .928 r
.41861 .73829 m .41042 .74065 L .40798 .73847 L p F P
0 g
s
.65 .758 .928 r
.54022 .74068 m .54862 .73831 L .55085 .74049 L p F P
0 g
s
.65 .758 .928 r
.54862 .73831 m .54022 .74068 L .53798 .7385 L p F P
0 g
s
.65 .758 .928 r
.68067 .74045 m .6893 .73808 L .69132 .74026 L p F P
0 g
s
.65 .758 .928 r
.6893 .73808 m .68067 .74045 L .67863 .73827 L p F P
0 g
s
.65 .758 .928 r
.42103 .74047 m .42924 .73812 L .43165 .7403 L p F P
0 g
s
.65 .758 .928 r
.42924 .73812 m .42103 .74047 L .41861 .73829 L p F P
0 g
s
.65 .758 .928 r
.55927 .73813 m .55085 .74049 L .54862 .73831 L p F P
0 g
s
.65 .758 .928 r
.55085 .74049 m .55927 .73813 L .56149 .74031 L p F P
0 g
s
.65 .758 .928 r
.69132 .74026 m .69996 .73789 L .70197 .74007 L p F P
0 g
s
.651 .758 .928 r
.69996 .73789 m .69132 .74026 L .6893 .73808 L p F P
0 g
s
.65 .758 .928 r
.43165 .7403 m .43988 .73794 L .44227 .74012 L p F P
0 g
s
.65 .758 .928 r
.43988 .73794 m .43165 .7403 L .42924 .73812 L p F P
0 g
s
.65 .758 .928 r
.56149 .74031 m .56992 .73795 L .57212 .74013 L p F P
0 g
s
.65 .758 .928 r
.56992 .73795 m .56149 .74031 L .55927 .73813 L p F P
0 g
s
.65 .758 .928 r
.32047 .73768 m .31242 .74003 L .30984 .73784 L p F P
0 g
s
.65 .758 .928 r
.31242 .74003 m .32047 .73768 L .32303 .73986 L p F P
0 g
s
.651 .758 .928 r
.70197 .74007 m .71063 .7377 L .71263 .73988 L p F P
0 g
s
.651 .758 .928 r
.71063 .7377 m .70197 .74007 L .69996 .73789 L p F P
0 g
s
.65 .758 .928 r
.44227 .74012 m .45052 .73776 L .45289 .73994 L p F P
0 g
s
.65 .758 .928 r
.45052 .73776 m .44227 .74012 L .43988 .73794 L p F P
0 g
s
.65 .758 .928 r
.58058 .73776 m .57212 .74013 L .56992 .73795 L p F P
0 g
s
.65 .758 .928 r
.57212 .74013 m .58058 .73776 L .58276 .73994 L p F P
0 g
s
.65 .758 .928 r
.32303 .73986 m .33109 .73751 L .33364 .73969 L p F P
0 g
s
.65 .758 .928 r
.33109 .73751 m .32303 .73986 L .32047 .73768 L p F P
0 g
s
.651 .758 .928 r
.7213 .73751 m .71263 .73988 L .71063 .7377 L p F P
0 g
s
.65 .758 .928 r
.45289 .73994 m .46116 .73758 L .46352 .73976 L p F P
0 g
s
.65 .758 .928 r
.46116 .73758 m .45289 .73994 L .45052 .73776 L p F P
0 g
s
.65 .758 .928 r
.58276 .73994 m .59123 .73758 L .59341 .73976 L p F P
0 g
s
.65 .758 .928 r
.59123 .73758 m .58276 .73994 L .58058 .73776 L p F P
0 g
s
.65 .758 .928 r
.33364 .73969 m .34172 .73733 L .34425 .73952 L p F P
0 g
s
.65 .758 .928 r
.34172 .73733 m .33364 .73969 L .33109 .73751 L p F P
0 g
s
.65 .758 .928 r
.59341 .73976 m .60189 .73739 L .60405 .73958 L p F P
0 g
s
.65 .758 .928 r
.60189 .73739 m .59341 .73976 L .59123 .73758 L p F P
0 g
s
.65 .758 .928 r
.46352 .73976 m .4718 .7374 L .47415 .73958 L p F P
0 g
s
.65 .758 .928 r
.4718 .7374 m .46352 .73976 L .46116 .73758 L p F P
0 g
s
.65 .758 .928 r
.34425 .73952 m .35235 .73716 L .35487 .73935 L p F P
0 g
s
.65 .758 .928 r
.35235 .73716 m .34425 .73952 L .34172 .73733 L p F P
0 g
s
.65 .758 .928 r
.60405 .73958 m .61256 .73721 L .6147 .73939 L p F P
0 g
s
.65 .758 .928 r
.61256 .73721 m .60405 .73958 L .60189 .73739 L p F P
0 g
s
.65 .758 .928 r
.47415 .73958 m .48245 .73722 L .48478 .7394 L p F P
0 g
s
.65 .758 .928 r
.48245 .73722 m .47415 .73958 L .4718 .7374 L p F P
0 g
s
.65 .758 .928 r
.35487 .73935 m .36298 .73699 L .36548 .73917 L p F P
0 g
s
.65 .758 .928 r
.36298 .73699 m .35487 .73935 L .35235 .73716 L p F P
0 g
s
.65 .758 .928 r
.6147 .73939 m .62322 .73702 L .62535 .73921 L p F P
0 g
s
.65 .758 .928 r
.62322 .73702 m .6147 .73939 L .61256 .73721 L p F P
0 g
s
.65 .758 .928 r
.48478 .7394 m .4931 .73704 L .49541 .73922 L p F P
0 g
s
.65 .758 .928 r
.4931 .73704 m .48478 .7394 L .48245 .73722 L p F P
0 g
s
.65 .758 .928 r
.36548 .73917 m .37362 .73681 L .3761 .739 L p F P
0 g
s
.65 .758 .928 r
.37362 .73681 m .36548 .73917 L .36298 .73699 L p F P
0 g
s
.65 .758 .928 r
.62535 .73921 m .63389 .73684 L .636 .73902 L p F P
0 g
s
.65 .758 .928 r
.63389 .73684 m .62535 .73921 L .62322 .73702 L p F P
0 g
s
.65 .758 .928 r
.49541 .73922 m .50375 .73686 L .50605 .73904 L p F P
0 g
s
.65 .758 .928 r
.50375 .73686 m .49541 .73922 L .4931 .73704 L p F P
0 g
s
.65 .758 .928 r
.3761 .739 m .38425 .73664 L .38673 .73882 L p F P
0 g
s
.65 .758 .928 r
.38425 .73664 m .3761 .739 L .37362 .73681 L p F P
0 g
s
.65 .758 .928 r
.636 .73902 m .64456 .73665 L .64665 .73883 L p F P
0 g
s
.65 .758 .928 r
.64456 .73665 m .636 .73902 L .63389 .73684 L p F P
0 g
s
.65 .758 .928 r
.50605 .73904 m .51441 .73668 L .51669 .73886 L p F P
0 g
s
.65 .758 .928 r
.51441 .73668 m .50605 .73904 L .50375 .73686 L p F P
0 g
s
.65 .758 .928 r
.38673 .73882 m .39489 .73646 L .39735 .73865 L p F P
0 g
s
.65 .758 .928 r
.39489 .73646 m .38673 .73882 L .38425 .73664 L p F P
0 g
s
.65 .758 .928 r
.64665 .73883 m .65523 .73646 L .65731 .73865 L p F P
0 g
s
.65 .758 .928 r
.65523 .73646 m .64665 .73883 L .64456 .73665 L p F P
0 g
s
.65 .758 .928 r
.51669 .73886 m .52506 .73649 L .52733 .73868 L p F P
0 g
s
.65 .758 .928 r
.52506 .73649 m .51669 .73886 L .51441 .73668 L p F P
0 g
s
.65 .758 .928 r
.65731 .73865 m .6659 .73627 L .66797 .73846 L p F P
0 g
s
.65 .758 .928 r
.6659 .73627 m .65731 .73865 L .65523 .73646 L p F P
0 g
s
.65 .758 .928 r
.39735 .73865 m .40554 .73628 L .40798 .73847 L p F P
0 g
s
.65 .758 .928 r
.40554 .73628 m .39735 .73865 L .39489 .73646 L p F P
0 g
s
.65 .758 .928 r
.52733 .73868 m .53572 .73631 L .53798 .7385 L p F P
0 g
s
.65 .758 .928 r
.53572 .73631 m .52733 .73868 L .52506 .73649 L p F P
0 g
s
.65 .758 .928 r
.66797 .73846 m .67658 .73609 L .67863 .73827 L p F P
0 g
s
.65 .758 .928 r
.67658 .73609 m .66797 .73846 L .6659 .73627 L p F P
0 g
s
.65 .758 .928 r
.40798 .73847 m .41618 .73611 L .41861 .73829 L p F P
0 g
s
.65 .758 .928 r
.41618 .73611 m .40798 .73847 L .40554 .73628 L p F P
0 g
s
.65 .758 .928 r
.53798 .7385 m .54638 .73613 L .54862 .73831 L p F P
0 g
s
.65 .758 .928 r
.54638 .73613 m .53798 .7385 L .53572 .73631 L p F P
0 g
s
.65 .758 .928 r
.67863 .73827 m .68726 .7359 L .6893 .73808 L p F P
0 g
s
.65 .758 .928 r
.68726 .7359 m .67863 .73827 L .67658 .73609 L p F P
0 g
s
.65 .758 .928 r
.41861 .73829 m .42683 .73593 L .42924 .73812 L p F P
0 g
s
.65 .758 .928 r
.42683 .73593 m .41861 .73829 L .41618 .73611 L p F P
0 g
s
.65 .758 .928 r
.54862 .73831 m .55705 .73594 L .55927 .73813 L p F P
0 g
s
.65 .758 .928 r
.55705 .73594 m .54862 .73831 L .54638 .73613 L p F P
0 g
s
.651 .758 .928 r
.6893 .73808 m .69794 .7357 L .69996 .73789 L p F P
0 g
s
.651 .758 .928 r
.69794 .7357 m .6893 .73808 L .68726 .7359 L p F P
0 g
s
.65 .758 .928 r
.42924 .73812 m .43748 .73575 L .43988 .73794 L p F P
0 g
s
.65 .758 .928 r
.43748 .73575 m .42924 .73812 L .42683 .73593 L p F P
0 g
s
.65 .758 .928 r
.56771 .73576 m .55927 .73813 L .55705 .73594 L p F P
0 g
s
.65 .758 .928 r
.55927 .73813 m .56771 .73576 L .56992 .73795 L p F P
0 g
s
.65 .758 .928 r
.30984 .73784 m .31789 .73549 L .32047 .73768 L p F P
0 g
s
.65 .757 .928 r
.31789 .73549 m .30984 .73784 L .30726 .73566 L p F P
0 g
s
.651 .758 .928 r
.69996 .73789 m .70863 .73551 L .71063 .7377 L p F P
0 g
s
.651 .758 .928 r
.70863 .73551 m .69996 .73789 L .69794 .7357 L p F P
0 g
s
.65 .758 .928 r
.43988 .73794 m .44814 .73557 L .45052 .73776 L p F P
0 g
s
.65 .758 .928 r
.44814 .73557 m .43988 .73794 L .43748 .73575 L p F P
0 g
s
.65 .758 .928 r
.56992 .73795 m .57838 .73558 L .58058 .73776 L p F P
0 g
s
.65 .758 .928 r
.57838 .73558 m .56992 .73795 L .56771 .73576 L p F P
0 g
s
.65 .758 .928 r
.32047 .73768 m .32853 .73532 L .33109 .73751 L p F P
0 g
s
.65 .758 .928 r
.32853 .73532 m .32047 .73768 L .31789 .73549 L p F P
0 g
s
.651 .758 .928 r
.71063 .7377 m .71932 .73532 L .7213 .73751 L p F P
0 g
s
.651 .758 .928 r
.71932 .73532 m .71063 .7377 L .70863 .73551 L p F P
0 g
s
.65 .758 .928 r
.45052 .73776 m .45879 .73539 L .46116 .73758 L p F P
0 g
s
.65 .758 .928 r
.45879 .73539 m .45052 .73776 L .44814 .73557 L p F P
0 g
s
.65 .758 .928 r
.58058 .73776 m .58906 .73539 L .59123 .73758 L p F P
0 g
s
.65 .758 .928 r
.58906 .73539 m .58058 .73776 L .57838 .73558 L p F P
0 g
s
.651 .758 .928 r
.73001 .73513 m .7213 .73751 L .71932 .73532 L p F P
0 g
s
.65 .758 .928 r
.33109 .73751 m .33918 .73514 L .34172 .73733 L p F P
0 g
s
.65 .758 .928 r
.33918 .73514 m .33109 .73751 L .32853 .73532 L p F P
0 g
s
.65 .758 .928 r
.59123 .73758 m .59973 .73521 L .60189 .73739 L p F P
0 g
s
.65 .758 .928 r
.59973 .73521 m .59123 .73758 L .58906 .73539 L p F P
0 g
s
.65 .758 .928 r
.46116 .73758 m .46945 .73521 L .4718 .7374 L p F P
0 g
s
.65 .758 .928 r
.46945 .73521 m .46116 .73758 L .45879 .73539 L p F P
0 g
s
.65 .758 .928 r
.34172 .73733 m .34982 .73497 L .35235 .73716 L p F P
0 g
s
.65 .758 .928 r
.34982 .73497 m .34172 .73733 L .33918 .73514 L p F P
0 g
s
.65 .758 .928 r
.60189 .73739 m .61041 .73502 L .61256 .73721 L p F P
0 g
s
.65 .758 .928 r
.61041 .73502 m .60189 .73739 L .59973 .73521 L p F P
0 g
s
.65 .758 .928 r
.4718 .7374 m .48011 .73503 L .48245 .73722 L p F P
0 g
s
.65 .758 .928 r
.48011 .73503 m .4718 .7374 L .46945 .73521 L p F P
0 g
s
.65 .758 .928 r
.35235 .73716 m .36047 .7348 L .36298 .73699 L p F P
0 g
s
.65 .758 .928 r
.36047 .7348 m .35235 .73716 L .34982 .73497 L p F P
0 g
s
.65 .758 .928 r
.61256 .73721 m .62109 .73483 L .62322 .73702 L p F P
0 g
s
.65 .758 .928 r
.62109 .73483 m .61256 .73721 L .61041 .73502 L p F P
0 g
s
.65 .758 .928 r
.48245 .73722 m .49078 .73485 L .4931 .73704 L p F P
0 g
s
.65 .758 .928 r
.49078 .73485 m .48245 .73722 L .48011 .73503 L p F P
0 g
s
.65 .758 .928 r
.36298 .73699 m .37112 .73462 L .37362 .73681 L p F P
0 g
s
.65 .758 .928 r
.37112 .73462 m .36298 .73699 L .36047 .7348 L p F P
0 g
s
.65 .758 .928 r
.62322 .73702 m .63177 .73465 L .63389 .73684 L p F P
0 g
s
.65 .758 .928 r
.63177 .73465 m .62322 .73702 L .62109 .73483 L p F P
0 g
s
.65 .758 .928 r
.4931 .73704 m .50144 .73467 L .50375 .73686 L p F P
0 g
s
.65 .758 .928 r
.50144 .73467 m .4931 .73704 L .49078 .73485 L p F P
0 g
s
.65 .758 .928 r
.37362 .73681 m .38177 .73445 L .38425 .73664 L p F P
0 g
s
.65 .758 .928 r
.38177 .73445 m .37362 .73681 L .37112 .73462 L p F P
0 g
s
.65 .758 .928 r
.63389 .73684 m .64246 .73446 L .64456 .73665 L p F P
0 g
s
.65 .758 .928 r
.64246 .73446 m .63389 .73684 L .63177 .73465 L p F P
0 g
s
.65 .758 .928 r
.50375 .73686 m .51211 .73448 L .51441 .73668 L p F P
0 g
s
.65 .758 .928 r
.51211 .73448 m .50375 .73686 L .50144 .73467 L p F P
0 g
s
.65 .758 .928 r
.38425 .73664 m .39243 .73427 L .39489 .73646 L p F P
0 g
s
.65 .758 .928 r
.39243 .73427 m .38425 .73664 L .38177 .73445 L p F P
0 g
s
.65 .758 .928 r
.64456 .73665 m .65314 .73427 L .65523 .73646 L p F P
0 g
s
.65 .758 .928 r
.65314 .73427 m .64456 .73665 L .64246 .73446 L p F P
0 g
s
.65 .758 .928 r
.51441 .73668 m .52279 .7343 L .52506 .73649 L p F P
0 g
s
.65 .758 .928 r
.52279 .7343 m .51441 .73668 L .51211 .73448 L p F P
0 g
s
.65 .758 .928 r
.39489 .73646 m .40309 .73409 L .40554 .73628 L p F P
0 g
s
.65 .758 .928 r
.40309 .73409 m .39489 .73646 L .39243 .73427 L p F P
0 g
s
.65 .758 .928 r
.65523 .73646 m .66383 .73408 L .6659 .73627 L p F P
0 g
s
.65 .758 .928 r
.66383 .73408 m .65523 .73646 L .65314 .73427 L p F P
0 g
s
.65 .758 .928 r
.52506 .73649 m .53346 .73412 L .53572 .73631 L p F P
0 g
s
.65 .758 .928 r
.53346 .73412 m .52506 .73649 L .52279 .7343 L p F P
0 g
s
.65 .758 .928 r
.6659 .73627 m .67453 .73389 L .67658 .73609 L p F P
0 g
s
.65 .758 .928 r
.67453 .73389 m .6659 .73627 L .66383 .73408 L p F P
0 g
s
.65 .758 .928 r
.40554 .73628 m .41375 .73391 L .41618 .73611 L p F P
0 g
s
.65 .758 .928 r
.41375 .73391 m .40554 .73628 L .40309 .73409 L p F P
0 g
s
.65 .758 .928 r
.53572 .73631 m .54414 .73393 L .54638 .73613 L p F P
0 g
s
.65 .758 .928 r
.54414 .73393 m .53572 .73631 L .53346 .73412 L p F P
0 g
s
.65 .758 .928 r
.67658 .73609 m .68522 .7337 L .68726 .7359 L p F P
0 g
s
.65 .758 .928 r
.68522 .7337 m .67658 .73609 L .67453 .73389 L p F P
0 g
s
.65 .758 .928 r
.41618 .73611 m .42441 .73373 L .42683 .73593 L p F P
0 g
s
.65 .758 .928 r
.42441 .73373 m .41618 .73611 L .41375 .73391 L p F P
0 g
s
.65 .758 .928 r
.54638 .73613 m .55482 .73375 L .55705 .73594 L p F P
0 g
s
.65 .758 .928 r
.55482 .73375 m .54638 .73613 L .54414 .73393 L p F P
0 g
s
.651 .758 .928 r
.68726 .7359 m .69592 .73351 L .69794 .7357 L p F P
0 g
s
.651 .758 .928 r
.69592 .73351 m .68726 .7359 L .68522 .7337 L p F P
0 g
s
.65 .758 .928 r
.42683 .73593 m .43508 .73356 L .43748 .73575 L p F P
0 g
s
.65 .758 .928 r
.43508 .73356 m .42683 .73593 L .42441 .73373 L p F P
0 g
s
.65 .758 .928 r
.55705 .73594 m .5655 .73357 L .56771 .73576 L p F P
0 g
s
.65 .758 .928 r
.5655 .73357 m .55705 .73594 L .55482 .73375 L p F P
0 g
s
.65 .757 .928 r
.30726 .73566 m .31531 .73329 L .31789 .73549 L p F P
0 g
s
.65 .757 .928 r
.31531 .73329 m .30726 .73566 L .30466 .73346 L p F P
0 g
s
.651 .758 .928 r
.69794 .7357 m .70662 .73332 L .70863 .73551 L p F P
0 g
s
.651 .758 .928 r
.70662 .73332 m .69794 .7357 L .69592 .73351 L p F P
0 g
s
.65 .758 .928 r
.43748 .73575 m .44575 .73338 L .44814 .73557 L p F P
0 g
s
.65 .758 .928 r
.44575 .73338 m .43748 .73575 L .43508 .73356 L p F P
0 g
s
.65 .758 .928 r
.57619 .73338 m .56771 .73576 L .5655 .73357 L p F P
0 g
s
.65 .758 .928 r
.56771 .73576 m .57619 .73338 L .57838 .73558 L p F P
0 g
s
.65 .758 .928 r
.31789 .73549 m .32597 .73312 L .32853 .73532 L p F P
0 g
s
.65 .757 .928 r
.32597 .73312 m .31789 .73549 L .31531 .73329 L p F P
0 g
s
.651 .758 .928 r
.70863 .73551 m .71732 .73313 L .71932 .73532 L p F P
0 g
s
.651 .758 .928 r
.71732 .73313 m .70863 .73551 L .70662 .73332 L p F P
0 g
s
.65 .758 .928 r
.44814 .73557 m .45642 .73319 L .45879 .73539 L p F P
0 g
s
.65 .758 .928 r
.45642 .73319 m .44814 .73557 L .44575 .73338 L p F P
0 g
s
.65 .758 .928 r
.57838 .73558 m .58687 .7332 L .58906 .73539 L p F P
0 g
s
.65 .758 .928 r
.58687 .7332 m .57838 .73558 L .57619 .73338 L p F P
0 g
s
.65 .758 .928 r
.32853 .73532 m .33663 .73295 L .33918 .73514 L p F P
0 g
s
.65 .758 .928 r
.33663 .73295 m .32853 .73532 L .32597 .73312 L p F P
0 g
s
.651 .758 .928 r
.71932 .73532 m .72803 .73294 L .73001 .73513 L p F P
0 g
s
.651 .758 .928 r
.72803 .73294 m .71932 .73532 L .71732 .73313 L p F P
0 g
s
.65 .758 .928 r
.45879 .73539 m .46709 .73301 L .46945 .73521 L p F P
0 g
s
.65 .758 .928 r
.46709 .73301 m .45879 .73539 L .45642 .73319 L p F P
0 g
s
.65 .758 .928 r
.59756 .73301 m .58906 .73539 L .58687 .7332 L p F P
0 g
s
.65 .758 .928 r
.58906 .73539 m .59756 .73301 L .59973 .73521 L p F P
0 g
s
.651 .758 .928 r
.73874 .73274 m .73001 .73513 L .72803 .73294 L p F P
0 g
s
.65 .758 .928 r
.33918 .73514 m .34729 .73278 L .34982 .73497 L p F P
0 g
s
.65 .758 .928 r
.34729 .73278 m .33918 .73514 L .33663 .73295 L p F P
0 g
s
.65 .758 .928 r
.59973 .73521 m .60826 .73282 L .61041 .73502 L p F P
0 g
s
.65 .758 .928 r
.60826 .73282 m .59973 .73521 L .59756 .73301 L p F P
0 g
s
.65 .758 .928 r
.46945 .73521 m .47777 .73283 L .48011 .73503 L p F P
0 g
s
.65 .758 .928 r
.47777 .73283 m .46945 .73521 L .46709 .73301 L p F P
0 g
s
.65 .758 .928 r
.34982 .73497 m .35795 .7326 L .36047 .7348 L p F P
0 g
s
.65 .758 .928 r
.35795 .7326 m .34982 .73497 L .34729 .73278 L p F P
0 g
s
.65 .758 .928 r
.61041 .73502 m .61895 .73264 L .62109 .73483 L p F P
0 g
s
.65 .758 .928 r
.61895 .73264 m .61041 .73502 L .60826 .73282 L p F P
0 g
s
.65 .758 .928 r
.48011 .73503 m .48845 .73265 L .49078 .73485 L p F P
0 g
s
.65 .758 .928 r
.48845 .73265 m .48011 .73503 L .47777 .73283 L p F P
0 g
s
.65 .758 .928 r
.36047 .7348 m .36862 .73242 L .37112 .73462 L p F P
0 g
s
.65 .758 .928 r
.36862 .73242 m .36047 .7348 L .35795 .7326 L p F P
0 g
s
.65 .758 .928 r
.62109 .73483 m .62965 .73245 L .63177 .73465 L p F P
0 g
s
.65 .758 .928 r
.62965 .73245 m .62109 .73483 L .61895 .73264 L p F P
0 g
s
.65 .758 .928 r
.49078 .73485 m .49913 .73247 L .50144 .73467 L p F P
0 g
s
.65 .758 .928 r
.49913 .73247 m .49078 .73485 L .48845 .73265 L p F P
0 g
s
.65 .758 .928 r
.37112 .73462 m .37928 .73225 L .38177 .73445 L p F P
0 g
s
.65 .758 .928 r
.37928 .73225 m .37112 .73462 L .36862 .73242 L p F P
0 g
s
.65 .758 .928 r
.63177 .73465 m .64035 .73226 L .64246 .73446 L p F P
0 g
s
.65 .758 .928 r
.64035 .73226 m .63177 .73465 L .62965 .73245 L p F P
0 g
s
.65 .758 .928 r
.50144 .73467 m .50982 .73229 L .51211 .73448 L p F P
0 g
s
.65 .758 .928 r
.50982 .73229 m .50144 .73467 L .49913 .73247 L p F P
0 g
s
.65 .758 .928 r
.38177 .73445 m .38996 .73207 L .39243 .73427 L p F P
0 g
s
.65 .758 .928 r
.38996 .73207 m .38177 .73445 L .37928 .73225 L p F P
0 g
s
.65 .758 .928 r
.64246 .73446 m .65105 .73208 L .65314 .73427 L p F P
0 g
s
.65 .758 .928 r
.65105 .73208 m .64246 .73446 L .64035 .73226 L p F P
0 g
s
.65 .758 .928 r
.51211 .73448 m .5205 .7321 L .52279 .7343 L p F P
0 g
s
.65 .758 .928 r
.5205 .7321 m .51211 .73448 L .50982 .73229 L p F P
0 g
s
.65 .758 .928 r
.39243 .73427 m .40063 .73189 L .40309 .73409 L p F P
0 g
s
.65 .758 .928 r
.40063 .73189 m .39243 .73427 L .38996 .73207 L p F P
0 g
s
.65 .758 .928 r
.65314 .73427 m .66176 .73189 L .66383 .73408 L p F P
0 g
s
.65 .758 .928 r
.66176 .73189 m .65314 .73427 L .65105 .73208 L p F P
0 g
s
.65 .758 .928 r
.52279 .7343 m .53119 .73192 L .53346 .73412 L p F P
0 g
s
.65 .758 .928 r
.53119 .73192 m .52279 .7343 L .5205 .7321 L p F P
0 g
s
.65 .758 .928 r
.66383 .73408 m .67247 .7317 L .67453 .73389 L p F P
0 g
s
.65 .758 .928 r
.67247 .7317 m .66383 .73408 L .66176 .73189 L p F P
0 g
s
.65 .758 .928 r
.40309 .73409 m .41131 .73171 L .41375 .73391 L p F P
0 g
s
.65 .758 .928 r
.41131 .73171 m .40309 .73409 L .40063 .73189 L p F P
0 g
s
.65 .758 .928 r
.53346 .73412 m .54189 .73173 L .54414 .73393 L p F P
0 g
s
.65 .758 .928 r
.54189 .73173 m .53346 .73412 L .53119 .73192 L p F P
0 g
s
.65 .758 .928 r
.67453 .73389 m .68318 .73151 L .68522 .7337 L p F P
0 g
s
.65 .758 .928 r
.68318 .73151 m .67453 .73389 L .67247 .7317 L p F P
0 g
s
.65 .758 .928 r
.41375 .73391 m .42198 .73153 L .42441 .73373 L p F P
0 g
s
.65 .758 .928 r
.42198 .73153 m .41375 .73391 L .41131 .73171 L p F P
0 g
s
.65 .758 .928 r
.54414 .73393 m .55258 .73155 L .55482 .73375 L p F P
0 g
s
.65 .758 .928 r
.55258 .73155 m .54414 .73393 L .54189 .73173 L p F P
0 g
s
.651 .758 .928 r
.68522 .7337 m .69389 .73132 L .69592 .73351 L p F P
0 g
s
.651 .758 .928 r
.69389 .73132 m .68522 .7337 L .68318 .73151 L p F P
0 g
s
.65 .758 .928 r
.42441 .73373 m .43267 .73135 L .43508 .73356 L p F P
0 g
s
.65 .758 .928 r
.43267 .73135 m .42441 .73373 L .42198 .73153 L p F P
0 g
s
.65 .758 .928 r
.55482 .73375 m .56328 .73137 L .5655 .73357 L p F P
0 g
s
.65 .758 .928 r
.56328 .73137 m .55482 .73375 L .55258 .73155 L p F P
0 g
s
.65 .757 .928 r
.30466 .73346 m .31273 .73109 L .31531 .73329 L p F P
0 g
s
.65 .757 .928 r
.31273 .73109 m .30466 .73346 L .30206 .73126 L p F P
0 g
s
.651 .758 .928 r
.69592 .73351 m .70461 .73112 L .70662 .73332 L p F P
0 g
s
.651 .758 .928 r
.70461 .73112 m .69592 .73351 L .69389 .73132 L p F P
0 g
s
.65 .758 .928 r
.43508 .73356 m .44335 .73117 L .44575 .73338 L p F P
0 g
s
.65 .758 .928 r
.44335 .73117 m .43508 .73356 L .43267 .73135 L p F P
0 g
s
.65 .758 .928 r
.5655 .73357 m .57398 .73118 L .57619 .73338 L p F P
0 g
s
.65 .758 .928 r
.57398 .73118 m .5655 .73357 L .56328 .73137 L p F P
0 g
s
.65 .757 .928 r
.31531 .73329 m .3234 .73092 L .32597 .73312 L p F P
0 g
s
.65 .757 .928 r
.3234 .73092 m .31531 .73329 L .31273 .73109 L p F P
0 g
s
.651 .758 .928 r
.70662 .73332 m .71532 .73093 L .71732 .73313 L p F P
0 g
s
.651 .758 .928 r
.71532 .73093 m .70662 .73332 L .70461 .73112 L p F P
0 g
s
.65 .758 .928 r
.44575 .73338 m .45404 .73099 L .45642 .73319 L p F P
0 g
s
.65 .758 .928 r
.45404 .73099 m .44575 .73338 L .44335 .73117 L p F P
0 g
s
.65 .758 .928 r
.57619 .73338 m .58468 .731 L .58687 .7332 L p F P
0 g
s
.65 .758 .928 r
.58468 .731 m .57619 .73338 L .57398 .73118 L p F P
0 g
s
.65 .758 .928 r
.32597 .73312 m .33407 .73075 L .33663 .73295 L p F P
0 g
s
.65 .758 .928 r
.33407 .73075 m .32597 .73312 L .3234 .73092 L p F P
0 g
s
.651 .758 .928 r
.71732 .73313 m .72604 .73074 L .72803 .73294 L p F P
0 g
s
.651 .758 .928 r
.72604 .73074 m .71732 .73313 L .71532 .73093 L p F P
0 g
s
.65 .758 .928 r
.45642 .73319 m .46473 .73081 L .46709 .73301 L p F P
0 g
s
.65 .758 .928 r
.46473 .73081 m .45642 .73319 L .45404 .73099 L p F P
0 g
s
.65 .758 .928 r
.58687 .7332 m .59539 .73081 L .59756 .73301 L p F P
0 g
s
.65 .758 .928 r
.59539 .73081 m .58687 .7332 L .58468 .731 L p F P
0 g
s
.651 .758 .928 r
.72803 .73294 m .73677 .73054 L .73874 .73274 L p F P
0 g
s
.651 .758 .928 r
.73677 .73054 m .72803 .73294 L .72604 .73074 L p F P
0 g
s
.65 .758 .928 r
.34475 .73057 m .33663 .73295 L .33407 .73075 L p F P
0 g
s
.65 .758 .928 r
.33663 .73295 m .34475 .73057 L .34729 .73278 L p F P
0 g
s
.65 .758 .928 r
.6061 .73062 m .59756 .73301 L .59539 .73081 L p F P
0 g
s
.65 .758 .928 r
.59756 .73301 m .6061 .73062 L .60826 .73282 L p F P
0 g
s
.65 .758 .928 r
.46709 .73301 m .47542 .73063 L .47777 .73283 L p F P
0 g
s
.65 .758 .928 r
.47542 .73063 m .46709 .73301 L .46473 .73081 L p F P
0 g
s
.651 .758 .928 r
.74749 .73035 m .73874 .73274 L .73677 .73054 L p F P
0 g
s
.65 .758 .928 r
.34729 .73278 m .35542 .7304 L .35795 .7326 L p F P
0 g
s
.65 .758 .928 r
.35542 .7304 m .34729 .73278 L .34475 .73057 L p F P
0 g
s
.65 .758 .928 r
.60826 .73282 m .61681 .73044 L .61895 .73264 L p F P
0 g
s
.65 .758 .928 r
.61681 .73044 m .60826 .73282 L .6061 .73062 L p F P
0 g
s
.65 .758 .928 r
.47777 .73283 m .48611 .73045 L .48845 .73265 L p F P
0 g
s
.65 .758 .928 r
.48611 .73045 m .47777 .73283 L .47542 .73063 L p F P
0 g
s
.65 .758 .928 r
.35795 .7326 m .36611 .73022 L .36862 .73242 L p F P
0 g
s
.65 .758 .928 r
.36611 .73022 m .35795 .7326 L .35542 .7304 L p F P
0 g
s
.65 .758 .928 r
.61895 .73264 m .62752 .73025 L .62965 .73245 L p F P
0 g
s
.65 .758 .928 r
.62752 .73025 m .61895 .73264 L .61681 .73044 L p F P
0 g
s
.65 .758 .928 r
.48845 .73265 m .49681 .73026 L .49913 .73247 L p F P
0 g
s
.65 .758 .928 r
.49681 .73026 m .48845 .73265 L .48611 .73045 L p F P
0 g
s
.65 .758 .928 r
.36862 .73242 m .37679 .73004 L .37928 .73225 L p F P
0 g
s
.65 .758 .928 r
.37679 .73004 m .36862 .73242 L .36611 .73022 L p F P
0 g
s
.65 .758 .928 r
.62965 .73245 m .63824 .73006 L .64035 .73226 L p F P
0 g
s
.65 .758 .928 r
.63824 .73006 m .62965 .73245 L .62752 .73025 L p F P
0 g
s
.65 .758 .928 r
.49913 .73247 m .50751 .73008 L .50982 .73229 L p F P
0 g
s
.65 .758 .928 r
.50751 .73008 m .49913 .73247 L .49681 .73026 L p F P
0 g
s
.65 .758 .928 r
.37928 .73225 m .38748 .72987 L .38996 .73207 L p F P
0 g
s
.65 .758 .928 r
.38748 .72987 m .37928 .73225 L .37679 .73004 L p F P
0 g
s
.65 .758 .928 r
.64035 .73226 m .64895 .72987 L .65105 .73208 L p F P
0 g
s
.65 .758 .928 r
.64895 .72987 m .64035 .73226 L .63824 .73006 L p F P
0 g
s
.65 .758 .928 r
.50982 .73229 m .51821 .7299 L .5205 .7321 L p F P
0 g
s
.65 .758 .928 r
.51821 .7299 m .50982 .73229 L .50751 .73008 L p F P
0 g
s
.65 .758 .928 r
.38996 .73207 m .39816 .72969 L .40063 .73189 L p F P
0 g
s
.65 .758 .928 r
.39816 .72969 m .38996 .73207 L .38748 .72987 L p F P
0 g
s
.65 .758 .928 r
.65105 .73208 m .65968 .72968 L .66176 .73189 L p F P
0 g
s
.65 .758 .928 r
.65968 .72968 m .65105 .73208 L .64895 .72987 L p F P
0 g
s
.65 .758 .928 r
.5205 .7321 m .52892 .72971 L .53119 .73192 L p F P
0 g
s
.65 .758 .928 r
.52892 .72971 m .5205 .7321 L .51821 .7299 L p F P
0 g
s
.65 .758 .928 r
.66176 .73189 m .6704 .72949 L .67247 .7317 L p F P
0 g
s
.65 .758 .928 r
.6704 .72949 m .66176 .73189 L .65968 .72968 L p F P
0 g
s
.65 .758 .928 r
.40063 .73189 m .40886 .72951 L .41131 .73171 L p F P
0 g
s
.65 .758 .928 r
.40886 .72951 m .40063 .73189 L .39816 .72969 L p F P
0 g
s
.65 .758 .928 r
.53119 .73192 m .53963 .72953 L .54189 .73173 L p F P
0 g
s
.65 .758 .928 r
.53963 .72953 m .53119 .73192 L .52892 .72971 L p F P
0 g
s
.65 .758 .928 r
.67247 .7317 m .68113 .7293 L .68318 .73151 L p F P
0 g
s
.65 .758 .928 r
.68113 .7293 m .67247 .7317 L .6704 .72949 L p F P
0 g
s
.65 .758 .928 r
.41131 .73171 m .41955 .72933 L .42198 .73153 L p F P
0 g
s
.65 .758 .928 r
.41955 .72933 m .41131 .73171 L .40886 .72951 L p F P
0 g
s
.65 .758 .928 r
.54189 .73173 m .55034 .72934 L .55258 .73155 L p F P
0 g
s
.65 .758 .928 r
.55034 .72934 m .54189 .73173 L .53963 .72953 L p F P
0 g
s
.651 .758 .928 r
.68318 .73151 m .69185 .72911 L .69389 .73132 L p F P
0 g
s
.651 .758 .928 r
.69185 .72911 m .68318 .73151 L .68113 .7293 L p F P
0 g
s
.65 .758 .928 r
.42198 .73153 m .43025 .72915 L .43267 .73135 L p F P
0 g
s
.65 .758 .928 r
.43025 .72915 m .42198 .73153 L .41955 .72933 L p F P
0 g
s
.65 .758 .928 r
.55258 .73155 m .56105 .72916 L .56328 .73137 L p F P
0 g
s
.65 .758 .928 r
.56105 .72916 m .55258 .73155 L .55034 .72934 L p F P
0 g
s
.65 .757 .928 r
.30206 .73126 m .31013 .72888 L .31273 .73109 L p F P
0 g
s
.65 .757 .928 r
.31013 .72888 m .30206 .73126 L .29945 .72905 L p F P
0 g
s
.651 .758 .928 r
.69389 .73132 m .70259 .72892 L .70461 .73112 L p F P
0 g
s
.651 .758 .928 r
.70259 .72892 m .69389 .73132 L .69185 .72911 L p F P
0 g
s
.65 .758 .928 r
.43267 .73135 m .44095 .72897 L .44335 .73117 L p F P
0 g
s
.65 .758 .928 r
.44095 .72897 m .43267 .73135 L .43025 .72915 L p F P
0 g
s
.65 .758 .928 r
.56328 .73137 m .57177 .72897 L .57398 .73118 L p F P
0 g
s
.65 .758 .928 r
.57177 .72897 m .56328 .73137 L .56105 .72916 L p F P
0 g
s
.65 .757 .928 r
.31273 .73109 m .32082 .72871 L .3234 .73092 L p F P
0 g
s
.65 .757 .928 r
.32082 .72871 m .31273 .73109 L .31013 .72888 L p F P
0 g
s
.651 .758 .928 r
.70461 .73112 m .71332 .72873 L .71532 .73093 L p F P
0 g
s
.651 .758 .928 r
.71332 .72873 m .70461 .73112 L .70259 .72892 L p F P
0 g
s
.65 .758 .928 r
.44335 .73117 m .45165 .72878 L .45404 .73099 L p F P
0 g
s
.65 .758 .928 r
.45165 .72878 m .44335 .73117 L .44095 .72897 L p F P
0 g
s
.65 .758 .928 r
.57398 .73118 m .58249 .72879 L .58468 .731 L p F P
0 g
s
.65 .758 .928 r
.58249 .72879 m .57398 .73118 L .57177 .72897 L p F P
0 g
s
.65 .758 .928 r
.3234 .73092 m .33151 .72854 L .33407 .73075 L p F P
0 g
s
.65 .757 .928 r
.33151 .72854 m .3234 .73092 L .32082 .72871 L p F P
0 g
s
.651 .758 .928 r
.71532 .73093 m .72406 .72853 L .72604 .73074 L p F P
0 g
s
.651 .758 .928 r
.72406 .72853 m .71532 .73093 L .71332 .72873 L p F P
0 g
s
.65 .758 .928 r
.45404 .73099 m .46235 .7286 L .46473 .73081 L p F P
0 g
s
.65 .758 .928 r
.46235 .7286 m .45404 .73099 L .45165 .72878 L p F P
0 g
s
.65 .758 .928 r
.59321 .7286 m .58468 .731 L .58249 .72879 L p F P
0 g
s
.65 .758 .928 r
.58468 .731 m .59321 .7286 L .59539 .73081 L p F P
0 g
s
.651 .758 .928 r
.72604 .73074 m .73479 .72834 L .73677 .73054 L p F P
0 g
s
.651 .758 .928 r
.73479 .72834 m .72604 .73074 L .72406 .72853 L p F P
0 g
s
.65 .758 .928 r
.33407 .73075 m .3422 .72836 L .34475 .73057 L p F P
0 g
s
.65 .758 .928 r
.3422 .72836 m .33407 .73075 L .33151 .72854 L p F P
0 g
s
.65 .758 .928 r
.59539 .73081 m .60393 .72841 L .6061 .73062 L p F P
0 g
s
.65 .758 .928 r
.60393 .72841 m .59539 .73081 L .59321 .7286 L p F P
0 g
s
.65 .758 .928 r
.46473 .73081 m .47306 .72842 L .47542 .73063 L p F P
0 g
s
.65 .758 .928 r
.47306 .72842 m .46473 .73081 L .46235 .7286 L p F P
0 g
s
.651 .758 .928 r
.73677 .73054 m .74554 .72814 L .74749 .73035 L p F P
0 g
s
.651 .758 .928 r
.74554 .72814 m .73677 .73054 L .73479 .72834 L p F P
0 g
s
.65 .758 .928 r
.34475 .73057 m .35289 .72819 L .35542 .7304 L p F P
0 g
s
.65 .758 .928 r
.35289 .72819 m .34475 .73057 L .3422 .72836 L p F P
0 g
s
.65 .758 .928 r
.61466 .72823 m .6061 .73062 L .60393 .72841 L p F P
0 g
s
.65 .758 .928 r
.6061 .73062 m .61466 .72823 L .61681 .73044 L p F P
0 g
s
.65 .758 .928 r
.47542 .73063 m .48377 .72824 L .48611 .73045 L p F P
0 g
s
.65 .758 .928 r
.48377 .72824 m .47542 .73063 L .47306 .72842 L p F P
0 g
s
.651 .758 .928 r
.75628 .72794 m .74749 .73035 L .74554 .72814 L p F P
0 g
s
.65 .758 .928 r
.35542 .7304 m .36359 .72801 L .36611 .73022 L p F P
0 g
s
.65 .758 .928 r
.36359 .72801 m .35542 .7304 L .35289 .72819 L p F P
0 g
s
.65 .758 .928 r
.61681 .73044 m .62539 .72804 L .62752 .73025 L p F P
0 g
s
.65 .758 .928 r
.62539 .72804 m .61681 .73044 L .61466 .72823 L p F P
0 g
s
.65 .758 .928 r
.48611 .73045 m .49449 .72805 L .49681 .73026 L p F P
0 g
s
.65 .758 .928 r
.49449 .72805 m .48611 .73045 L .48377 .72824 L p F P
0 g
s
.65 .758 .928 r
.36611 .73022 m .37429 .72783 L .37679 .73004 L p F P
0 g
s
.65 .758 .928 r
.37429 .72783 m .36611 .73022 L .36359 .72801 L p F P
0 g
s
.65 .758 .928 r
.62752 .73025 m .63612 .72785 L .63824 .73006 L p F P
0 g
s
.65 .758 .928 r
.63612 .72785 m .62752 .73025 L .62539 .72804 L p F P
0 g
s
.65 .758 .928 r
.49681 .73026 m .5052 .72787 L .50751 .73008 L p F P
0 g
s
.65 .758 .928 r
.5052 .72787 m .49681 .73026 L .49449 .72805 L p F P
0 g
s
.65 .758 .928 r
.37679 .73004 m .38499 .72765 L .38748 .72987 L p F P
0 g
s
.65 .758 .928 r
.38499 .72765 m .37679 .73004 L .37429 .72783 L p F P
0 g
s
.65 .758 .928 r
.63824 .73006 m .64685 .72766 L .64895 .72987 L p F P
0 g
s
.65 .758 .928 r
.64685 .72766 m .63824 .73006 L .63612 .72785 L p F P
0 g
s
.65 .758 .928 r
.50751 .73008 m .51592 .72769 L .51821 .7299 L p F P
0 g
s
.65 .758 .928 r
.51592 .72769 m .50751 .73008 L .5052 .72787 L p F P
0 g
s
.65 .758 .928 r
.38748 .72987 m .39569 .72747 L .39816 .72969 L p F P
0 g
s
.65 .758 .928 r
.39569 .72747 m .38748 .72987 L .38499 .72765 L p F P
0 g
s
.65 .758 .928 r
.64895 .72987 m .65759 .72747 L .65968 .72968 L p F P
0 g
s
.65 .758 .928 r
.65759 .72747 m .64895 .72987 L .64685 .72766 L p F P
0 g
s
.65 .758 .928 r
.51821 .7299 m .52664 .7275 L .52892 .72971 L p F P
0 g
s
.65 .758 .928 r
.52664 .7275 m .51821 .7299 L .51592 .72769 L p F P
0 g
s
.65 .758 .928 r
.65968 .72968 m .66833 .72728 L .6704 .72949 L p F P
0 g
s
.65 .758 .928 r
.66833 .72728 m .65968 .72968 L .65759 .72747 L p F P
0 g
s
.65 .758 .928 r
.39816 .72969 m .4064 .72729 L .40886 .72951 L p F P
0 g
s
.65 .758 .928 r
.4064 .72729 m .39816 .72969 L .39569 .72747 L p F P
0 g
s
.65 .758 .928 r
.52892 .72971 m .53736 .72732 L .53963 .72953 L p F P
0 g
s
.65 .758 .928 r
.53736 .72732 m .52892 .72971 L .52664 .7275 L p F P
0 g
s
.65 .758 .928 r
.6704 .72949 m .67907 .72709 L .68113 .7293 L p F P
0 g
s
.65 .758 .928 r
.67907 .72709 m .6704 .72949 L .66833 .72728 L p F P
0 g
s
.65 .758 .928 r
.40886 .72951 m .41711 .72711 L .41955 .72933 L p F P
0 g
s
.65 .758 .928 r
.41711 .72711 m .40886 .72951 L .4064 .72729 L p F P
0 g
s
.65 .758 .928 r
.53963 .72953 m .54809 .72713 L .55034 .72934 L p F P
0 g
s
.65 .758 .928 r
.54809 .72713 m .53963 .72953 L .53736 .72732 L p F P
0 g
s
.651 .758 .928 r
.68113 .7293 m .68981 .7269 L .69185 .72911 L p F P
0 g
s
.651 .758 .928 r
.68981 .7269 m .68113 .7293 L .67907 .72709 L p F P
0 g
s
.65 .758 .928 r
.41955 .72933 m .42782 .72693 L .43025 .72915 L p F P
0 g
s
.65 .758 .928 r
.42782 .72693 m .41955 .72933 L .41711 .72711 L p F P
0 g
s
.65 .758 .928 r
.55034 .72934 m .55882 .72695 L .56105 .72916 L p F P
0 g
s
.65 .758 .928 r
.55882 .72695 m .55034 .72934 L .54809 .72713 L p F P
0 g
s
.65 .757 .928 r
.29945 .72905 m .30753 .72667 L .31013 .72888 L p F P
0 g
s
.65 .757 .928 r
.30753 .72667 m .29945 .72905 L .29683 .72684 L p F P
0 g
s
.651 .758 .928 r
.69185 .72911 m .70056 .72671 L .70259 .72892 L p F P
0 g
s
.651 .758 .928 r
.70056 .72671 m .69185 .72911 L .68981 .7269 L p F P
0 g
s
.65 .758 .928 r
.43025 .72915 m .43854 .72675 L .44095 .72897 L p F P
0 g
s
.65 .758 .928 r
.43854 .72675 m .43025 .72915 L .42782 .72693 L p F P
0 g
s
.65 .758 .928 r
.56105 .72916 m .56955 .72676 L .57177 .72897 L p F P
0 g
s
.65 .758 .928 r
.56955 .72676 m .56105 .72916 L .55882 .72695 L p F P
0 g
s
.65 .757 .928 r
.31013 .72888 m .31823 .72649 L .32082 .72871 L p F P
0 g
s
.65 .757 .928 r
.31823 .72649 m .31013 .72888 L .30753 .72667 L p F P
0 g
s
.651 .758 .928 r
.70259 .72892 m .71131 .72652 L .71332 .72873 L p F P
0 g
s
.651 .758 .928 r
.71131 .72652 m .70259 .72892 L .70056 .72671 L p F P
0 g
s
.65 .758 .928 r
.44095 .72897 m .44925 .72657 L .45165 .72878 L p F P
0 g
s
.65 .758 .928 r
.44925 .72657 m .44095 .72897 L .43854 .72675 L p F P
0 g
s
.65 .758 .928 r
.57177 .72897 m .58028 .72657 L .58249 .72879 L p F P
0 g
s
.65 .758 .928 r
.58028 .72657 m .57177 .72897 L .56955 .72676 L p F P
0 g
s
.65 .757 .928 r
.32082 .72871 m .32893 .72632 L .33151 .72854 L p F P
0 g
s
.65 .757 .928 r
.32893 .72632 m .32082 .72871 L .31823 .72649 L p F P
0 g
s
.651 .758 .928 r
.71332 .72873 m .72206 .72632 L .72406 .72853 L p F P
0 g
s
.651 .758 .928 r
.72206 .72632 m .71332 .72873 L .71131 .72652 L p F P
0 g
s
.65 .758 .928 r
.45165 .72878 m .45997 .72639 L .46235 .7286 L p F P
0 g
s
.65 .758 .928 r
.45997 .72639 m .45165 .72878 L .44925 .72657 L p F P
0 g
s
.65 .758 .928 r
.58249 .72879 m .59102 .72639 L .59321 .7286 L p F P
0 g
s
.65 .758 .928 r
.59102 .72639 m .58249 .72879 L .58028 .72657 L p F P
0 g
s
.651 .758 .928 r
.72406 .72853 m .73281 .72613 L .73479 .72834 L p F P
0 g
s
.651 .758 .928 r
.73281 .72613 m .72406 .72853 L .72206 .72632 L p F P
0 g
s
.65 .758 .928 r
.33151 .72854 m .33964 .72615 L .3422 .72836 L p F P
0 g
s
.65 .757 .928 r
.33964 .72615 m .33151 .72854 L .32893 .72632 L p F P
0 g
s
.65 .758 .928 r
.60176 .7262 m .59321 .7286 L .59102 .72639 L p F P
0 g
s
.65 .758 .928 r
.59321 .7286 m .60176 .7262 L .60393 .72841 L p F P
0 g
s
.65 .758 .928 r
.46235 .7286 m .4707 .7262 L .47306 .72842 L p F P
0 g
s
.65 .758 .928 r
.4707 .7262 m .46235 .7286 L .45997 .72639 L p F P
0 g
s
0 0 .345 r
.5259 .35164 m .52584 .35179 L .52584 .34816 L p F P
0 g
s
0 0 .345 r
.52584 .34816 m .52591 .348 L .5259 .35164 L p F P
0 g
s
.762 .5 .538 r
.52562 .35175 m .52584 .35179 L .52584 .34816 L p F P
0 g
s
.762 .5 .538 r
.52584 .34816 m .52561 .34811 L .52562 .35175 L p F P
0 g
s
.651 .758 .928 r
.73479 .72834 m .74357 .72593 L .74554 .72814 L p F P
0 g
s
.651 .758 .928 r
.74357 .72593 m .73479 .72834 L .73281 .72613 L p F P
0 g
s
.65 .758 .928 r
.3422 .72836 m .35035 .72597 L .35289 .72819 L p F P
0 g
s
.65 .758 .928 r
.35035 .72597 m .3422 .72836 L .33964 .72615 L p F P
0 g
s
0 0 .348 r
.52568 .34796 m .52561 .34811 L .52562 .35175 L p F P
0 g
s
.65 .758 .928 r
.60393 .72841 m .6125 .72601 L .61466 .72823 L p F P
0 g
s
.65 .758 .928 r
.6125 .72601 m .60393 .72841 L .60176 .7262 L p F P
0 g
s
.65 .758 .928 r
.47306 .72842 m .48142 .72602 L .48377 .72824 L p F P
0 g
s
.65 .758 .928 r
.48142 .72602 m .47306 .72842 L .4707 .7262 L p F P
0 g
s
.762 .501 .539 r
.52568 .34796 m .52591 .348 L .5259 .35164 L p F P
0 g
s
.762 .501 .539 r
.5259 .35164 m .52568 .3516 L .52568 .34796 L p F P
0 g
s
0 0 .348 r
.52562 .35175 m .52568 .3516 L .52568 .34796 L p F P
0 g
s
.651 .758 .928 r
.74554 .72814 m .75433 .72573 L .75628 .72794 L p F P
0 g
s
.651 .758 .928 r
.75433 .72573 m .74554 .72814 L .74357 .72593 L p F P
0 g
s
.65 .758 .928 r
.36106 .72579 m .35289 .72819 L .35035 .72597 L p F P
0 g
s
.65 .758 .928 r
.35289 .72819 m .36106 .72579 L .36359 .72801 L p F P
0 g
s
.65 .758 .928 r
.62324 .72582 m .61466 .72823 L .6125 .72601 L p F P
0 g
s
.65 .758 .928 r
.61466 .72823 m .62324 .72582 L .62539 .72804 L p F P
0 g
s
.65 .758 .928 r
.48377 .72824 m .49215 .72584 L .49449 .72805 L p F P
0 g
s
.65 .758 .928 r
.49215 .72584 m .48377 .72824 L .48142 .72602 L p F P
0 g
s
.651 .758 .928 r
.76509 .72553 m .75628 .72794 L .75433 .72573 L p F P
0 g
s
.65 .758 .928 r
.36359 .72801 m .37178 .72561 L .37429 .72783 L p F P
0 g
s
.65 .758 .928 r
.37178 .72561 m .36359 .72801 L .36106 .72579 L p F P
0 g
s
.65 .758 .928 r
.62539 .72804 m .63399 .72563 L .63612 .72785 L p F P
0 g
s
.65 .758 .928 r
.63399 .72563 m .62539 .72804 L .62324 .72582 L p F P
0 g
s
.65 .758 .928 r
.49449 .72805 m .50288 .72565 L .5052 .72787 L p F P
0 g
s
.65 .758 .928 r
.50288 .72565 m .49449 .72805 L .49215 .72584 L p F P
0 g
s
.65 .758 .928 r
.37429 .72783 m .38249 .72543 L .38499 .72765 L p F P
0 g
s
.65 .758 .928 r
.38249 .72543 m .37429 .72783 L .37178 .72561 L p F P
0 g
s
.65 .758 .928 r
.63612 .72785 m .64474 .72545 L .64685 .72766 L p F P
0 g
s
.65 .758 .928 r
.64474 .72545 m .63612 .72785 L .63399 .72563 L p F P
0 g
s
.65 .758 .928 r
.5052 .72787 m .51362 .72547 L .51592 .72769 L p F P
0 g
s
.65 .758 .928 r
.51362 .72547 m .5052 .72787 L .50288 .72565 L p F P
0 g
s
.65 .758 .928 r
.38499 .72765 m .39321 .72525 L .39569 .72747 L p F P
0 g
s
.65 .758 .928 r
.39321 .72525 m .38499 .72765 L .38249 .72543 L p F P
0 g
s
.65 .758 .928 r
.64685 .72766 m .65549 .72526 L .65759 .72747 L p F P
0 g
s
.65 .758 .928 r
.65549 .72526 m .64685 .72766 L .64474 .72545 L p F P
0 g
s
.65 .758 .928 r
.51592 .72769 m .52435 .72528 L .52664 .7275 L p F P
0 g
s
.65 .758 .928 r
.52435 .72528 m .51592 .72769 L .51362 .72547 L p F P
0 g
s
.65 .758 .928 r
.65759 .72747 m .66625 .72507 L .66833 .72728 L p F P
0 g
s
.65 .758 .928 r
.66625 .72507 m .65759 .72747 L .65549 .72526 L p F P
0 g
s
.65 .758 .928 r
.39569 .72747 m .40394 .72507 L .4064 .72729 L p F P
0 g
s
.65 .758 .928 r
.40394 .72507 m .39569 .72747 L .39321 .72525 L p F P
0 g
s
.65 .758 .928 r
.52664 .7275 m .53509 .7251 L .53736 .72732 L p F P
0 g
s
.65 .758 .928 r
.53509 .7251 m .52664 .7275 L .52435 .72528 L p F P
0 g
s
.65 .758 .928 r
.66833 .72728 m .677 .72487 L .67907 .72709 L p F P
0 g
s
.65 .758 .928 r
.677 .72487 m .66833 .72728 L .66625 .72507 L p F P
0 g
s
.65 .758 .928 r
.4064 .72729 m .41466 .72489 L .41711 .72711 L p F P
0 g
s
.65 .758 .928 r
.41466 .72489 m .4064 .72729 L .40394 .72507 L p F P
0 g
s
.65 .758 .928 r
.53736 .72732 m .54583 .72491 L .54809 .72713 L p F P
0 g
s
.65 .758 .928 r
.54583 .72491 m .53736 .72732 L .53509 .7251 L p F P
0 g
s
.651 .758 .928 r
.67907 .72709 m .68776 .72468 L .68981 .7269 L p F P
0 g
s
.651 .758 .928 r
.68776 .72468 m .67907 .72709 L .677 .72487 L p F P
0 g
s
.65 .758 .928 r
.41711 .72711 m .42539 .72471 L .42782 .72693 L p F P
0 g
s
.65 .758 .928 r
.42539 .72471 m .41711 .72711 L .41466 .72489 L p F P
0 g
s
.65 .758 .928 r
.54809 .72713 m .55658 .72472 L .55882 .72695 L p F P
0 g
s
.65 .758 .928 r
.55658 .72472 m .54809 .72713 L .54583 .72491 L p F P
0 g
s
.65 .757 .928 r
.29683 .72684 m .30492 .72445 L .30753 .72667 L p F P
0 g
s
.65 .757 .928 r
.30492 .72445 m .29683 .72684 L .29421 .72462 L p F P
0 g
s
.651 .758 .928 r
.68981 .7269 m .69853 .72449 L .70056 .72671 L p F P
0 g
s
.651 .758 .928 r
.69853 .72449 m .68981 .7269 L .68776 .72468 L p F P
0 g
s
.65 .758 .928 r
.42782 .72693 m .43612 .72453 L .43854 .72675 L p F P
0 g
s
.65 .758 .928 r
.43612 .72453 m .42782 .72693 L .42539 .72471 L p F P
0 g
s
.65 .758 .928 r
.55882 .72695 m .56732 .72454 L .56955 .72676 L p F P
0 g
s
.65 .758 .928 r
.56732 .72454 m .55882 .72695 L .55658 .72472 L p F P
0 g
s
.65 .757 .928 r
.30753 .72667 m .31564 .72427 L .31823 .72649 L p F P
0 g
s
.65 .757 .928 r
.31564 .72427 m .30753 .72667 L .30492 .72445 L p F P
0 g
s
.651 .758 .928 r
.70056 .72671 m .70929 .7243 L .71131 .72652 L p F P
0 g
s
.651 .758 .928 r
.70929 .7243 m .70056 .72671 L .69853 .72449 L p F P
0 g
s
.65 .758 .928 r
.43854 .72675 m .44685 .72435 L .44925 .72657 L p F P
0 g
s
.65 .758 .928 r
.44685 .72435 m .43854 .72675 L .43612 .72453 L p F P
0 g
s
.65 .758 .928 r
.56955 .72676 m .57807 .72435 L .58028 .72657 L p F P
0 g
s
.65 .758 .928 r
.57807 .72435 m .56955 .72676 L .56732 .72454 L p F P
0 g
s
0 0 .345 r
.5259 .35529 m .52583 .35543 L .52584 .35179 L p F P
0 g
s
0 0 .345 r
.52584 .35179 m .5259 .35164 L .5259 .35529 L p F P
0 g
s
.762 .5 .538 r
.52563 .35539 m .52583 .35543 L .52584 .35179 L p F P
0 g
s
.762 .5 .538 r
.52584 .35179 m .52562 .35175 L .52563 .35539 L p F P
0 g
s
.65 .757 .928 r
.31823 .72649 m .32635 .7241 L .32893 .72632 L p F P
0 g
s
.65 .757 .928 r
.32635 .7241 m .31823 .72649 L .31564 .72427 L p F P
0 g
s
.651 .758 .928 r
.71131 .72652 m .72006 .7241 L .72206 .72632 L p F P
0 g
s
.651 .758 .928 r
.72006 .7241 m .71131 .72652 L .70929 .7243 L p F P
0 g
s
0 0 .348 r
.52568 .3516 m .52562 .35175 L .52563 .35539 L p F P
0 g
s
.65 .758 .928 r
.44925 .72657 m .45759 .72416 L .45997 .72639 L p F P
0 g
s
.65 .758 .928 r
.45759 .72416 m .44925 .72657 L .44685 .72435 L p F P
0 g
s
.65 .758 .928 r
.58028 .72657 m .58883 .72416 L .59102 .72639 L p F P
0 g
s
.65 .758 .928 r
.58883 .72416 m .58028 .72657 L .57807 .72435 L p F P
0 g
s
.762 .501 .539 r
.52568 .3516 m .5259 .35164 L .5259 .35529 L p F P
0 g
s
.762 .501 .539 r
.5259 .35529 m .52569 .35525 L .52568 .3516 L p F P
0 g
s
0 0 .348 r
.52563 .35539 m .52569 .35525 L .52568 .3516 L p F P
0 g
s
.65 .757 .928 r
.32893 .72632 m .33708 .72392 L .33964 .72615 L p F P
0 g
s
.65 .757 .928 r
.33708 .72392 m .32893 .72632 L .32635 .7241 L p F P
0 g
s
.651 .758 .928 r
.72206 .72632 m .73083 .72391 L .73281 .72613 L p F P
0 g
s
.651 .758 .928 r
.73083 .72391 m .72206 .72632 L .72006 .7241 L p F P
0 g
s
.65 .758 .928 r
.45997 .72639 m .46833 .72398 L .4707 .7262 L p F P
0 g
s
.65 .758 .928 r
.46833 .72398 m .45997 .72639 L .45759 .72416 L p F P
0 g
s
.65 .758 .928 r
.59102 .72639 m .59958 .72398 L .60176 .7262 L p F P
0 g
s
.65 .758 .928 r
.59958 .72398 m .59102 .72639 L .58883 .72416 L p F P
0 g
s
.651 .758 .928 r
.73281 .72613 m .7416 .72371 L .74357 .72593 L p F P
0 g
s
.651 .758 .928 r
.7416 .72371 m .73281 .72613 L .73083 .72391 L p F P
0 g
s
.65 .758 .928 r
.33964 .72615 m .3478 .72375 L .35035 .72597 L p F P
0 g
s
.65 .757 .928 r
.3478 .72375 m .33964 .72615 L .33708 .72392 L p F P
0 g
s
.65 .758 .928 r
.61034 .72379 m .60176 .7262 L .59958 .72398 L p F P
0 g
s
.65 .758 .928 r
.60176 .7262 m .61034 .72379 L .6125 .72601 L p F P
0 g
s
.65 .758 .928 r
.4707 .7262 m .47907 .7238 L .48142 .72602 L p F P
0 g
s
.65 .758 .928 r
.47907 .7238 m .4707 .7262 L .46833 .72398 L p F P
0 g
s
.651 .758 .928 r
.74357 .72593 m .75238 .72351 L .75433 .72573 L p F P
0 g
s
.651 .758 .928 r
.75238 .72351 m .74357 .72593 L .7416 .72371 L p F P
0 g
s
.65 .758 .928 r
.35035 .72597 m .35853 .72357 L .36106 .72579 L p F P
0 g
s
.65 .758 .928 r
.35853 .72357 m .35035 .72597 L .3478 .72375 L p F P
0 g
s
.65 .758 .928 r
.6125 .72601 m .6211 .7236 L .62324 .72582 L p F P
0 g
s
.65 .758 .928 r
.6211 .7236 m .6125 .72601 L .61034 .72379 L p F P
0 g
s
.65 .758 .928 r
.48142 .72602 m .48981 .72361 L .49215 .72584 L p F P
0 g
s
.65 .758 .928 r
.48981 .72361 m .48142 .72602 L .47907 .7238 L p F P
0 g
s
.651 .758 .928 r
.75433 .72573 m .76315 .72331 L .76509 .72553 L p F P
0 g
s
.651 .758 .928 r
.76315 .72331 m .75433 .72573 L .75238 .72351 L p F P
0 g
s
.65 .758 .928 r
.36926 .72339 m .36106 .72579 L .35853 .72357 L p F P
0 g
s
.65 .758 .928 r
.36106 .72579 m .36926 .72339 L .37178 .72561 L p F P
0 g
s
.65 .758 .928 r
.62324 .72582 m .63186 .72341 L .63399 .72563 L p F P
0 g
s
.65 .758 .928 r
.63186 .72341 m .62324 .72582 L .6211 .7236 L p F P
0 g
s
.65 .758 .928 r
.49215 .72584 m .50056 .72343 L .50288 .72565 L p F P
0 g
s
.65 .758 .928 r
.50056 .72343 m .49215 .72584 L .48981 .72361 L p F P
0 g
s
.651 .758 .928 r
.77393 .72311 m .76509 .72553 L .76315 .72331 L p F P
0 g
s
.65 .758 .928 r
.37178 .72561 m .37999 .72321 L .38249 .72543 L p F P
0 g
s
.65 .758 .928 r
.37999 .72321 m .37178 .72561 L .36926 .72339 L p F P
0 g
s
.65 .758 .928 r
.63399 .72563 m .64262 .72322 L .64474 .72545 L p F P
0 g
s
.65 .758 .928 r
.64262 .72322 m .63399 .72563 L .63186 .72341 L p F P
0 g
s
.65 .758 .928 r
.50288 .72565 m .51131 .72324 L .51362 .72547 L p F P
0 g
s
.65 .758 .928 r
.51131 .72324 m .50288 .72565 L .50056 .72343 L p F P
0 g
s
.65 .758 .928 r
.38249 .72543 m .39073 .72303 L .39321 .72525 L p F P
0 g
s
.65 .758 .928 r
.39073 .72303 m .38249 .72543 L .37999 .72321 L p F P
0 g
s
.65 .758 .928 r
.64474 .72545 m .65339 .72303 L .65549 .72526 L p F P
0 g
s
.65 .758 .928 r
.65339 .72303 m .64474 .72545 L .64262 .72322 L p F P
0 g
s
.65 .758 .928 r
.51362 .72547 m .52206 .72306 L .52435 .72528 L p F P
0 g
s
.65 .758 .928 r
.52206 .72306 m .51362 .72547 L .51131 .72324 L p F P
0 g
s
.65 .758 .928 r
.39321 .72525 m .40146 .72285 L .40394 .72507 L p F P
0 g
s
.65 .758 .928 r
.40146 .72285 m .39321 .72525 L .39073 .72303 L p F P
0 g
s
.65 .758 .928 r
.65549 .72526 m .66416 .72284 L .66625 .72507 L p F P
0 g
s
.65 .758 .928 r
.66416 .72284 m .65549 .72526 L .65339 .72303 L p F P
0 g
s
.65 .758 .928 r
.52435 .72528 m .53281 .72287 L .53509 .7251 L p F P
0 g
s
.65 .758 .928 r
.53281 .72287 m .52435 .72528 L .52206 .72306 L p F P
0 g
s
.65 .758 .928 r
.66625 .72507 m .67493 .72265 L .677 .72487 L p F P
0 g
s
.65 .758 .928 r
.67493 .72265 m .66625 .72507 L .66416 .72284 L p F P
0 g
s
.65 .758 .928 r
.40394 .72507 m .4122 .72267 L .41466 .72489 L p F P
0 g
s
.65 .758 .928 r
.4122 .72267 m .40394 .72507 L .40146 .72285 L p F P
0 g
s
.65 .758 .928 r
.53509 .7251 m .54357 .72268 L .54583 .72491 L p F P
0 g
s
.65 .758 .928 r
.54357 .72268 m .53509 .7251 L .53281 .72287 L p F P
0 g
s
.651 .758 .928 r
.677 .72487 m .68571 .72246 L .68776 .72468 L p F P
0 g
s
.651 .758 .928 r
.68571 .72246 m .677 .72487 L .67493 .72265 L p F P
0 g
s
.65 .758 .928 r
.41466 .72489 m .42295 .72248 L .42539 .72471 L p F P
0 g
s
.65 .758 .928 r
.42295 .72248 m .41466 .72489 L .4122 .72267 L p F P
0 g
s
.65 .758 .928 r
.54583 .72491 m .55433 .7225 L .55658 .72472 L p F P
0 g
s
.65 .758 .928 r
.55433 .7225 m .54583 .72491 L .54357 .72268 L p F P
0 g
s
.65 .757 .928 r
.29421 .72462 m .3023 .72222 L .30492 .72445 L p F P
0 g
s
.65 .757 .928 r
.3023 .72222 m .29421 .72462 L .29157 .72239 L p F P
0 g
s
0 0 .345 r
.52589 .35895 m .52583 .35908 L .52583 .35543 L p F P
0 g
s
0 0 .345 r
.52583 .35543 m .5259 .35529 L .52589 .35895 L p F P
0 g
s
.762 .5 .538 r
.52563 .35904 m .52583 .35908 L .52583 .35543 L p F P
0 g
s
.762 .5 .538 r
.52583 .35543 m .52563 .35539 L .52563 .35904 L p F P
0 g
s
.651 .758 .928 r
.68776 .72468 m .69649 .72227 L .69853 .72449 L p F P
0 g
s
.651 .758 .928 r
.69649 .72227 m .68776 .72468 L .68571 .72246 L p F P
0 g
s
0 0 .348 r
.52569 .35525 m .52563 .35539 L .52563 .35904 L p F P
0 g
s
.65 .758 .928 r
.42539 .72471 m .43369 .7223 L .43612 .72453 L p F P
0 g
s
.65 .758 .928 r
.43369 .7223 m .42539 .72471 L .42295 .72248 L p F P
0 g
s
.65 .758 .928 r
.55658 .72472 m .56509 .72231 L .56732 .72454 L p F P
0 g
s
.65 .758 .928 r
.56509 .72231 m .55658 .72472 L .55433 .7225 L p F P
0 g
s
.762 .501 .539 r
.52569 .35525 m .5259 .35529 L .52589 .35895 L p F P
0 g
s
.762 .501 .539 r
.52589 .35895 m .52569 .35891 L .52569 .35525 L p F P
0 g
s
0 0 .348 r
.52563 .35904 m .52569 .35891 L .52569 .35525 L p F P
0 g
s
.65 .757 .928 r
.30492 .72445 m .31303 .72204 L .31564 .72427 L p F P
0 g
s
.65 .757 .928 r
.31303 .72204 m .30492 .72445 L .3023 .72222 L p F P
0 g
s
.651 .758 .928 r
.69853 .72449 m .70727 .72207 L .70929 .7243 L p F P
0 g
s
.651 .758 .928 r
.70727 .72207 m .69853 .72449 L .69649 .72227 L p F P
0 g
s
.65 .758 .928 r
.43612 .72453 m .44444 .72212 L .44685 .72435 L p F P
0 g
s
.65 .758 .928 r
.44444 .72212 m .43612 .72453 L .43369 .7223 L p F P
0 g
s
.65 .758 .928 r
.56732 .72454 m .57586 .72212 L .57807 .72435 L p F P
0 g
s
.65 .758 .928 r
.57586 .72212 m .56732 .72454 L .56509 .72231 L p F P
0 g
s
.65 .757 .928 r
.31564 .72427 m .32377 .72187 L .32635 .7241 L p F P
0 g
s
.65 .757 .928 r
.32377 .72187 m .31564 .72427 L .31303 .72204 L p F P
0 g
s
.651 .758 .928 r
.70929 .7243 m .71805 .72188 L .72006 .7241 L p F P
0 g
s
.651 .758 .928 r
.71805 .72188 m .70929 .7243 L .70727 .72207 L p F P
0 g
s
.65 .758 .928 r
.44685 .72435 m .45519 .72193 L .45759 .72416 L p F P
0 g
s
.65 .758 .928 r
.45519 .72193 m .44685 .72435 L .44444 .72212 L p F P
0 g
s
.65 .758 .928 r
.57807 .72435 m .58662 .72194 L .58883 .72416 L p F P
0 g
s
.65 .758 .928 r
.58662 .72194 m .57807 .72435 L .57586 .72212 L p F P
0 g
s
.65 .757 .928 r
.32635 .7241 m .33451 .72169 L .33708 .72392 L p F P
0 g
s
.65 .757 .928 r
.33451 .72169 m .32635 .7241 L .32377 .72187 L p F P
0 g
s
.651 .758 .928 r
.72006 .7241 m .72884 .72168 L .73083 .72391 L p F P
0 g
s
.651 .758 .928 r
.72884 .72168 m .72006 .7241 L .71805 .72188 L p F P
0 g
s
.65 .758 .928 r
.45759 .72416 m .46595 .72175 L .46833 .72398 L p F P
0 g
s
.65 .758 .928 r
.46595 .72175 m .45759 .72416 L .45519 .72193 L p F P
0 g
s
.65 .758 .928 r
.58883 .72416 m .59739 .72175 L .59958 .72398 L p F P
0 g
s
.65 .758 .928 r
.59739 .72175 m .58883 .72416 L .58662 .72194 L p F P
0 g
s
.651 .758 .928 r
.73083 .72391 m .73963 .72149 L .7416 .72371 L p F P
0 g
s
.651 .758 .928 r
.73963 .72149 m .73083 .72391 L .72884 .72168 L p F P
0 g
s
.65 .757 .928 r
.33708 .72392 m .34525 .72151 L .3478 .72375 L p F P
0 g
s
.65 .757 .928 r
.34525 .72151 m .33708 .72392 L .33451 .72169 L p F P
0 g
s
.65 .758 .928 r
.59958 .72398 m .60817 .72156 L .61034 .72379 L p F P
0 g
s
.65 .758 .928 r
.60817 .72156 m .59958 .72398 L .59739 .72175 L p F P
0 g
s
.65 .758 .928 r
.46833 .72398 m .4767 .72157 L .47907 .7238 L p F P
0 g
s
.65 .758 .928 r
.4767 .72157 m .46833 .72398 L .46595 .72175 L p F P
0 g
s
.651 .758 .928 r
.7416 .72371 m .75042 .72129 L .75238 .72351 L p F P
0 g
s
.651 .758 .928 r
.75042 .72129 m .7416 .72371 L .73963 .72149 L p F P
0 g
s
.65 .758 .928 r
.3478 .72375 m .35599 .72134 L .35853 .72357 L p F P
0 g
s
.65 .758 .928 r
.35599 .72134 m .3478 .72375 L .34525 .72151 L p F P
0 g
s
.65 .758 .928 r
.61894 .72137 m .61034 .72379 L .60817 .72156 L p F P
0 g
s
.65 .758 .928 r
.61034 .72379 m .61894 .72137 L .6211 .7236 L p F P
0 g
s
.65 .758 .928 r
.47907 .7238 m .48746 .72138 L .48981 .72361 L p F P
0 g
s
.65 .758 .928 r
.48746 .72138 m .47907 .7238 L .4767 .72157 L p F P
0 g
s
.651 .758 .928 r
.75238 .72351 m .76121 .72109 L .76315 .72331 L p F P
0 g
s
.651 .758 .928 r
.76121 .72109 m .75238 .72351 L .75042 .72129 L p F P
0 g
s
.65 .758 .928 r
.35853 .72357 m .36673 .72116 L .36926 .72339 L p F P
0 g
s
.65 .758 .928 r
.36673 .72116 m .35853 .72357 L .35599 .72134 L p F P
0 g
s
.65 .758 .928 r
.6211 .7236 m .62972 .72118 L .63186 .72341 L p F P
0 g
s
.65 .758 .928 r
.62972 .72118 m .6211 .7236 L .61894 .72137 L p F P
0 g
s
.65 .758 .928 r
.48981 .72361 m .49823 .7212 L .50056 .72343 L p F P
0 g
s
.65 .758 .928 r
.49823 .7212 m .48981 .72361 L .48746 .72138 L p F P
0 g
s
.651 .758 .928 r
.76315 .72331 m .772 .72089 L .77393 .72311 L p F P
0 g
s
.651 .758 .928 r
.772 .72089 m .76315 .72331 L .76121 .72109 L p F P
0 g
s
.65 .758 .928 r
.36926 .72339 m .37748 .72098 L .37999 .72321 L p F P
0 g
s
.65 .758 .928 r
.37748 .72098 m .36926 .72339 L .36673 .72116 L p F P
0 g
s
.65 .758 .928 r
.6405 .72099 m .63186 .72341 L .62972 .72118 L p F P
0 g
s
.65 .758 .928 r
.63186 .72341 m .6405 .72099 L .64262 .72322 L p F P
0 g
s
.65 .758 .928 r
.50056 .72343 m .50899 .72101 L .51131 .72324 L p F P
0 g
s
.65 .758 .928 r
.50899 .72101 m .50056 .72343 L .49823 .7212 L p F P
0 g
s
.651 .758 .928 r
.7828 .72069 m .77393 .72311 L .772 .72089 L p F P
0 g
s
.65 .758 .928 r
.37999 .72321 m .38823 .7208 L .39073 .72303 L p F P
0 g
s
.65 .758 .928 r
.38823 .7208 m .37999 .72321 L .37748 .72098 L p F P
0 g
s
.65 .758 .928 r
.64262 .72322 m .65128 .7208 L .65339 .72303 L p F P
0 g
s
.65 .758 .928 r
.65128 .7208 m .64262 .72322 L .6405 .72099 L p F P
0 g
s
.65 .758 .928 r
.51131 .72324 m .51976 .72082 L .52206 .72306 L p F P
0 g
s
.65 .758 .928 r
.51976 .72082 m .51131 .72324 L .50899 .72101 L p F P
0 g
s
.65 .758 .928 r
.39073 .72303 m .39899 .72061 L .40146 .72285 L p F P
0 g
s
.65 .758 .928 r
.39899 .72061 m .39073 .72303 L .38823 .7208 L p F P
0 g
s
.65 .758 .928 r
.65339 .72303 m .66207 .72061 L .66416 .72284 L p F P
0 g
s
.65 .758 .928 r
.66207 .72061 m .65339 .72303 L .65128 .7208 L p F P
0 g
s
.65 .758 .928 r
.52206 .72306 m .53053 .72064 L .53281 .72287 L p F P
0 g
s
.65 .758 .928 r
.53053 .72064 m .52206 .72306 L .51976 .72082 L p F P
0 g
s
0 0 .345 r
.52588 .36262 m .52583 .36274 L .52583 .35908 L p F P
0 g
s
0 0 .345 r
.52583 .35908 m .52589 .35895 L .52588 .36262 L p F P
0 g
s
.762 .5 .538 r
.52564 .36271 m .52583 .36274 L .52583 .35908 L p F P
0 g
s
.762 .5 .538 r
.52583 .35908 m .52563 .35904 L .52564 .36271 L p F P
0 g
s
.65 .758 .928 r
.66416 .72284 m .67286 .72042 L .67493 .72265 L p F P
0 g
s
.65 .758 .928 r
.67286 .72042 m .66416 .72284 L .66207 .72061 L p F P
0 g
s
0 0 .348 r
.52569 .35891 m .52563 .35904 L .52564 .36271 L p F P
0 g
s
.65 .758 .928 r
.40146 .72285 m .40974 .72043 L .4122 .72267 L p F P
0 g
s
.65 .758 .928 r
.40974 .72043 m .40146 .72285 L .39899 .72061 L p F P
0 g
s
.65 .758 .928 r
.53281 .72287 m .5413 .72045 L .54357 .72268 L p F P
0 g
s
.65 .758 .928 r
.5413 .72045 m .53281 .72287 L .53053 .72064 L p F P
0 g
s
.762 .501 .539 r
.52569 .35891 m .52589 .35895 L .52588 .36262 L p F P
0 g
s
.762 .501 .539 r
.52588 .36262 m .52569 .36258 L .52569 .35891 L p F P
0 g
s
0 0 .348 r
.52564 .36271 m .52569 .36258 L .52569 .35891 L p F P
0 g
s
.651 .758 .928 r
.67493 .72265 m .68365 .72023 L .68571 .72246 L p F P
0 g
s
.651 .758 .928 r
.68365 .72023 m .67493 .72265 L .67286 .72042 L p F P
0 g
s
.65 .758 .928 r
.4122 .72267 m .4205 .72025 L .42295 .72248 L p F P
0 g
s
.65 .758 .928 r
.4205 .72025 m .4122 .72267 L .40974 .72043 L p F P
0 g
s
.65 .758 .928 r
.54357 .72268 m .55208 .72026 L .55433 .7225 L p F P
0 g
s
.65 .758 .928 r
.55208 .72026 m .54357 .72268 L .5413 .72045 L p F P
0 g
s
.65 .757 .928 r
.29157 .72239 m .29968 .71998 L .3023 .72222 L p F P
0 g
s
.65 .757 .928 r
.29968 .71998 m .29157 .72239 L .28893 .72016 L p F P
0 g
s
.651 .758 .928 r
.68571 .72246 m .69444 .72003 L .69649 .72227 L p F P
0 g
s
.651 .758 .928 r
.69444 .72003 m .68571 .72246 L .68365 .72023 L p F P
0 g
s
.65 .758 .928 r
.42295 .72248 m .43126 .72007 L .43369 .7223 L p F P
0 g
s
.65 .758 .928 r
.43126 .72007 m .42295 .72248 L .4205 .72025 L p F P
0 g
s
.65 .758 .928 r
.55433 .7225 m .56285 .72008 L .56509 .72231 L p F P
0 g
s
.65 .758 .928 r
.56285 .72008 m .55433 .7225 L .55208 .72026 L p F P
0 g
s
.65 .757 .928 r
.3023 .72222 m .31042 .71981 L .31303 .72204 L p F P
0 g
s
.65 .757 .928 r
.31042 .71981 m .3023 .72222 L .29968 .71998 L p F P
0 g
s
.651 .758 .928 r
.69649 .72227 m .70524 .71984 L .70727 .72207 L p F P
0 g
s
.651 .758 .928 r
.70524 .71984 m .69649 .72227 L .69444 .72003 L p F P
0 g
s
.65 .758 .928 r
.43369 .7223 m .44203 .71988 L .44444 .72212 L p F P
0 g
s
.65 .758 .928 r
.44203 .71988 m .43369 .7223 L .43126 .72007 L p F P
0 g
s
.65 .758 .928 r
.56509 .72231 m .57363 .71989 L .57586 .72212 L p F P
0 g
s
.65 .758 .928 r
.57363 .71989 m .56509 .72231 L .56285 .72008 L p F P
0 g
s
.65 .757 .928 r
.31303 .72204 m .32117 .71963 L .32377 .72187 L p F P
0 g
s
.65 .757 .928 r
.32117 .71963 m .31303 .72204 L .31042 .71981 L p F P
0 g
s
.651 .758 .928 r
.70727 .72207 m .71604 .71965 L .71805 .72188 L p F P
0 g
s
.651 .758 .928 r
.71604 .71965 m .70727 .72207 L .70524 .71984 L p F P
0 g
s
.65 .758 .928 r
.44444 .72212 m .45279 .7197 L .45519 .72193 L p F P
0 g
s
.65 .758 .928 r
.45279 .7197 m .44444 .72212 L .44203 .71988 L p F P
0 g
s
.65 .758 .928 r
.57586 .72212 m .58442 .7197 L .58662 .72194 L p F P
0 g
s
.65 .758 .928 r
.58442 .7197 m .57586 .72212 L .57363 .71989 L p F P
0 g
s
.65 .757 .928 r
.32377 .72187 m .33193 .71946 L .33451 .72169 L p F P
0 g
s
.65 .757 .928 r
.33193 .71946 m .32377 .72187 L .32117 .71963 L p F P
0 g
s
.651 .758 .928 r
.71805 .72188 m .72684 .71945 L .72884 .72168 L p F P
0 g
s
.651 .758 .928 r
.72684 .71945 m .71805 .72188 L .71604 .71965 L p F P
0 g
s
.65 .758 .928 r
.45519 .72193 m .46356 .71951 L .46595 .72175 L p F P
0 g
s
.65 .758 .928 r
.46356 .71951 m .45519 .72193 L .45279 .7197 L p F P
0 g
s
.65 .758 .928 r
.58662 .72194 m .5952 .71951 L .59739 .72175 L p F P
0 g
s
.65 .758 .928 r
.5952 .71951 m .58662 .72194 L .58442 .7197 L p F P
0 g
s
.651 .758 .928 r
.72884 .72168 m .73764 .71925 L .73963 .72149 L p F P
0 g
s
.651 .758 .928 r
.73764 .71925 m .72884 .72168 L .72684 .71945 L p F P
0 g
s
.65 .757 .928 r
.33451 .72169 m .34268 .71928 L .34525 .72151 L p F P
0 g
s
.65 .757 .928 r
.34268 .71928 m .33451 .72169 L .33193 .71946 L p F P
0 g
s
.65 .758 .928 r
.59739 .72175 m .60599 .71932 L .60817 .72156 L p F P
0 g
s
.65 .758 .928 r
.60599 .71932 m .59739 .72175 L .5952 .71951 L p F P
0 g
s
.65 .758 .928 r
.46595 .72175 m .47434 .71933 L .4767 .72157 L p F P
0 g
s
.65 .758 .928 r
.47434 .71933 m .46595 .72175 L .46356 .71951 L p F P
0 g
s
.651 .758 .928 r
.73963 .72149 m .74845 .71906 L .75042 .72129 L p F P
0 g
s
.651 .758 .928 r
.74845 .71906 m .73963 .72149 L .73764 .71925 L p F P
0 g
s
.65 .758 .928 r
.34525 .72151 m .35344 .7191 L .35599 .72134 L p F P
0 g
s
.65 .757 .928 r
.35344 .7191 m .34525 .72151 L .34268 .71928 L p F P
0 g
s
.65 .758 .928 r
.60817 .72156 m .61678 .71913 L .61894 .72137 L p F P
0 g
s
.65 .758 .928 r
.61678 .71913 m .60817 .72156 L .60599 .71932 L p F P
0 g
s
.65 .758 .928 r
.4767 .72157 m .48511 .71914 L .48746 .72138 L p F P
0 g
s
.65 .758 .928 r
.48511 .71914 m .4767 .72157 L .47434 .71933 L p F P
0 g
s
.651 .758 .928 r
.75042 .72129 m .75926 .71886 L .76121 .72109 L p F P
0 g
s
.651 .758 .928 r
.75926 .71886 m .75042 .72129 L .74845 .71906 L p F P
0 g
s
.65 .758 .928 r
.35599 .72134 m .3642 .71892 L .36673 .72116 L p F P
0 g
s
.65 .758 .928 r
.3642 .71892 m .35599 .72134 L .35344 .7191 L p F P
0 g
s
.65 .758 .928 r
.61894 .72137 m .62758 .71894 L .62972 .72118 L p F P
0 g
s
.65 .758 .928 r
.62758 .71894 m .61894 .72137 L .61678 .71913 L p F P
0 g
s
.65 .758 .928 r
.48746 .72138 m .49589 .71896 L .49823 .7212 L p F P
0 g
s
.65 .758 .928 r
.49589 .71896 m .48746 .72138 L .48511 .71914 L p F P
0 g
s
.651 .758 .928 r
.76121 .72109 m .77007 .71866 L .772 .72089 L p F P
0 g
s
.651 .758 .928 r
.77007 .71866 m .76121 .72109 L .75926 .71886 L p F P
0 g
s
.65 .758 .928 r
.36673 .72116 m .37496 .71874 L .37748 .72098 L p F P
0 g
s
.65 .758 .928 r
.37496 .71874 m .36673 .72116 L .3642 .71892 L p F P
0 g
s
.65 .758 .928 r
.62972 .72118 m .63837 .71875 L .6405 .72099 L p F P
0 g
s
.65 .758 .928 r
.63837 .71875 m .62972 .72118 L .62758 .71894 L p F P
0 g
s
.65 .758 .928 r
.49823 .7212 m .50667 .71877 L .50899 .72101 L p F P
0 g
s
.65 .758 .928 r
.50667 .71877 m .49823 .7212 L .49589 .71896 L p F P
0 g
s
.651 .758 .928 r
.772 .72089 m .78088 .71845 L .7828 .72069 L p F P
0 g
s
.651 .758 .928 r
.78088 .71845 m .772 .72089 L .77007 .71866 L p F P
0 g
s
0 0 .345 r
.52588 .3663 m .52582 .36641 L .52583 .36274 L p F P
0 g
s
0 0 .345 r
.52583 .36274 m .52588 .36262 L .52588 .3663 L p F P
0 g
s
.762 .5 .538 r
.52564 .36638 m .52582 .36641 L .52583 .36274 L p F P
0 g
s
.762 .5 .538 r
.52583 .36274 m .52564 .36271 L .52564 .36638 L p F P
0 g
s
.65 .758 .928 r
.38573 .71856 m .37748 .72098 L .37496 .71874 L p F P
0 g
s
.65 .758 .928 r
.37748 .72098 m .38573 .71856 L .38823 .7208 L p F P
0 g
s
0 0 .348 r
.52569 .36258 m .52564 .36271 L .52564 .36638 L p F P
0 g
s
.65 .758 .928 r
.64917 .71856 m .6405 .72099 L .63837 .71875 L p F P
0 g
s
.65 .758 .928 r
.6405 .72099 m .64917 .71856 L .65128 .7208 L p F P
0 g
s
.65 .758 .928 r
.50899 .72101 m .51745 .71859 L .51976 .72082 L p F P
0 g
s
.65 .758 .928 r
.51745 .71859 m .50899 .72101 L .50667 .71877 L p F P
0 g
s
.762 .501 .539 r
.52569 .36258 m .52588 .36262 L .52588 .3663 L p F P
0 g
s
.762 .501 .539 r
.52588 .3663 m .5257 .36626 L .52569 .36258 L p F P
0 g
s
0 0 .348 r
.52564 .36638 m .5257 .36626 L .52569 .36258 L p F P
0 g
s
.651 .758 .928 r
.7917 .71825 m .7828 .72069 L .78088 .71845 L p F P
0 g
s
.65 .758 .928 r
.38823 .7208 m .3965 .71837 L .39899 .72061 L p F P
0 g
s
.65 .758 .928 r
.3965 .71837 m .38823 .7208 L .38573 .71856 L p F P
0 g
s
.65 .758 .928 r
.65128 .7208 m .65997 .71837 L .66207 .72061 L p F P
0 g
s
.65 .758 .928 r
.65997 .71837 m .65128 .7208 L .64917 .71856 L p F P
0 g
s
.65 .758 .928 r
.51976 .72082 m .52824 .7184 L .53053 .72064 L p F P
0 g
s
.65 .758 .928 r
.52824 .7184 m .51976 .72082 L .51745 .71859 L p F P
0 g
s
.65 .758 .928 r
.66207 .72061 m .67078 .71818 L .67286 .72042 L p F P
0 g
s
.65 .758 .928 r
.67078 .71818 m .66207 .72061 L .65997 .71837 L p F P
0 g
s
.65 .758 .928 r
.39899 .72061 m .40727 .71819 L .40974 .72043 L p F P
0 g
s
.65 .758 .928 r
.40727 .71819 m .39899 .72061 L .3965 .71837 L p F P
0 g
s
.65 .758 .928 r
.53053 .72064 m .53902 .71821 L .5413 .72045 L p F P
0 g
s
.65 .758 .928 r
.53902 .71821 m .53053 .72064 L .52824 .7184 L p F P
0 g
s
.651 .758 .928 r
.67286 .72042 m .68158 .71799 L .68365 .72023 L p F P
0 g
s
.651 .758 .928 r
.68158 .71799 m .67286 .72042 L .67078 .71818 L p F P
0 g
s
.65 .758 .928 r
.40974 .72043 m .41805 .71801 L .4205 .72025 L p F P
0 g
s
.65 .758 .928 r
.41805 .71801 m .40974 .72043 L .40727 .71819 L p F P
0 g
s
.65 .758 .928 r
.5413 .72045 m .54982 .71802 L .55208 .72026 L p F P
0 g
s
.65 .758 .928 r
.54982 .71802 m .5413 .72045 L .53902 .71821 L p F P
0 g
s
.65 .757 .928 r
.28893 .72016 m .29704 .71774 L .29968 .71998 L p F P
0 g
s
.65 .757 .928 r
.29704 .71774 m .28893 .72016 L .28628 .71792 L p F P
0 g
s
.651 .758 .928 r
.68365 .72023 m .69239 .71779 L .69444 .72003 L p F P
0 g
s
.651 .758 .928 r
.69239 .71779 m .68365 .72023 L .68158 .71799 L p F P
0 g
s
.65 .758 .928 r
.4205 .72025 m .42882 .71782 L .43126 .72007 L p F P
0 g
s
.65 .758 .928 r
.42882 .71782 m .4205 .72025 L .41805 .71801 L p F P
0 g
s
.65 .758 .928 r
.55208 .72026 m .56061 .71784 L .56285 .72008 L p F P
0 g
s
.65 .758 .928 r
.56061 .71784 m .55208 .72026 L .54982 .71802 L p F P
0 g
s
.65 .757 .928 r
.29968 .71998 m .30781 .71757 L .31042 .71981 L p F P
0 g
s
.65 .757 .928 r
.30781 .71757 m .29968 .71998 L .29704 .71774 L p F P
0 g
s
.651 .758 .928 r
.69444 .72003 m .7032 .7176 L .70524 .71984 L p F P
0 g
s
.651 .758 .928 r
.7032 .7176 m .69444 .72003 L .69239 .71779 L p F P
0 g
s
.65 .758 .928 r
.43126 .72007 m .4396 .71764 L .44203 .71988 L p F P
0 g
s
.65 .758 .928 r
.4396 .71764 m .43126 .72007 L .42882 .71782 L p F P
0 g
s
.65 .758 .928 r
.56285 .72008 m .57141 .71765 L .57363 .71989 L p F P
0 g
s
.65 .758 .928 r
.57141 .71765 m .56285 .72008 L .56061 .71784 L p F P
0 g
s
.65 .757 .928 r
.31042 .71981 m .31857 .71739 L .32117 .71963 L p F P
0 g
s
.65 .757 .928 r
.31857 .71739 m .31042 .71981 L .30781 .71757 L p F P
0 g
s
.651 .758 .928 r
.70524 .71984 m .71402 .71741 L .71604 .71965 L p F P
0 g
s
.651 .758 .928 r
.71402 .71741 m .70524 .71984 L .7032 .7176 L p F P
0 g
s
.65 .758 .928 r
.44203 .71988 m .45039 .71746 L .45279 .7197 L p F P
0 g
s
.65 .758 .928 r
.45039 .71746 m .44203 .71988 L .4396 .71764 L p F P
0 g
s
.65 .758 .928 r
.57363 .71989 m .5822 .71746 L .58442 .7197 L p F P
0 g
s
.65 .758 .928 r
.5822 .71746 m .57363 .71989 L .57141 .71765 L p F P
0 g
s
.65 .757 .928 r
.32117 .71963 m .32934 .71721 L .33193 .71946 L p F P
0 g
s
.65 .757 .928 r
.32934 .71721 m .32117 .71963 L .31857 .71739 L p F P
0 g
s
.651 .758 .928 r
.71604 .71965 m .72484 .71721 L .72684 .71945 L p F P
0 g
s
.651 .758 .928 r
.72484 .71721 m .71604 .71965 L .71402 .71741 L p F P
0 g
s
.65 .758 .928 r
.45279 .7197 m .46117 .71727 L .46356 .71951 L p F P
0 g
s
.65 .758 .928 r
.46117 .71727 m .45279 .7197 L .45039 .71746 L p F P
0 g
s
.65 .758 .928 r
.58442 .7197 m .59301 .71727 L .5952 .71951 L p F P
0 g
s
.65 .758 .928 r
.59301 .71727 m .58442 .7197 L .5822 .71746 L p F P
0 g
s
.651 .758 .928 r
.72684 .71945 m .73566 .71701 L .73764 .71925 L p F P
0 g
s
.651 .758 .928 r
.73566 .71701 m .72684 .71945 L .72484 .71721 L p F P
0 g
s
.65 .757 .928 r
.33193 .71946 m .34011 .71703 L .34268 .71928 L p F P
0 g
s
.65 .757 .928 r
.34011 .71703 m .33193 .71946 L .32934 .71721 L p F P
0 g
s
.65 .758 .928 r
.5952 .71951 m .60381 .71708 L .60599 .71932 L p F P
0 g
s
.65 .758 .928 r
.60381 .71708 m .5952 .71951 L .59301 .71727 L p F P
0 g
s
.65 .758 .928 r
.46356 .71951 m .47196 .71709 L .47434 .71933 L p F P
0 g
s
.65 .758 .928 r
.47196 .71709 m .46356 .71951 L .46117 .71727 L p F P
0 g
s
.651 .758 .928 r
.73764 .71925 m .74648 .71682 L .74845 .71906 L p F P
0 g
s
.651 .758 .928 r
.74648 .71682 m .73764 .71925 L .73566 .71701 L p F P
0 g
s
.65 .757 .928 r
.34268 .71928 m .35088 .71685 L .35344 .7191 L p F P
0 g
s
.65 .757 .928 r
.35088 .71685 m .34268 .71928 L .34011 .71703 L p F P
0 g
s
.65 .758 .928 r
.60599 .71932 m .61462 .71689 L .61678 .71913 L p F P
0 g
s
.65 .758 .928 r
.61462 .71689 m .60599 .71932 L .60381 .71708 L p F P
0 g
s
.65 .758 .928 r
.47434 .71933 m .48275 .7169 L .48511 .71914 L p F P
0 g
s
.65 .758 .928 r
.48275 .7169 m .47434 .71933 L .47196 .71709 L p F P
0 g
s
.651 .758 .928 r
.74845 .71906 m .7573 .71662 L .75926 .71886 L p F P
0 g
s
.651 .758 .928 r
.7573 .71662 m .74845 .71906 L .74648 .71682 L p F P
0 g
s
0 0 .345 r
.52587 .36998 m .52582 .37009 L .52582 .36641 L p F P
0 g
s
0 0 .345 r
.52582 .36641 m .52588 .3663 L .52587 .36998 L p F P
0 g
s
.762 .5 .538 r
.52565 .37006 m .52582 .37009 L .52582 .36641 L p F P
0 g
s
.762 .5 .538 r
.52582 .36641 m .52564 .36638 L .52565 .37006 L p F P
0 g
s
.65 .758 .928 r
.35344 .7191 m .36166 .71667 L .3642 .71892 L p F P
0 g
s
.65 .757 .928 r
.36166 .71667 m .35344 .7191 L .35088 .71685 L p F P
0 g
s
0 0 .348 r
.5257 .36626 m .52564 .36638 L .52565 .37006 L p F P
0 g
s
.65 .758 .928 r
.61678 .71913 m .62543 .7167 L .62758 .71894 L p F P
0 g
s
.65 .758 .928 r
.62543 .7167 m .61678 .71913 L .61462 .71689 L p F P
0 g
s
.65 .758 .928 r
.48511 .71914 m .49354 .71671 L .49589 .71896 L p F P
0 g
s
.65 .758 .928 r
.49354 .71671 m .48511 .71914 L .48275 .7169 L p F P
0 g
s
.762 .501 .539 r
.5257 .36626 m .52588 .3663 L .52587 .36998 L p F P
0 g
s
.762 .501 .539 r
.52587 .36998 m .5257 .36995 L .5257 .36626 L p F P
0 g
s
0 0 .348 r
.52565 .37006 m .5257 .36995 L .5257 .36626 L p F P
0 g
s
.651 .758 .928 r
.75926 .71886 m .76813 .71642 L .77007 .71866 L p F P
0 g
s
.651 .758 .928 r
.76813 .71642 m .75926 .71886 L .7573 .71662 L p F P
0 g
s
.65 .758 .928 r
.3642 .71892 m .37244 .71649 L .37496 .71874 L p F P
0 g
s
.65 .758 .928 r
.37244 .71649 m .3642 .71892 L .36166 .71667 L p F P
0 g
s
.65 .758 .928 r
.63624 .71651 m .62758 .71894 L .62543 .7167 L p F P
0 g
s
.65 .758 .928 r
.62758 .71894 m .63624 .71651 L .63837 .71875 L p F P
0 g
s
.65 .758 .928 r
.49589 .71896 m .50434 .71653 L .50667 .71877 L p F P
0 g
s
.65 .758 .928 r
.50434 .71653 m .49589 .71896 L .49354 .71671 L p F P
0 g
s
.651 .758 .928 r
.77007 .71866 m .77896 .71621 L .78088 .71845 L p F P
0 g
s
.651 .758 .928 r
.77896 .71621 m .77007 .71866 L .76813 .71642 L p F P
0 g
s
.65 .758 .928 r
.37496 .71874 m .38322 .71631 L .38573 .71856 L p F P
0 g
s
.65 .758 .928 r
.38322 .71631 m .37496 .71874 L .37244 .71649 L p F P
0 g
s
.65 .758 .928 r
.63837 .71875 m .64705 .71632 L .64917 .71856 L p F P
0 g
s
.65 .758 .928 r
.64705 .71632 m .63837 .71875 L .63624 .71651 L p F P
0 g
s
.65 .758 .928 r
.50667 .71877 m .51514 .71634 L .51745 .71859 L p F P
0 g
s
.65 .758 .928 r
.51514 .71634 m .50667 .71877 L .50434 .71653 L p F P
0 g
s
.651 .758 .928 r
.78088 .71845 m .78979 .71601 L .7917 .71825 L p F P
0 g
s
.651 .758 .928 r
.78979 .71601 m .78088 .71845 L .77896 .71621 L p F P
0 g
s
.65 .758 .928 r
.38573 .71856 m .39401 .71613 L .3965 .71837 L p F P
0 g
s
.65 .758 .928 r
.39401 .71613 m .38573 .71856 L .38322 .71631 L p F P
0 g
s
.65 .758 .928 r
.64917 .71856 m .65787 .71613 L .65997 .71837 L p F P
0 g
s
.65 .758 .928 r
.65787 .71613 m .64917 .71856 L .64705 .71632 L p F P
0 g
s
.65 .758 .928 r
.51745 .71859 m .52594 .71615 L .52824 .7184 L p F P
0 g
s
.65 .758 .928 r
.52594 .71615 m .51745 .71859 L .51514 .71634 L p F P
0 g
s
.651 .758 .928 r
.80063 .7158 m .7917 .71825 L .78979 .71601 L p F P
0 g
s
.65 .758 .928 r
.65997 .71837 m .66869 .71594 L .67078 .71818 L p F P
0 g
s
.65 .758 .928 r
.66869 .71594 m .65997 .71837 L .65787 .71613 L p F P
0 g
s
.65 .758 .928 r
.3965 .71837 m .40479 .71594 L .40727 .71819 L p F P
0 g
s
.65 .758 .928 r
.40479 .71594 m .3965 .71837 L .39401 .71613 L p F P
0 g
s
.65 .758 .928 r
.52824 .7184 m .53674 .71596 L .53902 .71821 L p F P
0 g
s
.65 .758 .928 r
.53674 .71596 m .52824 .7184 L .52594 .71615 L p F P
0 g
s
.651 .758 .928 r
.67078 .71818 m .67951 .71574 L .68158 .71799 L p F P
0 g
s
.651 .758 .928 r
.67951 .71574 m .67078 .71818 L .66869 .71594 L p F P
0 g
s
.65 .758 .928 r
.40727 .71819 m .41558 .71576 L .41805 .71801 L p F P
0 g
s
.65 .758 .928 r
.41558 .71576 m .40727 .71819 L .40479 .71594 L p F P
0 g
s
.65 .758 .928 r
.53902 .71821 m .54755 .71578 L .54982 .71802 L p F P
0 g
s
.65 .758 .928 r
.54755 .71578 m .53902 .71821 L .53674 .71596 L p F P
0 g
s
.65 .757 .928 r
.28628 .71792 m .2944 .71549 L .29704 .71774 L p F P
0 g
s
.65 .757 .928 r
.2944 .71549 m .28628 .71792 L .28363 .71567 L p F P
0 g
s
.651 .758 .928 r
.68158 .71799 m .69034 .71555 L .69239 .71779 L p F P
0 g
s
.651 .758 .928 r
.69034 .71555 m .68158 .71799 L .67951 .71574 L p F P
0 g
s
.65 .758 .928 r
.41805 .71801 m .42638 .71558 L .42882 .71782 L p F P
0 g
s
.65 .758 .928 r
.42638 .71558 m .41805 .71801 L .41558 .71576 L p F P
0 g
s
.65 .758 .928 r
.54982 .71802 m .55836 .71559 L .56061 .71784 L p F P
0 g
s
.65 .758 .928 r
.55836 .71559 m .54982 .71802 L .54755 .71578 L p F P
0 g
s
.65 .757 .928 r
.29704 .71774 m .30518 .71532 L .30781 .71757 L p F P
0 g
s
.65 .757 .928 r
.30518 .71532 m .29704 .71774 L .2944 .71549 L p F P
0 g
s
.651 .758 .928 r
.69239 .71779 m .70116 .71536 L .7032 .7176 L p F P
0 g
s
.651 .758 .928 r
.70116 .71536 m .69239 .71779 L .69034 .71555 L p F P
0 g
s
.65 .758 .928 r
.42882 .71782 m .43717 .71539 L .4396 .71764 L p F P
0 g
s
.65 .758 .928 r
.43717 .71539 m .42882 .71782 L .42638 .71558 L p F P
0 g
s
.65 .758 .928 r
.56061 .71784 m .56917 .7154 L .57141 .71765 L p F P
0 g
s
.65 .758 .928 r
.56917 .7154 m .56061 .71784 L .55836 .71559 L p F P
0 g
s
.65 .757 .928 r
.30781 .71757 m .31596 .71514 L .31857 .71739 L p F P
0 g
s
.65 .757 .928 r
.31596 .71514 m .30781 .71757 L .30518 .71532 L p F P
0 g
s
.651 .758 .928 r
.7032 .7176 m .71199 .71516 L .71402 .71741 L p F P
0 g
s
.651 .758 .928 r
.71199 .71516 m .7032 .7176 L .70116 .71536 L p F P
0 g
s
.65 .758 .928 r
.4396 .71764 m .44797 .71521 L .45039 .71746 L p F P
0 g
s
.65 .758 .928 r
.44797 .71521 m .4396 .71764 L .43717 .71539 L p F P
0 g
s
.65 .758 .928 r
.57141 .71765 m .57998 .71521 L .5822 .71746 L p F P
0 g
s
.65 .758 .928 r
.57998 .71521 m .57141 .71765 L .56917 .7154 L p F P
0 g
s
.65 .757 .928 r
.31857 .71739 m .32675 .71496 L .32934 .71721 L p F P
0 g
s
.65 .757 .928 r
.32675 .71496 m .31857 .71739 L .31596 .71514 L p F P
0 g
s
.651 .758 .928 r
.71402 .71741 m .72283 .71496 L .72484 .71721 L p F P
0 g
s
.651 .758 .928 r
.72283 .71496 m .71402 .71741 L .71199 .71516 L p F P
0 g
s
.65 .758 .928 r
.45039 .71746 m .45877 .71502 L .46117 .71727 L p F P
0 g
s
.65 .758 .928 r
.45877 .71502 m .45039 .71746 L .44797 .71521 L p F P
0 g
s
.65 .758 .928 r
.5822 .71746 m .5908 .71502 L .59301 .71727 L p F P
0 g
s
.65 .758 .928 r
.5908 .71502 m .5822 .71746 L .57998 .71521 L p F P
0 g
s
0 0 .345 r
.52587 .37367 m .52582 .37378 L .52582 .37009 L p F P
0 g
s
0 0 .345 r
.52582 .37009 m .52587 .36998 L .52587 .37367 L p F P
0 g
s
.762 .5 .538 r
.52566 .37375 m .52582 .37378 L .52582 .37009 L p F P
0 g
s
.762 .5 .538 r
.52582 .37009 m .52565 .37006 L .52566 .37375 L p F P
0 g
s
.651 .758 .928 r
.72484 .71721 m .73366 .71477 L .73566 .71701 L p F P
0 g
s
.651 .758 .928 r
.73366 .71477 m .72484 .71721 L .72283 .71496 L p F P
0 g
s
.65 .757 .928 r
.32934 .71721 m .33753 .71478 L .34011 .71703 L p F P
0 g
s
.65 .757 .928 r
.33753 .71478 m .32934 .71721 L .32675 .71496 L p F P
0 g
s
0 0 .348 r
.5257 .36995 m .52565 .37006 L .52566 .37375 L p F P
0 g
s
.65 .758 .928 r
.59301 .71727 m .60162 .71483 L .60381 .71708 L p F P
0 g
s
.65 .758 .928 r
.60162 .71483 m .59301 .71727 L .5908 .71502 L p F P
0 g
s
.65 .758 .928 r
.46117 .71727 m .46957 .71483 L .47196 .71709 L p F P
0 g
s
.65 .758 .928 r
.46957 .71483 m .46117 .71727 L .45877 .71502 L p F P
0 g
s
.762 .501 .539 r
.5257 .36995 m .52587 .36998 L .52587 .37367 L p F P
0 g
s
.762 .501 .539 r
.52587 .37367 m .5257 .37364 L .5257 .36995 L p F P
0 g
s
0 0 .348 r
.52566 .37375 m .5257 .37364 L .5257 .36995 L p F P
0 g
s
.651 .758 .928 r
.73566 .71701 m .7445 .71457 L .74648 .71682 L p F P
0 g
s
.651 .758 .928 r
.7445 .71457 m .73566 .71701 L .73366 .71477 L p F P
0 g
s
.65 .757 .928 r
.34011 .71703 m .34832 .7146 L .35088 .71685 L p F P
0 g
s
.65 .757 .928 r
.34832 .7146 m .34011 .71703 L .33753 .71478 L p F P
0 g
s
.65 .758 .928 r
.60381 .71708 m .61244 .71464 L .61462 .71689 L p F P
0 g
s
.65 .758 .928 r
.61244 .71464 m .60381 .71708 L .60162 .71483 L p F P
0 g
s
.65 .758 .928 r
.47196 .71709 m .48038 .71465 L .48275 .7169 L p F P
0 g
s
.65 .758 .928 r
.48038 .71465 m .47196 .71709 L .46957 .71483 L p F P
0 g
s
.651 .758 .928 r
.74648 .71682 m .75534 .71437 L .7573 .71662 L p F P
0 g
s
.651 .758 .928 r
.75534 .71437 m .74648 .71682 L .7445 .71457 L p F P
0 g
s
.65 .757 .928 r
.35088 .71685 m .35911 .71442 L .36166 .71667 L p F P
0 g
s
.65 .757 .928 r
.35911 .71442 m .35088 .71685 L .34832 .7146 L p F P
0 g
s
.65 .758 .928 r
.61462 .71689 m .62327 .71445 L .62543 .7167 L p F P
0 g
s
.65 .758 .928 r
.62327 .71445 m .61462 .71689 L .61244 .71464 L p F P
0 g
s
.65 .758 .928 r
.48275 .7169 m .49119 .71446 L .49354 .71671 L p F P
0 g
s
.65 .758 .928 r
.49119 .71446 m .48275 .7169 L .48038 .71465 L p F P
0 g
s
.651 .758 .928 r
.7573 .71662 m .76618 .71417 L .76813 .71642 L p F P
0 g
s
.651 .758 .928 r
.76618 .71417 m .7573 .71662 L .75534 .71437 L p F P
0 g
s
.65 .758 .928 r
.36166 .71667 m .36991 .71424 L .37244 .71649 L p F P
0 g
s
.65 .758 .928 r
.36991 .71424 m .36166 .71667 L .35911 .71442 L p F P
0 g
s
.65 .758 .928 r
.62543 .7167 m .6341 .71426 L .63624 .71651 L p F P
0 g
s
.65 .758 .928 r
.6341 .71426 m .62543 .7167 L .62327 .71445 L p F P
0 g
s
.65 .758 .928 r
.49354 .71671 m .502 .71427 L .50434 .71653 L p F P
0 g
s
.65 .758 .928 r
.502 .71427 m .49354 .71671 L .49119 .71446 L p F P
0 g
s
.651 .758 .928 r
.76813 .71642 m .77703 .71397 L .77896 .71621 L p F P
0 g
s
.651 .758 .928 r
.77703 .71397 m .76813 .71642 L .76618 .71417 L p F P
0 g
s
.65 .758 .928 r
.37244 .71649 m .38071 .71406 L .38322 .71631 L p F P
0 g
s
.65 .758 .928 r
.38071 .71406 m .37244 .71649 L .36991 .71424 L p F P
0 g
s
.65 .758 .928 r
.64493 .71407 m .63624 .71651 L .6341 .71426 L p F P
0 g
s
.65 .758 .928 r
.63624 .71651 m .64493 .71407 L .64705 .71632 L p F P
0 g
s
.65 .758 .928 r
.50434 .71653 m .51282 .71409 L .51514 .71634 L p F P
0 g
s
.65 .758 .928 r
.51282 .71409 m .50434 .71653 L .502 .71427 L p F P
0 g
s
.651 .758 .928 r
.77896 .71621 m .78788 .71376 L .78979 .71601 L p F P
0 g
s
.651 .758 .928 r
.78788 .71376 m .77896 .71621 L .77703 .71397 L p F P
0 g
s
.65 .758 .928 r
.38322 .71631 m .39151 .71387 L .39401 .71613 L p F P
0 g
s
.65 .758 .928 r
.39151 .71387 m .38322 .71631 L .38071 .71406 L p F P
0 g
s
.65 .758 .928 r
.64705 .71632 m .65576 .71388 L .65787 .71613 L p F P
0 g
s
.65 .758 .928 r
.65576 .71388 m .64705 .71632 L .64493 .71407 L p F P
0 g
s
.65 .758 .928 r
.51514 .71634 m .52363 .7139 L .52594 .71615 L p F P
0 g
s
.65 .758 .928 r
.52363 .7139 m .51514 .71634 L .51282 .71409 L p F P
0 g
s
.651 .758 .928 r
.78979 .71601 m .79873 .71356 L .80063 .7158 L p F P
0 g
s
.651 .758 .928 r
.79873 .71356 m .78979 .71601 L .78788 .71376 L p F P
0 g
s
.651 .758 .928 r
.66659 .71368 m .65787 .71613 L .65576 .71388 L p F P
0 g
s
.65 .758 .928 r
.65787 .71613 m .66659 .71368 L .66869 .71594 L p F P
0 g
s
.65 .758 .928 r
.40231 .71369 m .39401 .71613 L .39151 .71387 L p F P
0 g
s
.65 .758 .928 r
.39401 .71613 m .40231 .71369 L .40479 .71594 L p F P
0 g
s
.65 .758 .928 r
.52594 .71615 m .53445 .71371 L .53674 .71596 L p F P
0 g
s
.65 .758 .928 r
.53445 .71371 m .52594 .71615 L .52363 .7139 L p F P
0 g
s
.651 .759 .928 r
.80958 .71335 m .80063 .7158 L .79873 .71356 L p F P
0 g
s
.651 .758 .928 r
.66869 .71594 m .67743 .71349 L .67951 .71574 L p F P
0 g
s
.651 .758 .928 r
.67743 .71349 m .66869 .71594 L .66659 .71368 L p F P
0 g
s
.65 .758 .928 r
.40479 .71594 m .41311 .71351 L .41558 .71576 L p F P
0 g
s
.65 .758 .928 r
.41311 .71351 m .40479 .71594 L .40231 .71369 L p F P
0 g
s
.65 .758 .928 r
.53674 .71596 m .54527 .71352 L .54755 .71578 L p F P
0 g
s
.65 .758 .928 r
.54527 .71352 m .53674 .71596 L .53445 .71371 L p F P
0 g
s
.65 .757 .928 r
.28363 .71567 m .29175 .71324 L .2944 .71549 L p F P
0 g
s
.65 .757 .928 r
.29175 .71324 m .28363 .71567 L .28096 .71341 L p F P
0 g
s
.651 .758 .928 r
.67951 .71574 m .68827 .7133 L .69034 .71555 L p F P
0 g
s
.651 .758 .928 r
.68827 .7133 m .67951 .71574 L .67743 .71349 L p F P
0 g
s
.65 .758 .928 r
.41558 .71576 m .42392 .71332 L .42638 .71558 L p F P
0 g
s
.65 .758 .928 r
.42392 .71332 m .41558 .71576 L .41311 .71351 L p F P
0 g
s
.65 .758 .928 r
.54755 .71578 m .5561 .71333 L .55836 .71559 L p F P
0 g
s
.65 .758 .928 r
.5561 .71333 m .54755 .71578 L .54527 .71352 L p F P
0 g
s
.65 .757 .928 r
.2944 .71549 m .30255 .71306 L .30518 .71532 L p F P
0 g
s
.65 .757 .928 r
.30255 .71306 m .2944 .71549 L .29175 .71324 L p F P
0 g
s
.651 .758 .928 r
.69034 .71555 m .69912 .7131 L .70116 .71536 L p F P
0 g
s
.651 .758 .928 r
.69912 .7131 m .69034 .71555 L .68827 .7133 L p F P
0 g
s
.65 .758 .928 r
.42638 .71558 m .43473 .71314 L .43717 .71539 L p F P
0 g
s
.65 .758 .928 r
.43473 .71314 m .42638 .71558 L .42392 .71332 L p F P
0 g
s
.65 .758 .928 r
.55836 .71559 m .56693 .71314 L .56917 .7154 L p F P
0 g
s
.65 .758 .928 r
.56693 .71314 m .55836 .71559 L .5561 .71333 L p F P
0 g
s
.65 .757 .928 r
.30518 .71532 m .31334 .71288 L .31596 .71514 L p F P
0 g
s
.65 .757 .928 r
.31334 .71288 m .30518 .71532 L .30255 .71306 L p F P
0 g
s
0 0 .345 r
.52586 .37738 m .52581 .37748 L .52582 .37378 L p F P
0 g
s
0 0 .345 r
.52582 .37378 m .52587 .37367 L .52586 .37738 L p F P
0 g
s
.762 .5 .538 r
.52566 .37745 m .52581 .37748 L .52582 .37378 L p F P
0 g
s
.762 .5 .538 r
.52582 .37378 m .52566 .37375 L .52566 .37745 L p F P
0 g
s
.651 .758 .928 r
.70116 .71536 m .70996 .71291 L .71199 .71516 L p F P
0 g
s
.651 .758 .928 r
.70996 .71291 m .70116 .71536 L .69912 .7131 L p F P
0 g
s
0 0 .348 r
.5257 .37364 m .52566 .37375 L .52566 .37745 L p F P
0 g
s
.65 .758 .928 r
.43717 .71539 m .44555 .71295 L .44797 .71521 L p F P
0 g
s
.65 .758 .928 r
.44555 .71295 m .43717 .71539 L .43473 .71314 L p F P
0 g
s
.65 .758 .928 r
.56917 .7154 m .57776 .71296 L .57998 .71521 L p F P
0 g
s
.65 .758 .928 r
.57776 .71296 m .56917 .7154 L .56693 .71314 L p F P
0 g
s
.762 .501 .539 r
.5257 .37364 m .52587 .37367 L .52586 .37738 L p F P
0 g
s
.762 .501 .539 r
.52586 .37738 m .52571 .37735 L .5257 .37364 L p F P
0 g
s
0 0 .348 r
.52566 .37745 m .52571 .37735 L .5257 .37364 L p F P
0 g
s
.65 .757 .928 r
.31596 .71514 m .32414 .71271 L .32675 .71496 L p F P
0 g
s
.65 .757 .928 r
.32414 .71271 m .31596 .71514 L .31334 .71288 L p F P
0 g
s
.651 .758 .928 r
.71199 .71516 m .72081 .71271 L .72283 .71496 L p F P
0 g
s
.651 .758 .928 r
.72081 .71271 m .71199 .71516 L .70996 .71291 L p F P
0 g
s
.65 .758 .928 r
.44797 .71521 m .45636 .71276 L .45877 .71502 L p F P
0 g
s
.65 .758 .928 r
.45636 .71276 m .44797 .71521 L .44555 .71295 L p F P
0 g
s
.65 .758 .928 r
.57998 .71521 m .58859 .71277 L .5908 .71502 L p F P
0 g
s
.65 .758 .928 r
.58859 .71277 m .57998 .71521 L .57776 .71296 L p F P
0 g
s
.65 .757 .928 r
.32675 .71496 m .33495 .71253 L .33753 .71478 L p F P
0 g
s
.65 .757 .928 r
.33495 .71253 m .32675 .71496 L .32414 .71271 L p F P
0 g
s
.651 .758 .928 r
.72283 .71496 m .73166 .71251 L .73366 .71477 L p F P
0 g
s
.651 .758 .928 r
.73166 .71251 m .72283 .71496 L .72081 .71271 L p F P
0 g
s
.65 .758 .928 r
.45877 .71502 m .46718 .71258 L .46957 .71483 L p F P
0 g
s
.65 .758 .928 r
.46718 .71258 m .45877 .71502 L .45636 .71276 L p F P
0 g
s
.65 .758 .928 r
.5908 .71502 m .59943 .71258 L .60162 .71483 L p F P
0 g
s
.65 .758 .928 r
.59943 .71258 m .5908 .71502 L .58859 .71277 L p F P
0 g
s
.651 .758 .928 r
.73366 .71477 m .74252 .71232 L .7445 .71457 L p F P
0 g
s
.651 .758 .928 r
.74252 .71232 m .73366 .71477 L .73166 .71251 L p F P
0 g
s
.65 .757 .928 r
.33753 .71478 m .34575 .71235 L .34832 .7146 L p F P
0 g
s
.65 .757 .928 r
.34575 .71235 m .33753 .71478 L .33495 .71253 L p F P
0 g
s
.65 .758 .928 r
.60162 .71483 m .61026 .71238 L .61244 .71464 L p F P
0 g
s
.65 .758 .928 r
.61026 .71238 m .60162 .71483 L .59943 .71258 L p F P
0 g
s
.65 .758 .928 r
.46957 .71483 m .47801 .71239 L .48038 .71465 L p F P
0 g
s
.65 .758 .928 r
.47801 .71239 m .46957 .71483 L .46718 .71258 L p F P
0 g
s
.651 .758 .928 r
.7445 .71457 m .75337 .71212 L .75534 .71437 L p F P
0 g
s
.651 .758 .928 r
.75337 .71212 m .7445 .71457 L .74252 .71232 L p F P
0 g
s
.65 .757 .928 r
.34832 .7146 m .35656 .71216 L .35911 .71442 L p F P
0 g
s
.65 .757 .928 r
.35656 .71216 m .34832 .7146 L .34575 .71235 L p F P
0 g
s
.65 .758 .928 r
.61244 .71464 m .6211 .71219 L .62327 .71445 L p F P
0 g
s
.65 .758 .928 r
.6211 .71219 m .61244 .71464 L .61026 .71238 L p F P
0 g
s
.65 .758 .928 r
.48038 .71465 m .48883 .7122 L .49119 .71446 L p F P
0 g
s
.65 .758 .928 r
.48883 .7122 m .48038 .71465 L .47801 .71239 L p F P
0 g
s
.651 .758 .928 r
.75534 .71437 m .76423 .71192 L .76618 .71417 L p F P
0 g
s
.651 .758 .928 r
.76423 .71192 m .75534 .71437 L .75337 .71212 L p F P
0 g
s
.65 .758 .928 r
.35911 .71442 m .36737 .71198 L .36991 .71424 L p F P
0 g
s
.65 .757 .928 r
.36737 .71198 m .35911 .71442 L .35656 .71216 L p F P
0 g
s
.65 .758 .928 r
.62327 .71445 m .63195 .712 L .6341 .71426 L p F P
0 g
s
.65 .758 .928 r
.63195 .712 m .62327 .71445 L .6211 .71219 L p F P
0 g
s
.65 .758 .928 r
.49119 .71446 m .49966 .71202 L .502 .71427 L p F P
0 g
s
.65 .758 .928 r
.49966 .71202 m .49119 .71446 L .48883 .7122 L p F P
0 g
s
.651 .758 .928 r
.76618 .71417 m .77509 .71171 L .77703 .71397 L p F P
0 g
s
.651 .758 .928 r
.77509 .71171 m .76618 .71417 L .76423 .71192 L p F P
0 g
s
.65 .758 .928 r
.36991 .71424 m .37818 .7118 L .38071 .71406 L p F P
0 g
s
.65 .758 .928 r
.37818 .7118 m .36991 .71424 L .36737 .71198 L p F P
0 g
s
.65 .758 .928 r
.6341 .71426 m .64279 .71181 L .64493 .71407 L p F P
0 g
s
.65 .758 .928 r
.64279 .71181 m .6341 .71426 L .63195 .712 L p F P
0 g
s
.65 .758 .928 r
.502 .71427 m .51049 .71183 L .51282 .71409 L p F P
0 g
s
.65 .758 .928 r
.51049 .71183 m .502 .71427 L .49966 .71202 L p F P
0 g
s
.651 .758 .928 r
.77703 .71397 m .78596 .71151 L .78788 .71376 L p F P
0 g
s
.651 .758 .928 r
.78596 .71151 m .77703 .71397 L .77509 .71171 L p F P
0 g
s
.65 .758 .928 r
.38071 .71406 m .389 .71161 L .39151 .71387 L p F P
0 g
s
.65 .758 .928 r
.389 .71161 m .38071 .71406 L .37818 .7118 L p F P
0 g
s
.65 .758 .928 r
.65364 .71162 m .64493 .71407 L .64279 .71181 L p F P
0 g
s
.65 .758 .928 r
.64493 .71407 m .65364 .71162 L .65576 .71388 L p F P
0 g
s
.65 .758 .928 r
.51282 .71409 m .52132 .71164 L .52363 .7139 L p F P
0 g
s
.65 .758 .928 r
.52132 .71164 m .51282 .71409 L .51049 .71183 L p F P
0 g
s
.651 .758 .928 r
.78788 .71376 m .79682 .71131 L .79873 .71356 L p F P
0 g
s
.651 .758 .928 r
.79682 .71131 m .78788 .71376 L .78596 .71151 L p F P
0 g
s
.65 .758 .928 r
.39151 .71387 m .39982 .71143 L .40231 .71369 L p F P
0 g
s
.65 .758 .928 r
.39982 .71143 m .39151 .71387 L .389 .71161 L p F P
0 g
s
.651 .758 .928 r
.65576 .71388 m .66449 .71143 L .66659 .71368 L p F P
0 g
s
.651 .758 .928 r
.66449 .71143 m .65576 .71388 L .65364 .71162 L p F P
0 g
s
.65 .758 .928 r
.52363 .7139 m .53216 .71145 L .53445 .71371 L p F P
0 g
s
.65 .758 .928 r
.53216 .71145 m .52363 .7139 L .52132 .71164 L p F P
0 g
s
.651 .759 .928 r
.79873 .71356 m .80769 .7111 L .80958 .71335 L p F P
0 g
s
.651 .758 .928 r
.80769 .7111 m .79873 .71356 L .79682 .71131 L p F P
0 g
s
.651 .758 .928 r
.66659 .71368 m .67535 .71123 L .67743 .71349 L p F P
0 g
s
.651 .758 .928 r
.67535 .71123 m .66659 .71368 L .66449 .71143 L p F P
0 g
s
.65 .758 .928 r
.41064 .71125 m .40231 .71369 L .39982 .71143 L p F P
0 g
s
.65 .758 .928 r
.40231 .71369 m .41064 .71125 L .41311 .71351 L p F P
0 g
s
.65 .758 .928 r
.53445 .71371 m .54299 .71126 L .54527 .71352 L p F P
0 g
s
.65 .758 .928 r
.54299 .71126 m .53445 .71371 L .53216 .71145 L p F P
0 g
s
.651 .759 .928 r
.81856 .71089 m .80958 .71335 L .80769 .7111 L p F P
0 g
s
.65 .757 .928 r
.28096 .71341 m .2891 .71098 L .29175 .71324 L p F P
0 g
s
.65 .757 .928 r
.2891 .71098 m .28096 .71341 L .27829 .71115 L p F P
0 g
s
0 0 .345 r
.52586 .38109 m .52581 .38118 L .52581 .37748 L p F P
0 g
s
0 0 .345 r
.52581 .37748 m .52586 .37738 L .52586 .38109 L p F P
0 g
s
.762 .5 .538 r
.52567 .38115 m .52581 .38118 L .52581 .37748 L p F P
0 g
s
.762 .5 .538 r
.52581 .37748 m .52566 .37745 L .52567 .38115 L p F P
0 g
s
.651 .758 .928 r
.67743 .71349 m .6862 .71104 L .68827 .7133 L p F P
0 g
s
.651 .758 .928 r
.6862 .71104 m .67743 .71349 L .67535 .71123 L p F P
0 g
s
0 0 .348 r
.52571 .37735 m .52566 .37745 L .52567 .38115 L p F P
0 g
s
.65 .758 .928 r
.41311 .71351 m .42146 .71106 L .42392 .71332 L p F P
0 g
s
.65 .758 .928 r
.42146 .71106 m .41311 .71351 L .41064 .71125 L p F P
0 g
s
.65 .758 .928 r
.54527 .71352 m .55383 .71107 L .5561 .71333 L p F P
0 g
s
.65 .758 .928 r
.55383 .71107 m .54527 .71352 L .54299 .71126 L p F P
0 g
s
.762 .501 .539 r
.52571 .37735 m .52586 .37738 L .52586 .38109 L p F P
0 g
s
.762 .501 .539 r
.52586 .38109 m .52571 .38106 L .52571 .37735 L p F P
0 g
s
0 0 .348 r
.52567 .38115 m .52571 .38106 L .52571 .37735 L p F P
0 g
s
.65 .757 .928 r
.29175 .71324 m .29991 .7108 L .30255 .71306 L p F P
0 g
s
.65 .757 .928 r
.29991 .7108 m .29175 .71324 L .2891 .71098 L p F P
0 g
s
.651 .758 .928 r
.68827 .7133 m .69706 .71084 L .69912 .7131 L p F P
0 g
s
.651 .758 .928 r
.69706 .71084 m .68827 .7133 L .6862 .71104 L p F P
0 g
s
.65 .758 .928 r
.42392 .71332 m .43229 .71087 L .43473 .71314 L p F P
0 g
s
.65 .758 .928 r
.43229 .71087 m .42392 .71332 L .42146 .71106 L p F P
0 g
s
.65 .758 .928 r
.5561 .71333 m .56468 .71088 L .56693 .71314 L p F P
0 g
s
.65 .758 .928 r
.56468 .71088 m .5561 .71333 L .55383 .71107 L p F P
0 g
s
.65 .757 .928 r
.30255 .71306 m .31072 .71062 L .31334 .71288 L p F P
0 g
s
.65 .757 .928 r
.31072 .71062 m .30255 .71306 L .29991 .7108 L p F P
0 g
s
.651 .758 .928 r
.69912 .7131 m .70793 .71065 L .70996 .71291 L p F P
0 g
s
.651 .758 .928 r
.70793 .71065 m .69912 .7131 L .69706 .71084 L p F P
0 g
s
.65 .758 .928 r
.43473 .71314 m .44312 .71069 L .44555 .71295 L p F P
0 g
s
.65 .758 .928 r
.44312 .71069 m .43473 .71314 L .43229 .71087 L p F P
0 g
s
.65 .758 .928 r
.56693 .71314 m .57552 .71069 L .57776 .71296 L p F P
0 g
s
.65 .758 .928 r
.57552 .71069 m .56693 .71314 L .56468 .71088 L p F P
0 g
s
.65 .757 .928 r
.31334 .71288 m .32153 .71044 L .32414 .71271 L p F P
0 g
s
.65 .757 .928 r
.32153 .71044 m .31334 .71288 L .31072 .71062 L p F P
0 g
s
.651 .758 .928 r
.70996 .71291 m .71879 .71045 L .72081 .71271 L p F P
0 g
s
.651 .758 .928 r
.71879 .71045 m .70996 .71291 L .70793 .71065 L p F P
0 g
s
.65 .758 .928 r
.44555 .71295 m .45395 .7105 L .45636 .71276 L p F P
0 g
s
.65 .758 .928 r
.45395 .7105 m .44555 .71295 L .44312 .71069 L p F P
0 g
s
.65 .758 .928 r
.57776 .71296 m .58637 .7105 L .58859 .71277 L p F P
0 g
s
.65 .758 .928 r
.58637 .7105 m .57776 .71296 L .57552 .71069 L p F P
0 g
s
.65 .757 .928 r
.32414 .71271 m .33235 .71026 L .33495 .71253 L p F P
0 g
s
.65 .757 .928 r
.33235 .71026 m .32414 .71271 L .32153 .71044 L p F P
0 g
s
.651 .758 .928 r
.72081 .71271 m .72966 .71025 L .73166 .71251 L p F P
0 g
s
.651 .758 .928 r
.72966 .71025 m .72081 .71271 L .71879 .71045 L p F P
0 g
s
.65 .758 .928 r
.45636 .71276 m .46479 .71031 L .46718 .71258 L p F P
0 g
s
.65 .758 .928 r
.46479 .71031 m .45636 .71276 L .45395 .7105 L p F P
0 g
s
.65 .758 .928 r
.58859 .71277 m .59722 .71031 L .59943 .71258 L p F P
0 g
s
.65 .758 .928 r
.59722 .71031 m .58859 .71277 L .58637 .7105 L p F P
0 g
s
.651 .758 .928 r
.73166 .71251 m .74053 .71006 L .74252 .71232 L p F P
0 g
s
.651 .758 .928 r
.74053 .71006 m .73166 .71251 L .72966 .71025 L p F P
0 g
s
.65 .757 .928 r
.33495 .71253 m .34317 .71008 L .34575 .71235 L p F P
0 g
s
.65 .757 .928 r
.34317 .71008 m .33495 .71253 L .33235 .71026 L p F P
0 g
s
.65 .758 .928 r
.59943 .71258 m .60808 .71012 L .61026 .71238 L p F P
0 g
s
.65 .758 .928 r
.60808 .71012 m .59943 .71258 L .59722 .71031 L p F P
0 g
s
.65 .758 .928 r
.46718 .71258 m .47562 .71013 L .47801 .71239 L p F P
0 g
s
.65 .758 .928 r
.47562 .71013 m .46718 .71258 L .46479 .71031 L p F P
0 g
s
.651 .758 .928 r
.74252 .71232 m .7514 .70986 L .75337 .71212 L p F P
0 g
s
.651 .758 .928 r
.7514 .70986 m .74252 .71232 L .74053 .71006 L p F P
0 g
s
.65 .757 .928 r
.34575 .71235 m .354 .7099 L .35656 .71216 L p F P
0 g
s
.65 .757 .928 r
.354 .7099 m .34575 .71235 L .34317 .71008 L p F P
0 g
s
.65 .758 .928 r
.61026 .71238 m .61893 .70993 L .6211 .71219 L p F P
0 g
s
.65 .758 .928 r
.61893 .70993 m .61026 .71238 L .60808 .71012 L p F P
0 g
s
.65 .758 .928 r
.47801 .71239 m .48646 .70994 L .48883 .7122 L p F P
0 g
s
.65 .758 .928 r
.48646 .70994 m .47801 .71239 L .47562 .71013 L p F P
0 g
s
.651 .758 .928 r
.75337 .71212 m .76227 .70966 L .76423 .71192 L p F P
0 g
s
.651 .758 .928 r
.76227 .70966 m .75337 .71212 L .7514 .70986 L p F P
0 g
s
.65 .757 .928 r
.35656 .71216 m .36482 .70972 L .36737 .71198 L p F P
0 g
s
.65 .757 .928 r
.36482 .70972 m .35656 .71216 L .354 .7099 L p F P
0 g
s
.65 .758 .928 r
.6211 .71219 m .62979 .70974 L .63195 .712 L p F P
0 g
s
.65 .758 .928 r
.62979 .70974 m .6211 .71219 L .61893 .70993 L p F P
0 g
s
.65 .758 .928 r
.48883 .7122 m .49731 .70975 L .49966 .71202 L p F P
0 g
s
.65 .758 .928 r
.49731 .70975 m .48883 .7122 L .48646 .70994 L p F P
0 g
s
.651 .758 .928 r
.76423 .71192 m .77315 .70945 L .77509 .71171 L p F P
0 g
s
.651 .758 .928 r
.77315 .70945 m .76423 .71192 L .76227 .70966 L p F P
0 g
s
.65 .758 .928 r
.36737 .71198 m .37565 .70953 L .37818 .7118 L p F P
0 g
s
.65 .757 .928 r
.37565 .70953 m .36737 .71198 L .36482 .70972 L p F P
0 g
s
.65 .758 .928 r
.63195 .712 m .64066 .70955 L .64279 .71181 L p F P
0 g
s
.65 .758 .928 r
.64066 .70955 m .63195 .712 L .62979 .70974 L p F P
0 g
s
.65 .758 .928 r
.49966 .71202 m .50815 .70956 L .51049 .71183 L p F P
0 g
s
.65 .758 .928 r
.50815 .70956 m .49966 .71202 L .49731 .70975 L p F P
0 g
s
.651 .758 .928 r
.77509 .71171 m .78403 .70925 L .78596 .71151 L p F P
0 g
s
.651 .758 .928 r
.78403 .70925 m .77509 .71171 L .77315 .70945 L p F P
0 g
s
.65 .758 .928 r
.37818 .7118 m .38648 .70935 L .389 .71161 L p F P
0 g
s
.65 .758 .928 r
.38648 .70935 m .37818 .7118 L .37565 .70953 L p F P
0 g
s
.65 .758 .928 r
.64279 .71181 m .65152 .70935 L .65364 .71162 L p F P
0 g
s
.65 .758 .928 r
.65152 .70935 m .64279 .71181 L .64066 .70955 L p F P
0 g
s
.65 .758 .928 r
.51049 .71183 m .519 .70937 L .52132 .71164 L p F P
0 g
s
.65 .758 .928 r
.519 .70937 m .51049 .71183 L .50815 .70956 L p F P
0 g
s
.651 .758 .928 r
.78596 .71151 m .79491 .70904 L .79682 .71131 L p F P
0 g
s
.651 .758 .928 r
.79491 .70904 m .78596 .71151 L .78403 .70925 L p F P
0 g
s
0 0 .346 r
.52585 .38481 m .52581 .3849 L .52581 .38118 L p F P
0 g
s
0 0 .346 r
.52581 .38118 m .52586 .38109 L .52585 .38481 L p F P
0 g
s
.762 .5 .538 r
.52567 .38487 m .52581 .3849 L .52581 .38118 L p F P
0 g
s
.762 .5 .538 r
.52581 .38118 m .52567 .38115 L .52567 .38487 L p F P
0 g
s
.65 .758 .928 r
.389 .71161 m .39732 .70916 L .39982 .71143 L p F P
0 g
s
.65 .758 .928 r
.39732 .70916 m .389 .71161 L .38648 .70935 L p F P
0 g
s
.651 .758 .928 r
.66239 .70916 m .65364 .71162 L .65152 .70935 L p F P
0 g
s
.651 .758 .928 r
.65364 .71162 m .66239 .70916 L .66449 .71143 L p F P
0 g
s
0 0 .348 r
.52571 .38106 m .52567 .38115 L .52567 .38487 L p F P
0 g
s
.65 .758 .928 r
.52132 .71164 m .52985 .70918 L .53216 .71145 L p F P
0 g
s
.65 .758 .928 r
.52985 .70918 m .52132 .71164 L .519 .70937 L p F P
0 g
s
.762 .501 .539 r
.52571 .38106 m .52586 .38109 L .52585 .38481 L p F P
0 g
s
.762 .501 .539 r
.52585 .38481 m .52571 .38478 L .52571 .38106 L p F P
0 g
s
0 0 .348 r
.52567 .38487 m .52571 .38478 L .52571 .38106 L p F P
0 g
s
.651 .758 .928 r
.79682 .71131 m .8058 .70884 L .80769 .7111 L p F P
0 g
s
.651 .758 .928 r
.8058 .70884 m .79682 .71131 L .79491 .70904 L p F P
0 g
s
.651 .758 .928 r
.66449 .71143 m .67326 .70897 L .67535 .71123 L p F P
0 g
s
.651 .758 .928 r
.67326 .70897 m .66449 .71143 L .66239 .70916 L p F P
0 g
s
.65 .758 .928 r
.39982 .71143 m .40815 .70898 L .41064 .71125 L p F P
0 g
s
.65 .758 .928 r
.40815 .70898 m .39982 .71143 L .39732 .70916 L p F P
0 g
s
.65 .758 .928 r
.53216 .71145 m .54071 .70899 L .54299 .71126 L p F P
0 g
s
.65 .758 .928 r
.54071 .70899 m .53216 .71145 L .52985 .70918 L p F P
0 g
s
.651 .759 .928 r
.80769 .7111 m .81669 .70863 L .81856 .71089 L p F P
0 g
s
.651 .759 .928 r
.81669 .70863 m .80769 .7111 L .8058 .70884 L p F P
0 g
s
.65 .757 .928 r
.27829 .71115 m .28643 .70871 L .2891 .71098 L p F P
0 g
s
.65 .757 .928 r
.28643 .70871 m .27829 .71115 L .27561 .70888 L p F P
0 g
s
.651 .758 .928 r
.68413 .70877 m .67535 .71123 L .67326 .70897 L p F P
0 g
s
.651 .758 .928 r
.67535 .71123 m .68413 .70877 L .6862 .71104 L p F P
0 g
s
.65 .758 .928 r
.41064 .71125 m .41899 .70879 L .42146 .71106 L p F P
0 g
s
.65 .758 .928 r
.41899 .70879 m .41064 .71125 L .40815 .70898 L p F P
0 g
s
.65 .758 .928 r
.54299 .71126 m .55156 .7088 L .55383 .71107 L p F P
0 g
s
.65 .758 .928 r
.55156 .7088 m .54299 .71126 L .54071 .70899 L p F P
0 g
s
.651 .759 .928 r
.82757 .70842 m .81856 .71089 L .81669 .70863 L p F P
0 g
s
.65 .757 .928 r
.2891 .71098 m .29726 .70853 L .29991 .7108 L p F P
0 g
s
.65 .757 .928 r
.29726 .70853 m .2891 .71098 L .28643 .70871 L p F P
0 g
s
.651 .758 .928 r
.6862 .71104 m .69501 .70858 L .69706 .71084 L p F P
0 g
s
.651 .758 .928 r
.69501 .70858 m .6862 .71104 L .68413 .70877 L p F P
0 g
s
.65 .758 .928 r
.42146 .71106 m .42984 .7086 L .43229 .71087 L p F P
0 g
s
.65 .758 .928 r
.42984 .7086 m .42146 .71106 L .41899 .70879 L p F P
0 g
s
.65 .758 .928 r
.55383 .71107 m .56242 .70861 L .56468 .71088 L p F P
0 g
s
.65 .758 .928 r
.56242 .70861 m .55383 .71107 L .55156 .7088 L p F P
0 g
s
.65 .757 .928 r
.29991 .7108 m .30809 .70835 L .31072 .71062 L p F P
0 g
s
.65 .757 .928 r
.30809 .70835 m .29991 .7108 L .29726 .70853 L p F P
0 g
s
.651 .758 .928 r
.69706 .71084 m .70588 .70838 L .70793 .71065 L p F P
0 g
s
.651 .758 .928 r
.70588 .70838 m .69706 .71084 L .69501 .70858 L p F P
0 g
s
.65 .758 .928 r
.43229 .71087 m .44068 .70842 L .44312 .71069 L p F P
0 g
s
.65 .758 .928 r
.44068 .70842 m .43229 .71087 L .42984 .7086 L p F P
0 g
s
.65 .758 .928 r
.56468 .71088 m .57328 .70842 L .57552 .71069 L p F P
0 g
s
.65 .758 .928 r
.57328 .70842 m .56468 .71088 L .56242 .70861 L p F P
0 g
s
.65 .757 .928 r
.31072 .71062 m .31892 .70817 L .32153 .71044 L p F P
0 g
s
.65 .757 .928 r
.31892 .70817 m .31072 .71062 L .30809 .70835 L p F P
0 g
s
.651 .758 .928 r
.70793 .71065 m .71676 .70818 L .71879 .71045 L p F P
0 g
s
.651 .758 .928 r
.71676 .70818 m .70793 .71065 L .70588 .70838 L p F P
0 g
s
.65 .758 .928 r
.44312 .71069 m .45153 .70823 L .45395 .7105 L p F P
0 g
s
.65 .758 .928 r
.45153 .70823 m .44312 .71069 L .44068 .70842 L p F P
0 g
s
.65 .758 .928 r
.57552 .71069 m .58415 .70823 L .58637 .7105 L p F P
0 g
s
.65 .758 .928 r
.58415 .70823 m .57552 .71069 L .57328 .70842 L p F P
0 g
s
.65 .757 .928 r
.32153 .71044 m .32975 .70799 L .33235 .71026 L p F P
0 g
s
.65 .757 .928 r
.32975 .70799 m .32153 .71044 L .31892 .70817 L p F P
0 g
s
.651 .758 .928 r
.71879 .71045 m .72765 .70799 L .72966 .71025 L p F P
0 g
s
.651 .758 .928 r
.72765 .70799 m .71879 .71045 L .71676 .70818 L p F P
0 g
s
.65 .758 .928 r
.45395 .7105 m .46238 .70804 L .46479 .71031 L p F P
0 g
s
.65 .758 .928 r
.46238 .70804 m .45395 .7105 L .45153 .70823 L p F P
0 g
s
.65 .758 .928 r
.58637 .7105 m .59502 .70804 L .59722 .71031 L p F P
0 g
s
.65 .758 .928 r
.59502 .70804 m .58637 .7105 L .58415 .70823 L p F P
0 g
s
.651 .758 .928 r
.72966 .71025 m .73853 .70779 L .74053 .71006 L p F P
0 g
s
.651 .758 .928 r
.73853 .70779 m .72966 .71025 L .72765 .70799 L p F P
0 g
s
.65 .757 .928 r
.33235 .71026 m .34059 .70781 L .34317 .71008 L p F P
0 g
s
.65 .757 .928 r
.34059 .70781 m .33235 .71026 L .32975 .70799 L p F P
0 g
s
.65 .758 .928 r
.59722 .71031 m .60589 .70785 L .60808 .71012 L p F P
0 g
s
.65 .758 .928 r
.60589 .70785 m .59722 .71031 L .59502 .70804 L p F P
0 g
s
.65 .758 .928 r
.46479 .71031 m .47323 .70786 L .47562 .71013 L p F P
0 g
s
.65 .758 .928 r
.47323 .70786 m .46479 .71031 L .46238 .70804 L p F P
0 g
s
.651 .758 .928 r
.74053 .71006 m .74942 .70759 L .7514 .70986 L p F P
0 g
s
.651 .758 .928 r
.74942 .70759 m .74053 .71006 L .73853 .70779 L p F P
0 g
s
.65 .757 .928 r
.34317 .71008 m .35143 .70763 L .354 .7099 L p F P
0 g
s
.65 .757 .928 r
.35143 .70763 m .34317 .71008 L .34059 .70781 L p F P
0 g
s
.65 .758 .928 r
.60808 .71012 m .61676 .70766 L .61893 .70993 L p F P
0 g
s
.65 .758 .928 r
.61676 .70766 m .60808 .71012 L .60589 .70785 L p F P
0 g
s
.65 .758 .928 r
.47562 .71013 m .48409 .70767 L .48646 .70994 L p F P
0 g
s
.65 .758 .928 r
.48409 .70767 m .47562 .71013 L .47323 .70786 L p F P
0 g
s
.651 .758 .928 r
.7514 .70986 m .76031 .70739 L .76227 .70966 L p F P
0 g
s
.651 .758 .928 r
.76031 .70739 m .7514 .70986 L .74942 .70759 L p F P
0 g
s
.65 .757 .928 r
.354 .7099 m .36227 .70744 L .36482 .70972 L p F P
0 g
s
.65 .757 .928 r
.36227 .70744 m .354 .7099 L .35143 .70763 L p F P
0 g
s
.65 .758 .928 r
.61893 .70993 m .62763 .70747 L .62979 .70974 L p F P
0 g
s
.65 .758 .928 r
.62763 .70747 m .61893 .70993 L .61676 .70766 L p F P
0 g
s
.65 .758 .928 r
.48646 .70994 m .49495 .70748 L .49731 .70975 L p F P
0 g
s
.65 .758 .928 r
.49495 .70748 m .48646 .70994 L .48409 .70767 L p F P
0 g
s
.651 .758 .928 r
.76227 .70966 m .7712 .70719 L .77315 .70945 L p F P
0 g
s
.651 .758 .928 r
.7712 .70719 m .76227 .70966 L .76031 .70739 L p F P
0 g
s
0 0 .346 r
.52585 .38854 m .52581 .38862 L .52581 .3849 L p F P
0 g
s
0 0 .346 r
.52581 .3849 m .52585 .38481 L .52585 .38854 L p F P
0 g
s
.762 .5 .538 r
.52568 .3886 m .52581 .38862 L .52581 .3849 L p F P
0 g
s
.762 .5 .538 r
.52581 .3849 m .52567 .38487 L .52568 .3886 L p F P
0 g
s
.65 .757 .928 r
.36482 .70972 m .37311 .70726 L .37565 .70953 L p F P
0 g
s
.65 .757 .928 r
.37311 .70726 m .36482 .70972 L .36227 .70744 L p F P
0 g
s
0 0 .348 r
.52571 .38478 m .52567 .38487 L .52568 .3886 L p F P
0 g
s
.65 .758 .928 r
.62979 .70974 m .63851 .70727 L .64066 .70955 L p F P
0 g
s
.65 .758 .928 r
.63851 .70727 m .62979 .70974 L .62763 .70747 L p F P
0 g
s
.65 .758 .928 r
.49731 .70975 m .50581 .70729 L .50815 .70956 L p F P
0 g
s
.65 .758 .928 r
.50581 .70729 m .49731 .70975 L .49495 .70748 L p F P
0 g
s
.762 .501 .539 r
.52571 .38478 m .52585 .38481 L .52585 .38854 L p F P
0 g
s
.762 .501 .539 r
.52585 .38854 m .52571 .38851 L .52571 .38478 L p F P
0 g
s
0 0 .348 r
.52568 .3886 m .52571 .38851 L .52571 .38478 L p F P
0 g
s
.651 .758 .928 r
.77315 .70945 m .7821 .70698 L .78403 .70925 L p F P
0 g
s
.651 .758 .928 r
.7821 .70698 m .77315 .70945 L .7712 .70719 L p F P
0 g
s
.65 .758 .928 r
.37565 .70953 m .38396 .70707 L .38648 .70935 L p F P
0 g
s
.65 .757 .928 r
.38396 .70707 m .37565 .70953 L .37311 .70726 L p F P
0 g
s
.65 .758 .928 r
.64066 .70955 m .64939 .70708 L .65152 .70935 L p F P
0 g
s
.65 .758 .928 r
.64939 .70708 m .64066 .70955 L .63851 .70727 L p F P
0 g
s
.65 .758 .928 r
.50815 .70956 m .51668 .7071 L .519 .70937 L p F P
0 g
s
.65 .758 .928 r
.51668 .7071 m .50815 .70956 L .50581 .70729 L p F P
0 g
s
.651 .758 .928 r
.78403 .70925 m .793 .70678 L .79491 .70904 L p F P
0 g
s
.651 .758 .928 r
.793 .70678 m .78403 .70925 L .7821 .70698 L p F P
0 g
s
.65 .758 .928 r
.38648 .70935 m .39481 .70689 L .39732 .70916 L p F P
0 g
s
.65 .758 .928 r
.39481 .70689 m .38648 .70935 L .38396 .70707 L p F P
0 g
s
.651 .758 .928 r
.65152 .70935 m .66027 .70689 L .66239 .70916 L p F P
0 g
s
.651 .758 .928 r
.66027 .70689 m .65152 .70935 L .64939 .70708 L p F P
0 g
s
.65 .758 .928 r
.519 .70937 m .52754 .70691 L .52985 .70918 L p F P
0 g
s
.65 .758 .928 r
.52754 .70691 m .519 .70937 L .51668 .7071 L p F P
0 g
s
.651 .758 .928 r
.79491 .70904 m .8039 .70657 L .8058 .70884 L p F P
0 g
s
.651 .758 .928 r
.8039 .70657 m .79491 .70904 L .793 .70678 L p F P
0 g
s
.651 .758 .928 r
.66239 .70916 m .67116 .70669 L .67326 .70897 L p F P
0 g
s
.651 .758 .928 r
.67116 .70669 m .66239 .70916 L .66027 .70689 L p F P
0 g
s
.65 .758 .928 r
.39732 .70916 m .40566 .7067 L .40815 .70898 L p F P
0 g
s
.65 .758 .928 r
.40566 .7067 m .39732 .70916 L .39481 .70689 L p F P
0 g
s
.65 .758 .928 r
.52985 .70918 m .53841 .70672 L .54071 .70899 L p F P
0 g
s
.65 .758 .928 r
.53841 .70672 m .52985 .70918 L .52754 .70691 L p F P
0 g
s
.651 .759 .928 r
.8058 .70884 m .8148 .70636 L .81669 .70863 L p F P
0 g
s
.651 .758 .928 r
.8148 .70636 m .8058 .70884 L .8039 .70657 L p F P
0 g
s
.65 .757 .928 r
.27561 .70888 m .28376 .70643 L .28643 .70871 L p F P
0 g
s
.65 .757 .928 r
.28376 .70643 m .27561 .70888 L .27292 .70661 L p F P
0 g
s
.651 .758 .928 r
.67326 .70897 m .68205 .7065 L .68413 .70877 L p F P
0 g
s
.651 .758 .928 r
.68205 .7065 m .67326 .70897 L .67116 .70669 L p F P
0 g
s
.65 .758 .928 r
.40815 .70898 m .41652 .70652 L .41899 .70879 L p F P
0 g
s
.65 .758 .928 r
.41652 .70652 m .40815 .70898 L .40566 .7067 L p F P
0 g
s
.65 .758 .928 r
.54071 .70899 m .54928 .70653 L .55156 .7088 L p F P
0 g
s
.65 .758 .928 r
.54928 .70653 m .54071 .70899 L .53841 .70672 L p F P
0 g
s
.651 .759 .928 r
.81669 .70863 m .82571 .70615 L .82757 .70842 L p F P
0 g
s
.651 .759 .928 r
.82571 .70615 m .81669 .70863 L .8148 .70636 L p F P
0 g
s
.65 .757 .928 r
.28643 .70871 m .2946 .70625 L .29726 .70853 L p F P
0 g
s
.65 .757 .928 r
.2946 .70625 m .28643 .70871 L .28376 .70643 L p F P
0 g
s
.651 .758 .928 r
.69294 .7063 m .68413 .70877 L .68205 .7065 L p F P
0 g
s
.651 .758 .928 r
.68413 .70877 m .69294 .7063 L .69501 .70858 L p F P
0 g
s
.65 .758 .928 r
.42738 .70633 m .41899 .70879 L .41652 .70652 L p F P
0 g
s
.65 .758 .928 r
.41899 .70879 m .42738 .70633 L .42984 .7086 L p F P
0 g
s
.65 .758 .928 r
.55156 .7088 m .56016 .70634 L .56242 .70861 L p F P
0 g
s
.65 .758 .928 r
.56016 .70634 m .55156 .7088 L .54928 .70653 L p F P
0 g
s
.651 .759 .928 r
.83662 .70594 m .82757 .70842 L .82571 .70615 L p F P
0 g
s
.65 .757 .928 r
.29726 .70853 m .30544 .70607 L .30809 .70835 L p F P
0 g
s
.65 .757 .928 r
.30544 .70607 m .29726 .70853 L .2946 .70625 L p F P
0 g
s
.651 .758 .928 r
.69501 .70858 m .70383 .70611 L .70588 .70838 L p F P
0 g
s
.651 .758 .928 r
.70383 .70611 m .69501 .70858 L .69294 .7063 L p F P
0 g
s
.65 .758 .928 r
.42984 .7086 m .43824 .70614 L .44068 .70842 L p F P
0 g
s
.65 .758 .928 r
.43824 .70614 m .42984 .7086 L .42738 .70633 L p F P
0 g
s
.65 .758 .928 r
.56242 .70861 m .57104 .70615 L .57328 .70842 L p F P
0 g
s
.65 .758 .928 r
.57104 .70615 m .56242 .70861 L .56016 .70634 L p F P
0 g
s
.65 .757 .928 r
.30809 .70835 m .31629 .70589 L .31892 .70817 L p F P
0 g
s
.65 .757 .928 r
.31629 .70589 m .30809 .70835 L .30544 .70607 L p F P
0 g
s
.651 .758 .928 r
.70588 .70838 m .71473 .70591 L .71676 .70818 L p F P
0 g
s
.651 .758 .928 r
.71473 .70591 m .70588 .70838 L .70383 .70611 L p F P
0 g
s
.65 .758 .928 r
.44068 .70842 m .4491 .70595 L .45153 .70823 L p F P
0 g
s
.65 .758 .928 r
.4491 .70595 m .44068 .70842 L .43824 .70614 L p F P
0 g
s
.65 .758 .928 r
.57328 .70842 m .58192 .70596 L .58415 .70823 L p F P
0 g
s
.65 .758 .928 r
.58192 .70596 m .57328 .70842 L .57104 .70615 L p F P
0 g
s
.65 .757 .928 r
.31892 .70817 m .32714 .70571 L .32975 .70799 L p F P
0 g
s
.65 .757 .928 r
.32714 .70571 m .31892 .70817 L .31629 .70589 L p F P
0 g
s
.651 .758 .928 r
.71676 .70818 m .72563 .70571 L .72765 .70799 L p F P
0 g
s
.651 .758 .928 r
.72563 .70571 m .71676 .70818 L .71473 .70591 L p F P
0 g
s
.65 .758 .928 r
.45153 .70823 m .45997 .70577 L .46238 .70804 L p F P
0 g
s
.65 .758 .928 r
.45997 .70577 m .45153 .70823 L .4491 .70595 L p F P
0 g
s
.65 .758 .928 r
.58415 .70823 m .5928 .70577 L .59502 .70804 L p F P
0 g
s
.65 .758 .928 r
.5928 .70577 m .58415 .70823 L .58192 .70596 L p F P
0 g
s
.651 .758 .928 r
.72765 .70799 m .73653 .70551 L .73853 .70779 L p F P
0 g
s
.651 .758 .928 r
.73653 .70551 m .72765 .70799 L .72563 .70571 L p F P
0 g
s
.65 .757 .928 r
.32975 .70799 m .33799 .70553 L .34059 .70781 L p F P
0 g
s
.65 .757 .928 r
.33799 .70553 m .32975 .70799 L .32714 .70571 L p F P
0 g
s
.65 .758 .928 r
.59502 .70804 m .60369 .70557 L .60589 .70785 L p F P
0 g
s
.65 .758 .928 r
.60369 .70557 m .59502 .70804 L .5928 .70577 L p F P
0 g
s
.65 .758 .928 r
.46238 .70804 m .47084 .70558 L .47323 .70786 L p F P
0 g
s
.65 .758 .928 r
.47084 .70558 m .46238 .70804 L .45997 .70577 L p F P
0 g
s
.651 .758 .928 r
.73853 .70779 m .74743 .70531 L .74942 .70759 L p F P
0 g
s
.651 .758 .928 r
.74743 .70531 m .73853 .70779 L .73653 .70551 L p F P
0 g
s
0 0 .346 r
.52584 .39228 m .5258 .39236 L .52581 .38862 L p F P
0 g
s
0 0 .346 r
.52581 .38862 m .52585 .38854 L .52584 .39228 L p F P
0 g
s
.762 .5 .538 r
.52568 .39234 m .5258 .39236 L .52581 .38862 L p F P
0 g
s
.762 .5 .538 r
.52581 .38862 m .52568 .3886 L .52568 .39234 L p F P
0 g
s
.65 .757 .928 r
.34059 .70781 m .34885 .70535 L .35143 .70763 L p F P
0 g
s
.65 .757 .928 r
.34885 .70535 m .34059 .70781 L .33799 .70553 L p F P
0 g
s
0 0 .348 r
.52571 .38851 m .52568 .3886 L .52568 .39234 L p F P
0 g
s
.65 .758 .928 r
.60589 .70785 m .61457 .70538 L .61676 .70766 L p F P
0 g
s
.65 .758 .928 r
.61457 .70538 m .60589 .70785 L .60369 .70557 L p F P
0 g
s
.65 .758 .928 r
.47323 .70786 m .48171 .70539 L .48409 .70767 L p F P
0 g
s
.65 .758 .928 r
.48171 .70539 m .47323 .70786 L .47084 .70558 L p F P
0 g
s
.762 .501 .539 r
.52571 .38851 m .52585 .38854 L .52584 .39228 L p F P
0 g
s
.762 .501 .539 r
.52584 .39228 m .52572 .39225 L .52571 .38851 L p F P
0 g
s
0 0 .348 r
.52568 .39234 m .52572 .39225 L .52571 .38851 L p F P
0 g
s
.651 .758 .928 r
.74942 .70759 m .75834 .70511 L .76031 .70739 L p F P
0 g
s
.651 .758 .928 r
.75834 .70511 m .74942 .70759 L .74743 .70531 L p F P
0 g
s
.65 .757 .928 r
.35143 .70763 m .35971 .70516 L .36227 .70744 L p F P
0 g
s
.65 .757 .928 r
.35971 .70516 m .35143 .70763 L .34885 .70535 L p F P
0 g
s
.65 .758 .928 r
.61676 .70766 m .62547 .70519 L .62763 .70747 L p F P
0 g
s
.65 .758 .928 r
.62547 .70519 m .61676 .70766 L .61457 .70538 L p F P
0 g
s
.65 .758 .928 r
.48409 .70767 m .49259 .7052 L .49495 .70748 L p F P
0 g
s
.65 .758 .928 r
.49259 .7052 m .48409 .70767 L .48171 .70539 L p F P
0 g
s
.651 .758 .928 r
.76031 .70739 m .76925 .70491 L .7712 .70719 L p F P
0 g
s
.651 .758 .928 r
.76925 .70491 m .76031 .70739 L .75834 .70511 L p F P
0 g
s
.65 .757 .928 r
.36227 .70744 m .37057 .70498 L .37311 .70726 L p F P
0 g
s
.65 .757 .928 r
.37057 .70498 m .36227 .70744 L .35971 .70516 L p F P
0 g
s
.65 .758 .928 r
.62763 .70747 m .63636 .705 L .63851 .70727 L p F P
0 g
s
.65 .758 .928 r
.63636 .705 m .62763 .70747 L .62547 .70519 L p F P
0 g
s
.65 .758 .928 r
.49495 .70748 m .50346 .70501 L .50581 .70729 L p F P
0 g
s
.65 .758 .928 r
.50346 .70501 m .49495 .70748 L .49259 .7052 L p F P
0 g
s
.651 .758 .928 r
.7712 .70719 m .78016 .70471 L .7821 .70698 L p F P
0 g
s
.651 .758 .928 r
.78016 .70471 m .7712 .70719 L .76925 .70491 L p F P
0 g
s
.65 .757 .928 r
.37311 .70726 m .38143 .70479 L .38396 .70707 L p F P
0 g
s
.65 .757 .928 r
.38143 .70479 m .37311 .70726 L .37057 .70498 L p F P
0 g
s
.65 .758 .928 r
.63851 .70727 m .64726 .7048 L .64939 .70708 L p F P
0 g
s
.65 .758 .928 r
.64726 .7048 m .63851 .70727 L .63636 .705 L p F P
0 g
s
.65 .758 .928 r
.50581 .70729 m .51434 .70482 L .51668 .7071 L p F P
0 g
s
.65 .758 .928 r
.51434 .70482 m .50581 .70729 L .50346 .70501 L p F P
0 g
s
.651 .758 .928 r
.7821 .70698 m .79108 .7045 L .793 .70678 L p F P
0 g
s
.651 .758 .928 r
.79108 .7045 m .7821 .70698 L .78016 .70471 L p F P
0 g
s
.65 .758 .928 r
.38396 .70707 m .3923 .70461 L .39481 .70689 L p F P
0 g
s
.65 .758 .928 r
.3923 .70461 m .38396 .70707 L .38143 .70479 L p F P
0 g
s
.651 .758 .928 r
.64939 .70708 m .65816 .70461 L .66027 .70689 L p F P
0 g
s
.651 .758 .928 r
.65816 .70461 m .64939 .70708 L .64726 .7048 L p F P
0 g
s
.65 .758 .928 r
.51668 .7071 m .52523 .70463 L .52754 .70691 L p F P
0 g
s
.65 .758 .928 r
.52523 .70463 m .51668 .7071 L .51434 .70482 L p F P
0 g
s
.651 .758 .928 r
.793 .70678 m .80199 .7043 L .8039 .70657 L p F P
0 g
s
.651 .758 .928 r
.80199 .7043 m .793 .70678 L .79108 .7045 L p F P
0 g
s
.651 .758 .928 r
.66027 .70689 m .66906 .70441 L .67116 .70669 L p F P
0 g
s
.651 .758 .928 r
.66906 .70441 m .66027 .70689 L .65816 .70461 L p F P
0 g
s
.65 .758 .928 r
.39481 .70689 m .40316 .70442 L .40566 .7067 L p F P
0 g
s
.65 .758 .928 r
.40316 .70442 m .39481 .70689 L .3923 .70461 L p F P
0 g
s
.65 .758 .928 r
.52754 .70691 m .53611 .70444 L .53841 .70672 L p F P
0 g
s
.65 .758 .928 r
.53611 .70444 m .52754 .70691 L .52523 .70463 L p F P
0 g
s
.651 .758 .928 r
.8039 .70657 m .81291 .70409 L .8148 .70636 L p F P
0 g
s
.651 .758 .928 r
.81291 .70409 m .8039 .70657 L .80199 .7043 L p F P
0 g
s
.65 .757 .928 r
.27292 .70661 m .28108 .70415 L .28376 .70643 L p F P
0 g
s
.65 .757 .928 r
.28108 .70415 m .27292 .70661 L .27023 .70433 L p F P
0 g
s
.651 .758 .928 r
.67996 .70422 m .67116 .70669 L .66906 .70441 L p F P
0 g
s
.651 .758 .928 r
.67116 .70669 m .67996 .70422 L .68205 .7065 L p F P
0 g
s
.65 .758 .928 r
.40566 .7067 m .41404 .70423 L .41652 .70652 L p F P
0 g
s
.65 .758 .928 r
.41404 .70423 m .40566 .7067 L .40316 .70442 L p F P
0 g
s
.65 .758 .928 r
.53841 .70672 m .547 .70425 L .54928 .70653 L p F P
0 g
s
.65 .758 .928 r
.547 .70425 m .53841 .70672 L .53611 .70444 L p F P
0 g
s
.651 .759 .928 r
.8148 .70636 m .82383 .70388 L .82571 .70615 L p F P
0 g
s
.651 .759 .928 r
.82383 .70388 m .8148 .70636 L .81291 .70409 L p F P
0 g
s
.65 .757 .928 r
.28376 .70643 m .29194 .70397 L .2946 .70625 L p F P
0 g
s
.65 .757 .928 r
.29194 .70397 m .28376 .70643 L .28108 .70415 L p F P
0 g
s
.651 .758 .928 r
.68205 .7065 m .69087 .70402 L .69294 .7063 L p F P
0 g
s
.651 .758 .928 r
.69087 .70402 m .68205 .7065 L .67996 .70422 L p F P
0 g
s
.65 .758 .928 r
.41652 .70652 m .42491 .70405 L .42738 .70633 L p F P
0 g
s
.65 .758 .928 r
.42491 .70405 m .41652 .70652 L .41404 .70423 L p F P
0 g
s
.65 .758 .928 r
.54928 .70653 m .55789 .70406 L .56016 .70634 L p F P
0 g
s
.65 .758 .928 r
.55789 .70406 m .54928 .70653 L .547 .70425 L p F P
0 g
s
.651 .759 .928 r
.82571 .70615 m .83476 .70366 L .83662 .70594 L p F P
0 g
s
.651 .759 .928 r
.83476 .70366 m .82571 .70615 L .82383 .70388 L p F P
0 g
s
.65 .757 .928 r
.2946 .70625 m .3028 .70379 L .30544 .70607 L p F P
0 g
s
.65 .757 .928 r
.3028 .70379 m .2946 .70625 L .29194 .70397 L p F P
0 g
s
.651 .758 .928 r
.69294 .7063 m .70178 .70383 L .70383 .70611 L p F P
0 g
s
.651 .758 .928 r
.70178 .70383 m .69294 .7063 L .69087 .70402 L p F P
0 g
s
.65 .758 .928 r
.42738 .70633 m .43579 .70386 L .43824 .70614 L p F P
0 g
s
.65 .758 .928 r
.43579 .70386 m .42738 .70633 L .42491 .70405 L p F P
0 g
s
.65 .758 .928 r
.56016 .70634 m .56878 .70387 L .57104 .70615 L p F P
0 g
s
.65 .758 .928 r
.56878 .70387 m .56016 .70634 L .55789 .70406 L p F P
0 g
s
.651 .759 .928 r
.84568 .70345 m .83662 .70594 L .83476 .70366 L p F P
0 g
s
.65 .757 .928 r
.30544 .70607 m .31366 .70361 L .31629 .70589 L p F P
0 g
s
.65 .757 .928 r
.31366 .70361 m .30544 .70607 L .3028 .70379 L p F P
0 g
s
.651 .758 .928 r
.70383 .70611 m .71269 .70363 L .71473 .70591 L p F P
0 g
s
.651 .758 .928 r
.71269 .70363 m .70383 .70611 L .70178 .70383 L p F P
0 g
s
.65 .758 .928 r
.43824 .70614 m .44667 .70367 L .4491 .70595 L p F P
0 g
s
.65 .758 .928 r
.44667 .70367 m .43824 .70614 L .43579 .70386 L p F P
0 g
s
.65 .758 .928 r
.57104 .70615 m .57968 .70367 L .58192 .70596 L p F P
0 g
s
.65 .758 .928 r
.57968 .70367 m .57104 .70615 L .56878 .70387 L p F P
0 g
s
.65 .757 .928 r
.31629 .70589 m .32452 .70343 L .32714 .70571 L p F P
0 g
s
.65 .757 .928 r
.32452 .70343 m .31629 .70589 L .31366 .70361 L p F P
0 g
s
0 0 .346 r
.52584 .39603 m .5258 .3961 L .5258 .39236 L p F P
0 g
s
0 0 .346 r
.5258 .39236 m .52584 .39228 L .52584 .39603 L p F P
0 g
s
.762 .5 .538 r
.52568 .39608 m .5258 .3961 L .5258 .39236 L p F P
0 g
s
.762 .5 .538 r
.5258 .39236 m .52568 .39234 L .52568 .39608 L p F P
0 g
s
.651 .758 .928 r
.71473 .70591 m .72361 .70343 L .72563 .70571 L p F P
0 g
s
.651 .758 .928 r
.72361 .70343 m .71473 .70591 L .71269 .70363 L p F P
0 g
s
0 0 .348 r
.52572 .39225 m .52568 .39234 L .52568 .39608 L p F P
0 g
s
.65 .758 .928 r
.4491 .70595 m .45755 .70348 L .45997 .70577 L p F P
0 g
s
.65 .758 .928 r
.45755 .70348 m .4491 .70595 L .44667 .70367 L p F P
0 g
s
.65 .758 .928 r
.58192 .70596 m .59058 .70348 L .5928 .70577 L p F P
0 g
s
.65 .758 .928 r
.59058 .70348 m .58192 .70596 L .57968 .70367 L p F P
0 g
s
.762 .501 .539 r
.52572 .39225 m .52584 .39228 L .52584 .39603 L p F P
0 g
s
.762 .501 .539 r
.52584 .39603 m .52572 .396 L .52572 .39225 L p F P
0 g
s
0 0 .348 r
.52568 .39608 m .52572 .396 L .52572 .39225 L p F P
0 g
s
.651 .758 .928 r
.72563 .70571 m .73452 .70323 L .73653 .70551 L p F P
0 g
s
.651 .758 .928 r
.73452 .70323 m .72563 .70571 L .72361 .70343 L p F P
0 g
s
.65 .757 .928 r
.32714 .70571 m .33539 .70325 L .33799 .70553 L p F P
0 g
s
.65 .757 .928 r
.33539 .70325 m .32714 .70571 L .32452 .70343 L p F P
0 g
s
.65 .758 .928 r
.5928 .70577 m .60148 .70329 L .60369 .70557 L p F P
0 g
s
.65 .758 .928 r
.60148 .70329 m .5928 .70577 L .59058 .70348 L p F P
0 g
s
.65 .758 .928 r
.45997 .70577 m .46843 .70329 L .47084 .70558 L p F P
0 g
s
.65 .758 .928 r
.46843 .70329 m .45997 .70577 L .45755 .70348 L p F P
0 g
s
.651 .758 .928 r
.73653 .70551 m .74544 .70303 L .74743 .70531 L p F P
0 g
s
.651 .758 .928 r
.74544 .70303 m .73653 .70551 L .73452 .70323 L p F P
0 g
s
.65 .757 .928 r
.33799 .70553 m .34626 .70306 L .34885 .70535 L p F P
0 g
s
.65 .757 .928 r
.34626 .70306 m .33799 .70553 L .33539 .70325 L p F P
0 g
s
.65 .758 .928 r
.60369 .70557 m .61239 .7031 L .61457 .70538 L p F P
0 g
s
.65 .758 .928 r
.61239 .7031 m .60369 .70557 L .60148 .70329 L p F P
0 g
s
.65 .758 .928 r
.47084 .70558 m .47932 .7031 L .48171 .70539 L p F P
0 g
s
.65 .758 .928 r
.47932 .7031 m .47084 .70558 L .46843 .70329 L p F P
0 g
s
.651 .758 .928 r
.74743 .70531 m .75637 .70283 L .75834 .70511 L p F P
0 g
s
.651 .758 .928 r
.75637 .70283 m .74743 .70531 L .74544 .70303 L p F P
0 g
s
.65 .757 .928 r
.34885 .70535 m .35714 .70288 L .35971 .70516 L p F P
0 g
s
.65 .757 .928 r
.35714 .70288 m .34885 .70535 L .34626 .70306 L p F P
0 g
s
.65 .758 .928 r
.61457 .70538 m .62329 .7029 L .62547 .70519 L p F P
0 g
s
.65 .758 .928 r
.62329 .7029 m .61457 .70538 L .61239 .7031 L p F P
0 g
s
.65 .758 .928 r
.48171 .70539 m .49021 .70291 L .49259 .7052 L p F P
0 g
s
.65 .758 .928 r
.49021 .70291 m .48171 .70539 L .47932 .7031 L p F P
0 g
s
.651 .758 .928 r
.75834 .70511 m .76729 .70263 L .76925 .70491 L p F P
0 g
s
.651 .758 .928 r
.76729 .70263 m .75834 .70511 L .75637 .70283 L p F P
0 g
s
.65 .757 .928 r
.35971 .70516 m .36801 .70269 L .37057 .70498 L p F P
0 g
s
.65 .757 .928 r
.36801 .70269 m .35971 .70516 L .35714 .70288 L p F P
0 g
s
.65 .758 .928 r
.62547 .70519 m .6342 .70271 L .63636 .705 L p F P
0 g
s
.65 .758 .928 r
.6342 .70271 m .62547 .70519 L .62329 .7029 L p F P
0 g
s
.65 .758 .928 r
.49259 .7052 m .50111 .70272 L .50346 .70501 L p F P
0 g
s
.65 .758 .928 r
.50111 .70272 m .49259 .7052 L .49021 .70291 L p F P
0 g
s
.651 .758 .928 r
.76925 .70491 m .77822 .70243 L .78016 .70471 L p F P
0 g
s
.651 .758 .928 r
.77822 .70243 m .76925 .70491 L .76729 .70263 L p F P
0 g
s
.65 .757 .928 r
.37057 .70498 m .37889 .70251 L .38143 .70479 L p F P
0 g
s
.65 .757 .928 r
.37889 .70251 m .37057 .70498 L .36801 .70269 L p F P
0 g
s
.65 .758 .928 r
.63636 .705 m .64511 .70252 L .64726 .7048 L p F P
0 g
s
.65 .758 .928 r
.64511 .70252 m .63636 .705 L .6342 .70271 L p F P
0 g
s
.65 .758 .928 r
.50346 .70501 m .512 .70253 L .51434 .70482 L p F P
0 g
s
.65 .758 .928 r
.512 .70253 m .50346 .70501 L .50111 .70272 L p F P
0 g
s
.651 .758 .928 r
.78016 .70471 m .78915 .70222 L .79108 .7045 L p F P
0 g
s
.651 .758 .928 r
.78915 .70222 m .78016 .70471 L .77822 .70243 L p F P
0 g
s
.65 .758 .928 r
.38143 .70479 m .38977 .70232 L .3923 .70461 L p F P
0 g
s
.65 .757 .928 r
.38977 .70232 m .38143 .70479 L .37889 .70251 L p F P
0 g
s
.651 .758 .928 r
.64726 .7048 m .65603 .70232 L .65816 .70461 L p F P
0 g
s
.651 .758 .928 r
.65603 .70232 m .64726 .7048 L .64511 .70252 L p F P
0 g
s
.65 .758 .928 r
.51434 .70482 m .5229 .70234 L .52523 .70463 L p F P
0 g
s
.65 .758 .928 r
.5229 .70234 m .51434 .70482 L .512 .70253 L p F P
0 g
s
.651 .758 .928 r
.79108 .7045 m .80008 .70201 L .80199 .7043 L p F P
0 g
s
.651 .758 .928 r
.80008 .70201 m .79108 .7045 L .78915 .70222 L p F P
0 g
s
.65 .758 .928 r
.3923 .70461 m .40066 .70213 L .40316 .70442 L p F P
0 g
s
.65 .758 .928 r
.40066 .70213 m .3923 .70461 L .38977 .70232 L p F P
0 g
s
.651 .758 .928 r
.65816 .70461 m .66695 .70213 L .66906 .70441 L p F P
0 g
s
.651 .758 .928 r
.66695 .70213 m .65816 .70461 L .65603 .70232 L p F P
0 g
s
.65 .758 .928 r
.52523 .70463 m .5338 .70215 L .53611 .70444 L p F P
0 g
s
.65 .758 .928 r
.5338 .70215 m .52523 .70463 L .5229 .70234 L p F P
0 g
s
.651 .758 .928 r
.80199 .7043 m .81102 .70181 L .81291 .70409 L p F P
0 g
s
.651 .758 .928 r
.81102 .70181 m .80199 .7043 L .80008 .70201 L p F P
0 g
s
.65 .757 .928 r
.27023 .70433 m .27839 .70186 L .28108 .70415 L p F P
0 g
s
.65 .757 .928 r
.27839 .70186 m .27023 .70433 L .26752 .70204 L p F P
0 g
s
.651 .758 .928 r
.66906 .70441 m .67787 .70193 L .67996 .70422 L p F P
0 g
s
.651 .758 .928 r
.67787 .70193 m .66906 .70441 L .66695 .70213 L p F P
0 g
s
.65 .758 .928 r
.40316 .70442 m .41155 .70194 L .41404 .70423 L p F P
0 g
s
.65 .758 .928 r
.41155 .70194 m .40316 .70442 L .40066 .70213 L p F P
0 g
s
.65 .758 .928 r
.53611 .70444 m .54471 .70196 L .547 .70425 L p F P
0 g
s
.65 .758 .928 r
.54471 .70196 m .53611 .70444 L .5338 .70215 L p F P
0 g
s
.651 .759 .928 r
.81291 .70409 m .82196 .70159 L .82383 .70388 L p F P
0 g
s
.651 .758 .928 r
.82196 .70159 m .81291 .70409 L .81102 .70181 L p F P
0 g
s
.65 .757 .928 r
.28108 .70415 m .28926 .70168 L .29194 .70397 L p F P
0 g
s
.65 .757 .928 r
.28926 .70168 m .28108 .70415 L .27839 .70186 L p F P
0 g
s
.651 .758 .928 r
.68879 .70173 m .67996 .70422 L .67787 .70193 L p F P
0 g
s
.651 .758 .928 r
.67996 .70422 m .68879 .70173 L .69087 .70402 L p F P
0 g
s
.65 .758 .928 r
.41404 .70423 m .42244 .70176 L .42491 .70405 L p F P
0 g
s
.65 .758 .928 r
.42244 .70176 m .41404 .70423 L .41155 .70194 L p F P
0 g
s
.65 .758 .928 r
.547 .70425 m .55561 .70177 L .55789 .70406 L p F P
0 g
s
.65 .758 .928 r
.55561 .70177 m .547 .70425 L .54471 .70196 L p F P
0 g
s
.651 .759 .928 r
.82383 .70388 m .8329 .70138 L .83476 .70366 L p F P
0 g
s
.651 .759 .928 r
.8329 .70138 m .82383 .70388 L .82196 .70159 L p F P
0 g
s
.65 .757 .928 r
.29194 .70397 m .30014 .7015 L .3028 .70379 L p F P
0 g
s
.65 .757 .928 r
.30014 .7015 m .29194 .70397 L .28926 .70168 L p F P
0 g
s
0 0 .346 r
.52583 .39978 m .5258 .39986 L .5258 .3961 L p F P
0 g
s
0 0 .346 r
.5258 .3961 m .52584 .39603 L .52583 .39978 L p F P
0 g
s
.762 .5 .538 r
.52569 .39984 m .5258 .39986 L .5258 .3961 L p F P
0 g
s
.762 .5 .538 r
.5258 .3961 m .52568 .39608 L .52569 .39984 L p F P
0 g
s
.651 .758 .928 r
.69087 .70402 m .69972 .70154 L .70178 .70383 L p F P
0 g
s
.651 .758 .928 r
.69972 .70154 m .69087 .70402 L .68879 .70173 L p F P
0 g
s
0 0 .348 r
.52572 .396 m .52568 .39608 L .52569 .39984 L p F P
0 g
s
.65 .758 .928 r
.42491 .70405 m .43333 .70157 L .43579 .70386 L p F P
0 g
s
.65 .758 .928 r
.43333 .70157 m .42491 .70405 L .42244 .70176 L p F P
0 g
s
.65 .758 .928 r
.55789 .70406 m .56652 .70158 L .56878 .70387 L p F P
0 g
s
.65 .758 .928 r
.56652 .70158 m .55789 .70406 L .55561 .70177 L p F P
0 g
s
.762 .501 .539 r
.52572 .396 m .52584 .39603 L .52583 .39978 L p F P
0 g
s
.762 .501 .539 r
.52583 .39978 m .52572 .39976 L .52572 .396 L p F P
0 g
s
0 0 .348 r
.52569 .39984 m .52572 .39976 L .52572 .396 L p F P
0 g
s
.651 .759 .928 r
.83476 .70366 m .84384 .70117 L .84568 .70345 L p F P
0 g
s
.651 .759 .928 r
.84384 .70117 m .83476 .70366 L .8329 .70138 L p F P
0 g
s
.65 .757 .928 r
.3028 .70379 m .31102 .70132 L .31366 .70361 L p F P
0 g
s
.65 .757 .928 r
.31102 .70132 m .3028 .70379 L .30014 .7015 L p F P
0 g
s
.651 .758 .928 r
.71065 .70134 m .70178 .70383 L .69972 .70154 L p F P
0 g
s
.651 .758 .928 r
.70178 .70383 m .71065 .70134 L .71269 .70363 L p F P
0 g
s
.65 .758 .928 r
.43579 .70386 m .44422 .70138 L .44667 .70367 L p F P
0 g
s
.65 .758 .928 r
.44422 .70138 m .43579 .70386 L .43333 .70157 L p F P
0 g
s
.65 .758 .928 r
.56878 .70387 m .57744 .70138 L .57968 .70367 L p F P
0 g
s
.65 .758 .928 r
.57744 .70138 m .56878 .70387 L .56652 .70158 L p F P
0 g
s
.651 .759 .928 r
.85478 .70095 m .84568 .70345 L .84384 .70117 L p F P
0 g
s
.65 .757 .928 r
.31366 .70361 m .3219 .70114 L .32452 .70343 L p F P
0 g
s
.65 .757 .928 r
.3219 .70114 m .31366 .70361 L .31102 .70132 L p F P
0 g
s
.651 .758 .928 r
.71269 .70363 m .72158 .70114 L .72361 .70343 L p F P
0 g
s
.651 .758 .928 r
.72158 .70114 m .71269 .70363 L .71065 .70134 L p F P
0 g
s
.65 .758 .928 r
.44667 .70367 m .45512 .70119 L .45755 .70348 L p F P
0 g
s
.65 .758 .928 r
.45512 .70119 m .44667 .70367 L .44422 .70138 L p F P
0 g
s
.65 .758 .928 r
.57968 .70367 m .58835 .70119 L .59058 .70348 L p F P
0 g
s
.65 .758 .928 r
.58835 .70119 m .57968 .70367 L .57744 .70138 L p F P
0 g
s
.65 .757 .928 r
.32452 .70343 m .33278 .70095 L .33539 .70325 L p F P
0 g
s
.65 .757 .928 r
.33278 .70095 m .32452 .70343 L .3219 .70114 L p F P
0 g
s
.651 .758 .928 r
.72361 .70343 m .73251 .70094 L .73452 .70323 L p F P
0 g
s
.651 .758 .928 r
.73251 .70094 m .72361 .70343 L .72158 .70114 L p F P
0 g
s
.65 .758 .928 r
.45755 .70348 m .46602 .701 L .46843 .70329 L p F P
0 g
s
.65 .758 .928 r
.46602 .701 m .45755 .70348 L .45512 .70119 L p F P
0 g
s
.65 .758 .928 r
.59058 .70348 m .59927 .701 L .60148 .70329 L p F P
0 g
s
.65 .758 .928 r
.59927 .701 m .59058 .70348 L .58835 .70119 L p F P
0 g
s
.651 .758 .928 r
.73452 .70323 m .74345 .70074 L .74544 .70303 L p F P
0 g
s
.651 .758 .928 r
.74345 .70074 m .73452 .70323 L .73251 .70094 L p F P
0 g
s
.65 .757 .928 r
.33539 .70325 m .34367 .70077 L .34626 .70306 L p F P
0 g
s
.65 .757 .928 r
.34367 .70077 m .33539 .70325 L .33278 .70095 L p F P
0 g
s
.65 .758 .928 r
.60148 .70329 m .61019 .7008 L .61239 .7031 L p F P
0 g
s
.65 .758 .928 r
.61019 .7008 m .60148 .70329 L .59927 .701 L p F P
0 g
s
.65 .758 .928 r
.46843 .70329 m .47693 .70081 L .47932 .7031 L p F P
0 g
s
.65 .758 .928 r
.47693 .70081 m .46843 .70329 L .46602 .701 L p F P
0 g
s
.651 .758 .928 r
.74544 .70303 m .75439 .70054 L .75637 .70283 L p F P
0 g
s
.651 .758 .928 r
.75439 .70054 m .74544 .70303 L .74345 .70074 L p F P
0 g
s
.65 .757 .928 r
.34626 .70306 m .35456 .70058 L .35714 .70288 L p F P
0 g
s
.65 .757 .928 r
.35456 .70058 m .34626 .70306 L .34367 .70077 L p F P
0 g
s
.65 .758 .928 r
.61239 .7031 m .62111 .70061 L .62329 .7029 L p F P
0 g
s
.65 .758 .928 r
.62111 .70061 m .61239 .7031 L .61019 .7008 L p F P
0 g
s
.65 .758 .928 r
.47932 .7031 m .48783 .70062 L .49021 .70291 L p F P
0 g
s
.65 .758 .928 r
.48783 .70062 m .47932 .7031 L .47693 .70081 L p F P
0 g
s
.651 .758 .928 r
.75637 .70283 m .76533 .70034 L .76729 .70263 L p F P
0 g
s
.651 .758 .928 r
.76533 .70034 m .75637 .70283 L .75439 .70054 L p F P
0 g
s
.65 .757 .928 r
.35714 .70288 m .36545 .7004 L .36801 .70269 L p F P
0 g
s
.65 .757 .928 r
.36545 .7004 m .35714 .70288 L .35456 .70058 L p F P
0 g
s
.65 .758 .928 r
.62329 .7029 m .63204 .70042 L .6342 .70271 L p F P
0 g
s
.65 .758 .928 r
.63204 .70042 m .62329 .7029 L .62111 .70061 L p F P
0 g
s
.65 .758 .928 r
.49021 .70291 m .49874 .70043 L .50111 .70272 L p F P
0 g
s
.65 .758 .928 r
.49874 .70043 m .49021 .70291 L .48783 .70062 L p F P
0 g
s
.651 .758 .928 r
.76729 .70263 m .77627 .70014 L .77822 .70243 L p F P
0 g
s
.651 .758 .928 r
.77627 .70014 m .76729 .70263 L .76533 .70034 L p F P
0 g
s
.65 .757 .928 r
.36801 .70269 m .37635 .70021 L .37889 .70251 L p F P
0 g
s
.65 .757 .928 r
.37635 .70021 m .36801 .70269 L .36545 .7004 L p F P
0 g
s
.65 .758 .928 r
.6342 .70271 m .64297 .70022 L .64511 .70252 L p F P
0 g
s
.65 .758 .928 r
.64297 .70022 m .6342 .70271 L .63204 .70042 L p F P
0 g
s
.65 .758 .928 r
.50111 .70272 m .50966 .70024 L .512 .70253 L p F P
0 g
s
.65 .758 .928 r
.50966 .70024 m .50111 .70272 L .49874 .70043 L p F P
0 g
s
.651 .758 .928 r
.77822 .70243 m .78722 .69993 L .78915 .70222 L p F P
0 g
s
.651 .758 .928 r
.78722 .69993 m .77822 .70243 L .77627 .70014 L p F P
0 g
s
.65 .757 .928 r
.37889 .70251 m .38724 .70002 L .38977 .70232 L p F P
0 g
s
.65 .757 .928 r
.38724 .70002 m .37889 .70251 L .37635 .70021 L p F P
0 g
s
.651 .758 .928 r
.64511 .70252 m .6539 .70003 L .65603 .70232 L p F P
0 g
s
.651 .758 .928 r
.6539 .70003 m .64511 .70252 L .64297 .70022 L p F P
0 g
s
.65 .758 .928 r
.512 .70253 m .52057 .70005 L .5229 .70234 L p F P
0 g
s
.65 .758 .928 r
.52057 .70005 m .512 .70253 L .50966 .70024 L p F P
0 g
s
.651 .758 .928 r
.78915 .70222 m .79817 .69972 L .80008 .70201 L p F P
0 g
s
.651 .758 .928 r
.79817 .69972 m .78915 .70222 L .78722 .69993 L p F P
0 g
s
.65 .758 .928 r
.38977 .70232 m .39814 .69984 L .40066 .70213 L p F P
0 g
s
.65 .757 .928 r
.39814 .69984 m .38977 .70232 L .38724 .70002 L p F P
0 g
s
.651 .758 .928 r
.65603 .70232 m .66483 .69983 L .66695 .70213 L p F P
0 g
s
.651 .758 .928 r
.66483 .69983 m .65603 .70232 L .6539 .70003 L p F P
0 g
s
.65 .758 .928 r
.5229 .70234 m .53149 .69986 L .5338 .70215 L p F P
0 g
s
.65 .758 .928 r
.53149 .69986 m .5229 .70234 L .52057 .70005 L p F P
0 g
s
.651 .758 .928 r
.80008 .70201 m .80912 .69952 L .81102 .70181 L p F P
0 g
s
.651 .758 .928 r
.80912 .69952 m .80008 .70201 L .79817 .69972 L p F P
0 g
s
.65 .757 .928 r
.26752 .70204 m .27569 .69956 L .27839 .70186 L p F P
0 g
s
.65 .757 .928 r
.27569 .69956 m .26752 .70204 L .26481 .69974 L p F P
0 g
s
0 0 .346 r
.52583 .40355 m .5258 .40362 L .5258 .39986 L p F P
0 g
s
0 0 .346 r
.5258 .39986 m .52583 .39978 L .52583 .40355 L p F P
0 g
s
.762 .5 .538 r
.52569 .4036 m .5258 .40362 L .5258 .39986 L p F P
0 g
s
.762 .5 .538 r
.5258 .39986 m .52569 .39984 L .52569 .4036 L p F P
0 g
s
.651 .758 .928 r
.66695 .70213 m .67577 .69964 L .67787 .70193 L p F P
0 g
s
.651 .758 .928 r
.67577 .69964 m .66695 .70213 L .66483 .69983 L p F P
0 g
s
.65 .758 .928 r
.40066 .70213 m .40905 .69965 L .41155 .70194 L p F P
0 g
s
.65 .758 .928 r
.40905 .69965 m .40066 .70213 L .39814 .69984 L p F P
0 g
s
0 0 .347 r
.52572 .39976 m .52569 .39984 L .52569 .4036 L p F P
0 g
s
.65 .758 .928 r
.5338 .70215 m .54241 .69966 L .54471 .70196 L p F P
0 g
s
.65 .758 .928 r
.54241 .69966 m .5338 .70215 L .53149 .69986 L p F P
0 g
s
.762 .501 .539 r
.52572 .39976 m .52583 .39978 L .52583 .40355 L p F P
0 g
s
.762 .501 .539 r
.52583 .40355 m .52572 .40353 L .52572 .39976 L p F P
0 g
s
0 0 .347 r
.52569 .4036 m .52572 .40353 L .52572 .39976 L p F P
0 g
s
.651 .758 .928 r
.81102 .70181 m .82007 .69931 L .82196 .70159 L p F P
0 g
s
.651 .758 .928 r
.82007 .69931 m .81102 .70181 L .80912 .69952 L p F P
0 g
s
.65 .757 .928 r
.27839 .70186 m .28658 .69938 L .28926 .70168 L p F P
0 g
s
.65 .757 .928 r
.28658 .69938 m .27839 .70186 L .27569 .69956 L p F P
0 g
s
.651 .758 .928 r
.67787 .70193 m .68671 .69944 L .68879 .70173 L p F P
0 g
s
.651 .758 .928 r
.68671 .69944 m .67787 .70193 L .67577 .69964 L p F P
0 g
s
.65 .758 .928 r
.41155 .70194 m .41995 .69946 L .42244 .70176 L p F P
0 g
s
.65 .758 .928 r
.41995 .69946 m .41155 .70194 L .40905 .69965 L p F P
0 g
s
.65 .758 .928 r
.54471 .70196 m .55333 .69947 L .55561 .70177 L p F P
0 g
s
.65 .758 .928 r
.55333 .69947 m .54471 .70196 L .54241 .69966 L p F P
0 g
s
.651 .759 .928 r
.82196 .70159 m .83103 .69909 L .8329 .70138 L p F P
0 g
s
.651 .759 .928 r
.83103 .69909 m .82196 .70159 L .82007 .69931 L p F P
0 g
s
.65 .757 .928 r
.28926 .70168 m .29747 .6992 L .30014 .7015 L p F P
0 g
s
.65 .757 .928 r
.29747 .6992 m .28926 .70168 L .28658 .69938 L p F P
0 g
s
.651 .758 .928 r
.69765 .69924 m .68879 .70173 L .68671 .69944 L p F P
0 g
s
.651 .758 .928 r
.68879 .70173 m .69765 .69924 L .69972 .70154 L p F P
0 g
s
.65 .758 .928 r
.42244 .70176 m .43086 .69927 L .43333 .70157 L p F P
0 g
s
.65 .758 .928 r
.43086 .69927 m .42244 .70176 L .41995 .69946 L p F P
0 g
s
.65 .758 .928 r
.55561 .70177 m .56426 .69928 L .56652 .70158 L p F P
0 g
s
.65 .758 .928 r
.56426 .69928 m .55561 .70177 L .55333 .69947 L p F P
0 g
s
.651 .759 .928 r
.8329 .70138 m .84199 .69888 L .84384 .70117 L p F P
0 g
s
.651 .759 .928 r
.84199 .69888 m .8329 .70138 L .83103 .69909 L p F P
0 g
s
.65 .757 .928 r
.30014 .7015 m .30837 .69902 L .31102 .70132 L p F P
0 g
s
.65 .757 .928 r
.30837 .69902 m .30014 .7015 L .29747 .6992 L p F P
0 g
s
.651 .758 .928 r
.69972 .70154 m .70859 .69905 L .71065 .70134 L p F P
0 g
s
.651 .758 .928 r
.70859 .69905 m .69972 .70154 L .69765 .69924 L p F P
0 g
s
.65 .758 .928 r
.43333 .70157 m .44177 .69908 L .44422 .70138 L p F P
0 g
s
.65 .758 .928 r
.44177 .69908 m .43333 .70157 L .43086 .69927 L p F P
0 g
s
.65 .758 .928 r
.56652 .70158 m .57519 .69909 L .57744 .70138 L p F P
0 g
s
.65 .758 .928 r
.57519 .69909 m .56652 .70158 L .56426 .69928 L p F P
0 g
s
.651 .759 .928 r
.84384 .70117 m .85295 .69866 L .85478 .70095 L p F P
0 g
s
.651 .759 .928 r
.85295 .69866 m .84384 .70117 L .84199 .69888 L p F P
0 g
s
.65 .757 .928 r
.31102 .70132 m .31927 .69884 L .3219 .70114 L p F P
0 g
s
.65 .757 .928 r
.31927 .69884 m .31102 .70132 L .30837 .69902 L p F P
0 g
s
.651 .758 .928 r
.71065 .70134 m .71954 .69885 L .72158 .70114 L p F P
0 g
s
.651 .758 .928 r
.71954 .69885 m .71065 .70134 L .70859 .69905 L p F P
0 g
s
.65 .758 .928 r
.44422 .70138 m .45269 .69889 L .45512 .70119 L p F P
0 g
s
.65 .758 .928 r
.45269 .69889 m .44422 .70138 L .44177 .69908 L p F P
0 g
s
.65 .758 .928 r
.57744 .70138 m .58612 .69889 L .58835 .70119 L p F P
0 g
s
.65 .758 .928 r
.58612 .69889 m .57744 .70138 L .57519 .69909 L p F P
0 g
s
.651 .759 .928 r
.86391 .69844 m .85478 .70095 L .85295 .69866 L p F P
0 g
s
.65 .757 .928 r
.3219 .70114 m .33017 .69865 L .33278 .70095 L p F P
0 g
s
.65 .757 .928 r
.33017 .69865 m .3219 .70114 L .31927 .69884 L p F P
0 g
s
.651 .758 .928 r
.72158 .70114 m .73049 .69865 L .73251 .70094 L p F P
0 g
s
.651 .758 .928 r
.73049 .69865 m .72158 .70114 L .71954 .69885 L p F P
0 g
s
.65 .758 .928 r
.45512 .70119 m .46361 .6987 L .46602 .701 L p F P
0 g
s
.65 .758 .928 r
.46361 .6987 m .45512 .70119 L .45269 .69889 L p F P
0 g
s
.65 .758 .928 r
.58835 .70119 m .59705 .6987 L .59927 .701 L p F P
0 g
s
.65 .758 .928 r
.59705 .6987 m .58835 .70119 L .58612 .69889 L p F P
0 g
s
.651 .758 .928 r
.73251 .70094 m .74144 .69845 L .74345 .70074 L p F P
0 g
s
.651 .758 .928 r
.74144 .69845 m .73251 .70094 L .73049 .69865 L p F P
0 g
s
.65 .757 .928 r
.33278 .70095 m .34107 .69847 L .34367 .70077 L p F P
0 g
s
.65 .757 .928 r
.34107 .69847 m .33278 .70095 L .33017 .69865 L p F P
0 g
s
.65 .758 .928 r
.59927 .701 m .60799 .69851 L .61019 .7008 L p F P
0 g
s
.65 .758 .928 r
.60799 .69851 m .59927 .701 L .59705 .6987 L p F P
0 g
s
.65 .758 .928 r
.46602 .701 m .47453 .69851 L .47693 .70081 L p F P
0 g
s
.65 .758 .928 r
.47453 .69851 m .46602 .701 L .46361 .6987 L p F P
0 g
s
.651 .758 .928 r
.74345 .70074 m .7524 .69825 L .75439 .70054 L p F P
0 g
s
.651 .758 .928 r
.7524 .69825 m .74345 .70074 L .74144 .69845 L p F P
0 g
s
.65 .757 .928 r
.34367 .70077 m .35197 .69828 L .35456 .70058 L p F P
0 g
s
.65 .757 .928 r
.35197 .69828 m .34367 .70077 L .34107 .69847 L p F P
0 g
s
.65 .758 .928 r
.61019 .7008 m .61893 .69831 L .62111 .70061 L p F P
0 g
s
.65 .758 .928 r
.61893 .69831 m .61019 .7008 L .60799 .69851 L p F P
0 g
s
.65 .758 .928 r
.47693 .70081 m .48545 .69832 L .48783 .70062 L p F P
0 g
s
.65 .758 .928 r
.48545 .69832 m .47693 .70081 L .47453 .69851 L p F P
0 g
s
.651 .758 .928 r
.75439 .70054 m .76336 .69804 L .76533 .70034 L p F P
0 g
s
.651 .758 .928 r
.76336 .69804 m .75439 .70054 L .7524 .69825 L p F P
0 g
s
.65 .757 .928 r
.35456 .70058 m .36288 .6981 L .36545 .7004 L p F P
0 g
s
.65 .757 .928 r
.36288 .6981 m .35456 .70058 L .35197 .69828 L p F P
0 g
s
.65 .758 .928 r
.62111 .70061 m .62987 .69812 L .63204 .70042 L p F P
0 g
s
.65 .758 .928 r
.62987 .69812 m .62111 .70061 L .61893 .69831 L p F P
0 g
s
.65 .758 .928 r
.48783 .70062 m .49637 .69813 L .49874 .70043 L p F P
0 g
s
.65 .758 .928 r
.49637 .69813 m .48783 .70062 L .48545 .69832 L p F P
0 g
s
.651 .758 .928 r
.76533 .70034 m .77432 .69784 L .77627 .70014 L p F P
0 g
s
.651 .758 .928 r
.77432 .69784 m .76533 .70034 L .76336 .69804 L p F P
0 g
s
.65 .757 .928 r
.36545 .7004 m .37379 .69791 L .37635 .70021 L p F P
0 g
s
.65 .757 .928 r
.37379 .69791 m .36545 .7004 L .36288 .6981 L p F P
0 g
s
.65 .758 .928 r
.63204 .70042 m .64081 .69792 L .64297 .70022 L p F P
0 g
s
.65 .758 .928 r
.64081 .69792 m .63204 .70042 L .62987 .69812 L p F P
0 g
s
.65 .758 .928 r
.49874 .70043 m .5073 .69794 L .50966 .70024 L p F P
0 g
s
.65 .758 .928 r
.5073 .69794 m .49874 .70043 L .49637 .69813 L p F P
0 g
s
.651 .758 .928 r
.77627 .70014 m .78528 .69763 L .78722 .69993 L p F P
0 g
s
.651 .758 .928 r
.78528 .69763 m .77627 .70014 L .77432 .69784 L p F P
0 g
s
0 0 .346 r
.52583 .40733 m .5258 .40739 L .5258 .40362 L p F P
0 g
s
0 0 .346 r
.5258 .40362 m .52583 .40355 L .52583 .40733 L p F P
0 g
s
.762 .5 .538 r
.52569 .40737 m .5258 .40739 L .5258 .40362 L p F P
0 g
s
.762 .5 .538 r
.5258 .40362 m .52569 .4036 L .52569 .40737 L p F P
0 g
s
.65 .757 .928 r
.37635 .70021 m .38471 .69772 L .38724 .70002 L p F P
0 g
s
.65 .757 .928 r
.38471 .69772 m .37635 .70021 L .37379 .69791 L p F P
0 g
s
.651 .758 .928 r
.64297 .70022 m .65176 .69773 L .6539 .70003 L p F P
0 g
s
.651 .758 .928 r
.65176 .69773 m .64297 .70022 L .64081 .69792 L p F P
0 g
s
0 0 .347 r
.52572 .40353 m .52569 .4036 L .52569 .40737 L p F P
0 g
s
.65 .758 .928 r
.50966 .70024 m .51823 .69775 L .52057 .70005 L p F P
0 g
s
.65 .758 .928 r
.51823 .69775 m .50966 .70024 L .5073 .69794 L p F P
0 g
s
.762 .501 .539 r
.52572 .40353 m .52583 .40355 L .52583 .40733 L p F P
0 g
s
.762 .501 .539 r
.52583 .40733 m .52572 .40731 L .52572 .40353 L p F P
0 g
s
0 0 .347 r
.52569 .40737 m .52572 .40731 L .52572 .40353 L p F P
0 g
s
.651 .758 .928 r
.78722 .69993 m .79624 .69743 L .79817 .69972 L p F P
0 g
s
.651 .758 .928 r
.79624 .69743 m .78722 .69993 L .78528 .69763 L p F P
0 g
s
.65 .757 .928 r
.38724 .70002 m .39562 .69753 L .39814 .69984 L p F P
0 g
s
.65 .757 .928 r
.39562 .69753 m .38724 .70002 L .38471 .69772 L p F P
0 g
s
.651 .758 .928 r
.6539 .70003 m .66271 .69753 L .66483 .69983 L p F P
0 g
s
.651 .758 .928 r
.66271 .69753 m .6539 .70003 L .65176 .69773 L p F P
0 g
s
.65 .758 .928 r
.52057 .70005 m .52917 .69755 L .53149 .69986 L p F P
0 g
s
.65 .758 .928 r
.52917 .69755 m .52057 .70005 L .51823 .69775 L p F P
0 g
s
.651 .758 .928 r
.79817 .69972 m .80721 .69722 L .80912 .69952 L p F P
0 g
s
.651 .758 .928 r
.80721 .69722 m .79817 .69972 L .79624 .69743 L p F P
0 g
s
.65 .757 .928 r
.26481 .69974 m .27299 .69726 L .27569 .69956 L p F P
0 g
s
.65 .757 .928 r
.27299 .69726 m .26481 .69974 L .26209 .69744 L p F P
0 g
s
.651 .758 .928 r
.66483 .69983 m .67366 .69734 L .67577 .69964 L p F P
0 g
s
.651 .758 .928 r
.67366 .69734 m .66483 .69983 L .66271 .69753 L p F P
0 g
s
.65 .758 .928 r
.39814 .69984 m .40654 .69735 L .40905 .69965 L p F P
0 g
s
.65 .757 .928 r
.40654 .69735 m .39814 .69984 L .39562 .69753 L p F P
0 g
s
.65 .758 .928 r
.53149 .69986 m .5401 .69736 L .54241 .69966 L p F P
0 g
s
.65 .758 .928 r
.5401 .69736 m .53149 .69986 L .52917 .69755 L p F P
0 g
s
.651 .758 .928 r
.80912 .69952 m .81818 .69701 L .82007 .69931 L p F P
0 g
s
.651 .758 .928 r
.81818 .69701 m .80912 .69952 L .80721 .69722 L p F P
0 g
s
.65 .757 .928 r
.27569 .69956 m .28389 .69708 L .28658 .69938 L p F P
0 g
s
.65 .757 .928 r
.28389 .69708 m .27569 .69956 L .27299 .69726 L p F P
0 g
s
.651 .758 .928 r
.67577 .69964 m .68462 .69714 L .68671 .69944 L p F P
0 g
s
.651 .758 .928 r
.68462 .69714 m .67577 .69964 L .67366 .69734 L p F P
0 g
s
.65 .758 .928 r
.40905 .69965 m .41747 .69716 L .41995 .69946 L p F P
0 g
s
.65 .758 .928 r
.41747 .69716 m .40905 .69965 L .40654 .69735 L p F P
0 g
s
.65 .758 .928 r
.54241 .69966 m .55104 .69717 L .55333 .69947 L p F P
0 g
s
.65 .758 .928 r
.55104 .69717 m .54241 .69966 L .5401 .69736 L p F P
0 g
s
.651 .759 .928 r
.82007 .69931 m .82915 .6968 L .83103 .69909 L p F P
0 g
s
.651 .758 .928 r
.82915 .6968 m .82007 .69931 L .81818 .69701 L p F P
0 g
s
.65 .757 .928 r
.28658 .69938 m .2948 .6969 L .29747 .6992 L p F P
0 g
s
.65 .757 .928 r
.2948 .6969 m .28658 .69938 L .28389 .69708 L p F P
0 g
s
.651 .758 .928 r
.68671 .69944 m .69558 .69694 L .69765 .69924 L p F P
0 g
s
.651 .758 .928 r
.69558 .69694 m .68671 .69944 L .68462 .69714 L p F P
0 g
s
.65 .758 .928 r
.41995 .69946 m .42839 .69697 L .43086 .69927 L p F P
0 g
s
.65 .758 .928 r
.42839 .69697 m .41995 .69946 L .41747 .69716 L p F P
0 g
s
.65 .758 .928 r
.55333 .69947 m .56198 .69698 L .56426 .69928 L p F P
0 g
s
.65 .758 .928 r
.56198 .69698 m .55333 .69947 L .55104 .69717 L p F P
0 g
s
.651 .759 .928 r
.83103 .69909 m .84013 .69658 L .84199 .69888 L p F P
0 g
s
.651 .759 .928 r
.84013 .69658 m .83103 .69909 L .82915 .6968 L p F P
0 g
s
.65 .757 .928 r
.29747 .6992 m .30571 .69672 L .30837 .69902 L p F P
0 g
s
.65 .757 .928 r
.30571 .69672 m .29747 .6992 L .2948 .6969 L p F P
0 g
s
.651 .758 .928 r
.70654 .69674 m .69765 .69924 L .69558 .69694 L p F P
0 g
s
.651 .758 .928 r
.69765 .69924 m .70654 .69674 L .70859 .69905 L p F P
0 g
s
.65 .758 .928 r
.43086 .69927 m .43932 .69678 L .44177 .69908 L p F P
0 g
s
.65 .758 .928 r
.43932 .69678 m .43086 .69927 L .42839 .69697 L p F P
0 g
s
.65 .758 .928 r
.56426 .69928 m .57293 .69678 L .57519 .69909 L p F P
0 g
s
.65 .758 .928 r
.57293 .69678 m .56426 .69928 L .56198 .69698 L p F P
0 g
s
.651 .759 .928 r
.84199 .69888 m .85111 .69637 L .85295 .69866 L p F P
0 g
s
.651 .759 .928 r
.85111 .69637 m .84199 .69888 L .84013 .69658 L p F P
0 g
s
.65 .757 .928 r
.30837 .69902 m .31662 .69653 L .31927 .69884 L p F P
0 g
s
.65 .757 .928 r
.31662 .69653 m .30837 .69902 L .30571 .69672 L p F P
0 g
s
.651 .758 .928 r
.70859 .69905 m .7175 .69654 L .71954 .69885 L p F P
0 g
s
.651 .758 .928 r
.7175 .69654 m .70859 .69905 L .70654 .69674 L p F P
0 g
s
.65 .758 .928 r
.44177 .69908 m .45025 .69659 L .45269 .69889 L p F P
0 g
s
.65 .758 .928 r
.45025 .69659 m .44177 .69908 L .43932 .69678 L p F P
0 g
s
.65 .758 .928 r
.57519 .69909 m .58388 .69659 L .58612 .69889 L p F P
0 g
s
.65 .758 .928 r
.58388 .69659 m .57519 .69909 L .57293 .69678 L p F P
0 g
s
.651 .759 .928 r
.85295 .69866 m .86209 .69615 L .86391 .69844 L p F P
0 g
s
.651 .759 .928 r
.86209 .69615 m .85295 .69866 L .85111 .69637 L p F P
0 g
s
.65 .757 .928 r
.31927 .69884 m .32754 .69635 L .33017 .69865 L p F P
0 g
s
.65 .757 .928 r
.32754 .69635 m .31927 .69884 L .31662 .69653 L p F P
0 g
s
.651 .758 .928 r
.72847 .69634 m .71954 .69885 L .7175 .69654 L p F P
0 g
s
.651 .758 .928 r
.71954 .69885 m .72847 .69634 L .73049 .69865 L p F P
0 g
s
.65 .758 .928 r
.45269 .69889 m .46118 .6964 L .46361 .6987 L p F P
0 g
s
.65 .758 .928 r
.46118 .6964 m .45269 .69889 L .45025 .69659 L p F P
0 g
s
.65 .758 .928 r
.58612 .69889 m .59482 .69639 L .59705 .6987 L p F P
0 g
s
.65 .758 .928 r
.59482 .69639 m .58612 .69889 L .58388 .69659 L p F P
0 g
s
.651 .759 .928 r
.87307 .69592 m .86391 .69844 L .86209 .69615 L p F P
0 g
s
.651 .758 .928 r
.73049 .69865 m .73943 .69614 L .74144 .69845 L p F P
0 g
s
.651 .758 .928 r
.73943 .69614 m .73049 .69865 L .72847 .69634 L p F P
0 g
s
.65 .757 .928 r
.33017 .69865 m .33846 .69616 L .34107 .69847 L p F P
0 g
s
.65 .757 .928 r
.33846 .69616 m .33017 .69865 L .32754 .69635 L p F P
0 g
s
.65 .758 .928 r
.59705 .6987 m .60578 .6962 L .60799 .69851 L p F P
0 g
s
.65 .758 .928 r
.60578 .6962 m .59705 .6987 L .59482 .69639 L p F P
0 g
s
.65 .758 .928 r
.46361 .6987 m .47212 .6962 L .47453 .69851 L p F P
0 g
s
.65 .758 .928 r
.47212 .6962 m .46361 .6987 L .46118 .6964 L p F P
0 g
s
.651 .758 .928 r
.74144 .69845 m .7504 .69594 L .7524 .69825 L p F P
0 g
s
.651 .758 .928 r
.7504 .69594 m .74144 .69845 L .73943 .69614 L p F P
0 g
s
.65 .757 .928 r
.34107 .69847 m .34938 .69598 L .35197 .69828 L p F P
0 g
s
.65 .757 .928 r
.34938 .69598 m .34107 .69847 L .33846 .69616 L p F P
0 g
s
.65 .758 .928 r
.60799 .69851 m .61673 .69601 L .61893 .69831 L p F P
0 g
s
.65 .758 .928 r
.61673 .69601 m .60799 .69851 L .60578 .6962 L p F P
0 g
s
.65 .758 .928 r
.47453 .69851 m .48306 .69601 L .48545 .69832 L p F P
0 g
s
.65 .758 .928 r
.48306 .69601 m .47453 .69851 L .47212 .6962 L p F P
0 g
s
.651 .758 .928 r
.7524 .69825 m .76138 .69574 L .76336 .69804 L p F P
0 g
s
.651 .758 .928 r
.76138 .69574 m .7524 .69825 L .7504 .69594 L p F P
0 g
s
0 0 .346 r
.52582 .41111 m .52579 .41117 L .5258 .40739 L p F P
0 g
s
0 0 .346 r
.5258 .40739 m .52583 .40733 L .52582 .41111 L p F P
0 g
s
.762 .5 .538 r
.5257 .41116 m .52579 .41117 L .5258 .40739 L p F P
0 g
s
.762 .5 .538 r
.5258 .40739 m .52569 .40737 L .5257 .41116 L p F P
0 g
s
.65 .757 .928 r
.35197 .69828 m .36031 .69579 L .36288 .6981 L p F P
0 g
s
.65 .757 .928 r
.36031 .69579 m .35197 .69828 L .34938 .69598 L p F P
0 g
s
.65 .758 .928 r
.61893 .69831 m .62769 .69581 L .62987 .69812 L p F P
0 g
s
.65 .758 .928 r
.62769 .69581 m .61893 .69831 L .61673 .69601 L p F P
0 g
s
0 0 .347 r
.52572 .40731 m .52569 .40737 L .5257 .41116 L p F P
0 g
s
.65 .758 .928 r
.48545 .69832 m .494 .69582 L .49637 .69813 L p F P
0 g
s
.65 .758 .928 r
.494 .69582 m .48545 .69832 L .48306 .69601 L p F P
0 g
s
.762 .501 .539 r
.52572 .40731 m .52583 .40733 L .52582 .41111 L p F P
0 g
s
.762 .501 .539 r
.52582 .41111 m .52573 .41109 L .52572 .40731 L p F P
0 g
s
0 0 .347 r
.5257 .41116 m .52573 .41109 L .52572 .40731 L p F P
0 g
s
.651 .758 .928 r
.76336 .69804 m .77236 .69554 L .77432 .69784 L p F P
0 g
s
.651 .758 .928 r
.77236 .69554 m .76336 .69804 L .76138 .69574 L p F P
0 g
s
.65 .757 .928 r
.36288 .6981 m .37123 .6956 L .37379 .69791 L p F P
0 g
s
.65 .757 .928 r
.37123 .6956 m .36288 .6981 L .36031 .69579 L p F P
0 g
s
.65 .758 .928 r
.62987 .69812 m .63865 .69562 L .64081 .69792 L p F P
0 g
s
.65 .758 .928 r
.63865 .69562 m .62987 .69812 L .62769 .69581 L p F P
0 g
s
.65 .758 .928 r
.49637 .69813 m .50494 .69563 L .5073 .69794 L p F P
0 g
s
.65 .758 .928 r
.50494 .69563 m .49637 .69813 L .494 .69582 L p F P
0 g
s
.651 .758 .928 r
.77432 .69784 m .78333 .69533 L .78528 .69763 L p F P
0 g
s
.651 .758 .928 r
.78333 .69533 m .77432 .69784 L .77236 .69554 L p F P
0 g
s
.65 .757 .928 r
.37379 .69791 m .38216 .69541 L .38471 .69772 L p F P
0 g
s
.65 .757 .928 r
.38216 .69541 m .37379 .69791 L .37123 .6956 L p F P
0 g
s
.651 .758 .928 r
.64081 .69792 m .64961 .69542 L .65176 .69773 L p F P
0 g
s
.651 .758 .928 r
.64961 .69542 m .64081 .69792 L .63865 .69562 L p F P
0 g
s
.65 .758 .928 r
.5073 .69794 m .51589 .69544 L .51823 .69775 L p F P
0 g
s
.65 .758 .928 r
.51589 .69544 m .5073 .69794 L .50494 .69563 L p F P
0 g
s
.651 .758 .928 r
.78528 .69763 m .79432 .69512 L .79624 .69743 L p F P
0 g
s
.651 .758 .928 r
.79432 .69512 m .78528 .69763 L .78333 .69533 L p F P
0 g
s
.65 .757 .928 r
.38471 .69772 m .3931 .69522 L .39562 .69753 L p F P
0 g
s
.65 .757 .928 r
.3931 .69522 m .38471 .69772 L .38216 .69541 L p F P
0 g
s
.651 .758 .928 r
.65176 .69773 m .66058 .69522 L .66271 .69753 L p F P
0 g
s
.651 .758 .928 r
.66058 .69522 m .65176 .69773 L .64961 .69542 L p F P
0 g
s
.65 .758 .928 r
.51823 .69775 m .52684 .69524 L .52917 .69755 L p F P
0 g
s
.65 .758 .928 r
.52684 .69524 m .51823 .69775 L .51589 .69544 L p F P
0 g
s
.651 .758 .928 r
.79624 .69743 m .8053 .69492 L .80721 .69722 L p F P
0 g
s
.651 .758 .928 r
.8053 .69492 m .79624 .69743 L .79432 .69512 L p F P
0 g
s
.65 .757 .928 r
.26209 .69744 m .27028 .69495 L .27299 .69726 L p F P
0 g
s
.65 .757 .928 r
.27028 .69495 m .26209 .69744 L .25936 .69513 L p F P
0 g
s
.651 .758 .928 r
.66271 .69753 m .67155 .69503 L .67366 .69734 L p F P
0 g
s
.651 .758 .928 r
.67155 .69503 m .66271 .69753 L .66058 .69522 L p F P
0 g
s
.65 .757 .928 r
.39562 .69753 m .40403 .69504 L .40654 .69735 L p F P
0 g
s
.65 .757 .928 r
.40403 .69504 m .39562 .69753 L .3931 .69522 L p F P
0 g
s
.65 .758 .928 r
.52917 .69755 m .53779 .69505 L .5401 .69736 L p F P
0 g
s
.65 .758 .928 r
.53779 .69505 m .52917 .69755 L .52684 .69524 L p F P
0 g
s
.651 .758 .928 r
.80721 .69722 m .81629 .69471 L .81818 .69701 L p F P
0 g
s
.651 .758 .928 r
.81629 .69471 m .80721 .69722 L .8053 .69492 L p F P
0 g
s
.65 .757 .928 r
.27299 .69726 m .2812 .69477 L .28389 .69708 L p F P
0 g
s
.65 .757 .928 r
.2812 .69477 m .27299 .69726 L .27028 .69495 L p F P
0 g
s
.651 .758 .928 r
.67366 .69734 m .68252 .69483 L .68462 .69714 L p F P
0 g
s
.651 .758 .928 r
.68252 .69483 m .67366 .69734 L .67155 .69503 L p F P
0 g
s
.65 .758 .928 r
.40654 .69735 m .41497 .69485 L .41747 .69716 L p F P
0 g
s
.65 .758 .928 r
.41497 .69485 m .40654 .69735 L .40403 .69504 L p F P
0 g
s
.65 .758 .928 r
.5401 .69736 m .54875 .69486 L .55104 .69717 L p F P
0 g
s
.65 .758 .928 r
.54875 .69486 m .5401 .69736 L .53779 .69505 L p F P
0 g
s
.651 .758 .928 r
.81818 .69701 m .82728 .69449 L .82915 .6968 L p F P
0 g
s
.651 .758 .928 r
.82728 .69449 m .81818 .69701 L .81629 .69471 L p F P
0 g
s
.65 .757 .928 r
.28389 .69708 m .29212 .69459 L .2948 .6969 L p F P
0 g
s
.65 .757 .928 r
.29212 .69459 m .28389 .69708 L .2812 .69477 L p F P
0 g
s
.651 .758 .928 r
.68462 .69714 m .6935 .69463 L .69558 .69694 L p F P
0 g
s
.651 .758 .928 r
.6935 .69463 m .68462 .69714 L .68252 .69483 L p F P
0 g
s
.65 .758 .928 r
.41747 .69716 m .42591 .69466 L .42839 .69697 L p F P
0 g
s
.65 .758 .928 r
.42591 .69466 m .41747 .69716 L .41497 .69485 L p F P
0 g
s
.65 .758 .928 r
.55104 .69717 m .5597 .69467 L .56198 .69698 L p F P
0 g
s
.65 .758 .928 r
.5597 .69467 m .55104 .69717 L .54875 .69486 L p F P
0 g
s
.651 .759 .928 r
.82915 .6968 m .83827 .69428 L .84013 .69658 L p F P
0 g
s
.651 .759 .928 r
.83827 .69428 m .82915 .6968 L .82728 .69449 L p F P
0 g
s
.65 .757 .928 r
.2948 .6969 m .30305 .6944 L .30571 .69672 L p F P
0 g
s
.65 .757 .928 r
.30305 .6944 m .2948 .6969 L .29212 .69459 L p F P
0 g
s
.651 .758 .928 r
.69558 .69694 m .70447 .69443 L .70654 .69674 L p F P
0 g
s
.651 .758 .928 r
.70447 .69443 m .69558 .69694 L .6935 .69463 L p F P
0 g
s
.65 .758 .928 r
.42839 .69697 m .43685 .69447 L .43932 .69678 L p F P
0 g
s
.65 .758 .928 r
.43685 .69447 m .42839 .69697 L .42591 .69466 L p F P
0 g
s
.65 .758 .928 r
.56198 .69698 m .57066 .69447 L .57293 .69678 L p F P
0 g
s
.65 .758 .928 r
.57066 .69447 m .56198 .69698 L .5597 .69467 L p F P
0 g
s
.651 .759 .928 r
.84013 .69658 m .84926 .69406 L .85111 .69637 L p F P
0 g
s
.651 .759 .928 r
.84926 .69406 m .84013 .69658 L .83827 .69428 L p F P
0 g
s
.65 .757 .928 r
.30571 .69672 m .31398 .69422 L .31662 .69653 L p F P
0 g
s
.65 .757 .928 r
.31398 .69422 m .30571 .69672 L .30305 .6944 L p F P
0 g
s
.651 .758 .928 r
.70654 .69674 m .71545 .69423 L .7175 .69654 L p F P
0 g
s
.651 .758 .928 r
.71545 .69423 m .70654 .69674 L .70447 .69443 L p F P
0 g
s
.65 .758 .928 r
.43932 .69678 m .4478 .69427 L .45025 .69659 L p F P
0 g
s
.65 .758 .928 r
.4478 .69427 m .43932 .69678 L .43685 .69447 L p F P
0 g
s
.65 .758 .928 r
.57293 .69678 m .58163 .69428 L .58388 .69659 L p F P
0 g
s
.65 .758 .928 r
.58163 .69428 m .57293 .69678 L .57066 .69447 L p F P
0 g
s
.651 .759 .928 r
.85111 .69637 m .86026 .69384 L .86209 .69615 L p F P
0 g
s
.651 .759 .928 r
.86026 .69384 m .85111 .69637 L .84926 .69406 L p F P
0 g
s
.65 .757 .928 r
.31662 .69653 m .32491 .69403 L .32754 .69635 L p F P
0 g
s
.65 .757 .928 r
.32491 .69403 m .31662 .69653 L .31398 .69422 L p F P
0 g
s
.651 .758 .928 r
.7175 .69654 m .72643 .69404 L .72847 .69634 L p F P
0 g
s
.651 .758 .928 r
.72643 .69404 m .7175 .69654 L .71545 .69423 L p F P
0 g
s
.65 .758 .928 r
.45025 .69659 m .45875 .69408 L .46118 .6964 L p F P
0 g
s
.65 .758 .928 r
.45875 .69408 m .45025 .69659 L .4478 .69427 L p F P
0 g
s
.65 .758 .928 r
.58388 .69659 m .59259 .69408 L .59482 .69639 L p F P
0 g
s
.65 .758 .928 r
.59259 .69408 m .58388 .69659 L .58163 .69428 L p F P
0 g
s
.651 .759 .928 r
.86209 .69615 m .87125 .69362 L .87307 .69592 L p F P
0 g
s
.651 .759 .928 r
.87125 .69362 m .86209 .69615 L .86026 .69384 L p F P
0 g
s
.651 .758 .928 r
.73742 .69383 m .72847 .69634 L .72643 .69404 L p F P
0 g
s
.651 .758 .928 r
.72847 .69634 m .73742 .69383 L .73943 .69614 L p F P
0 g
s
.65 .757 .928 r
.32754 .69635 m .33584 .69385 L .33846 .69616 L p F P
0 g
s
.65 .757 .928 r
.33584 .69385 m .32754 .69635 L .32491 .69403 L p F P
0 g
s
0 0 .346 r
.52582 .41491 m .52579 .41497 L .52579 .41117 L p F P
0 g
s
0 0 .346 r
.52579 .41117 m .52582 .41111 L .52582 .41491 L p F P
0 g
s
.762 .5 .538 r
.5257 .41495 m .52579 .41497 L .52579 .41117 L p F P
0 g
s
.762 .5 .538 r
.52579 .41117 m .5257 .41116 L .5257 .41495 L p F P
0 g
s
0 0 .347 r
.52573 .41109 m .5257 .41116 L .5257 .41495 L p F P
0 g
s
.65 .758 .928 r
.59482 .69639 m .60356 .69389 L .60578 .6962 L p F P
0 g
s
.65 .758 .928 r
.60356 .69389 m .59482 .69639 L .59259 .69408 L p F P
0 g
s
.65 .758 .928 r
.4697 .69389 m .46118 .6964 L .45875 .69408 L p F P
0 g
s
.65 .758 .928 r
.46118 .6964 m .4697 .69389 L .47212 .6962 L p F P
0 g
s
.762 .501 .539 r
.52573 .41109 m .52582 .41111 L .52582 .41491 L p F P
0 g
s
.762 .501 .539 r
.52582 .41491 m .52573 .41489 L .52573 .41109 L p F P
0 g
s
0 0 .347 r
.5257 .41495 m .52573 .41489 L .52573 .41109 L p F P
0 g
s
.651 .759 .928 r
.88225 .69339 m .87307 .69592 L .87125 .69362 L p F P
0 g
s
.651 .758 .928 r
.73943 .69614 m .74841 .69363 L .7504 .69594 L p F P
0 g
s
.651 .758 .928 r
.74841 .69363 m .73943 .69614 L .73742 .69383 L p F P
0 g
s
.65 .757 .928 r
.33846 .69616 m .34678 .69366 L .34938 .69598 L p F P
0 g
s
.65 .757 .928 r
.34678 .69366 m .33846 .69616 L .33584 .69385 L p F P
0 g
s
.65 .758 .928 r
.60578 .6962 m .61453 .69369 L .61673 .69601 L p F P
0 g
s
.65 .758 .928 r
.61453 .69369 m .60578 .6962 L .60356 .69389 L p F P
0 g
s
.65 .758 .928 r
.47212 .6962 m .48066 .6937 L .48306 .69601 L p F P
0 g
s
.65 .758 .928 r
.48066 .6937 m .47212 .6962 L .4697 .69389 L p F P
0 g
s
.651 .758 .928 r
.7504 .69594 m .7594 .69343 L .76138 .69574 L p F P
0 g
s
.651 .758 .928 r
.7594 .69343 m .7504 .69594 L .74841 .69363 L p F P
0 g
s
.65 .757 .928 r
.34938 .69598 m .35772 .69347 L .36031 .69579 L p F P
0 g
s
.65 .757 .928 r
.35772 .69347 m .34938 .69598 L .34678 .69366 L p F P
0 g
s
.65 .758 .928 r
.61673 .69601 m .62551 .6935 L .62769 .69581 L p F P
0 g
s
.65 .758 .928 r
.62551 .6935 m .61673 .69601 L .61453 .69369 L p F P
0 g
s
.65 .758 .928 r
.48306 .69601 m .49161 .69351 L .494 .69582 L p F P
0 g
s
.65 .758 .928 r
.49161 .69351 m .48306 .69601 L .48066 .6937 L p F P
0 g
s
.651 .758 .928 r
.76138 .69574 m .77039 .69323 L .77236 .69554 L p F P
0 g
s
.651 .758 .928 r
.77039 .69323 m .76138 .69574 L .7594 .69343 L p F P
0 g
s
.65 .757 .928 r
.36031 .69579 m .36866 .69329 L .37123 .6956 L p F P
0 g
s
.65 .757 .928 r
.36866 .69329 m .36031 .69579 L .35772 .69347 L p F P
0 g
s
.65 .758 .928 r
.62769 .69581 m .63648 .6933 L .63865 .69562 L p F P
0 g
s
.65 .758 .928 r
.63648 .6933 m .62769 .69581 L .62551 .6935 L p F P
0 g
s
.65 .758 .928 r
.494 .69582 m .50257 .69331 L .50494 .69563 L p F P
0 g
s
.65 .758 .928 r
.50257 .69331 m .494 .69582 L .49161 .69351 L p F P
0 g
s
.651 .758 .928 r
.77236 .69554 m .78138 .69302 L .78333 .69533 L p F P
0 g
s
.651 .758 .928 r
.78138 .69302 m .77236 .69554 L .77039 .69323 L p F P
0 g
s
.65 .757 .928 r
.37123 .6956 m .37961 .6931 L .38216 .69541 L p F P
0 g
s
.65 .757 .928 r
.37961 .6931 m .37123 .6956 L .36866 .69329 L p F P
0 g
s
.651 .758 .928 r
.63865 .69562 m .64746 .69311 L .64961 .69542 L p F P
0 g
s
.651 .758 .928 r
.64746 .69311 m .63865 .69562 L .63648 .6933 L p F P
0 g
s
.65 .758 .928 r
.50494 .69563 m .51354 .69312 L .51589 .69544 L p F P
0 g
s
.65 .758 .928 r
.51354 .69312 m .50494 .69563 L .50257 .69331 L p F P
0 g
s
.651 .758 .928 r
.78333 .69533 m .79238 .69281 L .79432 .69512 L p F P
0 g
s
.651 .758 .928 r
.79238 .69281 m .78333 .69533 L .78138 .69302 L p F P
0 g
s
.65 .757 .928 r
.38216 .69541 m .39056 .69291 L .3931 .69522 L p F P
0 g
s
.65 .757 .928 r
.39056 .69291 m .38216 .69541 L .37961 .6931 L p F P
0 g
s
.651 .758 .928 r
.64961 .69542 m .65845 .69291 L .66058 .69522 L p F P
0 g
s
.651 .758 .928 r
.65845 .69291 m .64961 .69542 L .64746 .69311 L p F P
0 g
s
.65 .758 .928 r
.51589 .69544 m .5245 .69293 L .52684 .69524 L p F P
0 g
s
.65 .758 .928 r
.5245 .69293 m .51589 .69544 L .51354 .69312 L p F P
0 g
s
.651 .758 .928 r
.79432 .69512 m .80338 .69261 L .8053 .69492 L p F P
0 g
s
.651 .758 .928 r
.80338 .69261 m .79432 .69512 L .79238 .69281 L p F P
0 g
s
.65 .757 .928 r
.25936 .69513 m .26756 .69263 L .27028 .69495 L p F P
0 g
s
.65 .757 .928 r
.26756 .69263 m .25936 .69513 L .25662 .69281 L p F P
0 g
s
.651 .758 .928 r
.66058 .69522 m .66943 .69271 L .67155 .69503 L p F P
0 g
s
.651 .758 .928 r
.66943 .69271 m .66058 .69522 L .65845 .69291 L p F P
0 g
s
.65 .757 .928 r
.3931 .69522 m .40151 .69272 L .40403 .69504 L p F P
0 g
s
.65 .757 .928 r
.40151 .69272 m .3931 .69522 L .39056 .69291 L p F P
0 g
s
.65 .758 .928 r
.52684 .69524 m .53547 .69274 L .53779 .69505 L p F P
0 g
s
.65 .758 .928 r
.53547 .69274 m .52684 .69524 L .5245 .69293 L p F P
0 g
s
.651 .758 .928 r
.8053 .69492 m .81438 .6924 L .81629 .69471 L p F P
0 g
s
.651 .758 .928 r
.81438 .6924 m .8053 .69492 L .80338 .69261 L p F P
0 g
s
.65 .757 .928 r
.27028 .69495 m .27849 .69245 L .2812 .69477 L p F P
0 g
s
.65 .757 .928 r
.27849 .69245 m .27028 .69495 L .26756 .69263 L p F P
0 g
s
.651 .758 .928 r
.67155 .69503 m .68042 .69251 L .68252 .69483 L p F P
0 g
s
.651 .758 .928 r
.68042 .69251 m .67155 .69503 L .66943 .69271 L p F P
0 g
s
.65 .758 .928 r
.40403 .69504 m .41246 .69253 L .41497 .69485 L p F P
0 g
s
.65 .757 .928 r
.41246 .69253 m .40403 .69504 L .40151 .69272 L p F P
0 g
s
.65 .758 .928 r
.53779 .69505 m .54644 .69254 L .54875 .69486 L p F P
0 g
s
.65 .758 .928 r
.54644 .69254 m .53779 .69505 L .53547 .69274 L p F P
0 g
s
.651 .758 .928 r
.81629 .69471 m .82539 .69218 L .82728 .69449 L p F P
0 g
s
.651 .758 .928 r
.82539 .69218 m .81629 .69471 L .81438 .6924 L p F P
0 g
s
.65 .757 .928 r
.2812 .69477 m .28943 .69227 L .29212 .69459 L p F P
0 g
s
.65 .757 .928 r
.28943 .69227 m .2812 .69477 L .27849 .69245 L p F P
0 g
s
.651 .758 .928 r
.68252 .69483 m .69141 .69232 L .6935 .69463 L p F P
0 g
s
.651 .758 .928 r
.69141 .69232 m .68252 .69483 L .68042 .69251 L p F P
0 g
s
.65 .758 .928 r
.41497 .69485 m .42342 .69234 L .42591 .69466 L p F P
0 g
s
.65 .758 .928 r
.42342 .69234 m .41497 .69485 L .41246 .69253 L p F P
0 g
s
.65 .758 .928 r
.54875 .69486 m .55742 .69235 L .5597 .69467 L p F P
0 g
s
.65 .758 .928 r
.55742 .69235 m .54875 .69486 L .54644 .69254 L p F P
0 g
s
.651 .759 .928 r
.82728 .69449 m .8364 .69197 L .83827 .69428 L p F P
0 g
s
.651 .758 .928 r
.8364 .69197 m .82728 .69449 L .82539 .69218 L p F P
0 g
s
.65 .757 .928 r
.29212 .69459 m .30037 .69208 L .30305 .6944 L p F P
0 g
s
.65 .757 .928 r
.30037 .69208 m .29212 .69459 L .28943 .69227 L p F P
0 g
s
.651 .758 .928 r
.6935 .69463 m .7024 .69212 L .70447 .69443 L p F P
0 g
s
.651 .758 .928 r
.7024 .69212 m .6935 .69463 L .69141 .69232 L p F P
0 g
s
.65 .758 .928 r
.42591 .69466 m .43438 .69215 L .43685 .69447 L p F P
0 g
s
.65 .758 .928 r
.43438 .69215 m .42591 .69466 L .42342 .69234 L p F P
0 g
s
.65 .758 .928 r
.5597 .69467 m .56839 .69215 L .57066 .69447 L p F P
0 g
s
.65 .758 .928 r
.56839 .69215 m .5597 .69467 L .55742 .69235 L p F P
0 g
s
.651 .759 .928 r
.83827 .69428 m .84741 .69175 L .84926 .69406 L p F P
0 g
s
.651 .759 .928 r
.84741 .69175 m .83827 .69428 L .8364 .69197 L p F P
0 g
s
.65 .757 .928 r
.30305 .6944 m .31132 .6919 L .31398 .69422 L p F P
0 g
s
.65 .757 .928 r
.31132 .6919 m .30305 .6944 L .30037 .69208 L p F P
0 g
s
.651 .758 .928 r
.70447 .69443 m .7134 .69192 L .71545 .69423 L p F P
0 g
s
.651 .758 .928 r
.7134 .69192 m .70447 .69443 L .7024 .69212 L p F P
0 g
s
0 0 .346 r
.52582 .41871 m .52579 .41877 L .52579 .41497 L p F P
0 g
s
0 0 .346 r
.52579 .41497 m .52582 .41491 L .52582 .41871 L p F P
0 g
s
.762 .5 .538 r
.5257 .41875 m .52579 .41877 L .52579 .41497 L p F P
0 g
s
.762 .5 .538 r
.52579 .41497 m .5257 .41495 L .5257 .41875 L p F P
0 g
s
.65 .758 .928 r
.43685 .69447 m .44534 .69196 L .4478 .69427 L p F P
0 g
s
.65 .758 .928 r
.44534 .69196 m .43685 .69447 L .43438 .69215 L p F P
0 g
s
0 0 .347 r
.52573 .41489 m .5257 .41495 L .5257 .41875 L p F P
0 g
s
.65 .758 .928 r
.57066 .69447 m .57937 .69196 L .58163 .69428 L p F P
0 g
s
.65 .758 .928 r
.57937 .69196 m .57066 .69447 L .56839 .69215 L p F P
0 g
s
.762 .501 .539 r
.52573 .41489 m .52582 .41491 L .52582 .41871 L p F P
0 g
s
.762 .501 .539 r
.52582 .41871 m .52573 .4187 L .52573 .41489 L p F P
0 g
s
0 0 .347 r
.5257 .41875 m .52573 .4187 L .52573 .41489 L p F P
0 g
s
.651 .759 .928 r
.84926 .69406 m .85842 .69153 L .86026 .69384 L p F P
0 g
s
.651 .759 .928 r
.85842 .69153 m .84926 .69406 L .84741 .69175 L p F P
0 g
s
.65 .757 .928 r
.31398 .69422 m .32227 .69171 L .32491 .69403 L p F P
0 g
s
.65 .757 .928 r
.32227 .69171 m .31398 .69422 L .31132 .6919 L p F P
0 g
s
.651 .758 .928 r
.7244 .69172 m .71545 .69423 L .7134 .69192 L p F P
0 g
s
.651 .758 .928 r
.71545 .69423 m .7244 .69172 L .72643 .69404 L p F P
0 g
s
.65 .758 .928 r
.4478 .69427 m .45631 .69176 L .45875 .69408 L p F P
0 g
s
.65 .758 .928 r
.45631 .69176 m .4478 .69427 L .44534 .69196 L p F P
0 g
s
.65 .758 .928 r
.58163 .69428 m .59035 .69176 L .59259 .69408 L p F P
0 g
s
.65 .758 .928 r
.59035 .69176 m .58163 .69428 L .57937 .69196 L p F P
0 g
s
.651 .759 .928 r
.86026 .69384 m .86944 .69131 L .87125 .69362 L p F P
0 g
s
.651 .759 .928 r
.86944 .69131 m .86026 .69384 L .85842 .69153 L p F P
0 g
s
.65 .757 .928 r
.32491 .69403 m .33322 .69153 L .33584 .69385 L p F P
0 g
s
.65 .757 .928 r
.33322 .69153 m .32491 .69403 L .32227 .69171 L p F P
0 g
s
.651 .758 .928 r
.72643 .69404 m .7354 .69152 L .73742 .69383 L p F P
0 g
s
.651 .758 .928 r
.7354 .69152 m .72643 .69404 L .7244 .69172 L p F P
0 g
s
.65 .758 .928 r
.45875 .69408 m .46728 .69157 L .4697 .69389 L p F P
0 g
s
.65 .758 .928 r
.46728 .69157 m .45875 .69408 L .45631 .69176 L p F P
0 g
s
.65 .758 .928 r
.59259 .69408 m .60134 .69157 L .60356 .69389 L p F P
0 g
s
.65 .758 .928 r
.60134 .69157 m .59259 .69408 L .59035 .69176 L p F P
0 g
s
.651 .759 .928 r
.87125 .69362 m .88045 .69108 L .88225 .69339 L p F P
0 g
s
.651 .759 .928 r
.88045 .69108 m .87125 .69362 L .86944 .69131 L p F P
0 g
s
.651 .758 .928 r
.73742 .69383 m .7464 .69131 L .74841 .69363 L p F P
0 g
s
.651 .758 .928 r
.7464 .69131 m .73742 .69383 L .7354 .69152 L p F P
0 g
s
.65 .757 .928 r
.33584 .69385 m .34417 .69134 L .34678 .69366 L p F P
0 g
s
.65 .757 .928 r
.34417 .69134 m .33584 .69385 L .33322 .69153 L p F P
0 g
s
.65 .758 .928 r
.60356 .69389 m .61233 .69137 L .61453 .69369 L p F P
0 g
s
.65 .758 .928 r
.61233 .69137 m .60356 .69389 L .60134 .69157 L p F P
0 g
s
.65 .758 .928 r
.4697 .69389 m .47825 .69138 L .48066 .6937 L p F P
0 g
s
.65 .758 .928 r
.47825 .69138 m .4697 .69389 L .46728 .69157 L p F P
0 g
s
.651 .759 .928 r
.89147 .69086 m .88225 .69339 L .88045 .69108 L p F P
0 g
s
.651 .758 .928 r
.74841 .69363 m .75741 .69111 L .7594 .69343 L p F P
0 g
s
.651 .758 .928 r
.75741 .69111 m .74841 .69363 L .7464 .69131 L p F P
0 g
s
.65 .757 .928 r
.34678 .69366 m .35513 .69115 L .35772 .69347 L p F P
0 g
s
.65 .757 .928 r
.35513 .69115 m .34678 .69366 L .34417 .69134 L p F P
0 g
s
.65 .758 .928 r
.61453 .69369 m .62332 .69118 L .62551 .6935 L p F P
0 g
s
.65 .758 .928 r
.62332 .69118 m .61453 .69369 L .61233 .69137 L p F P
0 g
s
.65 .758 .928 r
.48066 .6937 m .48922 .69119 L .49161 .69351 L p F P
0 g
s
.65 .758 .928 r
.48922 .69119 m .48066 .6937 L .47825 .69138 L p F P
0 g
s
.651 .758 .928 r
.7594 .69343 m .76842 .69091 L .77039 .69323 L p F P
0 g
s
.651 .758 .928 r
.76842 .69091 m .7594 .69343 L .75741 .69111 L p F P
0 g
s
.65 .757 .928 r
.35772 .69347 m .36609 .69096 L .36866 .69329 L p F P
0 g
s
.65 .757 .928 r
.36609 .69096 m .35772 .69347 L .35513 .69115 L p F P
0 g
s
.65 .758 .928 r
.62551 .6935 m .63431 .69098 L .63648 .6933 L p F P
0 g
s
.65 .758 .928 r
.63431 .69098 m .62551 .6935 L .62332 .69118 L p F P
0 g
s
.65 .758 .928 r
.49161 .69351 m .5002 .69099 L .50257 .69331 L p F P
0 g
s
.65 .758 .928 r
.5002 .69099 m .49161 .69351 L .48922 .69119 L p F P
0 g
s
.651 .758 .928 r
.77039 .69323 m .77943 .6907 L .78138 .69302 L p F P
0 g
s
.651 .758 .928 r
.77943 .6907 m .77039 .69323 L .76842 .69091 L p F P
0 g
s
.65 .757 .928 r
.36866 .69329 m .37705 .69077 L .37961 .6931 L p F P
0 g
s
.65 .757 .928 r
.37705 .69077 m .36866 .69329 L .36609 .69096 L p F P
0 g
s
.651 .758 .928 r
.63648 .6933 m .64531 .69078 L .64746 .69311 L p F P
0 g
s
.651 .758 .928 r
.64531 .69078 m .63648 .6933 L .63431 .69098 L p F P
0 g
s
.65 .758 .928 r
.50257 .69331 m .51118 .6908 L .51354 .69312 L p F P
0 g
s
.65 .758 .928 r
.51118 .6908 m .50257 .69331 L .5002 .69099 L p F P
0 g
s
.651 .758 .928 r
.78138 .69302 m .79044 .6905 L .79238 .69281 L p F P
0 g
s
.651 .758 .928 r
.79044 .6905 m .78138 .69302 L .77943 .6907 L p F P
0 g
s
.65 .757 .928 r
.37961 .6931 m .38801 .69059 L .39056 .69291 L p F P
0 g
s
.65 .757 .928 r
.38801 .69059 m .37961 .6931 L .37705 .69077 L p F P
0 g
s
.651 .758 .928 r
.64746 .69311 m .6563 .69059 L .65845 .69291 L p F P
0 g
s
.651 .758 .928 r
.6563 .69059 m .64746 .69311 L .64531 .69078 L p F P
0 g
s
.65 .758 .928 r
.51354 .69312 m .52216 .69061 L .5245 .69293 L p F P
0 g
s
.65 .758 .928 r
.52216 .69061 m .51354 .69312 L .51118 .6908 L p F P
0 g
s
.65 .757 .928 r
.25662 .69281 m .26483 .69031 L .26756 .69263 L p F P
0 g
s
.65 .757 .928 r
.26483 .69031 m .25662 .69281 L .25388 .69049 L p F P
0 g
s
.651 .758 .928 r
.79238 .69281 m .80146 .69029 L .80338 .69261 L p F P
0 g
s
.651 .758 .928 r
.80146 .69029 m .79238 .69281 L .79044 .6905 L p F P
0 g
s
.65 .757 .928 r
.39056 .69291 m .39898 .69039 L .40151 .69272 L p F P
0 g
s
.65 .757 .928 r
.39898 .69039 m .39056 .69291 L .38801 .69059 L p F P
0 g
s
.651 .758 .928 r
.65845 .69291 m .66731 .69039 L .66943 .69271 L p F P
0 g
s
.651 .758 .928 r
.66731 .69039 m .65845 .69291 L .6563 .69059 L p F P
0 g
s
.65 .758 .928 r
.5245 .69293 m .53314 .69041 L .53547 .69274 L p F P
0 g
s
.65 .758 .928 r
.53314 .69041 m .5245 .69293 L .52216 .69061 L p F P
0 g
s
.651 .758 .928 r
.80338 .69261 m .81248 .69008 L .81438 .6924 L p F P
0 g
s
.651 .758 .928 r
.81248 .69008 m .80338 .69261 L .80146 .69029 L p F P
0 g
s
.65 .757 .928 r
.26756 .69263 m .27578 .69013 L .27849 .69245 L p F P
0 g
s
.65 .757 .928 r
.27578 .69013 m .26756 .69263 L .26483 .69031 L p F P
0 g
s
.651 .758 .928 r
.66943 .69271 m .67831 .69019 L .68042 .69251 L p F P
0 g
s
.651 .758 .928 r
.67831 .69019 m .66943 .69271 L .66731 .69039 L p F P
0 g
s
.65 .757 .928 r
.40151 .69272 m .40995 .6902 L .41246 .69253 L p F P
0 g
s
.65 .757 .928 r
.40995 .6902 m .40151 .69272 L .39898 .69039 L p F P
0 g
s
.65 .758 .928 r
.53547 .69274 m .54413 .69022 L .54644 .69254 L p F P
0 g
s
.65 .758 .928 r
.54413 .69022 m .53547 .69274 L .53314 .69041 L p F P
0 g
s
.651 .758 .928 r
.81438 .6924 m .8235 .68987 L .82539 .69218 L p F P
0 g
s
.651 .758 .928 r
.8235 .68987 m .81438 .6924 L .81248 .69008 L p F P
0 g
s
.65 .757 .928 r
.27849 .69245 m .28674 .68994 L .28943 .69227 L p F P
0 g
s
.65 .757 .928 r
.28674 .68994 m .27849 .69245 L .27578 .69013 L p F P
0 g
s
0 0 .346 r
.52581 .42253 m .52579 .42258 L .52579 .41877 L p F P
0 g
s
0 0 .346 r
.52579 .41877 m .52582 .41871 L .52581 .42253 L p F P
0 g
s
.762 .5 .538 r
.52571 .42256 m .52579 .42258 L .52579 .41877 L p F P
0 g
s
.762 .5 .538 r
.52579 .41877 m .5257 .41875 L .52571 .42256 L p F P
0 g
s
.651 .758 .928 r
.68042 .69251 m .68932 .68999 L .69141 .69232 L p F P
0 g
s
.651 .758 .928 r
.68932 .68999 m .68042 .69251 L .67831 .69019 L p F P
0 g
s
.65 .758 .928 r
.41246 .69253 m .42093 .69001 L .42342 .69234 L p F P
0 g
s
.65 .757 .928 r
.42093 .69001 m .41246 .69253 L .40995 .6902 L p F P
0 g
s
0 0 .347 r
.52573 .4187 m .5257 .41875 L .52571 .42256 L p F P
0 g
s
.65 .758 .928 r
.54644 .69254 m .55512 .69002 L .55742 .69235 L p F P
0 g
s
.65 .758 .928 r
.55512 .69002 m .54644 .69254 L .54413 .69022 L p F P
0 g
s
.762 .501 .539 r
.52573 .4187 m .52582 .41871 L .52581 .42253 L p F P
0 g
s
.762 .501 .539 r
.52581 .42253 m .52573 .42251 L .52573 .4187 L p F P
0 g
s
0 0 .347 r
.52571 .42256 m .52573 .42251 L .52573 .4187 L p F P
0 g
s
.651 .758 .928 r
.82539 .69218 m .83452 .68965 L .8364 .69197 L p F P
0 g
s
.651 .758 .928 r
.83452 .68965 m .82539 .69218 L .8235 .68987 L p F P
0 g
s
.65 .757 .928 r
.28943 .69227 m .29769 .68976 L .30037 .69208 L p F P
0 g
s
.65 .757 .928 r
.29769 .68976 m .28943 .69227 L .28674 .68994 L p F P
0 g
s
.651 .758 .928 r
.69141 .69232 m .70033 .68979 L .7024 .69212 L p F P
0 g
s
.651 .758 .928 r
.70033 .68979 m .69141 .69232 L .68932 .68999 L p F P
0 g
s
.65 .758 .928 r
.42342 .69234 m .4319 .68982 L .43438 .69215 L p F P
0 g
s
.65 .758 .928 r
.4319 .68982 m .42342 .69234 L .42093 .69001 L p F P
0 g
s
.65 .758 .928 r
.55742 .69235 m .56611 .68983 L .56839 .69215 L p F P
0 g
s
.65 .758 .928 r
.56611 .68983 m .55742 .69235 L .55512 .69002 L p F P
0 g
s
.651 .759 .928 r
.8364 .69197 m .84555 .68944 L .84741 .69175 L p F P
0 g
s
.651 .759 .928 r
.84555 .68944 m .8364 .69197 L .83452 .68965 L p F P
0 g
s
.65 .757 .928 r
.30037 .69208 m .30866 .68957 L .31132 .6919 L p F P
0 g
s
.65 .757 .928 r
.30866 .68957 m .30037 .69208 L .29769 .68976 L p F P
0 g
s
.651 .758 .928 r
.7024 .69212 m .71134 .68959 L .7134 .69192 L p F P
0 g
s
.651 .758 .928 r
.71134 .68959 m .7024 .69212 L .70033 .68979 L p F P
0 g
s
.65 .758 .928 r
.43438 .69215 m .44288 .68963 L .44534 .69196 L p F P
0 g
s
.65 .758 .928 r
.44288 .68963 m .43438 .69215 L .4319 .68982 L p F P
0 g
s
.65 .758 .928 r
.56839 .69215 m .57711 .68963 L .57937 .69196 L p F P
0 g
s
.65 .758 .928 r
.57711 .68963 m .56839 .69215 L .56611 .68983 L p F P
0 g
s
.651 .759 .928 r
.84741 .69175 m .85658 .68922 L .85842 .69153 L p F P
0 g
s
.651 .759 .928 r
.85658 .68922 m .84741 .69175 L .84555 .68944 L p F P
0 g
s
.65 .757 .928 r
.31132 .6919 m .31962 .68939 L .32227 .69171 L p F P
0 g
s
.65 .757 .928 r
.31962 .68939 m .31132 .6919 L .30866 .68957 L p F P
0 g
s
.651 .758 .928 r
.7134 .69192 m .72235 .68939 L .7244 .69172 L p F P
0 g
s
.651 .758 .928 r
.72235 .68939 m .7134 .69192 L .71134 .68959 L p F P
0 g
s
.65 .758 .928 r
.44534 .69196 m .45386 .68944 L .45631 .69176 L p F P
0 g
s
.65 .758 .928 r
.45386 .68944 m .44534 .69196 L .44288 .68963 L p F P
0 g
s
.65 .758 .928 r
.57937 .69196 m .58811 .68944 L .59035 .69176 L p F P
0 g
s
.65 .758 .928 r
.58811 .68944 m .57937 .69196 L .57711 .68963 L p F P
0 g
s
.651 .759 .928 r
.85842 .69153 m .86761 .68899 L .86944 .69131 L p F P
0 g
s
.651 .759 .928 r
.86761 .68899 m .85842 .69153 L .85658 .68922 L p F P
0 g
s
.65 .757 .928 r
.32227 .69171 m .33059 .6892 L .33322 .69153 L p F P
0 g
s
.65 .757 .928 r
.33059 .6892 m .32227 .69171 L .31962 .68939 L p F P
0 g
s
.651 .758 .928 r
.73337 .68919 m .7244 .69172 L .72235 .68939 L p F P
0 g
s
.651 .758 .928 r
.7244 .69172 m .73337 .68919 L .7354 .69152 L p F P
0 g
s
.65 .758 .928 r
.45631 .69176 m .46485 .68924 L .46728 .69157 L p F P
0 g
s
.65 .758 .928 r
.46485 .68924 m .45631 .69176 L .45386 .68944 L p F P
0 g
s
.65 .758 .928 r
.59035 .69176 m .59911 .68924 L .60134 .69157 L p F P
0 g
s
.65 .758 .928 r
.59911 .68924 m .59035 .69176 L .58811 .68944 L p F P
0 g
s
.651 .759 .928 r
.86944 .69131 m .87864 .68877 L .88045 .69108 L p F P
0 g
s
.651 .759 .928 r
.87864 .68877 m .86944 .69131 L .86761 .68899 L p F P
0 g
s
.651 .758 .928 r
.7354 .69152 m .74439 .68899 L .7464 .69131 L p F P
0 g
s
.651 .758 .928 r
.74439 .68899 m .7354 .69152 L .73337 .68919 L p F P
0 g
s
.65 .757 .928 r
.33322 .69153 m .34156 .68901 L .34417 .69134 L p F P
0 g
s
.65 .757 .928 r
.34156 .68901 m .33322 .69153 L .33059 .6892 L p F P
0 g
s
.65 .758 .928 r
.60134 .69157 m .61011 .68905 L .61233 .69137 L p F P
0 g
s
.65 .758 .928 r
.61011 .68905 m .60134 .69157 L .59911 .68924 L p F P
0 g
s
.65 .758 .928 r
.46728 .69157 m .47583 .68905 L .47825 .69138 L p F P
0 g
s
.65 .758 .928 r
.47583 .68905 m .46728 .69157 L .46485 .68924 L p F P
0 g
s
.651 .759 .928 r
.88045 .69108 m .88968 .68854 L .89147 .69086 L p F P
0 g
s
.651 .759 .928 r
.88968 .68854 m .88045 .69108 L .87864 .68877 L p F P
0 g
s
.651 .758 .928 r
.75541 .68879 m .7464 .69131 L .74439 .68899 L p F P
0 g
s
.651 .758 .928 r
.7464 .69131 m .75541 .68879 L .75741 .69111 L p F P
0 g
s
.65 .757 .928 r
.34417 .69134 m .35253 .68882 L .35513 .69115 L p F P
0 g
s
.65 .757 .928 r
.35253 .68882 m .34417 .69134 L .34156 .68901 L p F P
0 g
s
.65 .758 .928 r
.61233 .69137 m .62112 .68885 L .62332 .69118 L p F P
0 g
s
.65 .758 .928 r
.62112 .68885 m .61233 .69137 L .61011 .68905 L p F P
0 g
s
.65 .758 .928 r
.48682 .68886 m .47825 .69138 L .47583 .68905 L p F P
0 g
s
.65 .758 .928 r
.47825 .69138 m .48682 .68886 L .48922 .69119 L p F P
0 g
s
.651 .759 .928 r
.90072 .68831 m .89147 .69086 L .88968 .68854 L p F P
0 g
s
.651 .758 .928 r
.75741 .69111 m .76644 .68858 L .76842 .69091 L p F P
0 g
s
.651 .758 .928 r
.76644 .68858 m .75741 .69111 L .75541 .68879 L p F P
0 g
s
.65 .757 .928 r
.35513 .69115 m .3635 .68863 L .36609 .69096 L p F P
0 g
s
.65 .757 .928 r
.3635 .68863 m .35513 .69115 L .35253 .68882 L p F P
0 g
s
.65 .758 .928 r
.62332 .69118 m .63213 .68865 L .63431 .69098 L p F P
0 g
s
.65 .758 .928 r
.63213 .68865 m .62332 .69118 L .62112 .68885 L p F P
0 g
s
.65 .758 .928 r
.48922 .69119 m .49782 .68866 L .5002 .69099 L p F P
0 g
s
.65 .758 .928 r
.49782 .68866 m .48922 .69119 L .48682 .68886 L p F P
0 g
s
.651 .758 .928 r
.76842 .69091 m .77747 .68838 L .77943 .6907 L p F P
0 g
s
.651 .758 .928 r
.77747 .68838 m .76842 .69091 L .76644 .68858 L p F P
0 g
s
.65 .757 .928 r
.36609 .69096 m .37448 .68845 L .37705 .69077 L p F P
0 g
s
.65 .757 .928 r
.37448 .68845 m .36609 .69096 L .3635 .68863 L p F P
0 g
s
.651 .758 .928 r
.63431 .69098 m .64314 .68846 L .64531 .69078 L p F P
0 g
s
.651 .758 .928 r
.64314 .68846 m .63431 .69098 L .63213 .68865 L p F P
0 g
s
.65 .758 .928 r
.5002 .69099 m .50881 .68847 L .51118 .6908 L p F P
0 g
s
.65 .758 .928 r
.50881 .68847 m .5002 .69099 L .49782 .68866 L p F P
0 g
s
.651 .758 .928 r
.77943 .6907 m .7885 .68817 L .79044 .6905 L p F P
0 g
s
.651 .758 .928 r
.7885 .68817 m .77943 .6907 L .77747 .68838 L p F P
0 g
s
.65 .757 .928 r
.37705 .69077 m .38546 .68825 L .38801 .69059 L p F P
0 g
s
.65 .757 .928 r
.38546 .68825 m .37705 .69077 L .37448 .68845 L p F P
0 g
s
.651 .758 .928 r
.64531 .69078 m .65416 .68826 L .6563 .69059 L p F P
0 g
s
.651 .758 .928 r
.65416 .68826 m .64531 .69078 L .64314 .68846 L p F P
0 g
s
.65 .758 .928 r
.51118 .6908 m .51981 .68828 L .52216 .69061 L p F P
0 g
s
.65 .758 .928 r
.51981 .68828 m .51118 .6908 L .50881 .68847 L p F P
0 g
s
.65 .757 .928 r
.25388 .69049 m .26209 .68797 L .26483 .69031 L p F P
0 g
s
.65 .757 .928 r
.26209 .68797 m .25388 .69049 L .25113 .68816 L p F P
0 g
s
.651 .758 .928 r
.79044 .6905 m .79953 .68796 L .80146 .69029 L p F P
0 g
s
.651 .758 .928 r
.79953 .68796 m .79044 .6905 L .7885 .68817 L p F P
0 g
s
0 0 .346 r
.52581 .42635 m .52579 .4264 L .52579 .42258 L p F P
0 g
s
0 0 .346 r
.52579 .42258 m .52581 .42253 L .52581 .42635 L p F P
0 g
s
.762 .5 .538 r
.52571 .42638 m .52579 .4264 L .52579 .42258 L p F P
0 g
s
.762 .5 .538 r
.52579 .42258 m .52571 .42256 L .52571 .42638 L p F P
0 g
s
.65 .757 .928 r
.38801 .69059 m .39645 .68806 L .39898 .69039 L p F P
0 g
s
.65 .757 .928 r
.39645 .68806 m .38801 .69059 L .38546 .68825 L p F P
0 g
s
.651 .758 .928 r
.6563 .69059 m .66517 .68806 L .66731 .69039 L p F P
0 g
s
.651 .758 .928 r
.66517 .68806 m .6563 .69059 L .65416 .68826 L p F P
0 g
s
0 0 .347 r
.52573 .42251 m .52571 .42256 L .52571 .42638 L p F P
0 g
s
.65 .758 .928 r
.52216 .69061 m .53081 .68808 L .53314 .69041 L p F P
0 g
s
.65 .758 .928 r
.53081 .68808 m .52216 .69061 L .51981 .68828 L p F P
0 g
s
.762 .501 .539 r
.52573 .42251 m .52581 .42253 L .52581 .42635 L p F P
0 g
s
.762 .501 .539 r
.52581 .42635 m .52573 .42633 L .52573 .42251 L p F P
0 g
s
0 0 .347 r
.52571 .42638 m .52573 .42633 L .52573 .42251 L p F P
0 g
s
.651 .758 .928 r
.80146 .69029 m .81056 .68775 L .81248 .69008 L p F P
0 g
s
.651 .758 .928 r
.81056 .68775 m .80146 .69029 L .79953 .68796 L p F P
0 g
s
.65 .757 .928 r
.26483 .69031 m .27306 .68779 L .27578 .69013 L p F P
0 g
s
.65 .757 .928 r
.27306 .68779 m .26483 .69031 L .26209 .68797 L p F P
0 g
s
.651 .758 .928 r
.66731 .69039 m .67619 .68786 L .67831 .69019 L p F P
0 g
s
.651 .758 .928 r
.67619 .68786 m .66731 .69039 L .66517 .68806 L p F P
0 g
s
.65 .757 .928 r
.39898 .69039 m .40743 .68787 L .40995 .6902 L p F P
0 g
s
.65 .757 .928 r
.40743 .68787 m .39898 .69039 L .39645 .68806 L p F P
0 g
s
.65 .758 .928 r
.53314 .69041 m .54181 .68789 L .54413 .69022 L p F P
0 g
s
.65 .758 .928 r
.54181 .68789 m .53314 .69041 L .53081 .68808 L p F P
0 g
s
.651 .758 .928 r
.81248 .69008 m .8216 .68754 L .8235 .68987 L p F P
0 g
s
.651 .758 .928 r
.8216 .68754 m .81248 .69008 L .81056 .68775 L p F P
0 g
s
.65 .757 .928 r
.27578 .69013 m .28403 .68761 L .28674 .68994 L p F P
0 g
s
.65 .757 .928 r
.28403 .68761 m .27578 .69013 L .27306 .68779 L p F P
0 g
s
.651 .758 .928 r
.67831 .69019 m .68722 .68766 L .68932 .68999 L p F P
0 g
s
.651 .758 .928 r
.68722 .68766 m .67831 .69019 L .67619 .68786 L p F P
0 g
s
.65 .757 .928 r
.40995 .6902 m .41842 .68768 L .42093 .69001 L p F P
0 g
s
.65 .757 .928 r
.41842 .68768 m .40995 .6902 L .40743 .68787 L p F P
0 g
s
.65 .758 .928 r
.54413 .69022 m .55282 .68769 L .55512 .69002 L p F P
0 g
s
.65 .758 .928 r
.55282 .68769 m .54413 .69022 L .54181 .68789 L p F P
0 g
s
.651 .758 .928 r
.8235 .68987 m .83264 .68733 L .83452 .68965 L p F P
0 g
s
.651 .758 .928 r
.83264 .68733 m .8235 .68987 L .8216 .68754 L p F P
0 g
s
.65 .757 .928 r
.28674 .68994 m .29501 .68743 L .29769 .68976 L p F P
0 g
s
.65 .757 .928 r
.29501 .68743 m .28674 .68994 L .28403 .68761 L p F P
0 g
s
.651 .758 .928 r
.68932 .68999 m .69824 .68746 L .70033 .68979 L p F P
0 g
s
.651 .758 .928 r
.69824 .68746 m .68932 .68999 L .68722 .68766 L p F P
0 g
s
.65 .758 .928 r
.42093 .69001 m .42942 .68749 L .4319 .68982 L p F P
0 g
s
.65 .758 .928 r
.42942 .68749 m .42093 .69001 L .41842 .68768 L p F P
0 g
s
.65 .758 .928 r
.55512 .69002 m .56383 .6875 L .56611 .68983 L p F P
0 g
s
.65 .758 .928 r
.56383 .6875 m .55512 .69002 L .55282 .68769 L p F P
0 g
s
.651 .759 .928 r
.83452 .68965 m .84369 .68711 L .84555 .68944 L p F P
0 g
s
.651 .758 .928 r
.84369 .68711 m .83452 .68965 L .83264 .68733 L p F P
0 g
s
.65 .757 .928 r
.30598 .68724 m .29769 .68976 L .29501 .68743 L p F P
0 g
s
.65 .757 .928 r
.29769 .68976 m .30598 .68724 L .30866 .68957 L p F P
0 g
s
.651 .758 .928 r
.70033 .68979 m .70927 .68726 L .71134 .68959 L p F P
0 g
s
.651 .758 .928 r
.70927 .68726 m .70033 .68979 L .69824 .68746 L p F P
0 g
s
.65 .758 .928 r
.4319 .68982 m .44041 .6873 L .44288 .68963 L p F P
0 g
s
.65 .758 .928 r
.44041 .6873 m .4319 .68982 L .42942 .68749 L p F P
0 g
s
.65 .758 .928 r
.56611 .68983 m .57484 .6873 L .57711 .68963 L p F P
0 g
s
.65 .758 .928 r
.57484 .6873 m .56611 .68983 L .56383 .6875 L p F P
0 g
s
.651 .759 .928 r
.84555 .68944 m .85473 .68689 L .85658 .68922 L p F P
0 g
s
.651 .759 .928 r
.85473 .68689 m .84555 .68944 L .84369 .68711 L p F P
0 g
s
.65 .757 .928 r
.30866 .68957 m .31696 .68705 L .31962 .68939 L p F P
0 g
s
.65 .757 .928 r
.31696 .68705 m .30866 .68957 L .30598 .68724 L p F P
0 g
s
.651 .758 .928 r
.71134 .68959 m .7203 .68706 L .72235 .68939 L p F P
0 g
s
.651 .758 .928 r
.7203 .68706 m .71134 .68959 L .70927 .68726 L p F P
0 g
s
.65 .758 .928 r
.44288 .68963 m .45141 .6871 L .45386 .68944 L p F P
0 g
s
.65 .758 .928 r
.45141 .6871 m .44288 .68963 L .44041 .6873 L p F P
0 g
s
.65 .758 .928 r
.57711 .68963 m .58586 .6871 L .58811 .68944 L p F P
0 g
s
.65 .758 .928 r
.58586 .6871 m .57711 .68963 L .57484 .6873 L p F P
0 g
s
.651 .759 .928 r
.85658 .68922 m .86578 .68667 L .86761 .68899 L p F P
0 g
s
.651 .759 .928 r
.86578 .68667 m .85658 .68922 L .85473 .68689 L p F P
0 g
s
.65 .757 .928 r
.31962 .68939 m .32795 .68687 L .33059 .6892 L p F P
0 g
s
.65 .757 .928 r
.32795 .68687 m .31962 .68939 L .31696 .68705 L p F P
0 g
s
.651 .758 .928 r
.72235 .68939 m .73134 .68686 L .73337 .68919 L p F P
0 g
s
.651 .758 .928 r
.73134 .68686 m .72235 .68939 L .7203 .68706 L p F P
0 g
s
.65 .758 .928 r
.45386 .68944 m .46241 .68691 L .46485 .68924 L p F P
0 g
s
.65 .758 .928 r
.46241 .68691 m .45386 .68944 L .45141 .6871 L p F P
0 g
s
.65 .758 .928 r
.58811 .68944 m .59687 .68691 L .59911 .68924 L p F P
0 g
s
.65 .758 .928 r
.59687 .68691 m .58811 .68944 L .58586 .6871 L p F P
0 g
s
.651 .759 .928 r
.86761 .68899 m .87683 .68645 L .87864 .68877 L p F P
0 g
s
.651 .759 .928 r
.87683 .68645 m .86761 .68899 L .86578 .68667 L p F P
0 g
s
.651 .758 .928 r
.74237 .68666 m .73337 .68919 L .73134 .68686 L p F P
0 g
s
.651 .758 .928 r
.73337 .68919 m .74237 .68666 L .74439 .68899 L p F P
0 g
s
.65 .757 .928 r
.33059 .6892 m .33893 .68668 L .34156 .68901 L p F P
0 g
s
.65 .757 .928 r
.33893 .68668 m .33059 .6892 L .32795 .68687 L p F P
0 g
s
.65 .758 .928 r
.59911 .68924 m .60789 .68671 L .61011 .68905 L p F P
0 g
s
.65 .758 .928 r
.60789 .68671 m .59911 .68924 L .59687 .68691 L p F P
0 g
s
.65 .758 .928 r
.46485 .68924 m .47341 .68672 L .47583 .68905 L p F P
0 g
s
.65 .758 .928 r
.47341 .68672 m .46485 .68924 L .46241 .68691 L p F P
0 g
s
.651 .759 .928 r
.87864 .68877 m .88788 .68622 L .88968 .68854 L p F P
0 g
s
.651 .759 .928 r
.88788 .68622 m .87864 .68877 L .87683 .68645 L p F P
0 g
s
.651 .758 .928 r
.74439 .68899 m .75341 .68645 L .75541 .68879 L p F P
0 g
s
.651 .758 .928 r
.75341 .68645 m .74439 .68899 L .74237 .68666 L p F P
0 g
s
.65 .757 .928 r
.34156 .68901 m .34992 .68649 L .35253 .68882 L p F P
0 g
s
.65 .757 .928 r
.34992 .68649 m .34156 .68901 L .33893 .68668 L p F P
0 g
s
.65 .758 .928 r
.61011 .68905 m .61892 .68651 L .62112 .68885 L p F P
0 g
s
.65 .758 .928 r
.61892 .68651 m .61011 .68905 L .60789 .68671 L p F P
0 g
s
.65 .758 .928 r
.47583 .68905 m .48442 .68652 L .48682 .68886 L p F P
0 g
s
.65 .758 .928 r
.48442 .68652 m .47583 .68905 L .47341 .68672 L p F P
0 g
s
.651 .759 .928 r
.88968 .68854 m .89894 .68598 L .90072 .68831 L p F P
0 g
s
.651 .759 .928 r
.89894 .68598 m .88968 .68854 L .88788 .68622 L p F P
0 g
s
.651 .758 .928 r
.76445 .68625 m .75541 .68879 L .75341 .68645 L p F P
0 g
s
.651 .758 .928 r
.75541 .68879 m .76445 .68625 L .76644 .68858 L p F P
0 g
s
.65 .757 .928 r
.35253 .68882 m .36091 .6863 L .3635 .68863 L p F P
0 g
s
.65 .757 .928 r
.36091 .6863 m .35253 .68882 L .34992 .68649 L p F P
0 g
s
.65 .758 .928 r
.62112 .68885 m .62994 .68632 L .63213 .68865 L p F P
0 g
s
.65 .758 .928 r
.62994 .68632 m .62112 .68885 L .61892 .68651 L p F P
0 g
s
.65 .758 .928 r
.49543 .68633 m .48682 .68886 L .48442 .68652 L p F P
0 g
s
.65 .758 .928 r
.48682 .68886 m .49543 .68633 L .49782 .68866 L p F P
0 g
s
.652 .759 .928 r
.90999 .68575 m .90072 .68831 L .89894 .68598 L p F P
0 g
s
.651 .758 .928 r
.76644 .68858 m .7755 .68604 L .77747 .68838 L p F P
0 g
s
.651 .758 .928 r
.7755 .68604 m .76644 .68858 L .76445 .68625 L p F P
0 g
s
0 0 .346 r
.52581 .43018 m .52579 .43023 L .52579 .4264 L p F P
0 g
s
0 0 .346 r
.52579 .4264 m .52581 .42635 L .52581 .43018 L p F P
0 g
s
.762 .5 .538 r
.52571 .43022 m .52579 .43023 L .52579 .4264 L p F P
0 g
s
.762 .5 .538 r
.52579 .4264 m .52571 .42638 L .52571 .43022 L p F P
0 g
s
.65 .757 .928 r
.3635 .68863 m .37191 .68611 L .37448 .68845 L p F P
0 g
s
.65 .757 .928 r
.37191 .68611 m .3635 .68863 L .36091 .6863 L p F P
0 g
s
.651 .758 .928 r
.63213 .68865 m .64097 .68612 L .64314 .68846 L p F P
0 g
s
.651 .758 .928 r
.64097 .68612 m .63213 .68865 L .62994 .68632 L p F P
0 g
s
0 0 .347 r
.52573 .42633 m .52571 .42638 L .52571 .43022 L p F P
0 g
s
.65 .758 .928 r
.49782 .68866 m .50644 .68613 L .50881 .68847 L p F P
0 g
s
.65 .758 .928 r
.50644 .68613 m .49782 .68866 L .49543 .68633 L p F P
0 g
s
.762 .501 .539 r
.52573 .42633 m .52581 .42635 L .52581 .43018 L p F P
0 g
s
.762 .501 .539 r
.52581 .43018 m .52573 .43017 L .52573 .42633 L p F P
0 g
s
0 0 .347 r
.52571 .43022 m .52573 .43017 L .52573 .42633 L p F P
0 g
s
.651 .758 .928 r
.77747 .68838 m .78654 .68584 L .7885 .68817 L p F P
0 g
s
.651 .758 .928 r
.78654 .68584 m .77747 .68838 L .7755 .68604 L p F P
0 g
s
.65 .757 .928 r
.37448 .68845 m .3829 .68592 L .38546 .68825 L p F P
0 g
s
.65 .757 .928 r
.3829 .68592 m .37448 .68845 L .37191 .68611 L p F P
0 g
s
.651 .758 .928 r
.64314 .68846 m .652 .68592 L .65416 .68826 L p F P
0 g
s
.651 .758 .928 r
.652 .68592 m .64314 .68846 L .64097 .68612 L p F P
0 g
s
.65 .758 .928 r
.50881 .68847 m .51745 .68594 L .51981 .68828 L p F P
0 g
s
.65 .758 .928 r
.51745 .68594 m .50881 .68847 L .50644 .68613 L p F P
0 g
s
.65 .757 .928 r
.25113 .68816 m .25935 .68564 L .26209 .68797 L p F P
0 g
s
.65 .757 .928 r
.25935 .68564 m .25113 .68816 L .24836 .68582 L p F P
0 g
s
.651 .758 .928 r
.7885 .68817 m .79759 .68563 L .79953 .68796 L p F P
0 g
s
.651 .758 .928 r
.79759 .68563 m .7885 .68817 L .78654 .68584 L p F P
0 g
s
.65 .757 .928 r
.38546 .68825 m .3939 .68573 L .39645 .68806 L p F P
0 g
s
.65 .757 .928 r
.3939 .68573 m .38546 .68825 L .3829 .68592 L p F P
0 g
s
.651 .758 .928 r
.65416 .68826 m .66304 .68572 L .66517 .68806 L p F P
0 g
s
.651 .758 .928 r
.66304 .68572 m .65416 .68826 L .652 .68592 L p F P
0 g
s
.65 .758 .928 r
.51981 .68828 m .52847 .68574 L .53081 .68808 L p F P
0 g
s
.65 .758 .928 r
.52847 .68574 m .51981 .68828 L .51745 .68594 L p F P
0 g
s
.651 .758 .928 r
.79953 .68796 m .80865 .68542 L .81056 .68775 L p F P
0 g
s
.651 .758 .928 r
.80865 .68542 m .79953 .68796 L .79759 .68563 L p F P
0 g
s
.65 .757 .928 r
.26209 .68797 m .27033 .68545 L .27306 .68779 L p F P
0 g
s
.65 .757 .928 r
.27033 .68545 m .26209 .68797 L .25935 .68564 L p F P
0 g
s
.651 .758 .928 r
.66517 .68806 m .67407 .68552 L .67619 .68786 L p F P
0 g
s
.651 .758 .928 r
.67407 .68552 m .66517 .68806 L .66304 .68572 L p F P
0 g
s
.65 .757 .928 r
.39645 .68806 m .40491 .68553 L .40743 .68787 L p F P
0 g
s
.65 .757 .928 r
.40491 .68553 m .39645 .68806 L .3939 .68573 L p F P
0 g
s
.65 .758 .928 r
.53081 .68808 m .53949 .68555 L .54181 .68789 L p F P
0 g
s
.65 .758 .928 r
.53949 .68555 m .53081 .68808 L .52847 .68574 L p F P
0 g
s
.651 .758 .928 r
.81056 .68775 m .8197 .68521 L .8216 .68754 L p F P
0 g
s
.651 .758 .928 r
.8197 .68521 m .81056 .68775 L .80865 .68542 L p F P
0 g
s
.65 .757 .928 r
.27306 .68779 m .28132 .68527 L .28403 .68761 L p F P
0 g
s
.65 .757 .928 r
.28132 .68527 m .27306 .68779 L .27033 .68545 L p F P
0 g
s
.651 .758 .928 r
.67619 .68786 m .68511 .68533 L .68722 .68766 L p F P
0 g
s
.651 .758 .928 r
.68511 .68533 m .67619 .68786 L .67407 .68552 L p F P
0 g
s
.65 .757 .928 r
.40743 .68787 m .41591 .68534 L .41842 .68768 L p F P
0 g
s
.65 .757 .928 r
.41591 .68534 m .40743 .68787 L .40491 .68553 L p F P
0 g
s
.65 .758 .928 r
.54181 .68789 m .55051 .68535 L .55282 .68769 L p F P
0 g
s
.65 .758 .928 r
.55051 .68535 m .54181 .68789 L .53949 .68555 L p F P
0 g
s
.651 .758 .928 r
.8216 .68754 m .83076 .68499 L .83264 .68733 L p F P
0 g
s
.651 .758 .928 r
.83076 .68499 m .8216 .68754 L .8197 .68521 L p F P
0 g
s
.65 .757 .928 r
.28403 .68761 m .29231 .68509 L .29501 .68743 L p F P
0 g
s
.65 .757 .928 r
.29231 .68509 m .28403 .68761 L .28132 .68527 L p F P
0 g
s
.651 .758 .928 r
.68722 .68766 m .69615 .68513 L .69824 .68746 L p F P
0 g
s
.651 .758 .928 r
.69615 .68513 m .68722 .68766 L .68511 .68533 L p F P
0 g
s
.65 .758 .928 r
.41842 .68768 m .42692 .68515 L .42942 .68749 L p F P
0 g
s
.65 .757 .928 r
.42692 .68515 m .41842 .68768 L .41591 .68534 L p F P
0 g
s
.65 .758 .928 r
.55282 .68769 m .56154 .68516 L .56383 .6875 L p F P
0 g
s
.65 .758 .928 r
.56154 .68516 m .55282 .68769 L .55051 .68535 L p F P
0 g
s
.651 .758 .928 r
.83264 .68733 m .84182 .68478 L .84369 .68711 L p F P
0 g
s
.651 .758 .928 r
.84182 .68478 m .83264 .68733 L .83076 .68499 L p F P
0 g
s
.65 .757 .928 r
.29501 .68743 m .3033 .6849 L .30598 .68724 L p F P
0 g
s
.65 .757 .928 r
.3033 .6849 m .29501 .68743 L .29231 .68509 L p F P
0 g
s
.651 .758 .928 r
.69824 .68746 m .7072 .68493 L .70927 .68726 L p F P
0 g
s
.651 .758 .928 r
.7072 .68493 m .69824 .68746 L .69615 .68513 L p F P
0 g
s
.65 .758 .928 r
.42942 .68749 m .43793 .68496 L .44041 .6873 L p F P
0 g
s
.65 .758 .928 r
.43793 .68496 m .42942 .68749 L .42692 .68515 L p F P
0 g
s
.65 .758 .928 r
.56383 .6875 m .57257 .68496 L .57484 .6873 L p F P
0 g
s
.65 .758 .928 r
.57257 .68496 m .56383 .6875 L .56154 .68516 L p F P
0 g
s
.651 .759 .928 r
.84369 .68711 m .85288 .68456 L .85473 .68689 L p F P
0 g
s
.651 .759 .928 r
.85288 .68456 m .84369 .68711 L .84182 .68478 L p F P
0 g
s
.65 .757 .928 r
.3143 .68471 m .30598 .68724 L .3033 .6849 L p F P
0 g
s
.65 .757 .928 r
.30598 .68724 m .3143 .68471 L .31696 .68705 L p F P
0 g
s
.651 .758 .928 r
.70927 .68726 m .71825 .68472 L .7203 .68706 L p F P
0 g
s
.651 .758 .928 r
.71825 .68472 m .70927 .68726 L .7072 .68493 L p F P
0 g
s
.65 .758 .928 r
.44041 .6873 m .44895 .68476 L .45141 .6871 L p F P
0 g
s
.65 .758 .928 r
.44895 .68476 m .44041 .6873 L .43793 .68496 L p F P
0 g
s
.65 .758 .928 r
.57484 .6873 m .5836 .68476 L .58586 .6871 L p F P
0 g
s
.65 .758 .928 r
.5836 .68476 m .57484 .6873 L .57257 .68496 L p F P
0 g
s
.651 .759 .928 r
.85473 .68689 m .86394 .68434 L .86578 .68667 L p F P
0 g
s
.651 .759 .928 r
.86394 .68434 m .85473 .68689 L .85288 .68456 L p F P
0 g
s
.65 .757 .928 r
.31696 .68705 m .3253 .68452 L .32795 .68687 L p F P
0 g
s
.65 .757 .928 r
.3253 .68452 m .31696 .68705 L .3143 .68471 L p F P
0 g
s
.651 .758 .928 r
.7203 .68706 m .7293 .68452 L .73134 .68686 L p F P
0 g
s
.651 .758 .928 r
.7293 .68452 m .7203 .68706 L .71825 .68472 L p F P
0 g
s
.65 .758 .928 r
.45141 .6871 m .45996 .68457 L .46241 .68691 L p F P
0 g
s
.65 .758 .928 r
.45996 .68457 m .45141 .6871 L .44895 .68476 L p F P
0 g
s
.65 .758 .928 r
.58586 .6871 m .59463 .68457 L .59687 .68691 L p F P
0 g
s
.65 .758 .928 r
.59463 .68457 m .58586 .6871 L .5836 .68476 L p F P
0 g
s
.651 .759 .928 r
.86578 .68667 m .87501 .68411 L .87683 .68645 L p F P
0 g
s
.651 .759 .928 r
.87501 .68411 m .86578 .68667 L .86394 .68434 L p F P
0 g
s
.651 .758 .928 r
.73134 .68686 m .74035 .68432 L .74237 .68666 L p F P
0 g
s
.651 .758 .928 r
.74035 .68432 m .73134 .68686 L .7293 .68452 L p F P
0 g
s
.65 .757 .928 r
.32795 .68687 m .3363 .68433 L .33893 .68668 L p F P
0 g
s
.65 .757 .928 r
.3363 .68433 m .32795 .68687 L .3253 .68452 L p F P
0 g
s
.65 .758 .928 r
.59687 .68691 m .60567 .68437 L .60789 .68671 L p F P
0 g
s
.65 .758 .928 r
.60567 .68437 m .59687 .68691 L .59463 .68457 L p F P
0 g
s
.65 .758 .928 r
.46241 .68691 m .47098 .68437 L .47341 .68672 L p F P
0 g
s
.65 .758 .928 r
.47098 .68437 m .46241 .68691 L .45996 .68457 L p F P
0 g
s
.651 .759 .928 r
.87683 .68645 m .88608 .68389 L .88788 .68622 L p F P
0 g
s
.651 .759 .928 r
.88608 .68389 m .87683 .68645 L .87501 .68411 L p F P
0 g
s
.651 .758 .928 r
.7514 .68412 m .74237 .68666 L .74035 .68432 L p F P
0 g
s
.651 .758 .928 r
.74237 .68666 m .7514 .68412 L .75341 .68645 L p F P
0 g
s
.65 .757 .928 r
.33893 .68668 m .34731 .68415 L .34992 .68649 L p F P
0 g
s
.65 .757 .928 r
.34731 .68415 m .33893 .68668 L .3363 .68433 L p F P
0 g
s
0 0 .346 r
.52581 .43402 m .52579 .43407 L .52579 .43023 L p F P
0 g
s
0 0 .346 r
.52579 .43023 m .52581 .43018 L .52581 .43402 L p F P
0 g
s
.762 .5 .538 r
.52571 .43406 m .52579 .43407 L .52579 .43023 L p F P
0 g
s
.762 .5 .538 r
.52579 .43023 m .52571 .43022 L .52571 .43406 L p F P
0 g
s
.65 .758 .928 r
.60789 .68671 m .61671 .68417 L .61892 .68651 L p F P
0 g
s
.65 .758 .928 r
.61671 .68417 m .60789 .68671 L .60567 .68437 L p F P
0 g
s
0 0 .347 r
.52573 .43017 m .52571 .43022 L .52571 .43406 L p F P
0 g
s
.65 .758 .928 r
.47341 .68672 m .48201 .68418 L .48442 .68652 L p F P
0 g
s
.65 .758 .928 r
.48201 .68418 m .47341 .68672 L .47098 .68437 L p F P
0 g
s
.762 .501 .539 r
.52573 .43017 m .52581 .43018 L .52581 .43402 L p F P
0 g
s
.762 .501 .539 r
.52581 .43402 m .52574 .43401 L .52573 .43017 L p F P
0 g
s
0 0 .347 r
.52571 .43406 m .52574 .43401 L .52573 .43017 L p F P
0 g
s
.651 .759 .928 r
.88788 .68622 m .89715 .68365 L .89894 .68598 L p F P
0 g
s
.651 .759 .928 r
.89715 .68365 m .88788 .68622 L .88608 .68389 L p F P
0 g
s
.651 .758 .928 r
.75341 .68645 m .76246 .68391 L .76445 .68625 L p F P
0 g
s
.651 .758 .928 r
.76246 .68391 m .75341 .68645 L .7514 .68412 L p F P
0 g
s
.65 .757 .928 r
.34992 .68649 m .35831 .68395 L .36091 .6863 L p F P
0 g
s
.65 .757 .928 r
.35831 .68395 m .34992 .68649 L .34731 .68415 L p F P
0 g
s
.65 .758 .928 r
.61892 .68651 m .62775 .68398 L .62994 .68632 L p F P
0 g
s
.651 .758 .928 r
.62775 .68398 m .61892 .68651 L .61671 .68417 L p F P
0 g
s
.65 .758 .928 r
.48442 .68652 m .49303 .68398 L .49543 .68633 L p F P
0 g
s
.65 .758 .928 r
.49303 .68398 m .48442 .68652 L .48201 .68418 L p F P
0 g
s
.652 .759 .928 r
.89894 .68598 m .90822 .68342 L .90999 .68575 L p F P
0 g
s
.651 .759 .928 r
.90822 .68342 m .89894 .68598 L .89715 .68365 L p F P
0 g
s
.651 .758 .928 r
.77352 .6837 m .76445 .68625 L .76246 .68391 L p F P
0 g
s
.651 .758 .928 r
.76445 .68625 m .77352 .6837 L .7755 .68604 L p F P
0 g
s
.65 .757 .928 r
.36091 .6863 m .36932 .68376 L .37191 .68611 L p F P
0 g
s
.65 .757 .928 r
.36932 .68376 m .36091 .6863 L .35831 .68395 L p F P
0 g
s
.651 .758 .928 r
.62994 .68632 m .63879 .68378 L .64097 .68612 L p F P
0 g
s
.651 .758 .928 r
.63879 .68378 m .62994 .68632 L .62775 .68398 L p F P
0 g
s
.65 .758 .928 r
.49543 .68633 m .50406 .68379 L .50644 .68613 L p F P
0 g
s
.65 .758 .928 r
.50406 .68379 m .49543 .68633 L .49303 .68398 L p F P
0 g
s
.652 .759 .928 r
.9193 .68318 m .90999 .68575 L .90822 .68342 L p F P
0 g
s
.651 .758 .928 r
.7755 .68604 m .78459 .6835 L .78654 .68584 L p F P
0 g
s
.651 .758 .928 r
.78459 .6835 m .7755 .68604 L .77352 .6837 L p F P
0 g
s
.65 .757 .928 r
.37191 .68611 m .38034 .68357 L .3829 .68592 L p F P
0 g
s
.65 .757 .928 r
.38034 .68357 m .37191 .68611 L .36932 .68376 L p F P
0 g
s
.651 .758 .928 r
.64097 .68612 m .64984 .68358 L .652 .68592 L p F P
0 g
s
.651 .758 .928 r
.64984 .68358 m .64097 .68612 L .63879 .68378 L p F P
0 g
s
.65 .758 .928 r
.50644 .68613 m .51509 .68359 L .51745 .68594 L p F P
0 g
s
.65 .758 .928 r
.51509 .68359 m .50644 .68613 L .50406 .68379 L p F P
0 g
s
.65 .757 .928 r
.24836 .68582 m .25659 .68329 L .25935 .68564 L p F P
0 g
s
.65 .757 .928 r
.25383 .68094 m .24559 .68347 L .24836 .68582 L p F P
0 g
s
.65 .757 .928 r
.24836 .68582 m .25659 .68329 L .25383 .68094 L p F P
0 g
s
.651 .758 .928 r
.78654 .68584 m .79565 .68329 L .79759 .68563 L p F P
0 g
s
.651 .758 .928 r
.79565 .68329 m .78654 .68584 L .78459 .6835 L p F P
0 g
s
.65 .757 .928 r
.3829 .68592 m .39135 .68338 L .3939 .68573 L p F P
0 g
s
.65 .757 .928 r
.39135 .68338 m .3829 .68592 L .38034 .68357 L p F P
0 g
s
.651 .758 .928 r
.652 .68592 m .66089 .68338 L .66304 .68572 L p F P
0 g
s
.651 .758 .928 r
.66089 .68338 m .652 .68592 L .64984 .68358 L p F P
0 g
s
.65 .758 .928 r
.51745 .68594 m .52612 .6834 L .52847 .68574 L p F P
0 g
s
.65 .758 .928 r
.52612 .6834 m .51745 .68594 L .51509 .68359 L p F P
0 g
s
.651 .758 .928 r
.79759 .68563 m .80672 .68308 L .80865 .68542 L p F P
0 g
s
.651 .758 .928 r
.80672 .68308 m .79759 .68563 L .79565 .68329 L p F P
0 g
s
.65 .757 .928 r
.25935 .68564 m .26759 .68311 L .27033 .68545 L p F P
0 g
s
.65 .757 .928 r
.26759 .68311 m .25935 .68564 L .25659 .68329 L p F P
0 g
s
.651 .758 .928 r
.66304 .68572 m .67194 .68318 L .67407 .68552 L p F P
0 g
s
.651 .758 .928 r
.67194 .68318 m .66304 .68572 L .66089 .68338 L p F P
0 g
s
.65 .757 .928 r
.3939 .68573 m .40237 .68319 L .40491 .68553 L p F P
0 g
s
.65 .757 .928 r
.40237 .68319 m .3939 .68573 L .39135 .68338 L p F P
0 g
s
.65 .758 .928 r
.52847 .68574 m .53716 .6832 L .53949 .68555 L p F P
0 g
s
.65 .758 .928 r
.53716 .6832 m .52847 .68574 L .52612 .6834 L p F P
0 g
s
.651 .758 .928 r
.80865 .68542 m .81779 .68287 L .8197 .68521 L p F P
0 g
s
.651 .758 .928 r
.81779 .68287 m .80865 .68542 L .80672 .68308 L p F P
0 g
s
.65 .757 .928 r
.27033 .68545 m .2786 .68292 L .28132 .68527 L p F P
0 g
s
.65 .757 .928 r
.2786 .68292 m .27033 .68545 L .26759 .68311 L p F P
0 g
s
.651 .758 .928 r
.67407 .68552 m .683 .68298 L .68511 .68533 L p F P
0 g
s
.651 .758 .928 r
.683 .68298 m .67407 .68552 L .67194 .68318 L p F P
0 g
s
.65 .757 .928 r
.40491 .68553 m .41339 .68299 L .41591 .68534 L p F P
0 g
s
.65 .757 .928 r
.41339 .68299 m .40491 .68553 L .40237 .68319 L p F P
0 g
s
.65 .758 .928 r
.53949 .68555 m .5482 .68301 L .55051 .68535 L p F P
0 g
s
.65 .758 .928 r
.5482 .68301 m .53949 .68555 L .53716 .6832 L p F P
0 g
s
.651 .758 .928 r
.8197 .68521 m .82887 .68265 L .83076 .68499 L p F P
0 g
s
.651 .758 .928 r
.82887 .68265 m .8197 .68521 L .81779 .68287 L p F P
0 g
s
.65 .757 .928 r
.28132 .68527 m .2896 .68274 L .29231 .68509 L p F P
0 g
s
.65 .757 .928 r
.2896 .68274 m .28132 .68527 L .2786 .68292 L p F P
0 g
s
.651 .758 .928 r
.68511 .68533 m .69406 .68278 L .69615 .68513 L p F P
0 g
s
.651 .758 .928 r
.69406 .68278 m .68511 .68533 L .683 .68298 L p F P
0 g
s
.65 .757 .928 r
.41591 .68534 m .42442 .6828 L .42692 .68515 L p F P
0 g
s
.65 .757 .928 r
.42442 .6828 m .41591 .68534 L .41339 .68299 L p F P
0 g
s
.65 .758 .928 r
.55051 .68535 m .55924 .68281 L .56154 .68516 L p F P
0 g
s
.65 .758 .928 r
.55924 .68281 m .55051 .68535 L .5482 .68301 L p F P
0 g
s
.651 .758 .928 r
.83076 .68499 m .83994 .68244 L .84182 .68478 L p F P
0 g
s
.651 .758 .928 r
.83994 .68244 m .83076 .68499 L .82887 .68265 L p F P
0 g
s
.65 .757 .928 r
.29231 .68509 m .30061 .68255 L .3033 .6849 L p F P
0 g
s
.65 .757 .928 r
.30061 .68255 m .29231 .68509 L .2896 .68274 L p F P
0 g
s
.651 .758 .928 r
.69615 .68513 m .70512 .68258 L .7072 .68493 L p F P
0 g
s
.651 .758 .928 r
.70512 .68258 m .69615 .68513 L .69406 .68278 L p F P
0 g
s
.65 .758 .928 r
.42692 .68515 m .43545 .68261 L .43793 .68496 L p F P
0 g
s
.65 .757 .928 r
.43545 .68261 m .42692 .68515 L .42442 .6828 L p F P
0 g
s
.65 .758 .928 r
.56154 .68516 m .57028 .68261 L .57257 .68496 L p F P
0 g
s
.65 .758 .928 r
.57028 .68261 m .56154 .68516 L .55924 .68281 L p F P
0 g
s
.651 .759 .928 r
.84182 .68478 m .85102 .68222 L .85288 .68456 L p F P
0 g
s
.651 .758 .928 r
.85102 .68222 m .84182 .68478 L .83994 .68244 L p F P
0 g
s
.65 .757 .928 r
.3033 .6849 m .31163 .68236 L .3143 .68471 L p F P
0 g
s
.65 .757 .928 r
.31163 .68236 m .3033 .6849 L .30061 .68255 L p F P
0 g
s
.651 .758 .928 r
.7072 .68493 m .71618 .68238 L .71825 .68472 L p F P
0 g
s
.651 .758 .928 r
.71618 .68238 m .7072 .68493 L .70512 .68258 L p F P
0 g
s
.65 .758 .928 r
.43793 .68496 m .44648 .68241 L .44895 .68476 L p F P
0 g
s
.65 .758 .928 r
.44648 .68241 m .43793 .68496 L .43545 .68261 L p F P
0 g
s
.65 .758 .928 r
.57257 .68496 m .58133 .68242 L .5836 .68476 L p F P
0 g
s
.65 .758 .928 r
.58133 .68242 m .57257 .68496 L .57028 .68261 L p F P
0 g
s
.651 .759 .928 r
.85288 .68456 m .8621 .682 L .86394 .68434 L p F P
0 g
s
.651 .759 .928 r
.8621 .682 m .85288 .68456 L .85102 .68222 L p F P
0 g
s
.65 .757 .928 r
.32264 .68217 m .3143 .68471 L .31163 .68236 L p F P
0 g
s
.65 .757 .928 r
.3143 .68471 m .32264 .68217 L .3253 .68452 L p F P
0 g
s
.651 .758 .928 r
.71825 .68472 m .72725 .68218 L .7293 .68452 L p F P
0 g
s
.651 .758 .928 r
.72725 .68218 m .71825 .68472 L .71618 .68238 L p F P
0 g
s
0 0 .346 r
.5258 .43788 m .52578 .43792 L .52579 .43407 L p F P
0 g
s
0 0 .346 r
.52579 .43407 m .52581 .43402 L .5258 .43788 L p F P
0 g
s
.762 .5 .538 r
.52572 .43791 m .52578 .43792 L .52579 .43407 L p F P
0 g
s
.762 .5 .538 r
.52579 .43407 m .52571 .43406 L .52572 .43791 L p F P
0 g
s
.65 .758 .928 r
.44895 .68476 m .45751 .68222 L .45996 .68457 L p F P
0 g
s
.65 .758 .928 r
.45751 .68222 m .44895 .68476 L .44648 .68241 L p F P
0 g
s
0 0 .347 r
.52574 .43401 m .52571 .43406 L .52572 .43791 L p F P
0 g
s
.65 .758 .928 r
.5836 .68476 m .59238 .68222 L .59463 .68457 L p F P
0 g
s
.65 .758 .928 r
.59238 .68222 m .5836 .68476 L .58133 .68242 L p F P
0 g
s
.762 .501 .539 r
.52574 .43401 m .52581 .43402 L .5258 .43788 L p F P
0 g
s
.762 .501 .539 r
.5258 .43788 m .52574 .43786 L .52574 .43401 L p F P
0 g
s
0 0 .347 r
.52572 .43791 m .52574 .43786 L .52574 .43401 L p F P
0 g
s
.651 .759 .928 r
.86394 .68434 m .87319 .68177 L .87501 .68411 L p F P
0 g
s
.651 .759 .928 r
.87319 .68177 m .86394 .68434 L .8621 .682 L p F P
0 g
s
.651 .758 .928 r
.7293 .68452 m .73832 .68197 L .74035 .68432 L p F P
0 g
s
.651 .758 .928 r
.73832 .68197 m .7293 .68452 L .72725 .68218 L p F P
0 g
s
.65 .757 .928 r
.3253 .68452 m .33366 .68199 L .3363 .68433 L p F P
0 g
s
.65 .757 .928 r
.33366 .68199 m .3253 .68452 L .32264 .68217 L p F P
0 g
s
.65 .758 .928 r
.59463 .68457 m .60343 .68202 L .60567 .68437 L p F P
0 g
s
.65 .758 .928 r
.60343 .68202 m .59463 .68457 L .59238 .68222 L p F P
0 g
s
.65 .758 .928 r
.45996 .68457 m .46855 .68202 L .47098 .68437 L p F P
0 g
s
.65 .758 .928 r
.46855 .68202 m .45996 .68457 L .45751 .68222 L p F P
0 g
s
.651 .759 .928 r
.87501 .68411 m .88427 .68155 L .88608 .68389 L p F P
0 g
s
.651 .759 .928 r
.88427 .68155 m .87501 .68411 L .87319 .68177 L p F P
0 g
s
.651 .758 .928 r
.74035 .68432 m .74939 .68177 L .7514 .68412 L p F P
0 g
s
.651 .758 .928 r
.74939 .68177 m .74035 .68432 L .73832 .68197 L p F P
0 g
s
.65 .757 .928 r
.3363 .68433 m .34468 .6818 L .34731 .68415 L p F P
0 g
s
.65 .757 .928 r
.34468 .6818 m .3363 .68433 L .33366 .68199 L p F P
0 g
s
.65 .758 .928 r
.60567 .68437 m .61449 .68182 L .61671 .68417 L p F P
0 g
s
.65 .758 .928 r
.61449 .68182 m .60567 .68437 L .60343 .68202 L p F P
0 g
s
.65 .758 .928 r
.47098 .68437 m .47959 .68183 L .48201 .68418 L p F P
0 g
s
.65 .758 .928 r
.47959 .68183 m .47098 .68437 L .46855 .68202 L p F P
0 g
s
.651 .759 .928 r
.88608 .68389 m .89536 .68132 L .89715 .68365 L p F P
0 g
s
.651 .759 .928 r
.89536 .68132 m .88608 .68389 L .88427 .68155 L p F P
0 g
s
.651 .758 .928 r
.76047 .68156 m .7514 .68412 L .74939 .68177 L p F P
0 g
s
.651 .758 .928 r
.7514 .68412 m .76047 .68156 L .76246 .68391 L p F P
0 g
s
.65 .757 .928 r
.34731 .68415 m .35571 .6816 L .35831 .68395 L p F P
0 g
s
.65 .757 .928 r
.35571 .6816 m .34731 .68415 L .34468 .6818 L p F P
0 g
s
.651 .758 .928 r
.61671 .68417 m .62555 .68163 L .62775 .68398 L p F P
0 g
s
.651 .758 .928 r
.62555 .68163 m .61671 .68417 L .61449 .68182 L p F P
0 g
s
.65 .758 .928 r
.48201 .68418 m .49063 .68163 L .49303 .68398 L p F P
0 g
s
.65 .758 .928 r
.49063 .68163 m .48201 .68418 L .47959 .68183 L p F P
0 g
s
.651 .759 .928 r
.89715 .68365 m .90645 .68108 L .90822 .68342 L p F P
0 g
s
.651 .759 .928 r
.90645 .68108 m .89715 .68365 L .89536 .68132 L p F P
0 g
s
.651 .758 .928 r
.76246 .68391 m .77154 .68136 L .77352 .6837 L p F P
0 g
s
.651 .758 .928 r
.77154 .68136 m .76246 .68391 L .76047 .68156 L p F P
0 g
s
.65 .757 .928 r
.35831 .68395 m .36673 .68141 L .36932 .68376 L p F P
0 g
s
.65 .757 .928 r
.36673 .68141 m .35831 .68395 L .35571 .6816 L p F P
0 g
s
.651 .758 .928 r
.62775 .68398 m .63661 .68143 L .63879 .68378 L p F P
0 g
s
.651 .758 .928 r
.63661 .68143 m .62775 .68398 L .62555 .68163 L p F P
0 g
s
.65 .758 .928 r
.49303 .68398 m .50167 .68144 L .50406 .68379 L p F P
0 g
s
.65 .758 .928 r
.50167 .68144 m .49303 .68398 L .49063 .68163 L p F P
0 g
s
.652 .759 .928 r
.90822 .68342 m .91754 .68084 L .9193 .68318 L p F P
0 g
s
.652 .759 .928 r
.91754 .68084 m .90822 .68342 L .90645 .68108 L p F P
0 g
s
.651 .758 .928 r
.78262 .68115 m .77352 .6837 L .77154 .68136 L p F P
0 g
s
.651 .758 .928 r
.77352 .6837 m .78262 .68115 L .78459 .6835 L p F P
0 g
s
.65 .757 .928 r
.36932 .68376 m .37776 .68122 L .38034 .68357 L p F P
0 g
s
.65 .757 .928 r
.37776 .68122 m .36932 .68376 L .36673 .68141 L p F P
0 g
s
.651 .758 .928 r
.63879 .68378 m .64767 .68123 L .64984 .68358 L p F P
0 g
s
.651 .758 .928 r
.64767 .68123 m .63879 .68378 L .63661 .68143 L p F P
0 g
s
.65 .758 .928 r
.50406 .68379 m .51272 .68124 L .51509 .68359 L p F P
0 g
s
.65 .758 .928 r
.51272 .68124 m .50406 .68379 L .50167 .68144 L p F P
0 g
s
.652 .76 .929 r
.92863 .6806 m .9193 .68318 L .91754 .68084 L p F P
0 g
s
.65 .757 .928 r
.25106 .67858 m .24282 .68112 L .24559 .68347 L p F P
0 g
s
.65 .757 .928 r
.24559 .68347 m .25383 .68094 L .25106 .67858 L p F P
0 g
s
.651 .758 .928 r
.78459 .6835 m .79371 .68094 L .79565 .68329 L p F P
0 g
s
.651 .758 .928 r
.79371 .68094 m .78459 .6835 L .78262 .68115 L p F P
0 g
s
.65 .757 .928 r
.38034 .68357 m .3888 .68103 L .39135 .68338 L p F P
0 g
s
.65 .757 .928 r
.3888 .68103 m .38034 .68357 L .37776 .68122 L p F P
0 g
s
.651 .758 .928 r
.64984 .68358 m .65874 .68103 L .66089 .68338 L p F P
0 g
s
.651 .758 .928 r
.65874 .68103 m .64984 .68358 L .64767 .68123 L p F P
0 g
s
.65 .758 .928 r
.51509 .68359 m .52377 .68105 L .52612 .6834 L p F P
0 g
s
.65 .758 .928 r
.52377 .68105 m .51509 .68359 L .51272 .68124 L p F P
0 g
s
.651 .758 .928 r
.79565 .68329 m .80479 .68073 L .80672 .68308 L p F P
0 g
s
.651 .758 .928 r
.80479 .68073 m .79565 .68329 L .79371 .68094 L p F P
0 g
s
.65 .757 .928 r
.25659 .68329 m .26485 .68075 L .26759 .68311 L p F P
0 g
s
.65 .757 .928 r
.26209 .67839 m .25383 .68094 L .25659 .68329 L p F P
0 g
s
.65 .757 .928 r
.25659 .68329 m .26485 .68075 L .26209 .67839 L p F P
0 g
s
.651 .758 .928 r
.66089 .68338 m .66981 .68083 L .67194 .68318 L p F P
0 g
s
.651 .758 .928 r
.66981 .68083 m .66089 .68338 L .65874 .68103 L p F P
0 g
s
.65 .757 .928 r
.39135 .68338 m .39983 .68083 L .40237 .68319 L p F P
0 g
s
.65 .757 .928 r
.39983 .68083 m .39135 .68338 L .3888 .68103 L p F P
0 g
s
.65 .758 .928 r
.52612 .6834 m .53482 .68085 L .53716 .6832 L p F P
0 g
s
.65 .758 .928 r
.53482 .68085 m .52612 .6834 L .52377 .68105 L p F P
0 g
s
.651 .758 .928 r
.80672 .68308 m .81588 .68052 L .81779 .68287 L p F P
0 g
s
.651 .758 .928 r
.81588 .68052 m .80672 .68308 L .80479 .68073 L p F P
0 g
s
.65 .757 .928 r
.26759 .68311 m .27587 .68057 L .2786 .68292 L p F P
0 g
s
.65 .757 .928 r
.27587 .68057 m .26759 .68311 L .26485 .68075 L p F P
0 g
s
.651 .758 .928 r
.67194 .68318 m .68088 .68063 L .683 .68298 L p F P
0 g
s
.651 .758 .928 r
.68088 .68063 m .67194 .68318 L .66981 .68083 L p F P
0 g
s
.65 .757 .928 r
.40237 .68319 m .41087 .68064 L .41339 .68299 L p F P
0 g
s
.65 .757 .928 r
.41087 .68064 m .40237 .68319 L .39983 .68083 L p F P
0 g
s
.65 .758 .928 r
.53716 .6832 m .54588 .68065 L .5482 .68301 L p F P
0 g
s
.65 .758 .928 r
.54588 .68065 m .53716 .6832 L .53482 .68085 L p F P
0 g
s
.651 .758 .928 r
.81779 .68287 m .82697 .68031 L .82887 .68265 L p F P
0 g
s
.651 .758 .928 r
.82697 .68031 m .81779 .68287 L .81588 .68052 L p F P
0 g
s
.65 .757 .928 r
.2786 .68292 m .28689 .68038 L .2896 .68274 L p F P
0 g
s
.65 .757 .928 r
.28689 .68038 m .2786 .68292 L .27587 .68057 L p F P
0 g
s
.651 .758 .928 r
.683 .68298 m .69196 .68043 L .69406 .68278 L p F P
0 g
s
.651 .758 .928 r
.69196 .68043 m .683 .68298 L .68088 .68063 L p F P
0 g
s
.65 .757 .928 r
.41339 .68299 m .42191 .68045 L .42442 .6828 L p F P
0 g
s
.65 .757 .928 r
.42191 .68045 m .41339 .68299 L .41087 .68064 L p F P
0 g
s
.65 .758 .928 r
.5482 .68301 m .55693 .68046 L .55924 .68281 L p F P
0 g
s
.65 .758 .928 r
.55693 .68046 m .5482 .68301 L .54588 .68065 L p F P
0 g
s
.651 .758 .928 r
.82887 .68265 m .83806 .68009 L .83994 .68244 L p F P
0 g
s
.651 .758 .928 r
.83806 .68009 m .82887 .68265 L .82697 .68031 L p F P
0 g
s
.65 .757 .928 r
.2896 .68274 m .29792 .6802 L .30061 .68255 L p F P
0 g
s
.65 .757 .928 r
.29792 .6802 m .2896 .68274 L .28689 .68038 L p F P
0 g
s
.651 .758 .928 r
.69406 .68278 m .70303 .68023 L .70512 .68258 L p F P
0 g
s
.651 .758 .928 r
.70303 .68023 m .69406 .68278 L .69196 .68043 L p F P
0 g
s
0 0 .346 r
.5258 .44174 m .52578 .44178 L .52578 .43792 L p F P
0 g
s
0 0 .346 r
.52578 .43792 m .5258 .43788 L .5258 .44174 L p F P
0 g
s
.762 .5 .538 r
.52572 .44177 m .52578 .44178 L .52578 .43792 L p F P
0 g
s
.762 .5 .538 r
.52578 .43792 m .52572 .43791 L .52572 .44177 L p F P
0 g
s
.65 .757 .928 r
.42442 .6828 m .43295 .68025 L .43545 .68261 L p F P
0 g
s
.65 .757 .928 r
.43295 .68025 m .42442 .6828 L .42191 .68045 L p F P
0 g
s
0 0 .347 r
.52574 .43786 m .52572 .43791 L .52572 .44177 L p F P
0 g
s
.65 .758 .928 r
.55924 .68281 m .568 .68026 L .57028 .68261 L p F P
0 g
s
.65 .758 .928 r
.568 .68026 m .55924 .68281 L .55693 .68046 L p F P
0 g
s
.762 .501 .539 r
.52574 .43786 m .5258 .43788 L .5258 .44174 L p F P
0 g
s
.762 .501 .539 r
.5258 .44174 m .52574 .44173 L .52574 .43786 L p F P
0 g
s
0 0 .347 r
.52572 .44177 m .52574 .44173 L .52574 .43786 L p F P
0 g
s
.651 .758 .928 r
.83994 .68244 m .84916 .67987 L .85102 .68222 L p F P
0 g
s
.651 .758 .928 r
.84916 .67987 m .83994 .68244 L .83806 .68009 L p F P
0 g
s
.65 .757 .928 r
.30061 .68255 m .30895 .68001 L .31163 .68236 L p F P
0 g
s
.65 .757 .928 r
.30895 .68001 m .30061 .68255 L .29792 .6802 L p F P
0 g
s
.651 .758 .928 r
.70512 .68258 m .71412 .68003 L .71618 .68238 L p F P
0 g
s
.651 .758 .928 r
.71412 .68003 m .70512 .68258 L .70303 .68023 L p F P
0 g
s
.65 .758 .928 r
.43545 .68261 m .444 .68006 L .44648 .68241 L p F P
0 g
s
.65 .757 .928 r
.444 .68006 m .43545 .68261 L .43295 .68025 L p F P
0 g
s
.65 .758 .928 r
.57028 .68261 m .57906 .68006 L .58133 .68242 L p F P
0 g
s
.65 .758 .928 r
.57906 .68006 m .57028 .68261 L .568 .68026 L p F P
0 g
s
.651 .759 .928 r
.85102 .68222 m .86025 .67965 L .8621 .682 L p F P
0 g
s
.651 .759 .928 r
.86025 .67965 m .85102 .68222 L .84916 .67987 L p F P
0 g
s
.65 .757 .928 r
.31163 .68236 m .31998 .67982 L .32264 .68217 L p F P
0 g
s
.65 .757 .928 r
.31998 .67982 m .31163 .68236 L .30895 .68001 L p F P
0 g
s
.651 .758 .928 r
.71618 .68238 m .7252 .67982 L .72725 .68218 L p F P
0 g
s
.651 .758 .928 r
.7252 .67982 m .71618 .68238 L .71412 .68003 L p F P
0 g
s
.65 .758 .928 r
.44648 .68241 m .45505 .67986 L .45751 .68222 L p F P
0 g
s
.65 .758 .928 r
.45505 .67986 m .44648 .68241 L .444 .68006 L p F P
0 g
s
.65 .758 .928 r
.58133 .68242 m .59013 .67986 L .59238 .68222 L p F P
0 g
s
.65 .758 .928 r
.59013 .67986 m .58133 .68242 L .57906 .68006 L p F P
0 g
s
.651 .759 .928 r
.8621 .682 m .87135 .67943 L .87319 .68177 L p F P
0 g
s
.651 .759 .928 r
.87135 .67943 m .8621 .682 L .86025 .67965 L p F P
0 g
s
.65 .757 .928 r
.33101 .67963 m .32264 .68217 L .31998 .67982 L p F P
0 g
s
.65 .757 .928 r
.32264 .68217 m .33101 .67963 L .33366 .68199 L p F P
0 g
s
.651 .758 .928 r
.72725 .68218 m .73628 .67962 L .73832 .68197 L p F P
0 g
s
.651 .758 .928 r
.73628 .67962 m .72725 .68218 L .7252 .67982 L p F P
0 g
s
.65 .758 .928 r
.45751 .68222 m .4661 .67967 L .46855 .68202 L p F P
0 g
s
.65 .758 .928 r
.4661 .67967 m .45751 .68222 L .45505 .67986 L p F P
0 g
s
.65 .758 .928 r
.59238 .68222 m .60119 .67967 L .60343 .68202 L p F P
0 g
s
.65 .758 .928 r
.60119 .67967 m .59238 .68222 L .59013 .67986 L p F P
0 g
s
.651 .759 .928 r
.87319 .68177 m .88246 .6792 L .88427 .68155 L p F P
0 g
s
.651 .759 .928 r
.88246 .6792 m .87319 .68177 L .87135 .67943 L p F P
0 g
s
.651 .758 .928 r
.73832 .68197 m .74737 .67941 L .74939 .68177 L p F P
0 g
s
.651 .758 .928 r
.74737 .67941 m .73832 .68197 L .73628 .67962 L p F P
0 g
s
.65 .757 .928 r
.33366 .68199 m .34205 .67944 L .34468 .6818 L p F P
0 g
s
.65 .757 .928 r
.34205 .67944 m .33366 .68199 L .33101 .67963 L p F P
0 g
s
.65 .758 .928 r
.60343 .68202 m .61227 .67947 L .61449 .68182 L p F P
0 g
s
.65 .758 .928 r
.61227 .67947 m .60343 .68202 L .60119 .67967 L p F P
0 g
s
.65 .758 .928 r
.46855 .68202 m .47716 .67947 L .47959 .68183 L p F P
0 g
s
.65 .758 .928 r
.47716 .67947 m .46855 .68202 L .4661 .67967 L p F P
0 g
s
.651 .759 .928 r
.88427 .68155 m .89356 .67897 L .89536 .68132 L p F P
0 g
s
.651 .759 .928 r
.89356 .67897 m .88427 .68155 L .88246 .6792 L p F P
0 g
s
.651 .758 .928 r
.74939 .68177 m .75846 .67921 L .76047 .68156 L p F P
0 g
s
.651 .758 .928 r
.75846 .67921 m .74939 .68177 L .74737 .67941 L p F P
0 g
s
.65 .757 .928 r
.34468 .6818 m .35309 .67925 L .35571 .6816 L p F P
0 g
s
.65 .757 .928 r
.35309 .67925 m .34468 .6818 L .34205 .67944 L p F P
0 g
s
.651 .758 .928 r
.61449 .68182 m .62334 .67927 L .62555 .68163 L p F P
0 g
s
.651 .758 .928 r
.62334 .67927 m .61449 .68182 L .61227 .67947 L p F P
0 g
s
.65 .758 .928 r
.47959 .68183 m .48822 .67928 L .49063 .68163 L p F P
0 g
s
.65 .758 .928 r
.48822 .67928 m .47959 .68183 L .47716 .67947 L p F P
0 g
s
.651 .759 .928 r
.89536 .68132 m .90467 .67874 L .90645 .68108 L p F P
0 g
s
.651 .759 .928 r
.90467 .67874 m .89536 .68132 L .89356 .67897 L p F P
0 g
s
.651 .758 .928 r
.76956 .679 m .76047 .68156 L .75846 .67921 L p F P
0 g
s
.651 .758 .928 r
.76047 .68156 m .76956 .679 L .77154 .68136 L p F P
0 g
s
.65 .757 .928 r
.35571 .6816 m .36413 .67905 L .36673 .68141 L p F P
0 g
s
.65 .757 .928 r
.36413 .67905 m .35571 .6816 L .35309 .67925 L p F P
0 g
s
.651 .758 .928 r
.62555 .68163 m .63442 .67907 L .63661 .68143 L p F P
0 g
s
.651 .758 .928 r
.63442 .67907 m .62555 .68163 L .62334 .67927 L p F P
0 g
s
.65 .758 .928 r
.49063 .68163 m .49928 .67908 L .50167 .68144 L p F P
0 g
s
.65 .758 .928 r
.49928 .67908 m .49063 .68163 L .48822 .67928 L p F P
0 g
s
.652 .759 .928 r
.90645 .68108 m .91578 .6785 L .91754 .68084 L p F P
0 g
s
.652 .759 .928 r
.91578 .6785 m .90645 .68108 L .90467 .67874 L p F P
0 g
s
.651 .758 .928 r
.77154 .68136 m .78065 .6788 L .78262 .68115 L p F P
0 g
s
.651 .758 .928 r
.78065 .6788 m .77154 .68136 L .76956 .679 L p F P
0 g
s
.65 .757 .928 r
.36673 .68141 m .37518 .67886 L .37776 .68122 L p F P
0 g
s
.65 .757 .928 r
.37518 .67886 m .36673 .68141 L .36413 .67905 L p F P
0 g
s
.651 .758 .928 r
.63661 .68143 m .6455 .67887 L .64767 .68123 L p F P
0 g
s
.651 .758 .928 r
.6455 .67887 m .63661 .68143 L .63442 .67907 L p F P
0 g
s
.65 .758 .928 r
.50167 .68144 m .51034 .67888 L .51272 .68124 L p F P
0 g
s
.65 .758 .928 r
.51034 .67888 m .50167 .68144 L .49928 .67908 L p F P
0 g
s
.652 .76 .929 r
.91754 .68084 m .92689 .67825 L .92863 .6806 L p F P
0 g
s
.652 .76 .928 r
.92689 .67825 m .91754 .68084 L .91578 .6785 L p F P
0 g
s
.65 .757 .928 r
.24828 .67621 m .24003 .67876 L .24282 .68112 L p F P
0 g
s
.65 .757 .928 r
.24282 .68112 m .25106 .67858 L .24828 .67621 L p F P
0 g
s
.651 .758 .928 r
.79175 .67859 m .78262 .68115 L .78065 .6788 L p F P
0 g
s
.651 .758 .928 r
.78262 .68115 m .79175 .67859 L .79371 .68094 L p F P
0 g
s
.652 .76 .929 r
.938 .678 m .92863 .6806 L .92689 .67825 L p F P
0 g
s
.65 .757 .928 r
.37776 .68122 m .38623 .67867 L .3888 .68103 L p F P
0 g
s
.65 .757 .928 r
.38623 .67867 m .37776 .68122 L .37518 .67886 L p F P
0 g
s
.651 .758 .928 r
.64767 .68123 m .65658 .67867 L .65874 .68103 L p F P
0 g
s
.651 .758 .928 r
.65658 .67867 m .64767 .68123 L .6455 .67887 L p F P
0 g
s
.65 .758 .928 r
.52141 .67869 m .51272 .68124 L .51034 .67888 L p F P
0 g
s
.65 .758 .928 r
.51272 .68124 m .52141 .67869 L .52377 .68105 L p F P
0 g
s
.65 .757 .928 r
.25933 .67602 m .25106 .67858 L .25383 .68094 L p F P
0 g
s
.65 .757 .928 r
.25383 .68094 m .26209 .67839 L .25933 .67602 L p F P
0 g
s
.651 .758 .928 r
.79371 .68094 m .80286 .67838 L .80479 .68073 L p F P
0 g
s
.651 .758 .928 r
.80286 .67838 m .79371 .68094 L .79175 .67859 L p F P
0 g
s
.65 .757 .928 r
.3888 .68103 m .39728 .67847 L .39983 .68083 L p F P
0 g
s
.65 .757 .928 r
.39728 .67847 m .3888 .68103 L .38623 .67867 L p F P
0 g
s
.651 .758 .928 r
.65874 .68103 m .66767 .67847 L .66981 .68083 L p F P
0 g
s
.651 .758 .928 r
.66767 .67847 m .65874 .68103 L .65658 .67867 L p F P
0 g
s
.65 .758 .928 r
.52377 .68105 m .53248 .67849 L .53482 .68085 L p F P
0 g
s
.65 .758 .928 r
.53248 .67849 m .52377 .68105 L .52141 .67869 L p F P
0 g
s
.651 .758 .928 r
.80479 .68073 m .81396 .67816 L .81588 .68052 L p F P
0 g
s
.651 .758 .928 r
.81396 .67816 m .80479 .68073 L .80286 .67838 L p F P
0 g
s
.65 .757 .928 r
.26485 .68075 m .27313 .67821 L .27587 .68057 L p F P
0 g
s
.65 .757 .928 r
.27038 .67584 m .26209 .67839 L .26485 .68075 L p F P
0 g
s
.65 .757 .928 r
.26485 .68075 m .27313 .67821 L .27038 .67584 L p F P
0 g
s
0 0 .347 r
.5258 .44561 m .52578 .44565 L .52578 .44178 L p F P
0 g
s
0 0 .347 r
.52578 .44178 m .5258 .44174 L .5258 .44561 L p F P
0 g
s
.762 .5 .538 r
.52572 .44564 m .52578 .44565 L .52578 .44178 L p F P
0 g
s
.762 .5 .538 r
.52578 .44178 m .52572 .44177 L .52572 .44564 L p F P
0 g
s
.651 .758 .928 r
.66981 .68083 m .67876 .67827 L .68088 .68063 L p F P
0 g
s
.651 .758 .928 r
.67876 .67827 m .66981 .68083 L .66767 .67847 L p F P
0 g
s
.65 .757 .928 r
.39983 .68083 m .40834 .67828 L .41087 .68064 L p F P
0 g
s
.65 .757 .928 r
.40834 .67828 m .39983 .68083 L .39728 .67847 L p F P
0 g
s
0 0 .347 r
.52574 .44173 m .52572 .44177 L .52572 .44564 L p F P
0 g
s
.65 .758 .928 r
.53482 .68085 m .54355 .67829 L .54588 .68065 L p F P
0 g
s
.65 .758 .928 r
.54355 .67829 m .53482 .68085 L .53248 .67849 L p F P
0 g
s
.762 .501 .539 r
.52574 .44173 m .5258 .44174 L .5258 .44561 L p F P
0 g
s
.762 .501 .539 r
.5258 .44561 m .52574 .4456 L .52574 .44173 L p F P
0 g
s
0 0 .347 r
.52572 .44564 m .52574 .4456 L .52574 .44173 L p F P
0 g
s
.651 .758 .928 r
.81588 .68052 m .82507 .67795 L .82697 .68031 L p F P
0 g
s
.651 .758 .928 r
.82507 .67795 m .81588 .68052 L .81396 .67816 L p F P
0 g
s
.65 .757 .928 r
.27587 .68057 m .28417 .67802 L .28689 .68038 L p F P
0 g
s
.65 .757 .928 r
.28417 .67802 m .27587 .68057 L .27313 .67821 L p F P
0 g
s
.651 .758 .928 r
.68088 .68063 m .68985 .67807 L .69196 .68043 L p F P
0 g
s
.651 .758 .928 r
.68985 .67807 m .68088 .68063 L .67876 .67827 L p F P
0 g
s
.65 .757 .928 r
.41087 .68064 m .41939 .67809 L .42191 .68045 L p F P
0 g
s
.65 .757 .928 r
.41939 .67809 m .41087 .68064 L .40834 .67828 L p F P
0 g
s
.65 .758 .928 r
.54588 .68065 m .55462 .6781 L .55693 .68046 L p F P
0 g
s
.65 .758 .928 r
.55462 .6781 m .54588 .68065 L .54355 .67829 L p F P
0 g
s
.651 .758 .928 r
.82697 .68031 m .83618 .67774 L .83806 .68009 L p F P
0 g
s
.651 .758 .928 r
.83618 .67774 m .82697 .68031 L .82507 .67795 L p F P
0 g
s
.65 .757 .928 r
.28689 .68038 m .29521 .67783 L .29792 .6802 L p F P
0 g
s
.65 .757 .928 r
.29521 .67783 m .28689 .68038 L .28417 .67802 L p F P
0 g
s
.651 .758 .928 r
.69196 .68043 m .70094 .67787 L .70303 .68023 L p F P
0 g
s
.651 .758 .928 r
.70094 .67787 m .69196 .68043 L .68985 .67807 L p F P
0 g
s
.65 .757 .928 r
.42191 .68045 m .43045 .67789 L .43295 .68025 L p F P
0 g
s
.65 .757 .928 r
.43045 .67789 m .42191 .68045 L .41939 .67809 L p F P
0 g
s
.65 .758 .928 r
.55693 .68046 m .5657 .6779 L .568 .68026 L p F P
0 g
s
.65 .758 .928 r
.5657 .6779 m .55693 .68046 L .55462 .6781 L p F P
0 g
s
.651 .758 .928 r
.83806 .68009 m .84729 .67752 L .84916 .67987 L p F P
0 g
s
.651 .758 .928 r
.84729 .67752 m .83806 .68009 L .83618 .67774 L p F P
0 g
s
.65 .757 .928 r
.29792 .6802 m .30626 .67764 L .30895 .68001 L p F P
0 g
s
.65 .757 .928 r
.30626 .67764 m .29792 .6802 L .29521 .67783 L p F P
0 g
s
.651 .758 .928 r
.70303 .68023 m .71204 .67766 L .71412 .68003 L p F P
0 g
s
.651 .758 .928 r
.71204 .67766 m .70303 .68023 L .70094 .67787 L p F P
0 g
s
.65 .757 .928 r
.43295 .68025 m .44152 .6777 L .444 .68006 L p F P
0 g
s
.65 .757 .928 r
.44152 .6777 m .43295 .68025 L .43045 .67789 L p F P
0 g
s
.65 .758 .928 r
.568 .68026 m .57678 .6777 L .57906 .68006 L p F P
0 g
s
.65 .758 .928 r
.57678 .6777 m .568 .68026 L .5657 .6779 L p F P
0 g
s
.651 .759 .928 r
.84916 .67987 m .8584 .6773 L .86025 .67965 L p F P
0 g
s
.651 .759 .928 r
.8584 .6773 m .84916 .67987 L .84729 .67752 L p F P
0 g
s
.65 .757 .928 r
.30895 .68001 m .31731 .67746 L .31998 .67982 L p F P
0 g
s
.65 .757 .928 r
.31731 .67746 m .30895 .68001 L .30626 .67764 L p F P
0 g
s
.651 .758 .928 r
.71412 .68003 m .72314 .67746 L .7252 .67982 L p F P
0 g
s
.651 .758 .928 r
.72314 .67746 m .71412 .68003 L .71204 .67766 L p F P
0 g
s
.65 .758 .928 r
.444 .68006 m .45258 .6775 L .45505 .67986 L p F P
0 g
s
.65 .758 .928 r
.45258 .6775 m .444 .68006 L .44152 .6777 L p F P
0 g
s
.65 .758 .928 r
.57906 .68006 m .58786 .6775 L .59013 .67986 L p F P
0 g
s
.65 .758 .928 r
.58786 .6775 m .57906 .68006 L .57678 .6777 L p F P
0 g
s
.651 .759 .928 r
.86025 .67965 m .86952 .67707 L .87135 .67943 L p F P
0 g
s
.651 .759 .928 r
.86952 .67707 m .86025 .67965 L .8584 .6773 L p F P
0 g
s
.65 .757 .928 r
.31998 .67982 m .32836 .67726 L .33101 .67963 L p F P
0 g
s
.65 .757 .928 r
.32836 .67726 m .31998 .67982 L .31731 .67746 L p F P
0 g
s
.651 .758 .928 r
.7252 .67982 m .73424 .67726 L .73628 .67962 L p F P
0 g
s
.651 .758 .928 r
.73424 .67726 m .7252 .67982 L .72314 .67746 L p F P
0 g
s
.65 .758 .928 r
.45505 .67986 m .46365 .6773 L .4661 .67967 L p F P
0 g
s
.65 .758 .928 r
.46365 .6773 m .45505 .67986 L .45258 .6775 L p F P
0 g
s
.65 .758 .928 r
.59013 .67986 m .59895 .6773 L .60119 .67967 L p F P
0 g
s
.65 .758 .928 r
.59895 .6773 m .59013 .67986 L .58786 .6775 L p F P
0 g
s
.651 .759 .928 r
.87135 .67943 m .88064 .67685 L .88246 .6792 L p F P
0 g
s
.651 .759 .928 r
.88064 .67685 m .87135 .67943 L .86952 .67707 L p F P
0 g
s
.651 .758 .928 r
.73628 .67962 m .74535 .67705 L .74737 .67941 L p F P
0 g
s
.651 .758 .928 r
.74535 .67705 m .73628 .67962 L .73424 .67726 L p F P
0 g
s
.65 .757 .928 r
.33941 .67707 m .33101 .67963 L .32836 .67726 L p F P
0 g
s
.65 .757 .928 r
.33101 .67963 m .33941 .67707 L .34205 .67944 L p F P
0 g
s
.65 .758 .928 r
.60119 .67967 m .61004 .6771 L .61227 .67947 L p F P
0 g
s
.65 .758 .928 r
.61004 .6771 m .60119 .67967 L .59895 .6773 L p F P
0 g
s
.65 .758 .928 r
.4661 .67967 m .47472 .67711 L .47716 .67947 L p F P
0 g
s
.65 .758 .928 r
.47472 .67711 m .4661 .67967 L .46365 .6773 L p F P
0 g
s
.651 .759 .928 r
.88246 .6792 m .89176 .67662 L .89356 .67897 L p F P
0 g
s
.651 .759 .928 r
.89176 .67662 m .88246 .6792 L .88064 .67685 L p F P
0 g
s
.651 .758 .928 r
.74737 .67941 m .75646 .67685 L .75846 .67921 L p F P
0 g
s
.651 .758 .928 r
.75646 .67685 m .74737 .67941 L .74535 .67705 L p F P
0 g
s
.65 .757 .928 r
.34205 .67944 m .35047 .67688 L .35309 .67925 L p F P
0 g
s
.65 .757 .928 r
.35047 .67688 m .34205 .67944 L .33941 .67707 L p F P
0 g
s
.651 .758 .928 r
.61227 .67947 m .62113 .6769 L .62334 .67927 L p F P
0 g
s
.651 .758 .928 r
.62113 .6769 m .61227 .67947 L .61004 .6771 L p F P
0 g
s
.65 .758 .928 r
.47716 .67947 m .4858 .67691 L .48822 .67928 L p F P
0 g
s
.65 .758 .928 r
.4858 .67691 m .47716 .67947 L .47472 .67711 L p F P
0 g
s
.651 .759 .928 r
.89356 .67897 m .90288 .67638 L .90467 .67874 L p F P
0 g
s
.651 .759 .928 r
.90288 .67638 m .89356 .67897 L .89176 .67662 L p F P
0 g
s
.651 .758 .928 r
.75846 .67921 m .76757 .67664 L .76956 .679 L p F P
0 g
s
.651 .758 .928 r
.76757 .67664 m .75846 .67921 L .75646 .67685 L p F P
0 g
s
.65 .757 .928 r
.35309 .67925 m .36153 .67669 L .36413 .67905 L p F P
0 g
s
.65 .757 .928 r
.36153 .67669 m .35309 .67925 L .35047 .67688 L p F P
0 g
s
.651 .758 .928 r
.62334 .67927 m .63222 .67671 L .63442 .67907 L p F P
0 g
s
.651 .758 .928 r
.63222 .67671 m .62334 .67927 L .62113 .6769 L p F P
0 g
s
.65 .758 .928 r
.48822 .67928 m .49687 .67672 L .49928 .67908 L p F P
0 g
s
.65 .758 .928 r
.49687 .67672 m .48822 .67928 L .4858 .67691 L p F P
0 g
s
.652 .759 .928 r
.90467 .67874 m .91401 .67615 L .91578 .6785 L p F P
0 g
s
.652 .759 .928 r
.91401 .67615 m .90467 .67874 L .90288 .67638 L p F P
0 g
s
.651 .758 .928 r
.77868 .67643 m .76956 .679 L .76757 .67664 L p F P
0 g
s
.651 .758 .928 r
.76956 .679 m .77868 .67643 L .78065 .6788 L p F P
0 g
s
.65 .757 .928 r
.36413 .67905 m .37259 .6765 L .37518 .67886 L p F P
0 g
s
.65 .757 .928 r
.37259 .6765 m .36413 .67905 L .36153 .67669 L p F P
0 g
s
.651 .758 .928 r
.63442 .67907 m .64332 .67651 L .6455 .67887 L p F P
0 g
s
.651 .758 .928 r
.64332 .67651 m .63442 .67907 L .63222 .67671 L p F P
0 g
s
.65 .758 .928 r
.49928 .67908 m .50795 .67652 L .51034 .67888 L p F P
0 g
s
.65 .758 .928 r
.50795 .67652 m .49928 .67908 L .49687 .67672 L p F P
0 g
s
.652 .76 .928 r
.91578 .6785 m .92513 .6759 L .92689 .67825 L p F P
0 g
s
.652 .759 .928 r
.92513 .6759 m .91578 .6785 L .91401 .67615 L p F P
0 g
s
.65 .757 .928 r
.24549 .67383 m .23723 .67639 L .24003 .67876 L p F P
0 g
s
.65 .757 .928 r
.24003 .67876 m .24828 .67621 L .24549 .67383 L p F P
0 g
s
.651 .758 .928 r
.78065 .6788 m .78979 .67622 L .79175 .67859 L p F P
0 g
s
.651 .758 .928 r
.78979 .67622 m .78065 .6788 L .77868 .67643 L p F P
0 g
s
0 0 .347 r
.5258 .44949 m .52578 .44953 L .52578 .44565 L p F P
0 g
s
0 0 .347 r
.52578 .44565 m .5258 .44561 L .5258 .44949 L p F P
0 g
s
.762 .5 .538 r
.52572 .44952 m .52578 .44953 L .52578 .44565 L p F P
0 g
s
.762 .5 .538 r
.52578 .44565 m .52572 .44564 L .52572 .44952 L p F P
0 g
s
.65 .757 .928 r
.37518 .67886 m .38366 .6763 L .38623 .67867 L p F P
0 g
s
.65 .757 .928 r
.38366 .6763 m .37518 .67886 L .37259 .6765 L p F P
0 g
s
.652 .76 .929 r
.92689 .67825 m .93626 .67566 L .938 .678 L p F P
0 g
s
.652 .76 .928 r
.93626 .67566 m .92689 .67825 L .92513 .6759 L p F P
0 g
s
.651 .758 .928 r
.6455 .67887 m .65442 .67631 L .65658 .67867 L p F P
0 g
s
.651 .758 .928 r
.65442 .67631 m .6455 .67887 L .64332 .67651 L p F P
0 g
s
0 0 .347 r
.52574 .4456 m .52572 .44564 L .52572 .44952 L p F P
0 g
s
.65 .758 .928 r
.51034 .67888 m .51904 .67632 L .52141 .67869 L p F P
0 g
s
.65 .758 .928 r
.51904 .67632 m .51034 .67888 L .50795 .67652 L p F P
0 g
s
.762 .5 .539 r
.52574 .4456 m .5258 .44561 L .5258 .44949 L p F P
0 g
s
.762 .5 .539 r
.5258 .44949 m .52574 .44948 L .52574 .4456 L p F P
0 g
s
0 0 .347 r
.52572 .44952 m .52574 .44948 L .52574 .4456 L p F P
0 g
s
.65 .757 .928 r
.25656 .67365 m .24828 .67621 L .25106 .67858 L p F P
0 g
s
.65 .757 .928 r
.25106 .67858 m .25933 .67602 L .25656 .67365 L p F P
0 g
s
.651 .758 .928 r
.80091 .67601 m .79175 .67859 L .78979 .67622 L p F P
0 g
s
.651 .758 .928 r
.79175 .67859 m .80091 .67601 L .80286 .67838 L p F P
0 g
s
.652 .76 .929 r
.94739 .6754 m .938 .678 L .93626 .67566 L p F P
0 g
s
.65 .757 .928 r
.38623 .67867 m .39472 .67611 L .39728 .67847 L p F P
0 g
s
.65 .757 .928 r
.39472 .67611 m .38623 .67867 L .38366 .6763 L p F P
0 g
s
.651 .758 .928 r
.65658 .67867 m .66552 .6761 L .66767 .67847 L p F P
0 g
s
.651 .758 .928 r
.66552 .6761 m .65658 .67867 L .65442 .67631 L p F P
0 g
s
.65 .758 .928 r
.53012 .67612 m .52141 .67869 L .51904 .67632 L p F P
0 g
s
.65 .758 .928 r
.52141 .67869 m .53012 .67612 L .53248 .67849 L p F P
0 g
s
.651 .758 .928 r
.80286 .67838 m .81203 .6758 L .81396 .67816 L p F P
0 g
s
.651 .758 .928 r
.81203 .6758 m .80286 .67838 L .80091 .67601 L p F P
0 g
s
.65 .757 .928 r
.26763 .67346 m .25933 .67602 L .26209 .67839 L p F P
0 g
s
.65 .757 .928 r
.26209 .67839 m .27038 .67584 L .26763 .67346 L p F P
0 g
s
.651 .758 .928 r
.66767 .67847 m .67663 .6759 L .67876 .67827 L p F P
0 g
s
.651 .758 .928 r
.67663 .6759 m .66767 .67847 L .66552 .6761 L p F P
0 g
s
.65 .757 .928 r
.39728 .67847 m .40579 .67591 L .40834 .67828 L p F P
0 g
s
.65 .757 .928 r
.40579 .67591 m .39728 .67847 L .39472 .67611 L p F P
0 g
s
.65 .758 .928 r
.53248 .67849 m .54121 .67593 L .54355 .67829 L p F P
0 g
s
.65 .758 .928 r
.54121 .67593 m .53248 .67849 L .53012 .67612 L p F P
0 g
s
.651 .758 .928 r
.81396 .67816 m .82316 .67559 L .82507 .67795 L p F P
0 g
s
.651 .758 .928 r
.82316 .67559 m .81396 .67816 L .81203 .6758 L p F P
0 g
s
.65 .757 .928 r
.27313 .67821 m .28144 .67565 L .28417 .67802 L p F P
0 g
s
.65 .757 .928 r
.2787 .67328 m .27038 .67584 L .27313 .67821 L p F P
0 g
s
.65 .757 .928 r
.27313 .67821 m .28144 .67565 L .2787 .67328 L p F P
0 g
s
.651 .758 .928 r
.67876 .67827 m .68773 .6757 L .68985 .67807 L p F P
0 g
s
.651 .758 .928 r
.68773 .6757 m .67876 .67827 L .67663 .6759 L p F P
0 g
s
.65 .757 .928 r
.40834 .67828 m .41687 .67572 L .41939 .67809 L p F P
0 g
s
.65 .757 .928 r
.41687 .67572 m .40834 .67828 L .40579 .67591 L p F P
0 g
s
.65 .758 .928 r
.54355 .67829 m .5523 .67573 L .55462 .6781 L p F P
0 g
s
.65 .758 .928 r
.5523 .67573 m .54355 .67829 L .54121 .67593 L p F P
0 g
s
.651 .758 .928 r
.82507 .67795 m .83428 .67537 L .83618 .67774 L p F P
0 g
s
.651 .758 .928 r
.83428 .67537 m .82507 .67795 L .82316 .67559 L p F P
0 g
s
.65 .757 .928 r
.28417 .67802 m .2925 .67546 L .29521 .67783 L p F P
0 g
s
.65 .757 .928 r
.2925 .67546 m .28417 .67802 L .28144 .67565 L p F P
0 g
s
.651 .758 .928 r
.68985 .67807 m .69885 .6755 L .70094 .67787 L p F P
0 g
s
.651 .758 .928 r
.69885 .6755 m .68985 .67807 L .68773 .6757 L p F P
0 g
s
.65 .757 .928 r
.41939 .67809 m .42795 .67552 L .43045 .67789 L p F P
0 g
s
.65 .757 .928 r
.42795 .67552 m .41939 .67809 L .41687 .67572 L p F P
0 g
s
.65 .758 .928 r
.55462 .6781 m .5634 .67553 L .5657 .6779 L p F P
0 g
s
.65 .758 .928 r
.5634 .67553 m .55462 .6781 L .5523 .67573 L p F P
0 g
s
.651 .758 .928 r
.83618 .67774 m .84541 .67516 L .84729 .67752 L p F P
0 g
s
.651 .758 .928 r
.84541 .67516 m .83618 .67774 L .83428 .67537 L p F P
0 g
s
.65 .757 .928 r
.29521 .67783 m .30356 .67527 L .30626 .67764 L p F P
0 g
s
.65 .757 .928 r
.30356 .67527 m .29521 .67783 L .2925 .67546 L p F P
0 g
s
.651 .758 .928 r
.70094 .67787 m .70996 .6753 L .71204 .67766 L p F P
0 g
s
.651 .758 .928 r
.70996 .6753 m .70094 .67787 L .69885 .6755 L p F P
0 g
s
.65 .757 .928 r
.43045 .67789 m .43902 .67533 L .44152 .6777 L p F P
0 g
s
.65 .757 .928 r
.43902 .67533 m .43045 .67789 L .42795 .67552 L p F P
0 g
s
.65 .758 .928 r
.5657 .6779 m .57449 .67533 L .57678 .6777 L p F P
0 g
s
.65 .758 .928 r
.57449 .67533 m .5657 .6779 L .5634 .67553 L p F P
0 g
s
.651 .759 .928 r
.84729 .67752 m .85654 .67494 L .8584 .6773 L p F P
0 g
s
.651 .758 .928 r
.85654 .67494 m .84729 .67752 L .84541 .67516 L p F P
0 g
s
.65 .757 .928 r
.30626 .67764 m .31463 .67508 L .31731 .67746 L p F P
0 g
s
.65 .757 .928 r
.31463 .67508 m .30626 .67764 L .30356 .67527 L p F P
0 g
s
.651 .758 .928 r
.71204 .67766 m .72108 .67509 L .72314 .67746 L p F P
0 g
s
.651 .758 .928 r
.72108 .67509 m .71204 .67766 L .70996 .6753 L p F P
0 g
s
.65 .758 .928 r
.44152 .6777 m .45011 .67513 L .45258 .6775 L p F P
0 g
s
.65 .757 .928 r
.45011 .67513 m .44152 .6777 L .43902 .67533 L p F P
0 g
s
.65 .758 .928 r
.57678 .6777 m .58559 .67513 L .58786 .6775 L p F P
0 g
s
.65 .758 .928 r
.58559 .67513 m .57678 .6777 L .57449 .67533 L p F P
0 g
s
.651 .759 .928 r
.8584 .6773 m .86768 .67471 L .86952 .67707 L p F P
0 g
s
.651 .759 .928 r
.86768 .67471 m .8584 .6773 L .85654 .67494 L p F P
0 g
s
.65 .757 .928 r
.31731 .67746 m .32569 .67489 L .32836 .67726 L p F P
0 g
s
.65 .757 .928 r
.32569 .67489 m .31731 .67746 L .31463 .67508 L p F P
0 g
s
.651 .758 .928 r
.72314 .67746 m .73219 .67489 L .73424 .67726 L p F P
0 g
s
.651 .758 .928 r
.73219 .67489 m .72314 .67746 L .72108 .67509 L p F P
0 g
s
.65 .758 .928 r
.45258 .6775 m .46119 .67493 L .46365 .6773 L p F P
0 g
s
.65 .758 .928 r
.46119 .67493 m .45258 .6775 L .45011 .67513 L p F P
0 g
s
.65 .758 .928 r
.58786 .6775 m .59669 .67493 L .59895 .6773 L p F P
0 g
s
.65 .758 .928 r
.59669 .67493 m .58786 .6775 L .58559 .67513 L p F P
0 g
s
.651 .759 .928 r
.86952 .67707 m .87881 .67449 L .88064 .67685 L p F P
0 g
s
.651 .759 .928 r
.87881 .67449 m .86952 .67707 L .86768 .67471 L p F P
0 g
s
.651 .758 .928 r
.73424 .67726 m .74332 .67468 L .74535 .67705 L p F P
0 g
s
.651 .758 .928 r
.74332 .67468 m .73424 .67726 L .73219 .67489 L p F P
0 g
s
.65 .757 .928 r
.32836 .67726 m .33676 .6747 L .33941 .67707 L p F P
0 g
s
.65 .757 .928 r
.33676 .6747 m .32836 .67726 L .32569 .67489 L p F P
0 g
s
.65 .758 .928 r
.59895 .6773 m .6078 .67473 L .61004 .6771 L p F P
0 g
s
.65 .758 .928 r
.6078 .67473 m .59895 .6773 L .59669 .67493 L p F P
0 g
s
.65 .758 .928 r
.46365 .6773 m .47228 .67474 L .47472 .67711 L p F P
0 g
s
.65 .758 .928 r
.47228 .67474 m .46365 .6773 L .46119 .67493 L p F P
0 g
s
.651 .759 .928 r
.88064 .67685 m .88995 .67426 L .89176 .67662 L p F P
0 g
s
.651 .759 .928 r
.88995 .67426 m .88064 .67685 L .87881 .67449 L p F P
0 g
s
.651 .758 .928 r
.74535 .67705 m .75444 .67448 L .75646 .67685 L p F P
0 g
s
.651 .758 .928 r
.75444 .67448 m .74535 .67705 L .74332 .67468 L p F P
0 g
s
.65 .757 .928 r
.34784 .67451 m .33941 .67707 L .33676 .6747 L p F P
0 g
s
.65 .757 .928 r
.33941 .67707 m .34784 .67451 L .35047 .67688 L p F P
0 g
s
.651 .758 .928 r
.61004 .6771 m .61891 .67453 L .62113 .6769 L p F P
0 g
s
.651 .758 .928 r
.61891 .67453 m .61004 .6771 L .6078 .67473 L p F P
0 g
s
.65 .758 .928 r
.47472 .67711 m .48337 .67454 L .4858 .67691 L p F P
0 g
s
.65 .758 .928 r
.48337 .67454 m .47472 .67711 L .47228 .67474 L p F P
0 g
s
.651 .759 .928 r
.89176 .67662 m .90109 .67402 L .90288 .67638 L p F P
0 g
s
.651 .759 .928 r
.90109 .67402 m .89176 .67662 L .88995 .67426 L p F P
0 g
s
.651 .758 .928 r
.75646 .67685 m .76557 .67427 L .76757 .67664 L p F P
0 g
s
.651 .758 .928 r
.76557 .67427 m .75646 .67685 L .75444 .67448 L p F P
0 g
s
.65 .757 .928 r
.35047 .67688 m .35891 .67432 L .36153 .67669 L p F P
0 g
s
.65 .757 .928 r
.35891 .67432 m .35047 .67688 L .34784 .67451 L p F P
0 g
s
0 0 .347 r
.5258 .45338 m .52578 .45342 L .52578 .44953 L p F P
0 g
s
0 0 .347 r
.52578 .44953 m .5258 .44949 L .5258 .45338 L p F P
0 g
s
.762 .5 .538 r
.52572 .45341 m .52578 .45342 L .52578 .44953 L p F P
0 g
s
.762 .5 .538 r
.52578 .44953 m .52572 .44952 L .52572 .45341 L p F P
0 g
s
.651 .758 .928 r
.62113 .6769 m .63002 .67433 L .63222 .67671 L p F P
0 g
s
.651 .758 .928 r
.63002 .67433 m .62113 .6769 L .61891 .67453 L p F P
0 g
s
0 0 .347 r
.52574 .44948 m .52572 .44952 L .52572 .45341 L p F P
0 g
s
.65 .758 .928 r
.4858 .67691 m .49447 .67434 L .49687 .67672 L p F P
0 g
s
.65 .758 .928 r
.49447 .67434 m .4858 .67691 L .48337 .67454 L p F P
0 g
s
.762 .5 .539 r
.52574 .44948 m .5258 .44949 L .5258 .45338 L p F P
0 g
s
.762 .5 .539 r
.5258 .45338 m .52574 .45337 L .52574 .44948 L p F P
0 g
s
0 0 .347 r
.52572 .45341 m .52574 .45337 L .52574 .44948 L p F P
0 g
s
.652 .759 .928 r
.90288 .67638 m .91223 .67379 L .91401 .67615 L p F P
0 g
s
.652 .759 .928 r
.91223 .67379 m .90288 .67638 L .90109 .67402 L p F P
0 g
s
.651 .758 .928 r
.76757 .67664 m .7767 .67406 L .77868 .67643 L p F P
0 g
s
.651 .758 .928 r
.7767 .67406 m .76757 .67664 L .76557 .67427 L p F P
0 g
s
.65 .757 .928 r
.36153 .67669 m .36999 .67412 L .37259 .6765 L p F P
0 g
s
.65 .757 .928 r
.36999 .67412 m .36153 .67669 L .35891 .67432 L p F P
0 g
s
.651 .758 .928 r
.63222 .67671 m .64113 .67413 L .64332 .67651 L p F P
0 g
s
.651 .758 .928 r
.64113 .67413 m .63222 .67671 L .63002 .67433 L p F P
0 g
s
.65 .758 .928 r
.49687 .67672 m .50556 .67415 L .50795 .67652 L p F P
0 g
s
.65 .758 .928 r
.50556 .67415 m .49687 .67672 L .49447 .67434 L p F P
0 g
s
.652 .759 .928 r
.91401 .67615 m .92338 .67355 L .92513 .6759 L p F P
0 g
s
.652 .759 .928 r
.92338 .67355 m .91401 .67615 L .91223 .67379 L p F P
0 g
s
.65 .757 .928 r
.2427 .67145 m .23443 .67402 L .23723 .67639 L p F P
0 g
s
.65 .757 .928 r
.23723 .67639 m .24549 .67383 L .2427 .67145 L p F P
0 g
s
.651 .758 .928 r
.78783 .67385 m .77868 .67643 L .7767 .67406 L p F P
0 g
s
.651 .758 .928 r
.77868 .67643 m .78783 .67385 L .78979 .67622 L p F P
0 g
s
.65 .757 .928 r
.37259 .6765 m .38107 .67393 L .38366 .6763 L p F P
0 g
s
.65 .757 .928 r
.38107 .67393 m .37259 .6765 L .36999 .67412 L p F P
0 g
s
.651 .758 .928 r
.64332 .67651 m .65225 .67393 L .65442 .67631 L p F P
0 g
s
.651 .758 .928 r
.65225 .67393 m .64332 .67651 L .64113 .67413 L p F P
0 g
s
.65 .758 .928 r
.50795 .67652 m .51666 .67395 L .51904 .67632 L p F P
0 g
s
.65 .758 .928 r
.51666 .67395 m .50795 .67652 L .50556 .67415 L p F P
0 g
s
.652 .76 .928 r
.92513 .6759 m .93452 .6733 L .93626 .67566 L p F P
0 g
s
.652 .76 .928 r
.93452 .6733 m .92513 .6759 L .92338 .67355 L p F P
0 g
s
.65 .757 .928 r
.25378 .67127 m .24549 .67383 L .24828 .67621 L p F P
0 g
s
.65 .757 .928 r
.24828 .67621 m .25656 .67365 L .25378 .67127 L p F P
0 g
s
.651 .758 .928 r
.78979 .67622 m .79897 .67364 L .80091 .67601 L p F P
0 g
s
.651 .758 .928 r
.79897 .67364 m .78979 .67622 L .78783 .67385 L p F P
0 g
s
.652 .76 .929 r
.93626 .67566 m .94567 .67304 L .94739 .6754 L p F P
0 g
s
.652 .76 .929 r
.94567 .67304 m .93626 .67566 L .93452 .6733 L p F P
0 g
s
.65 .757 .928 r
.38366 .6763 m .39216 .67373 L .39472 .67611 L p F P
0 g
s
.65 .757 .928 r
.39216 .67373 m .38366 .6763 L .38107 .67393 L p F P
0 g
s
.651 .758 .928 r
.65442 .67631 m .66337 .67373 L .66552 .6761 L p F P
0 g
s
.651 .758 .928 r
.66337 .67373 m .65442 .67631 L .65225 .67393 L p F P
0 g
s
.65 .758 .928 r
.51904 .67632 m .52776 .67375 L .53012 .67612 L p F P
0 g
s
.65 .758 .928 r
.52776 .67375 m .51904 .67632 L .51666 .67395 L p F P
0 g
s
.651 .758 .928 r
.8101 .67343 m .80091 .67601 L .79897 .67364 L p F P
0 g
s
.651 .758 .928 r
.80091 .67601 m .8101 .67343 L .81203 .6758 L p F P
0 g
s
.652 .76 .929 r
.95682 .67279 m .94739 .6754 L .94567 .67304 L p F P
0 g
s
.65 .757 .928 r
.26487 .67108 m .25656 .67365 L .25933 .67602 L p F P
0 g
s
.65 .757 .928 r
.25933 .67602 m .26763 .67346 L .26487 .67108 L p F P
0 g
s
.651 .758 .928 r
.66552 .6761 m .67449 .67353 L .67663 .6759 L p F P
0 g
s
.651 .758 .928 r
.67449 .67353 m .66552 .6761 L .66337 .67373 L p F P
0 g
s
.65 .757 .928 r
.39472 .67611 m .40325 .67354 L .40579 .67591 L p F P
0 g
s
.65 .757 .928 r
.40325 .67354 m .39472 .67611 L .39216 .67373 L p F P
0 g
s
.65 .758 .928 r
.53887 .67355 m .53012 .67612 L .52776 .67375 L p F P
0 g
s
.65 .758 .928 r
.53012 .67612 m .53887 .67355 L .54121 .67593 L p F P
0 g
s
.651 .758 .928 r
.81203 .6758 m .82124 .67322 L .82316 .67559 L p F P
0 g
s
.651 .758 .928 r
.82124 .67322 m .81203 .6758 L .8101 .67343 L p F P
0 g
s
.65 .757 .928 r
.27596 .67089 m .26763 .67346 L .27038 .67584 L p F P
0 g
s
.65 .757 .928 r
.27038 .67584 m .2787 .67328 L .27596 .67089 L p F P
0 g
s
.651 .758 .928 r
.67663 .6759 m .68561 .67333 L .68773 .6757 L p F P
0 g
s
.651 .758 .928 r
.68561 .67333 m .67663 .6759 L .67449 .67353 L p F P
0 g
s
.65 .757 .928 r
.40579 .67591 m .41434 .67334 L .41687 .67572 L p F P
0 g
s
.65 .757 .928 r
.41434 .67334 m .40579 .67591 L .40325 .67354 L p F P
0 g
s
.65 .758 .928 r
.54121 .67593 m .54998 .67335 L .5523 .67573 L p F P
0 g
s
.65 .758 .928 r
.54998 .67335 m .54121 .67593 L .53887 .67355 L p F P
0 g
s
.651 .758 .928 r
.82316 .67559 m .83239 .673 L .83428 .67537 L p F P
0 g
s
.651 .758 .928 r
.83239 .673 m .82316 .67559 L .82124 .67322 L p F P
0 g
s
.65 .757 .928 r
.28144 .67565 m .28978 .67309 L .2925 .67546 L p F P
0 g
s
.65 .757 .928 r
.28705 .6707 m .2787 .67328 L .28144 .67565 L p F P
0 g
s
.65 .757 .928 r
.28144 .67565 m .28978 .67309 L .28705 .6707 L p F P
0 g
s
.651 .758 .928 r
.68773 .6757 m .69674 .67313 L .69885 .6755 L p F P
0 g
s
.651 .758 .928 r
.69674 .67313 m .68773 .6757 L .68561 .67333 L p F P
0 g
s
.65 .757 .928 r
.41687 .67572 m .42543 .67315 L .42795 .67552 L p F P
0 g
s
.65 .757 .928 r
.42543 .67315 m .41687 .67572 L .41434 .67334 L p F P
0 g
s
.65 .758 .928 r
.5523 .67573 m .56109 .67315 L .5634 .67553 L p F P
0 g
s
.65 .758 .928 r
.56109 .67315 m .5523 .67573 L .54998 .67335 L p F P
0 g
s
.651 .758 .928 r
.83428 .67537 m .84353 .67279 L .84541 .67516 L p F P
0 g
s
.651 .758 .928 r
.84353 .67279 m .83428 .67537 L .83239 .673 L p F P
0 g
s
.65 .757 .928 r
.2925 .67546 m .30086 .6729 L .30356 .67527 L p F P
0 g
s
.65 .757 .928 r
.30086 .6729 m .2925 .67546 L .28978 .67309 L p F P
0 g
s
.651 .758 .928 r
.69885 .6755 m .70787 .67292 L .70996 .6753 L p F P
0 g
s
.651 .758 .928 r
.70787 .67292 m .69885 .6755 L .69674 .67313 L p F P
0 g
s
.65 .757 .928 r
.42795 .67552 m .43653 .67295 L .43902 .67533 L p F P
0 g
s
.65 .757 .928 r
.43653 .67295 m .42795 .67552 L .42543 .67315 L p F P
0 g
s
.65 .758 .928 r
.5634 .67553 m .5722 .67295 L .57449 .67533 L p F P
0 g
s
.65 .758 .928 r
.5722 .67295 m .5634 .67553 L .56109 .67315 L p F P
0 g
s
.651 .758 .928 r
.84541 .67516 m .85468 .67257 L .85654 .67494 L p F P
0 g
s
.651 .758 .928 r
.85468 .67257 m .84541 .67516 L .84353 .67279 L p F P
0 g
s
.65 .757 .928 r
.30356 .67527 m .31194 .67271 L .31463 .67508 L p F P
0 g
s
.65 .757 .928 r
.31194 .67271 m .30356 .67527 L .30086 .6729 L p F P
0 g
s
.651 .758 .928 r
.70996 .6753 m .719 .67272 L .72108 .67509 L p F P
0 g
s
.651 .758 .928 r
.719 .67272 m .70996 .6753 L .70787 .67292 L p F P
0 g
s
.65 .757 .928 r
.43902 .67533 m .44762 .67275 L .45011 .67513 L p F P
0 g
s
.65 .757 .928 r
.44762 .67275 m .43902 .67533 L .43653 .67295 L p F P
0 g
s
.65 .758 .928 r
.57449 .67533 m .58332 .67275 L .58559 .67513 L p F P
0 g
s
.65 .758 .928 r
.58332 .67275 m .57449 .67533 L .5722 .67295 L p F P
0 g
s
.651 .759 .928 r
.85654 .67494 m .86583 .67234 L .86768 .67471 L p F P
0 g
s
.651 .759 .928 r
.86583 .67234 m .85654 .67494 L .85468 .67257 L p F P
0 g
s
.65 .757 .928 r
.31463 .67508 m .32302 .67251 L .32569 .67489 L p F P
0 g
s
.65 .757 .928 r
.32302 .67251 m .31463 .67508 L .31194 .67271 L p F P
0 g
s
.651 .758 .928 r
.72108 .67509 m .73014 .67251 L .73219 .67489 L p F P
0 g
s
.651 .758 .928 r
.73014 .67251 m .72108 .67509 L .719 .67272 L p F P
0 g
s
.65 .758 .928 r
.45011 .67513 m .45873 .67256 L .46119 .67493 L p F P
0 g
s
.65 .757 .928 r
.45873 .67256 m .45011 .67513 L .44762 .67275 L p F P
0 g
s
.65 .758 .928 r
.58559 .67513 m .59443 .67256 L .59669 .67493 L p F P
0 g
s
.65 .758 .928 r
.59443 .67256 m .58559 .67513 L .58332 .67275 L p F P
0 g
s
.651 .759 .928 r
.86768 .67471 m .87698 .67212 L .87881 .67449 L p F P
0 g
s
.651 .759 .928 r
.87698 .67212 m .86768 .67471 L .86583 .67234 L p F P
0 g
s
.651 .758 .928 r
.73219 .67489 m .74128 .67231 L .74332 .67468 L p F P
0 g
s
.651 .758 .928 r
.74128 .67231 m .73219 .67489 L .73014 .67251 L p F P
0 g
s
.65 .757 .928 r
.32569 .67489 m .33411 .67232 L .33676 .6747 L p F P
0 g
s
.65 .757 .928 r
.33411 .67232 m .32569 .67489 L .32302 .67251 L p F P
0 g
s
0 0 .347 r
.5258 .45728 m .52578 .45732 L .52578 .45342 L p F P
0 g
s
0 0 .347 r
.52578 .45342 m .5258 .45338 L .5258 .45728 L p F P
0 g
s
.762 .5 .538 r
.52573 .45731 m .52578 .45732 L .52578 .45342 L p F P
0 g
s
.762 .5 .538 r
.52578 .45342 m .52572 .45341 L .52573 .45731 L p F P
0 g
s
.65 .758 .928 r
.59669 .67493 m .60556 .67236 L .6078 .67473 L p F P
0 g
s
.65 .758 .928 r
.60556 .67236 m .59669 .67493 L .59443 .67256 L p F P
0 g
s
.65 .758 .928 r
.46119 .67493 m .46983 .67236 L .47228 .67474 L p F P
0 g
s
.65 .758 .928 r
.46983 .67236 m .46119 .67493 L .45873 .67256 L p F P
0 g
s
0 0 .347 r
.52574 .45337 m .52572 .45341 L .52573 .45731 L p F P
0 g
s
.762 .5 .539 r
.52574 .45337 m .5258 .45338 L .5258 .45728 L p F P
0 g
s
.762 .5 .539 r
.5258 .45728 m .52574 .45727 L .52574 .45337 L p F P
0 g
s
0 0 .347 r
.52573 .45731 m .52574 .45727 L .52574 .45337 L p F P
0 g
s
.651 .759 .928 r
.87881 .67449 m .88814 .67189 L .88995 .67426 L p F P
0 g
s
.651 .759 .928 r
.88814 .67189 m .87881 .67449 L .87698 .67212 L p F P
0 g
s
.651 .758 .928 r
.74332 .67468 m .75242 .6721 L .75444 .67448 L p F P
0 g
s
.651 .758 .928 r
.75242 .6721 m .74332 .67468 L .74128 .67231 L p F P
0 g
s
.65 .757 .928 r
.33676 .6747 m .3452 .67213 L .34784 .67451 L p F P
0 g
s
.65 .757 .928 r
.3452 .67213 m .33676 .6747 L .33411 .67232 L p F P
0 g
s
.651 .758 .928 r
.6078 .67473 m .61668 .67216 L .61891 .67453 L p F P
0 g
s
.651 .758 .928 r
.61668 .67216 m .6078 .67473 L .60556 .67236 L p F P
0 g
s
.65 .758 .928 r
.47228 .67474 m .48094 .67216 L .48337 .67454 L p F P
0 g
s
.65 .758 .928 r
.48094 .67216 m .47228 .67474 L .46983 .67236 L p F P
0 g
s
.651 .759 .928 r
.88995 .67426 m .89929 .67166 L .90109 .67402 L p F P
0 g
s
.651 .759 .928 r
.89929 .67166 m .88995 .67426 L .88814 .67189 L p F P
0 g
s
.651 .758 .928 r
.75444 .67448 m .76356 .6719 L .76557 .67427 L p F P
0 g
s
.651 .758 .928 r
.76356 .6719 m .75444 .67448 L .75242 .6721 L p F P
0 g
s
.65 .757 .928 r
.35629 .67194 m .34784 .67451 L .3452 .67213 L p F P
0 g
s
.65 .757 .928 r
.34784 .67451 m .35629 .67194 L .35891 .67432 L p F P
0 g
s
.651 .758 .928 r
.61891 .67453 m .62781 .67195 L .63002 .67433 L p F P
0 g
s
.651 .758 .928 r
.62781 .67195 m .61891 .67453 L .61668 .67216 L p F P
0 g
s
.65 .758 .928 r
.48337 .67454 m .49205 .67196 L .49447 .67434 L p F P
0 g
s
.65 .758 .928 r
.49205 .67196 m .48337 .67454 L .48094 .67216 L p F P
0 g
s
.652 .759 .928 r
.90109 .67402 m .91045 .67142 L .91223 .67379 L p F P
0 g
s
.651 .759 .928 r
.91045 .67142 m .90109 .67402 L .89929 .67166 L p F P
0 g
s
.651 .758 .928 r
.76557 .67427 m .77471 .67169 L .7767 .67406 L p F P
0 g
s
.651 .758 .928 r
.77471 .67169 m .76557 .67427 L .76356 .6719 L p F P
0 g
s
.65 .757 .928 r
.35891 .67432 m .36739 .67174 L .36999 .67412 L p F P
0 g
s
.65 .757 .928 r
.36739 .67174 m .35891 .67432 L .35629 .67194 L p F P
0 g
s
.651 .758 .928 r
.63002 .67433 m .63894 .67175 L .64113 .67413 L p F P
0 g
s
.651 .758 .928 r
.63894 .67175 m .63002 .67433 L .62781 .67195 L p F P
0 g
s
.65 .758 .928 r
.49447 .67434 m .50316 .67176 L .50556 .67415 L p F P
0 g
s
.65 .758 .928 r
.50316 .67176 m .49447 .67434 L .49205 .67196 L p F P
0 g
s
.652 .759 .928 r
.91223 .67379 m .92161 .67118 L .92338 .67355 L p F P
0 g
s
.652 .759 .928 r
.92161 .67118 m .91223 .67379 L .91045 .67142 L p F P
0 g
s
.65 .757 .928 r
.23989 .66906 m .23162 .67163 L .23443 .67402 L p F P
0 g
s
.65 .757 .928 r
.23443 .67402 m .2427 .67145 L .23989 .66906 L p F P
0 g
s
.651 .758 .928 r
.7767 .67406 m .78586 .67148 L .78783 .67385 L p F P
0 g
s
.651 .758 .928 r
.78586 .67148 m .7767 .67406 L .77471 .67169 L p F P
0 g
s
.65 .757 .928 r
.36999 .67412 m .37848 .67155 L .38107 .67393 L p F P
0 g
s
.65 .757 .928 r
.37848 .67155 m .36999 .67412 L .36739 .67174 L p F P
0 g
s
.651 .758 .928 r
.64113 .67413 m .65007 .67155 L .65225 .67393 L p F P
0 g
s
.651 .758 .928 r
.65007 .67155 m .64113 .67413 L .63894 .67175 L p F P
0 g
s
.65 .758 .928 r
.50556 .67415 m .51428 .67157 L .51666 .67395 L p F P
0 g
s
.65 .758 .928 r
.51428 .67157 m .50556 .67415 L .50316 .67176 L p F P
0 g
s
.652 .76 .928 r
.92338 .67355 m .93278 .67093 L .93452 .6733 L p F P
0 g
s
.652 .759 .928 r
.93278 .67093 m .92338 .67355 L .92161 .67118 L p F P
0 g
s
.65 .757 .928 r
.25099 .66888 m .2427 .67145 L .24549 .67383 L p F P
0 g
s
.65 .757 .928 r
.24549 .67383 m .25378 .67127 L .25099 .66888 L p F P
0 g
s
.651 .758 .928 r
.79701 .67127 m .78783 .67385 L .78586 .67148 L p F P
0 g
s
.651 .758 .928 r
.78783 .67385 m .79701 .67127 L .79897 .67364 L p F P
0 g
s
.652 .76 .929 r
.93452 .6733 m .94394 .67068 L .94567 .67304 L p F P
0 g
s
.652 .76 .928 r
.94394 .67068 m .93452 .6733 L .93278 .67093 L p F P
0 g
s
.65 .757 .928 r
.38107 .67393 m .38959 .67135 L .39216 .67373 L p F P
0 g
s
.65 .757 .928 r
.38959 .67135 m .38107 .67393 L .37848 .67155 L p F P
0 g
s
.651 .758 .928 r
.65225 .67393 m .66121 .67135 L .66337 .67373 L p F P
0 g
s
.651 .758 .928 r
.66121 .67135 m .65225 .67393 L .65007 .67155 L p F P
0 g
s
.65 .758 .928 r
.51666 .67395 m .5254 .67137 L .52776 .67375 L p F P
0 g
s
.65 .758 .928 r
.5254 .67137 m .51666 .67395 L .51428 .67157 L p F P
0 g
s
.651 .758 .928 r
.79897 .67364 m .80817 .67105 L .8101 .67343 L p F P
0 g
s
.651 .758 .928 r
.80817 .67105 m .79897 .67364 L .79701 .67127 L p F P
0 g
s
.65 .757 .928 r
.2621 .66869 m .25378 .67127 L .25656 .67365 L p F P
0 g
s
.65 .757 .928 r
.25656 .67365 m .26487 .67108 L .2621 .66869 L p F P
0 g
s
.652 .76 .929 r
.94567 .67304 m .95511 .67042 L .95682 .67279 L p F P
0 g
s
.652 .76 .929 r
.95511 .67042 m .94567 .67304 L .94394 .67068 L p F P
0 g
s
.651 .758 .928 r
.66337 .67373 m .67235 .67115 L .67449 .67353 L p F P
0 g
s
.651 .758 .928 r
.67235 .67115 m .66337 .67373 L .66121 .67135 L p F P
0 g
s
.65 .757 .928 r
.39216 .67373 m .40069 .67115 L .40325 .67354 L p F P
0 g
s
.65 .757 .928 r
.40069 .67115 m .39216 .67373 L .38959 .67135 L p F P
0 g
s
.65 .758 .928 r
.52776 .67375 m .53652 .67117 L .53887 .67355 L p F P
0 g
s
.65 .758 .928 r
.53652 .67117 m .52776 .67375 L .5254 .67137 L p F P
0 g
s
.651 .758 .928 r
.81932 .67084 m .8101 .67343 L .80817 .67105 L p F P
0 g
s
.651 .758 .928 r
.8101 .67343 m .81932 .67084 L .82124 .67322 L p F P
0 g
s
.65 .757 .928 r
.2732 .6685 m .26487 .67108 L .26763 .67346 L p F P
0 g
s
.65 .757 .928 r
.26763 .67346 m .27596 .67089 L .2732 .6685 L p F P
0 g
s
.651 .758 .928 r
.67449 .67353 m .68349 .67095 L .68561 .67333 L p F P
0 g
s
.651 .758 .928 r
.68349 .67095 m .67449 .67353 L .67235 .67115 L p F P
0 g
s
.65 .757 .928 r
.40325 .67354 m .4118 .67096 L .41434 .67334 L p F P
0 g
s
.65 .757 .928 r
.4118 .67096 m .40325 .67354 L .40069 .67115 L p F P
0 g
s
.65 .758 .928 r
.53887 .67355 m .54764 .67097 L .54998 .67335 L p F P
0 g
s
.65 .758 .928 r
.54764 .67097 m .53887 .67355 L .53652 .67117 L p F P
0 g
s
.651 .758 .928 r
.82124 .67322 m .83048 .67063 L .83239 .673 L p F P
0 g
s
.651 .758 .928 r
.83048 .67063 m .82124 .67322 L .81932 .67084 L p F P
0 g
s
.65 .757 .928 r
.28431 .66831 m .27596 .67089 L .2787 .67328 L p F P
0 g
s
.65 .757 .928 r
.2787 .67328 m .28705 .6707 L .28431 .66831 L p F P
0 g
s
.651 .758 .928 r
.68561 .67333 m .69463 .67074 L .69674 .67313 L p F P
0 g
s
.651 .758 .928 r
.69463 .67074 m .68561 .67333 L .68349 .67095 L p F P
0 g
s
.65 .757 .928 r
.41434 .67334 m .42291 .67076 L .42543 .67315 L p F P
0 g
s
.65 .757 .928 r
.42291 .67076 m .41434 .67334 L .4118 .67096 L p F P
0 g
s
.65 .758 .928 r
.54998 .67335 m .55877 .67077 L .56109 .67315 L p F P
0 g
s
.65 .758 .928 r
.55877 .67077 m .54998 .67335 L .54764 .67097 L p F P
0 g
s
.651 .758 .928 r
.83239 .673 m .84164 .67041 L .84353 .67279 L p F P
0 g
s
.651 .758 .928 r
.84164 .67041 m .83239 .673 L .83048 .67063 L p F P
0 g
s
.65 .757 .928 r
.28978 .67309 m .29814 .67051 L .30086 .6729 L p F P
0 g
s
.65 .757 .928 r
.29542 .66812 m .28705 .6707 L .28978 .67309 L p F P
0 g
s
.65 .757 .928 r
.28978 .67309 m .29814 .67051 L .29542 .66812 L p F P
0 g
s
.651 .758 .928 r
.69674 .67313 m .70578 .67054 L .70787 .67292 L p F P
0 g
s
.651 .758 .928 r
.70578 .67054 m .69674 .67313 L .69463 .67074 L p F P
0 g
s
.65 .757 .928 r
.42543 .67315 m .43402 .67057 L .43653 .67295 L p F P
0 g
s
.65 .757 .928 r
.43402 .67057 m .42543 .67315 L .42291 .67076 L p F P
0 g
s
.65 .758 .928 r
.56109 .67315 m .5699 .67057 L .5722 .67295 L p F P
0 g
s
.65 .758 .928 r
.5699 .67057 m .56109 .67315 L .55877 .67077 L p F P
0 g
s
.651 .758 .928 r
.84353 .67279 m .85281 .67019 L .85468 .67257 L p F P
0 g
s
.651 .758 .928 r
.85281 .67019 m .84353 .67279 L .84164 .67041 L p F P
0 g
s
.65 .757 .928 r
.30086 .6729 m .30924 .67032 L .31194 .67271 L p F P
0 g
s
.65 .757 .928 r
.30924 .67032 m .30086 .6729 L .29814 .67051 L p F P
0 g
s
.651 .758 .928 r
.70787 .67292 m .71693 .67034 L .719 .67272 L p F P
0 g
s
.651 .758 .928 r
.71693 .67034 m .70787 .67292 L .70578 .67054 L p F P
0 g
s
0 0 .347 r
.52579 .46119 m .52578 .46122 L .52578 .45732 L p F P
0 g
s
0 0 .347 r
.52578 .45732 m .5258 .45728 L .52579 .46119 L p F P
0 g
s
.762 .5 .538 r
.52573 .46122 m .52578 .46122 L .52578 .45732 L p F P
0 g
s
.762 .5 .538 r
.52578 .45732 m .52573 .45731 L .52573 .46122 L p F P
0 g
s
.65 .757 .928 r
.43653 .67295 m .44513 .67037 L .44762 .67275 L p F P
0 g
s
.65 .757 .928 r
.44513 .67037 m .43653 .67295 L .43402 .67057 L p F P
0 g
s
.65 .758 .928 r
.5722 .67295 m .58103 .67037 L .58332 .67275 L p F P
0 g
s
.65 .758 .928 r
.58103 .67037 m .5722 .67295 L .5699 .67057 L p F P
0 g
s
0 0 .348 r
.52574 .45727 m .52573 .45731 L .52573 .46122 L p F P
0 g
s
.762 .5 .539 r
.52574 .45727 m .5258 .45728 L .52579 .46119 L p F P
0 g
s
.762 .5 .539 r
.52579 .46119 m .52574 .46118 L .52574 .45727 L p F P
0 g
s
0 0 .348 r
.52573 .46122 m .52574 .46118 L .52574 .45727 L p F P
0 g
s
.651 .759 .928 r
.85468 .67257 m .86398 .66997 L .86583 .67234 L p F P
0 g
s
.651 .758 .928 r
.86398 .66997 m .85468 .67257 L .85281 .67019 L p F P
0 g
s
.65 .757 .928 r
.31194 .67271 m .32034 .67013 L .32302 .67251 L p F P
0 g
s
.65 .757 .928 r
.32034 .67013 m .31194 .67271 L .30924 .67032 L p F P
0 g
s
.651 .758 .928 r
.719 .67272 m .72808 .67013 L .73014 .67251 L p F P
0 g
s
.651 .758 .928 r
.72808 .67013 m .719 .67272 L .71693 .67034 L p F P
0 g
s
.65 .757 .928 r
.44762 .67275 m .45625 .67017 L .45873 .67256 L p F P
0 g
s
.65 .757 .928 r
.45625 .67017 m .44762 .67275 L .44513 .67037 L p F P
0 g
s
.65 .758 .928 r
.58332 .67275 m .59217 .67017 L .59443 .67256 L p F P
0 g
s
.65 .758 .928 r
.59217 .67017 m .58332 .67275 L .58103 .67037 L p F P
0 g
s
.651 .759 .928 r
.86583 .67234 m .87515 .66974 L .87698 .67212 L p F P
0 g
s
.651 .759 .928 r
.87515 .66974 m .86583 .67234 L .86398 .66997 L p F P
0 g
s
.651 .758 .928 r
.73014 .67251 m .73923 .66992 L .74128 .67231 L p F P
0 g
s
.651 .758 .928 r
.73923 .66992 m .73014 .67251 L .72808 .67013 L p F P
0 g
s
.65 .757 .928 r
.32302 .67251 m .33144 .66994 L .33411 .67232 L p F P
0 g
s
.65 .757 .928 r
.33144 .66994 m .32302 .67251 L .32034 .67013 L p F P
0 g
s
.65 .758 .928 r
.59443 .67256 m .60331 .66997 L .60556 .67236 L p F P
0 g
s
.65 .758 .928 r
.60331 .66997 m .59443 .67256 L .59217 .67017 L p F P
0 g
s
.65 .758 .928 r
.45873 .67256 m .46737 .66997 L .46983 .67236 L p F P
0 g
s
.65 .758 .928 r
.46737 .66997 m .45873 .67256 L .45625 .67017 L p F P
0 g
s
.651 .759 .928 r
.87698 .67212 m .88632 .66951 L .88814 .67189 L p F P
0 g
s
.651 .759 .928 r
.88632 .66951 m .87698 .67212 L .87515 .66974 L p F P
0 g
s
.651 .758 .928 r
.74128 .67231 m .75039 .66972 L .75242 .6721 L p F P
0 g
s
.651 .758 .928 r
.75039 .66972 m .74128 .67231 L .73923 .66992 L p F P
0 g
s
.65 .757 .928 r
.33411 .67232 m .34255 .66974 L .3452 .67213 L p F P
0 g
s
.65 .757 .928 r
.34255 .66974 m .33411 .67232 L .33144 .66994 L p F P
0 g
s
.651 .758 .928 r
.60556 .67236 m .61445 .66977 L .61668 .67216 L p F P
0 g
s
.651 .758 .928 r
.61445 .66977 m .60556 .67236 L .60331 .66997 L p F P
0 g
s
.65 .758 .928 r
.46983 .67236 m .4785 .66977 L .48094 .67216 L p F P
0 g
s
.65 .758 .928 r
.4785 .66977 m .46983 .67236 L .46737 .66997 L p F P
0 g
s
.651 .759 .928 r
.88814 .67189 m .89749 .66928 L .89929 .67166 L p F P
0 g
s
.651 .759 .928 r
.89749 .66928 m .88814 .67189 L .88632 .66951 L p F P
0 g
s
.651 .758 .928 r
.75242 .6721 m .76155 .66951 L .76356 .6719 L p F P
0 g
s
.651 .758 .928 r
.76155 .66951 m .75242 .6721 L .75039 .66972 L p F P
0 g
s
.65 .757 .928 r
.3452 .67213 m .35366 .66955 L .35629 .67194 L p F P
0 g
s
.65 .757 .928 r
.35366 .66955 m .3452 .67213 L .34255 .66974 L p F P
0 g
s
.651 .758 .928 r
.61668 .67216 m .62559 .66957 L .62781 .67195 L p F P
0 g
s
.651 .758 .928 r
.62559 .66957 m .61668 .67216 L .61445 .66977 L p F P
0 g
s
.65 .758 .928 r
.48094 .67216 m .48962 .66958 L .49205 .67196 L p F P
0 g
s
.65 .758 .928 r
.48962 .66958 m .48094 .67216 L .4785 .66977 L p F P
0 g
s
.651 .759 .928 r
.89929 .67166 m .90867 .66904 L .91045 .67142 L p F P
0 g
s
.651 .759 .928 r
.90867 .66904 m .89929 .67166 L .89749 .66928 L p F P
0 g
s
.651 .758 .928 r
.76356 .6719 m .77272 .6693 L .77471 .67169 L p F P
0 g
s
.651 .758 .928 r
.77272 .6693 m .76356 .6719 L .76155 .66951 L p F P
0 g
s
.65 .757 .928 r
.36477 .66935 m .35629 .67194 L .35366 .66955 L p F P
0 g
s
.65 .757 .928 r
.35629 .67194 m .36477 .66935 L .36739 .67174 L p F P
0 g
s
.651 .758 .928 r
.62781 .67195 m .63674 .66937 L .63894 .67175 L p F P
0 g
s
.651 .758 .928 r
.63674 .66937 m .62781 .67195 L .62559 .66957 L p F P
0 g
s
.65 .758 .928 r
.49205 .67196 m .50075 .66938 L .50316 .67176 L p F P
0 g
s
.65 .758 .928 r
.50075 .66938 m .49205 .67196 L .48962 .66958 L p F P
0 g
s
.652 .759 .928 r
.91045 .67142 m .91985 .6688 L .92161 .67118 L p F P
0 g
s
.652 .759 .928 r
.91985 .6688 m .91045 .67142 L .90867 .66904 L p F P
0 g
s
.65 .757 .928 r
.23708 .66666 m .2288 .66925 L .23162 .67163 L p F P
0 g
s
.65 .757 .928 r
.23162 .67163 m .23989 .66906 L .23708 .66666 L p F P
0 g
s
.651 .758 .928 r
.77471 .67169 m .78388 .66909 L .78586 .67148 L p F P
0 g
s
.651 .758 .928 r
.78388 .66909 m .77471 .67169 L .77272 .6693 L p F P
0 g
s
.65 .757 .928 r
.36739 .67174 m .37589 .66916 L .37848 .67155 L p F P
0 g
s
.65 .757 .928 r
.37589 .66916 m .36739 .67174 L .36477 .66935 L p F P
0 g
s
.651 .758 .928 r
.63894 .67175 m .64789 .66917 L .65007 .67155 L p F P
0 g
s
.651 .758 .928 r
.64789 .66917 m .63894 .67175 L .63674 .66937 L p F P
0 g
s
.65 .758 .928 r
.50316 .67176 m .51189 .66918 L .51428 .67157 L p F P
0 g
s
.65 .758 .928 r
.51189 .66918 m .50316 .67176 L .50075 .66938 L p F P
0 g
s
.652 .759 .928 r
.92161 .67118 m .93103 .66856 L .93278 .67093 L p F P
0 g
s
.652 .759 .928 r
.93103 .66856 m .92161 .67118 L .91985 .6688 L p F P
0 g
s
.65 .757 .928 r
.2482 .66648 m .23989 .66906 L .2427 .67145 L p F P
0 g
s
.65 .757 .928 r
.2427 .67145 m .25099 .66888 L .2482 .66648 L p F P
0 g
s
.651 .758 .928 r
.78586 .67148 m .79505 .66888 L .79701 .67127 L p F P
0 g
s
.651 .758 .928 r
.79505 .66888 m .78586 .67148 L .78388 .66909 L p F P
0 g
s
.65 .757 .928 r
.37848 .67155 m .387 .66896 L .38959 .67135 L p F P
0 g
s
.65 .757 .928 r
.387 .66896 m .37848 .67155 L .37589 .66916 L p F P
0 g
s
.652 .76 .928 r
.93278 .67093 m .94221 .66831 L .94394 .67068 L p F P
0 g
s
.652 .76 .928 r
.94221 .66831 m .93278 .67093 L .93103 .66856 L p F P
0 g
s
.651 .758 .928 r
.65007 .67155 m .65904 .66896 L .66121 .67135 L p F P
0 g
s
.651 .758 .928 r
.65904 .66896 m .65007 .67155 L .64789 .66917 L p F P
0 g
s
.65 .758 .928 r
.51428 .67157 m .52302 .66898 L .5254 .67137 L p F P
0 g
s
.65 .758 .928 r
.52302 .66898 m .51428 .67157 L .51189 .66918 L p F P
0 g
s
.65 .757 .928 r
.25932 .66629 m .25099 .66888 L .25378 .67127 L p F P
0 g
s
.65 .757 .928 r
.25378 .67127 m .2621 .66869 L .25932 .66629 L p F P
0 g
s
.651 .758 .928 r
.79701 .67127 m .80622 .66867 L .80817 .67105 L p F P
0 g
s
.651 .758 .928 r
.80622 .66867 m .79701 .67127 L .79505 .66888 L p F P
0 g
s
.652 .76 .929 r
.94394 .67068 m .95339 .66805 L .95511 .67042 L p F P
0 g
s
.652 .76 .929 r
.95339 .66805 m .94394 .67068 L .94221 .66831 L p F P
0 g
s
.65 .757 .928 r
.38959 .67135 m .39813 .66877 L .40069 .67115 L p F P
0 g
s
.65 .757 .928 r
.39813 .66877 m .38959 .67135 L .387 .66896 L p F P
0 g
s
.651 .758 .928 r
.66121 .67135 m .6702 .66876 L .67235 .67115 L p F P
0 g
s
.651 .758 .928 r
.6702 .66876 m .66121 .67135 L .65904 .66896 L p F P
0 g
s
.65 .758 .928 r
.5254 .67137 m .53416 .66878 L .53652 .67117 L p F P
0 g
s
.65 .758 .928 r
.53416 .66878 m .5254 .67137 L .52302 .66898 L p F P
0 g
s
.651 .758 .928 r
.80817 .67105 m .8174 .66846 L .81932 .67084 L p F P
0 g
s
.651 .758 .928 r
.8174 .66846 m .80817 .67105 L .80622 .66867 L p F P
0 g
s
.65 .757 .928 r
.27044 .6661 m .2621 .66869 L .26487 .67108 L p F P
0 g
s
.65 .757 .928 r
.26487 .67108 m .2732 .6685 L .27044 .6661 L p F P
0 g
s
.651 .758 .928 r
.67235 .67115 m .68135 .66856 L .68349 .67095 L p F P
0 g
s
.651 .758 .928 r
.68135 .66856 m .67235 .67115 L .6702 .66876 L p F P
0 g
s
.65 .757 .928 r
.40069 .67115 m .40925 .66857 L .4118 .67096 L p F P
0 g
s
.65 .757 .928 r
.40925 .66857 m .40069 .67115 L .39813 .66877 L p F P
0 g
s
.65 .758 .928 r
.53652 .67117 m .5453 .66858 L .54764 .67097 L p F P
0 g
s
.65 .758 .928 r
.5453 .66858 m .53652 .67117 L .53416 .66878 L p F P
0 g
s
.651 .758 .928 r
.82857 .66824 m .81932 .67084 L .8174 .66846 L p F P
0 g
s
.651 .758 .928 r
.81932 .67084 m .82857 .66824 L .83048 .67063 L p F P
0 g
s
.65 .757 .928 r
.28156 .66591 m .2732 .6685 L .27596 .67089 L p F P
0 g
s
.65 .757 .928 r
.27596 .67089 m .28431 .66831 L .28156 .66591 L p F P
0 g
s
.651 .758 .928 r
.68349 .67095 m .69251 .66835 L .69463 .67074 L p F P
0 g
s
.651 .758 .928 r
.69251 .66835 m .68349 .67095 L .68135 .66856 L p F P
0 g
s
0 0 .347 r
.52579 .46511 m .52578 .46514 L .52578 .46122 L p F P
0 g
s
0 0 .347 r
.52578 .46122 m .52579 .46119 L .52579 .46511 L p F P
0 g
s
.762 .5 .538 r
.52573 .46513 m .52578 .46514 L .52578 .46122 L p F P
0 g
s
.762 .5 .538 r
.52578 .46122 m .52573 .46122 L .52573 .46513 L p F P
0 g
s
.65 .757 .928 r
.4118 .67096 m .42038 .66837 L .42291 .67076 L p F P
0 g
s
.65 .757 .928 r
.42038 .66837 m .4118 .67096 L .40925 .66857 L p F P
0 g
s
0 0 .348 r
.52574 .46118 m .52573 .46122 L .52573 .46513 L p F P
0 g
s
.65 .758 .928 r
.54764 .67097 m .55645 .66838 L .55877 .67077 L p F P
0 g
s
.65 .758 .928 r
.55645 .66838 m .54764 .67097 L .5453 .66858 L p F P
0 g
s
.762 .5 .539 r
.52574 .46118 m .52579 .46119 L .52579 .46511 L p F P
0 g
s
.762 .5 .539 r
.52579 .46511 m .52574 .46511 L .52574 .46118 L p F P
0 g
s
0 0 .348 r
.52573 .46513 m .52574 .46511 L .52574 .46118 L p F P
0 g
s
.651 .758 .928 r
.83048 .67063 m .83975 .66802 L .84164 .67041 L p F P
0 g
s
.651 .758 .928 r
.83975 .66802 m .83048 .67063 L .82857 .66824 L p F P
0 g
s
.65 .757 .928 r
.29269 .66572 m .28431 .66831 L .28705 .6707 L p F P
0 g
s
.65 .757 .928 r
.28705 .6707 m .29542 .66812 L .29269 .66572 L p F P
0 g
s
.651 .758 .928 r
.69463 .67074 m .70368 .66815 L .70578 .67054 L p F P
0 g
s
.651 .758 .928 r
.70368 .66815 m .69463 .67074 L .69251 .66835 L p F P
0 g
s
.65 .757 .928 r
.42291 .67076 m .4315 .66817 L .43402 .67057 L p F P
0 g
s
.65 .757 .928 r
.4315 .66817 m .42291 .67076 L .42038 .66837 L p F P
0 g
s
.65 .758 .928 r
.55877 .67077 m .56759 .66818 L .5699 .67057 L p F P
0 g
s
.65 .758 .928 r
.56759 .66818 m .55877 .67077 L .55645 .66838 L p F P
0 g
s
.651 .758 .928 r
.84164 .67041 m .85093 .6678 L .85281 .67019 L p F P
0 g
s
.651 .758 .928 r
.85093 .6678 m .84164 .67041 L .83975 .66802 L p F P
0 g
s
.65 .757 .928 r
.29814 .67051 m .30654 .66793 L .30924 .67032 L p F P
0 g
s
.65 .757 .928 r
.30382 .66553 m .29542 .66812 L .29814 .67051 L p F P
0 g
s
.65 .757 .928 r
.29814 .67051 m .30654 .66793 L .30382 .66553 L p F P
0 g
s
.651 .758 .928 r
.70578 .67054 m .71484 .66795 L .71693 .67034 L p F P
0 g
s
.651 .758 .928 r
.71484 .66795 m .70578 .67054 L .70368 .66815 L p F P
0 g
s
.65 .757 .928 r
.43402 .67057 m .44264 .66798 L .44513 .67037 L p F P
0 g
s
.65 .757 .928 r
.44264 .66798 m .43402 .67057 L .4315 .66817 L p F P
0 g
s
.65 .758 .928 r
.5699 .67057 m .57874 .66798 L .58103 .67037 L p F P
0 g
s
.65 .758 .928 r
.57874 .66798 m .5699 .67057 L .56759 .66818 L p F P
0 g
s
.651 .758 .928 r
.85281 .67019 m .86212 .66758 L .86398 .66997 L p F P
0 g
s
.651 .758 .928 r
.86212 .66758 m .85281 .67019 L .85093 .6678 L p F P
0 g
s
.65 .757 .928 r
.30924 .67032 m .31765 .66774 L .32034 .67013 L p F P
0 g
s
.65 .757 .928 r
.31765 .66774 m .30924 .67032 L .30654 .66793 L p F P
0 g
s
.651 .758 .928 r
.71693 .67034 m .72601 .66774 L .72808 .67013 L p F P
0 g
s
.651 .758 .928 r
.72601 .66774 m .71693 .67034 L .71484 .66795 L p F P
0 g
s
.65 .757 .928 r
.44513 .67037 m .45377 .66778 L .45625 .67017 L p F P
0 g
s
.65 .757 .928 r
.45377 .66778 m .44513 .67037 L .44264 .66798 L p F P
0 g
s
.65 .758 .928 r
.58103 .67037 m .58989 .66778 L .59217 .67017 L p F P
0 g
s
.65 .758 .928 r
.58989 .66778 m .58103 .67037 L .57874 .66798 L p F P
0 g
s
.651 .759 .928 r
.86398 .66997 m .8733 .66736 L .87515 .66974 L p F P
0 g
s
.651 .759 .928 r
.8733 .66736 m .86398 .66997 L .86212 .66758 L p F P
0 g
s
.65 .757 .928 r
.32034 .67013 m .32877 .66754 L .33144 .66994 L p F P
0 g
s
.65 .757 .928 r
.32877 .66754 m .32034 .67013 L .31765 .66774 L p F P
0 g
s
.651 .758 .928 r
.72808 .67013 m .73718 .66753 L .73923 .66992 L p F P
0 g
s
.651 .758 .928 r
.73718 .66753 m .72808 .67013 L .72601 .66774 L p F P
0 g
s
.65 .758 .928 r
.45625 .67017 m .46491 .66758 L .46737 .66997 L p F P
0 g
s
.65 .757 .928 r
.46491 .66758 m .45625 .67017 L .45377 .66778 L p F P
0 g
s
.65 .758 .928 r
.59217 .67017 m .60105 .66758 L .60331 .66997 L p F P
0 g
s
.65 .758 .928 r
.60105 .66758 m .59217 .67017 L .58989 .66778 L p F P
0 g
s
.651 .759 .928 r
.87515 .66974 m .88449 .66713 L .88632 .66951 L p F P
0 g
s
.651 .759 .928 r
.88449 .66713 m .87515 .66974 L .8733 .66736 L p F P
0 g
s
.651 .758 .928 r
.73923 .66992 m .74836 .66733 L .75039 .66972 L p F P
0 g
s
.651 .758 .928 r
.74836 .66733 m .73923 .66992 L .73718 .66753 L p F P
0 g
s
.65 .757 .928 r
.33144 .66994 m .3399 .66735 L .34255 .66974 L p F P
0 g
s
.65 .757 .928 r
.3399 .66735 m .33144 .66994 L .32877 .66754 L p F P
0 g
s
.651 .758 .928 r
.60331 .66997 m .61221 .66738 L .61445 .66977 L p F P
0 g
s
.651 .758 .928 r
.61221 .66738 m .60331 .66997 L .60105 .66758 L p F P
0 g
s
.65 .758 .928 r
.46737 .66997 m .47605 .66738 L .4785 .66977 L p F P
0 g
s
.65 .758 .928 r
.47605 .66738 m .46737 .66997 L .46491 .66758 L p F P
0 g
s
.651 .759 .928 r
.88632 .66951 m .89568 .6669 L .89749 .66928 L p F P
0 g
s
.651 .759 .928 r
.89568 .6669 m .88632 .66951 L .88449 .66713 L p F P
0 g
s
.651 .758 .928 r
.75039 .66972 m .75954 .66712 L .76155 .66951 L p F P
0 g
s
.651 .758 .928 r
.75954 .66712 m .75039 .66972 L .74836 .66733 L p F P
0 g
s
.65 .757 .928 r
.34255 .66974 m .35102 .66715 L .35366 .66955 L p F P
0 g
s
.65 .757 .928 r
.35102 .66715 m .34255 .66974 L .3399 .66735 L p F P
0 g
s
.651 .758 .928 r
.61445 .66977 m .62337 .66717 L .62559 .66957 L p F P
0 g
s
.651 .758 .928 r
.62337 .66717 m .61445 .66977 L .61221 .66738 L p F P
0 g
s
.65 .758 .928 r
.4785 .66977 m .48719 .66718 L .48962 .66958 L p F P
0 g
s
.65 .758 .928 r
.48719 .66718 m .4785 .66977 L .47605 .66738 L p F P
0 g
s
.651 .759 .928 r
.89749 .66928 m .90688 .66666 L .90867 .66904 L p F P
0 g
s
.651 .759 .928 r
.90688 .66666 m .89749 .66928 L .89568 .6669 L p F P
0 g
s
.651 .758 .928 r
.76155 .66951 m .77072 .66691 L .77272 .6693 L p F P
0 g
s
.651 .758 .928 r
.77072 .66691 m .76155 .66951 L .75954 .66712 L p F P
0 g
s
.65 .757 .928 r
.35366 .66955 m .36215 .66696 L .36477 .66935 L p F P
0 g
s
.65 .757 .928 r
.36215 .66696 m .35366 .66955 L .35102 .66715 L p F P
0 g
s
.651 .758 .928 r
.62559 .66957 m .63453 .66697 L .63674 .66937 L p F P
0 g
s
.651 .758 .928 r
.63453 .66697 m .62559 .66957 L .62337 .66717 L p F P
0 g
s
.65 .758 .928 r
.48962 .66958 m .49834 .66698 L .50075 .66938 L p F P
0 g
s
.65 .758 .928 r
.49834 .66698 m .48962 .66958 L .48719 .66718 L p F P
0 g
s
.652 .759 .928 r
.90867 .66904 m .91807 .66642 L .91985 .6688 L p F P
0 g
s
.652 .759 .928 r
.91807 .66642 m .90867 .66904 L .90688 .66666 L p F P
0 g
s
.65 .757 .928 r
.23426 .66426 m .22597 .66685 L .2288 .66925 L p F P
0 g
s
.65 .757 .928 r
.2288 .66925 m .23708 .66666 L .23426 .66426 L p F P
0 g
s
.651 .758 .928 r
.77272 .6693 m .7819 .6667 L .78388 .66909 L p F P
0 g
s
.651 .758 .928 r
.7819 .6667 m .77272 .6693 L .77072 .66691 L p F P
0 g
s
.65 .757 .928 r
.37328 .66676 m .36477 .66935 L .36215 .66696 L p F P
0 g
s
.65 .757 .928 r
.36477 .66935 m .37328 .66676 L .37589 .66916 L p F P
0 g
s
.651 .758 .928 r
.63674 .66937 m .6457 .66677 L .64789 .66917 L p F P
0 g
s
.651 .758 .928 r
.6457 .66677 m .63674 .66937 L .63453 .66697 L p F P
0 g
s
.65 .758 .928 r
.50075 .66938 m .50949 .66678 L .51189 .66918 L p F P
0 g
s
.65 .758 .928 r
.50949 .66678 m .50075 .66938 L .49834 .66698 L p F P
0 g
s
.652 .759 .928 r
.91985 .6688 m .92927 .66618 L .93103 .66856 L p F P
0 g
s
.652 .759 .928 r
.92927 .66618 m .91985 .6688 L .91807 .66642 L p F P
0 g
s
.65 .757 .928 r
.24539 .66407 m .23708 .66666 L .23989 .66906 L p F P
0 g
s
.65 .757 .928 r
.23989 .66906 m .2482 .66648 L .24539 .66407 L p F P
0 g
s
.651 .758 .928 r
.78388 .66909 m .79309 .66649 L .79505 .66888 L p F P
0 g
s
.651 .758 .928 r
.79309 .66649 m .78388 .66909 L .7819 .6667 L p F P
0 g
s
.65 .757 .928 r
.37589 .66916 m .38442 .66656 L .387 .66896 L p F P
0 g
s
.65 .757 .928 r
.38442 .66656 m .37589 .66916 L .37328 .66676 L p F P
0 g
s
.651 .758 .928 r
.64789 .66917 m .65687 .66657 L .65904 .66896 L p F P
0 g
s
.651 .758 .928 r
.65687 .66657 m .64789 .66917 L .6457 .66677 L p F P
0 g
s
.652 .76 .928 r
.93103 .66856 m .94047 .66593 L .94221 .66831 L p F P
0 g
s
.652 .76 .928 r
.94047 .66593 m .93103 .66856 L .92927 .66618 L p F P
0 g
s
.65 .758 .928 r
.51189 .66918 m .52064 .66658 L .52302 .66898 L p F P
0 g
s
.65 .758 .928 r
.52064 .66658 m .51189 .66918 L .50949 .66678 L p F P
0 g
s
.65 .757 .928 r
.25653 .66389 m .2482 .66648 L .25099 .66888 L p F P
0 g
s
.65 .757 .928 r
.25099 .66888 m .25932 .66629 L .25653 .66389 L p F P
0 g
s
.651 .758 .928 r
.79505 .66888 m .80427 .66628 L .80622 .66867 L p F P
0 g
s
.651 .758 .928 r
.80427 .66628 m .79505 .66888 L .79309 .66649 L p F P
0 g
s
.652 .76 .929 r
.94221 .66831 m .95167 .66567 L .95339 .66805 L p F P
0 g
s
.652 .76 .928 r
.95167 .66567 m .94221 .66831 L .94047 .66593 L p F P
0 g
s
.65 .757 .928 r
.387 .66896 m .39555 .66637 L .39813 .66877 L p F P
0 g
s
.65 .757 .928 r
.39555 .66637 m .387 .66896 L .38442 .66656 L p F P
0 g
s
0 0 .347 r
.52579 .46904 m .52578 .46907 L .52578 .46514 L p F P
0 g
s
0 0 .347 r
.52578 .46514 m .52579 .46511 L .52579 .46904 L p F P
0 g
s
.762 .5 .538 r
.52573 .46906 m .52578 .46907 L .52578 .46514 L p F P
0 g
s
.762 .5 .538 r
.52578 .46514 m .52573 .46513 L .52573 .46906 L p F P
0 g
s
.651 .758 .928 r
.65904 .66896 m .66804 .66636 L .6702 .66876 L p F P
0 g
s
.651 .758 .928 r
.66804 .66636 m .65904 .66896 L .65687 .66657 L p F P
0 g
s
0 0 .348 r
.52574 .46511 m .52573 .46513 L .52573 .46906 L p F P
0 g
s
.65 .758 .928 r
.52302 .66898 m .5318 .66638 L .53416 .66878 L p F P
0 g
s
.65 .758 .928 r
.5318 .66638 m .52302 .66898 L .52064 .66658 L p F P
0 g
s
.762 .5 .539 r
.52574 .46511 m .52579 .46511 L .52579 .46904 L p F P
0 g
s
.762 .5 .539 r
.52579 .46904 m .52574 .46904 L .52574 .46511 L p F P
0 g
s
0 0 .348 r
.52573 .46906 m .52574 .46904 L .52574 .46511 L p F P
0 g
s
.651 .758 .928 r
.81546 .66606 m .80622 .66867 L .80427 .66628 L p F P
0 g
s
.651 .758 .928 r
.80622 .66867 m .81546 .66606 L .8174 .66846 L p F P
0 g
s
.65 .757 .928 r
.26767 .6637 m .25932 .66629 L .2621 .66869 L p F P
0 g
s
.65 .757 .928 r
.2621 .66869 m .27044 .6661 L .26767 .6637 L p F P
0 g
s
.651 .758 .928 r
.6702 .66876 m .67921 .66616 L .68135 .66856 L p F P
0 g
s
.651 .758 .928 r
.67921 .66616 m .6702 .66876 L .66804 .66636 L p F P
0 g
s
.65 .757 .928 r
.39813 .66877 m .40669 .66617 L .40925 .66857 L p F P
0 g
s
.65 .757 .928 r
.40669 .66617 m .39813 .66877 L .39555 .66637 L p F P
0 g
s
.65 .758 .928 r
.53416 .66878 m .54295 .66618 L .5453 .66858 L p F P
0 g
s
.65 .758 .928 r
.54295 .66618 m .53416 .66878 L .5318 .66638 L p F P
0 g
s
.651 .758 .928 r
.8174 .66846 m .82666 .66585 L .82857 .66824 L p F P
0 g
s
.651 .758 .928 r
.82666 .66585 m .8174 .66846 L .81546 .66606 L p F P
0 g
s
.65 .757 .928 r
.27881 .66351 m .27044 .6661 L .2732 .6685 L p F P
0 g
s
.65 .757 .928 r
.2732 .6685 m .28156 .66591 L .27881 .66351 L p F P
0 g
s
.651 .758 .928 r
.68135 .66856 m .69039 .66596 L .69251 .66835 L p F P
0 g
s
.651 .758 .928 r
.69039 .66596 m .68135 .66856 L .67921 .66616 L p F P
0 g
s
.65 .757 .928 r
.40925 .66857 m .41784 .66597 L .42038 .66837 L p F P
0 g
s
.65 .757 .928 r
.41784 .66597 m .40925 .66857 L .40669 .66617 L p F P
0 g
s
.65 .758 .928 r
.5453 .66858 m .55411 .66598 L .55645 .66838 L p F P
0 g
s
.65 .758 .928 r
.55411 .66598 m .5453 .66858 L .54295 .66618 L p F P
0 g
s
.651 .758 .928 r
.83785 .66563 m .82857 .66824 L .82666 .66585 L p F P
0 g
s
.651 .758 .928 r
.82857 .66824 m .83785 .66563 L .83975 .66802 L p F P
0 g
s
.65 .757 .928 r
.28995 .66331 m .28156 .66591 L .28431 .66831 L p F P
0 g
s
.65 .757 .928 r
.28431 .66831 m .29269 .66572 L .28995 .66331 L p F P
0 g
s
.651 .758 .928 r
.69251 .66835 m .70157 .66575 L .70368 .66815 L p F P
0 g
s
.651 .758 .928 r
.70157 .66575 m .69251 .66835 L .69039 .66596 L p F P
0 g
s
.65 .757 .928 r
.42038 .66837 m .42898 .66577 L .4315 .66817 L p F P
0 g
s
.65 .757 .928 r
.42898 .66577 m .42038 .66837 L .41784 .66597 L p F P
0 g
s
.65 .758 .928 r
.56528 .66578 m .55645 .66838 L .55411 .66598 L p F P
0 g
s
.65 .758 .928 r
.55645 .66838 m .56528 .66578 L .56759 .66818 L p F P
0 g
s
.651 .758 .928 r
.83975 .66802 m .84905 .66541 L .85093 .6678 L p F P
0 g
s
.651 .758 .928 r
.84905 .66541 m .83975 .66802 L .83785 .66563 L p F P
0 g
s
.65 .757 .928 r
.3011 .66312 m .29269 .66572 L .29542 .66812 L p F P
0 g
s
.65 .757 .928 r
.29542 .66812 m .30382 .66553 L .3011 .66312 L p F P
0 g
s
.651 .758 .928 r
.70368 .66815 m .71275 .66555 L .71484 .66795 L p F P
0 g
s
.651 .758 .928 r
.71275 .66555 m .70368 .66815 L .70157 .66575 L p F P
0 g
s
.65 .757 .928 r
.4315 .66817 m .44013 .66558 L .44264 .66798 L p F P
0 g
s
.65 .757 .928 r
.44013 .66558 m .4315 .66817 L .42898 .66577 L p F P
0 g
s
.65 .758 .928 r
.56759 .66818 m .57644 .66558 L .57874 .66798 L p F P
0 g
s
.65 .758 .928 r
.57644 .66558 m .56759 .66818 L .56528 .66578 L p F P
0 g
s
.651 .758 .928 r
.85093 .6678 m .86025 .66519 L .86212 .66758 L p F P
0 g
s
.651 .758 .928 r
.86025 .66519 m .85093 .6678 L .84905 .66541 L p F P
0 g
s
.65 .757 .928 r
.30654 .66793 m .31496 .66534 L .31765 .66774 L p F P
0 g
s
.65 .757 .928 r
.31225 .66293 m .30382 .66553 L .30654 .66793 L p F P
0 g
s
.65 .757 .928 r
.30654 .66793 m .31496 .66534 L .31225 .66293 L p F P
0 g
s
.651 .758 .928 r
.71484 .66795 m .72394 .66534 L .72601 .66774 L p F P
0 g
s
.651 .758 .928 r
.72394 .66534 m .71484 .66795 L .71275 .66555 L p F P
0 g
s
.65 .757 .928 r
.44264 .66798 m .45128 .66538 L .45377 .66778 L p F P
0 g
s
.65 .757 .928 r
.45128 .66538 m .44264 .66798 L .44013 .66558 L p F P
0 g
s
.65 .758 .928 r
.57874 .66798 m .58761 .66538 L .58989 .66778 L p F P
0 g
s
.65 .758 .928 r
.58761 .66538 m .57874 .66798 L .57644 .66558 L p F P
0 g
s
.651 .759 .928 r
.86212 .66758 m .87146 .66496 L .8733 .66736 L p F P
0 g
s
.651 .759 .928 r
.87146 .66496 m .86212 .66758 L .86025 .66519 L p F P
0 g
s
.65 .757 .928 r
.31765 .66774 m .32609 .66514 L .32877 .66754 L p F P
0 g
s
.65 .757 .928 r
.32609 .66514 m .31765 .66774 L .31496 .66534 L p F P
0 g
s
.651 .758 .928 r
.72601 .66774 m .73513 .66514 L .73718 .66753 L p F P
0 g
s
.651 .758 .928 r
.73513 .66514 m .72601 .66774 L .72394 .66534 L p F P
0 g
s
.65 .757 .928 r
.45377 .66778 m .46244 .66518 L .46491 .66758 L p F P
0 g
s
.65 .757 .928 r
.46244 .66518 m .45377 .66778 L .45128 .66538 L p F P
0 g
s
.65 .758 .928 r
.58989 .66778 m .59878 .66518 L .60105 .66758 L p F P
0 g
s
.65 .758 .928 r
.59878 .66518 m .58989 .66778 L .58761 .66538 L p F P
0 g
s
.651 .759 .928 r
.8733 .66736 m .88266 .66474 L .88449 .66713 L p F P
0 g
s
.651 .759 .928 r
.88266 .66474 m .8733 .66736 L .87146 .66496 L p F P
0 g
s
.651 .758 .928 r
.73718 .66753 m .74632 .66493 L .74836 .66733 L p F P
0 g
s
.651 .758 .928 r
.74632 .66493 m .73718 .66753 L .73513 .66514 L p F P
0 g
s
.65 .757 .928 r
.32877 .66754 m .33723 .66495 L .3399 .66735 L p F P
0 g
s
.65 .757 .928 r
.33723 .66495 m .32877 .66754 L .32609 .66514 L p F P
0 g
s
.651 .758 .928 r
.60105 .66758 m .60996 .66498 L .61221 .66738 L p F P
0 g
s
.651 .758 .928 r
.60996 .66498 m .60105 .66758 L .59878 .66518 L p F P
0 g
s
.65 .758 .928 r
.46491 .66758 m .47359 .66498 L .47605 .66738 L p F P
0 g
s
.65 .757 .928 r
.47359 .66498 m .46491 .66758 L .46244 .66518 L p F P
0 g
s
.651 .759 .928 r
.88449 .66713 m .89387 .66451 L .89568 .6669 L p F P
0 g
s
.651 .759 .928 r
.89387 .66451 m .88449 .66713 L .88266 .66474 L p F P
0 g
s
.651 .758 .928 r
.74836 .66733 m .75751 .66472 L .75954 .66712 L p F P
0 g
s
.651 .758 .928 r
.75751 .66472 m .74836 .66733 L .74632 .66493 L p F P
0 g
s
.65 .757 .928 r
.3399 .66735 m .34837 .66475 L .35102 .66715 L p F P
0 g
s
.65 .757 .928 r
.34837 .66475 m .3399 .66735 L .33723 .66495 L p F P
0 g
s
.651 .758 .928 r
.61221 .66738 m .62114 .66477 L .62337 .66717 L p F P
0 g
s
.651 .758 .928 r
.62114 .66477 m .61221 .66738 L .60996 .66498 L p F P
0 g
s
.65 .758 .928 r
.47605 .66738 m .48475 .66478 L .48719 .66718 L p F P
0 g
s
.65 .758 .928 r
.48475 .66478 m .47605 .66738 L .47359 .66498 L p F P
0 g
s
.651 .759 .928 r
.89568 .6669 m .90508 .66427 L .90688 .66666 L p F P
0 g
s
.651 .759 .928 r
.90508 .66427 m .89568 .6669 L .89387 .66451 L p F P
0 g
s
.651 .758 .928 r
.75954 .66712 m .76871 .66451 L .77072 .66691 L p F P
0 g
s
.651 .758 .928 r
.76871 .66451 m .75954 .66712 L .75751 .66472 L p F P
0 g
s
.65 .757 .928 r
.35102 .66715 m .35952 .66455 L .36215 .66696 L p F P
0 g
s
.65 .757 .928 r
.35952 .66455 m .35102 .66715 L .34837 .66475 L p F P
0 g
s
.651 .758 .928 r
.62337 .66717 m .63232 .66457 L .63453 .66697 L p F P
0 g
s
.651 .758 .928 r
.63232 .66457 m .62337 .66717 L .62114 .66477 L p F P
0 g
s
.65 .758 .928 r
.48719 .66718 m .49592 .66458 L .49834 .66698 L p F P
0 g
s
.65 .758 .928 r
.49592 .66458 m .48719 .66718 L .48475 .66478 L p F P
0 g
s
.652 .759 .928 r
.90688 .66666 m .91629 .66403 L .91807 .66642 L p F P
0 g
s
.652 .759 .928 r
.91629 .66403 m .90688 .66666 L .90508 .66427 L p F P
0 g
s
.65 .757 .928 r
.23143 .66185 m .22313 .66444 L .22597 .66685 L p F P
0 g
s
.65 .757 .928 r
.22597 .66685 m .23426 .66426 L .23143 .66185 L p F P
0 g
s
.651 .758 .928 r
.77072 .66691 m .77991 .6643 L .7819 .6667 L p F P
0 g
s
.651 .758 .928 r
.77991 .6643 m .77072 .66691 L .76871 .66451 L p F P
0 g
s
.65 .757 .928 r
.36215 .66696 m .37067 .66436 L .37328 .66676 L p F P
0 g
s
.65 .757 .928 r
.37067 .66436 m .36215 .66696 L .35952 .66455 L p F P
0 g
s
0 0 .347 r
.52579 .47298 m .52578 .47301 L .52578 .46907 L p F P
0 g
s
0 0 .347 r
.52578 .46907 m .52579 .46904 L .52579 .47298 L p F P
0 g
s
.762 .5 .538 r
.52573 .473 m .52578 .47301 L .52578 .46907 L p F P
0 g
s
.762 .5 .538 r
.52578 .46907 m .52573 .46906 L .52573 .473 L p F P
0 g
s
.651 .758 .928 r
.63453 .66697 m .6435 .66437 L .6457 .66677 L p F P
0 g
s
.651 .758 .928 r
.6435 .66437 m .63453 .66697 L .63232 .66457 L p F P
0 g
s
.65 .758 .928 r
.49834 .66698 m .50708 .66438 L .50949 .66678 L p F P
0 g
s
.65 .758 .928 r
.50708 .66438 m .49834 .66698 L .49592 .66458 L p F P
0 g
s
0 0 .348 r
.52574 .46904 m .52573 .46906 L .52573 .473 L p F P
0 g
s
.762 .5 .539 r
.52574 .46904 m .52579 .46904 L .52579 .47298 L p F P
0 g
s
.762 .5 .539 r
.52579 .47298 m .52575 .47298 L .52574 .46904 L p F P
0 g
s
0 0 .348 r
.52573 .473 m .52575 .47298 L .52574 .46904 L p F P
0 g
s
.652 .759 .928 r
.91807 .66642 m .92751 .66379 L .92927 .66618 L p F P
0 g
s
.652 .759 .928 r
.92751 .66379 m .91807 .66642 L .91629 .66403 L p F P
0 g
s
.65 .757 .928 r
.24258 .66166 m .23426 .66426 L .23708 .66666 L p F P
0 g
s
.65 .757 .928 r
.23708 .66666 m .24539 .66407 L .24258 .66166 L p F P
0 g
s
.651 .758 .928 r
.7819 .6667 m .79111 .66409 L .79309 .66649 L p F P
0 g
s
.651 .758 .928 r
.79111 .66409 m .7819 .6667 L .77991 .6643 L p F P
0 g
s
.65 .757 .928 r
.38182 .66416 m .37328 .66676 L .37067 .66436 L p F P
0 g
s
.65 .757 .928 r
.37328 .66676 m .38182 .66416 L .38442 .66656 L p F P
0 g
s
.651 .758 .928 r
.6457 .66677 m .65469 .66417 L .65687 .66657 L p F P
0 g
s
.651 .758 .928 r
.65469 .66417 m .6457 .66677 L .6435 .66437 L p F P
0 g
s
.65 .758 .928 r
.50949 .66678 m .51825 .66418 L .52064 .66658 L p F P
0 g
s
.65 .758 .928 r
.51825 .66418 m .50949 .66678 L .50708 .66438 L p F P
0 g
s
.652 .76 .928 r
.92927 .66618 m .93872 .66354 L .94047 .66593 L p F P
0 g
s
.652 .759 .928 r
.93872 .66354 m .92927 .66618 L .92751 .66379 L p F P
0 g
s
.65 .757 .928 r
.25373 .66147 m .24539 .66407 L .2482 .66648 L p F P
0 g
s
.65 .757 .928 r
.2482 .66648 m .25653 .66389 L .25373 .66147 L p F P
0 g
s
.651 .758 .928 r
.79309 .66649 m .80232 .66388 L .80427 .66628 L p F P
0 g
s
.651 .758 .928 r
.80232 .66388 m .79309 .66649 L .79111 .66409 L p F P
0 g
s
.652 .76 .928 r
.94047 .66593 m .94994 .66328 L .95167 .66567 L p F P
0 g
s
.652 .76 .928 r
.94994 .66328 m .94047 .66593 L .93872 .66354 L p F P
0 g
s
.65 .757 .928 r
.38442 .66656 m .39297 .66396 L .39555 .66637 L p F P
0 g
s
.65 .757 .928 r
.39297 .66396 m .38442 .66656 L .38182 .66416 L p F P
0 g
s
.651 .758 .928 r
.65687 .66657 m .66587 .66396 L .66804 .66636 L p F P
0 g
s
.651 .758 .928 r
.66587 .66396 m .65687 .66657 L .65469 .66417 L p F P
0 g
s
.65 .758 .928 r
.52064 .66658 m .52942 .66398 L .5318 .66638 L p F P
0 g
s
.65 .758 .928 r
.52942 .66398 m .52064 .66658 L .51825 .66418 L p F P
0 g
s
.651 .758 .928 r
.80427 .66628 m .81353 .66366 L .81546 .66606 L p F P
0 g
s
.651 .758 .928 r
.81353 .66366 m .80427 .66628 L .80232 .66388 L p F P
0 g
s
.65 .757 .928 r
.26489 .66128 m .25653 .66389 L .25932 .66629 L p F P
0 g
s
.65 .757 .928 r
.25932 .66629 m .26767 .6637 L .26489 .66128 L p F P
0 g
s
.651 .758 .928 r
.66804 .66636 m .67707 .66376 L .67921 .66616 L p F P
0 g
s
.651 .758 .928 r
.67707 .66376 m .66804 .66636 L .66587 .66396 L p F P
0 g
s
.65 .757 .928 r
.39555 .66637 m .40413 .66377 L .40669 .66617 L p F P
0 g
s
.65 .757 .928 r
.40413 .66377 m .39555 .66637 L .39297 .66396 L p F P
0 g
s
.65 .758 .928 r
.5318 .66638 m .5406 .66378 L .54295 .66618 L p F P
0 g
s
.65 .758 .928 r
.5406 .66378 m .5318 .66638 L .52942 .66398 L p F P
0 g
s
.651 .758 .928 r
.82474 .66345 m .81546 .66606 L .81353 .66366 L p F P
0 g
s
.651 .758 .928 r
.81546 .66606 m .82474 .66345 L .82666 .66585 L p F P
0 g
s
.65 .757 .928 r
.27605 .66109 m .26767 .6637 L .27044 .6661 L p F P
0 g
s
.65 .757 .928 r
.27044 .6661 m .27881 .66351 L .27605 .66109 L p F P
0 g
s
.651 .758 .928 r
.67921 .66616 m .68826 .66355 L .69039 .66596 L p F P
0 g
s
.651 .758 .928 r
.68826 .66355 m .67921 .66616 L .67707 .66376 L p F P
0 g
s
.65 .757 .928 r
.40669 .66617 m .41529 .66357 L .41784 .66597 L p F P
0 g
s
.65 .757 .928 r
.41529 .66357 m .40669 .66617 L .40413 .66377 L p F P
0 g
s
.65 .758 .928 r
.54295 .66618 m .55178 .66358 L .55411 .66598 L p F P
0 g
s
.65 .758 .928 r
.55178 .66358 m .54295 .66618 L .5406 .66378 L p F P
0 g
s
.651 .758 .928 r
.82666 .66585 m .83595 .66323 L .83785 .66563 L p F P
0 g
s
.651 .758 .928 r
.83595 .66323 m .82666 .66585 L .82474 .66345 L p F P
0 g
s
.65 .757 .928 r
.28721 .6609 m .27881 .66351 L .28156 .66591 L p F P
0 g
s
.65 .757 .928 r
.28156 .66591 m .28995 .66331 L .28721 .6609 L p F P
0 g
s
.651 .758 .928 r
.69039 .66596 m .69946 .66335 L .70157 .66575 L p F P
0 g
s
.651 .758 .928 r
.69946 .66335 m .69039 .66596 L .68826 .66355 L p F P
0 g
s
.65 .757 .928 r
.41784 .66597 m .42645 .66337 L .42898 .66577 L p F P
0 g
s
.65 .757 .928 r
.42645 .66337 m .41784 .66597 L .41529 .66357 L p F P
0 g
s
.65 .758 .928 r
.55411 .66598 m .56296 .66338 L .56528 .66578 L p F P
0 g
s
.65 .758 .928 r
.56296 .66338 m .55411 .66598 L .55178 .66358 L p F P
0 g
s
.651 .758 .928 r
.84716 .66301 m .83785 .66563 L .83595 .66323 L p F P
0 g
s
.651 .758 .928 r
.83785 .66563 m .84716 .66301 L .84905 .66541 L p F P
0 g
s
.65 .757 .928 r
.29837 .66071 m .28995 .66331 L .29269 .66572 L p F P
0 g
s
.65 .757 .928 r
.29269 .66572 m .3011 .66312 L .29837 .66071 L p F P
0 g
s
.651 .758 .928 r
.70157 .66575 m .71066 .66314 L .71275 .66555 L p F P
0 g
s
.651 .758 .928 r
.71066 .66314 m .70157 .66575 L .69946 .66335 L p F P
0 g
s
.65 .757 .928 r
.42898 .66577 m .43762 .66317 L .44013 .66558 L p F P
0 g
s
.65 .757 .928 r
.43762 .66317 m .42898 .66577 L .42645 .66337 L p F P
0 g
s
.65 .758 .928 r
.57414 .66317 m .56528 .66578 L .56296 .66338 L p F P
0 g
s
.65 .758 .928 r
.56528 .66578 m .57414 .66317 L .57644 .66558 L p F P
0 g
s
.651 .758 .928 r
.84905 .66541 m .85838 .66279 L .86025 .66519 L p F P
0 g
s
.651 .758 .928 r
.85838 .66279 m .84905 .66541 L .84716 .66301 L p F P
0 g
s
.65 .757 .928 r
.30954 .66051 m .3011 .66312 L .30382 .66553 L p F P
0 g
s
.65 .757 .928 r
.30382 .66553 m .31225 .66293 L .30954 .66051 L p F P
0 g
s
.651 .758 .928 r
.71275 .66555 m .72186 .66294 L .72394 .66534 L p F P
0 g
s
.651 .758 .928 r
.72186 .66294 m .71275 .66555 L .71066 .66314 L p F P
0 g
s
.65 .757 .928 r
.44013 .66558 m .44879 .66297 L .45128 .66538 L p F P
0 g
s
.65 .757 .928 r
.44879 .66297 m .44013 .66558 L .43762 .66317 L p F P
0 g
s
.65 .758 .928 r
.57644 .66558 m .58532 .66297 L .58761 .66538 L p F P
0 g
s
.65 .758 .928 r
.58532 .66297 m .57644 .66558 L .57414 .66317 L p F P
0 g
s
.651 .759 .928 r
.86025 .66519 m .8696 .66256 L .87146 .66496 L p F P
0 g
s
.651 .758 .928 r
.8696 .66256 m .86025 .66519 L .85838 .66279 L p F P
0 g
s
.65 .757 .928 r
.31496 .66534 m .3234 .66273 L .32609 .66514 L p F P
0 g
s
.65 .757 .928 r
.32071 .66032 m .31225 .66293 L .31496 .66534 L p F P
0 g
s
.65 .757 .928 r
.31496 .66534 m .3234 .66273 L .32071 .66032 L p F P
0 g
s
.651 .758 .928 r
.72394 .66534 m .73307 .66273 L .73513 .66514 L p F P
0 g
s
.651 .758 .928 r
.73307 .66273 m .72394 .66534 L .72186 .66294 L p F P
0 g
s
.65 .757 .928 r
.45128 .66538 m .45996 .66277 L .46244 .66518 L p F P
0 g
s
.65 .757 .928 r
.45996 .66277 m .45128 .66538 L .44879 .66297 L p F P
0 g
s
.65 .758 .928 r
.58761 .66538 m .59651 .66277 L .59878 .66518 L p F P
0 g
s
.65 .758 .928 r
.59651 .66277 m .58761 .66538 L .58532 .66297 L p F P
0 g
s
.651 .759 .928 r
.87146 .66496 m .88083 .66234 L .88266 .66474 L p F P
0 g
s
.651 .759 .928 r
.88083 .66234 m .87146 .66496 L .8696 .66256 L p F P
0 g
s
.651 .758 .928 r
.73513 .66514 m .74427 .66252 L .74632 .66493 L p F P
0 g
s
.651 .758 .928 r
.74427 .66252 m .73513 .66514 L .73307 .66273 L p F P
0 g
s
.65 .757 .928 r
.32609 .66514 m .33456 .66254 L .33723 .66495 L p F P
0 g
s
.65 .757 .928 r
.33456 .66254 m .32609 .66514 L .3234 .66273 L p F P
0 g
s
.651 .758 .928 r
.59878 .66518 m .6077 .66257 L .60996 .66498 L p F P
0 g
s
.651 .758 .928 r
.6077 .66257 m .59878 .66518 L .59651 .66277 L p F P
0 g
s
.65 .757 .928 r
.46244 .66518 m .47113 .66257 L .47359 .66498 L p F P
0 g
s
.65 .757 .928 r
.47113 .66257 m .46244 .66518 L .45996 .66277 L p F P
0 g
s
.651 .759 .928 r
.88266 .66474 m .89205 .66211 L .89387 .66451 L p F P
0 g
s
.651 .759 .928 r
.89205 .66211 m .88266 .66474 L .88083 .66234 L p F P
0 g
s
.651 .758 .928 r
.74632 .66493 m .75549 .66231 L .75751 .66472 L p F P
0 g
s
.651 .758 .928 r
.75549 .66231 m .74632 .66493 L .74427 .66252 L p F P
0 g
s
.65 .757 .928 r
.33723 .66495 m .34572 .66234 L .34837 .66475 L p F P
0 g
s
.65 .757 .928 r
.34572 .66234 m .33723 .66495 L .33456 .66254 L p F P
0 g
s
0 0 .347 r
.52579 .47694 m .52578 .47696 L .52578 .47301 L p F P
0 g
s
0 0 .347 r
.52578 .47301 m .52579 .47298 L .52579 .47694 L p F P
0 g
s
.762 .5 .538 r
.52573 .47695 m .52578 .47696 L .52578 .47301 L p F P
0 g
s
.762 .5 .538 r
.52578 .47301 m .52573 .473 L .52573 .47695 L p F P
0 g
s
.651 .758 .928 r
.60996 .66498 m .6189 .66236 L .62114 .66477 L p F P
0 g
s
.651 .758 .928 r
.6189 .66236 m .60996 .66498 L .6077 .66257 L p F P
0 g
s
.65 .758 .928 r
.47359 .66498 m .48231 .66237 L .48475 .66478 L p F P
0 g
s
.65 .758 .928 r
.48231 .66237 m .47359 .66498 L .47113 .66257 L p F P
0 g
s
0 0 .348 r
.52575 .47298 m .52573 .473 L .52573 .47695 L p F P
0 g
s
.762 .5 .539 r
.52575 .47298 m .52579 .47298 L .52579 .47694 L p F P
0 g
s
.762 .5 .539 r
.52579 .47694 m .52575 .47693 L .52575 .47298 L p F P
0 g
s
0 0 .348 r
.52573 .47695 m .52575 .47693 L .52575 .47298 L p F P
0 g
s
.651 .759 .928 r
.89387 .66451 m .90328 .66187 L .90508 .66427 L p F P
0 g
s
.651 .759 .928 r
.90328 .66187 m .89387 .66451 L .89205 .66211 L p F P
0 g
s
.651 .758 .928 r
.75751 .66472 m .7667 .6621 L .76871 .66451 L p F P
0 g
s
.651 .758 .928 r
.7667 .6621 m .75751 .66472 L .75549 .66231 L p F P
0 g
s
.65 .757 .928 r
.34837 .66475 m .35688 .66214 L .35952 .66455 L p F P
0 g
s
.65 .757 .928 r
.35688 .66214 m .34837 .66475 L .34572 .66234 L p F P
0 g
s
.651 .758 .928 r
.62114 .66477 m .6301 .66216 L .63232 .66457 L p F P
0 g
s
.651 .758 .928 r
.6301 .66216 m .62114 .66477 L .6189 .66236 L p F P
0 g
s
.65 .758 .928 r
.48475 .66478 m .49349 .66217 L .49592 .66458 L p F P
0 g
s
.65 .758 .928 r
.49349 .66217 m .48475 .66478 L .48231 .66237 L p F P
0 g
s
.652 .759 .928 r
.90508 .66427 m .91451 .66163 L .91629 .66403 L p F P
0 g
s
.652 .759 .928 r
.91451 .66163 m .90508 .66427 L .90328 .66187 L p F P
0 g
s
.65 .757 .928 r
.22859 .65943 m .22029 .66203 L .22313 .66444 L p F P
0 g
s
.65 .757 .928 r
.22313 .66444 m .23143 .66185 L .22859 .65943 L p F P
0 g
s
.651 .758 .928 r
.76871 .66451 m .77792 .66189 L .77991 .6643 L p F P
0 g
s
.651 .758 .928 r
.77792 .66189 m .76871 .66451 L .7667 .6621 L p F P
0 g
s
.65 .757 .928 r
.35952 .66455 m .36805 .66195 L .37067 .66436 L p F P
0 g
s
.65 .757 .928 r
.36805 .66195 m .35952 .66455 L .35688 .66214 L p F P
0 g
s
.651 .758 .928 r
.63232 .66457 m .6413 .66196 L .6435 .66437 L p F P
0 g
s
.651 .758 .928 r
.6413 .66196 m .63232 .66457 L .6301 .66216 L p F P
0 g
s
.65 .758 .928 r
.49592 .66458 m .50467 .66197 L .50708 .66438 L p F P
0 g
s
.65 .758 .928 r
.50467 .66197 m .49592 .66458 L .49349 .66217 L p F P
0 g
s
.652 .759 .928 r
.91629 .66403 m .92574 .66139 L .92751 .66379 L p F P
0 g
s
.652 .759 .928 r
.92574 .66139 m .91629 .66403 L .91451 .66163 L p F P
0 g
s
.65 .757 .928 r
.23976 .65924 m .23143 .66185 L .23426 .66426 L p F P
0 g
s
.65 .757 .928 r
.23426 .66426 m .24258 .66166 L .23976 .65924 L p F P
0 g
s
.651 .758 .928 r
.77991 .6643 m .78914 .66168 L .79111 .66409 L p F P
0 g
s
.651 .758 .928 r
.78914 .66168 m .77991 .6643 L .77792 .66189 L p F P
0 g
s
.65 .757 .928 r
.37067 .66436 m .37921 .66175 L .38182 .66416 L p F P
0 g
s
.65 .757 .928 r
.37921 .66175 m .37067 .66436 L .36805 .66195 L p F P
0 g
s
.651 .758 .928 r
.6435 .66437 m .6525 .66175 L .65469 .66417 L p F P
0 g
s
.651 .758 .928 r
.6525 .66175 m .6435 .66437 L .6413 .66196 L p F P
0 g
s
.65 .758 .928 r
.50708 .66438 m .51586 .66177 L .51825 .66418 L p F P
0 g
s
.65 .758 .928 r
.51586 .66177 m .50708 .66438 L .50467 .66197 L p F P
0 g
s
.652 .759 .928 r
.92751 .66379 m .93697 .66114 L .93872 .66354 L p F P
0 g
s
.652 .759 .928 r
.93697 .66114 m .92751 .66379 L .92574 .66139 L p F P
0 g
s
.65 .757 .928 r
.25093 .65905 m .24258 .66166 L .24539 .66407 L p F P
0 g
s
.65 .757 .928 r
.24539 .66407 m .25373 .66147 L .25093 .65905 L p F P
0 g
s
.651 .758 .928 r
.79111 .66409 m .80036 .66147 L .80232 .66388 L p F P
0 g
s
.651 .758 .928 r
.80036 .66147 m .79111 .66409 L .78914 .66168 L p F P
0 g
s
.652 .76 .928 r
.93872 .66354 m .94821 .66089 L .94994 .66328 L p F P
0 g
s
.652 .76 .928 r
.94821 .66089 m .93872 .66354 L .93697 .66114 L p F P
0 g
s
.65 .757 .928 r
.39039 .66155 m .38182 .66416 L .37921 .66175 L p F P
0 g
s
.65 .757 .928 r
.38182 .66416 m .39039 .66155 L .39297 .66396 L p F P
0 g
s
.651 .758 .928 r
.65469 .66417 m .6637 .66155 L .66587 .66396 L p F P
0 g
s
.651 .758 .928 r
.6637 .66155 m .65469 .66417 L .6525 .66175 L p F P
0 g
s
.65 .758 .928 r
.51825 .66418 m .52704 .66157 L .52942 .66398 L p F P
0 g
s
.65 .758 .928 r
.52704 .66157 m .51825 .66418 L .51586 .66177 L p F P
0 g
s
.651 .758 .928 r
.80232 .66388 m .81158 .66126 L .81353 .66366 L p F P
0 g
s
.651 .758 .928 r
.81158 .66126 m .80232 .66388 L .80036 .66147 L p F P
0 g
s
.65 .757 .928 r
.2621 .65886 m .25373 .66147 L .25653 .66389 L p F P
0 g
s
.65 .757 .928 r
.25653 .66389 m .26489 .66128 L .2621 .65886 L p F P
0 g
s
.651 .758 .928 r
.66587 .66396 m .67491 .66135 L .67707 .66376 L p F P
0 g
s
.651 .758 .928 r
.67491 .66135 m .66587 .66396 L .6637 .66155 L p F P
0 g
s
.65 .757 .928 r
.39297 .66396 m .40156 .66135 L .40413 .66377 L p F P
0 g
s
.65 .757 .928 r
.40156 .66135 m .39297 .66396 L .39039 .66155 L p F P
0 g
s
.65 .758 .928 r
.52942 .66398 m .53824 .66137 L .5406 .66378 L p F P
0 g
s
.65 .758 .928 r
.53824 .66137 m .52942 .66398 L .52704 .66157 L p F P
0 g
s
.651 .758 .928 r
.81353 .66366 m .82281 .66104 L .82474 .66345 L p F P
0 g
s
.651 .758 .928 r
.82281 .66104 m .81353 .66366 L .81158 .66126 L p F P
0 g
s
.65 .757 .928 r
.27327 .65867 m .26489 .66128 L .26767 .6637 L p F P
0 g
s
.65 .757 .928 r
.26767 .6637 m .27605 .66109 L .27327 .65867 L p F P
0 g
s
.651 .758 .928 r
.67707 .66376 m .68612 .66114 L .68826 .66355 L p F P
0 g
s
.651 .758 .928 r
.68612 .66114 m .67707 .66376 L .67491 .66135 L p F P
0 g
s
.65 .757 .928 r
.40413 .66377 m .41274 .66115 L .41529 .66357 L p F P
0 g
s
.65 .757 .928 r
.41274 .66115 m .40413 .66377 L .40156 .66135 L p F P
0 g
s
.65 .758 .928 r
.5406 .66378 m .54943 .66116 L .55178 .66358 L p F P
0 g
s
.65 .758 .928 r
.54943 .66116 m .5406 .66378 L .53824 .66137 L p F P
0 g
s
.651 .758 .928 r
.83404 .66082 m .82474 .66345 L .82281 .66104 L p F P
0 g
s
.651 .758 .928 r
.82474 .66345 m .83404 .66082 L .83595 .66323 L p F P
0 g
s
.65 .757 .928 r
.28445 .65848 m .27605 .66109 L .27881 .66351 L p F P
0 g
s
.65 .757 .928 r
.27881 .66351 m .28721 .6609 L .28445 .65848 L p F P
0 g
s
.651 .758 .928 r
.68826 .66355 m .69734 .66094 L .69946 .66335 L p F P
0 g
s
.651 .758 .928 r
.69734 .66094 m .68826 .66355 L .68612 .66114 L p F P
0 g
s
.65 .757 .928 r
.41529 .66357 m .42391 .66095 L .42645 .66337 L p F P
0 g
s
.65 .757 .928 r
.42391 .66095 m .41529 .66357 L .41274 .66115 L p F P
0 g
s
.65 .758 .928 r
.55178 .66358 m .56063 .66096 L .56296 .66338 L p F P
0 g
s
.65 .758 .928 r
.56063 .66096 m .55178 .66358 L .54943 .66116 L p F P
0 g
s
.651 .758 .928 r
.83595 .66323 m .84527 .6606 L .84716 .66301 L p F P
0 g
s
.651 .758 .928 r
.84527 .6606 m .83595 .66323 L .83404 .66082 L p F P
0 g
s
.65 .757 .928 r
.29563 .65828 m .28721 .6609 L .28995 .66331 L p F P
0 g
s
.65 .757 .928 r
.28995 .66331 m .29837 .66071 L .29563 .65828 L p F P
0 g
s
.651 .758 .928 r
.69946 .66335 m .70855 .66073 L .71066 .66314 L p F P
0 g
s
.651 .758 .928 r
.70855 .66073 m .69946 .66335 L .69734 .66094 L p F P
0 g
s
.65 .757 .928 r
.42645 .66337 m .4351 .66076 L .43762 .66317 L p F P
0 g
s
.65 .757 .928 r
.4351 .66076 m .42645 .66337 L .42391 .66095 L p F P
0 g
s
.65 .758 .928 r
.56296 .66338 m .57183 .66076 L .57414 .66317 L p F P
0 g
s
.65 .758 .928 r
.57183 .66076 m .56296 .66338 L .56063 .66096 L p F P
0 g
s
.651 .758 .928 r
.85651 .66038 m .84716 .66301 L .84527 .6606 L p F P
0 g
s
.651 .758 .928 r
.84716 .66301 m .85651 .66038 L .85838 .66279 L p F P
0 g
s
.65 .757 .928 r
.30682 .65809 m .29837 .66071 L .3011 .66312 L p F P
0 g
s
.65 .757 .928 r
.3011 .66312 m .30954 .66051 L .30682 .65809 L p F P
0 g
s
.651 .758 .928 r
.71066 .66314 m .71977 .66052 L .72186 .66294 L p F P
0 g
s
.651 .758 .928 r
.71977 .66052 m .71066 .66314 L .70855 .66073 L p F P
0 g
s
.65 .757 .928 r
.43762 .66317 m .44628 .66056 L .44879 .66297 L p F P
0 g
s
.65 .757 .928 r
.44628 .66056 m .43762 .66317 L .4351 .66076 L p F P
0 g
s
.65 .758 .928 r
.58303 .66056 m .57414 .66317 L .57183 .66076 L p F P
0 g
s
.65 .758 .928 r
.57414 .66317 m .58303 .66056 L .58532 .66297 L p F P
0 g
s
.651 .758 .928 r
.85838 .66279 m .86774 .66016 L .8696 .66256 L p F P
0 g
s
.651 .758 .928 r
.86774 .66016 m .85838 .66279 L .85651 .66038 L p F P
0 g
s
.65 .757 .928 r
.318 .65789 m .30954 .66051 L .31225 .66293 L p F P
0 g
s
.65 .757 .928 r
.31225 .66293 m .32071 .66032 L .318 .65789 L p F P
0 g
s
.651 .758 .928 r
.72186 .66294 m .731 .66032 L .73307 .66273 L p F P
0 g
s
.651 .758 .928 r
.731 .66032 m .72186 .66294 L .71977 .66052 L p F P
0 g
s
0 0 .347 r
.52579 .4809 m .52577 .48092 L .52578 .47696 L p F P
0 g
s
0 0 .347 r
.52578 .47696 m .52579 .47694 L .52579 .4809 L p F P
0 g
s
.762 .5 .538 r
.52574 .48091 m .52577 .48092 L .52578 .47696 L p F P
0 g
s
.762 .5 .538 r
.52578 .47696 m .52573 .47695 L .52574 .48091 L p F P
0 g
s
.65 .757 .928 r
.44879 .66297 m .45747 .66036 L .45996 .66277 L p F P
0 g
s
.65 .757 .928 r
.45747 .66036 m .44879 .66297 L .44628 .66056 L p F P
0 g
s
.65 .758 .928 r
.58532 .66297 m .59423 .66036 L .59651 .66277 L p F P
0 g
s
.65 .758 .928 r
.59423 .66036 m .58532 .66297 L .58303 .66056 L p F P
0 g
s
0 0 .348 r
.52575 .47693 m .52573 .47695 L .52574 .48091 L p F P
0 g
s
.762 .5 .539 r
.52575 .47693 m .52579 .47694 L .52579 .4809 L p F P
0 g
s
.762 .5 .539 r
.52579 .4809 m .52575 .48089 L .52575 .47693 L p F P
0 g
s
0 0 .348 r
.52574 .48091 m .52575 .48089 L .52575 .47693 L p F P
0 g
s
.651 .759 .928 r
.8696 .66256 m .87898 .65993 L .88083 .66234 L p F P
0 g
s
.651 .759 .928 r
.87898 .65993 m .8696 .66256 L .86774 .66016 L p F P
0 g
s
.651 .758 .928 r
.73307 .66273 m .74222 .66011 L .74427 .66252 L p F P
0 g
s
.651 .758 .928 r
.74222 .66011 m .73307 .66273 L .731 .66032 L p F P
0 g
s
.65 .757 .928 r
.3234 .66273 m .33188 .66012 L .33456 .66254 L p F P
0 g
s
.65 .757 .928 r
.32919 .6577 m .32071 .66032 L .3234 .66273 L p F P
0 g
s
.65 .757 .928 r
.3234 .66273 m .33188 .66012 L .32919 .6577 L p F P
0 g
s
.651 .758 .928 r
.59651 .66277 m .60544 .66015 L .6077 .66257 L p F P
0 g
s
.651 .758 .928 r
.60544 .66015 m .59651 .66277 L .59423 .66036 L p F P
0 g
s
.65 .757 .928 r
.45996 .66277 m .46866 .66015 L .47113 .66257 L p F P
0 g
s
.65 .757 .928 r
.46866 .66015 m .45996 .66277 L .45747 .66036 L p F P
0 g
s
.651 .759 .928 r
.88083 .66234 m .89023 .6597 L .89205 .66211 L p F P
0 g
s
.651 .759 .928 r
.89023 .6597 m .88083 .66234 L .87898 .65993 L p F P
0 g
s
.651 .758 .928 r
.74427 .66252 m .75345 .6599 L .75549 .66231 L p F P
0 g
s
.651 .758 .928 r
.75345 .6599 m .74427 .66252 L .74222 .66011 L p F P
0 g
s
.65 .757 .928 r
.33456 .66254 m .34306 .65992 L .34572 .66234 L p F P
0 g
s
.65 .757 .928 r
.34306 .65992 m .33456 .66254 L .33188 .66012 L p F P
0 g
s
.651 .758 .928 r
.6077 .66257 m .61665 .65995 L .6189 .66236 L p F P
0 g
s
.651 .758 .928 r
.61665 .65995 m .6077 .66257 L .60544 .66015 L p F P
0 g
s
.65 .758 .928 r
.47113 .66257 m .47985 .65995 L .48231 .66237 L p F P
0 g
s
.65 .757 .928 r
.47985 .65995 m .47113 .66257 L .46866 .66015 L p F P
0 g
s
.651 .759 .928 r
.89205 .66211 m .90147 .65947 L .90328 .66187 L p F P
0 g
s
.651 .759 .928 r
.90147 .65947 m .89205 .66211 L .89023 .6597 L p F P
0 g
s
.651 .758 .928 r
.75549 .66231 m .76468 .65969 L .7667 .6621 L p F P
0 g
s
.651 .758 .928 r
.76468 .65969 m .75549 .66231 L .75345 .6599 L p F P
0 g
s
.65 .757 .928 r
.34572 .66234 m .35424 .65973 L .35688 .66214 L p F P
0 g
s
.65 .757 .928 r
.35424 .65973 m .34572 .66234 L .34306 .65992 L p F P
0 g
s
.651 .758 .928 r
.6189 .66236 m .62787 .65975 L .6301 .66216 L p F P
0 g
s
.651 .758 .928 r
.62787 .65975 m .6189 .66236 L .61665 .65995 L p F P
0 g
s
.65 .758 .928 r
.48231 .66237 m .49105 .65975 L .49349 .66217 L p F P
0 g
s
.65 .758 .928 r
.49105 .65975 m .48231 .66237 L .47985 .65995 L p F P
0 g
s
.652 .759 .928 r
.90328 .66187 m .91272 .65923 L .91451 .66163 L p F P
0 g
s
.651 .759 .928 r
.91272 .65923 m .90328 .66187 L .90147 .65947 L p F P
0 g
s
.65 .757 .928 r
.22575 .657 m .21743 .65961 L .22029 .66203 L p F P
0 g
s
.65 .757 .928 r
.22029 .66203 m .22859 .65943 L .22575 .657 L p F P
0 g
s
.651 .758 .928 r
.7667 .6621 m .77591 .65948 L .77792 .66189 L p F P
0 g
s
.651 .758 .928 r
.77591 .65948 m .7667 .6621 L .76468 .65969 L p F P
0 g
s
.65 .757 .928 r
.35688 .66214 m .36542 .65953 L .36805 .66195 L p F P
0 g
s
.65 .757 .928 r
.36542 .65953 m .35688 .66214 L .35424 .65973 L p F P
0 g
s
.651 .758 .928 r
.6301 .66216 m .63909 .65954 L .6413 .66196 L p F P
0 g
s
.651 .758 .928 r
.63909 .65954 m .6301 .66216 L .62787 .65975 L p F P
0 g
s
.65 .758 .928 r
.49349 .66217 m .50225 .65955 L .50467 .66197 L p F P
0 g
s
.65 .758 .928 r
.50225 .65955 m .49349 .66217 L .49105 .65975 L p F P
0 g
s
.652 .759 .928 r
.91451 .66163 m .92397 .65899 L .92574 .66139 L p F P
0 g
s
.652 .759 .928 r
.92397 .65899 m .91451 .66163 L .91272 .65923 L p F P
0 g
s
.65 .757 .928 r
.23693 .65681 m .22859 .65943 L .23143 .66185 L p F P
0 g
s
.65 .757 .928 r
.23143 .66185 m .23976 .65924 L .23693 .65681 L p F P
0 g
s
.651 .758 .928 r
.77792 .66189 m .78715 .65927 L .78914 .66168 L p F P
0 g
s
.651 .758 .928 r
.78715 .65927 m .77792 .66189 L .77591 .65948 L p F P
0 g
s
.65 .757 .928 r
.36805 .66195 m .3766 .65933 L .37921 .66175 L p F P
0 g
s
.65 .757 .928 r
.3766 .65933 m .36805 .66195 L .36542 .65953 L p F P
0 g
s
.651 .758 .928 r
.6413 .66196 m .6503 .65934 L .6525 .66175 L p F P
0 g
s
.651 .758 .928 r
.6503 .65934 m .6413 .66196 L .63909 .65954 L p F P
0 g
s
.65 .758 .928 r
.50467 .66197 m .51345 .65935 L .51586 .66177 L p F P
0 g
s
.65 .758 .928 r
.51345 .65935 m .50467 .66197 L .50225 .65955 L p F P
0 g
s
.652 .759 .928 r
.92574 .66139 m .93522 .65874 L .93697 .66114 L p F P
0 g
s
.652 .759 .928 r
.93522 .65874 m .92574 .66139 L .92397 .65899 L p F P
0 g
s
.65 .757 .928 r
.24811 .65662 m .23976 .65924 L .24258 .66166 L p F P
0 g
s
.65 .757 .928 r
.24258 .66166 m .25093 .65905 L .24811 .65662 L p F P
0 g
s
.651 .758 .928 r
.78914 .66168 m .79839 .65905 L .80036 .66147 L p F P
0 g
s
.651 .758 .928 r
.79839 .65905 m .78914 .66168 L .78715 .65927 L p F P
0 g
s
.65 .757 .928 r
.37921 .66175 m .38779 .65913 L .39039 .66155 L p F P
0 g
s
.65 .757 .928 r
.38779 .65913 m .37921 .66175 L .3766 .65933 L p F P
0 g
s
.651 .758 .928 r
.6525 .66175 m .66153 .65913 L .6637 .66155 L p F P
0 g
s
.651 .758 .928 r
.66153 .65913 m .6525 .66175 L .6503 .65934 L p F P
0 g
s
.652 .76 .928 r
.93697 .66114 m .94647 .65849 L .94821 .66089 L p F P
0 g
s
.652 .76 .928 r
.94647 .65849 m .93697 .66114 L .93522 .65874 L p F P
0 g
s
.65 .758 .928 r
.51586 .66177 m .52466 .65915 L .52704 .66157 L p F P
0 g
s
.65 .758 .928 r
.52466 .65915 m .51586 .66177 L .51345 .65935 L p F P
0 g
s
.651 .758 .928 r
.80036 .66147 m .80963 .65884 L .81158 .66126 L p F P
0 g
s
.651 .758 .928 r
.80963 .65884 m .80036 .66147 L .79839 .65905 L p F P
0 g
s
.65 .757 .928 r
.2593 .65643 m .25093 .65905 L .25373 .66147 L p F P
0 g
s
.65 .757 .928 r
.25373 .66147 m .2621 .65886 L .2593 .65643 L p F P
0 g
s
.651 .758 .928 r
.6637 .66155 m .67275 .65893 L .67491 .66135 L p F P
0 g
s
.651 .758 .928 r
.67275 .65893 m .6637 .66155 L .66153 .65913 L p F P
0 g
s
.65 .757 .928 r
.39039 .66155 m .39898 .65893 L .40156 .66135 L p F P
0 g
s
.65 .757 .928 r
.39898 .65893 m .39039 .66155 L .38779 .65913 L p F P
0 g
s
.65 .758 .928 r
.52704 .66157 m .53587 .65895 L .53824 .66137 L p F P
0 g
s
.65 .758 .928 r
.53587 .65895 m .52704 .66157 L .52466 .65915 L p F P
0 g
s
.651 .758 .928 r
.81158 .66126 m .82088 .65862 L .82281 .66104 L p F P
0 g
s
.651 .758 .928 r
.82088 .65862 m .81158 .66126 L .80963 .65884 L p F P
0 g
s
.65 .757 .928 r
.27049 .65624 m .2621 .65886 L .26489 .66128 L p F P
0 g
s
.65 .757 .928 r
.26489 .66128 m .27327 .65867 L .27049 .65624 L p F P
0 g
s
.651 .758 .928 r
.67491 .66135 m .68398 .65872 L .68612 .66114 L p F P
0 g
s
.651 .758 .928 r
.68398 .65872 m .67491 .66135 L .67275 .65893 L p F P
0 g
s
.65 .757 .928 r
.40156 .66135 m .41017 .65873 L .41274 .66115 L p F P
0 g
s
.65 .757 .928 r
.41017 .65873 m .40156 .66135 L .39898 .65893 L p F P
0 g
s
.65 .758 .928 r
.53824 .66137 m .54708 .65874 L .54943 .66116 L p F P
0 g
s
.65 .758 .928 r
.54708 .65874 m .53824 .66137 L .53587 .65895 L p F P
0 g
s
.651 .758 .928 r
.82281 .66104 m .83212 .65841 L .83404 .66082 L p F P
0 g
s
.651 .758 .928 r
.83212 .65841 m .82281 .66104 L .82088 .65862 L p F P
0 g
s
.65 .757 .928 r
.28169 .65605 m .27327 .65867 L .27605 .66109 L p F P
0 g
s
.65 .757 .928 r
.27605 .66109 m .28445 .65848 L .28169 .65605 L p F P
0 g
s
.651 .758 .928 r
.68612 .66114 m .69521 .65852 L .69734 .66094 L p F P
0 g
s
.651 .758 .928 r
.69521 .65852 m .68612 .66114 L .68398 .65872 L p F P
0 g
s
.65 .757 .928 r
.41274 .66115 m .42137 .65853 L .42391 .66095 L p F P
0 g
s
.65 .757 .928 r
.42137 .65853 m .41274 .66115 L .41017 .65873 L p F P
0 g
s
.65 .758 .928 r
.54943 .66116 m .55829 .65854 L .56063 .66096 L p F P
0 g
s
.65 .758 .928 r
.55829 .65854 m .54943 .66116 L .54708 .65874 L p F P
0 g
s
.651 .758 .928 r
.84337 .65819 m .83404 .66082 L .83212 .65841 L p F P
0 g
s
.651 .758 .928 r
.83404 .66082 m .84337 .65819 L .84527 .6606 L p F P
0 g
s
.65 .757 .928 r
.29289 .65585 m .28445 .65848 L .28721 .6609 L p F P
0 g
s
.65 .757 .928 r
.28721 .6609 m .29563 .65828 L .29289 .65585 L p F P
0 g
s
.651 .758 .928 r
.69734 .66094 m .70645 .65831 L .70855 .66073 L p F P
0 g
s
.651 .758 .928 r
.70645 .65831 m .69734 .66094 L .69521 .65852 L p F P
0 g
s
0 0 .347 r
.52578 .48487 m .52577 .48489 L .52577 .48092 L p F P
0 g
s
0 0 .347 r
.52577 .48092 m .52579 .4809 L .52578 .48487 L p F P
0 g
s
.762 .5 .538 r
.52574 .48488 m .52577 .48489 L .52577 .48092 L p F P
0 g
s
.762 .5 .538 r
.52577 .48092 m .52574 .48091 L .52574 .48488 L p F P
0 g
s
.65 .757 .928 r
.42391 .66095 m .43257 .65833 L .4351 .66076 L p F P
0 g
s
.65 .757 .928 r
.43257 .65833 m .42391 .66095 L .42137 .65853 L p F P
0 g
s
.65 .758 .928 r
.56063 .66096 m .56951 .65834 L .57183 .66076 L p F P
0 g
s
.65 .758 .928 r
.56951 .65834 m .56063 .66096 L .55829 .65854 L p F P
0 g
s
0 0 .348 r
.52575 .48089 m .52574 .48091 L .52574 .48488 L p F P
0 g
s
.762 .5 .539 r
.52575 .48089 m .52579 .4809 L .52578 .48487 L p F P
0 g
s
.762 .5 .539 r
.52578 .48487 m .52575 .48486 L .52575 .48089 L p F P
0 g
s
0 0 .348 r
.52574 .48488 m .52575 .48486 L .52575 .48089 L p F P
0 g
s
.651 .758 .928 r
.84527 .6606 m .85462 .65796 L .85651 .66038 L p F P
0 g
s
.651 .758 .928 r
.85462 .65796 m .84527 .6606 L .84337 .65819 L p F P
0 g
s
.65 .757 .928 r
.30409 .65566 m .29563 .65828 L .29837 .66071 L p F P
0 g
s
.65 .757 .928 r
.29837 .66071 m .30682 .65809 L .30409 .65566 L p F P
0 g
s
.651 .758 .928 r
.70855 .66073 m .71768 .6581 L .71977 .66052 L p F P
0 g
s
.651 .758 .928 r
.71768 .6581 m .70855 .66073 L .70645 .65831 L p F P
0 g
s
.65 .757 .928 r
.4351 .66076 m .44377 .65813 L .44628 .66056 L p F P
0 g
s
.65 .757 .928 r
.44377 .65813 m .4351 .66076 L .43257 .65833 L p F P
0 g
s
.65 .758 .928 r
.57183 .66076 m .58073 .65814 L .58303 .66056 L p F P
0 g
s
.65 .758 .928 r
.58073 .65814 m .57183 .66076 L .56951 .65834 L p F P
0 g
s
.651 .758 .928 r
.86588 .65774 m .85651 .66038 L .85462 .65796 L p F P
0 g
s
.651 .758 .928 r
.85651 .66038 m .86588 .65774 L .86774 .66016 L p F P
0 g
s
.65 .757 .928 r
.31529 .65546 m .30682 .65809 L .30954 .66051 L p F P
0 g
s
.65 .757 .928 r
.30954 .66051 m .318 .65789 L .31529 .65546 L p F P
0 g
s
.651 .758 .928 r
.71977 .66052 m .72892 .6579 L .731 .66032 L p F P
0 g
s
.651 .758 .928 r
.72892 .6579 m .71977 .66052 L .71768 .6581 L p F P
0 g
s
.65 .757 .928 r
.44628 .66056 m .45498 .65793 L .45747 .66036 L p F P
0 g
s
.65 .757 .928 r
.45498 .65793 m .44628 .66056 L .44377 .65813 L p F P
0 g
s
.65 .758 .928 r
.58303 .66056 m .59195 .65793 L .59423 .66036 L p F P
0 g
s
.65 .758 .928 r
.59195 .65793 m .58303 .66056 L .58073 .65814 L p F P
0 g
s
.651 .759 .928 r
.86774 .66016 m .87714 .65751 L .87898 .65993 L p F P
0 g
s
.651 .758 .928 r
.87714 .65751 m .86774 .66016 L .86588 .65774 L p F P
0 g
s
.651 .758 .928 r
.731 .66032 m .74016 .65769 L .74222 .66011 L p F P
0 g
s
.651 .758 .928 r
.74016 .65769 m .731 .66032 L .72892 .6579 L p F P
0 g
s
.65 .757 .928 r
.3265 .65527 m .318 .65789 L .32071 .66032 L p F P
0 g
s
.65 .757 .928 r
.32071 .66032 m .32919 .6577 L .3265 .65527 L p F P
0 g
s
.651 .758 .928 r
.59423 .66036 m .60317 .65773 L .60544 .66015 L p F P
0 g
s
.651 .758 .928 r
.60317 .65773 m .59423 .66036 L .59195 .65793 L p F P
0 g
s
.65 .757 .928 r
.45747 .66036 m .46618 .65773 L .46866 .66015 L p F P
0 g
s
.65 .757 .928 r
.46618 .65773 m .45747 .66036 L .45498 .65793 L p F P
0 g
s
.651 .759 .928 r
.87898 .65993 m .88839 .65728 L .89023 .6597 L p F P
0 g
s
.651 .759 .928 r
.88839 .65728 m .87898 .65993 L .87714 .65751 L p F P
0 g
s
.651 .758 .928 r
.74222 .66011 m .75141 .65748 L .75345 .6599 L p F P
0 g
s
.651 .758 .928 r
.75141 .65748 m .74222 .66011 L .74016 .65769 L p F P
0 g
s
.65 .757 .928 r
.33188 .66012 m .34039 .6575 L .34306 .65992 L p F P
0 g
s
.65 .757 .928 r
.33771 .65507 m .32919 .6577 L .33188 .66012 L p F P
0 g
s
.65 .757 .928 r
.33188 .66012 m .34039 .6575 L .33771 .65507 L p F P
0 g
s
.651 .758 .928 r
.60544 .66015 m .6144 .65753 L .61665 .65995 L p F P
0 g
s
.651 .758 .928 r
.6144 .65753 m .60544 .66015 L .60317 .65773 L p F P
0 g
s
.65 .757 .928 r
.46866 .66015 m .47739 .65753 L .47985 .65995 L p F P
0 g
s
.65 .757 .928 r
.47739 .65753 m .46866 .66015 L .46618 .65773 L p F P
0 g
s
.651 .759 .928 r
.89023 .6597 m .89966 .65705 L .90147 .65947 L p F P
0 g
s
.651 .759 .928 r
.89966 .65705 m .89023 .6597 L .88839 .65728 L p F P
0 g
s
.651 .758 .928 r
.75345 .6599 m .76266 .65727 L .76468 .65969 L p F P
0 g
s
.651 .758 .928 r
.76266 .65727 m .75345 .6599 L .75141 .65748 L p F P
0 g
s
.65 .757 .928 r
.34306 .65992 m .35158 .6573 L .35424 .65973 L p F P
0 g
s
.65 .757 .928 r
.35158 .6573 m .34306 .65992 L .34039 .6575 L p F P
0 g
s
.651 .758 .928 r
.61665 .65995 m .62563 .65732 L .62787 .65975 L p F P
0 g
s
.651 .758 .928 r
.62563 .65732 m .61665 .65995 L .6144 .65753 L p F P
0 g
s
.65 .758 .928 r
.47985 .65995 m .48861 .65733 L .49105 .65975 L p F P
0 g
s
.65 .758 .928 r
.48861 .65733 m .47985 .65995 L .47739 .65753 L p F P
0 g
s
.651 .759 .928 r
.90147 .65947 m .91092 .65681 L .91272 .65923 L p F P
0 g
s
.651 .759 .928 r
.91092 .65681 m .90147 .65947 L .89966 .65705 L p F P
0 g
s
.65 .757 .928 r
.22289 .65457 m .21457 .65719 L .21743 .65961 L p F P
0 g
s
.65 .757 .928 r
.21743 .65961 m .22575 .657 L .22289 .65457 L p F P
0 g
s
.651 .758 .928 r
.76468 .65969 m .77391 .65706 L .77591 .65948 L p F P
0 g
s
.651 .758 .928 r
.77391 .65706 m .76468 .65969 L .76266 .65727 L p F P
0 g
s
.65 .757 .928 r
.35424 .65973 m .36278 .6571 L .36542 .65953 L p F P
0 g
s
.65 .757 .928 r
.36278 .6571 m .35424 .65973 L .35158 .6573 L p F P
0 g
s
.651 .758 .928 r
.62787 .65975 m .63687 .65712 L .63909 .65954 L p F P
0 g
s
.651 .758 .928 r
.63687 .65712 m .62787 .65975 L .62563 .65732 L p F P
0 g
s
.65 .758 .928 r
.49105 .65975 m .49982 .65713 L .50225 .65955 L p F P
0 g
s
.65 .758 .928 r
.49982 .65713 m .49105 .65975 L .48861 .65733 L p F P
0 g
s
.652 .759 .928 r
.91272 .65923 m .92219 .65657 L .92397 .65899 L p F P
0 g
s
.652 .759 .928 r
.92219 .65657 m .91272 .65923 L .91092 .65681 L p F P
0 g
s
.65 .757 .928 r
.23409 .65438 m .22575 .657 L .22859 .65943 L p F P
0 g
s
.65 .757 .928 r
.22859 .65943 m .23693 .65681 L .23409 .65438 L p F P
0 g
s
.651 .758 .928 r
.77591 .65948 m .78516 .65684 L .78715 .65927 L p F P
0 g
s
.651 .758 .928 r
.78516 .65684 m .77591 .65948 L .77391 .65706 L p F P
0 g
s
.65 .757 .928 r
.36542 .65953 m .37398 .6569 L .3766 .65933 L p F P
0 g
s
.65 .757 .928 r
.37398 .6569 m .36542 .65953 L .36278 .6571 L p F P
0 g
s
.651 .758 .928 r
.63909 .65954 m .6481 .65691 L .6503 .65934 L p F P
0 g
s
.651 .758 .928 r
.6481 .65691 m .63909 .65954 L .63687 .65712 L p F P
0 g
s
.65 .758 .928 r
.50225 .65955 m .51104 .65692 L .51345 .65935 L p F P
0 g
s
.65 .758 .928 r
.51104 .65692 m .50225 .65955 L .49982 .65713 L p F P
0 g
s
.652 .759 .928 r
.92397 .65899 m .93345 .65633 L .93522 .65874 L p F P
0 g
s
.652 .759 .928 r
.93345 .65633 m .92397 .65899 L .92219 .65657 L p F P
0 g
s
.65 .757 .928 r
.24529 .65419 m .23693 .65681 L .23976 .65924 L p F P
0 g
s
.65 .757 .928 r
.23976 .65924 m .24811 .65662 L .24529 .65419 L p F P
0 g
s
.651 .758 .928 r
.78715 .65927 m .79642 .65663 L .79839 .65905 L p F P
0 g
s
.651 .758 .928 r
.79642 .65663 m .78715 .65927 L .78516 .65684 L p F P
0 g
s
.65 .757 .928 r
.3766 .65933 m .38519 .65671 L .38779 .65913 L p F P
0 g
s
.65 .757 .928 r
.38519 .65671 m .3766 .65933 L .37398 .6569 L p F P
0 g
s
.651 .758 .928 r
.6503 .65934 m .65934 .65671 L .66153 .65913 L p F P
0 g
s
.651 .758 .928 r
.65934 .65671 m .6503 .65934 L .6481 .65691 L p F P
0 g
s
.65 .758 .928 r
.51345 .65935 m .52226 .65672 L .52466 .65915 L p F P
0 g
s
.65 .758 .928 r
.52226 .65672 m .51345 .65935 L .51104 .65692 L p F P
0 g
s
.652 .76 .928 r
.93522 .65874 m .94472 .65607 L .94647 .65849 L p F P
0 g
s
.652 .759 .928 r
.94472 .65607 m .93522 .65874 L .93345 .65633 L p F P
0 g
s
.65 .757 .928 r
.2565 .654 m .24811 .65662 L .25093 .65905 L p F P
0 g
s
.65 .757 .928 r
.25093 .65905 m .2593 .65643 L .2565 .654 L p F P
0 g
s
.651 .758 .928 r
.79839 .65905 m .80768 .65642 L .80963 .65884 L p F P
0 g
s
.651 .758 .928 r
.80768 .65642 m .79839 .65905 L .79642 .65663 L p F P
0 g
s
.65 .757 .928 r
.38779 .65913 m .39639 .65651 L .39898 .65893 L p F P
0 g
s
.65 .757 .928 r
.39639 .65651 m .38779 .65913 L .38519 .65671 L p F P
0 g
s
.651 .758 .928 r
.66153 .65913 m .67059 .6565 L .67275 .65893 L p F P
0 g
s
.651 .758 .928 r
.67059 .6565 m .66153 .65913 L .65934 .65671 L p F P
0 g
s
.65 .758 .928 r
.52466 .65915 m .53349 .65652 L .53587 .65895 L p F P
0 g
s
.65 .758 .928 r
.53349 .65652 m .52466 .65915 L .52226 .65672 L p F P
0 g
s
.651 .758 .928 r
.80963 .65884 m .81894 .6562 L .82088 .65862 L p F P
0 g
s
.651 .758 .928 r
.81894 .6562 m .80963 .65884 L .80768 .65642 L p F P
0 g
s
.65 .757 .928 r
.26771 .6538 m .2593 .65643 L .2621 .65886 L p F P
0 g
s
.65 .757 .928 r
.2621 .65886 m .27049 .65624 L .26771 .6538 L p F P
0 g
s
.651 .758 .928 r
.67275 .65893 m .68183 .6563 L .68398 .65872 L p F P
0 g
s
.651 .758 .928 r
.68183 .6563 m .67275 .65893 L .67059 .6565 L p F P
0 g
s
.65 .757 .928 r
.39898 .65893 m .4076 .65631 L .41017 .65873 L p F P
0 g
s
.65 .757 .928 r
.4076 .65631 m .39898 .65893 L .39639 .65651 L p F P
0 g
s
0 0 .347 r
.52578 .48885 m .52577 .48887 L .52577 .48489 L p F P
0 g
s
0 0 .347 r
.52577 .48489 m .52578 .48487 L .52578 .48885 L p F P
0 g
s
.761 .5 .538 r
.52574 .48886 m .52577 .48887 L .52577 .48489 L p F P
0 g
s
.761 .5 .538 r
.52577 .48489 m .52574 .48488 L .52574 .48886 L p F P
0 g
s
.65 .758 .928 r
.53587 .65895 m .54472 .65632 L .54708 .65874 L p F P
0 g
s
.65 .758 .928 r
.54472 .65632 m .53587 .65895 L .53349 .65652 L p F P
0 g
s
0 0 .348 r
.52575 .48486 m .52574 .48488 L .52574 .48886 L p F P
0 g
s
.761 .5 .539 r
.52575 .48486 m .52578 .48487 L .52578 .48885 L p F P
0 g
s
.761 .5 .539 r
.52578 .48885 m .52575 .48884 L .52575 .48486 L p F P
0 g
s
0 0 .348 r
.52574 .48886 m .52575 .48884 L .52575 .48486 L p F P
0 g
s
.651 .758 .928 r
.82088 .65862 m .8302 .65598 L .83212 .65841 L p F P
0 g
s
.651 .758 .928 r
.8302 .65598 m .82088 .65862 L .81894 .6562 L p F P
0 g
s
.65 .757 .928 r
.27892 .65361 m .27049 .65624 L .27327 .65867 L p F P
0 g
s
.65 .757 .928 r
.27327 .65867 m .28169 .65605 L .27892 .65361 L p F P
0 g
s
.651 .758 .928 r
.68398 .65872 m .69308 .65609 L .69521 .65852 L p F P
0 g
s
.651 .758 .928 r
.69308 .65609 m .68398 .65872 L .68183 .6563 L p F P
0 g
s
.65 .757 .928 r
.41017 .65873 m .41882 .65611 L .42137 .65853 L p F P
0 g
s
.65 .757 .928 r
.41882 .65611 m .41017 .65873 L .4076 .65631 L p F P
0 g
s
.65 .758 .928 r
.54708 .65874 m .55595 .65611 L .55829 .65854 L p F P
0 g
s
.65 .758 .928 r
.55595 .65611 m .54708 .65874 L .54472 .65632 L p F P
0 g
s
.651 .758 .928 r
.83212 .65841 m .84147 .65576 L .84337 .65819 L p F P
0 g
s
.651 .758 .928 r
.84147 .65576 m .83212 .65841 L .8302 .65598 L p F P
0 g
s
.65 .757 .928 r
.29013 .65342 m .28169 .65605 L .28445 .65848 L p F P
0 g
s
.65 .757 .928 r
.28445 .65848 m .29289 .65585 L .29013 .65342 L p F P
0 g
s
.651 .758 .928 r
.69521 .65852 m .70433 .65588 L .70645 .65831 L p F P
0 g
s
.651 .758 .928 r
.70433 .65588 m .69521 .65852 L .69308 .65609 L p F P
0 g
s
.65 .757 .928 r
.42137 .65853 m .43003 .6559 L .43257 .65833 L p F P
0 g
s
.65 .757 .928 r
.43003 .6559 m .42137 .65853 L .41882 .65611 L p F P
0 g
s
.65 .758 .928 r
.55829 .65854 m .56718 .65591 L .56951 .65834 L p F P
0 g
s
.65 .758 .928 r
.56718 .65591 m .55829 .65854 L .55595 .65611 L p F P
0 g
s
.651 .758 .928 r
.85274 .65554 m .84337 .65819 L .84147 .65576 L p F P
0 g
s
.651 .758 .928 r
.84337 .65819 m .85274 .65554 L .85462 .65796 L p F P
0 g
s
.65 .757 .928 r
.30135 .65322 m .29289 .65585 L .29563 .65828 L p F P
0 g
s
.65 .757 .928 r
.29563 .65828 m .30409 .65566 L .30135 .65322 L p F P
0 g
s
.651 .758 .928 r
.70645 .65831 m .71558 .65568 L .71768 .6581 L p F P
0 g
s
.651 .758 .928 r
.71558 .65568 m .70645 .65831 L .70433 .65588 L p F P
0 g
s
.65 .757 .928 r
.43257 .65833 m .44125 .6557 L .44377 .65813 L p F P
0 g
s
.65 .757 .928 r
.44125 .6557 m .43257 .65833 L .43003 .6559 L p F P
0 g
s
.65 .758 .928 r
.56951 .65834 m .57842 .65571 L .58073 .65814 L p F P
0 g
s
.65 .758 .928 r
.57842 .65571 m .56951 .65834 L .56718 .65591 L p F P
0 g
s
.651 .758 .928 r
.85462 .65796 m .86401 .65532 L .86588 .65774 L p F P
0 g
s
.651 .758 .928 r
.86401 .65532 m .85462 .65796 L .85274 .65554 L p F P
0 g
s
.65 .757 .928 r
.31257 .65302 m .30409 .65566 L .30682 .65809 L p F P
0 g
s
.65 .757 .928 r
.30682 .65809 m .31529 .65546 L .31257 .65302 L p F P
0 g
s
.651 .758 .928 r
.71768 .6581 m .72684 .65547 L .72892 .6579 L p F P
0 g
s
.651 .758 .928 r
.72684 .65547 m .71768 .6581 L .71558 .65568 L p F P
0 g
s
.65 .757 .928 r
.44377 .65813 m .45247 .6555 L .45498 .65793 L p F P
0 g
s
.65 .757 .928 r
.45247 .6555 m .44377 .65813 L .44125 .6557 L p F P
0 g
s
.65 .758 .928 r
.58073 .65814 m .58966 .6555 L .59195 .65793 L p F P
0 g
s
.65 .758 .928 r
.58966 .6555 m .58073 .65814 L .57842 .65571 L p F P
0 g
s
.651 .758 .928 r
.87528 .65509 m .86588 .65774 L .86401 .65532 L p F P
0 g
s
.651 .758 .928 r
.86588 .65774 m .87528 .65509 L .87714 .65751 L p F P
0 g
s
.65 .757 .928 r
.32379 .65283 m .31529 .65546 L .318 .65789 L p F P
0 g
s
.65 .757 .928 r
.318 .65789 m .3265 .65527 L .32379 .65283 L p F P
0 g
s
.651 .758 .928 r
.72892 .6579 m .7381 .65526 L .74016 .65769 L p F P
0 g
s
.651 .758 .928 r
.7381 .65526 m .72892 .6579 L .72684 .65547 L p F P
0 g
s
.65 .757 .928 r
.45498 .65793 m .4637 .6553 L .46618 .65773 L p F P
0 g
s
.65 .757 .928 r
.4637 .6553 m .45498 .65793 L .45247 .6555 L p F P
0 g
s
.651 .758 .928 r
.6009 .6553 m .59195 .65793 L .58966 .6555 L p F P
0 g
s
.651 .758 .928 r
.59195 .65793 m .6009 .6553 L .60317 .65773 L p F P
0 g
s
.651 .759 .928 r
.87714 .65751 m .88656 .65486 L .88839 .65728 L p F P
0 g
s
.651 .759 .928 r
.88656 .65486 m .87714 .65751 L .87528 .65509 L p F P
0 g
s
.651 .758 .928 r
.74016 .65769 m .74936 .65505 L .75141 .65748 L p F P
0 g
s
.651 .758 .928 r
.74936 .65505 m .74016 .65769 L .7381 .65526 L p F P
0 g
s
.65 .757 .928 r
.33502 .65263 m .3265 .65527 L .32919 .6577 L p F P
0 g
s
.65 .757 .928 r
.32919 .6577 m .33771 .65507 L .33502 .65263 L p F P
0 g
s
.651 .758 .928 r
.60317 .65773 m .61214 .65509 L .6144 .65753 L p F P
0 g
s
.651 .758 .928 r
.61214 .65509 m .60317 .65773 L .6009 .6553 L p F P
0 g
s
.65 .757 .928 r
.46618 .65773 m .47492 .6551 L .47739 .65753 L p F P
0 g
s
.65 .757 .928 r
.47492 .6551 m .46618 .65773 L .4637 .6553 L p F P
0 g
s
.651 .759 .928 r
.88839 .65728 m .89784 .65463 L .89966 .65705 L p F P
0 g
s
.651 .759 .928 r
.89784 .65463 m .88839 .65728 L .88656 .65486 L p F P
0 g
s
.651 .758 .928 r
.75141 .65748 m .76063 .65484 L .76266 .65727 L p F P
0 g
s
.651 .758 .928 r
.76063 .65484 m .75141 .65748 L .74936 .65505 L p F P
0 g
s
.65 .757 .928 r
.34039 .6575 m .34892 .65487 L .35158 .6573 L p F P
0 g
s
.65 .757 .928 r
.34625 .65243 m .33771 .65507 L .34039 .6575 L p F P
0 g
s
.65 .757 .928 r
.34039 .6575 m .34892 .65487 L .34625 .65243 L p F P
0 g
s
.651 .758 .928 r
.6144 .65753 m .62339 .65489 L .62563 .65732 L p F P
0 g
s
.651 .758 .928 r
.62339 .65489 m .6144 .65753 L .61214 .65509 L p F P
0 g
s
.65 .758 .928 r
.47739 .65753 m .48616 .6549 L .48861 .65733 L p F P
0 g
s
.65 .757 .928 r
.48616 .6549 m .47739 .65753 L .47492 .6551 L p F P
0 g
s
.651 .759 .928 r
.89966 .65705 m .90912 .65439 L .91092 .65681 L p F P
0 g
s
.651 .759 .928 r
.90912 .65439 m .89966 .65705 L .89784 .65463 L p F P
0 g
s
.65 .757 .928 r
.22003 .65212 m .21169 .65475 L .21457 .65719 L p F P
0 g
s
.65 .757 .928 r
.21457 .65719 m .22289 .65457 L .22003 .65212 L p F P
0 g
s
.651 .758 .928 r
.76266 .65727 m .77189 .65463 L .77391 .65706 L p F P
0 g
s
.651 .758 .928 r
.77189 .65463 m .76266 .65727 L .76063 .65484 L p F P
0 g
s
.65 .757 .928 r
.35158 .6573 m .36013 .65467 L .36278 .6571 L p F P
0 g
s
.65 .757 .928 r
.36013 .65467 m .35158 .6573 L .34892 .65487 L p F P
0 g
s
.651 .758 .928 r
.62563 .65732 m .63464 .65469 L .63687 .65712 L p F P
0 g
s
.651 .758 .928 r
.63464 .65469 m .62563 .65732 L .62339 .65489 L p F P
0 g
s
.65 .758 .928 r
.48861 .65733 m .49739 .65469 L .49982 .65713 L p F P
0 g
s
.65 .758 .928 r
.49739 .65469 m .48861 .65733 L .48616 .6549 L p F P
0 g
s
.652 .759 .928 r
.91092 .65681 m .9204 .65415 L .92219 .65657 L p F P
0 g
s
.652 .759 .928 r
.9204 .65415 m .91092 .65681 L .90912 .65439 L p F P
0 g
s
.65 .757 .928 r
.23124 .65194 m .22289 .65457 L .22575 .657 L p F P
0 g
s
.65 .757 .928 r
.22575 .657 m .23409 .65438 L .23124 .65194 L p F P
0 g
s
.651 .758 .928 r
.77391 .65706 m .78316 .65441 L .78516 .65684 L p F P
0 g
s
.651 .758 .928 r
.78316 .65441 m .77391 .65706 L .77189 .65463 L p F P
0 g
s
.65 .757 .928 r
.36278 .6571 m .37135 .65447 L .37398 .6569 L p F P
0 g
s
.65 .757 .928 r
.37135 .65447 m .36278 .6571 L .36013 .65467 L p F P
0 g
s
.651 .758 .928 r
.63687 .65712 m .6459 .65448 L .6481 .65691 L p F P
0 g
s
.651 .758 .928 r
.6459 .65448 m .63687 .65712 L .63464 .65469 L p F P
0 g
s
.65 .758 .928 r
.49982 .65713 m .50862 .65449 L .51104 .65692 L p F P
0 g
s
.65 .758 .928 r
.50862 .65449 m .49982 .65713 L .49739 .65469 L p F P
0 g
s
.652 .759 .928 r
.92219 .65657 m .93169 .6539 L .93345 .65633 L p F P
0 g
s
.652 .759 .928 r
.93169 .6539 m .92219 .65657 L .9204 .65415 L p F P
0 g
s
.65 .757 .928 r
.24246 .65175 m .23409 .65438 L .23693 .65681 L p F P
0 g
s
.65 .757 .928 r
.23693 .65681 m .24529 .65419 L .24246 .65175 L p F P
0 g
s
.651 .758 .928 r
.78516 .65684 m .79444 .6542 L .79642 .65663 L p F P
0 g
s
.651 .758 .928 r
.79444 .6542 m .78516 .65684 L .78316 .65441 L p F P
0 g
s
.65 .757 .928 r
.37398 .6569 m .38257 .65427 L .38519 .65671 L p F P
0 g
s
.65 .757 .928 r
.38257 .65427 m .37398 .6569 L .37135 .65447 L p F P
0 g
s
.651 .758 .928 r
.6481 .65691 m .65715 .65427 L .65934 .65671 L p F P
0 g
s
.651 .758 .928 r
.65715 .65427 m .6481 .65691 L .6459 .65448 L p F P
0 g
s
0 0 .347 r
.52578 .49284 m .52577 .49286 L .52577 .48887 L p F P
0 g
s
0 0 .347 r
.52577 .48887 m .52578 .48885 L .52578 .49284 L p F P
0 g
s
.761 .5 .538 r
.52574 .49285 m .52577 .49286 L .52577 .48887 L p F P
0 g
s
.761 .5 .538 r
.52577 .48887 m .52574 .48886 L .52574 .49285 L p F P
0 g
s
.65 .758 .928 r
.51104 .65692 m .51986 .65429 L .52226 .65672 L p F P
0 g
s
.65 .758 .928 r
.51986 .65429 m .51104 .65692 L .50862 .65449 L p F P
0 g
s
0 0 .348 r
.52575 .48884 m .52574 .48886 L .52574 .49285 L p F P
0 g
s
.652 .759 .928 r
.93345 .65633 m .94297 .65365 L .94472 .65607 L p F P
0 g
s
.652 .759 .928 r
.94297 .65365 m .93345 .65633 L .93169 .6539 L p F P
0 g
s
.761 .5 .539 r
.52575 .48884 m .52578 .48885 L .52578 .49284 L p F P
0 g
s
.761 .5 .539 r
.52578 .49284 m .52575 .49283 L .52575 .48884 L p F P
0 g
s
0 0 .348 r
.52574 .49285 m .52575 .49283 L .52575 .48884 L p F P
0 g
s
.65 .757 .928 r
.25368 .65155 m .24529 .65419 L .24811 .65662 L p F P
0 g
s
.65 .757 .928 r
.24811 .65662 m .2565 .654 L .25368 .65155 L p F P
0 g
s
.651 .758 .928 r
.79642 .65663 m .80571 .65399 L .80768 .65642 L p F P
0 g
s
.651 .758 .928 r
.80571 .65399 m .79642 .65663 L .79444 .6542 L p F P
0 g
s
.65 .757 .928 r
.38519 .65671 m .3938 .65407 L .39639 .65651 L p F P
0 g
s
.65 .757 .928 r
.3938 .65407 m .38519 .65671 L .38257 .65427 L p F P
0 g
s
.651 .758 .928 r
.65934 .65671 m .66841 .65407 L .67059 .6565 L p F P
0 g
s
.651 .758 .928 r
.66841 .65407 m .65934 .65671 L .65715 .65427 L p F P
0 g
s
.65 .758 .928 r
.52226 .65672 m .53111 .65409 L .53349 .65652 L p F P
0 g
s
.65 .758 .928 r
.53111 .65409 m .52226 .65672 L .51986 .65429 L p F P
0 g
s
.651 .758 .928 r
.80768 .65642 m .81699 .65377 L .81894 .6562 L p F P
0 g
s
.651 .758 .928 r
.81699 .65377 m .80768 .65642 L .80571 .65399 L p F P
0 g
s
.65 .757 .928 r
.26491 .65136 m .2565 .654 L .2593 .65643 L p F P
0 g
s
.65 .757 .928 r
.2593 .65643 m .26771 .6538 L .26491 .65136 L p F P
0 g
s
.651 .758 .928 r
.67059 .6565 m .67968 .65386 L .68183 .6563 L p F P
0 g
s
.651 .758 .928 r
.67968 .65386 m .67059 .6565 L .66841 .65407 L p F P
0 g
s
.65 .757 .928 r
.39639 .65651 m .40503 .65387 L .4076 .65631 L p F P
0 g
s
.65 .757 .928 r
.40503 .65387 m .39639 .65651 L .3938 .65407 L p F P
0 g
s
.65 .758 .928 r
.53349 .65652 m .54235 .65388 L .54472 .65632 L p F P
0 g
s
.65 .758 .928 r
.54235 .65388 m .53349 .65652 L .53111 .65409 L p F P
0 g
s
.651 .758 .928 r
.81894 .6562 m .82827 .65355 L .8302 .65598 L p F P
0 g
s
.651 .758 .928 r
.82827 .65355 m .81894 .6562 L .81699 .65377 L p F P
0 g
s
.65 .757 .928 r
.27614 .65117 m .26771 .6538 L .27049 .65624 L p F P
0 g
s
.65 .757 .928 r
.27049 .65624 m .27892 .65361 L .27614 .65117 L p F P
0 g
s
.651 .758 .928 r
.68183 .6563 m .69094 .65365 L .69308 .65609 L p F P
0 g
s
.651 .758 .928 r
.69094 .65365 m .68183 .6563 L .67968 .65386 L p F P
0 g
s
.65 .757 .928 r
.41626 .65367 m .4076 .65631 L .40503 .65387 L p F P
0 g
s
.65 .757 .928 r
.4076 .65631 m .41626 .65367 L .41882 .65611 L p F P
0 g
s
.65 .758 .928 r
.54472 .65632 m .5536 .65368 L .55595 .65611 L p F P
0 g
s
.65 .758 .928 r
.5536 .65368 m .54472 .65632 L .54235 .65388 L p F P
0 g
s
.651 .758 .928 r
.8302 .65598 m .83956 .65333 L .84147 .65576 L p F P
0 g
s
.651 .758 .928 r
.83956 .65333 m .8302 .65598 L .82827 .65355 L p F P
0 g
s
.65 .757 .928 r
.28737 .65097 m .27892 .65361 L .28169 .65605 L p F P
0 g
s
.65 .757 .928 r
.28169 .65605 m .29013 .65342 L .28737 .65097 L p F P
0 g
s
.651 .758 .928 r
.69308 .65609 m .70221 .65345 L .70433 .65588 L p F P
0 g
s
.651 .758 .928 r
.70221 .65345 m .69308 .65609 L .69094 .65365 L p F P
0 g
s
.65 .757 .928 r
.41882 .65611 m .42749 .65347 L .43003 .6559 L p F P
0 g
s
.65 .757 .928 r
.42749 .65347 m .41882 .65611 L .41626 .65367 L p F P
0 g
s
.65 .758 .928 r
.55595 .65611 m .56485 .65347 L .56718 .65591 L p F P
0 g
s
.65 .758 .928 r
.56485 .65347 m .55595 .65611 L .5536 .65368 L p F P
0 g
s
.651 .758 .928 r
.84147 .65576 m .85084 .65311 L .85274 .65554 L p F P
0 g
s
.651 .758 .928 r
.85084 .65311 m .84147 .65576 L .83956 .65333 L p F P
0 g
s
.65 .757 .928 r
.2986 .65077 m .29013 .65342 L .29289 .65585 L p F P
0 g
s
.65 .757 .928 r
.29289 .65585 m .30135 .65322 L .2986 .65077 L p F P
0 g
s
.651 .758 .928 r
.70433 .65588 m .71348 .65324 L .71558 .65568 L p F P
0 g
s
.651 .758 .928 r
.71348 .65324 m .70433 .65588 L .70221 .65345 L p F P
0 g
s
.65 .757 .928 r
.43003 .6559 m .43872 .65327 L .44125 .6557 L p F P
0 g
s
.65 .757 .928 r
.43872 .65327 m .43003 .6559 L .42749 .65347 L p F P
0 g
s
.65 .758 .928 r
.56718 .65591 m .5761 .65327 L .57842 .65571 L p F P
0 g
s
.65 .758 .928 r
.5761 .65327 m .56718 .65591 L .56485 .65347 L p F P
0 g
s
.651 .758 .928 r
.86213 .65289 m .85274 .65554 L .85084 .65311 L p F P
0 g
s
.651 .758 .928 r
.85274 .65554 m .86213 .65289 L .86401 .65532 L p F P
0 g
s
.65 .757 .928 r
.30984 .65058 m .30135 .65322 L .30409 .65566 L p F P
0 g
s
.65 .757 .928 r
.30409 .65566 m .31257 .65302 L .30984 .65058 L p F P
0 g
s
.651 .758 .928 r
.71558 .65568 m .72475 .65303 L .72684 .65547 L p F P
0 g
s
.651 .758 .928 r
.72475 .65303 m .71558 .65568 L .71348 .65324 L p F P
0 g
s
.65 .757 .928 r
.44125 .6557 m .44996 .65306 L .45247 .6555 L p F P
0 g
s
.65 .757 .928 r
.44996 .65306 m .44125 .6557 L .43872 .65327 L p F P
0 g
s
.65 .758 .928 r
.57842 .65571 m .58736 .65307 L .58966 .6555 L p F P
0 g
s
.65 .758 .928 r
.58736 .65307 m .57842 .65571 L .5761 .65327 L p F P
0 g
s
.651 .758 .928 r
.86401 .65532 m .87342 .65266 L .87528 .65509 L p F P
0 g
s
.651 .758 .928 r
.87342 .65266 m .86401 .65532 L .86213 .65289 L p F P
0 g
s
.65 .757 .928 r
.32108 .65038 m .31257 .65302 L .31529 .65546 L p F P
0 g
s
.65 .757 .928 r
.31529 .65546 m .32379 .65283 L .32108 .65038 L p F P
0 g
s
.651 .758 .928 r
.72684 .65547 m .73603 .65282 L .7381 .65526 L p F P
0 g
s
.651 .758 .928 r
.73603 .65282 m .72684 .65547 L .72475 .65303 L p F P
0 g
s
.65 .757 .928 r
.45247 .6555 m .4612 .65286 L .4637 .6553 L p F P
0 g
s
.65 .757 .928 r
.4612 .65286 m .45247 .6555 L .44996 .65306 L p F P
0 g
s
.651 .758 .928 r
.58966 .6555 m .59862 .65286 L .6009 .6553 L p F P
0 g
s
.651 .758 .928 r
.59862 .65286 m .58966 .6555 L .58736 .65307 L p F P
0 g
s
.651 .759 .928 r
.88472 .65243 m .87528 .65509 L .87342 .65266 L p F P
0 g
s
.651 .759 .928 r
.87528 .65509 m .88472 .65243 L .88656 .65486 L p F P
0 g
s
.651 .758 .928 r
.7381 .65526 m .74731 .65261 L .74936 .65505 L p F P
0 g
s
.651 .758 .928 r
.74731 .65261 m .7381 .65526 L .73603 .65282 L p F P
0 g
s
.65 .757 .928 r
.33232 .65018 m .32379 .65283 L .3265 .65527 L p F P
0 g
s
.65 .757 .928 r
.3265 .65527 m .33502 .65263 L .33232 .65018 L p F P
0 g
s
.651 .758 .928 r
.60988 .65266 m .6009 .6553 L .59862 .65286 L p F P
0 g
s
.651 .758 .928 r
.6009 .6553 m .60988 .65266 L .61214 .65509 L p F P
0 g
s
.65 .757 .928 r
.4637 .6553 m .47245 .65266 L .47492 .6551 L p F P
0 g
s
.65 .757 .928 r
.47245 .65266 m .4637 .6553 L .4612 .65286 L p F P
0 g
s
.651 .759 .928 r
.88656 .65486 m .89601 .6522 L .89784 .65463 L p F P
0 g
s
.651 .759 .928 r
.89601 .6522 m .88656 .65486 L .88472 .65243 L p F P
0 g
s
.651 .758 .928 r
.74936 .65505 m .75859 .6524 L .76063 .65484 L p F P
0 g
s
.651 .758 .928 r
.75859 .6524 m .74936 .65505 L .74731 .65261 L p F P
0 g
s
.65 .757 .928 r
.34357 .64998 m .33502 .65263 L .33771 .65507 L p F P
0 g
s
.65 .757 .928 r
.33771 .65507 m .34625 .65243 L .34357 .64998 L p F P
0 g
s
.651 .758 .928 r
.61214 .65509 m .62114 .65245 L .62339 .65489 L p F P
0 g
s
.651 .758 .928 r
.62114 .65245 m .61214 .65509 L .60988 .65266 L p F P
0 g
s
.65 .757 .928 r
.47492 .6551 m .4837 .65246 L .48616 .6549 L p F P
0 g
s
.65 .757 .928 r
.4837 .65246 m .47492 .6551 L .47245 .65266 L p F P
0 g
s
.651 .759 .928 r
.89784 .65463 m .90731 .65196 L .90912 .65439 L p F P
0 g
s
.651 .759 .928 r
.90731 .65196 m .89784 .65463 L .89601 .6522 L p F P
0 g
s
.65 .757 .928 r
.21715 .64967 m .20881 .65231 L .21169 .65475 L p F P
0 g
s
.65 .757 .928 r
.21169 .65475 m .22003 .65212 L .21715 .64967 L p F P
0 g
s
.651 .758 .928 r
.76063 .65484 m .76987 .65219 L .77189 .65463 L p F P
0 g
s
.651 .758 .928 r
.76987 .65219 m .76063 .65484 L .75859 .6524 L p F P
0 g
s
.65 .757 .928 r
.34892 .65487 m .35748 .65223 L .36013 .65467 L p F P
0 g
s
.65 .757 .928 r
.35482 .64978 m .34625 .65243 L .34892 .65487 L p F P
0 g
s
.65 .757 .928 r
.34892 .65487 m .35748 .65223 L .35482 .64978 L p F P
0 g
s
0 0 .348 r
.52578 .49684 m .52577 .49686 L .52577 .49286 L p F P
0 g
s
0 0 .348 r
.52577 .49286 m .52578 .49284 L .52578 .49684 L p F P
0 g
s
.761 .5 .538 r
.52574 .49685 m .52577 .49686 L .52577 .49286 L p F P
0 g
s
.761 .5 .538 r
.52577 .49286 m .52574 .49285 L .52574 .49685 L p F P
0 g
s
.651 .758 .928 r
.62339 .65489 m .63241 .65225 L .63464 .65469 L p F P
0 g
s
.651 .758 .928 r
.63241 .65225 m .62339 .65489 L .62114 .65245 L p F P
0 g
s
.65 .758 .928 r
.48616 .6549 m .49495 .65225 L .49739 .65469 L p F P
0 g
s
.65 .757 .928 r
.49495 .65225 m .48616 .6549 L .4837 .65246 L p F P
0 g
s
0 0 .348 r
.52575 .49283 m .52574 .49285 L .52574 .49685 L p F P
0 g
s
.761 .5 .539 r
.52575 .49283 m .52578 .49284 L .52578 .49684 L p F P
0 g
s
.761 .5 .539 r
.52578 .49684 m .52575 .49683 L .52575 .49283 L p F P
0 g
s
0 0 .348 r
.52574 .49685 m .52575 .49683 L .52575 .49283 L p F P
0 g
s
.652 .759 .928 r
.90912 .65439 m .91861 .65172 L .9204 .65415 L p F P
0 g
s
.652 .759 .928 r
.91861 .65172 m .90912 .65439 L .90731 .65196 L p F P
0 g
s
.65 .757 .928 r
.22838 .64949 m .22003 .65212 L .22289 .65457 L p F P
0 g
s
.65 .757 .928 r
.22289 .65457 m .23124 .65194 L .22838 .64949 L p F P
0 g
s
.651 .758 .928 r
.77189 .65463 m .78116 .65198 L .78316 .65441 L p F P
0 g
s
.651 .758 .928 r
.78116 .65198 m .77189 .65463 L .76987 .65219 L p F P
0 g
s
.65 .757 .928 r
.36013 .65467 m .36872 .65203 L .37135 .65447 L p F P
0 g
s
.65 .757 .928 r
.36872 .65203 m .36013 .65467 L .35748 .65223 L p F P
0 g
s
.651 .758 .928 r
.63464 .65469 m .64368 .65204 L .6459 .65448 L p F P
0 g
s
.651 .758 .928 r
.64368 .65204 m .63464 .65469 L .63241 .65225 L p F P
0 g
s
.65 .758 .928 r
.49739 .65469 m .5062 .65205 L .50862 .65449 L p F P
0 g
s
.65 .758 .928 r
.5062 .65205 m .49739 .65469 L .49495 .65225 L p F P
0 g
s
.652 .759 .928 r
.9204 .65415 m .92991 .65148 L .93169 .6539 L p F P
0 g
s
.652 .759 .928 r
.92991 .65148 m .9204 .65415 L .91861 .65172 L p F P
0 g
s
.65 .757 .928 r
.23962 .64929 m .23124 .65194 L .23409 .65438 L p F P
0 g
s
.65 .757 .928 r
.23409 .65438 m .24246 .65175 L .23962 .64929 L p F P
0 g
s
.651 .758 .928 r
.78316 .65441 m .79245 .65176 L .79444 .6542 L p F P
0 g
s
.651 .758 .928 r
.79245 .65176 m .78316 .65441 L .78116 .65198 L p F P
0 g
s
.65 .757 .928 r
.37135 .65447 m .37995 .65183 L .38257 .65427 L p F P
0 g
s
.65 .757 .928 r
.37995 .65183 m .37135 .65447 L .36872 .65203 L p F P
0 g
s
.651 .758 .928 r
.6459 .65448 m .65496 .65183 L .65715 .65427 L p F P
0 g
s
.651 .758 .928 r
.65496 .65183 m .6459 .65448 L .64368 .65204 L p F P
0 g
s
.65 .758 .928 r
.50862 .65449 m .51746 .65185 L .51986 .65429 L p F P
0 g
s
.65 .758 .928 r
.51746 .65185 m .50862 .65449 L .5062 .65205 L p F P
0 g
s
.652 .759 .928 r
.93169 .6539 m .94122 .65123 L .94297 .65365 L p F P
0 g
s
.652 .759 .928 r
.94122 .65123 m .93169 .6539 L .92991 .65148 L p F P
0 g
s
.65 .757 .928 r
.25086 .6491 m .24246 .65175 L .24529 .65419 L p F P
0 g
s
.65 .757 .928 r
.24529 .65419 m .25368 .65155 L .25086 .6491 L p F P
0 g
s
.651 .758 .928 r
.79444 .6542 m .80374 .65155 L .80571 .65399 L p F P
0 g
s
.651 .758 .928 r
.80374 .65155 m .79444 .6542 L .79245 .65176 L p F P
0 g
s
.65 .757 .928 r
.38257 .65427 m .3912 .65163 L .3938 .65407 L p F P
0 g
s
.65 .757 .928 r
.3912 .65163 m .38257 .65427 L .37995 .65183 L p F P
0 g
s
.651 .758 .928 r
.65715 .65427 m .66623 .65163 L .66841 .65407 L p F P
0 g
s
.651 .758 .928 r
.66623 .65163 m .65715 .65427 L .65496 .65183 L p F P
0 g
s
.65 .758 .928 r
.51986 .65429 m .52871 .65164 L .53111 .65409 L p F P
0 g
s
.65 .758 .928 r
.52871 .65164 m .51986 .65429 L .51746 .65185 L p F P
0 g
s
.651 .758 .928 r
.80571 .65399 m .81504 .65133 L .81699 .65377 L p F P
0 g
s
.651 .758 .928 r
.81504 .65133 m .80571 .65399 L .80374 .65155 L p F P
0 g
s
.65 .757 .928 r
.2621 .64891 m .25368 .65155 L .2565 .654 L p F P
0 g
s
.65 .757 .928 r
.2565 .654 m .26491 .65136 L .2621 .64891 L p F P
0 g
s
.651 .758 .928 r
.66841 .65407 m .67751 .65142 L .67968 .65386 L p F P
0 g
s
.651 .758 .928 r
.67751 .65142 m .66841 .65407 L .66623 .65163 L p F P
0 g
s
.65 .757 .928 r
.3938 .65407 m .40244 .65143 L .40503 .65387 L p F P
0 g
s
.65 .757 .928 r
.40244 .65143 m .3938 .65407 L .3912 .65163 L p F P
0 g
s
.65 .758 .928 r
.53111 .65409 m .53998 .65144 L .54235 .65388 L p F P
0 g
s
.65 .758 .928 r
.53998 .65144 m .53111 .65409 L .52871 .65164 L p F P
0 g
s
.651 .758 .928 r
.81699 .65377 m .82634 .65111 L .82827 .65355 L p F P
0 g
s
.651 .758 .928 r
.82634 .65111 m .81699 .65377 L .81504 .65133 L p F P
0 g
s
.65 .757 .928 r
.27335 .64871 m .26491 .65136 L .26771 .6538 L p F P
0 g
s
.65 .757 .928 r
.26771 .6538 m .27614 .65117 L .27335 .64871 L p F P
0 g
s
.651 .758 .928 r
.67968 .65386 m .68879 .65121 L .69094 .65365 L p F P
0 g
s
.651 .758 .928 r
.68879 .65121 m .67968 .65386 L .67751 .65142 L p F P
0 g
s
.65 .757 .928 r
.40503 .65387 m .41369 .65123 L .41626 .65367 L p F P
0 g
s
.65 .757 .928 r
.41369 .65123 m .40503 .65387 L .40244 .65143 L p F P
0 g
s
.65 .758 .928 r
.54235 .65388 m .55124 .65124 L .5536 .65368 L p F P
0 g
s
.65 .758 .928 r
.55124 .65124 m .54235 .65388 L .53998 .65144 L p F P
0 g
s
.651 .758 .928 r
.82827 .65355 m .83764 .65089 L .83956 .65333 L p F P
0 g
s
.651 .758 .928 r
.83764 .65089 m .82827 .65355 L .82634 .65111 L p F P
0 g
s
.65 .757 .928 r
.2846 .64852 m .27614 .65117 L .27892 .65361 L p F P
0 g
s
.65 .757 .928 r
.27892 .65361 m .28737 .65097 L .2846 .64852 L p F P
0 g
s
.651 .758 .928 r
.69094 .65365 m .70008 .651 L .70221 .65345 L p F P
0 g
s
.651 .758 .928 r
.70008 .651 m .69094 .65365 L .68879 .65121 L p F P
0 g
s
.65 .757 .928 r
.42494 .65102 m .41626 .65367 L .41369 .65123 L p F P
0 g
s
.65 .757 .928 r
.41626 .65367 m .42494 .65102 L .42749 .65347 L p F P
0 g
s
.65 .758 .928 r
.5536 .65368 m .56251 .65103 L .56485 .65347 L p F P
0 g
s
.65 .758 .928 r
.56251 .65103 m .5536 .65368 L .55124 .65124 L p F P
0 g
s
.651 .758 .928 r
.83956 .65333 m .84894 .65067 L .85084 .65311 L p F P
0 g
s
.651 .758 .928 r
.84894 .65067 m .83956 .65333 L .83764 .65089 L p F P
0 g
s
.65 .757 .928 r
.29585 .64832 m .28737 .65097 L .29013 .65342 L p F P
0 g
s
.65 .757 .928 r
.29013 .65342 m .2986 .65077 L .29585 .64832 L p F P
0 g
s
.651 .758 .928 r
.70221 .65345 m .71137 .6508 L .71348 .65324 L p F P
0 g
s
.651 .758 .928 r
.71137 .6508 m .70221 .65345 L .70008 .651 L p F P
0 g
s
.65 .757 .928 r
.42749 .65347 m .43619 .65082 L .43872 .65327 L p F P
0 g
s
.65 .757 .928 r
.43619 .65082 m .42749 .65347 L .42494 .65102 L p F P
0 g
s
.65 .758 .928 r
.56485 .65347 m .57378 .65083 L .5761 .65327 L p F P
0 g
s
.65 .758 .928 r
.57378 .65083 m .56485 .65347 L .56251 .65103 L p F P
0 g
s
.651 .758 .928 r
.85084 .65311 m .86025 .65045 L .86213 .65289 L p F P
0 g
s
.651 .758 .928 r
.86025 .65045 m .85084 .65311 L .84894 .65067 L p F P
0 g
s
.65 .757 .928 r
.3071 .64812 m .2986 .65077 L .30135 .65322 L p F P
0 g
s
.65 .757 .928 r
.30135 .65322 m .30984 .65058 L .3071 .64812 L p F P
0 g
s
.651 .758 .928 r
.71348 .65324 m .72266 .65059 L .72475 .65303 L p F P
0 g
s
.651 .758 .928 r
.72266 .65059 m .71348 .65324 L .71137 .6508 L p F P
0 g
s
.65 .757 .928 r
.43872 .65327 m .44744 .65062 L .44996 .65306 L p F P
0 g
s
.65 .757 .928 r
.44744 .65062 m .43872 .65327 L .43619 .65082 L p F P
0 g
s
.65 .758 .928 r
.5761 .65327 m .58505 .65062 L .58736 .65307 L p F P
0 g
s
.65 .758 .928 r
.58505 .65062 m .5761 .65327 L .57378 .65083 L p F P
0 g
s
.651 .758 .928 r
.87156 .65022 m .86213 .65289 L .86025 .65045 L p F P
0 g
s
.651 .758 .928 r
.86213 .65289 m .87156 .65022 L .87342 .65266 L p F P
0 g
s
.65 .757 .928 r
.31836 .64793 m .30984 .65058 L .31257 .65302 L p F P
0 g
s
.65 .757 .928 r
.31257 .65302 m .32108 .65038 L .31836 .64793 L p F P
0 g
s
.651 .758 .928 r
.72475 .65303 m .73395 .65038 L .73603 .65282 L p F P
0 g
s
.651 .758 .928 r
.73395 .65038 m .72475 .65303 L .72266 .65059 L p F P
0 g
s
.65 .757 .928 r
.44996 .65306 m .4587 .65042 L .4612 .65286 L p F P
0 g
s
.65 .757 .928 r
.4587 .65042 m .44996 .65306 L .44744 .65062 L p F P
0 g
s
.651 .758 .928 r
.58736 .65307 m .59633 .65042 L .59862 .65286 L p F P
0 g
s
.651 .758 .928 r
.59633 .65042 m .58736 .65307 L .58505 .65062 L p F P
0 g
s
.651 .759 .928 r
.87342 .65266 m .88287 .64999 L .88472 .65243 L p F P
0 g
s
.651 .758 .928 r
.88287 .64999 m .87342 .65266 L .87156 .65022 L p F P
0 g
s
.651 .758 .928 r
.73603 .65282 m .74525 .65017 L .74731 .65261 L p F P
0 g
s
.651 .758 .928 r
.74525 .65017 m .73603 .65282 L .73395 .65038 L p F P
0 g
s
.65 .757 .928 r
.32962 .64773 m .32108 .65038 L .32379 .65283 L p F P
0 g
s
.65 .757 .928 r
.32379 .65283 m .33232 .65018 L .32962 .64773 L p F P
0 g
s
0 0 .348 r
.52578 .50085 m .52577 .50087 L .52577 .49686 L p F P
0 g
s
0 0 .348 r
.52577 .49686 m .52578 .49684 L .52578 .50085 L p F P
0 g
s
.761 .5 .538 r
.52574 .50086 m .52577 .50087 L .52577 .49686 L p F P
0 g
s
.761 .5 .538 r
.52577 .49686 m .52574 .49685 L .52574 .50086 L p F P
0 g
s
.651 .758 .928 r
.59862 .65286 m .60761 .65021 L .60988 .65266 L p F P
0 g
s
.651 .758 .928 r
.60761 .65021 m .59862 .65286 L .59633 .65042 L p F P
0 g
s
.65 .757 .928 r
.4612 .65286 m .46996 .65021 L .47245 .65266 L p F P
0 g
s
.65 .757 .928 r
.46996 .65021 m .4612 .65286 L .4587 .65042 L p F P
0 g
s
0 0 .348 r
.52575 .49683 m .52574 .49685 L .52574 .50086 L p F P
0 g
s
.761 .5 .539 r
.52575 .49683 m .52578 .49684 L .52578 .50085 L p F P
0 g
s
.761 .5 .539 r
.52578 .50085 m .52575 .50084 L .52575 .49683 L p F P
0 g
s
0 0 .348 r
.52574 .50086 m .52575 .50084 L .52575 .49683 L p F P
0 g
s
.651 .759 .928 r
.89418 .64976 m .88472 .65243 L .88287 .64999 L p F P
0 g
s
.651 .759 .928 r
.88472 .65243 m .89418 .64976 L .89601 .6522 L p F P
0 g
s
.651 .758 .928 r
.74731 .65261 m .75655 .64996 L .75859 .6524 L p F P
0 g
s
.651 .758 .928 r
.75655 .64996 m .74731 .65261 L .74525 .65017 L p F P
0 g
s
.65 .757 .928 r
.34088 .64753 m .33232 .65018 L .33502 .65263 L p F P
0 g
s
.65 .757 .928 r
.33502 .65263 m .34357 .64998 L .34088 .64753 L p F P
0 g
s
.651 .758 .928 r
.61889 .65 m .60988 .65266 L .60761 .65021 L p F P
0 g
s
.651 .758 .928 r
.60988 .65266 m .61889 .65 L .62114 .65245 L p F P
0 g
s
.65 .757 .928 r
.47245 .65266 m .48123 .65001 L .4837 .65246 L p F P
0 g
s
.65 .757 .928 r
.48123 .65001 m .47245 .65266 L .46996 .65021 L p F P
0 g
s
.651 .759 .928 r
.89601 .6522 m .9055 .64952 L .90731 .65196 L p F P
0 g
s
.651 .759 .928 r
.9055 .64952 m .89601 .6522 L .89418 .64976 L p F P
0 g
s
.65 .757 .928 r
.21427 .64722 m .20592 .64986 L .20881 .65231 L p F P
0 g
s
.65 .757 .928 r
.20881 .65231 m .21715 .64967 L .21427 .64722 L p F P
0 g
s
.651 .758 .928 r
.75859 .6524 m .76785 .64974 L .76987 .65219 L p F P
0 g
s
.651 .758 .928 r
.76785 .64974 m .75859 .6524 L .75655 .64996 L p F P
0 g
s
.65 .757 .928 r
.35215 .64733 m .34357 .64998 L .34625 .65243 L p F P
0 g
s
.65 .757 .928 r
.34625 .65243 m .35482 .64978 L .35215 .64733 L p F P
0 g
s
.651 .758 .928 r
.62114 .65245 m .63017 .6498 L .63241 .65225 L p F P
0 g
s
.651 .758 .928 r
.63017 .6498 m .62114 .65245 L .61889 .65 L p F P
0 g
s
.65 .757 .928 r
.4837 .65246 m .4925 .64981 L .49495 .65225 L p F P
0 g
s
.65 .757 .928 r
.4925 .64981 m .4837 .65246 L .48123 .65001 L p F P
0 g
s
.652 .759 .928 r
.90731 .65196 m .91682 .64928 L .91861 .65172 L p F P
0 g
s
.652 .759 .928 r
.91682 .64928 m .90731 .65196 L .9055 .64952 L p F P
0 g
s
.65 .757 .928 r
.22552 .64703 m .21715 .64967 L .22003 .65212 L p F P
0 g
s
.65 .757 .928 r
.22003 .65212 m .22838 .64949 L .22552 .64703 L p F P
0 g
s
.651 .758 .928 r
.76987 .65219 m .77915 .64953 L .78116 .65198 L p F P
0 g
s
.651 .758 .928 r
.77915 .64953 m .76987 .65219 L .76785 .64974 L p F P
0 g
s
.65 .757 .928 r
.35748 .65223 m .36607 .64958 L .36872 .65203 L p F P
0 g
s
.65 .757 .928 r
.36342 .64712 m .35482 .64978 L .35748 .65223 L p F P
0 g
s
.65 .757 .928 r
.35748 .65223 m .36607 .64958 L .36342 .64712 L p F P
0 g
s
.651 .758 .928 r
.63241 .65225 m .64146 .64959 L .64368 .65204 L p F P
0 g
s
.651 .758 .928 r
.64146 .64959 m .63241 .65225 L .63017 .6498 L p F P
0 g
s
.65 .758 .928 r
.49495 .65225 m .50377 .6496 L .5062 .65205 L p F P
0 g
s
.65 .758 .928 r
.50377 .6496 m .49495 .65225 L .4925 .64981 L p F P
0 g
s
.652 .759 .928 r
.91861 .65172 m .92814 .64904 L .92991 .65148 L p F P
0 g
s
.652 .759 .928 r
.92814 .64904 m .91861 .65172 L .91682 .64928 L p F P
0 g
s
.65 .757 .928 r
.23677 .64684 m .22838 .64949 L .23124 .65194 L p F P
0 g
s
.65 .757 .928 r
.23124 .65194 m .23962 .64929 L .23677 .64684 L p F P
0 g
s
.651 .758 .928 r
.78116 .65198 m .79046 .64932 L .79245 .65176 L p F P
0 g
s
.651 .758 .928 r
.79046 .64932 m .78116 .65198 L .77915 .64953 L p F P
0 g
s
.65 .757 .928 r
.36872 .65203 m .37733 .64938 L .37995 .65183 L p F P
0 g
s
.65 .757 .928 r
.37733 .64938 m .36872 .65203 L .36607 .64958 L p F P
0 g
s
.651 .758 .928 r
.64368 .65204 m .65275 .64939 L .65496 .65183 L p F P
0 g
s
.651 .758 .928 r
.65275 .64939 m .64368 .65204 L .64146 .64959 L p F P
0 g
s
.65 .758 .928 r
.5062 .65205 m .51504 .6494 L .51746 .65185 L p F P
0 g
s
.65 .758 .928 r
.51504 .6494 m .5062 .65205 L .50377 .6496 L p F P
0 g
s
.652 .759 .928 r
.92991 .65148 m .93946 .64879 L .94122 .65123 L p F P
0 g
s
.652 .759 .928 r
.93946 .64879 m .92991 .65148 L .92814 .64904 L p F P
0 g
s
.65 .757 .928 r
.24803 .64664 m .23962 .64929 L .24246 .65175 L p F P
0 g
s
.65 .757 .928 r
.24246 .65175 m .25086 .6491 L .24803 .64664 L p F P
0 g
s
.651 .758 .928 r
.79245 .65176 m .80177 .6491 L .80374 .65155 L p F P
0 g
s
.651 .758 .928 r
.80177 .6491 m .79245 .65176 L .79046 .64932 L p F P
0 g
s
.65 .757 .928 r
.37995 .65183 m .38858 .64918 L .3912 .65163 L p F P
0 g
s
.65 .757 .928 r
.38858 .64918 m .37995 .65183 L .37733 .64938 L p F P
0 g
s
.651 .758 .928 r
.65496 .65183 m .66405 .64918 L .66623 .65163 L p F P
0 g
s
.651 .758 .928 r
.66405 .64918 m .65496 .65183 L .65275 .64939 L p F P
0 g
s
.65 .758 .928 r
.51746 .65185 m .52632 .64919 L .52871 .65164 L p F P
0 g
s
.65 .758 .928 r
.52632 .64919 m .51746 .65185 L .51504 .6494 L p F P
0 g
s
.651 .758 .928 r
.80374 .65155 m .81308 .64888 L .81504 .65133 L p F P
0 g
s
.651 .758 .928 r
.81308 .64888 m .80374 .65155 L .80177 .6491 L p F P
0 g
s
.65 .757 .928 r
.25929 .64645 m .25086 .6491 L .25368 .65155 L p F P
0 g
s
.65 .757 .928 r
.25368 .65155 m .2621 .64891 L .25929 .64645 L p F P
0 g
s
.651 .758 .928 r
.66623 .65163 m .67534 .64897 L .67751 .65142 L p F P
0 g
s
.651 .758 .928 r
.67534 .64897 m .66623 .65163 L .66405 .64918 L p F P
0 g
s
.65 .757 .928 r
.3912 .65163 m .39985 .64898 L .40244 .65143 L p F P
0 g
s
.65 .757 .928 r
.39985 .64898 m .3912 .65163 L .38858 .64918 L p F P
0 g
s
.65 .758 .928 r
.52871 .65164 m .53759 .64899 L .53998 .65144 L p F P
0 g
s
.65 .758 .928 r
.53759 .64899 m .52871 .65164 L .52632 .64919 L p F P
0 g
s
.651 .758 .928 r
.81504 .65133 m .8244 .64867 L .82634 .65111 L p F P
0 g
s
.651 .758 .928 r
.8244 .64867 m .81504 .65133 L .81308 .64888 L p F P
0 g
s
.65 .757 .928 r
.27055 .64625 m .2621 .64891 L .26491 .65136 L p F P
0 g
s
.65 .757 .928 r
.26491 .65136 m .27335 .64871 L .27055 .64625 L p F P
0 g
s
.651 .758 .928 r
.67751 .65142 m .68664 .64876 L .68879 .65121 L p F P
0 g
s
.651 .758 .928 r
.68664 .64876 m .67751 .65142 L .67534 .64897 L p F P
0 g
s
.65 .757 .928 r
.40244 .65143 m .41111 .64877 L .41369 .65123 L p F P
0 g
s
.65 .757 .928 r
.41111 .64877 m .40244 .65143 L .39985 .64898 L p F P
0 g
s
.65 .758 .928 r
.53998 .65144 m .54888 .64878 L .55124 .65124 L p F P
0 g
s
.65 .758 .928 r
.54888 .64878 m .53998 .65144 L .53759 .64899 L p F P
0 g
s
.651 .758 .928 r
.82634 .65111 m .83572 .64845 L .83764 .65089 L p F P
0 g
s
.651 .758 .928 r
.83572 .64845 m .82634 .65111 L .8244 .64867 L p F P
0 g
s
.65 .757 .928 r
.28182 .64606 m .27335 .64871 L .27614 .65117 L p F P
0 g
s
.65 .757 .928 r
.27614 .65117 m .2846 .64852 L .28182 .64606 L p F P
0 g
s
.651 .758 .928 r
.68879 .65121 m .69794 .64855 L .70008 .651 L p F P
0 g
s
.651 .758 .928 r
.69794 .64855 m .68879 .65121 L .68664 .64876 L p F P
0 g
s
.65 .757 .928 r
.41369 .65123 m .42238 .64857 L .42494 .65102 L p F P
0 g
s
.65 .757 .928 r
.42238 .64857 m .41369 .65123 L .41111 .64877 L p F P
0 g
s
.65 .758 .928 r
.55124 .65124 m .56016 .64858 L .56251 .65103 L p F P
0 g
s
.65 .758 .928 r
.56016 .64858 m .55124 .65124 L .54888 .64878 L p F P
0 g
s
.651 .758 .928 r
.83764 .65089 m .84704 .64822 L .84894 .65067 L p F P
0 g
s
.651 .758 .928 r
.84704 .64822 m .83764 .65089 L .83572 .64845 L p F P
0 g
s
.65 .757 .928 r
.29308 .64586 m .2846 .64852 L .28737 .65097 L p F P
0 g
s
.65 .757 .928 r
.28737 .65097 m .29585 .64832 L .29308 .64586 L p F P
0 g
s
.651 .758 .928 r
.70008 .651 m .70925 .64835 L .71137 .6508 L p F P
0 g
s
.651 .758 .928 r
.70925 .64835 m .70008 .651 L .69794 .64855 L p F P
0 g
s
.65 .757 .928 r
.42494 .65102 m .43365 .64837 L .43619 .65082 L p F P
0 g
s
.65 .757 .928 r
.43365 .64837 m .42494 .65102 L .42238 .64857 L p F P
0 g
s
.65 .758 .928 r
.56251 .65103 m .57145 .64837 L .57378 .65083 L p F P
0 g
s
.65 .758 .928 r
.57145 .64837 m .56251 .65103 L .56016 .64858 L p F P
0 g
s
.651 .758 .928 r
.84894 .65067 m .85836 .648 L .86025 .65045 L p F P
0 g
s
.651 .758 .928 r
.85836 .648 m .84894 .65067 L .84704 .64822 L p F P
0 g
s
.65 .757 .928 r
.30436 .64566 m .29585 .64832 L .2986 .65077 L p F P
0 g
s
.65 .757 .928 r
.2986 .65077 m .3071 .64812 L .30436 .64566 L p F P
0 g
s
.651 .758 .928 r
.71137 .6508 m .72056 .64814 L .72266 .65059 L p F P
0 g
s
.651 .758 .928 r
.72056 .64814 m .71137 .6508 L .70925 .64835 L p F P
0 g
s
0 0 .348 r
.52578 .50487 m .52577 .50489 L .52577 .50087 L p F P
0 g
s
0 0 .348 r
.52577 .50087 m .52578 .50085 L .52578 .50487 L p F P
0 g
s
.761 .5 .538 r
.52574 .50488 m .52577 .50489 L .52577 .50087 L p F P
0 g
s
.761 .5 .538 r
.52577 .50087 m .52574 .50086 L .52574 .50488 L p F P
0 g
s
.65 .757 .928 r
.43619 .65082 m .44492 .64817 L .44744 .65062 L p F P
0 g
s
.65 .757 .928 r
.44492 .64817 m .43619 .65082 L .43365 .64837 L p F P
0 g
s
.65 .758 .928 r
.57378 .65083 m .58274 .64817 L .58505 .65062 L p F P
0 g
s
.65 .758 .928 r
.58274 .64817 m .57378 .65083 L .57145 .64837 L p F P
0 g
s
0 0 .348 r
.52575 .50084 m .52574 .50086 L .52574 .50488 L p F P
0 g
s
.761 .5 .539 r
.52575 .50084 m .52578 .50085 L .52578 .50487 L p F P
0 g
s
.761 .5 .539 r
.52578 .50487 m .52575 .50487 L .52575 .50084 L p F P
0 g
s
0 0 .348 r
.52574 .50488 m .52575 .50487 L .52575 .50084 L p F P
0 g
s
.651 .758 .928 r
.86025 .65045 m .86969 .64777 L .87156 .65022 L p F P
0 g
s
.651 .758 .928 r
.86969 .64777 m .86025 .65045 L .85836 .648 L p F P
0 g
s
.65 .757 .928 r
.31563 .64546 m .3071 .64812 L .30984 .65058 L p F P
0 g
s
.65 .757 .928 r
.30984 .65058 m .31836 .64793 L .31563 .64546 L p F P
0 g
s
.651 .758 .928 r
.72266 .65059 m .73187 .64793 L .73395 .65038 L p F P
0 g
s
.651 .758 .928 r
.73187 .64793 m .72266 .65059 L .72056 .64814 L p F P
0 g
s
.65 .757 .928 r
.44744 .65062 m .45619 .64796 L .4587 .65042 L p F P
0 g
s
.65 .757 .928 r
.45619 .64796 m .44744 .65062 L .44492 .64817 L p F P
0 g
s
.651 .758 .928 r
.58505 .65062 m .59403 .64796 L .59633 .65042 L p F P
0 g
s
.651 .758 .928 r
.59403 .64796 m .58505 .65062 L .58274 .64817 L p F P
0 g
s
.651 .758 .928 r
.88102 .64754 m .87156 .65022 L .86969 .64777 L p F P
0 g
s
.651 .758 .928 r
.87156 .65022 m .88102 .64754 L .88287 .64999 L p F P
0 g
s
.651 .758 .928 r
.73395 .65038 m .74318 .64772 L .74525 .65017 L p F P
0 g
s
.651 .758 .928 r
.74318 .64772 m .73395 .65038 L .73187 .64793 L p F P
0 g
s
.65 .757 .928 r
.32691 .64526 m .31836 .64793 L .32108 .65038 L p F P
0 g
s
.65 .757 .928 r
.32108 .65038 m .32962 .64773 L .32691 .64526 L p F P
0 g
s
.651 .758 .928 r
.59633 .65042 m .60533 .64776 L .60761 .65021 L p F P
0 g
s
.651 .758 .928 r
.60533 .64776 m .59633 .65042 L .59403 .64796 L p F P
0 g
s
.65 .757 .928 r
.4587 .65042 m .46747 .64776 L .46996 .65021 L p F P
0 g
s
.65 .757 .928 r
.46747 .64776 m .4587 .65042 L .45619 .64796 L p F P
0 g
s
.651 .759 .928 r
.88287 .64999 m .89235 .64731 L .89418 .64976 L p F P
0 g
s
.651 .759 .928 r
.89235 .64731 m .88287 .64999 L .88102 .64754 L p F P
0 g
s
.651 .758 .928 r
.74525 .65017 m .7545 .6475 L .75655 .64996 L p F P
0 g
s
.651 .758 .928 r
.7545 .6475 m .74525 .65017 L .74318 .64772 L p F P
0 g
s
.65 .757 .928 r
.33819 .64506 m .32962 .64773 L .33232 .65018 L p F P
0 g
s
.65 .757 .928 r
.33232 .65018 m .34088 .64753 L .33819 .64506 L p F P
0 g
s
.651 .758 .928 r
.60761 .65021 m .61663 .64755 L .61889 .65 L p F P
0 g
s
.651 .758 .928 r
.61663 .64755 m .60761 .65021 L .60533 .64776 L p F P
0 g
s
.65 .757 .928 r
.46996 .65021 m .47875 .64755 L .48123 .65001 L p F P
0 g
s
.65 .757 .928 r
.47875 .64755 m .46996 .65021 L .46747 .64776 L p F P
0 g
s
.651 .759 .928 r
.90368 .64708 m .89418 .64976 L .89235 .64731 L p F P
0 g
s
.651 .759 .928 r
.89418 .64976 m .90368 .64708 L .9055 .64952 L p F P
0 g
s
.65 .757 .928 r
.21138 .64475 m .20302 .6474 L .20592 .64986 L p F P
0 g
s
.65 .757 .928 r
.20592 .64986 m .21427 .64722 L .21138 .64475 L p F P
0 g
s
.651 .758 .928 r
.75655 .64996 m .76582 .64729 L .76785 .64974 L p F P
0 g
s
.651 .758 .928 r
.76582 .64729 m .75655 .64996 L .7545 .6475 L p F P
0 g
s
.65 .757 .928 r
.34947 .64486 m .34088 .64753 L .34357 .64998 L p F P
0 g
s
.65 .757 .928 r
.34357 .64998 m .35215 .64733 L .34947 .64486 L p F P
0 g
s
.651 .758 .928 r
.61889 .65 m .62793 .64734 L .63017 .6498 L p F P
0 g
s
.651 .758 .928 r
.62793 .64734 m .61889 .65 L .61663 .64755 L p F P
0 g
s
.65 .757 .928 r
.48123 .65001 m .49004 .64735 L .4925 .64981 L p F P
0 g
s
.65 .757 .928 r
.49004 .64735 m .48123 .65001 L .47875 .64755 L p F P
0 g
s
.652 .759 .928 r
.9055 .64952 m .91502 .64684 L .91682 .64928 L p F P
0 g
s
.651 .759 .928 r
.91502 .64684 m .9055 .64952 L .90368 .64708 L p F P
0 g
s
.65 .757 .928 r
.22265 .64456 m .21427 .64722 L .21715 .64967 L p F P
0 g
s
.65 .757 .928 r
.21715 .64967 m .22552 .64703 L .22265 .64456 L p F P
0 g
s
.651 .758 .928 r
.76785 .64974 m .77714 .64708 L .77915 .64953 L p F P
0 g
s
.651 .758 .928 r
.77714 .64708 m .76785 .64974 L .76582 .64729 L p F P
0 g
s
.65 .757 .928 r
.36076 .64466 m .35215 .64733 L .35482 .64978 L p F P
0 g
s
.65 .757 .928 r
.35482 .64978 m .36342 .64712 L .36076 .64466 L p F P
0 g
s
.651 .758 .928 r
.63017 .6498 m .63923 .64714 L .64146 .64959 L p F P
0 g
s
.651 .758 .928 r
.63923 .64714 m .63017 .6498 L .62793 .64734 L p F P
0 g
s
.65 .758 .928 r
.4925 .64981 m .50133 .64715 L .50377 .6496 L p F P
0 g
s
.65 .757 .928 r
.50133 .64715 m .4925 .64981 L .49004 .64735 L p F P
0 g
s
.652 .759 .928 r
.91682 .64928 m .92635 .64659 L .92814 .64904 L p F P
0 g
s
.652 .759 .928 r
.92635 .64659 m .91682 .64928 L .91502 .64684 L p F P
0 g
s
.65 .757 .928 r
.23392 .64437 m .22552 .64703 L .22838 .64949 L p F P
0 g
s
.65 .757 .928 r
.22838 .64949 m .23677 .64684 L .23392 .64437 L p F P
0 g
s
.651 .758 .928 r
.77915 .64953 m .78846 .64686 L .79046 .64932 L p F P
0 g
s
.651 .758 .928 r
.78846 .64686 m .77915 .64953 L .77714 .64708 L p F P
0 g
s
.65 .757 .928 r
.36607 .64958 m .37469 .64692 L .37733 .64938 L p F P
0 g
s
.65 .757 .928 r
.37205 .64446 m .36342 .64712 L .36607 .64958 L p F P
0 g
s
.65 .757 .928 r
.36607 .64958 m .37469 .64692 L .37205 .64446 L p F P
0 g
s
.651 .758 .928 r
.64146 .64959 m .65054 .64693 L .65275 .64939 L p F P
0 g
s
.651 .758 .928 r
.65054 .64693 m .64146 .64959 L .63923 .64714 L p F P
0 g
s
.65 .758 .928 r
.50377 .6496 m .51262 .64694 L .51504 .6494 L p F P
0 g
s
.65 .758 .928 r
.51262 .64694 m .50377 .6496 L .50133 .64715 L p F P
0 g
s
.652 .759 .928 r
.92814 .64904 m .93769 .64635 L .93946 .64879 L p F P
0 g
s
.652 .759 .928 r
.93769 .64635 m .92814 .64904 L .92635 .64659 L p F P
0 g
s
.65 .757 .928 r
.24519 .64418 m .23677 .64684 L .23962 .64929 L p F P
0 g
s
.65 .757 .928 r
.23962 .64929 m .24803 .64664 L .24519 .64418 L p F P
0 g
s
.651 .758 .928 r
.79046 .64932 m .79979 .64665 L .80177 .6491 L p F P
0 g
s
.651 .758 .928 r
.79979 .64665 m .79046 .64932 L .78846 .64686 L p F P
0 g
s
.65 .757 .928 r
.37733 .64938 m .38597 .64672 L .38858 .64918 L p F P
0 g
s
.65 .757 .928 r
.38597 .64672 m .37733 .64938 L .37469 .64692 L p F P
0 g
s
.651 .758 .928 r
.65275 .64939 m .66185 .64672 L .66405 .64918 L p F P
0 g
s
.651 .758 .928 r
.66185 .64672 m .65275 .64939 L .65054 .64693 L p F P
0 g
s
.65 .758 .928 r
.51504 .6494 m .52391 .64674 L .52632 .64919 L p F P
0 g
s
.65 .758 .928 r
.52391 .64674 m .51504 .6494 L .51262 .64694 L p F P
0 g
s
.651 .758 .928 r
.80177 .6491 m .81112 .64643 L .81308 .64888 L p F P
0 g
s
.651 .758 .928 r
.81112 .64643 m .80177 .6491 L .79979 .64665 L p F P
0 g
s
.65 .757 .928 r
.25646 .64398 m .24803 .64664 L .25086 .6491 L p F P
0 g
s
.65 .757 .928 r
.25086 .6491 m .25929 .64645 L .25646 .64398 L p F P
0 g
s
.651 .758 .928 r
.66405 .64918 m .67317 .64651 L .67534 .64897 L p F P
0 g
s
.651 .758 .928 r
.67317 .64651 m .66405 .64918 L .66185 .64672 L p F P
0 g
s
.65 .757 .928 r
.38858 .64918 m .39724 .64652 L .39985 .64898 L p F P
0 g
s
.65 .757 .928 r
.39724 .64652 m .38858 .64918 L .38597 .64672 L p F P
0 g
s
.65 .758 .928 r
.52632 .64919 m .53521 .64653 L .53759 .64899 L p F P
0 g
s
.65 .758 .928 r
.53521 .64653 m .52632 .64919 L .52391 .64674 L p F P
0 g
s
.651 .758 .928 r
.81308 .64888 m .82245 .64621 L .8244 .64867 L p F P
0 g
s
.651 .758 .928 r
.82245 .64621 m .81308 .64888 L .81112 .64643 L p F P
0 g
s
.65 .757 .928 r
.26774 .64379 m .25929 .64645 L .2621 .64891 L p F P
0 g
s
.65 .757 .928 r
.2621 .64891 m .27055 .64625 L .26774 .64379 L p F P
0 g
s
.651 .758 .928 r
.67534 .64897 m .68448 .64631 L .68664 .64876 L p F P
0 g
s
.651 .758 .928 r
.68448 .64631 m .67534 .64897 L .67317 .64651 L p F P
0 g
s
.65 .757 .928 r
.39985 .64898 m .40852 .64632 L .41111 .64877 L p F P
0 g
s
.65 .757 .928 r
.40852 .64632 m .39985 .64898 L .39724 .64652 L p F P
0 g
s
.65 .758 .928 r
.53759 .64899 m .5465 .64633 L .54888 .64878 L p F P
0 g
s
.65 .758 .928 r
.5465 .64633 m .53759 .64899 L .53521 .64653 L p F P
0 g
s
.651 .758 .928 r
.8244 .64867 m .83379 .64599 L .83572 .64845 L p F P
0 g
s
.651 .758 .928 r
.83379 .64599 m .8244 .64867 L .82245 .64621 L p F P
0 g
s
.65 .757 .928 r
.27903 .64359 m .27055 .64625 L .27335 .64871 L p F P
0 g
s
.65 .757 .928 r
.27335 .64871 m .28182 .64606 L .27903 .64359 L p F P
0 g
s
.651 .758 .928 r
.68664 .64876 m .6958 .6461 L .69794 .64855 L p F P
0 g
s
.651 .758 .928 r
.6958 .6461 m .68664 .64876 L .68448 .64631 L p F P
0 g
s
.65 .757 .928 r
.41111 .64877 m .41981 .64611 L .42238 .64857 L p F P
0 g
s
.65 .757 .928 r
.41981 .64611 m .41111 .64877 L .40852 .64632 L p F P
0 g
s
0 0 .348 r
.52578 .5089 m .52577 .50892 L .52577 .50489 L p F P
0 g
s
0 0 .348 r
.52577 .50489 m .52578 .50487 L .52578 .5089 L p F P
0 g
s
.761 .5 .538 r
.52574 .50892 m .52577 .50892 L .52577 .50489 L p F P
0 g
s
.761 .5 .538 r
.52577 .50489 m .52574 .50488 L .52574 .50892 L p F P
0 g
s
.65 .758 .928 r
.54888 .64878 m .55781 .64612 L .56016 .64858 L p F P
0 g
s
.65 .758 .928 r
.55781 .64612 m .54888 .64878 L .5465 .64633 L p F P
0 g
s
0 0 .348 r
.52575 .50487 m .52574 .50488 L .52574 .50892 L p F P
0 g
s
.761 .5 .539 r
.52575 .50487 m .52578 .50487 L .52578 .5089 L p F P
0 g
s
.761 .5 .539 r
.52578 .5089 m .52575 .5089 L .52575 .50487 L p F P
0 g
s
0 0 .348 r
.52574 .50892 m .52575 .5089 L .52575 .50487 L p F P
0 g
s
.651 .758 .928 r
.83572 .64845 m .84513 .64577 L .84704 .64822 L p F P
0 g
s
.651 .758 .928 r
.84513 .64577 m .83572 .64845 L .83379 .64599 L p F P
0 g
s
.65 .757 .928 r
.29031 .64339 m .28182 .64606 L .2846 .64852 L p F P
0 g
s
.65 .757 .928 r
.2846 .64852 m .29308 .64586 L .29031 .64339 L p F P
0 g
s
.651 .758 .928 r
.69794 .64855 m .70712 .64589 L .70925 .64835 L p F P
0 g
s
.651 .758 .928 r
.70712 .64589 m .69794 .64855 L .6958 .6461 L p F P
0 g
s
.65 .757 .928 r
.42238 .64857 m .4311 .64591 L .43365 .64837 L p F P
0 g
s
.65 .757 .928 r
.4311 .64591 m .42238 .64857 L .41981 .64611 L p F P
0 g
s
.65 .758 .928 r
.56016 .64858 m .56911 .64591 L .57145 .64837 L p F P
0 g
s
.65 .758 .928 r
.56911 .64591 m .56016 .64858 L .55781 .64612 L p F P
0 g
s
.651 .758 .928 r
.84704 .64822 m .85647 .64555 L .85836 .648 L p F P
0 g
s
.651 .758 .928 r
.85647 .64555 m .84704 .64822 L .84513 .64577 L p F P
0 g
s
.65 .757 .928 r
.3016 .64319 m .29308 .64586 L .29585 .64832 L p F P
0 g
s
.65 .757 .928 r
.29585 .64832 m .30436 .64566 L .3016 .64319 L p F P
0 g
s
.651 .758 .928 r
.70925 .64835 m .71845 .64568 L .72056 .64814 L p F P
0 g
s
.651 .758 .928 r
.71845 .64568 m .70925 .64835 L .70712 .64589 L p F P
0 g
s
.65 .757 .928 r
.43365 .64837 m .44239 .64571 L .44492 .64817 L p F P
0 g
s
.65 .757 .928 r
.44239 .64571 m .43365 .64837 L .4311 .64591 L p F P
0 g
s
.65 .758 .928 r
.57145 .64837 m .58042 .64571 L .58274 .64817 L p F P
0 g
s
.65 .758 .928 r
.58042 .64571 m .57145 .64837 L .56911 .64591 L p F P
0 g
s
.651 .758 .928 r
.85836 .648 m .86781 .64532 L .86969 .64777 L p F P
0 g
s
.651 .758 .928 r
.86781 .64532 m .85836 .648 L .85647 .64555 L p F P
0 g
s
.65 .757 .928 r
.31289 .64299 m .30436 .64566 L .3071 .64812 L p F P
0 g
s
.65 .757 .928 r
.3071 .64812 m .31563 .64546 L .31289 .64299 L p F P
0 g
s
.651 .758 .928 r
.72056 .64814 m .72978 .64547 L .73187 .64793 L p F P
0 g
s
.651 .758 .928 r
.72978 .64547 m .72056 .64814 L .71845 .64568 L p F P
0 g
s
.65 .757 .928 r
.44492 .64817 m .45368 .6455 L .45619 .64796 L p F P
0 g
s
.65 .757 .928 r
.45368 .6455 m .44492 .64817 L .44239 .64571 L p F P
0 g
s
.651 .758 .928 r
.58274 .64817 m .59173 .6455 L .59403 .64796 L p F P
0 g
s
.651 .758 .928 r
.59173 .6455 m .58274 .64817 L .58042 .64571 L p F P
0 g
s
.651 .758 .928 r
.86969 .64777 m .87916 .64509 L .88102 .64754 L p F P
0 g
s
.651 .758 .928 r
.87916 .64509 m .86969 .64777 L .86781 .64532 L p F P
0 g
s
.65 .757 .928 r
.32419 .64279 m .31563 .64546 L .31836 .64793 L p F P
0 g
s
.65 .757 .928 r
.31836 .64793 m .32691 .64526 L .32419 .64279 L p F P
0 g
s
.651 .758 .928 r
.73187 .64793 m .74111 .64526 L .74318 .64772 L p F P
0 g
s
.651 .758 .928 r
.74111 .64526 m .73187 .64793 L .72978 .64547 L p F P
0 g
s
.65 .757 .928 r
.45619 .64796 m .46497 .6453 L .46747 .64776 L p F P
0 g
s
.65 .757 .928 r
.46497 .6453 m .45619 .64796 L .45368 .6455 L p F P
0 g
s
.651 .758 .928 r
.59403 .64796 m .60304 .6453 L .60533 .64776 L p F P
0 g
s
.651 .758 .928 r
.60304 .6453 m .59403 .64796 L .59173 .6455 L p F P
0 g
s
.651 .759 .928 r
.8905 .64486 m .88102 .64754 L .87916 .64509 L p F P
0 g
s
.651 .759 .928 r
.88102 .64754 m .8905 .64486 L .89235 .64731 L p F P
0 g
s
.651 .758 .928 r
.74318 .64772 m .75244 .64504 L .7545 .6475 L p F P
0 g
s
.651 .758 .928 r
.75244 .64504 m .74318 .64772 L .74111 .64526 L p F P
0 g
s
.65 .757 .928 r
.33548 .64259 m .32691 .64526 L .32962 .64773 L p F P
0 g
s
.65 .757 .928 r
.32962 .64773 m .33819 .64506 L .33548 .64259 L p F P
0 g
s
.651 .758 .928 r
.60533 .64776 m .61436 .64509 L .61663 .64755 L p F P
0 g
s
.651 .758 .928 r
.61436 .64509 m .60533 .64776 L .60304 .6453 L p F P
0 g
s
.65 .757 .928 r
.46747 .64776 m .47627 .64509 L .47875 .64755 L p F P
0 g
s
.65 .757 .928 r
.47627 .64509 m .46747 .64776 L .46497 .6453 L p F P
0 g
s
.651 .759 .928 r
.89235 .64731 m .90186 .64462 L .90368 .64708 L p F P
0 g
s
.651 .759 .928 r
.90186 .64462 m .89235 .64731 L .8905 .64486 L p F P
0 g
s
.65 .757 .928 r
.20848 .64228 m .20011 .64494 L .20302 .6474 L p F P
0 g
s
.65 .757 .928 r
.20302 .6474 m .21138 .64475 L .20848 .64228 L p F P
0 g
s
.651 .758 .928 r
.7545 .6475 m .76378 .64483 L .76582 .64729 L p F P
0 g
s
.651 .758 .928 r
.76378 .64483 m .7545 .6475 L .75244 .64504 L p F P
0 g
s
.65 .757 .928 r
.34678 .64239 m .33819 .64506 L .34088 .64753 L p F P
0 g
s
.65 .757 .928 r
.34088 .64753 m .34947 .64486 L .34678 .64239 L p F P
0 g
s
.651 .758 .928 r
.61663 .64755 m .62568 .64488 L .62793 .64734 L p F P
0 g
s
.651 .758 .928 r
.62568 .64488 m .61663 .64755 L .61436 .64509 L p F P
0 g
s
.65 .757 .928 r
.47875 .64755 m .48757 .64489 L .49004 .64735 L p F P
0 g
s
.65 .757 .928 r
.48757 .64489 m .47875 .64755 L .47627 .64509 L p F P
0 g
s
.651 .759 .928 r
.91321 .64438 m .90368 .64708 L .90186 .64462 L p F P
0 g
s
.651 .759 .928 r
.90368 .64708 m .91321 .64438 L .91502 .64684 L p F P
0 g
s
.65 .757 .928 r
.21976 .64209 m .21138 .64475 L .21427 .64722 L p F P
0 g
s
.65 .757 .928 r
.21427 .64722 m .22265 .64456 L .21976 .64209 L p F P
0 g
s
.651 .758 .928 r
.76582 .64729 m .77512 .64462 L .77714 .64708 L p F P
0 g
s
.651 .758 .928 r
.77512 .64462 m .76582 .64729 L .76378 .64483 L p F P
0 g
s
.65 .757 .928 r
.35809 .64219 m .34947 .64486 L .35215 .64733 L p F P
0 g
s
.65 .757 .928 r
.35215 .64733 m .36076 .64466 L .35809 .64219 L p F P
0 g
s
.651 .758 .928 r
.637 .64467 m .62793 .64734 L .62568 .64488 L p F P
0 g
s
.651 .758 .928 r
.62793 .64734 m .637 .64467 L .63923 .64714 L p F P
0 g
s
.65 .757 .928 r
.49004 .64735 m .49888 .64468 L .50133 .64715 L p F P
0 g
s
.65 .757 .928 r
.49888 .64468 m .49004 .64735 L .48757 .64489 L p F P
0 g
s
.652 .759 .928 r
.91502 .64684 m .92456 .64414 L .92635 .64659 L p F P
0 g
s
.652 .759 .928 r
.92456 .64414 m .91502 .64684 L .91321 .64438 L p F P
0 g
s
.65 .757 .928 r
.23105 .6419 m .22265 .64456 L .22552 .64703 L p F P
0 g
s
.65 .757 .928 r
.22552 .64703 m .23392 .64437 L .23105 .6419 L p F P
0 g
s
.651 .758 .928 r
.77714 .64708 m .78646 .6444 L .78846 .64686 L p F P
0 g
s
.651 .758 .928 r
.78646 .6444 m .77714 .64708 L .77512 .64462 L p F P
0 g
s
.65 .757 .928 r
.36939 .64199 m .36076 .64466 L .36342 .64712 L p F P
0 g
s
.65 .757 .928 r
.36342 .64712 m .37205 .64446 L .36939 .64199 L p F P
0 g
s
.651 .758 .928 r
.63923 .64714 m .64832 .64447 L .65054 .64693 L p F P
0 g
s
.651 .758 .928 r
.64832 .64447 m .63923 .64714 L .637 .64467 L p F P
0 g
s
.65 .758 .928 r
.50133 .64715 m .51019 .64448 L .51262 .64694 L p F P
0 g
s
.65 .758 .928 r
.51019 .64448 m .50133 .64715 L .49888 .64468 L p F P
0 g
s
.652 .759 .928 r
.92635 .64659 m .93592 .64389 L .93769 .64635 L p F P
0 g
s
.652 .759 .928 r
.93592 .64389 m .92635 .64659 L .92456 .64414 L p F P
0 g
s
.65 .757 .928 r
.24234 .6417 m .23392 .64437 L .23677 .64684 L p F P
0 g
s
.65 .757 .928 r
.23677 .64684 m .24519 .64418 L .24234 .6417 L p F P
0 g
s
.651 .758 .928 r
.78846 .64686 m .7978 .64419 L .79979 .64665 L p F P
0 g
s
.651 .758 .928 r
.7978 .64419 m .78846 .64686 L .78646 .6444 L p F P
0 g
s
.65 .757 .928 r
.37469 .64692 m .38334 .64426 L .38597 .64672 L p F P
0 g
s
.65 .757 .928 r
.3807 .64178 m .37205 .64446 L .37469 .64692 L p F P
0 g
s
.65 .757 .928 r
.37469 .64692 m .38334 .64426 L .3807 .64178 L p F P
0 g
s
.651 .758 .928 r
.65054 .64693 m .65965 .64426 L .66185 .64672 L p F P
0 g
s
.651 .758 .928 r
.65965 .64426 m .65054 .64693 L .64832 .64447 L p F P
0 g
s
.65 .758 .928 r
.51262 .64694 m .5215 .64427 L .52391 .64674 L p F P
0 g
s
.65 .758 .928 r
.5215 .64427 m .51262 .64694 L .51019 .64448 L p F P
0 g
s
.65 .757 .928 r
.25363 .64151 m .24519 .64418 L .24803 .64664 L p F P
0 g
s
.65 .757 .928 r
.24803 .64664 m .25646 .64398 L .25363 .64151 L p F P
0 g
s
.651 .758 .928 r
.79979 .64665 m .80915 .64397 L .81112 .64643 L p F P
0 g
s
.651 .758 .928 r
.80915 .64397 m .79979 .64665 L .7978 .64419 L p F P
0 g
s
.65 .757 .928 r
.38597 .64672 m .39463 .64405 L .39724 .64652 L p F P
0 g
s
.65 .757 .928 r
.39463 .64405 m .38597 .64672 L .38334 .64426 L p F P
0 g
s
.651 .758 .928 r
.66185 .64672 m .67098 .64405 L .67317 .64651 L p F P
0 g
s
.651 .758 .928 r
.67098 .64405 m .66185 .64672 L .65965 .64426 L p F P
0 g
s
0 0 .348 r
.52578 .51295 m .52577 .51296 L .52577 .50892 L p F P
0 g
s
0 0 .348 r
.52577 .50892 m .52578 .5089 L .52578 .51295 L p F P
0 g
s
.761 .5 .538 r
.52574 .51296 m .52577 .51296 L .52577 .50892 L p F P
0 g
s
.761 .5 .538 r
.52577 .50892 m .52574 .50892 L .52574 .51296 L p F P
0 g
s
.65 .758 .928 r
.52391 .64674 m .53281 .64407 L .53521 .64653 L p F P
0 g
s
.65 .758 .928 r
.53281 .64407 m .52391 .64674 L .5215 .64427 L p F P
0 g
s
0 0 .349 r
.52575 .5089 m .52574 .50892 L .52574 .51296 L p F P
0 g
s
.761 .5 .539 r
.52575 .5089 m .52578 .5089 L .52578 .51295 L p F P
0 g
s
.761 .5 .539 r
.52578 .51295 m .52575 .51294 L .52575 .5089 L p F P
0 g
s
0 0 .349 r
.52574 .51296 m .52575 .51294 L .52575 .5089 L p F P
0 g
s
.651 .758 .928 r
.81112 .64643 m .8205 .64375 L .82245 .64621 L p F P
0 g
s
.651 .758 .928 r
.8205 .64375 m .81112 .64643 L .80915 .64397 L p F P
0 g
s
.65 .757 .928 r
.26493 .64131 m .25646 .64398 L .25929 .64645 L p F P
0 g
s
.65 .757 .928 r
.25929 .64645 m .26774 .64379 L .26493 .64131 L p F P
0 g
s
.651 .758 .928 r
.67317 .64651 m .68232 .64384 L .68448 .64631 L p F P
0 g
s
.651 .758 .928 r
.68232 .64384 m .67317 .64651 L .67098 .64405 L p F P
0 g
s
.65 .757 .928 r
.39724 .64652 m .40593 .64385 L .40852 .64632 L p F P
0 g
s
.65 .757 .928 r
.40593 .64385 m .39724 .64652 L .39463 .64405 L p F P
0 g
s
.65 .758 .928 r
.53521 .64653 m .54412 .64386 L .5465 .64633 L p F P
0 g
s
.65 .758 .928 r
.54412 .64386 m .53521 .64653 L .53281 .64407 L p F P
0 g
s
.651 .758 .928 r
.82245 .64621 m .83185 .64353 L .83379 .64599 L p F P
0 g
s
.651 .758 .928 r
.83185 .64353 m .82245 .64621 L .8205 .64375 L p F P
0 g
s
.65 .757 .928 r
.27623 .64111 m .26774 .64379 L .27055 .64625 L p F P
0 g
s
.65 .757 .928 r
.27055 .64625 m .27903 .64359 L .27623 .64111 L p F P
0 g
s
.651 .758 .928 r
.68448 .64631 m .69365 .64363 L .6958 .6461 L p F P
0 g
s
.651 .758 .928 r
.69365 .64363 m .68448 .64631 L .68232 .64384 L p F P
0 g
s
.65 .757 .928 r
.40852 .64632 m .41723 .64365 L .41981 .64611 L p F P
0 g
s
.65 .757 .928 r
.41723 .64365 m .40852 .64632 L .40593 .64385 L p F P
0 g
s
.65 .758 .928 r
.5465 .64633 m .55544 .64365 L .55781 .64612 L p F P
0 g
s
.65 .758 .928 r
.55544 .64365 m .5465 .64633 L .54412 .64386 L p F P
0 g
s
.651 .758 .928 r
.83379 .64599 m .84321 .64331 L .84513 .64577 L p F P
0 g
s
.651 .758 .928 r
.84321 .64331 m .83379 .64599 L .83185 .64353 L p F P
0 g
s
.65 .757 .928 r
.28753 .64092 m .27903 .64359 L .28182 .64606 L p F P
0 g
s
.65 .757 .928 r
.28182 .64606 m .29031 .64339 L .28753 .64092 L p F P
0 g
s
.651 .758 .928 r
.6958 .6461 m .70499 .64342 L .70712 .64589 L p F P
0 g
s
.651 .758 .928 r
.70499 .64342 m .6958 .6461 L .69365 .64363 L p F P
0 g
s
.65 .757 .928 r
.41981 .64611 m .42854 .64344 L .4311 .64591 L p F P
0 g
s
.65 .757 .928 r
.42854 .64344 m .41981 .64611 L .41723 .64365 L p F P
0 g
s
.65 .758 .928 r
.55781 .64612 m .56677 .64345 L .56911 .64591 L p F P
0 g
s
.65 .758 .928 r
.56677 .64345 m .55781 .64612 L .55544 .64365 L p F P
0 g
s
.651 .758 .928 r
.84513 .64577 m .85457 .64308 L .85647 .64555 L p F P
0 g
s
.651 .758 .928 r
.85457 .64308 m .84513 .64577 L .84321 .64331 L p F P
0 g
s
.65 .757 .928 r
.29884 .64072 m .29031 .64339 L .29308 .64586 L p F P
0 g
s
.65 .757 .928 r
.29308 .64586 m .3016 .64319 L .29884 .64072 L p F P
0 g
s
.651 .758 .928 r
.70712 .64589 m .71634 .64321 L .71845 .64568 L p F P
0 g
s
.651 .758 .928 r
.71634 .64321 m .70712 .64589 L .70499 .64342 L p F P
0 g
s
.65 .757 .928 r
.4311 .64591 m .43984 .64324 L .44239 .64571 L p F P
0 g
s
.65 .757 .928 r
.43984 .64324 m .4311 .64591 L .42854 .64344 L p F P
0 g
s
.65 .758 .928 r
.56911 .64591 m .57809 .64324 L .58042 .64571 L p F P
0 g
s
.65 .758 .928 r
.57809 .64324 m .56911 .64591 L .56677 .64345 L p F P
0 g
s
.651 .758 .928 r
.85647 .64555 m .86593 .64286 L .86781 .64532 L p F P
0 g
s
.651 .758 .928 r
.86593 .64286 m .85647 .64555 L .85457 .64308 L p F P
0 g
s
.65 .757 .928 r
.31015 .64052 m .3016 .64319 L .30436 .64566 L p F P
0 g
s
.65 .757 .928 r
.30436 .64566 m .31289 .64299 L .31015 .64052 L p F P
0 g
s
.651 .758 .928 r
.71845 .64568 m .72768 .643 L .72978 .64547 L p F P
0 g
s
.651 .758 .928 r
.72768 .643 m .71845 .64568 L .71634 .64321 L p F P
0 g
s
.65 .757 .928 r
.44239 .64571 m .45115 .64303 L .45368 .6455 L p F P
0 g
s
.65 .757 .928 r
.45115 .64303 m .44239 .64571 L .43984 .64324 L p F P
0 g
s
.651 .758 .928 r
.58042 .64571 m .58942 .64303 L .59173 .6455 L p F P
0 g
s
.651 .758 .928 r
.58942 .64303 m .58042 .64571 L .57809 .64324 L p F P
0 g
s
.651 .758 .928 r
.86781 .64532 m .87729 .64263 L .87916 .64509 L p F P
0 g
s
.651 .758 .928 r
.87729 .64263 m .86781 .64532 L .86593 .64286 L p F P
0 g
s
.65 .757 .928 r
.32146 .64032 m .31289 .64299 L .31563 .64546 L p F P
0 g
s
.65 .757 .928 r
.31563 .64546 m .32419 .64279 L .32146 .64032 L p F P
0 g
s
.651 .758 .928 r
.72978 .64547 m .73903 .64279 L .74111 .64526 L p F P
0 g
s
.651 .758 .928 r
.73903 .64279 m .72978 .64547 L .72768 .643 L p F P
0 g
s
.65 .757 .928 r
.45368 .6455 m .46247 .64283 L .46497 .6453 L p F P
0 g
s
.65 .757 .928 r
.46247 .64283 m .45368 .6455 L .45115 .64303 L p F P
0 g
s
.651 .758 .928 r
.59173 .6455 m .60075 .64283 L .60304 .6453 L p F P
0 g
s
.651 .758 .928 r
.60075 .64283 m .59173 .6455 L .58942 .64303 L p F P
0 g
s
.651 .759 .928 r
.87916 .64509 m .88866 .6424 L .8905 .64486 L p F P
0 g
s
.651 .758 .928 r
.88866 .6424 m .87916 .64509 L .87729 .64263 L p F P
0 g
s
.651 .758 .928 r
.74111 .64526 m .75038 .64258 L .75244 .64504 L p F P
0 g
s
.651 .758 .928 r
.75038 .64258 m .74111 .64526 L .73903 .64279 L p F P
0 g
s
.65 .757 .928 r
.33277 .64011 m .32419 .64279 L .32691 .64526 L p F P
0 g
s
.65 .757 .928 r
.32691 .64526 m .33548 .64259 L .33277 .64011 L p F P
0 g
s
.651 .758 .928 r
.60304 .6453 m .61208 .64262 L .61436 .64509 L p F P
0 g
s
.651 .758 .928 r
.61208 .64262 m .60304 .6453 L .60075 .64283 L p F P
0 g
s
.65 .757 .928 r
.46497 .6453 m .47378 .64262 L .47627 .64509 L p F P
0 g
s
.65 .757 .928 r
.47378 .64262 m .46497 .6453 L .46247 .64283 L p F P
0 g
s
.651 .759 .928 r
.90003 .64216 m .8905 .64486 L .88866 .6424 L p F P
0 g
s
.651 .759 .928 r
.8905 .64486 m .90003 .64216 L .90186 .64462 L p F P
0 g
s
.65 .757 .928 r
.20557 .6398 m .1972 .64247 L .20011 .64494 L p F P
0 g
s
.65 .757 .928 r
.20011 .64494 m .20848 .64228 L .20557 .6398 L p F P
0 g
s
.651 .758 .928 r
.75244 .64504 m .76173 .64236 L .76378 .64483 L p F P
0 g
s
.651 .758 .928 r
.76173 .64236 m .75244 .64504 L .75038 .64258 L p F P
0 g
s
.65 .757 .928 r
.34409 .63991 m .33548 .64259 L .33819 .64506 L p F P
0 g
s
.65 .757 .928 r
.33819 .64506 m .34678 .64239 L .34409 .63991 L p F P
0 g
s
.651 .758 .928 r
.61436 .64509 m .62342 .64241 L .62568 .64488 L p F P
0 g
s
.651 .758 .928 r
.62342 .64241 m .61436 .64509 L .61208 .64262 L p F P
0 g
s
.65 .757 .928 r
.47627 .64509 m .4851 .64242 L .48757 .64489 L p F P
0 g
s
.65 .757 .928 r
.4851 .64242 m .47627 .64509 L .47378 .64262 L p F P
0 g
s
.651 .759 .928 r
.90186 .64462 m .9114 .64192 L .91321 .64438 L p F P
0 g
s
.651 .759 .928 r
.9114 .64192 m .90186 .64462 L .90003 .64216 L p F P
0 g
s
.65 .757 .928 r
.21687 .63961 m .20848 .64228 L .21138 .64475 L p F P
0 g
s
.65 .757 .928 r
.21138 .64475 m .21976 .64209 L .21687 .63961 L p F P
0 g
s
.651 .758 .928 r
.76378 .64483 m .77309 .64215 L .77512 .64462 L p F P
0 g
s
.651 .758 .928 r
.77309 .64215 m .76378 .64483 L .76173 .64236 L p F P
0 g
s
.65 .757 .928 r
.35541 .63971 m .34678 .64239 L .34947 .64486 L p F P
0 g
s
.65 .757 .928 r
.34947 .64486 m .35809 .64219 L .35541 .63971 L p F P
0 g
s
.651 .758 .928 r
.62568 .64488 m .63476 .6422 L .637 .64467 L p F P
0 g
s
.651 .758 .928 r
.63476 .6422 m .62568 .64488 L .62342 .64241 L p F P
0 g
s
.65 .757 .928 r
.48757 .64489 m .49642 .64221 L .49888 .64468 L p F P
0 g
s
.65 .757 .928 r
.49642 .64221 m .48757 .64489 L .4851 .64242 L p F P
0 g
s
.652 .759 .928 r
.92277 .64168 m .91321 .64438 L .9114 .64192 L p F P
0 g
s
.652 .759 .928 r
.91321 .64438 m .92277 .64168 L .92456 .64414 L p F P
0 g
s
.65 .757 .928 r
.22817 .63941 m .21976 .64209 L .22265 .64456 L p F P
0 g
s
.65 .757 .928 r
.22265 .64456 m .23105 .6419 L .22817 .63941 L p F P
0 g
s
.651 .758 .928 r
.77512 .64462 m .78445 .64193 L .78646 .6444 L p F P
0 g
s
.651 .758 .928 r
.78445 .64193 m .77512 .64462 L .77309 .64215 L p F P
0 g
s
.65 .757 .928 r
.36673 .63951 m .35809 .64219 L .36076 .64466 L p F P
0 g
s
.65 .757 .928 r
.36076 .64466 m .36939 .64199 L .36673 .63951 L p F P
0 g
s
.651 .758 .928 r
.6461 .64199 m .637 .64467 L .63476 .6422 L p F P
0 g
s
.651 .758 .928 r
.637 .64467 m .6461 .64199 L .64832 .64447 L p F P
0 g
s
0 0 .348 r
.52578 .517 m .52577 .51701 L .52577 .51296 L p F P
0 g
s
0 0 .348 r
.52577 .51296 m .52578 .51295 L .52578 .517 L p F P
0 g
s
.761 .5 .538 r
.52574 .51701 m .52577 .51701 L .52577 .51296 L p F P
0 g
s
.761 .5 .538 r
.52577 .51296 m .52574 .51296 L .52574 .51701 L p F P
0 g
s
.65 .758 .928 r
.49888 .64468 m .50775 .64201 L .51019 .64448 L p F P
0 g
s
.65 .757 .928 r
.50775 .64201 m .49888 .64468 L .49642 .64221 L p F P
0 g
s
0 0 .349 r
.52575 .51294 m .52574 .51296 L .52574 .51701 L p F P
0 g
s
.761 .5 .539 r
.52575 .51294 m .52578 .51295 L .52578 .517 L p F P
0 g
s
.761 .5 .539 r
.52578 .517 m .52575 .51699 L .52575 .51294 L p F P
0 g
s
0 0 .349 r
.52574 .51701 m .52575 .51699 L .52575 .51294 L p F P
0 g
s
.652 .759 .928 r
.92456 .64414 m .93414 .64143 L .93592 .64389 L p F P
0 g
s
.652 .759 .928 r
.93414 .64143 m .92456 .64414 L .92277 .64168 L p F P
0 g
s
.65 .757 .928 r
.23948 .63922 m .23105 .6419 L .23392 .64437 L p F P
0 g
s
.65 .757 .928 r
.23392 .64437 m .24234 .6417 L .23948 .63922 L p F P
0 g
s
.651 .758 .928 r
.78646 .6444 m .79581 .64172 L .7978 .64419 L p F P
0 g
s
.651 .758 .928 r
.79581 .64172 m .78646 .6444 L .78445 .64193 L p F P
0 g
s
.65 .757 .928 r
.37806 .6393 m .36939 .64199 L .37205 .64446 L p F P
0 g
s
.65 .757 .928 r
.37205 .64446 m .3807 .64178 L .37806 .6393 L p F P
0 g
s
.651 .758 .928 r
.64832 .64447 m .65745 .64179 L .65965 .64426 L p F P
0 g
s
.651 .758 .928 r
.65745 .64179 m .64832 .64447 L .6461 .64199 L p F P
0 g
s
.65 .758 .928 r
.51019 .64448 m .51907 .6418 L .5215 .64427 L p F P
0 g
s
.65 .758 .928 r
.51907 .6418 m .51019 .64448 L .50775 .64201 L p F P
0 g
s
.65 .757 .928 r
.25079 .63903 m .24234 .6417 L .24519 .64418 L p F P
0 g
s
.65 .757 .928 r
.24519 .64418 m .25363 .64151 L .25079 .63903 L p F P
0 g
s
.651 .758 .928 r
.7978 .64419 m .80718 .6415 L .80915 .64397 L p F P
0 g
s
.651 .758 .928 r
.80718 .6415 m .7978 .64419 L .79581 .64172 L p F P
0 g
s
.65 .757 .928 r
.38334 .64426 m .39202 .64158 L .39463 .64405 L p F P
0 g
s
.65 .757 .928 r
.38939 .6391 m .3807 .64178 L .38334 .64426 L p F P
0 g
s
.65 .757 .928 r
.38334 .64426 m .39202 .64158 L .38939 .6391 L p F P
0 g
s
.651 .758 .928 r
.65965 .64426 m .66879 .64158 L .67098 .64405 L p F P
0 g
s
.651 .758 .928 r
.66879 .64158 m .65965 .64426 L .65745 .64179 L p F P
0 g
s
.65 .758 .928 r
.5215 .64427 m .5304 .64159 L .53281 .64407 L p F P
0 g
s
.65 .758 .928 r
.5304 .64159 m .5215 .64427 L .51907 .6418 L p F P
0 g
s
.651 .758 .928 r
.80915 .64397 m .81854 .64128 L .8205 .64375 L p F P
0 g
s
.651 .758 .928 r
.81854 .64128 m .80915 .64397 L .80718 .6415 L p F P
0 g
s
.65 .757 .928 r
.26211 .63883 m .25363 .64151 L .25646 .64398 L p F P
0 g
s
.65 .757 .928 r
.25646 .64398 m .26493 .64131 L .26211 .63883 L p F P
0 g
s
.651 .758 .928 r
.67098 .64405 m .68014 .64137 L .68232 .64384 L p F P
0 g
s
.651 .758 .928 r
.68014 .64137 m .67098 .64405 L .66879 .64158 L p F P
0 g
s
.65 .757 .928 r
.39463 .64405 m .40333 .64137 L .40593 .64385 L p F P
0 g
s
.65 .757 .928 r
.40333 .64137 m .39463 .64405 L .39202 .64158 L p F P
0 g
s
.65 .758 .928 r
.53281 .64407 m .54174 .64139 L .54412 .64386 L p F P
0 g
s
.65 .758 .928 r
.54174 .64139 m .53281 .64407 L .5304 .64159 L p F P
0 g
s
.651 .758 .928 r
.8205 .64375 m .82991 .64106 L .83185 .64353 L p F P
0 g
s
.651 .758 .928 r
.82991 .64106 m .8205 .64375 L .81854 .64128 L p F P
0 g
s
.65 .757 .928 r
.27342 .63863 m .26493 .64131 L .26774 .64379 L p F P
0 g
s
.65 .757 .928 r
.26774 .64379 m .27623 .64111 L .27342 .63863 L p F P
0 g
s
.651 .758 .928 r
.68232 .64384 m .6915 .64116 L .69365 .64363 L p F P
0 g
s
.651 .758 .928 r
.6915 .64116 m .68232 .64384 L .68014 .64137 L p F P
0 g
s
.65 .757 .928 r
.40593 .64385 m .41465 .64117 L .41723 .64365 L p F P
0 g
s
.65 .757 .928 r
.41465 .64117 m .40593 .64385 L .40333 .64137 L p F P
0 g
s
.65 .758 .928 r
.54412 .64386 m .55307 .64118 L .55544 .64365 L p F P
0 g
s
.65 .758 .928 r
.55307 .64118 m .54412 .64386 L .54174 .64139 L p F P
0 g
s
.651 .758 .928 r
.83185 .64353 m .84129 .64084 L .84321 .64331 L p F P
0 g
s
.651 .758 .928 r
.84129 .64084 m .83185 .64353 L .82991 .64106 L p F P
0 g
s
.65 .757 .928 r
.28474 .63843 m .27623 .64111 L .27903 .64359 L p F P
0 g
s
.65 .757 .928 r
.27903 .64359 m .28753 .64092 L .28474 .63843 L p F P
0 g
s
.651 .758 .928 r
.69365 .64363 m .70286 .64095 L .70499 .64342 L p F P
0 g
s
.651 .758 .928 r
.70286 .64095 m .69365 .64363 L .6915 .64116 L p F P
0 g
s
.65 .757 .928 r
.41723 .64365 m .42597 .64097 L .42854 .64344 L p F P
0 g
s
.65 .757 .928 r
.42597 .64097 m .41723 .64365 L .41465 .64117 L p F P
0 g
s
.65 .758 .928 r
.55544 .64365 m .56441 .64097 L .56677 .64345 L p F P
0 g
s
.65 .758 .928 r
.56441 .64097 m .55544 .64365 L .55307 .64118 L p F P
0 g
s
.651 .758 .928 r
.84321 .64331 m .85266 .64061 L .85457 .64308 L p F P
0 g
s
.651 .758 .928 r
.85266 .64061 m .84321 .64331 L .84129 .64084 L p F P
0 g
s
.65 .757 .928 r
.29606 .63823 m .28753 .64092 L .29031 .64339 L p F P
0 g
s
.65 .757 .928 r
.29031 .64339 m .29884 .64072 L .29606 .63823 L p F P
0 g
s
.651 .758 .928 r
.70499 .64342 m .71421 .64074 L .71634 .64321 L p F P
0 g
s
.651 .758 .928 r
.71421 .64074 m .70499 .64342 L .70286 .64095 L p F P
0 g
s
.65 .757 .928 r
.42854 .64344 m .43729 .64076 L .43984 .64324 L p F P
0 g
s
.65 .757 .928 r
.43729 .64076 m .42854 .64344 L .42597 .64097 L p F P
0 g
s
.65 .758 .928 r
.56677 .64345 m .57576 .64077 L .57809 .64324 L p F P
0 g
s
.651 .758 .928 r
.57576 .64077 m .56677 .64345 L .56441 .64097 L p F P
0 g
s
.651 .758 .928 r
.85457 .64308 m .86404 .64039 L .86593 .64286 L p F P
0 g
s
.651 .758 .928 r
.86404 .64039 m .85457 .64308 L .85266 .64061 L p F P
0 g
s
.65 .757 .928 r
.30739 .63803 m .29884 .64072 L .3016 .64319 L p F P
0 g
s
.65 .757 .928 r
.3016 .64319 m .31015 .64052 L .30739 .63803 L p F P
0 g
s
.651 .758 .928 r
.71634 .64321 m .72558 .64052 L .72768 .643 L p F P
0 g
s
.651 .758 .928 r
.72558 .64052 m .71634 .64321 L .71421 .64074 L p F P
0 g
s
.65 .757 .928 r
.43984 .64324 m .44862 .64056 L .45115 .64303 L p F P
0 g
s
.65 .757 .928 r
.44862 .64056 m .43984 .64324 L .43729 .64076 L p F P
0 g
s
.651 .758 .928 r
.57809 .64324 m .5871 .64056 L .58942 .64303 L p F P
0 g
s
.651 .758 .928 r
.5871 .64056 m .57809 .64324 L .57576 .64077 L p F P
0 g
s
.651 .758 .928 r
.86593 .64286 m .87542 .64016 L .87729 .64263 L p F P
0 g
s
.651 .758 .928 r
.87542 .64016 m .86593 .64286 L .86404 .64039 L p F P
0 g
s
.65 .757 .928 r
.31872 .63783 m .31015 .64052 L .31289 .64299 L p F P
0 g
s
.65 .757 .928 r
.31289 .64299 m .32146 .64032 L .31872 .63783 L p F P
0 g
s
.651 .758 .928 r
.72768 .643 m .73694 .64031 L .73903 .64279 L p F P
0 g
s
.651 .758 .928 r
.73694 .64031 m .72768 .643 L .72558 .64052 L p F P
0 g
s
.65 .757 .928 r
.45115 .64303 m .45995 .64035 L .46247 .64283 L p F P
0 g
s
.65 .757 .928 r
.45995 .64035 m .45115 .64303 L .44862 .64056 L p F P
0 g
s
.651 .758 .928 r
.58942 .64303 m .59845 .64035 L .60075 .64283 L p F P
0 g
s
.651 .758 .928 r
.59845 .64035 m .58942 .64303 L .5871 .64056 L p F P
0 g
s
.651 .758 .928 r
.87729 .64263 m .8868 .63993 L .88866 .6424 L p F P
0 g
s
.651 .758 .928 r
.8868 .63993 m .87729 .64263 L .87542 .64016 L p F P
0 g
s
.651 .758 .928 r
.73903 .64279 m .74831 .6401 L .75038 .64258 L p F P
0 g
s
.651 .758 .928 r
.74831 .6401 m .73903 .64279 L .73694 .64031 L p F P
0 g
s
.65 .757 .928 r
.33005 .63763 m .32146 .64032 L .32419 .64279 L p F P
0 g
s
.65 .757 .928 r
.32419 .64279 m .33277 .64011 L .33005 .63763 L p F P
0 g
s
.651 .758 .928 r
.60075 .64283 m .6098 .64014 L .61208 .64262 L p F P
0 g
s
.651 .758 .928 r
.6098 .64014 m .60075 .64283 L .59845 .64035 L p F P
0 g
s
.65 .757 .928 r
.46247 .64283 m .47128 .64014 L .47378 .64262 L p F P
0 g
s
.65 .757 .928 r
.47128 .64014 m .46247 .64283 L .45995 .64035 L p F P
0 g
s
.651 .759 .928 r
.88866 .6424 m .89819 .63969 L .90003 .64216 L p F P
0 g
s
.651 .759 .928 r
.89819 .63969 m .88866 .6424 L .8868 .63993 L p F P
0 g
s
.65 .757 .928 r
.20265 .63731 m .19427 .63999 L .1972 .64247 L p F P
0 g
s
.65 .757 .928 r
.1972 .64247 m .20557 .6398 L .20265 .63731 L p F P
0 g
s
.651 .758 .928 r
.75038 .64258 m .75968 .63989 L .76173 .64236 L p F P
0 g
s
.651 .758 .928 r
.75968 .63989 m .75038 .64258 L .74831 .6401 L p F P
0 g
s
.65 .757 .928 r
.34139 .63743 m .33277 .64011 L .33548 .64259 L p F P
0 g
s
.65 .757 .928 r
.33548 .64259 m .34409 .63991 L .34139 .63743 L p F P
0 g
s
0 0 .349 r
.52578 .52106 m .52577 .52108 L .52577 .51701 L p F P
0 g
s
0 0 .349 r
.52577 .51701 m .52578 .517 L .52578 .52106 L p F P
0 g
s
.761 .5 .538 r
.52575 .52107 m .52577 .52108 L .52577 .51701 L p F P
0 g
s
.761 .5 .538 r
.52577 .51701 m .52574 .51701 L .52575 .52107 L p F P
0 g
s
.651 .758 .928 r
.61208 .64262 m .62115 .63993 L .62342 .64241 L p F P
0 g
s
.651 .758 .928 r
.62115 .63993 m .61208 .64262 L .6098 .64014 L p F P
0 g
s
.65 .757 .928 r
.47378 .64262 m .48262 .63994 L .4851 .64242 L p F P
0 g
s
.65 .757 .928 r
.48262 .63994 m .47378 .64262 L .47128 .64014 L p F P
0 g
s
0 0 .349 r
.52575 .51699 m .52574 .51701 L .52575 .52107 L p F P
0 g
s
.761 .5 .539 r
.52575 .51699 m .52578 .517 L .52578 .52106 L p F P
0 g
s
.761 .5 .539 r
.52578 .52106 m .52575 .52106 L .52575 .51699 L p F P
0 g
s
0 0 .349 r
.52575 .52107 m .52575 .52106 L .52575 .51699 L p F P
0 g
s
.651 .759 .928 r
.90958 .63945 m .90003 .64216 L .89819 .63969 L p F P
0 g
s
.651 .759 .928 r
.90003 .64216 m .90958 .63945 L .9114 .64192 L p F P
0 g
s
.65 .757 .928 r
.21397 .63712 m .20557 .6398 L .20848 .64228 L p F P
0 g
s
.65 .757 .928 r
.20848 .64228 m .21687 .63961 L .21397 .63712 L p F P
0 g
s
.651 .758 .928 r
.76173 .64236 m .77106 .63967 L .77309 .64215 L p F P
0 g
s
.651 .758 .928 r
.77106 .63967 m .76173 .64236 L .75968 .63989 L p F P
0 g
s
.65 .757 .928 r
.35272 .63722 m .34409 .63991 L .34678 .64239 L p F P
0 g
s
.65 .757 .928 r
.34678 .64239 m .35541 .63971 L .35272 .63722 L p F P
0 g
s
.651 .758 .928 r
.62342 .64241 m .63251 .63972 L .63476 .6422 L p F P
0 g
s
.651 .758 .928 r
.63251 .63972 m .62342 .64241 L .62115 .63993 L p F P
0 g
s
.65 .757 .928 r
.4851 .64242 m .49396 .63973 L .49642 .64221 L p F P
0 g
s
.65 .757 .928 r
.49396 .63973 m .4851 .64242 L .48262 .63994 L p F P
0 g
s
.652 .759 .928 r
.9114 .64192 m .92097 .63921 L .92277 .64168 L p F P
0 g
s
.652 .759 .928 r
.92097 .63921 m .9114 .64192 L .90958 .63945 L p F P
0 g
s
.65 .757 .928 r
.22529 .63693 m .21687 .63961 L .21976 .64209 L p F P
0 g
s
.65 .757 .928 r
.21976 .64209 m .22817 .63941 L .22529 .63693 L p F P
0 g
s
.651 .758 .928 r
.77309 .64215 m .78243 .63946 L .78445 .64193 L p F P
0 g
s
.651 .758 .928 r
.78243 .63946 m .77309 .64215 L .77106 .63967 L p F P
0 g
s
.65 .757 .928 r
.36406 .63702 m .35541 .63971 L .35809 .64219 L p F P
0 g
s
.65 .757 .928 r
.35809 .64219 m .36673 .63951 L .36406 .63702 L p F P
0 g
s
.651 .758 .928 r
.63476 .6422 m .64387 .63952 L .6461 .64199 L p F P
0 g
s
.651 .758 .928 r
.64387 .63952 m .63476 .6422 L .63251 .63972 L p F P
0 g
s
.65 .757 .928 r
.49642 .64221 m .5053 .63953 L .50775 .64201 L p F P
0 g
s
.65 .757 .928 r
.5053 .63953 m .49642 .64221 L .49396 .63973 L p F P
0 g
s
.652 .759 .928 r
.93236 .63896 m .92277 .64168 L .92097 .63921 L p F P
0 g
s
.652 .759 .928 r
.92277 .64168 m .93236 .63896 L .93414 .64143 L p F P
0 g
s
.65 .757 .928 r
.23662 .63673 m .22817 .63941 L .23105 .6419 L p F P
0 g
s
.65 .757 .928 r
.23105 .6419 m .23948 .63922 L .23662 .63673 L p F P
0 g
s
.651 .758 .928 r
.78445 .64193 m .79381 .63924 L .79581 .64172 L p F P
0 g
s
.651 .758 .928 r
.79381 .63924 m .78445 .64193 L .78243 .63946 L p F P
0 g
s
.65 .757 .928 r
.37541 .63681 m .36673 .63951 L .36939 .64199 L p F P
0 g
s
.65 .757 .928 r
.36939 .64199 m .37806 .6393 L .37541 .63681 L p F P
0 g
s
.651 .758 .928 r
.65523 .63931 m .6461 .64199 L .64387 .63952 L p F P
0 g
s
.651 .758 .928 r
.6461 .64199 m .65523 .63931 L .65745 .64179 L p F P
0 g
s
.65 .758 .928 r
.50775 .64201 m .51665 .63932 L .51907 .6418 L p F P
0 g
s
.65 .758 .928 r
.51665 .63932 m .50775 .64201 L .5053 .63953 L p F P
0 g
s
.65 .757 .928 r
.24794 .63654 m .23948 .63922 L .24234 .6417 L p F P
0 g
s
.65 .757 .928 r
.24234 .6417 m .25079 .63903 L .24794 .63654 L p F P
0 g
s
.651 .758 .928 r
.79581 .64172 m .80519 .63902 L .80718 .6415 L p F P
0 g
s
.651 .758 .928 r
.80519 .63902 m .79581 .64172 L .79381 .63924 L p F P
0 g
s
.65 .757 .928 r
.38676 .63661 m .37806 .6393 L .3807 .64178 L p F P
0 g
s
.65 .757 .928 r
.3807 .64178 m .38939 .6391 L .38676 .63661 L p F P
0 g
s
.651 .758 .928 r
.65745 .64179 m .6666 .6391 L .66879 .64158 L p F P
0 g
s
.651 .758 .928 r
.6666 .6391 m .65745 .64179 L .65523 .63931 L p F P
0 g
s
.65 .758 .928 r
.51907 .6418 m .52799 .63911 L .5304 .64159 L p F P
0 g
s
.65 .758 .928 r
.52799 .63911 m .51907 .6418 L .51665 .63932 L p F P
0 g
s
.651 .758 .928 r
.80718 .6415 m .81658 .6388 L .81854 .64128 L p F P
0 g
s
.651 .758 .928 r
.81658 .6388 m .80718 .6415 L .80519 .63902 L p F P
0 g
s
.65 .757 .928 r
.25927 .63634 m .25079 .63903 L .25363 .64151 L p F P
0 g
s
.65 .757 .928 r
.25363 .64151 m .26211 .63883 L .25927 .63634 L p F P
0 g
s
.651 .758 .928 r
.66879 .64158 m .67797 .63889 L .68014 .64137 L p F P
0 g
s
.651 .758 .928 r
.67797 .63889 m .66879 .64158 L .6666 .6391 L p F P
0 g
s
.65 .757 .928 r
.39202 .64158 m .40072 .63889 L .40333 .64137 L p F P
0 g
s
.65 .757 .928 r
.39811 .6364 m .38939 .6391 L .39202 .64158 L p F P
0 g
s
.65 .757 .928 r
.39202 .64158 m .40072 .63889 L .39811 .6364 L p F P
0 g
s
.65 .758 .928 r
.5304 .64159 m .53934 .63891 L .54174 .64139 L p F P
0 g
s
.65 .758 .928 r
.53934 .63891 m .5304 .64159 L .52799 .63911 L p F P
0 g
s
.651 .758 .928 r
.81854 .64128 m .82797 .63858 L .82991 .64106 L p F P
0 g
s
.651 .758 .928 r
.82797 .63858 m .81854 .64128 L .81658 .6388 L p F P
0 g
s
.65 .757 .928 r
.27061 .63614 m .26211 .63883 L .26493 .64131 L p F P
0 g
s
.65 .757 .928 r
.26493 .64131 m .27342 .63863 L .27061 .63614 L p F P
0 g
s
.651 .758 .928 r
.68014 .64137 m .68934 .63868 L .6915 .64116 L p F P
0 g
s
.651 .758 .928 r
.68934 .63868 m .68014 .64137 L .67797 .63889 L p F P
0 g
s
.65 .757 .928 r
.40333 .64137 m .41206 .63869 L .41465 .64117 L p F P
0 g
s
.65 .757 .928 r
.41206 .63869 m .40333 .64137 L .40072 .63889 L p F P
0 g
s
.65 .758 .928 r
.54174 .64139 m .5507 .6387 L .55307 .64118 L p F P
0 g
s
.65 .758 .928 r
.5507 .6387 m .54174 .64139 L .53934 .63891 L p F P
0 g
s
.651 .758 .928 r
.82991 .64106 m .83936 .63836 L .84129 .64084 L p F P
0 g
s
.651 .758 .928 r
.83936 .63836 m .82991 .64106 L .82797 .63858 L p F P
0 g
s
.65 .757 .928 r
.28194 .63594 m .27342 .63863 L .27623 .64111 L p F P
0 g
s
.65 .757 .928 r
.27623 .64111 m .28474 .63843 L .28194 .63594 L p F P
0 g
s
.651 .758 .928 r
.6915 .64116 m .70071 .63847 L .70286 .64095 L p F P
0 g
s
.651 .758 .928 r
.70071 .63847 m .6915 .64116 L .68934 .63868 L p F P
0 g
s
.65 .757 .928 r
.41465 .64117 m .4234 .63848 L .42597 .64097 L p F P
0 g
s
.65 .757 .928 r
.4234 .63848 m .41465 .64117 L .41206 .63869 L p F P
0 g
s
.65 .758 .928 r
.55307 .64118 m .56205 .63849 L .56441 .64097 L p F P
0 g
s
.65 .758 .928 r
.56205 .63849 m .55307 .64118 L .5507 .6387 L p F P
0 g
s
.651 .758 .928 r
.84129 .64084 m .85075 .63813 L .85266 .64061 L p F P
0 g
s
.651 .758 .928 r
.85075 .63813 m .84129 .64084 L .83936 .63836 L p F P
0 g
s
.65 .757 .928 r
.29328 .63574 m .28474 .63843 L .28753 .64092 L p F P
0 g
s
.65 .757 .928 r
.28753 .64092 m .29606 .63823 L .29328 .63574 L p F P
0 g
s
.651 .758 .928 r
.70286 .64095 m .71209 .63825 L .71421 .64074 L p F P
0 g
s
.651 .758 .928 r
.71209 .63825 m .70286 .64095 L .70071 .63847 L p F P
0 g
s
.65 .757 .928 r
.42597 .64097 m .43474 .63828 L .43729 .64076 L p F P
0 g
s
.65 .757 .928 r
.43474 .63828 m .42597 .64097 L .4234 .63848 L p F P
0 g
s
.651 .758 .928 r
.56441 .64097 m .57341 .63828 L .57576 .64077 L p F P
0 g
s
.651 .758 .928 r
.57341 .63828 m .56441 .64097 L .56205 .63849 L p F P
0 g
s
.651 .758 .928 r
.85266 .64061 m .86215 .63791 L .86404 .64039 L p F P
0 g
s
.651 .758 .928 r
.86215 .63791 m .85266 .64061 L .85075 .63813 L p F P
0 g
s
.65 .757 .928 r
.30463 .63554 m .29606 .63823 L .29884 .64072 L p F P
0 g
s
.65 .757 .928 r
.29884 .64072 m .30739 .63803 L .30463 .63554 L p F P
0 g
s
.651 .758 .928 r
.71421 .64074 m .72347 .63804 L .72558 .64052 L p F P
0 g
s
.651 .758 .928 r
.72347 .63804 m .71421 .64074 L .71209 .63825 L p F P
0 g
s
.65 .757 .928 r
.43729 .64076 m .44608 .63807 L .44862 .64056 L p F P
0 g
s
.65 .757 .928 r
.44608 .63807 m .43729 .64076 L .43474 .63828 L p F P
0 g
s
.651 .758 .928 r
.57576 .64077 m .58478 .63807 L .5871 .64056 L p F P
0 g
s
.651 .758 .928 r
.58478 .63807 m .57576 .64077 L .57341 .63828 L p F P
0 g
s
.651 .758 .928 r
.86404 .64039 m .87354 .63768 L .87542 .64016 L p F P
0 g
s
.651 .758 .928 r
.87354 .63768 m .86404 .64039 L .86215 .63791 L p F P
0 g
s
.65 .757 .928 r
.31597 .63534 m .30739 .63803 L .31015 .64052 L p F P
0 g
s
.65 .757 .928 r
.31015 .64052 m .31872 .63783 L .31597 .63534 L p F P
0 g
s
.651 .758 .928 r
.72558 .64052 m .73485 .63783 L .73694 .64031 L p F P
0 g
s
.651 .758 .928 r
.73485 .63783 m .72558 .64052 L .72347 .63804 L p F P
0 g
s
0 0 .349 r
.52578 .52514 m .52577 .52515 L .52577 .52108 L p F P
0 g
s
0 0 .349 r
.52577 .52108 m .52578 .52106 L .52578 .52514 L p F P
0 g
s
.761 .5 .538 r
.52575 .52514 m .52577 .52515 L .52577 .52108 L p F P
0 g
s
.761 .5 .538 r
.52577 .52108 m .52575 .52107 L .52575 .52514 L p F P
0 g
s
.65 .757 .928 r
.44862 .64056 m .45743 .63787 L .45995 .64035 L p F P
0 g
s
.65 .757 .928 r
.45743 .63787 m .44862 .64056 L .44608 .63807 L p F P
0 g
s
.651 .758 .928 r
.5871 .64056 m .59614 .63787 L .59845 .64035 L p F P
0 g
s
.651 .758 .928 r
.59614 .63787 m .5871 .64056 L .58478 .63807 L p F P
0 g
s
0 0 .349 r
.52575 .52106 m .52575 .52107 L .52575 .52514 L p F P
0 g
s
.761 .5 .539 r
.52575 .52106 m .52578 .52106 L .52578 .52514 L p F P
0 g
s
.761 .5 .539 r
.52578 .52514 m .52575 .52513 L .52575 .52106 L p F P
0 g
s
0 0 .349 r
.52575 .52514 m .52575 .52513 L .52575 .52106 L p F P
0 g
s
.651 .758 .928 r
.87542 .64016 m .88495 .63745 L .8868 .63993 L p F P
0 g
s
.651 .758 .928 r
.88495 .63745 m .87542 .64016 L .87354 .63768 L p F P
0 g
s
.651 .758 .928 r
.73694 .64031 m .74624 .63762 L .74831 .6401 L p F P
0 g
s
.651 .758 .928 r
.74624 .63762 m .73694 .64031 L .73485 .63783 L p F P
0 g
s
.65 .757 .928 r
.32732 .63513 m .31872 .63783 L .32146 .64032 L p F P
0 g
s
.65 .757 .928 r
.32146 .64032 m .33005 .63763 L .32732 .63513 L p F P
0 g
s
.651 .758 .928 r
.59845 .64035 m .60751 .63766 L .6098 .64014 L p F P
0 g
s
.651 .758 .928 r
.60751 .63766 m .59845 .64035 L .59614 .63787 L p F P
0 g
s
.65 .757 .928 r
.45995 .64035 m .46878 .63766 L .47128 .64014 L p F P
0 g
s
.65 .757 .928 r
.46878 .63766 m .45995 .64035 L .45743 .63787 L p F P
0 g
s
.651 .759 .928 r
.8868 .63993 m .89635 .63721 L .89819 .63969 L p F P
0 g
s
.651 .758 .928 r
.89635 .63721 m .8868 .63993 L .88495 .63745 L p F P
0 g
s
.65 .757 .928 r
.19972 .63481 m .19134 .6375 L .19427 .63999 L p F P
0 g
s
.65 .757 .928 r
.19427 .63999 m .20265 .63731 L .19972 .63481 L p F P
0 g
s
.651 .758 .928 r
.74831 .6401 m .75762 .6374 L .75968 .63989 L p F P
0 g
s
.651 .758 .928 r
.75762 .6374 m .74831 .6401 L .74624 .63762 L p F P
0 g
s
.65 .757 .928 r
.33867 .63493 m .33005 .63763 L .33277 .64011 L p F P
0 g
s
.65 .757 .928 r
.33277 .64011 m .34139 .63743 L .33867 .63493 L p F P
0 g
s
.651 .758 .928 r
.6098 .64014 m .61888 .63745 L .62115 .63993 L p F P
0 g
s
.651 .758 .928 r
.61888 .63745 m .6098 .64014 L .60751 .63766 L p F P
0 g
s
.65 .757 .928 r
.47128 .64014 m .48013 .63745 L .48262 .63994 L p F P
0 g
s
.65 .757 .928 r
.48013 .63745 m .47128 .64014 L .46878 .63766 L p F P
0 g
s
.651 .759 .928 r
.89819 .63969 m .90775 .63697 L .90958 .63945 L p F P
0 g
s
.651 .759 .928 r
.90775 .63697 m .89819 .63969 L .89635 .63721 L p F P
0 g
s
.65 .757 .928 r
.21106 .63462 m .20265 .63731 L .20557 .6398 L p F P
0 g
s
.65 .757 .928 r
.20557 .6398 m .21397 .63712 L .21106 .63462 L p F P
0 g
s
.651 .758 .928 r
.75968 .63989 m .76902 .63719 L .77106 .63967 L p F P
0 g
s
.651 .758 .928 r
.76902 .63719 m .75968 .63989 L .75762 .6374 L p F P
0 g
s
.65 .757 .928 r
.35003 .63473 m .34139 .63743 L .34409 .63991 L p F P
0 g
s
.65 .757 .928 r
.34409 .63991 m .35272 .63722 L .35003 .63473 L p F P
0 g
s
.651 .758 .928 r
.62115 .63993 m .63025 .63724 L .63251 .63972 L p F P
0 g
s
.651 .758 .928 r
.63025 .63724 m .62115 .63993 L .61888 .63745 L p F P
0 g
s
.65 .757 .928 r
.48262 .63994 m .49149 .63725 L .49396 .63973 L p F P
0 g
s
.65 .757 .928 r
.49149 .63725 m .48262 .63994 L .48013 .63745 L p F P
0 g
s
.652 .759 .928 r
.91916 .63673 m .90958 .63945 L .90775 .63697 L p F P
0 g
s
.652 .759 .928 r
.90958 .63945 m .91916 .63673 L .92097 .63921 L p F P
0 g
s
.65 .757 .928 r
.2224 .63443 m .21397 .63712 L .21687 .63961 L p F P
0 g
s
.65 .757 .928 r
.21687 .63961 m .22529 .63693 L .2224 .63443 L p F P
0 g
s
.651 .758 .928 r
.77106 .63967 m .78041 .63697 L .78243 .63946 L p F P
0 g
s
.651 .758 .928 r
.78041 .63697 m .77106 .63967 L .76902 .63719 L p F P
0 g
s
.65 .757 .928 r
.36139 .63452 m .35272 .63722 L .35541 .63971 L p F P
0 g
s
.65 .757 .928 r
.35541 .63971 m .36406 .63702 L .36139 .63452 L p F P
0 g
s
.651 .758 .928 r
.63251 .63972 m .64163 .63703 L .64387 .63952 L p F P
0 g
s
.651 .758 .928 r
.64163 .63703 m .63251 .63972 L .63025 .63724 L p F P
0 g
s
.65 .757 .928 r
.49396 .63973 m .50285 .63704 L .5053 .63953 L p F P
0 g
s
.65 .757 .928 r
.50285 .63704 m .49396 .63973 L .49149 .63725 L p F P
0 g
s
.652 .759 .928 r
.92097 .63921 m .93057 .63649 L .93236 .63896 L p F P
0 g
s
.652 .759 .928 r
.93057 .63649 m .92097 .63921 L .91916 .63673 L p F P
0 g
s
.65 .757 .928 r
.23374 .63423 m .22529 .63693 L .22817 .63941 L p F P
0 g
s
.65 .757 .928 r
.22817 .63941 m .23662 .63673 L .23374 .63423 L p F P
0 g
s
.651 .758 .928 r
.78243 .63946 m .79181 .63675 L .79381 .63924 L p F P
0 g
s
.651 .758 .928 r
.79181 .63675 m .78243 .63946 L .78041 .63697 L p F P
0 g
s
.65 .757 .928 r
.37275 .63432 m .36406 .63702 L .36673 .63951 L p F P
0 g
s
.65 .757 .928 r
.36673 .63951 m .37541 .63681 L .37275 .63432 L p F P
0 g
s
.651 .758 .928 r
.64387 .63952 m .65301 .63682 L .65523 .63931 L p F P
0 g
s
.651 .758 .928 r
.65301 .63682 m .64387 .63952 L .64163 .63703 L p F P
0 g
s
.65 .758 .928 r
.5053 .63953 m .51421 .63683 L .51665 .63932 L p F P
0 g
s
.65 .757 .928 r
.51421 .63683 m .5053 .63953 L .50285 .63704 L p F P
0 g
s
.65 .757 .928 r
.24508 .63404 m .23662 .63673 L .23948 .63922 L p F P
0 g
s
.65 .757 .928 r
.23948 .63922 m .24794 .63654 L .24508 .63404 L p F P
0 g
s
.651 .758 .928 r
.79381 .63924 m .80321 .63654 L .80519 .63902 L p F P
0 g
s
.651 .758 .928 r
.80321 .63654 m .79381 .63924 L .79181 .63675 L p F P
0 g
s
.65 .757 .928 r
.38411 .63411 m .37541 .63681 L .37806 .6393 L p F P
0 g
s
.65 .757 .928 r
.37806 .6393 m .38676 .63661 L .38411 .63411 L p F P
0 g
s
.651 .758 .928 r
.66439 .63661 m .65523 .63931 L .65301 .63682 L p F P
0 g
s
.651 .758 .928 r
.65523 .63931 m .66439 .63661 L .6666 .6391 L p F P
0 g
s
.65 .758 .928 r
.51665 .63932 m .52557 .63662 L .52799 .63911 L p F P
0 g
s
.65 .758 .928 r
.52557 .63662 m .51665 .63932 L .51421 .63683 L p F P
0 g
s
.651 .758 .928 r
.80519 .63902 m .81461 .63632 L .81658 .6388 L p F P
0 g
s
.651 .758 .928 r
.81461 .63632 m .80519 .63902 L .80321 .63654 L p F P
0 g
s
.65 .757 .928 r
.25643 .63384 m .24794 .63654 L .25079 .63903 L p F P
0 g
s
.65 .757 .928 r
.25079 .63903 m .25927 .63634 L .25643 .63384 L p F P
0 g
s
.651 .758 .928 r
.6666 .6391 m .67578 .6364 L .67797 .63889 L p F P
0 g
s
.651 .758 .928 r
.67578 .6364 m .6666 .6391 L .66439 .63661 L p F P
0 g
s
.65 .757 .928 r
.39548 .63391 m .38676 .63661 L .38939 .6391 L p F P
0 g
s
.65 .757 .928 r
.38939 .6391 m .39811 .6364 L .39548 .63391 L p F P
0 g
s
.65 .758 .928 r
.52799 .63911 m .53694 .63642 L .53934 .63891 L p F P
0 g
s
.65 .758 .928 r
.53694 .63642 m .52799 .63911 L .52557 .63662 L p F P
0 g
s
.651 .758 .928 r
.81658 .6388 m .82601 .6361 L .82797 .63858 L p F P
0 g
s
.651 .758 .928 r
.82601 .6361 m .81658 .6388 L .81461 .63632 L p F P
0 g
s
.65 .757 .928 r
.26778 .63364 m .25927 .63634 L .26211 .63883 L p F P
0 g
s
.65 .757 .928 r
.26211 .63883 m .27061 .63614 L .26778 .63364 L p F P
0 g
s
.651 .758 .928 r
.67797 .63889 m .68717 .63619 L .68934 .63868 L p F P
0 g
s
.651 .758 .928 r
.68717 .63619 m .67797 .63889 L .67578 .6364 L p F P
0 g
s
.65 .757 .928 r
.40072 .63889 m .40946 .6362 L .41206 .63869 L p F P
0 g
s
.65 .757 .928 r
.40685 .6337 m .39811 .6364 L .40072 .63889 L p F P
0 g
s
.65 .757 .928 r
.40072 .63889 m .40946 .6362 L .40685 .6337 L p F P
0 g
s
.65 .758 .928 r
.53934 .63891 m .54831 .63621 L .5507 .6387 L p F P
0 g
s
.65 .758 .928 r
.54831 .63621 m .53934 .63891 L .53694 .63642 L p F P
0 g
s
.651 .758 .928 r
.82797 .63858 m .83742 .63587 L .83936 .63836 L p F P
0 g
s
.651 .758 .928 r
.83742 .63587 m .82797 .63858 L .82601 .6361 L p F P
0 g
s
.65 .757 .928 r
.27914 .63344 m .27061 .63614 L .27342 .63863 L p F P
0 g
s
.65 .757 .928 r
.27342 .63863 m .28194 .63594 L .27914 .63344 L p F P
0 g
s
.651 .758 .928 r
.68934 .63868 m .69856 .63598 L .70071 .63847 L p F P
0 g
s
.651 .758 .928 r
.69856 .63598 m .68934 .63868 L .68717 .63619 L p F P
0 g
s
.65 .757 .928 r
.41206 .63869 m .42081 .63599 L .4234 .63848 L p F P
0 g
s
.65 .757 .928 r
.42081 .63599 m .41206 .63869 L .40946 .6362 L p F P
0 g
s
.65 .758 .928 r
.5507 .6387 m .55969 .636 L .56205 .63849 L p F P
0 g
s
.65 .758 .928 r
.55969 .636 m .5507 .6387 L .54831 .63621 L p F P
0 g
s
.651 .758 .928 r
.83936 .63836 m .84883 .63565 L .85075 .63813 L p F P
0 g
s
.651 .758 .928 r
.84883 .63565 m .83936 .63836 L .83742 .63587 L p F P
0 g
s
.65 .757 .928 r
.29049 .63324 m .28194 .63594 L .28474 .63843 L p F P
0 g
s
.65 .757 .928 r
.28474 .63843 m .29328 .63574 L .29049 .63324 L p F P
0 g
s
.651 .758 .928 r
.70071 .63847 m .70995 .63576 L .71209 .63825 L p F P
0 g
s
.651 .758 .928 r
.70995 .63576 m .70071 .63847 L .69856 .63598 L p F P
0 g
s
.65 .757 .928 r
.4234 .63848 m .43217 .63579 L .43474 .63828 L p F P
0 g
s
.65 .757 .928 r
.43217 .63579 m .4234 .63848 L .42081 .63599 L p F P
0 g
s
0 0 .349 r
.52577 .52922 m .52577 .52923 L .52577 .52515 L p F P
0 g
s
0 0 .349 r
.52577 .52515 m .52578 .52514 L .52577 .52922 L p F P
0 g
s
.761 .5 .538 r
.52575 .52923 m .52577 .52923 L .52577 .52515 L p F P
0 g
s
.761 .5 .538 r
.52577 .52515 m .52575 .52514 L .52575 .52923 L p F P
0 g
s
.651 .758 .928 r
.56205 .63849 m .57106 .63579 L .57341 .63828 L p F P
0 g
s
.651 .758 .928 r
.57106 .63579 m .56205 .63849 L .55969 .636 L p F P
0 g
s
0 0 .349 r
.52575 .52513 m .52575 .52514 L .52575 .52923 L p F P
0 g
s
.761 .5 .539 r
.52575 .52513 m .52578 .52514 L .52577 .52922 L p F P
0 g
s
.761 .5 .539 r
.52577 .52922 m .52575 .52922 L .52575 .52513 L p F P
0 g
s
0 0 .349 r
.52575 .52923 m .52575 .52922 L .52575 .52513 L p F P
0 g
s
.651 .758 .928 r
.85075 .63813 m .86025 .63542 L .86215 .63791 L p F P
0 g
s
.651 .758 .928 r
.86025 .63542 m .85075 .63813 L .84883 .63565 L p F P
0 g
s
.65 .757 .928 r
.30186 .63304 m .29328 .63574 L .29606 .63823 L p F P
0 g
s
.65 .757 .928 r
.29606 .63823 m .30463 .63554 L .30186 .63304 L p F P
0 g
s
.651 .758 .928 r
.71209 .63825 m .72135 .63555 L .72347 .63804 L p F P
0 g
s
.651 .758 .928 r
.72135 .63555 m .71209 .63825 L .70995 .63576 L p F P
0 g
s
.65 .757 .928 r
.43474 .63828 m .44353 .63558 L .44608 .63807 L p F P
0 g
s
.65 .757 .928 r
.44353 .63558 m .43474 .63828 L .43217 .63579 L p F P
0 g
s
.651 .758 .928 r
.57341 .63828 m .58244 .63558 L .58478 .63807 L p F P
0 g
s
.651 .758 .928 r
.58244 .63558 m .57341 .63828 L .57106 .63579 L p F P
0 g
s
.651 .758 .928 r
.86215 .63791 m .87166 .63519 L .87354 .63768 L p F P
0 g
s
.651 .758 .928 r
.87166 .63519 m .86215 .63791 L .86025 .63542 L p F P
0 g
s
.65 .757 .928 r
.31322 .63284 m .30463 .63554 L .30739 .63803 L p F P
0 g
s
.65 .757 .928 r
.30739 .63803 m .31597 .63534 L .31322 .63284 L p F P
0 g
s
.651 .758 .928 r
.72347 .63804 m .73275 .63534 L .73485 .63783 L p F P
0 g
s
.651 .758 .928 r
.73275 .63534 m .72347 .63804 L .72135 .63555 L p F P
0 g
s
.65 .757 .928 r
.44608 .63807 m .4549 .63537 L .45743 .63787 L p F P
0 g
s
.65 .757 .928 r
.4549 .63537 m .44608 .63807 L .44353 .63558 L p F P
0 g
s
.651 .758 .928 r
.58478 .63807 m .59383 .63537 L .59614 .63787 L p F P
0 g
s
.651 .758 .928 r
.59383 .63537 m .58478 .63807 L .58244 .63558 L p F P
0 g
s
.651 .758 .928 r
.87354 .63768 m .88308 .63496 L .88495 .63745 L p F P
0 g
s
.651 .758 .928 r
.88308 .63496 m .87354 .63768 L .87166 .63519 L p F P
0 g
s
.651 .758 .928 r
.73485 .63783 m .74415 .63512 L .74624 .63762 L p F P
0 g
s
.651 .758 .928 r
.74415 .63512 m .73485 .63783 L .73275 .63534 L p F P
0 g
s
.65 .757 .928 r
.32458 .63263 m .31597 .63534 L .31872 .63783 L p F P
0 g
s
.65 .757 .928 r
.31872 .63783 m .32732 .63513 L .32458 .63263 L p F P
0 g
s
.651 .758 .928 r
.59614 .63787 m .60521 .63516 L .60751 .63766 L p F P
0 g
s
.651 .758 .928 r
.60521 .63516 m .59614 .63787 L .59383 .63537 L p F P
0 g
s
.65 .757 .928 r
.45743 .63787 m .46627 .63517 L .46878 .63766 L p F P
0 g
s
.65 .757 .928 r
.46627 .63517 m .45743 .63787 L .4549 .63537 L p F P
0 g
s
.651 .758 .928 r
.88495 .63745 m .8945 .63473 L .89635 .63721 L p F P
0 g
s
.651 .758 .928 r
.8945 .63473 m .88495 .63745 L .88308 .63496 L p F P
0 g
s
.65 .757 .928 r
.19679 .63231 m .18839 .635 L .19134 .6375 L p F P
0 g
s
.65 .757 .928 r
.19134 .6375 m .19972 .63481 L .19679 .63231 L p F P
0 g
s
.651 .758 .928 r
.74624 .63762 m .75556 .63491 L .75762 .6374 L p F P
0 g
s
.651 .758 .928 r
.75556 .63491 m .74624 .63762 L .74415 .63512 L p F P
0 g
s
.65 .757 .928 r
.33595 .63243 m .32732 .63513 L .33005 .63763 L p F P
0 g
s
.65 .757 .928 r
.33005 .63763 m .33867 .63493 L .33595 .63243 L p F P
0 g
s
.651 .758 .928 r
.60751 .63766 m .6166 .63495 L .61888 .63745 L p F P
0 g
s
.651 .758 .928 r
.6166 .63495 m .60751 .63766 L .60521 .63516 L p F P
0 g
s
.65 .757 .928 r
.47764 .63496 m .46878 .63766 L .46627 .63517 L p F P
0 g
s
.65 .757 .928 r
.46878 .63766 m .47764 .63496 L .48013 .63745 L p F P
0 g
s
.651 .759 .928 r
.89635 .63721 m .90592 .63449 L .90775 .63697 L p F P
0 g
s
.651 .759 .928 r
.90592 .63449 m .89635 .63721 L .8945 .63473 L p F P
0 g
s
.65 .757 .928 r
.20814 .63212 m .19972 .63481 L .20265 .63731 L p F P
0 g
s
.65 .757 .928 r
.20265 .63731 m .21106 .63462 L .20814 .63212 L p F P
0 g
s
.651 .758 .928 r
.75762 .6374 m .76697 .63469 L .76902 .63719 L p F P
0 g
s
.651 .758 .928 r
.76697 .63469 m .75762 .6374 L .75556 .63491 L p F P
0 g
s
.65 .757 .928 r
.34733 .63222 m .33867 .63493 L .34139 .63743 L p F P
0 g
s
.65 .757 .928 r
.34139 .63743 m .35003 .63473 L .34733 .63222 L p F P
0 g
s
.651 .758 .928 r
.61888 .63745 m .62799 .63474 L .63025 .63724 L p F P
0 g
s
.651 .758 .928 r
.62799 .63474 m .61888 .63745 L .6166 .63495 L p F P
0 g
s
.65 .757 .928 r
.48013 .63745 m .48901 .63475 L .49149 .63725 L p F P
0 g
s
.65 .757 .928 r
.48901 .63475 m .48013 .63745 L .47764 .63496 L p F P
0 g
s
.652 .759 .928 r
.90775 .63697 m .91735 .63425 L .91916 .63673 L p F P
0 g
s
.651 .759 .928 r
.91735 .63425 m .90775 .63697 L .90592 .63449 L p F P
0 g
s
.65 .757 .928 r
.2195 .63192 m .21106 .63462 L .21397 .63712 L p F P
0 g
s
.65 .757 .928 r
.21397 .63712 m .2224 .63443 L .2195 .63192 L p F P
0 g
s
.651 .758 .928 r
.76902 .63719 m .77838 .63448 L .78041 .63697 L p F P
0 g
s
.651 .758 .928 r
.77838 .63448 m .76902 .63719 L .76697 .63469 L p F P
0 g
s
.65 .757 .928 r
.3587 .63202 m .35003 .63473 L .35272 .63722 L p F P
0 g
s
.65 .757 .928 r
.35272 .63722 m .36139 .63452 L .3587 .63202 L p F P
0 g
s
.651 .758 .928 r
.63025 .63724 m .63939 .63453 L .64163 .63703 L p F P
0 g
s
.651 .758 .928 r
.63939 .63453 m .63025 .63724 L .62799 .63474 L p F P
0 g
s
.65 .757 .928 r
.49149 .63725 m .50039 .63454 L .50285 .63704 L p F P
0 g
s
.65 .757 .928 r
.50039 .63454 m .49149 .63725 L .48901 .63475 L p F P
0 g
s
.652 .759 .928 r
.92878 .634 m .91916 .63673 L .91735 .63425 L p F P
0 g
s
.652 .759 .928 r
.91916 .63673 m .92878 .634 L .93057 .63649 L p F P
0 g
s
.65 .757 .928 r
.23085 .63173 m .2224 .63443 L .22529 .63693 L p F P
0 g
s
.65 .757 .928 r
.22529 .63693 m .23374 .63423 L .23085 .63173 L p F P
0 g
s
.651 .758 .928 r
.78041 .63697 m .7898 .63426 L .79181 .63675 L p F P
0 g
s
.651 .758 .928 r
.7898 .63426 m .78041 .63697 L .77838 .63448 L p F P
0 g
s
.65 .757 .928 r
.37008 .63181 m .36139 .63452 L .36406 .63702 L p F P
0 g
s
.65 .757 .928 r
.36406 .63702 m .37275 .63432 L .37008 .63181 L p F P
0 g
s
.651 .758 .928 r
.64163 .63703 m .65078 .63432 L .65301 .63682 L p F P
0 g
s
.651 .758 .928 r
.65078 .63432 m .64163 .63703 L .63939 .63453 L p F P
0 g
s
.65 .757 .928 r
.50285 .63704 m .51177 .63434 L .51421 .63683 L p F P
0 g
s
.65 .757 .928 r
.51177 .63434 m .50285 .63704 L .50039 .63454 L p F P
0 g
s
.65 .757 .928 r
.24222 .63153 m .23374 .63423 L .23662 .63673 L p F P
0 g
s
.65 .757 .928 r
.23662 .63673 m .24508 .63404 L .24222 .63153 L p F P
0 g
s
.651 .758 .928 r
.79181 .63675 m .80121 .63404 L .80321 .63654 L p F P
0 g
s
.651 .758 .928 r
.80121 .63404 m .79181 .63675 L .7898 .63426 L p F P
0 g
s
.65 .757 .928 r
.38146 .63161 m .37275 .63432 L .37541 .63681 L p F P
0 g
s
.65 .757 .928 r
.37541 .63681 m .38411 .63411 L .38146 .63161 L p F P
0 g
s
.651 .758 .928 r
.65301 .63682 m .66218 .63411 L .66439 .63661 L p F P
0 g
s
.651 .758 .928 r
.66218 .63411 m .65301 .63682 L .65078 .63432 L p F P
0 g
s
.65 .758 .928 r
.51421 .63683 m .52315 .63413 L .52557 .63662 L p F P
0 g
s
.65 .758 .928 r
.52315 .63413 m .51421 .63683 L .51177 .63434 L p F P
0 g
s
.65 .757 .928 r
.25358 .63133 m .24508 .63404 L .24794 .63654 L p F P
0 g
s
.65 .757 .928 r
.24794 .63654 m .25643 .63384 L .25358 .63133 L p F P
0 g
s
.651 .758 .928 r
.80321 .63654 m .81263 .63382 L .81461 .63632 L p F P
0 g
s
.651 .758 .928 r
.81263 .63382 m .80321 .63654 L .80121 .63404 L p F P
0 g
s
.65 .757 .928 r
.39285 .6314 m .38411 .63411 L .38676 .63661 L p F P
0 g
s
.65 .757 .928 r
.38676 .63661 m .39548 .63391 L .39285 .6314 L p F P
0 g
s
.651 .758 .928 r
.67359 .6339 m .66439 .63661 L .66218 .63411 L p F P
0 g
s
.651 .758 .928 r
.66439 .63661 m .67359 .6339 L .67578 .6364 L p F P
0 g
s
.65 .758 .928 r
.52557 .63662 m .53453 .63392 L .53694 .63642 L p F P
0 g
s
.65 .758 .928 r
.53453 .63392 m .52557 .63662 L .52315 .63413 L p F P
0 g
s
.651 .758 .928 r
.81461 .63632 m .82406 .6336 L .82601 .6361 L p F P
0 g
s
.651 .758 .928 r
.82406 .6336 m .81461 .63632 L .81263 .63382 L p F P
0 g
s
.65 .757 .928 r
.26495 .63113 m .25643 .63384 L .25927 .63634 L p F P
0 g
s
.65 .757 .928 r
.25927 .63634 m .26778 .63364 L .26495 .63113 L p F P
0 g
s
.651 .758 .928 r
.67578 .6364 m .68499 .63369 L .68717 .63619 L p F P
0 g
s
.651 .758 .928 r
.68499 .63369 m .67578 .6364 L .67359 .6339 L p F P
0 g
s
.65 .757 .928 r
.40423 .63119 m .39548 .63391 L .39811 .6364 L p F P
0 g
s
.65 .757 .928 r
.39811 .6364 m .40685 .6337 L .40423 .63119 L p F P
0 g
s
0 0 .349 r
.52577 .53331 m .52577 .53333 L .52577 .52923 L p F P
0 g
s
0 0 .349 r
.52577 .52923 m .52577 .52922 L .52577 .53331 L p F P
0 g
s
.761 .5 .538 r
.52575 .53332 m .52577 .53333 L .52577 .52923 L p F P
0 g
s
.761 .5 .538 r
.52577 .52923 m .52575 .52923 L .52575 .53332 L p F P
0 g
s
.65 .758 .928 r
.53694 .63642 m .54592 .63371 L .54831 .63621 L p F P
0 g
s
.65 .758 .928 r
.54592 .63371 m .53694 .63642 L .53453 .63392 L p F P
0 g
s
0 0 .35 r
.52575 .52922 m .52575 .52923 L .52575 .53332 L p F P
0 g
s
.761 .5 .539 r
.52575 .52922 m .52577 .52922 L .52577 .53331 L p F P
0 g
s
.761 .5 .539 r
.52577 .53331 m .52575 .53331 L .52575 .52922 L p F P
0 g
s
0 0 .35 r
.52575 .53332 m .52575 .53331 L .52575 .52922 L p F P
0 g
s
.651 .758 .928 r
.82601 .6361 m .83548 .63338 L .83742 .63587 L p F P
0 g
s
.651 .758 .928 r
.83548 .63338 m .82601 .6361 L .82406 .6336 L p F P
0 g
s
.65 .757 .928 r
.27632 .63093 m .26778 .63364 L .27061 .63614 L p F P
0 g
s
.65 .757 .928 r
.27061 .63614 m .27914 .63344 L .27632 .63093 L p F P
0 g
s
.651 .758 .928 r
.68717 .63619 m .6964 .63348 L .69856 .63598 L p F P
0 g
s
.651 .758 .928 r
.6964 .63348 m .68717 .63619 L .68499 .63369 L p F P
0 g
s
.65 .757 .928 r
.40946 .6362 m .41822 .63349 L .42081 .63599 L p F P
0 g
s
.65 .757 .928 r
.41562 .63099 m .40685 .6337 L .40946 .6362 L p F P
0 g
s
.65 .757 .928 r
.40946 .6362 m .41822 .63349 L .41562 .63099 L p F P
0 g
s
.65 .758 .928 r
.54831 .63621 m .55731 .6335 L .55969 .636 L p F P
0 g
s
.65 .758 .928 r
.55731 .6335 m .54831 .63621 L .54592 .63371 L p F P
0 g
s
.651 .758 .928 r
.83742 .63587 m .84691 .63315 L .84883 .63565 L p F P
0 g
s
.651 .758 .928 r
.84691 .63315 m .83742 .63587 L .83548 .63338 L p F P
0 g
s
.65 .757 .928 r
.2877 .63073 m .27914 .63344 L .28194 .63594 L p F P
0 g
s
.65 .757 .928 r
.28194 .63594 m .29049 .63324 L .2877 .63073 L p F P
0 g
s
.651 .758 .928 r
.69856 .63598 m .70781 .63327 L .70995 .63576 L p F P
0 g
s
.651 .758 .928 r
.70781 .63327 m .69856 .63598 L .6964 .63348 L p F P
0 g
s
.65 .757 .928 r
.42081 .63599 m .4296 .63329 L .43217 .63579 L p F P
0 g
s
.65 .757 .928 r
.4296 .63329 m .42081 .63599 L .41822 .63349 L p F P
0 g
s
.651 .758 .928 r
.55969 .636 m .56871 .63329 L .57106 .63579 L p F P
0 g
s
.651 .758 .928 r
.56871 .63329 m .55969 .636 L .55731 .6335 L p F P
0 g
s
.651 .758 .928 r
.84883 .63565 m .85834 .63293 L .86025 .63542 L p F P
0 g
s
.651 .758 .928 r
.85834 .63293 m .84883 .63565 L .84691 .63315 L p F P
0 g
s
.65 .757 .928 r
.29907 .63053 m .29049 .63324 L .29328 .63574 L p F P
0 g
s
.65 .757 .928 r
.29328 .63574 m .30186 .63304 L .29907 .63053 L p F P
0 g
s
.651 .758 .928 r
.70995 .63576 m .71923 .63305 L .72135 .63555 L p F P
0 g
s
.651 .758 .928 r
.71923 .63305 m .70995 .63576 L .70781 .63327 L p F P
0 g
s
.65 .757 .928 r
.43217 .63579 m .44098 .63308 L .44353 .63558 L p F P
0 g
s
.65 .757 .928 r
.44098 .63308 m .43217 .63579 L .4296 .63329 L p F P
0 g
s
.651 .758 .928 r
.57106 .63579 m .5801 .63308 L .58244 .63558 L p F P
0 g
s
.651 .758 .928 r
.5801 .63308 m .57106 .63579 L .56871 .63329 L p F P
0 g
s
.651 .758 .928 r
.86025 .63542 m .86977 .6327 L .87166 .63519 L p F P
0 g
s
.651 .758 .928 r
.86977 .6327 m .86025 .63542 L .85834 .63293 L p F P
0 g
s
.65 .757 .928 r
.31046 .63033 m .30186 .63304 L .30463 .63554 L p F P
0 g
s
.65 .757 .928 r
.30463 .63554 m .31322 .63284 L .31046 .63033 L p F P
0 g
s
.651 .758 .928 r
.72135 .63555 m .73065 .63284 L .73275 .63534 L p F P
0 g
s
.651 .758 .928 r
.73065 .63284 m .72135 .63555 L .71923 .63305 L p F P
0 g
s
.65 .757 .928 r
.44353 .63558 m .45236 .63287 L .4549 .63537 L p F P
0 g
s
.65 .757 .928 r
.45236 .63287 m .44353 .63558 L .44098 .63308 L p F P
0 g
s
.651 .758 .928 r
.58244 .63558 m .5915 .63287 L .59383 .63537 L p F P
0 g
s
.651 .758 .928 r
.5915 .63287 m .58244 .63558 L .5801 .63308 L p F P
0 g
s
.651 .758 .928 r
.87166 .63519 m .88121 .63247 L .88308 .63496 L p F P
0 g
s
.651 .758 .928 r
.88121 .63247 m .87166 .63519 L .86977 .6327 L p F P
0 g
s
.65 .757 .928 r
.32184 .63012 m .31322 .63284 L .31597 .63534 L p F P
0 g
s
.65 .757 .928 r
.31597 .63534 m .32458 .63263 L .32184 .63012 L p F P
0 g
s
.651 .758 .928 r
.73275 .63534 m .74207 .63262 L .74415 .63512 L p F P
0 g
s
.651 .758 .928 r
.74207 .63262 m .73275 .63534 L .73065 .63284 L p F P
0 g
s
.65 .757 .928 r
.4549 .63537 m .46374 .63266 L .46627 .63517 L p F P
0 g
s
.65 .757 .928 r
.46374 .63266 m .4549 .63537 L .45236 .63287 L p F P
0 g
s
.651 .758 .928 r
.59383 .63537 m .60291 .63266 L .60521 .63516 L p F P
0 g
s
.651 .758 .928 r
.60291 .63266 m .59383 .63537 L .5915 .63287 L p F P
0 g
s
.651 .758 .928 r
.88308 .63496 m .89265 .63223 L .8945 .63473 L p F P
0 g
s
.651 .758 .928 r
.89265 .63223 m .88308 .63496 L .88121 .63247 L p F P
0 g
s
.65 .757 .928 r
.19384 .62979 m .18544 .6325 L .18839 .635 L p F P
0 g
s
.65 .757 .928 r
.18839 .635 m .19679 .63231 L .19384 .62979 L p F P
0 g
s
.651 .758 .928 r
.74415 .63512 m .75349 .63241 L .75556 .63491 L p F P
0 g
s
.651 .758 .928 r
.75349 .63241 m .74415 .63512 L .74207 .63262 L p F P
0 g
s
.65 .757 .928 r
.33323 .62992 m .32458 .63263 L .32732 .63513 L p F P
0 g
s
.65 .757 .928 r
.32732 .63513 m .33595 .63243 L .33323 .62992 L p F P
0 g
s
.651 .758 .928 r
.60521 .63516 m .61431 .63245 L .6166 .63495 L p F P
0 g
s
.651 .758 .928 r
.61431 .63245 m .60521 .63516 L .60291 .63266 L p F P
0 g
s
.65 .757 .928 r
.46627 .63517 m .47513 .63246 L .47764 .63496 L p F P
0 g
s
.65 .757 .928 r
.47513 .63246 m .46627 .63517 L .46374 .63266 L p F P
0 g
s
.651 .759 .928 r
.8945 .63473 m .90409 .63199 L .90592 .63449 L p F P
0 g
s
.651 .759 .928 r
.90409 .63199 m .8945 .63473 L .89265 .63223 L p F P
0 g
s
.65 .757 .928 r
.20521 .6296 m .19679 .63231 L .19972 .63481 L p F P
0 g
s
.65 .757 .928 r
.19972 .63481 m .20814 .63212 L .20521 .6296 L p F P
0 g
s
.651 .758 .928 r
.75556 .63491 m .76492 .63219 L .76697 .63469 L p F P
0 g
s
.651 .758 .928 r
.76492 .63219 m .75556 .63491 L .75349 .63241 L p F P
0 g
s
.65 .757 .928 r
.34462 .62971 m .33595 .63243 L .33867 .63493 L p F P
0 g
s
.65 .757 .928 r
.33867 .63493 m .34733 .63222 L .34462 .62971 L p F P
0 g
s
.651 .758 .928 r
.6166 .63495 m .62572 .63224 L .62799 .63474 L p F P
0 g
s
.651 .758 .928 r
.62572 .63224 m .6166 .63495 L .61431 .63245 L p F P
0 g
s
.65 .757 .928 r
.47764 .63496 m .48652 .63225 L .48901 .63475 L p F P
0 g
s
.65 .757 .928 r
.48652 .63225 m .47764 .63496 L .47513 .63246 L p F P
0 g
s
.651 .759 .928 r
.90592 .63449 m .91553 .63175 L .91735 .63425 L p F P
0 g
s
.651 .759 .928 r
.91553 .63175 m .90592 .63449 L .90409 .63199 L p F P
0 g
s
.65 .757 .928 r
.21659 .62941 m .20814 .63212 L .21106 .63462 L p F P
0 g
s
.65 .757 .928 r
.21106 .63462 m .2195 .63192 L .21659 .62941 L p F P
0 g
s
.651 .758 .928 r
.76697 .63469 m .77635 .63198 L .77838 .63448 L p F P
0 g
s
.651 .758 .928 r
.77635 .63198 m .76697 .63469 L .76492 .63219 L p F P
0 g
s
.65 .757 .928 r
.35601 .62951 m .34733 .63222 L .35003 .63473 L p F P
0 g
s
.65 .757 .928 r
.35003 .63473 m .3587 .63202 L .35601 .62951 L p F P
0 g
s
.651 .758 .928 r
.62799 .63474 m .63713 .63203 L .63939 .63453 L p F P
0 g
s
.651 .758 .928 r
.63713 .63203 m .62799 .63474 L .62572 .63224 L p F P
0 g
s
.65 .757 .928 r
.48901 .63475 m .49792 .63204 L .50039 .63454 L p F P
0 g
s
.65 .757 .928 r
.49792 .63204 m .48901 .63475 L .48652 .63225 L p F P
0 g
s
.652 .759 .928 r
.91735 .63425 m .92698 .63151 L .92878 .634 L p F P
0 g
s
.652 .759 .928 r
.92698 .63151 m .91735 .63425 L .91553 .63175 L p F P
0 g
s
.65 .757 .928 r
.22796 .62921 m .2195 .63192 L .2224 .63443 L p F P
0 g
s
.65 .757 .928 r
.2224 .63443 m .23085 .63173 L .22796 .62921 L p F P
0 g
s
.651 .758 .928 r
.77838 .63448 m .78778 .63176 L .7898 .63426 L p F P
0 g
s
.651 .758 .928 r
.78778 .63176 m .77838 .63448 L .77635 .63198 L p F P
0 g
s
.65 .757 .928 r
.3674 .6293 m .3587 .63202 L .36139 .63452 L p F P
0 g
s
.65 .757 .928 r
.36139 .63452 m .37008 .63181 L .3674 .6293 L p F P
0 g
s
.651 .758 .928 r
.63939 .63453 m .64855 .63182 L .65078 .63432 L p F P
0 g
s
.651 .758 .928 r
.64855 .63182 m .63939 .63453 L .63713 .63203 L p F P
0 g
s
.65 .757 .928 r
.50039 .63454 m .50931 .63183 L .51177 .63434 L p F P
0 g
s
.65 .757 .928 r
.50931 .63183 m .50039 .63454 L .49792 .63204 L p F P
0 g
s
.65 .757 .928 r
.23934 .62902 m .23085 .63173 L .23374 .63423 L p F P
0 g
s
.65 .757 .928 r
.23374 .63423 m .24222 .63153 L .23934 .62902 L p F P
0 g
s
.651 .758 .928 r
.7898 .63426 m .79921 .63154 L .80121 .63404 L p F P
0 g
s
.651 .758 .928 r
.79921 .63154 m .7898 .63426 L .78778 .63176 L p F P
0 g
s
.65 .757 .928 r
.3788 .62909 m .37008 .63181 L .37275 .63432 L p F P
0 g
s
.65 .757 .928 r
.37275 .63432 m .38146 .63161 L .3788 .62909 L p F P
0 g
s
.651 .758 .928 r
.65078 .63432 m .65997 .63161 L .66218 .63411 L p F P
0 g
s
.651 .758 .928 r
.65997 .63161 m .65078 .63432 L .64855 .63182 L p F P
0 g
s
0 0 .35 r
.52577 .53742 m .52577 .53743 L .52577 .53333 L p F P
0 g
s
0 0 .35 r
.52577 .53333 m .52577 .53331 L .52577 .53742 L p F P
0 g
s
.761 .5 .538 r
.52575 .53743 m .52577 .53743 L .52577 .53333 L p F P
0 g
s
.761 .5 .538 r
.52577 .53333 m .52575 .53332 L .52575 .53743 L p F P
0 g
s
.65 .758 .928 r
.51177 .63434 m .52071 .63162 L .52315 .63413 L p F P
0 g
s
.65 .757 .928 r
.52071 .63162 m .51177 .63434 L .50931 .63183 L p F P
0 g
s
0 0 .35 r
.52575 .53331 m .52575 .53332 L .52575 .53743 L p F P
0 g
s
.761 .5 .539 r
.52575 .53331 m .52577 .53331 L .52577 .53742 L p F P
0 g
s
.761 .5 .539 r
.52577 .53742 m .52575 .53742 L .52575 .53331 L p F P
0 g
s
0 0 .35 r
.52575 .53743 m .52575 .53742 L .52575 .53331 L p F P
0 g
s
.65 .757 .928 r
.25072 .62882 m .24222 .63153 L .24508 .63404 L p F P
0 g
s
.65 .757 .928 r
.24508 .63404 m .25358 .63133 L .25072 .62882 L p F P
0 g
s
.651 .758 .928 r
.80121 .63404 m .81065 .63132 L .81263 .63382 L p F P
0 g
s
.651 .758 .928 r
.81065 .63132 m .80121 .63404 L .79921 .63154 L p F P
0 g
s
.65 .757 .928 r
.39021 .62889 m .38146 .63161 L .38411 .63411 L p F P
0 g
s
.65 .757 .928 r
.38411 .63411 m .39285 .6314 L .39021 .62889 L p F P
0 g
s
.651 .758 .928 r
.66218 .63411 m .67139 .6314 L .67359 .6339 L p F P
0 g
s
.651 .758 .928 r
.67139 .6314 m .66218 .63411 L .65997 .63161 L p F P
0 g
s
.65 .758 .928 r
.52315 .63413 m .53212 .63141 L .53453 .63392 L p F P
0 g
s
.65 .758 .928 r
.53212 .63141 m .52315 .63413 L .52071 .63162 L p F P
0 g
s
.651 .758 .928 r
.81263 .63382 m .82209 .6311 L .82406 .6336 L p F P
0 g
s
.651 .758 .928 r
.82209 .6311 m .81263 .63382 L .81065 .63132 L p F P
0 g
s
.65 .757 .928 r
.26211 .62862 m .25358 .63133 L .25643 .63384 L p F P
0 g
s
.65 .757 .928 r
.25643 .63384 m .26495 .63113 L .26211 .62862 L p F P
0 g
s
.651 .758 .928 r
.68281 .63119 m .67359 .6339 L .67139 .6314 L p F P
0 g
s
.651 .758 .928 r
.67359 .6339 m .68281 .63119 L .68499 .63369 L p F P
0 g
s
.65 .757 .928 r
.40161 .62868 m .39285 .6314 L .39548 .63391 L p F P
0 g
s
.65 .757 .928 r
.39548 .63391 m .40423 .63119 L .40161 .62868 L p F P
0 g
s
.65 .758 .928 r
.53453 .63392 m .54352 .63121 L .54592 .63371 L p F P
0 g
s
.65 .758 .928 r
.54352 .63121 m .53453 .63392 L .53212 .63141 L p F P
0 g
s
.651 .758 .928 r
.82406 .6336 m .83353 .63088 L .83548 .63338 L p F P
0 g
s
.651 .758 .928 r
.83353 .63088 m .82406 .6336 L .82209 .6311 L p F P
0 g
s
.65 .757 .928 r
.2735 .62842 m .26495 .63113 L .26778 .63364 L p F P
0 g
s
.65 .757 .928 r
.26778 .63364 m .27632 .63093 L .2735 .62842 L p F P
0 g
s
.651 .758 .928 r
.68499 .63369 m .69424 .63097 L .6964 .63348 L p F P
0 g
s
.651 .758 .928 r
.69424 .63097 m .68499 .63369 L .68281 .63119 L p F P
0 g
s
.65 .757 .928 r
.41302 .62847 m .40423 .63119 L .40685 .6337 L p F P
0 g
s
.65 .757 .928 r
.40685 .6337 m .41562 .63099 L .41302 .62847 L p F P
0 g
s
.65 .758 .928 r
.54592 .63371 m .55493 .631 L .55731 .6335 L p F P
0 g
s
.65 .758 .928 r
.55493 .631 m .54592 .63371 L .54352 .63121 L p F P
0 g
s
.651 .758 .928 r
.83548 .63338 m .84498 .63065 L .84691 .63315 L p F P
0 g
s
.651 .758 .928 r
.84498 .63065 m .83548 .63338 L .83353 .63088 L p F P
0 g
s
.65 .757 .928 r
.28489 .62822 m .27632 .63093 L .27914 .63344 L p F P
0 g
s
.65 .757 .928 r
.27914 .63344 m .2877 .63073 L .28489 .62822 L p F P
0 g
s
.651 .758 .928 r
.6964 .63348 m .70567 .63076 L .70781 .63327 L p F P
0 g
s
.651 .758 .928 r
.70567 .63076 m .6964 .63348 L .69424 .63097 L p F P
0 g
s
.65 .757 .928 r
.41822 .63349 m .42702 .63078 L .4296 .63329 L p F P
0 g
s
.65 .757 .928 r
.42443 .62826 m .41562 .63099 L .41822 .63349 L p F P
0 g
s
.65 .757 .928 r
.41822 .63349 m .42702 .63078 L .42443 .62826 L p F P
0 g
s
.651 .758 .928 r
.55731 .6335 m .56634 .63079 L .56871 .63329 L p F P
0 g
s
.651 .758 .928 r
.56634 .63079 m .55731 .6335 L .55493 .631 L p F P
0 g
s
.651 .758 .928 r
.84691 .63315 m .85643 .63042 L .85834 .63293 L p F P
0 g
s
.651 .758 .928 r
.85643 .63042 m .84691 .63315 L .84498 .63065 L p F P
0 g
s
.65 .757 .928 r
.29629 .62801 m .2877 .63073 L .29049 .63324 L p F P
0 g
s
.65 .757 .928 r
.29049 .63324 m .29907 .63053 L .29629 .62801 L p F P
0 g
s
.651 .758 .928 r
.70781 .63327 m .7171 .63055 L .71923 .63305 L p F P
0 g
s
.651 .758 .928 r
.7171 .63055 m .70781 .63327 L .70567 .63076 L p F P
0 g
s
.65 .757 .928 r
.4296 .63329 m .43841 .63057 L .44098 .63308 L p F P
0 g
s
.65 .757 .928 r
.43841 .63057 m .4296 .63329 L .42702 .63078 L p F P
0 g
s
.651 .758 .928 r
.56871 .63329 m .57776 .63058 L .5801 .63308 L p F P
0 g
s
.651 .758 .928 r
.57776 .63058 m .56871 .63329 L .56634 .63079 L p F P
0 g
s
.651 .758 .928 r
.85834 .63293 m .86788 .6302 L .86977 .6327 L p F P
0 g
s
.651 .758 .928 r
.86788 .6302 m .85834 .63293 L .85643 .63042 L p F P
0 g
s
.65 .757 .928 r
.30768 .62781 m .29907 .63053 L .30186 .63304 L p F P
0 g
s
.65 .757 .928 r
.30186 .63304 m .31046 .63033 L .30768 .62781 L p F P
0 g
s
.651 .758 .928 r
.71923 .63305 m .72853 .63033 L .73065 .63284 L p F P
0 g
s
.651 .758 .928 r
.72853 .63033 m .71923 .63305 L .7171 .63055 L p F P
0 g
s
.65 .757 .928 r
.44098 .63308 m .44981 .63036 L .45236 .63287 L p F P
0 g
s
.65 .757 .928 r
.44981 .63036 m .44098 .63308 L .43841 .63057 L p F P
0 g
s
.651 .758 .928 r
.5801 .63308 m .58917 .63037 L .5915 .63287 L p F P
0 g
s
.651 .758 .928 r
.58917 .63037 m .5801 .63308 L .57776 .63058 L p F P
0 g
s
.651 .758 .928 r
.86977 .6327 m .87933 .62996 L .88121 .63247 L p F P
0 g
s
.651 .758 .928 r
.87933 .62996 m .86977 .6327 L .86788 .6302 L p F P
0 g
s
.65 .757 .928 r
.31908 .62761 m .31046 .63033 L .31322 .63284 L p F P
0 g
s
.65 .757 .928 r
.31322 .63284 m .32184 .63012 L .31908 .62761 L p F P
0 g
s
.651 .758 .928 r
.73065 .63284 m .73997 .63012 L .74207 .63262 L p F P
0 g
s
.651 .758 .928 r
.73997 .63012 m .73065 .63284 L .72853 .63033 L p F P
0 g
s
.65 .757 .928 r
.45236 .63287 m .46122 .63016 L .46374 .63266 L p F P
0 g
s
.65 .757 .928 r
.46122 .63016 m .45236 .63287 L .44981 .63036 L p F P
0 g
s
.651 .758 .928 r
.5915 .63287 m .6006 .63015 L .60291 .63266 L p F P
0 g
s
.651 .758 .928 r
.6006 .63015 m .5915 .63287 L .58917 .63037 L p F P
0 g
s
.651 .758 .928 r
.88121 .63247 m .89079 .62973 L .89265 .63223 L p F P
0 g
s
.651 .758 .928 r
.89079 .62973 m .88121 .63247 L .87933 .62996 L p F P
0 g
s
.65 .757 .928 r
.19089 .62727 m .18248 .62998 L .18544 .6325 L p F P
0 g
s
.65 .757 .928 r
.18544 .6325 m .19384 .62979 L .19089 .62727 L p F P
0 g
s
.651 .758 .928 r
.74207 .63262 m .75141 .6299 L .75349 .63241 L p F P
0 g
s
.651 .758 .928 r
.75141 .6299 m .74207 .63262 L .73997 .63012 L p F P
0 g
s
.65 .757 .928 r
.33049 .6274 m .32184 .63012 L .32458 .63263 L p F P
0 g
s
.65 .757 .928 r
.32458 .63263 m .33323 .62992 L .33049 .6274 L p F P
0 g
s
.651 .758 .928 r
.60291 .63266 m .61202 .62994 L .61431 .63245 L p F P
0 g
s
.651 .758 .928 r
.61202 .62994 m .60291 .63266 L .6006 .63015 L p F P
0 g
s
.65 .757 .928 r
.46374 .63266 m .47262 .62995 L .47513 .63246 L p F P
0 g
s
.65 .757 .928 r
.47262 .62995 m .46374 .63266 L .46122 .63016 L p F P
0 g
s
.651 .759 .928 r
.89265 .63223 m .90225 .62949 L .90409 .63199 L p F P
0 g
s
.651 .758 .928 r
.90225 .62949 m .89265 .63223 L .89079 .62973 L p F P
0 g
s
.65 .757 .928 r
.20227 .62708 m .19384 .62979 L .19679 .63231 L p F P
0 g
s
.65 .757 .928 r
.19679 .63231 m .20521 .6296 L .20227 .62708 L p F P
0 g
s
.651 .758 .928 r
.75349 .63241 m .76286 .62969 L .76492 .63219 L p F P
0 g
s
.651 .758 .928 r
.76286 .62969 m .75349 .63241 L .75141 .6299 L p F P
0 g
s
.65 .757 .928 r
.3419 .62719 m .33323 .62992 L .33595 .63243 L p F P
0 g
s
.65 .757 .928 r
.33595 .63243 m .34462 .62971 L .3419 .62719 L p F P
0 g
s
.651 .758 .928 r
.61431 .63245 m .62345 .62973 L .62572 .63224 L p F P
0 g
s
.651 .758 .928 r
.62345 .62973 m .61431 .63245 L .61202 .62994 L p F P
0 g
s
.65 .757 .928 r
.47513 .63246 m .48403 .62974 L .48652 .63225 L p F P
0 g
s
.65 .757 .928 r
.48403 .62974 m .47513 .63246 L .47262 .62995 L p F P
0 g
s
.651 .759 .928 r
.90409 .63199 m .91371 .62925 L .91553 .63175 L p F P
0 g
s
.651 .759 .928 r
.91371 .62925 m .90409 .63199 L .90225 .62949 L p F P
0 g
s
.65 .757 .928 r
.21367 .62689 m .20521 .6296 L .20814 .63212 L p F P
0 g
s
.65 .757 .928 r
.20814 .63212 m .21659 .62941 L .21367 .62689 L p F P
0 g
s
.651 .758 .928 r
.76492 .63219 m .7743 .62947 L .77635 .63198 L p F P
0 g
s
.651 .758 .928 r
.7743 .62947 m .76492 .63219 L .76286 .62969 L p F P
0 g
s
.65 .757 .928 r
.35331 .62699 m .34462 .62971 L .34733 .63222 L p F P
0 g
s
.65 .757 .928 r
.34733 .63222 m .35601 .62951 L .35331 .62699 L p F P
0 g
s
.651 .758 .928 r
.62572 .63224 m .63487 .62952 L .63713 .63203 L p F P
0 g
s
.651 .758 .928 r
.63487 .62952 m .62572 .63224 L .62345 .62973 L p F P
0 g
s
0 0 .35 r
.52577 .54154 m .52577 .54155 L .52577 .53743 L p F P
0 g
s
0 0 .35 r
.52577 .53743 m .52577 .53742 L .52577 .54154 L p F P
0 g
s
.761 .499 .538 r
.52575 .54154 m .52577 .54155 L .52577 .53743 L p F P
0 g
s
.761 .499 .538 r
.52577 .53743 m .52575 .53743 L .52575 .54154 L p F P
0 g
s
.65 .757 .928 r
.49544 .62953 m .48652 .63225 L .48403 .62974 L p F P
0 g
s
.65 .757 .928 r
.48652 .63225 m .49544 .62953 L .49792 .63204 L p F P
0 g
s
0 0 .35 r
.52575 .53742 m .52575 .53743 L .52575 .54154 L p F P
0 g
s
.761 .5 .539 r
.52575 .53742 m .52577 .53742 L .52577 .54154 L p F P
0 g
s
.761 .5 .539 r
.52577 .54154 m .52575 .54153 L .52575 .53742 L p F P
0 g
s
0 0 .35 r
.52575 .54154 m .52575 .54153 L .52575 .53742 L p F P
0 g
s
.652 .759 .928 r
.91553 .63175 m .92517 .62901 L .92698 .63151 L p F P
0 g
s
.652 .759 .928 r
.92517 .62901 m .91553 .63175 L .91371 .62925 L p F P
0 g
s
.65 .757 .928 r
.22506 .62669 m .21659 .62941 L .2195 .63192 L p F P
0 g
s
.65 .757 .928 r
.2195 .63192 m .22796 .62921 L .22506 .62669 L p F P
0 g
s
.651 .758 .928 r
.77635 .63198 m .78575 .62925 L .78778 .63176 L p F P
0 g
s
.651 .758 .928 r
.78575 .62925 m .77635 .63198 L .7743 .62947 L p F P
0 g
s
.65 .757 .928 r
.36472 .62678 m .35601 .62951 L .3587 .63202 L p F P
0 g
s
.65 .757 .928 r
.3587 .63202 m .3674 .6293 L .36472 .62678 L p F P
0 g
s
.651 .758 .928 r
.63713 .63203 m .64631 .62931 L .64855 .63182 L p F P
0 g
s
.651 .758 .928 r
.64631 .62931 m .63713 .63203 L .63487 .62952 L p F P
0 g
s
.65 .757 .928 r
.49792 .63204 m .50686 .62932 L .50931 .63183 L p F P
0 g
s
.65 .757 .928 r
.50686 .62932 m .49792 .63204 L .49544 .62953 L p F P
0 g
s
.65 .757 .928 r
.23646 .62649 m .22796 .62921 L .23085 .63173 L p F P
0 g
s
.65 .757 .928 r
.23085 .63173 m .23934 .62902 L .23646 .62649 L p F P
0 g
s
.651 .758 .928 r
.78778 .63176 m .79721 .62903 L .79921 .63154 L p F P
0 g
s
.651 .758 .928 r
.79721 .62903 m .78778 .63176 L .78575 .62925 L p F P
0 g
s
.65 .757 .928 r
.37614 .62657 m .3674 .6293 L .37008 .63181 L p F P
0 g
s
.65 .757 .928 r
.37008 .63181 m .3788 .62909 L .37614 .62657 L p F P
0 g
s
.651 .758 .928 r
.64855 .63182 m .65774 .6291 L .65997 .63161 L p F P
0 g
s
.651 .758 .928 r
.65774 .6291 m .64855 .63182 L .64631 .62931 L p F P
0 g
s
.65 .757 .928 r
.50931 .63183 m .51827 .62911 L .52071 .63162 L p F P
0 g
s
.65 .757 .928 r
.51827 .62911 m .50931 .63183 L .50686 .62932 L p F P
0 g
s
.65 .757 .928 r
.24786 .6263 m .23934 .62902 L .24222 .63153 L p F P
0 g
s
.65 .757 .928 r
.24222 .63153 m .25072 .62882 L .24786 .6263 L p F P
0 g
s
.651 .758 .928 r
.79921 .63154 m .80866 .62881 L .81065 .63132 L p F P
0 g
s
.651 .758 .928 r
.80866 .62881 m .79921 .63154 L .79721 .62903 L p F P
0 g
s
.65 .757 .928 r
.38756 .62637 m .3788 .62909 L .38146 .63161 L p F P
0 g
s
.65 .757 .928 r
.38146 .63161 m .39021 .62889 L .38756 .62637 L p F P
0 g
s
.651 .758 .928 r
.65997 .63161 m .66918 .62889 L .67139 .6314 L p F P
0 g
s
.651 .758 .928 r
.66918 .62889 m .65997 .63161 L .65774 .6291 L p F P
0 g
s
.65 .758 .928 r
.52071 .63162 m .52969 .6289 L .53212 .63141 L p F P
0 g
s
.65 .758 .928 r
.52969 .6289 m .52071 .63162 L .51827 .62911 L p F P
0 g
s
.651 .758 .928 r
.81065 .63132 m .82012 .62859 L .82209 .6311 L p F P
0 g
s
.651 .758 .928 r
.82012 .62859 m .81065 .63132 L .80866 .62881 L p F P
0 g
s
.65 .757 .928 r
.25926 .6261 m .25072 .62882 L .25358 .63133 L p F P
0 g
s
.65 .757 .928 r
.25358 .63133 m .26211 .62862 L .25926 .6261 L p F P
0 g
s
.651 .758 .928 r
.67139 .6314 m .68062 .62867 L .68281 .63119 L p F P
0 g
s
.651 .758 .928 r
.68062 .62867 m .67139 .6314 L .66918 .62889 L p F P
0 g
s
.65 .757 .928 r
.39898 .62616 m .39021 .62889 L .39285 .6314 L p F P
0 g
s
.65 .757 .928 r
.39285 .6314 m .40161 .62868 L .39898 .62616 L p F P
0 g
s
.65 .758 .928 r
.53212 .63141 m .54112 .62869 L .54352 .63121 L p F P
0 g
s
.65 .758 .928 r
.54112 .62869 m .53212 .63141 L .52969 .6289 L p F P
0 g
s
.651 .758 .928 r
.82209 .6311 m .83158 .62837 L .83353 .63088 L p F P
0 g
s
.651 .758 .928 r
.83158 .62837 m .82209 .6311 L .82012 .62859 L p F P
0 g
s
.65 .757 .928 r
.27067 .62589 m .26211 .62862 L .26495 .63113 L p F P
0 g
s
.65 .757 .928 r
.26495 .63113 m .2735 .62842 L .27067 .62589 L p F P
0 g
s
.651 .758 .928 r
.69207 .62846 m .68281 .63119 L .68062 .62867 L p F P
0 g
s
.651 .758 .928 r
.68281 .63119 m .69207 .62846 L .69424 .63097 L p F P
0 g
s
.65 .757 .928 r
.4104 .62595 m .40161 .62868 L .40423 .63119 L p F P
0 g
s
.65 .757 .928 r
.40423 .63119 m .41302 .62847 L .4104 .62595 L p F P
0 g
s
.65 .758 .928 r
.54352 .63121 m .55254 .62848 L .55493 .631 L p F P
0 g
s
.65 .758 .928 r
.55254 .62848 m .54352 .63121 L .54112 .62869 L p F P
0 g
s
.651 .758 .928 r
.83353 .63088 m .84304 .62814 L .84498 .63065 L p F P
0 g
s
.651 .758 .928 r
.84304 .62814 m .83353 .63088 L .83158 .62837 L p F P
0 g
s
.65 .757 .928 r
.28207 .62569 m .2735 .62842 L .27632 .63093 L p F P
0 g
s
.65 .757 .928 r
.27632 .63093 m .28489 .62822 L .28207 .62569 L p F P
0 g
s
.651 .758 .928 r
.69424 .63097 m .70351 .62825 L .70567 .63076 L p F P
0 g
s
.651 .758 .928 r
.70351 .62825 m .69424 .63097 L .69207 .62846 L p F P
0 g
s
.65 .757 .928 r
.42183 .62574 m .41302 .62847 L .41562 .63099 L p F P
0 g
s
.65 .757 .928 r
.41562 .63099 m .42443 .62826 L .42183 .62574 L p F P
0 g
s
.651 .758 .928 r
.55493 .631 m .56397 .62827 L .56634 .63079 L p F P
0 g
s
.651 .758 .928 r
.56397 .62827 m .55493 .631 L .55254 .62848 L p F P
0 g
s
.651 .758 .928 r
.84498 .63065 m .85451 .62791 L .85643 .63042 L p F P
0 g
s
.651 .758 .928 r
.85451 .62791 m .84498 .63065 L .84304 .62814 L p F P
0 g
s
.65 .757 .928 r
.29349 .62549 m .28489 .62822 L .2877 .63073 L p F P
0 g
s
.65 .757 .928 r
.2877 .63073 m .29629 .62801 L .29349 .62549 L p F P
0 g
s
.651 .758 .928 r
.70567 .63076 m .71496 .62803 L .7171 .63055 L p F P
0 g
s
.651 .758 .928 r
.71496 .62803 m .70567 .63076 L .70351 .62825 L p F P
0 g
s
.65 .757 .928 r
.42702 .63078 m .43584 .62806 L .43841 .63057 L p F P
0 g
s
.65 .757 .928 r
.43326 .62553 m .42443 .62826 L .42702 .63078 L p F P
0 g
s
.65 .757 .928 r
.42702 .63078 m .43584 .62806 L .43326 .62553 L p F P
0 g
s
.651 .758 .928 r
.56634 .63079 m .5754 .62806 L .57776 .63058 L p F P
0 g
s
.651 .758 .928 r
.5754 .62806 m .56634 .63079 L .56397 .62827 L p F P
0 g
s
.651 .758 .928 r
.85643 .63042 m .86598 .62768 L .86788 .6302 L p F P
0 g
s
.651 .758 .928 r
.86598 .62768 m .85643 .63042 L .85451 .62791 L p F P
0 g
s
.65 .757 .928 r
.3049 .62528 m .29629 .62801 L .29907 .63053 L p F P
0 g
s
.65 .757 .928 r
.29907 .63053 m .30768 .62781 L .3049 .62528 L p F P
0 g
s
.651 .758 .928 r
.7171 .63055 m .72642 .62782 L .72853 .63033 L p F P
0 g
s
.651 .758 .928 r
.72642 .62782 m .7171 .63055 L .71496 .62803 L p F P
0 g
s
.65 .757 .928 r
.43841 .63057 m .44726 .62785 L .44981 .63036 L p F P
0 g
s
.65 .757 .928 r
.44726 .62785 m .43841 .63057 L .43584 .62806 L p F P
0 g
s
.651 .758 .928 r
.57776 .63058 m .58684 .62785 L .58917 .63037 L p F P
0 g
s
.651 .758 .928 r
.58684 .62785 m .57776 .63058 L .5754 .62806 L p F P
0 g
s
.651 .758 .928 r
.86788 .6302 m .87745 .62745 L .87933 .62996 L p F P
0 g
s
.651 .758 .928 r
.87745 .62745 m .86788 .6302 L .86598 .62768 L p F P
0 g
s
.65 .757 .928 r
.31632 .62508 m .30768 .62781 L .31046 .63033 L p F P
0 g
s
.65 .757 .928 r
.31046 .63033 m .31908 .62761 L .31632 .62508 L p F P
0 g
s
.651 .758 .928 r
.72853 .63033 m .73787 .6276 L .73997 .63012 L p F P
0 g
s
.651 .758 .928 r
.73787 .6276 m .72853 .63033 L .72642 .62782 L p F P
0 g
s
.65 .757 .928 r
.44981 .63036 m .45868 .62764 L .46122 .63016 L p F P
0 g
s
.65 .757 .928 r
.45868 .62764 m .44981 .63036 L .44726 .62785 L p F P
0 g
s
.651 .758 .928 r
.58917 .63037 m .59828 .62764 L .6006 .63015 L p F P
0 g
s
.651 .758 .928 r
.59828 .62764 m .58917 .63037 L .58684 .62785 L p F P
0 g
s
.651 .758 .928 r
.87933 .62996 m .88892 .62722 L .89079 .62973 L p F P
0 g
s
.651 .758 .928 r
.88892 .62722 m .87933 .62996 L .87745 .62745 L p F P
0 g
s
.65 .757 .928 r
.18792 .62475 m .1795 .62746 L .18248 .62998 L p F P
0 g
s
.65 .757 .928 r
.18248 .62998 m .19089 .62727 L .18792 .62475 L p F P
0 g
s
.651 .758 .928 r
.73997 .63012 m .74933 .62739 L .75141 .6299 L p F P
0 g
s
.651 .758 .928 r
.74933 .62739 m .73997 .63012 L .73787 .6276 L p F P
0 g
s
.65 .757 .928 r
.32774 .62487 m .31908 .62761 L .32184 .63012 L p F P
0 g
s
.65 .757 .928 r
.32184 .63012 m .33049 .6274 L .32774 .62487 L p F P
0 g
s
.651 .758 .928 r
.6006 .63015 m .60972 .62743 L .61202 .62994 L p F P
0 g
s
.651 .758 .928 r
.60972 .62743 m .6006 .63015 L .59828 .62764 L p F P
0 g
s
0 0 .351 r
.52577 .54566 m .52577 .54567 L .52577 .54155 L p F P
0 g
s
0 0 .351 r
.52577 .54155 m .52577 .54154 L .52577 .54566 L p F P
0 g
s
.76 .499 .539 r
.52575 .54567 m .52577 .54567 L .52577 .54155 L p F P
0 g
s
.76 .499 .539 r
.52577 .54155 m .52575 .54154 L .52575 .54567 L p F P
0 g
s
.65 .757 .928 r
.46122 .63016 m .4701 .62743 L .47262 .62995 L p F P
0 g
s
.65 .757 .928 r
.4701 .62743 m .46122 .63016 L .45868 .62764 L p F P
0 g
s
0 0 .351 r
.52575 .54153 m .52575 .54154 L .52575 .54567 L p F P
0 g
s
.76 .499 .539 r
.52575 .54153 m .52577 .54154 L .52577 .54566 L p F P
0 g
s
.76 .499 .539 r
.52577 .54566 m .52575 .54566 L .52575 .54153 L p F P
0 g
s
0 0 .351 r
.52575 .54567 m .52575 .54566 L .52575 .54153 L p F P
0 g
s
.651 .758 .928 r
.89079 .62973 m .9004 .62698 L .90225 .62949 L p F P
0 g
s
.651 .758 .928 r
.9004 .62698 m .89079 .62973 L .88892 .62722 L p F P
0 g
s
.65 .757 .928 r
.19933 .62455 m .19089 .62727 L .19384 .62979 L p F P
0 g
s
.65 .757 .928 r
.19384 .62979 m .20227 .62708 L .19933 .62455 L p F P
0 g
s
.651 .758 .928 r
.75141 .6299 m .76079 .62717 L .76286 .62969 L p F P
0 g
s
.651 .758 .928 r
.76079 .62717 m .75141 .6299 L .74933 .62739 L p F P
0 g
s
.65 .757 .928 r
.33917 .62467 m .33049 .6274 L .33323 .62992 L p F P
0 g
s
.65 .757 .928 r
.33323 .62992 m .3419 .62719 L .33917 .62467 L p F P
0 g
s
.651 .758 .928 r
.61202 .62994 m .62116 .62722 L .62345 .62973 L p F P
0 g
s
.651 .758 .928 r
.62116 .62722 m .61202 .62994 L .60972 .62743 L p F P
0 g
s
.65 .757 .928 r
.47262 .62995 m .48153 .62722 L .48403 .62974 L p F P
0 g
s
.65 .757 .928 r
.48153 .62722 m .47262 .62995 L .4701 .62743 L p F P
0 g
s
.651 .759 .928 r
.90225 .62949 m .91188 .62674 L .91371 .62925 L p F P
0 g
s
.651 .759 .928 r
.91188 .62674 m .90225 .62949 L .9004 .62698 L p F P
0 g
s
.65 .757 .928 r
.21074 .62436 m .20227 .62708 L .20521 .6296 L p F P
0 g
s
.65 .757 .928 r
.20521 .6296 m .21367 .62689 L .21074 .62436 L p F P
0 g
s
.651 .758 .928 r
.76286 .62969 m .77226 .62695 L .7743 .62947 L p F P
0 g
s
.651 .758 .928 r
.77226 .62695 m .76286 .62969 L .76079 .62717 L p F P
0 g
s
.65 .757 .928 r
.3506 .62446 m .3419 .62719 L .34462 .62971 L p F P
0 g
s
.65 .757 .928 r
.34462 .62971 m .35331 .62699 L .3506 .62446 L p F P
0 g
s
.651 .758 .928 r
.62345 .62973 m .63261 .627 L .63487 .62952 L p F P
0 g
s
.651 .758 .928 r
.63261 .627 m .62345 .62973 L .62116 .62722 L p F P
0 g
s
.65 .757 .928 r
.48403 .62974 m .49296 .62701 L .49544 .62953 L p F P
0 g
s
.65 .757 .928 r
.49296 .62701 m .48403 .62974 L .48153 .62722 L p F P
0 g
s
.652 .759 .928 r
.91371 .62925 m .92336 .6265 L .92517 .62901 L p F P
0 g
s
.652 .759 .928 r
.92336 .6265 m .91371 .62925 L .91188 .62674 L p F P
0 g
s
.65 .757 .928 r
.22215 .62416 m .21367 .62689 L .21659 .62941 L p F P
0 g
s
.65 .757 .928 r
.21659 .62941 m .22506 .62669 L .22215 .62416 L p F P
0 g
s
.651 .758 .928 r
.7743 .62947 m .78372 .62673 L .78575 .62925 L p F P
0 g
s
.651 .758 .928 r
.78372 .62673 m .7743 .62947 L .77226 .62695 L p F P
0 g
s
.65 .757 .928 r
.36203 .62425 m .35331 .62699 L .35601 .62951 L p F P
0 g
s
.65 .757 .928 r
.35601 .62951 m .36472 .62678 L .36203 .62425 L p F P
0 g
s
.651 .758 .928 r
.63487 .62952 m .64406 .62679 L .64631 .62931 L p F P
0 g
s
.651 .758 .928 r
.64406 .62679 m .63487 .62952 L .63261 .627 L p F P
0 g
s
.65 .757 .928 r
.49544 .62953 m .50439 .6268 L .50686 .62932 L p F P
0 g
s
.65 .757 .928 r
.50439 .6268 m .49544 .62953 L .49296 .62701 L p F P
0 g
s
.65 .757 .928 r
.23356 .62396 m .22506 .62669 L .22796 .62921 L p F P
0 g
s
.65 .757 .928 r
.22796 .62921 m .23646 .62649 L .23356 .62396 L p F P
0 g
s
.651 .758 .928 r
.78575 .62925 m .79519 .62651 L .79721 .62903 L p F P
0 g
s
.651 .758 .928 r
.79519 .62651 m .78575 .62925 L .78372 .62673 L p F P
0 g
s
.65 .757 .928 r
.37346 .62405 m .36472 .62678 L .3674 .6293 L p F P
0 g
s
.65 .757 .928 r
.3674 .6293 m .37614 .62657 L .37346 .62405 L p F P
0 g
s
.651 .758 .928 r
.64631 .62931 m .65551 .62658 L .65774 .6291 L p F P
0 g
s
.651 .758 .928 r
.65551 .62658 m .64631 .62931 L .64406 .62679 L p F P
0 g
s
.65 .757 .928 r
.50686 .62932 m .51582 .62659 L .51827 .62911 L p F P
0 g
s
.65 .757 .928 r
.51582 .62659 m .50686 .62932 L .50439 .6268 L p F P
0 g
s
.65 .757 .928 r
.24498 .62377 m .23646 .62649 L .23934 .62902 L p F P
0 g
s
.65 .757 .928 r
.23934 .62902 m .24786 .6263 L .24498 .62377 L p F P
0 g
s
.651 .758 .928 r
.79721 .62903 m .80667 .62629 L .80866 .62881 L p F P
0 g
s
.651 .758 .928 r
.80667 .62629 m .79721 .62903 L .79519 .62651 L p F P
0 g
s
.65 .757 .928 r
.3849 .62384 m .37614 .62657 L .3788 .62909 L p F P
0 g
s
.65 .757 .928 r
.3788 .62909 m .38756 .62637 L .3849 .62384 L p F P
0 g
s
.651 .758 .928 r
.65774 .6291 m .66697 .62637 L .66918 .62889 L p F P
0 g
s
.651 .758 .928 r
.66697 .62637 m .65774 .6291 L .65551 .62658 L p F P
0 g
s
.65 .758 .928 r
.51827 .62911 m .52726 .62638 L .52969 .6289 L p F P
0 g
s
.65 .758 .928 r
.52726 .62638 m .51827 .62911 L .51582 .62659 L p F P
0 g
s
.651 .758 .928 r
.80866 .62881 m .81814 .62607 L .82012 .62859 L p F P
0 g
s
.651 .758 .928 r
.81814 .62607 m .80866 .62881 L .80667 .62629 L p F P
0 g
s
.65 .757 .928 r
.2564 .62356 m .24786 .6263 L .25072 .62882 L p F P
0 g
s
.65 .757 .928 r
.25072 .62882 m .25926 .6261 L .2564 .62356 L p F P
0 g
s
.651 .758 .928 r
.66918 .62889 m .67843 .62615 L .68062 .62867 L p F P
0 g
s
.651 .758 .928 r
.67843 .62615 m .66918 .62889 L .66697 .62637 L p F P
0 g
s
.65 .757 .928 r
.39634 .62363 m .38756 .62637 L .39021 .62889 L p F P
0 g
s
.65 .757 .928 r
.39021 .62889 m .39898 .62616 L .39634 .62363 L p F P
0 g
s
.65 .758 .928 r
.52969 .6289 m .5387 .62617 L .54112 .62869 L p F P
0 g
s
.65 .758 .928 r
.5387 .62617 m .52969 .6289 L .52726 .62638 L p F P
0 g
s
.651 .758 .928 r
.82012 .62859 m .82962 .62585 L .83158 .62837 L p F P
0 g
s
.651 .758 .928 r
.82962 .62585 m .82012 .62859 L .81814 .62607 L p F P
0 g
s
.65 .757 .928 r
.26782 .62336 m .25926 .6261 L .26211 .62862 L p F P
0 g
s
.65 .757 .928 r
.26211 .62862 m .27067 .62589 L .26782 .62336 L p F P
0 g
s
.651 .758 .928 r
.68062 .62867 m .68989 .62594 L .69207 .62846 L p F P
0 g
s
.651 .758 .928 r
.68989 .62594 m .68062 .62867 L .67843 .62615 L p F P
0 g
s
.65 .757 .928 r
.40778 .62342 m .39898 .62616 L .40161 .62868 L p F P
0 g
s
.65 .757 .928 r
.40161 .62868 m .4104 .62595 L .40778 .62342 L p F P
0 g
s
.65 .758 .928 r
.54112 .62869 m .55015 .62596 L .55254 .62848 L p F P
0 g
s
.65 .758 .928 r
.55015 .62596 m .54112 .62869 L .5387 .62617 L p F P
0 g
s
.651 .758 .928 r
.83158 .62837 m .8411 .62562 L .84304 .62814 L p F P
0 g
s
.651 .758 .928 r
.8411 .62562 m .83158 .62837 L .82962 .62585 L p F P
0 g
s
.65 .757 .928 r
.27925 .62316 m .27067 .62589 L .2735 .62842 L p F P
0 g
s
.65 .757 .928 r
.2735 .62842 m .28207 .62569 L .27925 .62316 L p F P
0 g
s
.651 .758 .928 r
.70135 .62572 m .69207 .62846 L .68989 .62594 L p F P
0 g
s
.651 .758 .928 r
.69207 .62846 m .70135 .62572 L .70351 .62825 L p F P
0 g
s
.65 .757 .928 r
.41923 .62321 m .4104 .62595 L .41302 .62847 L p F P
0 g
s
.65 .757 .928 r
.41302 .62847 m .42183 .62574 L .41923 .62321 L p F P
0 g
s
.651 .758 .928 r
.55254 .62848 m .56159 .62575 L .56397 .62827 L p F P
0 g
s
.651 .758 .928 r
.56159 .62575 m .55254 .62848 L .55015 .62596 L p F P
0 g
s
.651 .758 .928 r
.84304 .62814 m .85259 .62539 L .85451 .62791 L p F P
0 g
s
.651 .758 .928 r
.85259 .62539 m .84304 .62814 L .8411 .62562 L p F P
0 g
s
.65 .757 .928 r
.29068 .62296 m .28207 .62569 L .28489 .62822 L p F P
0 g
s
.65 .757 .928 r
.28489 .62822 m .29349 .62549 L .29068 .62296 L p F P
0 g
s
.651 .758 .928 r
.70351 .62825 m .71282 .62551 L .71496 .62803 L p F P
0 g
s
.651 .758 .928 r
.71282 .62551 m .70351 .62825 L .70135 .62572 L p F P
0 g
s
.65 .757 .928 r
.43067 .623 m .42183 .62574 L .42443 .62826 L p F P
0 g
s
.65 .757 .928 r
.42443 .62826 m .43326 .62553 L .43067 .623 L p F P
0 g
s
.651 .758 .928 r
.56397 .62827 m .57304 .62554 L .5754 .62806 L p F P
0 g
s
.651 .758 .928 r
.57304 .62554 m .56397 .62827 L .56159 .62575 L p F P
0 g
s
.651 .758 .928 r
.85451 .62791 m .86407 .62517 L .86598 .62768 L p F P
0 g
s
.651 .758 .928 r
.86407 .62517 m .85451 .62791 L .85259 .62539 L p F P
0 g
s
.65 .757 .928 r
.30211 .62275 m .29349 .62549 L .29629 .62801 L p F P
0 g
s
.65 .757 .928 r
.29629 .62801 m .3049 .62528 L .30211 .62275 L p F P
0 g
s
.651 .758 .928 r
.71496 .62803 m .72429 .6253 L .72642 .62782 L p F P
0 g
s
.651 .758 .928 r
.72429 .6253 m .71496 .62803 L .71282 .62551 L p F P
0 g
s
.65 .757 .928 r
.43584 .62806 m .4447 .62532 L .44726 .62785 L p F P
0 g
s
.65 .757 .928 r
.44213 .62279 m .43326 .62553 L .43584 .62806 L p F P
0 g
s
.65 .757 .928 r
.43584 .62806 m .4447 .62532 L .44213 .62279 L p F P
0 g
s
0 0 .351 r
.52577 .5498 m .52577 .54981 L .52577 .54567 L p F P
0 g
s
0 0 .351 r
.52577 .54567 m .52577 .54566 L .52577 .5498 L p F P
0 g
s
.76 .499 .539 r
.52575 .54981 m .52577 .54981 L .52577 .54567 L p F P
0 g
s
.76 .499 .539 r
.52577 .54567 m .52575 .54567 L .52575 .54981 L p F P
0 g
s
.651 .758 .928 r
.5754 .62806 m .58449 .62533 L .58684 .62785 L p F P
0 g
s
.651 .758 .928 r
.58449 .62533 m .5754 .62806 L .57304 .62554 L p F P
0 g
s
0 0 .351 r
.52575 .54566 m .52575 .54567 L .52575 .54981 L p F P
0 g
s
.76 .499 .539 r
.52575 .54566 m .52577 .54566 L .52577 .5498 L p F P
0 g
s
.76 .499 .539 r
.52577 .5498 m .52576 .5498 L .52575 .54566 L p F P
0 g
s
0 0 .351 r
.52575 .54981 m .52576 .5498 L .52575 .54566 L p F P
0 g
s
.651 .758 .928 r
.86598 .62768 m .87556 .62493 L .87745 .62745 L p F P
0 g
s
.651 .758 .928 r
.87556 .62493 m .86598 .62768 L .86407 .62517 L p F P
0 g
s
.65 .757 .928 r
.31355 .62255 m .3049 .62528 L .30768 .62781 L p F P
0 g
s
.65 .757 .928 r
.30768 .62781 m .31632 .62508 L .31355 .62255 L p F P
0 g
s
.651 .758 .928 r
.72642 .62782 m .73576 .62508 L .73787 .6276 L p F P
0 g
s
.651 .758 .928 r
.73576 .62508 m .72642 .62782 L .72429 .6253 L p F P
0 g
s
.65 .757 .928 r
.44726 .62785 m .45613 .62511 L .45868 .62764 L p F P
0 g
s
.65 .757 .928 r
.45613 .62511 m .44726 .62785 L .4447 .62532 L p F P
0 g
s
.651 .758 .928 r
.58684 .62785 m .59595 .62511 L .59828 .62764 L p F P
0 g
s
.651 .758 .928 r
.59595 .62511 m .58684 .62785 L .58449 .62533 L p F P
0 g
s
.651 .758 .928 r
.87745 .62745 m .88705 .6247 L .88892 .62722 L p F P
0 g
s
.651 .758 .928 r
.88705 .6247 m .87745 .62745 L .87556 .62493 L p F P
0 g
s
.65 .757 .928 r
.18495 .62221 m .17652 .62493 L .1795 .62746 L p F P
0 g
s
.65 .757 .928 r
.1795 .62746 m .18792 .62475 L .18495 .62221 L p F P
0 g
s
.651 .758 .928 r
.73787 .6276 m .74724 .62486 L .74933 .62739 L p F P
0 g
s
.651 .758 .928 r
.74724 .62486 m .73787 .6276 L .73576 .62508 L p F P
0 g
s
.65 .757 .928 r
.32499 .62234 m .31632 .62508 L .31908 .62761 L p F P
0 g
s
.65 .757 .928 r
.31908 .62761 m .32774 .62487 L .32499 .62234 L p F P
0 g
s
.651 .758 .928 r
.59828 .62764 m .60741 .6249 L .60972 .62743 L p F P
0 g
s
.651 .758 .928 r
.60741 .6249 m .59828 .62764 L .59595 .62511 L p F P
0 g
s
.65 .757 .928 r
.45868 .62764 m .46757 .6249 L .4701 .62743 L p F P
0 g
s
.65 .757 .928 r
.46757 .6249 m .45868 .62764 L .45613 .62511 L p F P
0 g
s
.651 .758 .928 r
.88892 .62722 m .89855 .62446 L .9004 .62698 L p F P
0 g
s
.651 .758 .928 r
.89855 .62446 m .88892 .62722 L .88705 .6247 L p F P
0 g
s
.65 .757 .928 r
.19637 .62202 m .18792 .62475 L .19089 .62727 L p F P
0 g
s
.65 .757 .928 r
.19089 .62727 m .19933 .62455 L .19637 .62202 L p F P
0 g
s
.651 .758 .928 r
.74933 .62739 m .75872 .62465 L .76079 .62717 L p F P
0 g
s
.651 .758 .928 r
.75872 .62465 m .74933 .62739 L .74724 .62486 L p F P
0 g
s
.65 .757 .928 r
.33643 .62213 m .32774 .62487 L .33049 .6274 L p F P
0 g
s
.65 .757 .928 r
.33049 .6274 m .33917 .62467 L .33643 .62213 L p F P
0 g
s
.651 .758 .928 r
.60972 .62743 m .61887 .62469 L .62116 .62722 L p F P
0 g
s
.651 .758 .928 r
.61887 .62469 m .60972 .62743 L .60741 .6249 L p F P
0 g
s
.65 .757 .928 r
.4701 .62743 m .47902 .62469 L .48153 .62722 L p F P
0 g
s
.65 .757 .928 r
.47902 .62469 m .4701 .62743 L .46757 .6249 L p F P
0 g
s
.651 .759 .928 r
.9004 .62698 m .91004 .62422 L .91188 .62674 L p F P
0 g
s
.651 .759 .928 r
.91004 .62422 m .9004 .62698 L .89855 .62446 L p F P
0 g
s
.65 .757 .928 r
.2078 .62182 m .19933 .62455 L .20227 .62708 L p F P
0 g
s
.65 .757 .928 r
.20227 .62708 m .21074 .62436 L .2078 .62182 L p F P
0 g
s
.651 .758 .928 r
.76079 .62717 m .7702 .62443 L .77226 .62695 L p F P
0 g
s
.651 .758 .928 r
.7702 .62443 m .76079 .62717 L .75872 .62465 L p F P
0 g
s
.65 .757 .928 r
.34788 .62193 m .33917 .62467 L .3419 .62719 L p F P
0 g
s
.65 .757 .928 r
.3419 .62719 m .3506 .62446 L .34788 .62193 L p F P
0 g
s
.651 .758 .928 r
.62116 .62722 m .63033 .62448 L .63261 .627 L p F P
0 g
s
.651 .758 .928 r
.63033 .62448 m .62116 .62722 L .61887 .62469 L p F P
0 g
s
.65 .757 .928 r
.48153 .62722 m .49046 .62448 L .49296 .62701 L p F P
0 g
s
.65 .757 .928 r
.49046 .62448 m .48153 .62722 L .47902 .62469 L p F P
0 g
s
.652 .759 .928 r
.91188 .62674 m .92154 .62398 L .92336 .6265 L p F P
0 g
s
.652 .759 .928 r
.92154 .62398 m .91188 .62674 L .91004 .62422 L p F P
0 g
s
.65 .757 .928 r
.21923 .62162 m .21074 .62436 L .21367 .62689 L p F P
0 g
s
.65 .757 .928 r
.21367 .62689 m .22215 .62416 L .21923 .62162 L p F P
0 g
s
.651 .758 .928 r
.77226 .62695 m .78169 .62421 L .78372 .62673 L p F P
0 g
s
.651 .758 .928 r
.78169 .62421 m .77226 .62695 L .7702 .62443 L p F P
0 g
s
.65 .757 .928 r
.35932 .62172 m .3506 .62446 L .35331 .62699 L p F P
0 g
s
.65 .757 .928 r
.35331 .62699 m .36203 .62425 L .35932 .62172 L p F P
0 g
s
.651 .758 .928 r
.63261 .627 m .6418 .62426 L .64406 .62679 L p F P
0 g
s
.651 .758 .928 r
.6418 .62426 m .63261 .627 L .63033 .62448 L p F P
0 g
s
.65 .757 .928 r
.49296 .62701 m .50191 .62427 L .50439 .6268 L p F P
0 g
s
.65 .757 .928 r
.50191 .62427 m .49296 .62701 L .49046 .62448 L p F P
0 g
s
.65 .757 .928 r
.23066 .62143 m .22215 .62416 L .22506 .62669 L p F P
0 g
s
.65 .757 .928 r
.22506 .62669 m .23356 .62396 L .23066 .62143 L p F P
0 g
s
.651 .758 .928 r
.78372 .62673 m .79317 .62399 L .79519 .62651 L p F P
0 g
s
.651 .758 .928 r
.79317 .62399 m .78372 .62673 L .78169 .62421 L p F P
0 g
s
.65 .757 .928 r
.37078 .62151 m .36203 .62425 L .36472 .62678 L p F P
0 g
s
.65 .757 .928 r
.36472 .62678 m .37346 .62405 L .37078 .62151 L p F P
0 g
s
.651 .758 .928 r
.64406 .62679 m .65327 .62405 L .65551 .62658 L p F P
0 g
s
.651 .758 .928 r
.65327 .62405 m .64406 .62679 L .6418 .62426 L p F P
0 g
s
.65 .757 .928 r
.50439 .6268 m .51337 .62406 L .51582 .62659 L p F P
0 g
s
.65 .757 .928 r
.51337 .62406 m .50439 .6268 L .50191 .62427 L p F P
0 g
s
.65 .757 .928 r
.24209 .62123 m .23356 .62396 L .23646 .62649 L p F P
0 g
s
.65 .757 .928 r
.23646 .62649 m .24498 .62377 L .24209 .62123 L p F P
0 g
s
.651 .758 .928 r
.79519 .62651 m .80466 .62377 L .80667 .62629 L p F P
0 g
s
.651 .758 .928 r
.80466 .62377 m .79519 .62651 L .79317 .62399 L p F P
0 g
s
.65 .757 .928 r
.38223 .6213 m .37346 .62405 L .37614 .62657 L p F P
0 g
s
.65 .757 .928 r
.37614 .62657 m .3849 .62384 L .38223 .6213 L p F P
0 g
s
.651 .758 .928 r
.65551 .62658 m .66475 .62384 L .66697 .62637 L p F P
0 g
s
.651 .758 .928 r
.66475 .62384 m .65551 .62658 L .65327 .62405 L p F P
0 g
s
.65 .758 .928 r
.51582 .62659 m .52482 .62385 L .52726 .62638 L p F P
0 g
s
.65 .757 .928 r
.52482 .62385 m .51582 .62659 L .51337 .62406 L p F P
0 g
s
.651 .758 .928 r
.80667 .62629 m .81616 .62354 L .81814 .62607 L p F P
0 g
s
.651 .758 .928 r
.81616 .62354 m .80667 .62629 L .80466 .62377 L p F P
0 g
s
.65 .757 .928 r
.25353 .62103 m .24498 .62377 L .24786 .6263 L p F P
0 g
s
.65 .757 .928 r
.24786 .6263 m .2564 .62356 L .25353 .62103 L p F P
0 g
s
.651 .758 .928 r
.66697 .62637 m .67622 .62362 L .67843 .62615 L p F P
0 g
s
.651 .758 .928 r
.67622 .62362 m .66697 .62637 L .66475 .62384 L p F P
0 g
s
.65 .757 .928 r
.39369 .62109 m .3849 .62384 L .38756 .62637 L p F P
0 g
s
.65 .757 .928 r
.38756 .62637 m .39634 .62363 L .39369 .62109 L p F P
0 g
s
.65 .758 .928 r
.52726 .62638 m .53628 .62364 L .5387 .62617 L p F P
0 g
s
.65 .758 .928 r
.53628 .62364 m .52726 .62638 L .52482 .62385 L p F P
0 g
s
.651 .758 .928 r
.81814 .62607 m .82765 .62332 L .82962 .62585 L p F P
0 g
s
.651 .758 .928 r
.82765 .62332 m .81814 .62607 L .81616 .62354 L p F P
0 g
s
.65 .757 .928 r
.26497 .62082 m .2564 .62356 L .25926 .6261 L p F P
0 g
s
.65 .757 .928 r
.25926 .6261 m .26782 .62336 L .26497 .62082 L p F P
0 g
s
.651 .758 .928 r
.67843 .62615 m .6877 .62341 L .68989 .62594 L p F P
0 g
s
.651 .758 .928 r
.6877 .62341 m .67843 .62615 L .67622 .62362 L p F P
0 g
s
.65 .757 .928 r
.40515 .62088 m .39634 .62363 L .39898 .62616 L p F P
0 g
s
.65 .757 .928 r
.39898 .62616 m .40778 .62342 L .40515 .62088 L p F P
0 g
s
.65 .758 .928 r
.5387 .62617 m .54774 .62343 L .55015 .62596 L p F P
0 g
s
.65 .758 .928 r
.54774 .62343 m .5387 .62617 L .53628 .62364 L p F P
0 g
s
.651 .758 .928 r
.82962 .62585 m .83915 .6231 L .8411 .62562 L p F P
0 g
s
.651 .758 .928 r
.83915 .6231 m .82962 .62585 L .82765 .62332 L p F P
0 g
s
.65 .757 .928 r
.27642 .62062 m .26782 .62336 L .27067 .62589 L p F P
0 g
s
.65 .757 .928 r
.27067 .62589 m .27925 .62316 L .27642 .62062 L p F P
0 g
s
.651 .758 .928 r
.68989 .62594 m .69918 .6232 L .70135 .62572 L p F P
0 g
s
.651 .758 .928 r
.69918 .6232 m .68989 .62594 L .6877 .62341 L p F P
0 g
s
.65 .757 .928 r
.41661 .62067 m .40778 .62342 L .4104 .62595 L p F P
0 g
s
.65 .757 .928 r
.4104 .62595 m .41923 .62321 L .41661 .62067 L p F P
0 g
s
0 0 .352 r
.52577 .55395 m .52577 .55396 L .52577 .54981 L p F P
0 g
s
0 0 .352 r
.52577 .54981 m .52577 .5498 L .52577 .55395 L p F P
0 g
s
.76 .499 .539 r
.52575 .55396 m .52577 .55396 L .52577 .54981 L p F P
0 g
s
.76 .499 .539 r
.52577 .54981 m .52575 .54981 L .52575 .55396 L p F P
0 g
s
.651 .758 .928 r
.55015 .62596 m .55921 .62322 L .56159 .62575 L p F P
0 g
s
.651 .758 .928 r
.55921 .62322 m .55015 .62596 L .54774 .62343 L p F P
0 g
s
0 0 .352 r
.52576 .5498 m .52575 .54981 L .52575 .55396 L p F P
0 g
s
.76 .499 .539 r
.52576 .5498 m .52577 .5498 L .52577 .55395 L p F P
0 g
s
.76 .499 .539 r
.52577 .55395 m .52576 .55395 L .52576 .5498 L p F P
0 g
s
0 0 .352 r
.52575 .55396 m .52576 .55395 L .52576 .5498 L p F P
0 g
s
.651 .758 .928 r
.8411 .62562 m .85066 .62287 L .85259 .62539 L p F P
0 g
s
.651 .758 .928 r
.85066 .62287 m .8411 .62562 L .83915 .6231 L p F P
0 g
s
.65 .757 .928 r
.28786 .62042 m .27925 .62316 L .28207 .62569 L p F P
0 g
s
.65 .757 .928 r
.28207 .62569 m .29068 .62296 L .28786 .62042 L p F P
0 g
s
.651 .758 .928 r
.71067 .62298 m .70135 .62572 L .69918 .6232 L p F P
0 g
s
.651 .758 .928 r
.70135 .62572 m .71067 .62298 L .71282 .62551 L p F P
0 g
s
.65 .757 .928 r
.42808 .62046 m .41923 .62321 L .42183 .62574 L p F P
0 g
s
.65 .757 .928 r
.42183 .62574 m .43067 .623 L .42808 .62046 L p F P
0 g
s
.651 .758 .928 r
.56159 .62575 m .57067 .62301 L .57304 .62554 L p F P
0 g
s
.651 .758 .928 r
.57067 .62301 m .56159 .62575 L .55921 .62322 L p F P
0 g
s
.651 .758 .928 r
.85259 .62539 m .86216 .62264 L .86407 .62517 L p F P
0 g
s
.651 .758 .928 r
.86216 .62264 m .85259 .62539 L .85066 .62287 L p F P
0 g
s
.65 .757 .928 r
.29932 .62021 m .29068 .62296 L .29349 .62549 L p F P
0 g
s
.65 .757 .928 r
.29349 .62549 m .30211 .62275 L .29932 .62021 L p F P
0 g
s
.651 .758 .928 r
.71282 .62551 m .72216 .62276 L .72429 .6253 L p F P
0 g
s
.651 .758 .928 r
.72216 .62276 m .71282 .62551 L .71067 .62298 L p F P
0 g
s
.65 .757 .928 r
.43955 .62025 m .43067 .623 L .43326 .62553 L p F P
0 g
s
.65 .757 .928 r
.43326 .62553 m .44213 .62279 L .43955 .62025 L p F P
0 g
s
.651 .758 .928 r
.57304 .62554 m .58214 .62279 L .58449 .62533 L p F P
0 g
s
.651 .758 .928 r
.58214 .62279 m .57304 .62554 L .57067 .62301 L p F P
0 g
s
.651 .758 .928 r
.86407 .62517 m .87367 .62241 L .87556 .62493 L p F P
0 g
s
.651 .758 .928 r
.87367 .62241 m .86407 .62517 L .86216 .62264 L p F P
0 g
s
.65 .757 .928 r
.31077 .62 m .30211 .62275 L .3049 .62528 L p F P
0 g
s
.65 .757 .928 r
.3049 .62528 m .31355 .62255 L .31077 .62 L p F P
0 g
s
.651 .758 .928 r
.72429 .6253 m .73365 .62255 L .73576 .62508 L p F P
0 g
s
.651 .758 .928 r
.73365 .62255 m .72429 .6253 L .72216 .62276 L p F P
0 g
s
.65 .757 .928 r
.4447 .62532 m .45358 .62258 L .45613 .62511 L p F P
0 g
s
.65 .757 .928 r
.45102 .62004 m .44213 .62279 L .4447 .62532 L p F P
0 g
s
.65 .757 .928 r
.4447 .62532 m .45358 .62258 L .45102 .62004 L p F P
0 g
s
.651 .758 .928 r
.58449 .62533 m .59362 .62258 L .59595 .62511 L p F P
0 g
s
.651 .758 .928 r
.59362 .62258 m .58449 .62533 L .58214 .62279 L p F P
0 g
s
.651 .758 .928 r
.87556 .62493 m .88518 .62217 L .88705 .6247 L p F P
0 g
s
.651 .758 .928 r
.88518 .62217 m .87556 .62493 L .87367 .62241 L p F P
0 g
s
.65 .757 .928 r
.18197 .61966 m .17353 .6224 L .17652 .62493 L p F P
0 g
s
.65 .757 .928 r
.17652 .62493 m .18495 .62221 L .18197 .61966 L p F P
0 g
s
.651 .758 .928 r
.73576 .62508 m .74514 .62233 L .74724 .62486 L p F P
0 g
s
.651 .758 .928 r
.74514 .62233 m .73576 .62508 L .73365 .62255 L p F P
0 g
s
.65 .757 .928 r
.32223 .6198 m .31355 .62255 L .31632 .62508 L p F P
0 g
s
.65 .757 .928 r
.31632 .62508 m .32499 .62234 L .32223 .6198 L p F P
0 g
s
.651 .758 .928 r
.59595 .62511 m .60509 .62237 L .60741 .6249 L p F P
0 g
s
.651 .758 .928 r
.60509 .62237 m .59595 .62511 L .59362 .62258 L p F P
0 g
s
.65 .757 .928 r
.45613 .62511 m .46504 .62237 L .46757 .6249 L p F P
0 g
s
.65 .757 .928 r
.46504 .62237 m .45613 .62511 L .45358 .62258 L p F P
0 g
s
.651 .758 .928 r
.88705 .6247 m .89669 .62194 L .89855 .62446 L p F P
0 g
s
.651 .758 .928 r
.89669 .62194 m .88705 .6247 L .88518 .62217 L p F P
0 g
s
.65 .757 .928 r
.19341 .61947 m .18495 .62221 L .18792 .62475 L p F P
0 g
s
.65 .757 .928 r
.18792 .62475 m .19637 .62202 L .19341 .61947 L p F P
0 g
s
.651 .758 .928 r
.74724 .62486 m .75664 .62211 L .75872 .62465 L p F P
0 g
s
.651 .758 .928 r
.75664 .62211 m .74724 .62486 L .74514 .62233 L p F P
0 g
s
.65 .757 .928 r
.33369 .61959 m .32499 .62234 L .32774 .62487 L p F P
0 g
s
.65 .757 .928 r
.32774 .62487 m .33643 .62213 L .33369 .61959 L p F P
0 g
s
.651 .758 .928 r
.60741 .6249 m .61657 .62216 L .61887 .62469 L p F P
0 g
s
.651 .758 .928 r
.61657 .62216 m .60741 .6249 L .60509 .62237 L p F P
0 g
s
.65 .757 .928 r
.46757 .6249 m .4765 .62216 L .47902 .62469 L p F P
0 g
s
.65 .757 .928 r
.4765 .62216 m .46757 .6249 L .46504 .62237 L p F P
0 g
s
.651 .759 .928 r
.89855 .62446 m .9082 .62169 L .91004 .62422 L p F P
0 g
s
.651 .758 .928 r
.9082 .62169 m .89855 .62446 L .89669 .62194 L p F P
0 g
s
.65 .757 .928 r
.20485 .61928 m .19637 .62202 L .19933 .62455 L p F P
0 g
s
.65 .757 .928 r
.19933 .62455 m .2078 .62182 L .20485 .61928 L p F P
0 g
s
.651 .758 .928 r
.75872 .62465 m .76814 .62189 L .7702 .62443 L p F P
0 g
s
.651 .758 .928 r
.76814 .62189 m .75872 .62465 L .75664 .62211 L p F P
0 g
s
.65 .757 .928 r
.34515 .61938 m .33643 .62213 L .33917 .62467 L p F P
0 g
s
.65 .757 .928 r
.33917 .62467 m .34788 .62193 L .34515 .61938 L p F P
0 g
s
.651 .758 .928 r
.61887 .62469 m .62805 .62194 L .63033 .62448 L p F P
0 g
s
.651 .758 .928 r
.62805 .62194 m .61887 .62469 L .61657 .62216 L p F P
0 g
s
.65 .757 .928 r
.47902 .62469 m .48796 .62195 L .49046 .62448 L p F P
0 g
s
.65 .757 .928 r
.48796 .62195 m .47902 .62469 L .4765 .62216 L p F P
0 g
s
.652 .759 .928 r
.91004 .62422 m .91972 .62145 L .92154 .62398 L p F P
0 g
s
.652 .759 .928 r
.91972 .62145 m .91004 .62422 L .9082 .62169 L p F P
0 g
s
.65 .757 .928 r
.2163 .61908 m .2078 .62182 L .21074 .62436 L p F P
0 g
s
.65 .757 .928 r
.21074 .62436 m .21923 .62162 L .2163 .61908 L p F P
0 g
s
.651 .758 .928 r
.7702 .62443 m .77964 .62168 L .78169 .62421 L p F P
0 g
s
.651 .758 .928 r
.77964 .62168 m .7702 .62443 L .76814 .62189 L p F P
0 g
s
.65 .757 .928 r
.35661 .61917 m .34788 .62193 L .3506 .62446 L p F P
0 g
s
.65 .757 .928 r
.3506 .62446 m .35932 .62172 L .35661 .61917 L p F P
0 g
s
.651 .758 .928 r
.63033 .62448 m .63954 .62173 L .6418 .62426 L p F P
0 g
s
.651 .758 .928 r
.63954 .62173 m .63033 .62448 L .62805 .62194 L p F P
0 g
s
.65 .757 .928 r
.49046 .62448 m .49943 .62174 L .50191 .62427 L p F P
0 g
s
.65 .757 .928 r
.49943 .62174 m .49046 .62448 L .48796 .62195 L p F P
0 g
s
.65 .757 .928 r
.22775 .61888 m .21923 .62162 L .22215 .62416 L p F P
0 g
s
.65 .757 .928 r
.22215 .62416 m .23066 .62143 L .22775 .61888 L p F P
0 g
s
.651 .758 .928 r
.78169 .62421 m .79115 .62146 L .79317 .62399 L p F P
0 g
s
.651 .758 .928 r
.79115 .62146 m .78169 .62421 L .77964 .62168 L p F P
0 g
s
.65 .757 .928 r
.36808 .61896 m .35932 .62172 L .36203 .62425 L p F P
0 g
s
.65 .757 .928 r
.36203 .62425 m .37078 .62151 L .36808 .61896 L p F P
0 g
s
.651 .758 .928 r
.6418 .62426 m .65103 .62152 L .65327 .62405 L p F P
0 g
s
.651 .758 .928 r
.65103 .62152 m .6418 .62426 L .63954 .62173 L p F P
0 g
s
.65 .757 .928 r
.50191 .62427 m .5109 .62153 L .51337 .62406 L p F P
0 g
s
.65 .757 .928 r
.5109 .62153 m .50191 .62427 L .49943 .62174 L p F P
0 g
s
.65 .757 .928 r
.2392 .61868 m .23066 .62143 L .23356 .62396 L p F P
0 g
s
.65 .757 .928 r
.23356 .62396 m .24209 .62123 L .2392 .61868 L p F P
0 g
s
.651 .758 .928 r
.79317 .62399 m .80266 .62123 L .80466 .62377 L p F P
0 g
s
.651 .758 .928 r
.80266 .62123 m .79317 .62399 L .79115 .62146 L p F P
0 g
s
.65 .757 .928 r
.37956 .61876 m .37078 .62151 L .37346 .62405 L p F P
0 g
s
.65 .757 .928 r
.37346 .62405 m .38223 .6213 L .37956 .61876 L p F P
0 g
s
.651 .758 .928 r
.65327 .62405 m .66252 .6213 L .66475 .62384 L p F P
0 g
s
.651 .758 .928 r
.66252 .6213 m .65327 .62405 L .65103 .62152 L p F P
0 g
s
.65 .757 .928 r
.52237 .62132 m .51337 .62406 L .5109 .62153 L p F P
0 g
s
.65 .757 .928 r
.51337 .62406 m .52237 .62132 L .52482 .62385 L p F P
0 g
s
.65 .757 .928 r
.25065 .61848 m .24209 .62123 L .24498 .62377 L p F P
0 g
s
.65 .757 .928 r
.24498 .62377 m .25353 .62103 L .25065 .61848 L p F P
0 g
s
.651 .758 .928 r
.80466 .62377 m .81417 .62101 L .81616 .62354 L p F P
0 g
s
.651 .758 .928 r
.81417 .62101 m .80466 .62377 L .80266 .62123 L p F P
0 g
s
.65 .757 .928 r
.39103 .61855 m .38223 .6213 L .3849 .62384 L p F P
0 g
s
.65 .757 .928 r
.3849 .62384 m .39369 .62109 L .39103 .61855 L p F P
0 g
s
.651 .758 .928 r
.66475 .62384 m .67401 .62109 L .67622 .62362 L p F P
0 g
s
.651 .758 .928 r
.67401 .62109 m .66475 .62384 L .66252 .6213 L p F P
0 g
s
0 0 .353 r
.52577 .55811 m .52577 .55812 L .52577 .55396 L p F P
0 g
s
0 0 .353 r
.52577 .55396 m .52577 .55395 L .52577 .55811 L p F P
0 g
s
.76 .499 .539 r
.52575 .55811 m .52577 .55812 L .52577 .55396 L p F P
0 g
s
.76 .499 .539 r
.52577 .55396 m .52575 .55396 L .52575 .55811 L p F P
0 g
s
.65 .758 .928 r
.52482 .62385 m .53385 .62111 L .53628 .62364 L p F P
0 g
s
.65 .758 .928 r
.53385 .62111 m .52482 .62385 L .52237 .62132 L p F P
0 g
s
0 0 .353 r
.52576 .55395 m .52575 .55396 L .52575 .55811 L p F P
0 g
s
.76 .499 .539 r
.52576 .55395 m .52577 .55395 L .52577 .55811 L p F P
0 g
s
.76 .499 .539 r
.52577 .55811 m .52576 .55811 L .52576 .55395 L p F P
0 g
s
0 0 .353 r
.52575 .55811 m .52576 .55811 L .52576 .55395 L p F P
0 g
s
.651 .758 .928 r
.81616 .62354 m .82568 .62079 L .82765 .62332 L p F P
0 g
s
.651 .758 .928 r
.82568 .62079 m .81616 .62354 L .81417 .62101 L p F P
0 g
s
.65 .757 .928 r
.26211 .61828 m .25353 .62103 L .2564 .62356 L p F P
0 g
s
.65 .757 .928 r
.2564 .62356 m .26497 .62082 L .26211 .61828 L p F P
0 g
s
.651 .758 .928 r
.67622 .62362 m .68551 .62087 L .6877 .62341 L p F P
0 g
s
.651 .758 .928 r
.68551 .62087 m .67622 .62362 L .67401 .62109 L p F P
0 g
s
.65 .757 .928 r
.40251 .61834 m .39369 .62109 L .39634 .62363 L p F P
0 g
s
.65 .757 .928 r
.39634 .62363 m .40515 .62088 L .40251 .61834 L p F P
0 g
s
.65 .758 .928 r
.53628 .62364 m .54533 .62089 L .54774 .62343 L p F P
0 g
s
.65 .758 .928 r
.54533 .62089 m .53628 .62364 L .53385 .62111 L p F P
0 g
s
.651 .758 .928 r
.82765 .62332 m .8372 .62056 L .83915 .6231 L p F P
0 g
s
.651 .758 .928 r
.8372 .62056 m .82765 .62332 L .82568 .62079 L p F P
0 g
s
.65 .757 .928 r
.27357 .61807 m .26497 .62082 L .26782 .62336 L p F P
0 g
s
.65 .757 .928 r
.26782 .62336 m .27642 .62062 L .27357 .61807 L p F P
0 g
s
.651 .758 .928 r
.6877 .62341 m .69701 .62066 L .69918 .6232 L p F P
0 g
s
.651 .758 .928 r
.69701 .62066 m .6877 .62341 L .68551 .62087 L p F P
0 g
s
.65 .757 .928 r
.41399 .61813 m .40515 .62088 L .40778 .62342 L p F P
0 g
s
.65 .757 .928 r
.40778 .62342 m .41661 .62067 L .41399 .61813 L p F P
0 g
s
.651 .758 .928 r
.54774 .62343 m .55681 .62068 L .55921 .62322 L p F P
0 g
s
.651 .758 .928 r
.55681 .62068 m .54774 .62343 L .54533 .62089 L p F P
0 g
s
.651 .758 .928 r
.83915 .6231 m .84872 .62033 L .85066 .62287 L p F P
0 g
s
.651 .758 .928 r
.84872 .62033 m .83915 .6231 L .8372 .62056 L p F P
0 g
s
.65 .757 .928 r
.28504 .61787 m .27642 .62062 L .27925 .62316 L p F P
0 g
s
.65 .757 .928 r
.27925 .62316 m .28786 .62042 L .28504 .61787 L p F P
0 g
s
.651 .758 .928 r
.69918 .6232 m .70851 .62044 L .71067 .62298 L p F P
0 g
s
.651 .758 .928 r
.70851 .62044 m .69918 .6232 L .69701 .62066 L p F P
0 g
s
.65 .757 .928 r
.42547 .61791 m .41661 .62067 L .41923 .62321 L p F P
0 g
s
.65 .757 .928 r
.41923 .62321 m .42808 .62046 L .42547 .61791 L p F P
0 g
s
.651 .758 .928 r
.55921 .62322 m .5683 .62047 L .57067 .62301 L p F P
0 g
s
.651 .758 .928 r
.5683 .62047 m .55921 .62322 L .55681 .62068 L p F P
0 g
s
.651 .758 .928 r
.85066 .62287 m .86024 .6201 L .86216 .62264 L p F P
0 g
s
.651 .758 .928 r
.86024 .6201 m .85066 .62287 L .84872 .62033 L p F P
0 g
s
.65 .757 .928 r
.29651 .61766 m .28786 .62042 L .29068 .62296 L p F P
0 g
s
.65 .757 .928 r
.29068 .62296 m .29932 .62021 L .29651 .61766 L p F P
0 g
s
.651 .758 .928 r
.72002 .62023 m .71067 .62298 L .70851 .62044 L p F P
0 g
s
.651 .758 .928 r
.71067 .62298 m .72002 .62023 L .72216 .62276 L p F P
0 g
s
.65 .757 .928 r
.43696 .6177 m .42808 .62046 L .43067 .623 L p F P
0 g
s
.65 .757 .928 r
.43067 .623 m .43955 .62025 L .43696 .6177 L p F P
0 g
s
.651 .758 .928 r
.57067 .62301 m .57978 .62026 L .58214 .62279 L p F P
0 g
s
.651 .758 .928 r
.57978 .62026 m .57067 .62301 L .5683 .62047 L p F P
0 g
s
.651 .758 .928 r
.86216 .62264 m .87177 .61987 L .87367 .62241 L p F P
0 g
s
.651 .758 .928 r
.87177 .61987 m .86216 .62264 L .86024 .6201 L p F P
0 g
s
.65 .757 .928 r
.30798 .61746 m .29932 .62021 L .30211 .62275 L p F P
0 g
s
.65 .757 .928 r
.30211 .62275 m .31077 .62 L .30798 .61746 L p F P
0 g
s
.651 .758 .928 r
.72216 .62276 m .73153 .62001 L .73365 .62255 L p F P
0 g
s
.651 .758 .928 r
.73153 .62001 m .72216 .62276 L .72002 .62023 L p F P
0 g
s
.65 .757 .928 r
.44845 .61749 m .43955 .62025 L .44213 .62279 L p F P
0 g
s
.65 .757 .928 r
.44213 .62279 m .45102 .62004 L .44845 .61749 L p F P
0 g
s
.651 .758 .928 r
.58214 .62279 m .59128 .62004 L .59362 .62258 L p F P
0 g
s
.651 .758 .928 r
.59128 .62004 m .58214 .62279 L .57978 .62026 L p F P
0 g
s
.65 .757 .928 r
.17898 .61711 m .17053 .61985 L .17353 .6224 L p F P
0 g
s
.65 .757 .928 r
.17353 .6224 m .18197 .61966 L .17898 .61711 L p F P
0 g
s
.651 .758 .928 r
.87367 .62241 m .88329 .61964 L .88518 .62217 L p F P
0 g
s
.651 .758 .928 r
.88329 .61964 m .87367 .62241 L .87177 .61987 L p F P
0 g
s
.65 .757 .928 r
.31945 .61725 m .31077 .62 L .31355 .62255 L p F P
0 g
s
.65 .757 .928 r
.31355 .62255 m .32223 .6198 L .31945 .61725 L p F P
0 g
s
.651 .758 .928 r
.73365 .62255 m .74304 .61979 L .74514 .62233 L p F P
0 g
s
.651 .758 .928 r
.74304 .61979 m .73365 .62255 L .73153 .62001 L p F P
0 g
s
.65 .757 .928 r
.45358 .62258 m .4625 .61983 L .46504 .62237 L p F P
0 g
s
.65 .757 .928 r
.45995 .61728 m .45102 .62004 L .45358 .62258 L p F P
0 g
s
.65 .757 .928 r
.45358 .62258 m .4625 .61983 L .45995 .61728 L p F P
0 g
s
.651 .758 .928 r
.59362 .62258 m .60277 .61983 L .60509 .62237 L p F P
0 g
s
.651 .758 .928 r
.60277 .61983 m .59362 .62258 L .59128 .62004 L p F P
0 g
s
.651 .758 .928 r
.88518 .62217 m .89482 .6194 L .89669 .62194 L p F P
0 g
s
.651 .758 .928 r
.89482 .6194 m .88518 .62217 L .88329 .61964 L p F P
0 g
s
.65 .757 .928 r
.19043 .61692 m .18197 .61966 L .18495 .62221 L p F P
0 g
s
.65 .757 .928 r
.18495 .62221 m .19341 .61947 L .19043 .61692 L p F P
0 g
s
.651 .758 .928 r
.74514 .62233 m .75455 .61957 L .75664 .62211 L p F P
0 g
s
.651 .758 .928 r
.75455 .61957 m .74514 .62233 L .74304 .61979 L p F P
0 g
s
.65 .757 .928 r
.33093 .61704 m .32223 .6198 L .32499 .62234 L p F P
0 g
s
.65 .757 .928 r
.32499 .62234 m .33369 .61959 L .33093 .61704 L p F P
0 g
s
.651 .758 .928 r
.60509 .62237 m .61427 .61962 L .61657 .62216 L p F P
0 g
s
.651 .758 .928 r
.61427 .61962 m .60509 .62237 L .60277 .61983 L p F P
0 g
s
.65 .757 .928 r
.46504 .62237 m .47398 .61962 L .4765 .62216 L p F P
0 g
s
.65 .757 .928 r
.47398 .61962 m .46504 .62237 L .4625 .61983 L p F P
0 g
s
.651 .758 .928 r
.89669 .62194 m .90636 .61916 L .9082 .62169 L p F P
0 g
s
.651 .758 .928 r
.90636 .61916 m .89669 .62194 L .89482 .6194 L p F P
0 g
s
.65 .757 .928 r
.20189 .61672 m .19341 .61947 L .19637 .62202 L p F P
0 g
s
.65 .757 .928 r
.19637 .62202 m .20485 .61928 L .20189 .61672 L p F P
0 g
s
.651 .758 .928 r
.75664 .62211 m .76607 .61935 L .76814 .62189 L p F P
0 g
s
.651 .758 .928 r
.76607 .61935 m .75664 .62211 L .75455 .61957 L p F P
0 g
s
.65 .757 .928 r
.34241 .61683 m .33369 .61959 L .33643 .62213 L p F P
0 g
s
.65 .757 .928 r
.33643 .62213 m .34515 .61938 L .34241 .61683 L p F P
0 g
s
.651 .758 .928 r
.61657 .62216 m .62577 .6194 L .62805 .62194 L p F P
0 g
s
.651 .758 .928 r
.62577 .6194 m .61657 .62216 L .61427 .61962 L p F P
0 g
s
.65 .757 .928 r
.4765 .62216 m .48546 .61941 L .48796 .62195 L p F P
0 g
s
.65 .757 .928 r
.48546 .61941 m .4765 .62216 L .47398 .61962 L p F P
0 g
s
.652 .759 .928 r
.9082 .62169 m .91789 .61892 L .91972 .62145 L p F P
0 g
s
.651 .759 .928 r
.91789 .61892 m .9082 .62169 L .90636 .61916 L p F P
0 g
s
.65 .757 .928 r
.21336 .61653 m .20485 .61928 L .2078 .62182 L p F P
0 g
s
.65 .757 .928 r
.2078 .62182 m .2163 .61908 L .21336 .61653 L p F P
0 g
s
.651 .758 .928 r
.76814 .62189 m .77759 .61913 L .77964 .62168 L p F P
0 g
s
.651 .758 .928 r
.77759 .61913 m .76814 .62189 L .76607 .61935 L p F P
0 g
s
.65 .757 .928 r
.3539 .61662 m .34515 .61938 L .34788 .62193 L p F P
0 g
s
.65 .757 .928 r
.34788 .62193 m .35661 .61917 L .3539 .61662 L p F P
0 g
s
.651 .758 .928 r
.62805 .62194 m .63727 .61919 L .63954 .62173 L p F P
0 g
s
.651 .758 .928 r
.63727 .61919 m .62805 .62194 L .62577 .6194 L p F P
0 g
s
.65 .757 .928 r
.48796 .62195 m .49694 .6192 L .49943 .62174 L p F P
0 g
s
.65 .757 .928 r
.49694 .6192 m .48796 .62195 L .48546 .61941 L p F P
0 g
s
.65 .757 .928 r
.22482 .61633 m .2163 .61908 L .21923 .62162 L p F P
0 g
s
.65 .757 .928 r
.21923 .62162 m .22775 .61888 L .22482 .61633 L p F P
0 g
s
.651 .758 .928 r
.77964 .62168 m .78912 .61891 L .79115 .62146 L p F P
0 g
s
.651 .758 .928 r
.78912 .61891 m .77964 .62168 L .77759 .61913 L p F P
0 g
s
.65 .757 .928 r
.36538 .61641 m .35661 .61917 L .35932 .62172 L p F P
0 g
s
.65 .757 .928 r
.35932 .62172 m .36808 .61896 L .36538 .61641 L p F P
0 g
s
.651 .758 .928 r
.63954 .62173 m .64878 .61897 L .65103 .62152 L p F P
0 g
s
.651 .758 .928 r
.64878 .61897 m .63954 .62173 L .63727 .61919 L p F P
0 g
s
0 0 .354 r
.52577 .56228 m .52577 .56229 L .52577 .55812 L p F P
0 g
s
0 0 .354 r
.52577 .55812 m .52577 .55811 L .52577 .56228 L p F P
0 g
s
.759 .498 .539 r
.52575 .56228 m .52577 .56229 L .52577 .55812 L p F P
0 g
s
.759 .498 .539 r
.52577 .55812 m .52575 .55811 L .52575 .56228 L p F P
0 g
s
.65 .757 .928 r
.49943 .62174 m .50843 .61898 L .5109 .62153 L p F P
0 g
s
.65 .757 .928 r
.50843 .61898 m .49943 .62174 L .49694 .6192 L p F P
0 g
s
0 0 .354 r
.52576 .55811 m .52575 .55811 L .52575 .56228 L p F P
0 g
s
.759 .498 .539 r
.52576 .55811 m .52577 .55811 L .52577 .56228 L p F P
0 g
s
.759 .498 .539 r
.52577 .56228 m .52576 .56228 L .52576 .55811 L p F P
0 g
s
0 0 .354 r
.52575 .56228 m .52576 .56228 L .52576 .55811 L p F P
0 g
s
.65 .757 .928 r
.23629 .61613 m .22775 .61888 L .23066 .62143 L p F P
0 g
s
.65 .757 .928 r
.23066 .62143 m .2392 .61868 L .23629 .61613 L p F P
0 g
s
.651 .758 .928 r
.79115 .62146 m .80064 .61869 L .80266 .62123 L p F P
0 g
s
.651 .758 .928 r
.80064 .61869 m .79115 .62146 L .78912 .61891 L p F P
0 g
s
.65 .757 .928 r
.37687 .6162 m .36808 .61896 L .37078 .62151 L p F P
0 g
s
.65 .757 .928 r
.37078 .62151 m .37956 .61876 L .37687 .6162 L p F P
0 g
s
.651 .758 .928 r
.65103 .62152 m .66028 .61876 L .66252 .6213 L p F P
0 g
s
.651 .758 .928 r
.66028 .61876 m .65103 .62152 L .64878 .61897 L p F P
0 g
s
.65 .757 .928 r
.5109 .62153 m .51992 .61877 L .52237 .62132 L p F P
0 g
s
.65 .757 .928 r
.51992 .61877 m .5109 .62153 L .50843 .61898 L p F P
0 g
s
.65 .757 .928 r
.24777 .61592 m .2392 .61868 L .24209 .62123 L p F P
0 g
s
.65 .757 .928 r
.24209 .62123 m .25065 .61848 L .24777 .61592 L p F P
0 g
s
.651 .758 .928 r
.80266 .62123 m .81217 .61847 L .81417 .62101 L p F P
0 g
s
.651 .758 .928 r
.81217 .61847 m .80266 .62123 L .80064 .61869 L p F P
0 g
s
.65 .757 .928 r
.38837 .61599 m .37956 .61876 L .38223 .6213 L p F P
0 g
s
.65 .757 .928 r
.38223 .6213 m .39103 .61855 L .38837 .61599 L p F P
0 g
s
.651 .758 .928 r
.66252 .6213 m .6718 .61854 L .67401 .62109 L p F P
0 g
s
.651 .758 .928 r
.6718 .61854 m .66252 .6213 L .66028 .61876 L p F P
0 g
s
.65 .757 .928 r
.53141 .61856 m .52237 .62132 L .51992 .61877 L p F P
0 g
s
.65 .758 .928 r
.52237 .62132 m .53141 .61856 L .53385 .62111 L p F P
0 g
s
.651 .758 .928 r
.81417 .62101 m .8237 .61824 L .82568 .62079 L p F P
0 g
s
.651 .758 .928 r
.8237 .61824 m .81417 .62101 L .81217 .61847 L p F P
0 g
s
.65 .757 .928 r
.25924 .61572 m .25065 .61848 L .25353 .62103 L p F P
0 g
s
.65 .757 .928 r
.25353 .62103 m .26211 .61828 L .25924 .61572 L p F P
0 g
s
.651 .758 .928 r
.67401 .62109 m .68331 .61833 L .68551 .62087 L p F P
0 g
s
.651 .758 .928 r
.68331 .61833 m .67401 .62109 L .6718 .61854 L p F P
0 g
s
.65 .757 .928 r
.39986 .61578 m .39103 .61855 L .39369 .62109 L p F P
0 g
s
.65 .757 .928 r
.39369 .62109 m .40251 .61834 L .39986 .61578 L p F P
0 g
s
.65 .758 .928 r
.53385 .62111 m .54291 .61835 L .54533 .62089 L p F P
0 g
s
.65 .758 .928 r
.54291 .61835 m .53385 .62111 L .53141 .61856 L p F P
0 g
s
.651 .758 .928 r
.82568 .62079 m .83524 .61802 L .8372 .62056 L p F P
0 g
s
.651 .758 .928 r
.83524 .61802 m .82568 .62079 L .8237 .61824 L p F P
0 g
s
.65 .757 .928 r
.27072 .61552 m .26211 .61828 L .26497 .62082 L p F P
0 g
s
.65 .757 .928 r
.26497 .62082 m .27357 .61807 L .27072 .61552 L p F P
0 g
s
.651 .758 .928 r
.68551 .62087 m .69483 .61811 L .69701 .62066 L p F P
0 g
s
.651 .758 .928 r
.69483 .61811 m .68551 .62087 L .68331 .61833 L p F P
0 g
s
.65 .757 .928 r
.41136 .61557 m .40251 .61834 L .40515 .62088 L p F P
0 g
s
.65 .757 .928 r
.40515 .62088 m .41399 .61813 L .41136 .61557 L p F P
0 g
s
.651 .758 .928 r
.54533 .62089 m .55441 .61813 L .55681 .62068 L p F P
0 g
s
.651 .758 .928 r
.55441 .61813 m .54533 .62089 L .54291 .61835 L p F P
0 g
s
.651 .758 .928 r
.8372 .62056 m .84678 .61779 L .84872 .62033 L p F P
0 g
s
.651 .758 .928 r
.84678 .61779 m .8372 .62056 L .83524 .61802 L p F P
0 g
s
.65 .757 .928 r
.28221 .61531 m .27357 .61807 L .27642 .62062 L p F P
0 g
s
.65 .757 .928 r
.27642 .62062 m .28504 .61787 L .28221 .61531 L p F P
0 g
s
.651 .758 .928 r
.69701 .62066 m .70635 .6179 L .70851 .62044 L p F P
0 g
s
.651 .758 .928 r
.70635 .6179 m .69701 .62066 L .69483 .61811 L p F P
0 g
s
.65 .757 .928 r
.42286 .61536 m .41399 .61813 L .41661 .62067 L p F P
0 g
s
.65 .757 .928 r
.41661 .62067 m .42547 .61791 L .42286 .61536 L p F P
0 g
s
.651 .758 .928 r
.55681 .62068 m .56591 .61792 L .5683 .62047 L p F P
0 g
s
.651 .758 .928 r
.56591 .61792 m .55681 .62068 L .55441 .61813 L p F P
0 g
s
.651 .758 .928 r
.84872 .62033 m .85832 .61756 L .86024 .6201 L p F P
0 g
s
.651 .758 .928 r
.85832 .61756 m .84872 .62033 L .84678 .61779 L p F P
0 g
s
.65 .757 .928 r
.29369 .6151 m .28504 .61787 L .28786 .62042 L p F P
0 g
s
.65 .757 .928 r
.28786 .62042 m .29651 .61766 L .29369 .6151 L p F P
0 g
s
.651 .758 .928 r
.70851 .62044 m .71787 .61768 L .72002 .62023 L p F P
0 g
s
.651 .758 .928 r
.71787 .61768 m .70851 .62044 L .70635 .6179 L p F P
0 g
s
.65 .757 .928 r
.43437 .61515 m .42547 .61791 L .42808 .62046 L p F P
0 g
s
.65 .757 .928 r
.42808 .62046 m .43696 .6177 L .43437 .61515 L p F P
0 g
s
.651 .758 .928 r
.5683 .62047 m .57742 .61771 L .57978 .62026 L p F P
0 g
s
.651 .758 .928 r
.57742 .61771 m .5683 .62047 L .56591 .61792 L p F P
0 g
s
.651 .758 .928 r
.86024 .6201 m .86986 .61733 L .87177 .61987 L p F P
0 g
s
.651 .758 .928 r
.86986 .61733 m .86024 .6201 L .85832 .61756 L p F P
0 g
s
.65 .757 .928 r
.30518 .6149 m .29651 .61766 L .29932 .62021 L p F P
0 g
s
.65 .757 .928 r
.29932 .62021 m .30798 .61746 L .30518 .6149 L p F P
0 g
s
.651 .758 .928 r
.7294 .61746 m .72002 .62023 L .71787 .61768 L p F P
0 g
s
.651 .758 .928 r
.72002 .62023 m .7294 .61746 L .73153 .62001 L p F P
0 g
s
.65 .757 .928 r
.44588 .61494 m .43696 .6177 L .43955 .62025 L p F P
0 g
s
.65 .757 .928 r
.43955 .62025 m .44845 .61749 L .44588 .61494 L p F P
0 g
s
.651 .758 .928 r
.57978 .62026 m .58893 .61749 L .59128 .62004 L p F P
0 g
s
.651 .758 .928 r
.58893 .61749 m .57978 .62026 L .57742 .61771 L p F P
0 g
s
.65 .757 .928 r
.17598 .61455 m .16752 .6173 L .17053 .61985 L p F P
0 g
s
.65 .757 .928 r
.17053 .61985 m .17898 .61711 L .17598 .61455 L p F P
0 g
s
.651 .758 .928 r
.87177 .61987 m .88141 .61709 L .88329 .61964 L p F P
0 g
s
.651 .758 .928 r
.88141 .61709 m .87177 .61987 L .86986 .61733 L p F P
0 g
s
.65 .757 .928 r
.31667 .61469 m .30798 .61746 L .31077 .62 L p F P
0 g
s
.65 .757 .928 r
.31077 .62 m .31945 .61725 L .31667 .61469 L p F P
0 g
s
.651 .758 .928 r
.73153 .62001 m .74093 .61724 L .74304 .61979 L p F P
0 g
s
.651 .758 .928 r
.74093 .61724 m .73153 .62001 L .7294 .61746 L p F P
0 g
s
.65 .757 .928 r
.45739 .61472 m .44845 .61749 L .45102 .62004 L p F P
0 g
s
.65 .757 .928 r
.45102 .62004 m .45995 .61728 L .45739 .61472 L p F P
0 g
s
.651 .758 .928 r
.59128 .62004 m .60044 .61728 L .60277 .61983 L p F P
0 g
s
.651 .758 .928 r
.60044 .61728 m .59128 .62004 L .58893 .61749 L p F P
0 g
s
.651 .758 .928 r
.88329 .61964 m .89295 .61686 L .89482 .6194 L p F P
0 g
s
.651 .758 .928 r
.89295 .61686 m .88329 .61964 L .88141 .61709 L p F P
0 g
s
.65 .757 .928 r
.18745 .61436 m .17898 .61711 L .18197 .61966 L p F P
0 g
s
.65 .757 .928 r
.18197 .61966 m .19043 .61692 L .18745 .61436 L p F P
0 g
s
.651 .758 .928 r
.74304 .61979 m .75246 .61702 L .75455 .61957 L p F P
0 g
s
.651 .758 .928 r
.75246 .61702 m .74304 .61979 L .74093 .61724 L p F P
0 g
s
.65 .757 .928 r
.32817 .61448 m .31945 .61725 L .32223 .6198 L p F P
0 g
s
.65 .757 .928 r
.32223 .6198 m .33093 .61704 L .32817 .61448 L p F P
0 g
s
.651 .758 .928 r
.60277 .61983 m .61195 .61707 L .61427 .61962 L p F P
0 g
s
.651 .758 .928 r
.61195 .61707 m .60277 .61983 L .60044 .61728 L p F P
0 g
s
.65 .757 .928 r
.4625 .61983 m .47144 .61707 L .47398 .61962 L p F P
0 g
s
.65 .757 .928 r
.4689 .61451 m .45995 .61728 L .4625 .61983 L p F P
0 g
s
.65 .757 .928 r
.4625 .61983 m .47144 .61707 L .4689 .61451 L p F P
0 g
s
.651 .758 .928 r
.89482 .6194 m .9045 .61662 L .90636 .61916 L p F P
0 g
s
.651 .758 .928 r
.9045 .61662 m .89482 .6194 L .89295 .61686 L p F P
0 g
s
.65 .757 .928 r
.19893 .61416 m .19043 .61692 L .19341 .61947 L p F P
0 g
s
.65 .757 .928 r
.19341 .61947 m .20189 .61672 L .19893 .61416 L p F P
0 g
s
.651 .758 .928 r
.75455 .61957 m .764 .61681 L .76607 .61935 L p F P
0 g
s
.651 .758 .928 r
.764 .61681 m .75455 .61957 L .75246 .61702 L p F P
0 g
s
.65 .757 .928 r
.33967 .61427 m .33093 .61704 L .33369 .61959 L p F P
0 g
s
.65 .757 .928 r
.33369 .61959 m .34241 .61683 L .33967 .61427 L p F P
0 g
s
.651 .758 .928 r
.61427 .61962 m .62347 .61685 L .62577 .6194 L p F P
0 g
s
.651 .758 .928 r
.62347 .61685 m .61427 .61962 L .61195 .61707 L p F P
0 g
s
0 0 .355 r
.52577 .56646 m .52577 .56647 L .52577 .56229 L p F P
0 g
s
0 0 .355 r
.52577 .56229 m .52577 .56228 L .52577 .56646 L p F P
0 g
s
.759 .498 .539 r
.52575 .56646 m .52577 .56647 L .52577 .56229 L p F P
0 g
s
.759 .498 .539 r
.52577 .56229 m .52575 .56228 L .52575 .56646 L p F P
0 g
s
.65 .757 .928 r
.47398 .61962 m .48294 .61686 L .48546 .61941 L p F P
0 g
s
.65 .757 .928 r
.48294 .61686 m .47398 .61962 L .47144 .61707 L p F P
0 g
s
0 0 .356 r
.52576 .56228 m .52575 .56228 L .52575 .56646 L p F P
0 g
s
.759 .498 .539 r
.52576 .56228 m .52577 .56228 L .52577 .56646 L p F P
0 g
s
.759 .498 .539 r
.52577 .56646 m .52576 .56646 L .52576 .56228 L p F P
0 g
s
0 0 .356 r
.52575 .56646 m .52576 .56646 L .52576 .56228 L p F P
0 g
s
.651 .759 .928 r
.90636 .61916 m .91606 .61637 L .91789 .61892 L p F P
0 g
s
.651 .759 .928 r
.91606 .61637 m .90636 .61916 L .9045 .61662 L p F P
0 g
s
.65 .757 .928 r
.21041 .61396 m .20189 .61672 L .20485 .61928 L p F P
0 g
s
.65 .757 .928 r
.20485 .61928 m .21336 .61653 L .21041 .61396 L p F P
0 g
s
.651 .758 .928 r
.76607 .61935 m .77554 .61659 L .77759 .61913 L p F P
0 g
s
.651 .758 .928 r
.77554 .61659 m .76607 .61935 L .764 .61681 L p F P
0 g
s
.65 .757 .928 r
.35117 .61406 m .34241 .61683 L .34515 .61938 L p F P
0 g
s
.65 .757 .928 r
.34515 .61938 m .3539 .61662 L .35117 .61406 L p F P
0 g
s
.651 .758 .928 r
.62577 .6194 m .63499 .61664 L .63727 .61919 L p F P
0 g
s
.651 .758 .928 r
.63499 .61664 m .62577 .6194 L .62347 .61685 L p F P
0 g
s
.65 .757 .928 r
.48546 .61941 m .49444 .61665 L .49694 .6192 L p F P
0 g
s
.65 .757 .928 r
.49444 .61665 m .48546 .61941 L .48294 .61686 L p F P
0 g
s
.65 .757 .928 r
.22189 .61376 m .21336 .61653 L .2163 .61908 L p F P
0 g
s
.65 .757 .928 r
.2163 .61908 m .22482 .61633 L .22189 .61376 L p F P
0 g
s
.651 .758 .928 r
.77759 .61913 m .78708 .61636 L .78912 .61891 L p F P
0 g
s
.651 .758 .928 r
.78708 .61636 m .77759 .61913 L .77554 .61659 L p F P
0 g
s
.65 .757 .928 r
.36267 .61385 m .3539 .61662 L .35661 .61917 L p F P
0 g
s
.65 .757 .928 r
.35661 .61917 m .36538 .61641 L .36267 .61385 L p F P
0 g
s
.651 .758 .928 r
.63727 .61919 m .64652 .61642 L .64878 .61897 L p F P
0 g
s
.651 .758 .928 r
.64652 .61642 m .63727 .61919 L .63499 .61664 L p F P
0 g
s
.65 .757 .928 r
.49694 .6192 m .50595 .61643 L .50843 .61898 L p F P
0 g
s
.65 .757 .928 r
.50595 .61643 m .49694 .6192 L .49444 .61665 L p F P
0 g
s
.65 .757 .928 r
.23338 .61356 m .22482 .61633 L .22775 .61888 L p F P
0 g
s
.65 .757 .928 r
.22775 .61888 m .23629 .61613 L .23338 .61356 L p F P
0 g
s
.651 .758 .928 r
.78912 .61891 m .79862 .61614 L .80064 .61869 L p F P
0 g
s
.651 .758 .928 r
.79862 .61614 m .78912 .61891 L .78708 .61636 L p F P
0 g
s
.65 .757 .928 r
.37418 .61364 m .36538 .61641 L .36808 .61896 L p F P
0 g
s
.65 .757 .928 r
.36808 .61896 m .37687 .6162 L .37418 .61364 L p F P
0 g
s
.651 .758 .928 r
.64878 .61897 m .65804 .61621 L .66028 .61876 L p F P
0 g
s
.651 .758 .928 r
.65804 .61621 m .64878 .61897 L .64652 .61642 L p F P
0 g
s
.65 .757 .928 r
.50843 .61898 m .51746 .61622 L .51992 .61877 L p F P
0 g
s
.65 .757 .928 r
.51746 .61622 m .50843 .61898 L .50595 .61643 L p F P
0 g
s
.65 .757 .928 r
.24487 .61336 m .23629 .61613 L .2392 .61868 L p F P
0 g
s
.65 .757 .928 r
.2392 .61868 m .24777 .61592 L .24487 .61336 L p F P
0 g
s
.651 .758 .928 r
.80064 .61869 m .81017 .61592 L .81217 .61847 L p F P
0 g
s
.651 .758 .928 r
.81017 .61592 m .80064 .61869 L .79862 .61614 L p F P
0 g
s
.65 .757 .928 r
.38569 .61343 m .37687 .6162 L .37956 .61876 L p F P
0 g
s
.65 .757 .928 r
.37956 .61876 m .38837 .61599 L .38569 .61343 L p F P
0 g
s
.651 .758 .928 r
.66028 .61876 m .66957 .61599 L .6718 .61854 L p F P
0 g
s
.651 .758 .928 r
.66957 .61599 m .66028 .61876 L .65804 .61621 L p F P
0 g
s
.65 .757 .928 r
.51992 .61877 m .52897 .61601 L .53141 .61856 L p F P
0 g
s
.65 .757 .928 r
.52897 .61601 m .51992 .61877 L .51746 .61622 L p F P
0 g
s
.651 .758 .928 r
.81217 .61847 m .82172 .61569 L .8237 .61824 L p F P
0 g
s
.651 .758 .928 r
.82172 .61569 m .81217 .61847 L .81017 .61592 L p F P
0 g
s
.65 .757 .928 r
.25637 .61316 m .24777 .61592 L .25065 .61848 L p F P
0 g
s
.65 .757 .928 r
.25065 .61848 m .25924 .61572 L .25637 .61316 L p F P
0 g
s
.651 .758 .928 r
.6718 .61854 m .68111 .61577 L .68331 .61833 L p F P
0 g
s
.651 .758 .928 r
.68111 .61577 m .6718 .61854 L .66957 .61599 L p F P
0 g
s
.65 .757 .928 r
.39721 .61322 m .38837 .61599 L .39103 .61855 L p F P
0 g
s
.65 .757 .928 r
.39103 .61855 m .39986 .61578 L .39721 .61322 L p F P
0 g
s
.65 .758 .928 r
.53141 .61856 m .54048 .61579 L .54291 .61835 L p F P
0 g
s
.65 .758 .928 r
.54048 .61579 m .53141 .61856 L .52897 .61601 L p F P
0 g
s
.651 .758 .928 r
.8237 .61824 m .83327 .61547 L .83524 .61802 L p F P
0 g
s
.651 .758 .928 r
.83327 .61547 m .8237 .61824 L .82172 .61569 L p F P
0 g
s
.65 .757 .928 r
.26786 .61295 m .25924 .61572 L .26211 .61828 L p F P
0 g
s
.65 .757 .928 r
.26211 .61828 m .27072 .61552 L .26786 .61295 L p F P
0 g
s
.651 .758 .928 r
.68331 .61833 m .69264 .61556 L .69483 .61811 L p F P
0 g
s
.651 .758 .928 r
.69264 .61556 m .68331 .61833 L .68111 .61577 L p F P
0 g
s
.65 .757 .928 r
.40872 .61301 m .39986 .61578 L .40251 .61834 L p F P
0 g
s
.65 .757 .928 r
.40251 .61834 m .41136 .61557 L .40872 .61301 L p F P
0 g
s
.651 .758 .928 r
.54291 .61835 m .552 .61558 L .55441 .61813 L p F P
0 g
s
.651 .758 .928 r
.552 .61558 m .54291 .61835 L .54048 .61579 L p F P
0 g
s
.651 .758 .928 r
.83524 .61802 m .84483 .61524 L .84678 .61779 L p F P
0 g
s
.651 .758 .928 r
.84483 .61524 m .83524 .61802 L .83327 .61547 L p F P
0 g
s
.65 .757 .928 r
.27936 .61275 m .27072 .61552 L .27357 .61807 L p F P
0 g
s
.65 .757 .928 r
.27357 .61807 m .28221 .61531 L .27936 .61275 L p F P
0 g
s
.651 .758 .928 r
.69483 .61811 m .70418 .61534 L .70635 .6179 L p F P
0 g
s
.651 .758 .928 r
.70418 .61534 m .69483 .61811 L .69264 .61556 L p F P
0 g
s
.65 .757 .928 r
.42024 .6128 m .41136 .61557 L .41399 .61813 L p F P
0 g
s
.65 .757 .928 r
.41399 .61813 m .42286 .61536 L .42024 .6128 L p F P
0 g
s
.651 .758 .928 r
.55441 .61813 m .56352 .61537 L .56591 .61792 L p F P
0 g
s
.651 .758 .928 r
.56352 .61537 m .55441 .61813 L .552 .61558 L p F P
0 g
s
.651 .758 .928 r
.84678 .61779 m .85639 .61501 L .85832 .61756 L p F P
0 g
s
.651 .758 .928 r
.85639 .61501 m .84678 .61779 L .84483 .61524 L p F P
0 g
s
.65 .757 .928 r
.29087 .61254 m .28221 .61531 L .28504 .61787 L p F P
0 g
s
.65 .757 .928 r
.28504 .61787 m .29369 .6151 L .29087 .61254 L p F P
0 g
s
.651 .758 .928 r
.70635 .6179 m .71572 .61512 L .71787 .61768 L p F P
0 g
s
.651 .758 .928 r
.71572 .61512 m .70635 .6179 L .70418 .61534 L p F P
0 g
s
.65 .757 .928 r
.43176 .61258 m .42286 .61536 L .42547 .61791 L p F P
0 g
s
.65 .757 .928 r
.42547 .61791 m .43437 .61515 L .43176 .61258 L p F P
0 g
s
.651 .758 .928 r
.56591 .61792 m .57505 .61515 L .57742 .61771 L p F P
0 g
s
.651 .758 .928 r
.57505 .61515 m .56591 .61792 L .56352 .61537 L p F P
0 g
s
.651 .758 .928 r
.85832 .61756 m .86795 .61478 L .86986 .61733 L p F P
0 g
s
.651 .758 .928 r
.86795 .61478 m .85832 .61756 L .85639 .61501 L p F P
0 g
s
.65 .757 .928 r
.30237 .61233 m .29369 .6151 L .29651 .61766 L p F P
0 g
s
.65 .757 .928 r
.29651 .61766 m .30518 .6149 L .30237 .61233 L p F P
0 g
s
.651 .758 .928 r
.71787 .61768 m .72727 .61491 L .7294 .61746 L p F P
0 g
s
.651 .758 .928 r
.72727 .61491 m .71787 .61768 L .71572 .61512 L p F P
0 g
s
.65 .757 .928 r
.44329 .61237 m .43437 .61515 L .43696 .6177 L p F P
0 g
s
.65 .757 .928 r
.43696 .6177 m .44588 .61494 L .44329 .61237 L p F P
0 g
s
.651 .758 .928 r
.57742 .61771 m .58657 .61494 L .58893 .61749 L p F P
0 g
s
.651 .758 .928 r
.58657 .61494 m .57742 .61771 L .57505 .61515 L p F P
0 g
s
.65 .757 .928 r
.17296 .61198 m .1645 .61474 L .16752 .6173 L p F P
0 g
s
.65 .757 .928 r
.16752 .6173 m .17598 .61455 L .17296 .61198 L p F P
0 g
s
.651 .758 .928 r
.86986 .61733 m .87951 .61454 L .88141 .61709 L p F P
0 g
s
.651 .758 .928 r
.87951 .61454 m .86986 .61733 L .86795 .61478 L p F P
0 g
s
.65 .757 .928 r
.31388 .61212 m .30518 .6149 L .30798 .61746 L p F P
0 g
s
.65 .757 .928 r
.30798 .61746 m .31667 .61469 L .31388 .61212 L p F P
0 g
s
.651 .758 .928 r
.73881 .61469 m .7294 .61746 L .72727 .61491 L p F P
0 g
s
.651 .758 .928 r
.7294 .61746 m .73881 .61469 L .74093 .61724 L p F P
0 g
s
.65 .757 .928 r
.45482 .61216 m .44588 .61494 L .44845 .61749 L p F P
0 g
s
.65 .757 .928 r
.44845 .61749 m .45739 .61472 L .45482 .61216 L p F P
0 g
s
.651 .758 .928 r
.58893 .61749 m .5981 .61472 L .60044 .61728 L p F P
0 g
s
.651 .758 .928 r
.5981 .61472 m .58893 .61749 L .58657 .61494 L p F P
0 g
s
0 0 .357 r
.52577 .57065 m .52577 .57066 L .52577 .56647 L p F P
0 g
s
0 0 .357 r
.52577 .56647 m .52577 .56646 L .52577 .57065 L p F P
0 g
s
.758 .497 .539 r
.52575 .57066 m .52577 .57066 L .52577 .56647 L p F P
0 g
s
.758 .497 .539 r
.52577 .56647 m .52575 .56646 L .52575 .57066 L p F P
0 g
s
0 0 .358 r
.52576 .56646 m .52575 .56646 L .52575 .57066 L p F P
0 g
s
.758 .497 .539 r
.52576 .56646 m .52577 .56646 L .52577 .57065 L p F P
0 g
s
.758 .497 .539 r
.52577 .57065 m .52576 .57065 L .52576 .56646 L p F P
0 g
s
0 0 .358 r
.52575 .57066 m .52576 .57065 L .52576 .56646 L p F P
0 g
s
.651 .758 .928 r
.88141 .61709 m .89108 .6143 L .89295 .61686 L p F P
0 g
s
.651 .758 .928 r
.89108 .6143 m .88141 .61709 L .87951 .61454 L p F P
0 g
s
.65 .757 .928 r
.18446 .61179 m .17598 .61455 L .17898 .61711 L p F P
0 g
s
.65 .757 .928 r
.17898 .61711 m .18745 .61436 L .18446 .61179 L p F P
0 g
s
.651 .758 .928 r
.74093 .61724 m .75036 .61447 L .75246 .61702 L p F P
0 g
s
.651 .758 .928 r
.75036 .61447 m .74093 .61724 L .73881 .61469 L p F P
0 g
s
.65 .757 .928 r
.3254 .61191 m .31667 .61469 L .31945 .61725 L p F P
0 g
s
.65 .757 .928 r
.31945 .61725 m .32817 .61448 L .3254 .61191 L p F P
0 g
s
.651 .758 .928 r
.60044 .61728 m .60963 .61451 L .61195 .61707 L p F P
0 g
s
.651 .758 .928 r
.60963 .61451 m .60044 .61728 L .5981 .61472 L p F P
0 g
s
.65 .757 .928 r
.46635 .61194 m .45739 .61472 L .45995 .61728 L p F P
0 g
s
.65 .757 .928 r
.45995 .61728 m .4689 .61451 L .46635 .61194 L p F P
0 g
s
.651 .758 .928 r
.89295 .61686 m .90265 .61406 L .9045 .61662 L p F P
0 g
s
.651 .758 .928 r
.90265 .61406 m .89295 .61686 L .89108 .6143 L p F P
0 g
s
.65 .757 .928 r
.19595 .61159 m .18745 .61436 L .19043 .61692 L p F P
0 g
s
.65 .757 .928 r
.19043 .61692 m .19893 .61416 L .19595 .61159 L p F P
0 g
s
.651 .758 .928 r
.75246 .61702 m .76192 .61425 L .764 .61681 L p F P
0 g
s
.651 .758 .928 r
.76192 .61425 m .75246 .61702 L .75036 .61447 L p F P
0 g
s
.65 .757 .928 r
.33691 .6117 m .32817 .61448 L .33093 .61704 L p F P
0 g
s
.65 .757 .928 r
.33093 .61704 m .33967 .61427 L .33691 .6117 L p F P
0 g
s
.651 .758 .928 r
.61195 .61707 m .62117 .61429 L .62347 .61685 L p F P
0 g
s
.651 .758 .928 r
.62117 .61429 m .61195 .61707 L .60963 .61451 L p F P
0 g
s
.65 .757 .928 r
.47144 .61707 m .48042 .6143 L .48294 .61686 L p F P
0 g
s
.65 .757 .928 r
.47789 .61173 m .4689 .61451 L .47144 .61707 L p F P
0 g
s
.65 .757 .928 r
.47144 .61707 m .48042 .6143 L .47789 .61173 L p F P
0 g
s
.651 .759 .928 r
.9045 .61662 m .91422 .61382 L .91606 .61637 L p F P
0 g
s
.651 .759 .928 r
.91422 .61382 m .9045 .61662 L .90265 .61406 L p F P
0 g
s
.65 .757 .928 r
.20745 .61139 m .19893 .61416 L .20189 .61672 L p F P
0 g
s
.65 .757 .928 r
.20189 .61672 m .21041 .61396 L .20745 .61139 L p F P
0 g
s
.651 .758 .928 r
.764 .61681 m .77347 .61403 L .77554 .61659 L p F P
0 g
s
.651 .758 .928 r
.77347 .61403 m .764 .61681 L .76192 .61425 L p F P
0 g
s
.65 .757 .928 r
.34843 .61149 m .33967 .61427 L .34241 .61683 L p F P
0 g
s
.65 .757 .928 r
.34241 .61683 m .35117 .61406 L .34843 .61149 L p F P
0 g
s
.651 .758 .928 r
.62347 .61685 m .63271 .61408 L .63499 .61664 L p F P
0 g
s
.651 .758 .928 r
.63271 .61408 m .62347 .61685 L .62117 .61429 L p F P
0 g
s
.65 .757 .928 r
.48294 .61686 m .49194 .61409 L .49444 .61665 L p F P
0 g
s
.65 .757 .928 r
.49194 .61409 m .48294 .61686 L .48042 .6143 L p F P
0 g
s
.65 .757 .928 r
.21895 .61119 m .21041 .61396 L .21336 .61653 L p F P
0 g
s
.65 .757 .928 r
.21336 .61653 m .22189 .61376 L .21895 .61119 L p F P
0 g
s
.651 .758 .928 r
.77554 .61659 m .78503 .61381 L .78708 .61636 L p F P
0 g
s
.651 .758 .928 r
.78503 .61381 m .77554 .61659 L .77347 .61403 L p F P
0 g
s
.65 .757 .928 r
.35996 .61128 m .35117 .61406 L .3539 .61662 L p F P
0 g
s
.65 .757 .928 r
.3539 .61662 m .36267 .61385 L .35996 .61128 L p F P
0 g
s
.651 .758 .928 r
.63499 .61664 m .64425 .61386 L .64652 .61642 L p F P
0 g
s
.651 .758 .928 r
.64425 .61386 m .63499 .61664 L .63271 .61408 L p F P
0 g
s
.65 .757 .928 r
.49444 .61665 m .50346 .61387 L .50595 .61643 L p F P
0 g
s
.65 .757 .928 r
.50346 .61387 m .49444 .61665 L .49194 .61409 L p F P
0 g
s
.65 .757 .928 r
.23046 .61099 m .22189 .61376 L .22482 .61633 L p F P
0 g
s
.65 .757 .928 r
.22482 .61633 m .23338 .61356 L .23046 .61099 L p F P
0 g
s
.651 .758 .928 r
.78708 .61636 m .7966 .61358 L .79862 .61614 L p F P
0 g
s
.651 .758 .928 r
.7966 .61358 m .78708 .61636 L .78503 .61381 L p F P
0 g
s
.65 .757 .928 r
.37148 .61107 m .36267 .61385 L .36538 .61641 L p F P
0 g
s
.65 .757 .928 r
.36538 .61641 m .37418 .61364 L .37148 .61107 L p F P
0 g
s
.651 .758 .928 r
.64652 .61642 m .65579 .61365 L .65804 .61621 L p F P
0 g
s
.651 .758 .928 r
.65579 .61365 m .64652 .61642 L .64425 .61386 L p F P
0 g
s
.65 .757 .928 r
.50595 .61643 m .51499 .61366 L .51746 .61622 L p F P
0 g
s
.65 .757 .928 r
.51499 .61366 m .50595 .61643 L .50346 .61387 L p F P
0 g
s
.65 .757 .928 r
.24197 .61079 m .23338 .61356 L .23629 .61613 L p F P
0 g
s
.65 .757 .928 r
.23629 .61613 m .24487 .61336 L .24197 .61079 L p F P
0 g
s
.651 .758 .928 r
.79862 .61614 m .80816 .61336 L .81017 .61592 L p F P
0 g
s
.651 .758 .928 r
.80816 .61336 m .79862 .61614 L .7966 .61358 L p F P
0 g
s
.65 .757 .928 r
.38301 .61086 m .37418 .61364 L .37687 .6162 L p F P
0 g
s
.65 .757 .928 r
.37687 .6162 m .38569 .61343 L .38301 .61086 L p F P
0 g
s
.651 .758 .928 r
.65804 .61621 m .66734 .61343 L .66957 .61599 L p F P
0 g
s
.651 .758 .928 r
.66734 .61343 m .65804 .61621 L .65579 .61365 L p F P
0 g
s
.65 .757 .928 r
.51746 .61622 m .52652 .61345 L .52897 .61601 L p F P
0 g
s
.65 .757 .928 r
.52652 .61345 m .51746 .61622 L .51499 .61366 L p F P
0 g
s
.651 .758 .928 r
.81017 .61592 m .81973 .61313 L .82172 .61569 L p F P
0 g
s
.651 .758 .928 r
.81973 .61313 m .81017 .61592 L .80816 .61336 L p F P
0 g
s
.65 .757 .928 r
.25348 .61058 m .24487 .61336 L .24777 .61592 L p F P
0 g
s
.65 .757 .928 r
.24777 .61592 m .25637 .61316 L .25348 .61058 L p F P
0 g
s
.651 .758 .928 r
.66957 .61599 m .67889 .61321 L .68111 .61577 L p F P
0 g
s
.651 .758 .928 r
.67889 .61321 m .66957 .61599 L .66734 .61343 L p F P
0 g
s
.65 .757 .928 r
.39454 .61065 m .38569 .61343 L .38837 .61599 L p F P
0 g
s
.65 .757 .928 r
.38837 .61599 m .39721 .61322 L .39454 .61065 L p F P
0 g
s
.65 .758 .928 r
.52897 .61601 m .53805 .61323 L .54048 .61579 L p F P
0 g
s
.65 .757 .928 r
.53805 .61323 m .52897 .61601 L .52652 .61345 L p F P
0 g
s
.651 .758 .928 r
.82172 .61569 m .8313 .61291 L .83327 .61547 L p F P
0 g
s
.651 .758 .928 r
.8313 .61291 m .82172 .61569 L .81973 .61313 L p F P
0 g
s
.65 .757 .928 r
.26499 .61038 m .25637 .61316 L .25924 .61572 L p F P
0 g
s
.65 .757 .928 r
.25924 .61572 m .26786 .61295 L .26499 .61038 L p F P
0 g
s
.651 .758 .928 r
.68111 .61577 m .69045 .613 L .69264 .61556 L p F P
0 g
s
.651 .758 .928 r
.69045 .613 m .68111 .61577 L .67889 .61321 L p F P
0 g
s
.65 .757 .928 r
.40608 .61044 m .39721 .61322 L .39986 .61578 L p F P
0 g
s
.65 .757 .928 r
.39986 .61578 m .40872 .61301 L .40608 .61044 L p F P
0 g
s
.651 .758 .928 r
.54048 .61579 m .54958 .61302 L .552 .61558 L p F P
0 g
s
.651 .758 .928 r
.54958 .61302 m .54048 .61579 L .53805 .61323 L p F P
0 g
s
.651 .758 .928 r
.83327 .61547 m .84287 .61268 L .84483 .61524 L p F P
0 g
s
.651 .758 .928 r
.84287 .61268 m .83327 .61547 L .8313 .61291 L p F P
0 g
s
.65 .757 .928 r
.27651 .61017 m .26786 .61295 L .27072 .61552 L p F P
0 g
s
.65 .757 .928 r
.27072 .61552 m .27936 .61275 L .27651 .61017 L p F P
0 g
s
.651 .758 .928 r
.69264 .61556 m .702 .61278 L .70418 .61534 L p F P
0 g
s
.651 .758 .928 r
.702 .61278 m .69264 .61556 L .69045 .613 L p F P
0 g
s
.65 .757 .928 r
.41761 .61022 m .40872 .61301 L .41136 .61557 L p F P
0 g
s
.65 .757 .928 r
.41136 .61557 m .42024 .6128 L .41761 .61022 L p F P
0 g
s
.651 .758 .928 r
.552 .61558 m .56112 .6128 L .56352 .61537 L p F P
0 g
s
.651 .758 .928 r
.56112 .6128 m .552 .61558 L .54958 .61302 L p F P
0 g
s
.651 .758 .928 r
.84483 .61524 m .85445 .61245 L .85639 .61501 L p F P
0 g
s
.651 .758 .928 r
.85445 .61245 m .84483 .61524 L .84287 .61268 L p F P
0 g
s
.65 .757 .928 r
.28803 .60997 m .27936 .61275 L .28221 .61531 L p F P
0 g
s
.65 .757 .928 r
.28221 .61531 m .29087 .61254 L .28803 .60997 L p F P
0 g
s
.651 .758 .928 r
.70418 .61534 m .71356 .61256 L .71572 .61512 L p F P
0 g
s
.651 .758 .928 r
.71356 .61256 m .70418 .61534 L .702 .61278 L p F P
0 g
s
.65 .757 .928 r
.42915 .61001 m .42024 .6128 L .42286 .61536 L p F P
0 g
s
.65 .757 .928 r
.42286 .61536 m .43176 .61258 L .42915 .61001 L p F P
0 g
s
0 0 .36 r
.52577 .57485 m .52577 .57486 L .52577 .57066 L p F P
0 g
s
0 0 .36 r
.52577 .57066 m .52577 .57065 L .52577 .57485 L p F P
0 g
s
.757 .497 .539 r
.52575 .57486 m .52577 .57486 L .52577 .57066 L p F P
0 g
s
.757 .497 .539 r
.52577 .57066 m .52575 .57066 L .52575 .57486 L p F P
0 g
s
.651 .758 .928 r
.56352 .61537 m .57266 .61259 L .57505 .61515 L p F P
0 g
s
.651 .758 .928 r
.57266 .61259 m .56352 .61537 L .56112 .6128 L p F P
0 g
s
0 0 .36 r
.52576 .57065 m .52575 .57066 L .52575 .57486 L p F P
0 g
s
.757 .497 .539 r
.52576 .57065 m .52577 .57065 L .52577 .57485 L p F P
0 g
s
.757 .497 .539 r
.52577 .57485 m .52576 .57485 L .52576 .57065 L p F P
0 g
s
0 0 .36 r
.52575 .57486 m .52576 .57485 L .52576 .57065 L p F P
0 g
s
.651 .758 .928 r
.85639 .61501 m .86603 .61222 L .86795 .61478 L p F P
0 g
s
.651 .758 .928 r
.86603 .61222 m .85639 .61501 L .85445 .61245 L p F P
0 g
s
.65 .757 .928 r
.29956 .60976 m .29087 .61254 L .29369 .6151 L p F P
0 g
s
.65 .757 .928 r
.29369 .6151 m .30237 .61233 L .29956 .60976 L p F P
0 g
s
.651 .758 .928 r
.71572 .61512 m .72513 .61234 L .72727 .61491 L p F P
0 g
s
.651 .758 .928 r
.72513 .61234 m .71572 .61512 L .71356 .61256 L p F P
0 g
s
.65 .757 .928 r
.4407 .6098 m .43176 .61258 L .43437 .61515 L p F P
0 g
s
.65 .757 .928 r
.43437 .61515 m .44329 .61237 L .4407 .6098 L p F P
0 g
s
.651 .758 .928 r
.57505 .61515 m .58421 .61237 L .58657 .61494 L p F P
0 g
s
.651 .758 .928 r
.58421 .61237 m .57505 .61515 L .57266 .61259 L p F P
0 g
s
.65 .757 .928 r
.16994 .6094 m .16148 .61217 L .1645 .61474 L p F P
0 g
s
.65 .757 .928 r
.1645 .61474 m .17296 .61198 L .16994 .6094 L p F P
0 g
s
.651 .758 .928 r
.86795 .61478 m .87761 .61198 L .87951 .61454 L p F P
0 g
s
.651 .758 .928 r
.87761 .61198 m .86795 .61478 L .86603 .61222 L p F P
0 g
s
.65 .757 .928 r
.31109 .60955 m .30237 .61233 L .30518 .6149 L p F P
0 g
s
.65 .757 .928 r
.30518 .6149 m .31388 .61212 L .31109 .60955 L p F P
0 g
s
.651 .758 .928 r
.72727 .61491 m .73669 .61212 L .73881 .61469 L p F P
0 g
s
.651 .758 .928 r
.73669 .61212 m .72727 .61491 L .72513 .61234 L p F P
0 g
s
.65 .757 .928 r
.45224 .60958 m .44329 .61237 L .44588 .61494 L p F P
0 g
s
.65 .757 .928 r
.44588 .61494 m .45482 .61216 L .45224 .60958 L p F P
0 g
s
.651 .758 .928 r
.58657 .61494 m .59576 .61216 L .5981 .61472 L p F P
0 g
s
.651 .758 .928 r
.59576 .61216 m .58657 .61494 L .58421 .61237 L p F P
0 g
s
.651 .758 .928 r
.87951 .61454 m .8892 .61174 L .89108 .6143 L p F P
0 g
s
.651 .758 .928 r
.8892 .61174 m .87951 .61454 L .87761 .61198 L p F P
0 g
s
.65 .757 .928 r
.18145 .60921 m .17296 .61198 L .17598 .61455 L p F P
0 g
s
.65 .757 .928 r
.17598 .61455 m .18446 .61179 L .18145 .60921 L p F P
0 g
s
.651 .758 .928 r
.74826 .6119 m .73881 .61469 L .73669 .61212 L p F P
0 g
s
.651 .758 .928 r
.73881 .61469 m .74826 .6119 L .75036 .61447 L p F P
0 g
s
.65 .757 .928 r
.32262 .60934 m .31388 .61212 L .31667 .61469 L p F P
0 g
s
.65 .757 .928 r
.31667 .61469 m .3254 .61191 L .32262 .60934 L p F P
0 g
s
.651 .758 .928 r
.5981 .61472 m .60731 .61194 L .60963 .61451 L p F P
0 g
s
.651 .758 .928 r
.60731 .61194 m .5981 .61472 L .59576 .61216 L p F P
0 g
s
.65 .757 .928 r
.46379 .60937 m .45482 .61216 L .45739 .61472 L p F P
0 g
s
.65 .757 .928 r
.45739 .61472 m .46635 .61194 L .46379 .60937 L p F P
0 g
s
.651 .758 .928 r
.89108 .6143 m .90078 .6115 L .90265 .61406 L p F P
0 g
s
.651 .758 .928 r
.90078 .6115 m .89108 .6143 L .8892 .61174 L p F P
0 g
s
.65 .757 .928 r
.19297 .60901 m .18446 .61179 L .18745 .61436 L p F P
0 g
s
.65 .757 .928 r
.18745 .61436 m .19595 .61159 L .19297 .60901 L p F P
0 g
s
.651 .758 .928 r
.75036 .61447 m .75983 .61168 L .76192 .61425 L p F P
0 g
s
.651 .758 .928 r
.75983 .61168 m .75036 .61447 L .74826 .6119 L p F P
0 g
s
.65 .757 .928 r
.33415 .60913 m .3254 .61191 L .32817 .61448 L p F P
0 g
s
.65 .757 .928 r
.32817 .61448 m .33691 .6117 L .33415 .60913 L p F P
0 g
s
.651 .758 .928 r
.60963 .61451 m .61886 .61173 L .62117 .61429 L p F P
0 g
s
.651 .758 .928 r
.61886 .61173 m .60963 .61451 L .60731 .61194 L p F P
0 g
s
.65 .757 .928 r
.47535 .60916 m .46635 .61194 L .4689 .61451 L p F P
0 g
s
.65 .757 .928 r
.4689 .61451 m .47789 .61173 L .47535 .60916 L p F P
0 g
s
.651 .759 .928 r
.90265 .61406 m .91237 .61126 L .91422 .61382 L p F P
0 g
s
.651 .758 .928 r
.91237 .61126 m .90265 .61406 L .90078 .6115 L p F P
0 g
s
.65 .757 .928 r
.20448 .60881 m .19595 .61159 L .19893 .61416 L p F P
0 g
s
.65 .757 .928 r
.19893 .61416 m .20745 .61139 L .20448 .60881 L p F P
0 g
s
.651 .758 .928 r
.76192 .61425 m .77141 .61146 L .77347 .61403 L p F P
0 g
s
.651 .758 .928 r
.77141 .61146 m .76192 .61425 L .75983 .61168 L p F P
0 g
s
.65 .757 .928 r
.34569 .60892 m .33691 .6117 L .33967 .61427 L p F P
0 g
s
.65 .757 .928 r
.33967 .61427 m .34843 .61149 L .34569 .60892 L p F P
0 g
s
.651 .758 .928 r
.62117 .61429 m .63042 .61151 L .63271 .61408 L p F P
0 g
s
.651 .758 .928 r
.63042 .61151 m .62117 .61429 L .61886 .61173 L p F P
0 g
s
.65 .757 .928 r
.48042 .6143 m .48942 .61152 L .49194 .61409 L p F P
0 g
s
.65 .757 .928 r
.4869 .60894 m .47789 .61173 L .48042 .6143 L p F P
0 g
s
.65 .757 .928 r
.48042 .6143 m .48942 .61152 L .4869 .60894 L p F P
0 g
s
.65 .757 .928 r
.216 .60861 m .20745 .61139 L .21041 .61396 L p F P
0 g
s
.65 .757 .928 r
.21041 .61396 m .21895 .61119 L .216 .60861 L p F P
0 g
s
.651 .758 .928 r
.77347 .61403 m .78298 .61124 L .78503 .61381 L p F P
0 g
s
.651 .758 .928 r
.78298 .61124 m .77347 .61403 L .77141 .61146 L p F P
0 g
s
.65 .757 .928 r
.35723 .60871 m .34843 .61149 L .35117 .61406 L p F P
0 g
s
.65 .757 .928 r
.35117 .61406 m .35996 .61128 L .35723 .60871 L p F P
0 g
s
.651 .758 .928 r
.63271 .61408 m .64198 .61129 L .64425 .61386 L p F P
0 g
s
.651 .758 .928 r
.64198 .61129 m .63271 .61408 L .63042 .61151 L p F P
0 g
s
.65 .757 .928 r
.49194 .61409 m .50097 .6113 L .50346 .61387 L p F P
0 g
s
.65 .757 .928 r
.50097 .6113 m .49194 .61409 L .48942 .61152 L p F P
0 g
s
.65 .757 .928 r
.22753 .60841 m .21895 .61119 L .22189 .61376 L p F P
0 g
s
.65 .757 .928 r
.22189 .61376 m .23046 .61099 L .22753 .60841 L p F P
0 g
s
.651 .758 .928 r
.78503 .61381 m .79456 .61102 L .7966 .61358 L p F P
0 g
s
.651 .758 .928 r
.79456 .61102 m .78503 .61381 L .78298 .61124 L p F P
0 g
s
.65 .757 .928 r
.36877 .60849 m .35996 .61128 L .36267 .61385 L p F P
0 g
s
.65 .757 .928 r
.36267 .61385 m .37148 .61107 L .36877 .60849 L p F P
0 g
s
.651 .758 .928 r
.64425 .61386 m .65354 .61108 L .65579 .61365 L p F P
0 g
s
.651 .758 .928 r
.65354 .61108 m .64425 .61386 L .64198 .61129 L p F P
0 g
s
.65 .757 .928 r
.50346 .61387 m .51251 .61109 L .51499 .61366 L p F P
0 g
s
.65 .757 .928 r
.51251 .61109 m .50346 .61387 L .50097 .6113 L p F P
0 g
s
.65 .757 .928 r
.23905 .60821 m .23046 .61099 L .23338 .61356 L p F P
0 g
s
.65 .757 .928 r
.23338 .61356 m .24197 .61079 L .23905 .60821 L p F P
0 g
s
.651 .758 .928 r
.7966 .61358 m .80615 .61079 L .80816 .61336 L p F P
0 g
s
.651 .758 .928 r
.80615 .61079 m .7966 .61358 L .79456 .61102 L p F P
0 g
s
.65 .757 .928 r
.38032 .60828 m .37148 .61107 L .37418 .61364 L p F P
0 g
s
.65 .757 .928 r
.37418 .61364 m .38301 .61086 L .38032 .60828 L p F P
0 g
s
.651 .758 .928 r
.65579 .61365 m .6651 .61086 L .66734 .61343 L p F P
0 g
s
.651 .758 .928 r
.6651 .61086 m .65579 .61365 L .65354 .61108 L p F P
0 g
s
.65 .757 .928 r
.51499 .61366 m .52406 .61088 L .52652 .61345 L p F P
0 g
s
.65 .757 .928 r
.52406 .61088 m .51499 .61366 L .51251 .61109 L p F P
0 g
s
.651 .758 .928 r
.80816 .61336 m .81773 .61057 L .81973 .61313 L p F P
0 g
s
.651 .758 .928 r
.81773 .61057 m .80816 .61336 L .80615 .61079 L p F P
0 g
s
.65 .757 .928 r
.25058 .608 m .24197 .61079 L .24487 .61336 L p F P
0 g
s
.65 .757 .928 r
.24487 .61336 m .25348 .61058 L .25058 .608 L p F P
0 g
s
.651 .758 .928 r
.66734 .61343 m .67667 .61064 L .67889 .61321 L p F P
0 g
s
.651 .758 .928 r
.67667 .61064 m .66734 .61343 L .6651 .61086 L p F P
0 g
s
.65 .757 .928 r
.39187 .60807 m .38301 .61086 L .38569 .61343 L p F P
0 g
s
.65 .757 .928 r
.38569 .61343 m .39454 .61065 L .39187 .60807 L p F P
0 g
s
.65 .757 .928 r
.52652 .61345 m .53561 .61066 L .53805 .61323 L p F P
0 g
s
.65 .757 .928 r
.53561 .61066 m .52652 .61345 L .52406 .61088 L p F P
0 g
s
.651 .758 .928 r
.81973 .61313 m .82932 .61034 L .8313 .61291 L p F P
0 g
s
.651 .758 .928 r
.82932 .61034 m .81973 .61313 L .81773 .61057 L p F P
0 g
s
.65 .757 .928 r
.26212 .6078 m .25348 .61058 L .25637 .61316 L p F P
0 g
s
.65 .757 .928 r
.25637 .61316 m .26499 .61038 L .26212 .6078 L p F P
0 g
s
.651 .758 .928 r
.67889 .61321 m .68824 .61043 L .69045 .613 L p F P
0 g
s
.651 .758 .928 r
.68824 .61043 m .67889 .61321 L .67667 .61064 L p F P
0 g
s
.65 .757 .928 r
.40342 .60786 m .39454 .61065 L .39721 .61322 L p F P
0 g
s
.65 .757 .928 r
.39721 .61322 m .40608 .61044 L .40342 .60786 L p F P
0 g
s
0 0 .364 r
.52577 .57907 m .52576 .57907 L .52577 .57486 L p F P
0 g
s
0 0 .364 r
.52577 .57486 m .52577 .57485 L .52577 .57907 L p F P
0 g
s
.756 .495 .539 r
.52575 .57907 m .52576 .57907 L .52577 .57486 L p F P
0 g
s
.756 .495 .539 r
.52577 .57486 m .52575 .57486 L .52575 .57907 L p F P
0 g
s
.651 .758 .928 r
.53805 .61323 m .54716 .61045 L .54958 .61302 L p F P
0 g
s
.651 .758 .928 r
.54716 .61045 m .53805 .61323 L .53561 .61066 L p F P
0 g
s
0 0 .364 r
.52576 .57485 m .52575 .57486 L .52575 .57907 L p F P
0 g
s
.756 .495 .539 r
.52576 .57485 m .52577 .57485 L .52577 .57907 L p F P
0 g
s
.756 .495 .539 r
.52577 .57907 m .52576 .57907 L .52576 .57485 L p F P
0 g
s
0 0 .364 r
.52575 .57907 m .52576 .57907 L .52576 .57485 L p F P
0 g
s
.651 .758 .928 r
.8313 .61291 m .84091 .61011 L .84287 .61268 L p F P
0 g
s
.651 .758 .928 r
.84091 .61011 m .8313 .61291 L .82932 .61034 L p F P
0 g
s
.65 .757 .928 r
.27365 .60759 m .26499 .61038 L .26786 .61295 L p F P
0 g
s
.65 .757 .928 r
.26786 .61295 m .27651 .61017 L .27365 .60759 L p F P
0 g
s
.651 .758 .928 r
.69045 .613 m .69982 .61021 L .702 .61278 L p F P
0 g
s
.651 .758 .928 r
.69982 .61021 m .69045 .613 L .68824 .61043 L p F P
0 g
s
.65 .757 .928 r
.41498 .60764 m .40608 .61044 L .40872 .61301 L p F P
0 g
s
.65 .757 .928 r
.40872 .61301 m .41761 .61022 L .41498 .60764 L p F P
0 g
s
.651 .758 .928 r
.55872 .61023 m .54958 .61302 L .54716 .61045 L p F P
0 g
s
.651 .758 .928 r
.54958 .61302 m .55872 .61023 L .56112 .6128 L p F P
0 g
s
.651 .758 .928 r
.84287 .61268 m .85251 .60988 L .85445 .61245 L p F P
0 g
s
.651 .758 .928 r
.85251 .60988 m .84287 .61268 L .84091 .61011 L p F P
0 g
s
.65 .757 .928 r
.28519 .60738 m .27651 .61017 L .27936 .61275 L p F P
0 g
s
.65 .757 .928 r
.27936 .61275 m .28803 .60997 L .28519 .60738 L p F P
0 g
s
.651 .758 .928 r
.702 .61278 m .7114 .60999 L .71356 .61256 L p F P
0 g
s
.651 .758 .928 r
.7114 .60999 m .702 .61278 L .69982 .61021 L p F P
0 g
s
.65 .757 .928 r
.42653 .60743 m .41761 .61022 L .42024 .6128 L p F P
0 g
s
.65 .757 .928 r
.42024 .6128 m .42915 .61001 L .42653 .60743 L p F P
0 g
s
.651 .758 .928 r
.56112 .6128 m .57028 .61002 L .57266 .61259 L p F P
0 g
s
.651 .758 .928 r
.57028 .61002 m .56112 .6128 L .55872 .61023 L p F P
0 g
s
.651 .758 .928 r
.85445 .61245 m .8641 .60965 L .86603 .61222 L p F P
0 g
s
.651 .758 .928 r
.8641 .60965 m .85445 .61245 L .85251 .60988 L p F P
0 g
s
.65 .757 .928 r
.29673 .60718 m .28803 .60997 L .29087 .61254 L p F P
0 g
s
.65 .757 .928 r
.29087 .61254 m .29956 .60976 L .29673 .60718 L p F P
0 g
s
.651 .758 .928 r
.71356 .61256 m .72298 .60977 L .72513 .61234 L p F P
0 g
s
.651 .758 .928 r
.72298 .60977 m .71356 .61256 L .7114 .60999 L p F P
0 g
s
.65 .757 .928 r
.4381 .60722 m .42915 .61001 L .43176 .61258 L p F P
0 g
s
.65 .757 .928 r
.43176 .61258 m .4407 .6098 L .4381 .60722 L p F P
0 g
s
.651 .758 .928 r
.57266 .61259 m .58184 .6098 L .58421 .61237 L p F P
0 g
s
.651 .758 .928 r
.58184 .6098 m .57266 .61259 L .57028 .61002 L p F P
0 g
s
.65 .757 .928 r
.16692 .60681 m .15844 .60959 L .16148 .61217 L p F P
0 g
s
.65 .757 .928 r
.16148 .61217 m .16994 .6094 L .16692 .60681 L p F P
0 g
s
.651 .758 .928 r
.86603 .61222 m .8757 .60941 L .87761 .61198 L p F P
0 g
s
.651 .758 .928 r
.8757 .60941 m .86603 .61222 L .8641 .60965 L p F P
0 g
s
.65 .757 .928 r
.30828 .60697 m .29956 .60976 L .30237 .61233 L p F P
0 g
s
.65 .757 .928 r
.30237 .61233 m .31109 .60955 L .30828 .60697 L p F P
0 g
s
.651 .758 .928 r
.72513 .61234 m .73456 .60955 L .73669 .61212 L p F P
0 g
s
.651 .758 .928 r
.73456 .60955 m .72513 .61234 L .72298 .60977 L p F P
0 g
s
.65 .757 .928 r
.44966 .607 m .4407 .6098 L .44329 .61237 L p F P
0 g
s
.65 .757 .928 r
.44329 .61237 m .45224 .60958 L .44966 .607 L p F P
0 g
s
.651 .758 .928 r
.58421 .61237 m .5934 .60958 L .59576 .61216 L p F P
0 g
s
.651 .758 .928 r
.5934 .60958 m .58421 .61237 L .58184 .6098 L p F P
0 g
s
.65 .757 .928 r
.17844 .60662 m .16994 .6094 L .17296 .61198 L p F P
0 g
s
.65 .757 .928 r
.17296 .61198 m .18145 .60921 L .17844 .60662 L p F P
0 g
s
.651 .758 .928 r
.87761 .61198 m .88731 .60918 L .8892 .61174 L p F P
0 g
s
.651 .758 .928 r
.88731 .60918 m .87761 .61198 L .8757 .60941 L p F P
0 g
s
.65 .757 .928 r
.31983 .60676 m .31109 .60955 L .31388 .61212 L p F P
0 g
s
.65 .757 .928 r
.31388 .61212 m .32262 .60934 L .31983 .60676 L p F P
0 g
s
.651 .758 .928 r
.73669 .61212 m .74615 .60933 L .74826 .6119 L p F P
0 g
s
.651 .758 .928 r
.74615 .60933 m .73669 .61212 L .73456 .60955 L p F P
0 g
s
.65 .757 .928 r
.46123 .60679 m .45224 .60958 L .45482 .61216 L p F P
0 g
s
.65 .757 .928 r
.45482 .61216 m .46379 .60937 L .46123 .60679 L p F P
0 g
s
.651 .758 .928 r
.59576 .61216 m .60497 .60937 L .60731 .61194 L p F P
0 g
s
.651 .758 .928 r
.60497 .60937 m .59576 .61216 L .5934 .60958 L p F P
0 g
s
.651 .758 .928 r
.8892 .61174 m .89891 .60893 L .90078 .6115 L p F P
0 g
s
.651 .758 .928 r
.89891 .60893 m .8892 .61174 L .88731 .60918 L p F P
0 g
s
.65 .757 .928 r
.18997 .60643 m .18145 .60921 L .18446 .61179 L p F P
0 g
s
.65 .757 .928 r
.18446 .61179 m .19297 .60901 L .18997 .60643 L p F P
0 g
s
.651 .758 .928 r
.75774 .60911 m .74826 .6119 L .74615 .60933 L p F P
0 g
s
.651 .758 .928 r
.74826 .6119 m .75774 .60911 L .75983 .61168 L p F P
0 g
s
.65 .757 .928 r
.33138 .60654 m .32262 .60934 L .3254 .61191 L p F P
0 g
s
.65 .757 .928 r
.3254 .61191 m .33415 .60913 L .33138 .60654 L p F P
0 g
s
.651 .758 .928 r
.60731 .61194 m .61654 .60915 L .61886 .61173 L p F P
0 g
s
.651 .758 .928 r
.61654 .60915 m .60731 .61194 L .60497 .60937 L p F P
0 g
s
.65 .757 .928 r
.4728 .60657 m .46379 .60937 L .46635 .61194 L p F P
0 g
s
.65 .757 .928 r
.46635 .61194 m .47535 .60916 L .4728 .60657 L p F P
0 g
s
.651 .758 .928 r
.90078 .6115 m .91052 .60869 L .91237 .61126 L p F P
0 g
s
.651 .758 .928 r
.91052 .60869 m .90078 .6115 L .89891 .60893 L p F P
0 g
s
.65 .757 .928 r
.20151 .60623 m .19297 .60901 L .19595 .61159 L p F P
0 g
s
.65 .757 .928 r
.19595 .61159 m .20448 .60881 L .20151 .60623 L p F P
0 g
s
.651 .758 .928 r
.75983 .61168 m .76933 .60889 L .77141 .61146 L p F P
0 g
s
.651 .758 .928 r
.76933 .60889 m .75983 .61168 L .75774 .60911 L p F P
0 g
s
.65 .757 .928 r
.34294 .60633 m .33415 .60913 L .33691 .6117 L p F P
0 g
s
.65 .757 .928 r
.33691 .6117 m .34569 .60892 L .34294 .60633 L p F P
0 g
s
.651 .758 .928 r
.61886 .61173 m .62812 .60894 L .63042 .61151 L p F P
0 g
s
.651 .758 .928 r
.62812 .60894 m .61886 .61173 L .61654 .60915 L p F P
0 g
s
.65 .757 .928 r
.48437 .60636 m .47535 .60916 L .47789 .61173 L p F P
0 g
s
.65 .757 .928 r
.47789 .61173 m .4869 .60894 L .48437 .60636 L p F P
0 g
s
.65 .757 .928 r
.21305 .60603 m .20448 .60881 L .20745 .61139 L p F P
0 g
s
.65 .757 .928 r
.20745 .61139 m .216 .60861 L .21305 .60603 L p F P
0 g
s
.651 .758 .928 r
.77141 .61146 m .78093 .60867 L .78298 .61124 L p F P
0 g
s
.651 .758 .928 r
.78093 .60867 m .77141 .61146 L .76933 .60889 L p F P
0 g
s
.65 .757 .928 r
.35449 .60612 m .34569 .60892 L .34843 .61149 L p F P
0 g
s
.65 .757 .928 r
.34843 .61149 m .35723 .60871 L .35449 .60612 L p F P
0 g
s
.651 .758 .928 r
.63042 .61151 m .6397 .60872 L .64198 .61129 L p F P
0 g
s
.651 .758 .928 r
.6397 .60872 m .63042 .61151 L .62812 .60894 L p F P
0 g
s
.65 .757 .928 r
.48942 .61152 m .49846 .60873 L .50097 .6113 L p F P
0 g
s
.65 .757 .928 r
.49595 .60614 m .4869 .60894 L .48942 .61152 L p F P
0 g
s
.65 .757 .928 r
.48942 .61152 m .49846 .60873 L .49595 .60614 L p F P
0 g
s
.65 .757 .928 r
.22459 .60582 m .216 .60861 L .21895 .61119 L p F P
0 g
s
.65 .757 .928 r
.21895 .61119 m .22753 .60841 L .22459 .60582 L p F P
0 g
s
.651 .758 .928 r
.78298 .61124 m .79252 .60844 L .79456 .61102 L p F P
0 g
s
.651 .758 .928 r
.79252 .60844 m .78298 .61124 L .78093 .60867 L p F P
0 g
s
.65 .757 .928 r
.36605 .60591 m .35723 .60871 L .35996 .61128 L p F P
0 g
s
.65 .757 .928 r
.35996 .61128 m .36877 .60849 L .36605 .60591 L p F P
0 g
s
.651 .758 .928 r
.64198 .61129 m .65128 .6085 L .65354 .61108 L p F P
0 g
s
.651 .758 .928 r
.65128 .6085 m .64198 .61129 L .6397 .60872 L p F P
0 g
s
.65 .757 .928 r
.50097 .6113 m .51002 .60851 L .51251 .61109 L p F P
0 g
s
.65 .757 .928 r
.51002 .60851 m .50097 .6113 L .49846 .60873 L p F P
0 g
s
.65 .757 .928 r
.23613 .60562 m .22753 .60841 L .23046 .61099 L p F P
0 g
s
.65 .757 .928 r
.23046 .61099 m .23905 .60821 L .23613 .60562 L p F P
0 g
s
.651 .758 .928 r
.79456 .61102 m .80413 .60822 L .80615 .61079 L p F P
0 g
s
.651 .758 .928 r
.80413 .60822 m .79456 .61102 L .79252 .60844 L p F P
0 g
s
.65 .757 .928 r
.37762 .6057 m .36877 .60849 L .37148 .61107 L p F P
0 g
s
.65 .757 .928 r
.37148 .61107 m .38032 .60828 L .37762 .6057 L p F P
0 g
s
.651 .758 .928 r
.65354 .61108 m .66286 .60828 L .6651 .61086 L p F P
0 g
s
.651 .758 .928 r
.66286 .60828 m .65354 .61108 L .65128 .6085 L p F P
0 g
s
0 0 .37 r
.52577 .58329 m .52576 .5833 L .52576 .57907 L p F P
0 g
s
0 0 .37 r
.52576 .57907 m .52577 .57907 L .52577 .58329 L p F P
0 g
s
.754 .494 .539 r
.52575 .5833 m .52576 .5833 L .52576 .57907 L p F P
0 g
s
.754 .494 .539 r
.52576 .57907 m .52575 .57907 L .52575 .5833 L p F P
0 g
s
.65 .757 .928 r
.51251 .61109 m .52159 .6083 L .52406 .61088 L p F P
0 g
s
.65 .757 .928 r
.52159 .6083 m .51251 .61109 L .51002 .60851 L p F P
0 g
s
0 0 .37 r
.52576 .57907 m .52575 .57907 L .52575 .5833 L p F P
0 g
s
.754 .494 .539 r
.52576 .57907 m .52577 .57907 L .52577 .58329 L p F P
0 g
s
.754 .494 .539 r
.52577 .58329 m .52576 .58329 L .52576 .57907 L p F P
0 g
s
0 0 .37 r
.52575 .5833 m .52576 .58329 L .52576 .57907 L p F P
0 g
s
.65 .757 .928 r
.24768 .60542 m .23905 .60821 L .24197 .61079 L p F P
0 g
s
.65 .757 .928 r
.24197 .61079 m .25058 .608 L .24768 .60542 L p F P
0 g
s
.651 .758 .928 r
.80615 .61079 m .81573 .60799 L .81773 .61057 L p F P
0 g
s
.651 .758 .928 r
.81573 .60799 m .80615 .61079 L .80413 .60822 L p F P
0 g
s
.65 .757 .928 r
.38919 .60548 m .38032 .60828 L .38301 .61086 L p F P
0 g
s
.65 .757 .928 r
.38301 .61086 m .39187 .60807 L .38919 .60548 L p F P
0 g
s
.651 .758 .928 r
.6651 .61086 m .67445 .60807 L .67667 .61064 L p F P
0 g
s
.651 .758 .928 r
.67445 .60807 m .6651 .61086 L .66286 .60828 L p F P
0 g
s
.65 .757 .928 r
.52406 .61088 m .53316 .60808 L .53561 .61066 L p F P
0 g
s
.651 .757 .928 r
.53316 .60808 m .52406 .61088 L .52159 .6083 L p F P
0 g
s
.651 .758 .928 r
.81773 .61057 m .82734 .60776 L .82932 .61034 L p F P
0 g
s
.651 .758 .928 r
.82734 .60776 m .81773 .61057 L .81573 .60799 L p F P
0 g
s
.65 .757 .928 r
.25923 .60521 m .25058 .608 L .25348 .61058 L p F P
0 g
s
.65 .757 .928 r
.25348 .61058 m .26212 .6078 L .25923 .60521 L p F P
0 g
s
.651 .758 .928 r
.67667 .61064 m .68604 .60785 L .68824 .61043 L p F P
0 g
s
.651 .758 .928 r
.68604 .60785 m .67667 .61064 L .67445 .60807 L p F P
0 g
s
.65 .757 .928 r
.40076 .60527 m .39187 .60807 L .39454 .61065 L p F P
0 g
s
.65 .757 .928 r
.39454 .61065 m .40342 .60786 L .40076 .60527 L p F P
0 g
s
.651 .758 .928 r
.53561 .61066 m .54473 .60787 L .54716 .61045 L p F P
0 g
s
.651 .757 .928 r
.54473 .60787 m .53561 .61066 L .53316 .60808 L p F P
0 g
s
.651 .758 .928 r
.82932 .61034 m .83895 .60753 L .84091 .61011 L p F P
0 g
s
.651 .758 .928 r
.83895 .60753 m .82932 .61034 L .82734 .60776 L p F P
0 g
s
.65 .757 .928 r
.27078 .605 m .26212 .6078 L .26499 .61038 L p F P
0 g
s
.65 .757 .928 r
.26499 .61038 m .27365 .60759 L .27078 .605 L p F P
0 g
s
.703 .569 .701 r
.53047 .74505 m .53147 .74504 L .53338 .75131 L p F P
0 g
s
.703 .569 .701 r
.53338 .75131 m .52361 .75142 L .53047 .74505 L p F P
0 g
s
.703 .579 .712 r
.53147 .74504 m .53125 .74437 L .53047 .74505 L closepath p F P
0 g
s
.708 .576 .706 r
.51971 .74503 m .53047 .74505 L .52361 .75142 L p F P
0 g
s
.707 .587 .718 r
.52937 .73858 m .53125 .74437 L .53047 .74505 L p F P
0 g
s
.707 .587 .718 r
.52684 .73857 m .52937 .73858 L p .53047 .74505 L F P
0 g
s
.707 .587 .718 r
.5197 .74501 m .52684 .73857 L p .53047 .74505 L F P
0 g
s
.707 .587 .718 r
.53047 .74505 m .51971 .74503 L .5197 .74501 L p F P
0 g
s
.687 .56 .706 r
.53147 .74504 m .54254 .74437 L p .53525 .7512 L F P
0 g
s
.687 .56 .706 r
.53525 .7512 m .53338 .75131 L .53147 .74504 L p F P
0 g
s
.692 .573 .716 r
.54054 .73801 m .54254 .74437 L .53147 .74504 L p F P
0 g
s
.692 .573 .716 r
.53945 .73808 m .54054 .73801 L p .53147 .74504 L F P
0 g
s
.692 .573 .716 r
.53147 .74504 m .53125 .74437 L .53945 .73808 L p F P
0 g
s
.651 .758 .928 r
.68824 .61043 m .69763 .60763 L .69982 .61021 L p F P
0 g
s
.651 .758 .928 r
.69763 .60763 m .68824 .61043 L .68604 .60785 L p F P
0 g
s
.708 .576 .706 r
.52361 .75142 m .52174 .75142 L .51971 .74503 L p F P
0 g
s
.723 .585 .7 r
.51967 .74503 m .51971 .74503 L .52174 .75142 L p F P
0 g
s
.722 .595 .713 r
.51971 .74503 m .5197 .74501 L .51967 .74503 L closepath p F P
0 g
s
.712 .588 .715 r
.5197 .74501 m .52684 .73857 L .51746 .73843 L closepath p F P
0 g
s
.721 .593 .712 r
.51967 .74503 m .5197 .74501 L .51746 .73843 L p F P
0 g
s
.65 .757 .928 r
.41233 .60506 m .40342 .60786 L .40608 .61044 L p F P
0 g
s
.65 .757 .928 r
.40608 .61044 m .41498 .60764 L .41233 .60506 L p F P
0 g
s
.723 .585 .7 r
.52174 .75142 m .51408 .75105 L .51967 .74503 L p F P
0 g
s
.727 .595 .709 r
.51083 .74446 m .51967 .74503 L .51408 .75105 L p F P
0 g
s
.721 .593 .712 r
.51667 .73838 m .51083 .74446 L .51967 .74503 L p F P
0 g
s
.721 .593 .712 r
.51746 .73843 m .51667 .73838 L p .51967 .74503 L F P
0 g
s
.691 .57 .714 r
.53125 .74437 m .53945 .73808 L .52937 .73858 L closepath p F P
0 g
s
.651 .758 .928 r
.54716 .61045 m .5563 .60765 L .55872 .61023 L p F P
0 g
s
.651 .758 .928 r
.5563 .60765 m .54716 .61045 L .54473 .60787 L p F P
0 g
s
.703 .566 .697 r
.52361 .75142 m .53338 .75131 L p .52842 .75756 L F P
0 g
s
.703 .566 .697 r
.52216 .75287 m .52361 .75142 L p .52842 .75756 L F P
0 g
s
.707 .568 .695 r
.52216 .75287 m .52361 .75142 L .52174 .75142 L closepath p F P
0 g
s
.723 .585 .7 r
.52174 .75142 m .52216 .75287 L .51804 .75743 L p F P
0 g
s
.723 .585 .7 r
.51408 .75105 m .52174 .75142 L p .51804 .75743 L F P
0 g
s
.691 .579 .724 r
.53945 .73808 m .52937 .73858 L .52879 .73692 L p F P
0 g
s
.708 .588 .719 r
.52937 .73858 m .52879 .73692 L .52684 .73857 L closepath p F P
0 g
s
.712 .596 .726 r
.52708 .73194 m .52879 .73692 L .52684 .73857 L p F P
0 g
s
.712 .596 .726 r
.52394 .73189 m .52708 .73194 L p .52684 .73857 L F P
0 g
s
.712 .596 .726 r
.51724 .73783 m .52394 .73189 L p .52684 .73857 L F P
0 g
s
.712 .596 .726 r
.52684 .73857 m .51746 .73843 L .51724 .73783 L p F P
0 g
s
.703 .566 .697 r
.52842 .75756 m .52357 .75762 L .52216 .75287 L p F P
0 g
s
.719 .575 .693 r
.52357 .75762 m .52216 .75287 L .51804 .75743 L closepath p F P
0 g
s
.691 .579 .724 r
.52879 .73692 m .53577 .73162 L p .53945 .73808 L F P
0 g
s
.695 .58 .722 r
.52879 .73692 m .53577 .73162 L .52708 .73194 L closepath p F P
0 g
s
.686 .551 .695 r
.53372 .75249 m .53525 .7512 L .53338 .75131 L closepath p F P
0 g
s
.703 .566 .697 r
.53338 .75131 m .53372 .75249 L .52842 .75756 L p F P
0 g
s
.651 .758 .928 r
.84091 .61011 m .85056 .6073 L .85251 .60988 L p F P
0 g
s
.651 .758 .928 r
.85056 .6073 m .84091 .61011 L .83895 .60753 L p F P
0 g
s
.65 .757 .928 r
.28234 .60479 m .27365 .60759 L .27651 .61017 L p F P
0 g
s
.65 .757 .928 r
.27651 .61017 m .28519 .60738 L .28234 .60479 L p F P
0 g
s
.651 .758 .928 r
.69982 .61021 m .70922 .60741 L .7114 .60999 L p F P
0 g
s
.651 .758 .928 r
.70922 .60741 m .69982 .61021 L .69763 .60763 L p F P
0 g
s
.727 .604 .72 r
.51746 .73843 m .51724 .73783 L .51667 .73838 L closepath p F P
0 g
s
.683 .55 .697 r
.53372 .75249 m .53525 .7512 L p .54138 .75698 L F P
0 g
s
.683 .55 .697 r
.54138 .75698 m .53511 .75741 L .53372 .75249 L p F P
0 g
s
.699 .559 .693 r
.53511 .75741 m .53372 .75249 L .52842 .75756 L closepath p F P
0 g
s
.65 .757 .928 r
.42391 .60484 m .41498 .60764 L .41761 .61022 L p F P
0 g
s
.65 .757 .928 r
.41761 .61022 m .42653 .60743 L .42391 .60484 L p F P
0 g
s
.651 .758 .928 r
.55872 .61023 m .56788 .60744 L .57028 .61002 L p F P
0 g
s
.651 .758 .928 r
.56788 .60744 m .55872 .61023 L .5563 .60765 L p F P
0 g
s
.716 .598 .723 r
.51724 .73783 m .52394 .73189 L .51499 .73162 L closepath p F P
0 g
s
.726 .602 .719 r
.51667 .73838 m .51724 .73783 L .51499 .73162 L p F P
0 g
s
.703 .557 .687 r
.52462 .76149 m .52842 .75756 L .52357 .75762 L closepath p F P
0 g
s
.718 .574 .691 r
.52357 .75762 m .52462 .76149 L .52277 .7636 L p F P
0 g
s
.718 .574 .691 r
.51804 .75743 m .52357 .75762 L p .52277 .7636 L F P
0 g
s
.731 .606 .718 r
.50824 .7377 m .51667 .73838 L .51083 .74446 L p F P
0 g
s
.726 .602 .719 r
.51425 .73156 m .50824 .7377 L .51667 .73838 L p F P
0 g
s
.726 .602 .719 r
.51499 .73162 m .51425 .73156 L p .51667 .73838 L F P
0 g
s
.683 .55 .697 r
.53525 .7512 m .54436 .75056 L p .54138 .75698 L F P
0 g
s
.683 .554 .702 r
.54436 .75056 m .54281 .74531 L .53525 .7512 L closepath p F P
0 g
s
.687 .56 .706 r
.54254 .74437 m .54281 .74531 L .53525 .7512 L p F P
0 g
s
.695 .588 .732 r
.53577 .73162 m .52708 .73194 L .52633 .72989 L p F P
0 g
s
.712 .597 .726 r
.52708 .73194 m .52633 .72989 L .52394 .73189 L closepath p F P
0 g
s
.699 .556 .689 r
.52842 .75756 m .53511 .75741 L p .53417 .76345 L F P
0 g
s
.699 .556 .689 r
.52462 .76149 m .52842 .75756 L p .53417 .76345 L F P
0 g
s
.716 .606 .733 r
.5246 .72512 m .52633 .72989 L .52394 .73189 L p F P
0 g
s
.716 .606 .733 r
.52168 .72503 m .5246 .72512 L p .52394 .73189 L F P
0 g
s
.716 .606 .733 r
.51477 .73107 m .52168 .72503 L p .52394 .73189 L F P
0 g
s
.716 .606 .733 r
.52394 .73189 m .51499 .73162 L .51477 .73107 L p F P
0 g
s
.651 .758 .928 r
.85251 .60988 m .86217 .60707 L .8641 .60965 L p F P
0 g
s
.651 .758 .928 r
.86217 .60707 m .85251 .60988 L .85056 .6073 L p F P
0 g
s
.65 .757 .928 r
.2939 .60459 m .28519 .60738 L .28803 .60997 L p F P
0 g
s
.65 .757 .928 r
.28803 .60997 m .29673 .60718 L .2939 .60459 L p F P
0 g
s
.651 .758 .928 r
.7114 .60999 m .72082 .60719 L .72298 .60977 L p F P
0 g
s
.651 .758 .928 r
.72082 .60719 m .7114 .60999 L .70922 .60741 L p F P
0 g
s
.65 .757 .928 r
.43549 .60463 m .42653 .60743 L .42915 .61001 L p F P
0 g
s
.65 .757 .928 r
.42915 .61001 m .4381 .60722 L .43549 .60463 L p F P
0 g
s
.723 .585 .7 r
.5106 .75499 m .51408 .75105 L p .51804 .75743 L F P
0 g
s
.728 .586 .697 r
.5106 .75499 m .51408 .75105 L .50927 .75075 L closepath p F P
0 g
s
.727 .595 .709 r
.50814 .74742 m .51083 .74446 L p .51408 .75105 L F P
0 g
s
.727 .595 .709 r
.51408 .75105 m .50927 .75075 L .50814 .74742 L p F P
0 g
s
.651 .758 .928 r
.57028 .61002 m .57946 .60722 L .58184 .6098 L p F P
0 g
s
.651 .758 .928 r
.57946 .60722 m .57028 .61002 L .56788 .60744 L p F P
0 g
s
.695 .588 .732 r
.52633 .72989 m .53293 .72492 L p .53577 .73162 L F P
0 g
s
.699 .589 .729 r
.52633 .72989 m .53293 .72492 L .5246 .72512 L closepath p F P
0 g
s
.718 .574 .691 r
.51306 .76327 m .51804 .75743 L p .52277 .7636 L F P
0 g
s
.723 .576 .689 r
.51306 .76327 m .51804 .75743 L .51128 .75711 L closepath p F P
0 g
s
.723 .585 .7 r
.51804 .75743 m .51128 .75711 L .5106 .75499 L p F P
0 g
s
.682 .541 .687 r
.53618 .76147 m .54138 .75698 L .53511 .75741 L closepath p F P
0 g
s
.699 .556 .689 r
.53511 .75741 m .53618 .76147 L .53417 .76345 L p F P
0 g
s
.699 .556 .689 r
.53417 .76345 m .52522 .76365 L .52462 .76149 L p F P
0 g
s
.714 .565 .685 r
.52522 .76365 m .52462 .76149 L .52277 .7636 L closepath p F P
0 g
s
.65 .757 .928 r
.16388 .60422 m .15539 .60701 L .15844 .60959 L p F P
0 g
s
.65 .757 .928 r
.15844 .60959 m .16692 .60681 L .16388 .60422 L p F P
0 g
s
.651 .758 .928 r
.8641 .60965 m .87379 .60684 L .8757 .60941 L p F P
0 g
s
.651 .758 .928 r
.87379 .60684 m .8641 .60965 L .86217 .60707 L p F P
0 g
s
.688 .573 .721 r
.54054 .73801 m .54035 .73744 L .53945 .73808 L closepath p F P
0 g
s
.691 .579 .724 r
.53837 .73149 m .54035 .73744 L .53945 .73808 L p F P
0 g
s
.691 .579 .724 r
.53577 .73162 m .53837 .73149 L p .53945 .73808 L F P
0 g
s
.732 .597 .706 r
.50814 .74742 m .51083 .74446 L .50704 .74417 L closepath p F P
0 g
s
.731 .606 .718 r
.50567 .74043 m .50824 .7377 L p .51083 .74446 L F P
0 g
s
.731 .606 .718 r
.51083 .74446 m .50704 .74417 L .50567 .74043 L p F P
0 g
s
.65 .757 .928 r
.30546 .60438 m .29673 .60718 L .29956 .60976 L p F P
0 g
s
.65 .757 .928 r
.29956 .60976 m .30828 .60697 L .30546 .60438 L p F P
0 g
s
.651 .758 .928 r
.72298 .60977 m .73242 .60697 L .73456 .60955 L p F P
0 g
s
.651 .758 .928 r
.73242 .60697 m .72298 .60977 L .72082 .60719 L p F P
0 g
s
.731 .614 .727 r
.51499 .73162 m .51477 .73107 L .51425 .73156 L closepath p F P
0 g
s
.65 .757 .928 r
.44707 .60441 m .4381 .60722 L .4407 .6098 L p F P
0 g
s
.65 .757 .928 r
.4407 .6098 m .44966 .607 L .44707 .60441 L p F P
0 g
s
.651 .758 .928 r
.58184 .6098 m .59104 .607 L .5934 .60958 L p F P
0 g
s
.651 .758 .928 r
.59104 .607 m .58184 .6098 L .57946 .60722 L p F P
0 g
s
.691 .581 .727 r
.53837 .73149 m .53789 .73011 L .53577 .73162 L closepath p F P
0 g
s
.695 .588 .732 r
.53603 .7248 m .53789 .73011 L .53577 .73162 L p F P
0 g
s
.695 .588 .732 r
.53293 .72492 m .53603 .7248 L p .53577 .73162 L F P
0 g
s
.67 .554 .715 r
.54054 .73801 m .55106 .73679 L p .54458 .74413 L F P
0 g
s
.67 .554 .715 r
.54458 .74413 m .54254 .74437 L .54054 .73801 L p F P
0 g
s
.673 .565 .725 r
.54946 .73187 m .55106 .73679 L .54054 .73801 L p F P
0 g
s
.673 .565 .725 r
.54054 .73801 m .54035 .73744 L .54946 .73187 L p F P
0 g
s
.698 .546 .676 r
.52522 .76365 m .53417 .76345 L .52864 .76945 L p F P
0 g
s
.698 .546 .676 r
.52864 .76945 m .52668 .7695 L .52522 .76365 L p F P
0 g
s
.714 .555 .672 r
.52277 .7636 m .52522 .76365 L .52668 .7695 L p F P
0 g
s
.673 .563 .723 r
.54897 .73034 m .54946 .73187 L .54035 .73744 L p F P
0 g
s
.673 .563 .723 r
.54035 .73744 m .53837 .73149 L .54897 .73034 L p F P
0 g
s
.721 .602 .723 r
.52168 .72503 m .51477 .73107 L .5123 .72465 L p F P
0 g
s
.73 .613 .726 r
.51425 .73156 m .51477 .73107 L .5123 .72465 L p F P
0 g
s
.736 .618 .727 r
.50623 .73075 m .51425 .73156 L .50824 .7377 L p F P
0 g
s
.73 .613 .726 r
.5123 .72465 m .50623 .73075 L .51425 .73156 L p F P
0 g
s
.668 .544 .704 r
.54281 .74531 m .54458 .74413 L .54254 .74437 L closepath p F P
0 g
s
.718 .574 .691 r
.52277 .7636 m .51307 .76328 L .51306 .76327 L p F P
0 g
s
.714 .555 .672 r
.52668 .7695 m .51826 .76932 L .52277 .7636 L p F P
0 g
s
.718 .561 .676 r
.51307 .76328 m .52277 .7636 L .51826 .76932 L p F P
0 g
s
.699 .597 .739 r
.53293 .72492 m .5246 .72512 L .52387 .72321 L p F P
0 g
s
.716 .606 .733 r
.5246 .72512 m .52387 .72321 L .52168 .72503 L closepath p F P
0 g
s
.736 .591 .694 r
.50927 .75075 m .50565 .75036 L p .50903 .75691 L F P
0 g
s
.736 .591 .694 r
.50903 .75691 m .5106 .75499 L .50927 .75075 L p F P
0 g
s
.742 .603 .703 r
.50927 .75075 m .50814 .74742 L .50565 .75036 L closepath p F P
0 g
s
.666 .544 .706 r
.54281 .74531 m .54458 .74413 L p .55152 .74969 L F P
0 g
s
.666 .544 .706 r
.55152 .74969 m .54436 .75056 L .54281 .74531 L p F P
0 g
s
.65 .757 .928 r
.17542 .60403 m .16692 .60681 L .16994 .6094 L p F P
0 g
s
.65 .757 .928 r
.16994 .6094 m .17844 .60662 L .17542 .60403 L p F P
0 g
s
.651 .758 .928 r
.8757 .60941 m .88541 .6066 L .88731 .60918 L p F P
0 g
s
.651 .758 .928 r
.88541 .6066 m .8757 .60941 L .87379 .60684 L p F P
0 g
s
.677 .573 .731 r
.547 .72453 m .54897 .73034 L .53837 .73149 L p F P
0 g
s
.677 .573 .731 r
.53837 .73149 m .53789 .73011 L .547 .72453 L p F P
0 g
s
.737 .592 .695 r
.51128 .75711 m .5106 .75499 L .50903 .75691 L closepath p F P
0 g
s
.731 .58 .686 r
.51128 .75711 m .50903 .75691 L p .51306 .76328 L F P
0 g
s
.731 .58 .686 r
.51306 .76328 m .51306 .76327 L .51128 .75711 L p F P
0 g
s
.683 .543 .688 r
.53669 .76336 m .53618 .76147 L .54138 .75698 L p F P
0 g
s
.695 .55 .685 r
.53669 .76336 m .53618 .76147 L .53417 .76345 L closepath p F P
0 g
s
.721 .602 .723 r
.5123 .72465 m .51237 .72458 L .52168 .72503 L p F P
0 g
s
.715 .604 .732 r
.52 .71799 m .51237 .72458 L .52168 .72503 L p F P
0 g
s
.715 .604 .732 r
.52191 .71808 m .52 .71799 L p .52168 .72503 L F P
0 g
s
.715 .604 .732 r
.52168 .72503 m .52387 .72321 L .52191 .71808 L p F P
0 g
s
.65 .757 .928 r
.31703 .60416 m .30828 .60697 L .31109 .60955 L p F P
0 g
s
.65 .757 .928 r
.31109 .60955 m .31983 .60676 L .31703 .60416 L p F P
0 g
s
.651 .758 .928 r
.73456 .60955 m .74403 .60675 L .74615 .60933 L p F P
0 g
s
.651 .758 .928 r
.74403 .60675 m .73456 .60955 L .73242 .60697 L p F P
0 g
s
.741 .602 .703 r
.50565 .75036 m .50814 .74742 L .50704 .74417 L p F P
0 g
s
.677 .572 .729 r
.54674 .72375 m .547 .72453 L .53789 .73011 L p F P
0 g
s
.677 .572 .729 r
.53789 .73011 m .53603 .7248 L .54674 .72375 L p F P
0 g
s
.65 .757 .928 r
.45865 .6042 m .44966 .607 L .45224 .60958 L p F P
0 g
s
.65 .757 .928 r
.45224 .60958 m .46123 .60679 L .45865 .6042 L p F P
0 g
s
.651 .758 .928 r
.5934 .60958 m .60263 .60679 L .60497 .60937 L p F P
0 g
s
.651 .758 .928 r
.60263 .60679 m .5934 .60958 L .59104 .607 L p F P
0 g
s
.694 .539 .672 r
.53417 .76345 m .53669 .76336 L .53807 .76914 L p F P
0 g
s
.694 .539 .672 r
.53807 .76914 m .52864 .76945 L .53417 .76345 L p F P
0 g
s
.699 .597 .739 r
.52387 .72321 m .53084 .718 L p .53293 .72492 L F P
0 g
s
.704 .598 .736 r
.52387 .72321 m .53084 .718 L .52191 .71808 L closepath p F P
0 g
s
.741 .602 .703 r
.50704 .74417 m .50287 .74365 L p .50565 .75036 L F P
0 g
s
.746 .614 .711 r
.50704 .74417 m .50567 .74043 L .50287 .74365 L closepath p F P
0 g
s
.683 .543 .688 r
.54138 .75698 m .54604 .75661 L p .53669 .76336 L F P
0 g
s
.679 .545 .695 r
.54604 .75661 m .54528 .75389 L .54138 .75698 L closepath p F P
0 g
s
.683 .55 .697 r
.54436 .75056 m .54528 .75389 L .54138 .75698 L p F P
0 g
s
.695 .589 .733 r
.53603 .7248 m .53543 .72315 L .53293 .72492 L closepath p F P
0 g
s
.699 .597 .739 r
.53352 .71793 m .53543 .72315 L .53293 .72492 L p F P
0 g
s
.699 .597 .739 r
.53084 .718 m .53352 .71793 L p .53293 .72492 L F P
0 g
s
.665 .535 .697 r
.54528 .75389 m .55152 .74969 L .54436 .75056 L closepath p F P
0 g
s
.651 .758 .928 r
.88731 .60918 m .89704 .60636 L .89891 .60893 L p F P
0 g
s
.651 .758 .928 r
.89704 .60636 m .88731 .60918 L .88541 .6066 L p F P
0 g
s
.666 .544 .706 r
.54458 .74413 m .553 .74309 L p .55152 .74969 L F P
0 g
s
.666 .55 .713 r
.553 .74309 m .55193 .73964 L .54458 .74413 L closepath p F P
0 g
s
.67 .554 .715 r
.55106 .73679 m .55193 .73964 L .54458 .74413 L p F P
0 g
s
.683 .543 .688 r
.54604 .75661 m .54756 .76251 L .53669 .76336 L p F P
0 g
s
.678 .529 .676 r
.53669 .76336 m .54756 .76251 L p .54163 .76887 L F P
0 g
s
.678 .529 .676 r
.54163 .76887 m .53807 .76914 L .53669 .76336 L p F P
0 g
s
.65 .757 .928 r
.18697 .60383 m .17844 .60662 L .18145 .60921 L p F P
0 g
s
.65 .757 .928 r
.18145 .60921 m .18997 .60643 L .18697 .60383 L p F P
0 g
s
.737 .609 .715 r
.50567 .74043 m .50824 .7377 L .50455 .73734 L closepath p F P
0 g
s
.736 .618 .727 r
.5032 .7339 m .50623 .73075 L p .50824 .7377 L F P
0 g
s
.736 .618 .727 r
.50824 .7377 m .50455 .73734 L .5032 .7339 L p F P
0 g
s
.731 .58 .686 r
.50903 .75691 m .50485 .76254 L .51306 .76328 L p F P
0 g
s
.742 .593 .691 r
.50115 .75608 m .50903 .75691 L .50485 .76254 L p F P
0 g
s
.736 .591 .694 r
.50565 .75036 m .50115 .75608 L .50903 .75691 L p F P
0 g
s
.651 .758 .928 r
.74615 .60933 m .75564 .60653 L .75774 .60911 L p F P
0 g
s
.651 .758 .928 r
.75564 .60653 m .74615 .60933 L .74403 .60675 L p F P
0 g
s
.65 .757 .928 r
.3286 .60395 m .31983 .60676 L .32262 .60934 L p F P
0 g
s
.65 .757 .928 r
.32262 .60934 m .33138 .60654 L .3286 .60395 L p F P
0 g
s
.651 .758 .928 r
.60497 .60937 m .61422 .60657 L .61654 .60915 L p F P
0 g
s
.651 .758 .928 r
.61422 .60657 m .60497 .60937 L .60263 .60679 L p F P
0 g
s
.65 .757 .928 r
.47024 .60398 m .46123 .60679 L .46379 .60937 L p F P
0 g
s
.65 .757 .928 r
.46379 .60937 m .4728 .60657 L .47024 .60398 L p F P
0 g
s
.732 .582 .687 r
.51307 .76328 m .51306 .76327 L .51306 .76328 L closepath p F P
0 g
s
.718 .561 .676 r
.51826 .76932 m .5146 .7692 L .51307 .76328 L p F P
0 g
s
.733 .57 .671 r
.51306 .76328 m .51307 .76328 L .5146 .7692 L p F P
0 g
s
.733 .57 .671 r
.5146 .7692 m .50926 .7688 L .51306 .76328 L p F P
0 g
s
.737 .581 .681 r
.50485 .76254 m .51306 .76328 L .50926 .7688 L p F P
0 g
s
.681 .582 .738 r
.54454 .71757 m .54674 .72375 L .53603 .7248 L p F P
0 g
s
.681 .582 .738 r
.53603 .7248 m .53543 .72315 L .54454 .71757 L p F P
0 g
s
.746 .606 .701 r
.4981 .74943 m .50565 .75036 L .50115 .75608 L p F P
0 g
s
.741 .602 .703 r
.50287 .74365 m .4981 .74943 L .50565 .75036 L p F P
0 g
s
.651 .758 .928 r
.89891 .60893 m .90866 .60611 L .91052 .60869 L p F P
0 g
s
.651 .758 .928 r
.90866 .60611 m .89891 .60893 L .89704 .60636 L p F P
0 g
s
.666 .537 .698 r
.54604 .75661 m .54528 .75389 L .55152 .74969 L p F P
0 g
s
.746 .613 .711 r
.50287 .74365 m .50567 .74043 L .50455 .73734 L p F P
0 g
s
.68 .58 .736 r
.54433 .71699 m .54454 .71757 L .53543 .72315 L p F P
0 g
s
.68 .58 .736 r
.53543 .72315 m .53352 .71793 L .54433 .71699 L p F P
0 g
s
.65 .757 .928 r
.19852 .60363 m .18997 .60643 L .19297 .60901 L p F P
0 g
s
.65 .757 .928 r
.19297 .60901 m .20151 .60623 L .19852 .60363 L p F P
0 g
s
.651 .758 .928 r
.76725 .60631 m .75774 .60911 L .75564 .60653 L p F P
0 g
s
.651 .758 .928 r
.75774 .60911 m .76725 .60631 L .76933 .60889 L p F P
0 g
s
.65 .757 .928 r
.34017 .60374 m .33138 .60654 L .33415 .60913 L p F P
0 g
s
.65 .757 .928 r
.33415 .60913 m .34294 .60633 L .34017 .60374 L p F P
0 g
s
.651 .758 .928 r
.61654 .60915 m .62581 .60635 L .62812 .60894 L p F P
0 g
s
.651 .758 .928 r
.62581 .60635 m .61654 .60915 L .61422 .60657 L p F P
0 g
s
.65 .757 .928 r
.48184 .60377 m .4728 .60657 L .47535 .60916 L p F P
0 g
s
.65 .757 .928 r
.47535 .60916 m .48437 .60636 L .48184 .60377 L p F P
0 g
s
.697 .534 .662 r
.52709 .77136 m .52864 .76945 L .52668 .7695 L closepath p F P
0 g
s
.713 .55 .666 r
.52668 .7695 m .52709 .77136 L .52435 .77512 L p F P
0 g
s
.713 .55 .666 r
.51826 .76932 m .52668 .7695 L p .52435 .77512 L F P
0 g
s
.726 .611 .728 r
.5123 .72465 m .51237 .72458 L .51228 .72458 L closepath p F P
0 g
s
.74 .629 .736 r
.51228 .72458 m .5123 .72465 L .50623 .73075 L p F P
0 g
s
.725 .619 .74 r
.51123 .71739 m .52 .71799 L .51237 .72458 L p F P
0 g
s
.725 .619 .74 r
.50983 .71864 m .51123 .71739 L p .51237 .72458 L F P
0 g
s
.725 .619 .74 r
.51237 .72458 m .51228 .72458 L .50983 .71864 L p F P
0 g
s
.74 .629 .736 r
.50477 .72365 m .51228 .72458 L p .50623 .73075 L F P
0 g
s
.742 .628 .732 r
.51228 .72458 m .50983 .71864 L .50477 .72365 L closepath p F P
0 g
s
.694 .532 .664 r
.52864 .76945 m .53807 .76914 L p .53605 .77489 L F P
0 g
s
.694 .532 .664 r
.52709 .77136 m .52864 .76945 L p .53605 .77489 L F P
0 g
s
.661 .526 .688 r
.54604 .75661 m .55643 .75527 L p .54912 .76232 L F P
0 g
s
.661 .526 .688 r
.54912 .76232 m .54756 .76251 L .54604 .75661 L p F P
0 g
s
.666 .537 .698 r
.5548 .74926 m .55643 .75527 L .54604 .75661 L p F P
0 g
s
.666 .537 .698 r
.55152 .74969 m .5548 .74926 L p .54604 .75661 L F P
0 g
s
.746 .613 .711 r
.50455 .73734 m .50064 .73677 L p .50287 .74365 L F P
0 g
s
.751 .625 .72 r
.50455 .73734 m .5032 .7339 L .50064 .73677 L closepath p F P
0 g
s
.703 .607 .746 r
.53084 .718 m .52191 .71808 L .5214 .71683 L p F P
0 g
s
.72 .615 .739 r
.52191 .71808 m .5214 .71683 L .52 .71799 L closepath p F P
0 g
s
.65 .757 .928 r
.21008 .60343 m .20151 .60623 L .20448 .60881 L p F P
0 g
s
.65 .757 .928 r
.20448 .60881 m .21305 .60603 L .21008 .60343 L p F P
0 g
s
.651 .758 .928 r
.76933 .60889 m .77886 .60608 L .78093 .60867 L p F P
0 g
s
.651 .758 .928 r
.77886 .60608 m .76933 .60889 L .76725 .60631 L p F P
0 g
s
.713 .55 .666 r
.51552 .77317 m .51826 .76932 L p .52435 .77512 L F P
0 g
s
.718 .552 .664 r
.51552 .77317 m .51826 .76932 L .5146 .7692 L closepath p F P
0 g
s
.65 .757 .928 r
.35175 .60353 m .34294 .60633 L .34569 .60892 L p F P
0 g
s
.65 .757 .928 r
.34569 .60892 m .35449 .60612 L .35175 .60353 L p F P
0 g
s
.699 .598 .74 r
.53352 .71793 m .53296 .71649 L .53084 .718 L closepath p F P
0 g
s
.703 .607 .746 r
.53081 .71087 m .53296 .71649 L .53084 .718 L p F P
0 g
s
.703 .607 .746 r
.52939 .71089 m .53081 .71087 L p .53084 .718 L F P
0 g
s
.703 .607 .746 r
.5214 .71683 m .52939 .71089 L p .53084 .718 L F P
0 g
s
.651 .758 .928 r
.62812 .60894 m .63741 .60614 L .6397 .60872 L p F P
0 g
s
.651 .758 .928 r
.63741 .60614 m .62812 .60894 L .62581 .60635 L p F P
0 g
s
0 0 .38 r
.52577 .58753 m .52576 .58754 L .52576 .5833 L p F P
0 g
s
0 0 .38 r
.52576 .5833 m .52577 .58329 L .52577 .58753 L p F P
0 g
s
.75 .491 .539 r
.52575 .58753 m .52576 .58754 L .52576 .5833 L p F P
0 g
s
.75 .491 .539 r
.52576 .5833 m .52575 .5833 L .52575 .58753 L p F P
0 g
s
.65 .757 .928 r
.49343 .60355 m .48437 .60636 L .4869 .60894 L p F P
0 g
s
.65 .757 .928 r
.4869 .60894 m .49595 .60614 L .49343 .60355 L p F P
0 g
s
0 0 .38 r
.52576 .58329 m .52575 .5833 L .52575 .58753 L p F P
0 g
s
.72 .614 .738 r
.51882 .7108 m .51123 .71739 L .52 .71799 L p F P
0 g
s
.72 .614 .738 r
.51898 .71081 m .51882 .7108 L p .52 .71799 L F P
0 g
s
.72 .614 .738 r
.52 .71799 m .5214 .71683 L .51898 .71081 L p F P
0 g
s
.751 .618 .711 r
.49566 .74261 m .50287 .74365 L .4981 .74943 L p F P
0 g
s
.746 .613 .711 r
.50064 .73677 m .49566 .74261 L .50287 .74365 L p F P
0 g
s
.75 .491 .539 r
.52576 .58329 m .52577 .58329 L .52577 .58753 L p F P
0 g
s
.75 .491 .539 r
.52577 .58753 m .52576 .58753 L .52576 .58329 L p F P
0 g
s
0 0 .38 r
.52575 .58753 m .52576 .58753 L .52576 .58329 L p F P
0 g
s
.708 .608 .743 r
.5214 .71683 m .52939 .71089 L .51898 .71081 L closepath p F P
0 g
s
.685 .59 .744 r
.54208 .71093 m .54433 .71699 L .53352 .71793 L p F P
0 g
s
.685 .59 .744 r
.53352 .71793 m .53296 .71649 L .54208 .71093 L p F P
0 g
s
.694 .532 .664 r
.53605 .77489 m .52793 .77515 L .52709 .77136 L p F P
0 g
s
.709 .542 .66 r
.52793 .77515 m .52709 .77136 L .52435 .77512 L closepath p F P
0 g
s
.742 .62 .723 r
.5032 .7339 m .50623 .73075 L .50176 .73023 L closepath p F P
0 g
s
.74 .629 .736 r
.50072 .72775 m .50477 .72365 L p .50623 .73075 L F P
0 g
s
.74 .629 .736 r
.50623 .73075 m .50176 .73023 L .50072 .72775 L p F P
0 g
s
.727 .558 .661 r
.5146 .7692 m .50926 .7688 L p .51442 .77486 L F P
0 g
s
.727 .558 .661 r
.51442 .77486 m .51552 .77317 L .5146 .7692 L p F P
0 g
s
.65 .757 .928 r
.22164 .60323 m .21305 .60603 L .216 .60861 L p F P
0 g
s
.65 .757 .928 r
.216 .60861 m .22459 .60582 L .22164 .60323 L p F P
0 g
s
.676 .518 .663 r
.53866 .77187 m .54163 .76887 L .53807 .76914 L closepath p F P
0 g
s
.694 .532 .664 r
.53807 .76914 m .53866 .77187 L .53605 .77489 L p F P
0 g
s
.651 .758 .928 r
.78093 .60867 m .79048 .60586 L .79252 .60844 L p F P
0 g
s
.651 .758 .928 r
.79048 .60586 m .78093 .60867 L .77886 .60608 L p F P
0 g
s
.65 .757 .928 r
.36333 .60332 m .35449 .60612 L .35723 .60871 L p F P
0 g
s
.65 .757 .928 r
.35723 .60871 m .36605 .60591 L .36333 .60332 L p F P
0 g
s
.651 .758 .928 r
.6397 .60872 m .64901 .60592 L .65128 .6085 L p F P
0 g
s
.651 .758 .928 r
.64901 .60592 m .6397 .60872 L .63741 .60614 L p F P
0 g
s
.684 .589 .743 r
.54175 .71004 m .54208 .71093 L .53296 .71649 L p F P
0 g
s
.684 .589 .743 r
.53296 .71649 m .53081 .71087 L .54175 .71004 L p F P
0 g
s
.65 .757 .928 r
.49846 .60873 m .50753 .60593 L .51002 .60851 L p F P
0 g
s
.65 .757 .928 r
.50503 .60334 m .49595 .60614 L .49846 .60873 L p F P
0 g
s
.65 .757 .928 r
.49846 .60873 m .50753 .60593 L .50503 .60334 L p F P
0 g
s
.751 .624 .719 r
.50064 .73677 m .5032 .7339 L .50176 .73023 L p F P
0 g
s
.65 .757 .928 r
.2332 .60302 m .22459 .60582 L .22753 .60841 L p F P
0 g
s
.65 .757 .928 r
.22753 .60841 m .23613 .60562 L .2332 .60302 L p F P
0 g
s
.742 .593 .691 r
.49902 .75898 m .50115 .75608 L p .50485 .76254 L F P
0 g
s
.742 .593 .691 r
.50485 .76254 m .49997 .76204 L .49902 .75898 L p F P
0 g
s
.737 .581 .681 r
.50148 .76739 m .50485 .76254 L p .50926 .7688 L F P
0 g
s
.743 .584 .678 r
.50148 .76739 m .50485 .76254 L .49997 .76204 L closepath p F P
0 g
s
.651 .758 .928 r
.79252 .60844 m .8021 .60563 L .80413 .60822 L p F P
0 g
s
.651 .758 .928 r
.8021 .60563 m .79252 .60844 L .79048 .60586 L p F P
0 g
s
.663 .542 .707 r
.5548 .74926 m .5544 .74791 L .55152 .74969 L closepath p F P
0 g
s
.666 .544 .706 r
.553 .74309 m .5544 .74791 L .55152 .74969 L p F P
0 g
s
.659 .513 .674 r
.54776 .76334 m .54912 .76232 L .54756 .76251 L closepath p F P
0 g
s
.678 .529 .676 r
.54756 .76251 m .54776 .76334 L .54163 .76887 L p F P
0 g
s
.65 .757 .928 r
.37491 .6031 m .36605 .60591 L .36877 .60849 L p F P
0 g
s
.65 .757 .928 r
.36877 .60849 m .37762 .6057 L .37491 .6031 L p F P
0 g
s
.651 .758 .928 r
.65128 .6085 m .66061 .6057 L .66286 .60828 L p F P
0 g
s
.651 .758 .928 r
.66061 .6057 m .65128 .6085 L .64901 .60592 L p F P
0 g
s
.65 .757 .928 r
.51002 .60851 m .51911 .60571 L .52159 .6083 L p F P
0 g
s
.65 .757 .928 r
.51911 .60571 m .51002 .60851 L .50753 .60593 L p F P
0 g
s
.748 .596 .688 r
.49902 .75898 m .50115 .75608 L .498 .7557 L closepath p F P
0 g
s
.746 .606 .701 r
.49655 .75145 m .4981 .74943 L p .50115 .75608 L F P
0 g
s
.746 .606 .701 r
.50115 .75608 m .498 .7557 L .49655 .75145 L p F P
0 g
s
.649 .538 .715 r
.55193 .73964 m .55106 .73679 L .56105 .73503 L p F P
0 g
s
.653 .549 .724 r
.55899 .7286 m .56105 .73503 L .55106 .73679 L p F P
0 g
s
.653 .549 .724 r
.55438 .72942 m .55899 .7286 L p .55106 .73679 L F P
0 g
s
.653 .549 .724 r
.55106 .73679 m .54946 .73187 L .55438 .72942 L p F P
0 g
s
.677 .519 .664 r
.54163 .76887 m .54889 .76823 L p .53928 .77475 L F P
0 g
s
.677 .519 .664 r
.53928 .77475 m .53866 .77187 L .54163 .76887 L p F P
0 g
s
.674 .523 .673 r
.54889 .76823 m .54776 .76334 L .54163 .76887 L closepath p F P
0 g
s
.755 .63 .722 r
.49378 .73562 m .50064 .73677 L .49566 .74261 L p F P
0 g
s
.751 .624 .719 r
.4989 .72974 m .49378 .73562 L .50064 .73677 L p F P
0 g
s
.751 .624 .719 r
.50176 .73023 m .4989 .72974 L p .50064 .73677 L F P
0 g
s
.653 .547 .722 r
.54946 .73187 m .55438 .72942 L .54897 .73034 L closepath p F P
0 g
s
.654 .555 .731 r
.55438 .72942 m .54897 .73034 L .547 .72453 L p F P
0 g
s
.66 .514 .675 r
.54889 .76823 m .54776 .76334 L .54912 .76232 L p F P
0 g
s
.65 .541 .717 r
.553 .74309 m .55193 .73964 L .56107 .73509 L p F P
0 g
s
.649 .538 .715 r
.56105 .73503 m .56107 .73509 L .55193 .73964 L p F P
0 g
s
.727 .558 .661 r
.50926 .7688 m .50583 .77423 L .51442 .77486 L p F P
0 g
s
.737 .569 .665 r
.5017 .76815 m .50926 .7688 L .50583 .77423 L p F P
0 g
s
.737 .581 .681 r
.50926 .7688 m .5017 .76815 L .50148 .76739 L p F P
0 g
s
.65 .757 .928 r
.24476 .60282 m .23613 .60562 L .23905 .60821 L p F P
0 g
s
.65 .757 .928 r
.23905 .60821 m .24768 .60542 L .24476 .60282 L p F P
0 g
s
.651 .758 .928 r
.80413 .60822 m .81372 .60541 L .81573 .60799 L p F P
0 g
s
.651 .758 .928 r
.81372 .60541 m .80413 .60822 L .8021 .60563 L p F P
0 g
s
.646 .53 .708 r
.5544 .74791 m .553 .74309 L .56294 .74129 L p F P
0 g
s
.65 .541 .717 r
.56107 .73509 m .56294 .74129 L .553 .74309 L p F P
0 g
s
.689 .527 .661 r
.53928 .77475 m .53866 .77187 L .53605 .77489 L closepath p F P
0 g
s
.713 .55 .666 r
.52435 .77512 m .51594 .77495 L .51552 .77317 L p F P
0 g
s
.728 .559 .662 r
.51594 .77495 m .51552 .77317 L .51442 .77486 L closepath p F P
0 g
s
.692 .52 .65 r
.52793 .77515 m .53605 .77489 L .53184 .78054 L p F P
0 g
s
.692 .52 .65 r
.53184 .78054 m .52898 .78063 L .52793 .77515 L p F P
0 g
s
.708 .531 .647 r
.52435 .77512 m .52793 .77515 L .52898 .78063 L p F P
0 g
s
.731 .622 .737 r
.50983 .71864 m .51123 .71739 L .50925 .71722 L closepath p F P
0 g
s
.745 .64 .745 r
.50925 .71722 m .50983 .71864 L .50477 .72365 L p F P
0 g
s
.658 .521 .686 r
.5579 .76112 m .55688 .75706 L .54912 .76232 L closepath p F P
0 g
s
.661 .526 .688 r
.55643 .75527 m .55688 .75706 L .54912 .76232 L p F P
0 g
s
.66 .514 .675 r
.54912 .76232 m .5579 .76112 L p .54889 .76823 L F P
0 g
s
.65 .757 .928 r
.3865 .60289 m .37762 .6057 L .38032 .60828 L p F P
0 g
s
.65 .757 .928 r
.38032 .60828 m .38919 .60548 L .3865 .60289 L p F P
0 g
s
.651 .758 .928 r
.66286 .60828 m .67221 .60548 L .67445 .60807 L p F P
0 g
s
.651 .758 .928 r
.67221 .60548 m .66286 .60828 L .66061 .6057 L p F P
0 g
s
.756 .636 .728 r
.50176 .73023 m .50072 .72775 L .4989 .72974 L closepath p F P
0 g
s
.651 .757 .928 r
.52159 .6083 m .5307 .6055 L .53316 .60808 L p F P
0 g
s
.651 .757 .928 r
.5307 .6055 m .52159 .6083 L .51911 .60571 L p F P
0 g
s
.729 .631 .748 r
.51061 .71003 m .51882 .7108 L .51123 .71739 L p F P
0 g
s
.729 .631 .748 r
.50736 .71291 m .51061 .71003 L p .51123 .71739 L F P
0 g
s
.729 .631 .748 r
.51123 .71739 m .50925 .71722 L .50736 .71291 L p F P
0 g
s
.708 .531 .647 r
.52898 .78063 m .5209 .78056 L .52435 .77512 L p F P
0 g
s
.713 .536 .649 r
.51594 .77495 m .52435 .77512 L .5209 .78056 L p F P
0 g
s
.654 .555 .731 r
.547 .72453 m .54949 .7233 L p .55438 .72942 L F P
0 g
s
.656 .555 .729 r
.547 .72453 m .54949 .7233 L .54674 .72375 L closepath p F P
0 g
s
.753 .609 .698 r
.49655 .75145 m .4981 .74943 L .49575 .7491 L closepath p F P
0 g
s
.751 .618 .711 r
.49408 .74459 m .49566 .74261 L p .4981 .74943 L F P
0 g
s
.751 .618 .711 r
.4981 .74943 m .49575 .7491 L .49408 .74459 L p F P
0 g
s
.657 .564 .738 r
.54949 .7233 m .54674 .72375 L .54454 .71757 L p F P
0 g
s
.651 .758 .928 r
.81573 .60799 m .82534 .60518 L .82734 .60776 L p F P
0 g
s
.651 .758 .928 r
.82534 .60518 m .81573 .60799 L .81372 .60541 L p F P
0 g
s
.747 .632 .732 r
.50072 .72775 m .50477 .72365 L .49864 .72279 L closepath p F P
0 g
s
.745 .64 .745 r
.50377 .71641 m .50925 .71722 L p .50477 .72365 L F P
0 g
s
.745 .64 .745 r
.49824 .7219 m .50377 .71641 L p .50477 .72365 L F P
0 g
s
.745 .64 .745 r
.50477 .72365 m .49864 .72279 L .49824 .7219 L p F P
0 g
s
.65 .757 .928 r
.25633 .60261 m .24768 .60542 L .25058 .608 L p F P
0 g
s
.65 .757 .928 r
.25058 .608 m .25923 .60521 L .25633 .60261 L p F P
0 g
s
.646 .532 .71 r
.5548 .74926 m .5544 .74791 L .56354 .7434 L p F P
0 g
s
.646 .53 .708 r
.56294 .74129 m .56354 .7434 L .5544 .74791 L p F P
0 g
s
.747 .639 .74 r
.50925 .71722 m .50736 .71291 L .50377 .71641 L closepath p F P
0 g
s
.651 .758 .928 r
.67445 .60807 m .68382 .60526 L .68604 .60785 L p F P
0 g
s
.651 .758 .928 r
.68382 .60526 m .67445 .60807 L .67221 .60548 L p F P
0 g
s
.713 .536 .649 r
.5209 .78056 m .51704 .78048 L .51594 .77495 L p F P
0 g
s
.728 .547 .646 r
.51442 .77486 m .51594 .77495 L .51704 .78048 L p F P
0 g
s
.65 .757 .928 r
.39808 .60267 m .38919 .60548 L .39187 .60807 L p F P
0 g
s
.65 .757 .928 r
.39187 .60807 m .40076 .60527 L .39808 .60267 L p F P
0 g
s
.755 .6 .685 r
.498 .7557 m .49398 .75504 L p .49721 .76164 L F P
0 g
s
.755 .6 .685 r
.49721 .76164 m .49902 .75898 L .498 .7557 L p F P
0 g
s
.761 .613 .695 r
.498 .7557 m .49655 .75145 L .49398 .75504 L closepath p F P
0 g
s
.651 .757 .928 r
.53316 .60808 m .54229 .60528 L .54473 .60787 L p F P
0 g
s
.65 .757 .928 r
.54229 .60528 m .53316 .60808 L .5307 .6055 L p F P
0 g
s
.643 .52 .699 r
.5548 .74926 m .5647 .74742 L p .56217 .75422 L F P
0 g
s
.643 .52 .699 r
.56217 .75422 m .55643 .75527 L .5548 .74926 L p F P
0 g
s
.646 .532 .71 r
.56354 .7434 m .5647 .74742 L .5548 .74926 L p F P
0 g
s
.756 .601 .685 r
.49997 .76204 m .49902 .75898 L .49721 .76164 L closepath p F P
0 g
s
.688 .514 .646 r
.53605 .77489 m .53928 .77475 L .54029 .78018 L p F P
0 g
s
.688 .514 .646 r
.54029 .78018 m .53184 .78054 L .53605 .77489 L p F P
0 g
s
.75 .589 .675 r
.49997 .76204 m .49721 .76164 L p .50104 .76806 L F P
0 g
s
.75 .589 .675 r
.50104 .76806 m .50148 .76739 L .49997 .76204 L p F P
0 g
s
.728 .547 .646 r
.51704 .78048 m .51152 .78015 L .51442 .77486 L p F P
0 g
s
.732 .555 .653 r
.50583 .77423 m .51442 .77486 L .51152 .78015 L p F P
0 g
s
.76 .613 .695 r
.49398 .75504 m .49655 .75145 L .49575 .7491 L p F P
0 g
s
.756 .636 .728 r
.4989 .72974 m .50072 .72775 L .49864 .72279 L p F P
0 g
s
.651 .758 .928 r
.82734 .60776 m .83697 .60495 L .83895 .60753 L p F P
0 g
s
.651 .758 .928 r
.83697 .60495 m .82734 .60776 L .82534 .60518 L p F P
0 g
s
.65 .757 .928 r
.2679 .6024 m .25923 .60521 L .26212 .6078 L p F P
0 g
s
.65 .757 .928 r
.26212 .6078 m .27078 .605 L .2679 .6024 L p F P
0 g
s
.657 .564 .738 r
.54454 .71757 m .54635 .71667 L p .54949 .7233 L F P
0 g
s
.659 .564 .737 r
.54454 .71757 m .54635 .71667 L .54433 .71699 L closepath p F P
0 g
s
.76 .613 .695 r
.49575 .7491 m .49131 .74828 L p .49398 .75504 L F P
0 g
s
.765 .625 .704 r
.49575 .7491 m .49408 .74459 L .49131 .74828 L closepath p F P
0 g
s
.651 .758 .928 r
.68604 .60785 m .69543 .60504 L .69763 .60763 L p F P
0 g
s
.651 .758 .928 r
.69543 .60504 m .68604 .60785 L .68382 .60526 L p F P
0 g
s
.65 .757 .928 r
.40968 .60246 m .40076 .60527 L .40342 .60786 L p F P
0 g
s
.65 .757 .928 r
.40342 .60786 m .41233 .60506 L .40968 .60246 L p F P
0 g
s
.651 .758 .928 r
.54473 .60787 m .55388 .60507 L .5563 .60765 L p F P
0 g
s
.651 .758 .928 r
.55388 .60507 m .54473 .60787 L .54229 .60528 L p F P
0 g
s
.671 .503 .649 r
.53928 .77475 m .55008 .77383 L p .5457 .77972 L F P
0 g
s
.671 .503 .649 r
.5457 .77972 m .54029 .78018 L .53928 .77475 L p F P
0 g
s
.677 .519 .664 r
.54889 .76823 m .55008 .77383 L .53928 .77475 L p F P
0 g
s
.66 .572 .745 r
.54635 .71667 m .54433 .71699 L .54208 .71093 L p F P
0 g
s
.758 .621 .708 r
.49408 .74459 m .49566 .74261 L .4932 .74221 L closepath p F P
0 g
s
.755 .63 .722 r
.4916 .73825 m .49378 .73562 L p .49566 .74261 L F P
0 g
s
.755 .63 .722 r
.49566 .74261 m .4932 .74221 L .4916 .73825 L p F P
0 g
s
.76 .643 .732 r
.49241 .72849 m .4989 .72974 L .49378 .73562 L p F P
0 g
s
.756 .636 .728 r
.4976 .72259 m .49241 .72849 L .4989 .72974 L p F P
0 g
s
.756 .636 .728 r
.49864 .72279 m .4976 .72259 L p .4989 .72974 L F P
0 g
s
.655 .503 .665 r
.54889 .76823 m .55924 .76685 L p .55145 .77365 L F P
0 g
s
.655 .503 .665 r
.55145 .77365 m .55008 .77383 L .54889 .76823 L p F P
0 g
s
.66 .514 .675 r
.5579 .76112 m .55924 .76685 L .54889 .76823 L p F P
0 g
s
.654 .555 .731 r
.54949 .7233 m .55678 .72203 L p .55438 .72942 L F P
0 g
s
.654 .561 .738 r
.55678 .72203 m .55614 .7202 L .54949 .7233 L closepath p F P
0 g
s
.657 .564 .738 r
.55443 .71531 m .55614 .7202 L .54949 .7233 L p F P
0 g
s
.657 .564 .738 r
.54635 .71667 m .55443 .71531 L p .54949 .7233 L F P
0 g
s
.651 .758 .928 r
.83895 .60753 m .8486 .60472 L .85056 .6073 L p F P
0 g
s
.651 .758 .928 r
.8486 .60472 m .83895 .60753 L .83697 .60495 L p F P
0 g
s
.751 .589 .676 r
.5017 .76815 m .50148 .76739 L .50104 .76806 L closepath p F P
0 g
s
.65 .757 .928 r
.27948 .6022 m .27078 .605 L .27365 .60759 L p F P
0 g
s
.65 .757 .928 r
.27365 .60759 m .28234 .60479 L .27948 .6022 L p F P
0 g
s
.651 .758 .928 r
.69763 .60763 m .70705 .60482 L .70922 .60741 L p F P
0 g
s
.651 .758 .928 r
.70705 .60482 m .69763 .60763 L .69543 .60504 L p F P
0 g
s
.737 .569 .665 r
.50583 .77423 m .50314 .774 L .5017 .76815 L p F P
0 g
s
.752 .578 .66 r
.50104 .76806 m .5017 .76815 L .50314 .774 L p F P
0 g
s
.65 .757 .928 r
.42127 .60224 m .41233 .60506 L .41498 .60764 L p F P
0 g
s
.65 .757 .928 r
.41498 .60764 m .42391 .60484 L .42127 .60224 L p F P
0 g
s
.651 .758 .928 r
.5563 .60765 m .56548 .60485 L .56788 .60744 L p F P
0 g
s
.651 .758 .928 r
.56548 .60485 m .5563 .60765 L .55388 .60507 L p F P
0 g
s
.64 .509 .687 r
.55688 .75706 m .56217 .75422 L .55643 .75527 L closepath p F P
0 g
s
.752 .578 .66 r
.50314 .774 m .4981 .77336 L .50104 .76806 L p F P
0 g
s
.757 .585 .664 r
.49389 .76703 m .50104 .76806 L .4981 .77336 L p F P
0 g
s
.75 .589 .675 r
.49721 .76164 m .49389 .76703 L .50104 .76806 L p F P
0 g
s
.755 .6 .685 r
.49398 .75504 m .49033 .76051 L .49721 .76164 L p F P
0 g
s
.761 .604 .684 r
.49033 .76051 m .49721 .76164 L .49389 .76703 L p F P
0 g
s
.765 .625 .704 r
.49131 .74828 m .49408 .74459 L .4932 .74221 L p F P
0 g
s
.657 .569 .744 r
.55443 .71531 m .55368 .71326 L .54635 .71667 L closepath p F P
0 g
s
.66 .572 .745 r
.55192 .70844 m .55368 .71326 L .54635 .71667 L p F P
0 g
s
.66 .572 .745 r
.54478 .70959 m .55192 .70844 L p .54635 .71667 L F P
0 g
s
.66 .572 .745 r
.54208 .71093 m .54478 .70959 L p .54635 .71667 L F P
0 g
s
.651 .758 .928 r
.85056 .6073 m .86024 .60449 L .86217 .60707 L p F P
0 g
s
.651 .758 .928 r
.86024 .60449 m .85056 .6073 L .8486 .60472 L p F P
0 g
s
.65 .757 .928 r
.29106 .60199 m .28234 .60479 L .28519 .60738 L p F P
0 g
s
.65 .757 .928 r
.28519 .60738 m .2939 .60459 L .29106 .60199 L p F P
0 g
s
.651 .758 .928 r
.70922 .60741 m .71866 .6046 L .72082 .60719 L p F P
0 g
s
.651 .758 .928 r
.71866 .6046 m .70922 .60741 L .70705 .60482 L p F P
0 g
s
.65 .757 .928 r
.43287 .60203 m .42391 .60484 L .42653 .60743 L p F P
0 g
s
.65 .757 .928 r
.42653 .60743 m .43549 .60463 L .43287 .60203 L p F P
0 g
s
.651 .758 .928 r
.57707 .60463 m .56788 .60744 L .56548 .60485 L p F P
0 g
s
.651 .758 .928 r
.56788 .60744 m .57707 .60463 L .57946 .60722 L p F P
0 g
s
.652 .554 .732 r
.55899 .7286 m .5586 .72746 L .55438 .72942 L closepath p F P
0 g
s
.654 .555 .731 r
.55678 .72203 m .5586 .72746 L .55438 .72942 L p F P
0 g
s
.641 .511 .689 r
.5579 .76112 m .55688 .75706 L .56217 .75422 L p F P
0 g
s
.765 .625 .704 r
.4932 .74221 m .48916 .74137 L p .49131 .74828 L F P
0 g
s
.77 .637 .714 r
.4932 .74221 m .4916 .73825 L .48916 .74137 L closepath p F P
0 g
s
.663 .573 .744 r
.54208 .71093 m .54478 .70959 L .54175 .71004 L closepath p F P
0 g
s
.765 .617 .695 r
.4874 .75383 m .49398 .75504 L .49033 .76051 L p F P
0 g
s
.76 .613 .695 r
.49131 .74828 m .4874 .75383 L .49398 .75504 L p F P
0 g
s
.736 .634 .745 r
.50736 .71291 m .51061 .71003 L .50587 .70952 L closepath p F P
0 g
s
.747 .639 .74 r
.50377 .71641 m .50736 .71291 L .50587 .70952 L p F P
0 g
s
.65 .757 .928 r
.16083 .60162 m .15233 .60441 L .15539 .60701 L p F P
0 g
s
.65 .757 .928 r
.15539 .60701 m .16388 .60422 L .16083 .60162 L p F P
0 g
s
.651 .758 .928 r
.86217 .60707 m .87187 .60425 L .87379 .60684 L p F P
0 g
s
.651 .758 .928 r
.87187 .60425 m .86217 .60707 L .86024 .60449 L p F P
0 g
s
.732 .555 .653 r
.50393 .77769 m .50583 .77423 L p .51152 .78015 L F P
0 g
s
.737 .558 .651 r
.50393 .77769 m .50583 .77423 L .50314 .774 L closepath p F P
0 g
s
.69 .506 .633 r
.52956 .78423 m .53184 .78054 L .52898 .78063 L closepath p F P
0 g
s
.702 .514 .631 r
.52898 .78063 m .5209 .78056 L p .52863 .78592 L F P
0 g
s
.702 .514 .631 r
.52863 .78592 m .52956 .78423 L .52898 .78063 L p F P
0 g
s
.65 .757 .928 r
.30264 .60178 m .2939 .60459 L .29673 .60718 L p F P
0 g
s
.65 .757 .928 r
.29673 .60718 m .30546 .60438 L .30264 .60178 L p F P
0 g
s
.754 .642 .737 r
.50377 .71641 m .49824 .7219 L .49576 .71643 L p F P
0 g
s
.754 .642 .737 r
.49576 .71643 m .49691 .71525 L .50377 .71641 L p F P
0 g
s
.747 .639 .74 r
.50316 .70904 m .49691 .71525 L .50377 .71641 L p F P
0 g
s
.747 .639 .74 r
.50587 .70952 m .50316 .70904 L p .50377 .71641 L F P
0 g
s
.651 .758 .928 r
.72082 .60719 m .73028 .60438 L .73242 .60697 L p F P
0 g
s
.651 .758 .928 r
.73028 .60438 m .72082 .60719 L .71866 .6046 L p F P
0 g
s
.65 .757 .928 r
.44447 .60181 m .43549 .60463 L .4381 .60722 L p F P
0 g
s
.65 .757 .928 r
.4381 .60722 m .44707 .60441 L .44447 .60181 L p F P
0 g
s
.651 .758 .928 r
.57946 .60722 m .58868 .60441 L .59104 .607 L p F P
0 g
s
.651 .758 .928 r
.58868 .60441 m .57946 .60722 L .57707 .60463 L p F P
0 g
s
.76 .647 .736 r
.49864 .72279 m .49824 .7219 L .4976 .72259 L closepath p F P
0 g
s
.763 .634 .718 r
.4916 .73825 m .49378 .73562 L .49027 .73497 L closepath p F P
0 g
s
.76 .643 .732 r
.48911 .73231 m .49241 .72849 L p .49378 .73562 L F P
0 g
s
.76 .643 .732 r
.49378 .73562 m .49027 .73497 L .48911 .73231 L p F P
0 g
s
.702 .514 .631 r
.5209 .78056 m .51807 .78583 L .52863 .78592 L p F P
0 g
s
.711 .525 .635 r
.51704 .78048 m .5209 .78056 L .51807 .78583 L p F P
0 g
s
.691 .507 .634 r
.53184 .78054 m .54029 .78018 L p .52983 .78592 L F P
0 g
s
.691 .507 .634 r
.52983 .78592 m .52956 .78423 L .53184 .78054 L p F P
0 g
s
.65 .757 .928 r
.17239 .60142 m .16388 .60422 L .16692 .60681 L p F P
0 g
s
.65 .757 .928 r
.16692 .60681 m .17542 .60403 L .17239 .60142 L p F P
0 g
s
.711 .525 .635 r
.51807 .78583 m .51794 .78583 L .51704 .78048 L p F P
0 g
s
.728 .536 .631 r
.51152 .78015 m .51704 .78048 L .51794 .78583 L p F P
0 g
s
.651 .758 .928 r
.87379 .60684 m .88351 .60401 L .88541 .6066 L p F P
0 g
s
.651 .758 .928 r
.88351 .60401 m .87379 .60684 L .87187 .60425 L p F P
0 g
s
.762 .65 .738 r
.4976 .72259 m .49824 .7219 L .49576 .71643 L p F P
0 g
s
.65 .757 .928 r
.31422 .60156 m .30546 .60438 L .30828 .60697 L p F P
0 g
s
.65 .757 .928 r
.30828 .60697 m .31703 .60416 L .31422 .60156 L p F P
0 g
s
.746 .564 .648 r
.50314 .774 m .4981 .77336 L p .50302 .77949 L F P
0 g
s
.746 .564 .648 r
.50302 .77949 m .50393 .77769 L .50314 .774 L p F P
0 g
s
.651 .758 .928 r
.73242 .60697 m .7419 .60416 L .74403 .60675 L p F P
0 g
s
.651 .758 .928 r
.7419 .60416 m .73242 .60697 L .73028 .60438 L p F P
0 g
s
.65 .757 .928 r
.45607 .6016 m .44707 .60441 L .44966 .607 L p F P
0 g
s
.65 .757 .928 r
.44966 .607 m .45865 .6042 L .45607 .6016 L p F P
0 g
s
.651 .758 .928 r
.59104 .607 m .60028 .6042 L .60263 .60679 L p F P
0 g
s
.651 .758 .928 r
.60028 .6042 m .59104 .607 L .58868 .60441 L p F P
0 g
s
.641 .511 .689 r
.56633 .75343 m .56779 .75927 L .5579 .76112 L p F P
0 g
s
.641 .511 .689 r
.56217 .75422 m .56633 .75343 L p .5579 .76112 L F P
0 g
s
.637 .5 .679 r
.5579 .76112 m .56779 .75927 L p .56096 .76653 L F P
0 g
s
.637 .5 .679 r
.56096 .76653 m .55924 .76685 L .5579 .76112 L p F P
0 g
s
.77 .631 .706 r
.48503 .74698 m .49131 .74828 L .4874 .75383 L p F P
0 g
s
.765 .625 .704 r
.48916 .74137 m .48503 .74698 L .49131 .74828 L p F P
0 g
s
.764 .655 .742 r
.49147 .72122 m .4976 .72259 L .49241 .72849 L p F P
0 g
s
.762 .65 .738 r
.49576 .71643 m .49147 .72122 L .4976 .72259 L p F P
0 g
s
.77 .637 .714 r
.48916 .74137 m .4916 .73825 L .49027 .73497 L p F P
0 g
s
.651 .758 .928 r
.88541 .6066 m .89515 .60377 L .89704 .60636 L p F P
0 g
s
.651 .758 .928 r
.89515 .60377 m .88541 .6066 L .88351 .60401 L p F P
0 g
s
.65 .757 .928 r
.18396 .60123 m .17542 .60403 L .17844 .60662 L p F P
0 g
s
.65 .757 .928 r
.17844 .60662 m .18697 .60383 L .18396 .60123 L p F P
0 g
s
.652 .487 .648 r
.55025 .77473 m .55145 .77365 L .55008 .77383 L closepath p F P
0 g
s
.671 .503 .649 r
.55008 .77383 m .55025 .77473 L .5457 .77972 L p F P
0 g
s
.651 .758 .928 r
.74403 .60675 m .75353 .60394 L .75564 .60653 L p F P
0 g
s
.651 .758 .928 r
.75353 .60394 m .74403 .60675 L .7419 .60416 L p F P
0 g
s
.65 .757 .928 r
.32581 .60135 m .31703 .60416 L .31983 .60676 L p F P
0 g
s
.65 .757 .928 r
.31983 .60676 m .3286 .60395 L .32581 .60135 L p F P
0 g
s
.651 .758 .928 r
.60263 .60679 m .61189 .60398 L .61422 .60657 L p F P
0 g
s
.651 .758 .928 r
.61189 .60398 m .60263 .60679 L .60028 .6042 L p F P
0 g
s
.65 .757 .928 r
.46768 .60138 m .45865 .6042 L .46123 .60679 L p F P
0 g
s
.65 .757 .928 r
.46123 .60679 m .47024 .60398 L .46768 .60138 L p F P
0 g
s
.022 0 .396 r
.52577 .59178 m .52576 .59178 L .52576 .58754 L p F P
0 g
s
.022 0 .396 r
.52576 .58754 m .52577 .58753 L .52577 .59178 L p F P
0 g
s
.743 .485 .54 r
.52575 .59178 m .52576 .59178 L .52576 .58754 L p F P
0 g
s
.743 .485 .54 r
.52576 .58754 m .52575 .58753 L .52575 .59178 L p F P
0 g
s
.022 0 .395 r
.52576 .58753 m .52575 .58753 L .52575 .59178 L p F P
0 g
s
.743 .485 .54 r
.52576 .58753 m .52577 .58753 L .52577 .59178 L p F P
0 g
s
.743 .485 .54 r
.52577 .59178 m .52576 .59177 L .52576 .58753 L p F P
0 g
s
.022 0 .395 r
.52575 .59178 m .52576 .59177 L .52576 .58753 L p F P
0 g
s
.669 .49 .635 r
.54029 .78018 m .5457 .77972 L .54129 .78544 L p F P
0 g
s
.669 .49 .635 r
.54129 .78544 m .54112 .78545 L .54029 .78018 L p F P
0 g
s
.691 .507 .634 r
.54029 .78018 m .54112 .78545 L .52983 .78592 L p F P
0 g
s
.728 .536 .631 r
.51794 .78583 m .50914 .7853 L .51152 .78015 L p F P
0 g
s
.732 .54 .633 r
.50435 .77964 m .51152 .78015 L .50914 .7853 L p F P
0 g
s
.732 .555 .653 r
.51152 .78015 m .50435 .77964 L .50393 .77769 L p F P
0 g
s
.651 .758 .928 r
.89704 .60636 m .9068 .60353 L .90866 .60611 L p F P
0 g
s
.651 .758 .928 r
.9068 .60353 m .89704 .60636 L .89515 .60377 L p F P
0 g
s
.65 .757 .928 r
.19553 .60103 m .18697 .60383 L .18997 .60643 L p F P
0 g
s
.65 .757 .928 r
.18997 .60643 m .19852 .60363 L .19553 .60103 L p F P
0 g
s
.652 .488 .649 r
.55106 .77922 m .55025 .77473 L .55145 .77365 L p F P
0 g
s
.667 .498 .647 r
.55106 .77922 m .55025 .77473 L .5457 .77972 L closepath p F P
0 g
s
.652 .488 .649 r
.55145 .77365 m .56038 .77239 L p .55106 .77922 L F P
0 g
s
.651 .497 .661 r
.56038 .77239 m .55937 .76749 L .55145 .77365 L closepath p F P
0 g
s
.655 .503 .665 r
.55924 .76685 m .55937 .76749 L .55145 .77365 L p F P
0 g
s
.651 .758 .928 r
.75564 .60653 m .76516 .60372 L .76725 .60631 L p F P
0 g
s
.651 .758 .928 r
.76516 .60372 m .75564 .60653 L .75353 .60394 L p F P
0 g
s
.65 .757 .928 r
.3374 .60114 m .3286 .60395 L .33138 .60654 L p F P
0 g
s
.65 .757 .928 r
.33138 .60654 m .34017 .60374 L .3374 .60114 L p F P
0 g
s
.651 .758 .928 r
.61422 .60657 m .6235 .60376 L .62581 .60635 L p F P
0 g
s
.651 .758 .928 r
.6235 .60376 m .61422 .60657 L .61189 .60398 L p F P
0 g
s
.65 .757 .928 r
.47929 .60117 m .47024 .60398 L .4728 .60657 L p F P
0 g
s
.65 .757 .928 r
.4728 .60657 m .48184 .60377 L .47929 .60117 L p F P
0 g
s
.627 .522 .716 r
.56107 .73509 m .56158 .73491 L .56105 .73503 L closepath p F P
0 g
s
.629 .533 .727 r
.56158 .73491 m .56105 .73503 L .55899 .7286 L p F P
0 g
s
.627 .524 .717 r
.56294 .74129 m .56107 .73509 L .56158 .73491 L p F P
0 g
s
.629 .533 .727 r
.55899 .7286 m .56845 .72628 L p .56158 .73491 L F P
0 g
s
.632 .543 .736 r
.56778 .7243 m .56845 .72628 L .55899 .7286 L p F P
0 g
s
.632 .543 .736 r
.55899 .7286 m .5586 .72746 L .56778 .7243 L p F P
0 g
s
.631 .541 .734 r
.56625 .71971 m .56778 .7243 L .5586 .72746 L p F P
0 g
s
.631 .541 .734 r
.5586 .72746 m .55678 .72203 L .56625 .71971 L p F P
0 g
s
.77 .637 .714 r
.49027 .73497 m .48749 .73432 L p .48916 .74137 L F P
0 g
s
.775 .649 .723 r
.49027 .73497 m .48911 .73231 L .48749 .73432 L closepath p F P
0 g
s
.641 .52 .7 r
.56633 .75343 m .56603 .75232 L .56217 .75422 L closepath p F P
0 g
s
.643 .52 .699 r
.5647 .74742 m .56603 .75232 L .56217 .75422 L p F P
0 g
s
.774 .644 .718 r
.48318 .73997 m .48916 .74137 L .48503 .74698 L p F P
0 g
s
.77 .637 .714 r
.48749 .73432 m .48318 .73997 L .48916 .74137 L p F P
0 g
s
.747 .565 .648 r
.50435 .77964 m .50393 .77769 L .50302 .77949 L closepath p F P
0 g
s
.65 .757 .928 r
.2071 .60083 m .19852 .60363 L .20151 .60623 L p F P
0 g
s
.65 .757 .928 r
.20151 .60623 m .21008 .60343 L .2071 .60083 L p F P
0 g
s
.768 .647 .728 r
.48911 .73231 m .49241 .72849 L .48692 .72732 L closepath p F P
0 g
s
.764 .655 .742 r
.48662 .72668 m .49147 .72122 L p .49241 .72849 L F P
0 g
s
.764 .655 .742 r
.49241 .72849 m .48692 .72732 L .48662 .72668 L p F P
0 g
s
.757 .585 .664 r
.4981 .77336 m .49088 .77234 L .49389 .76703 L p F P
0 g
s
.762 .592 .667 r
.48763 .76604 m .49389 .76703 L .49088 .77234 L p F P
0 g
s
.761 .604 .684 r
.48739 .76525 m .49033 .76051 L p .49389 .76703 L F P
0 g
s
.761 .604 .684 r
.49389 .76703 m .48763 .76604 L .48739 .76525 L p F P
0 g
s
.627 .524 .717 r
.56158 .73491 m .5705 .73271 L p .56294 .74129 L F P
0 g
s
.629 .534 .728 r
.5705 .73271 m .57025 .73193 L .56158 .73491 L closepath p F P
0 g
s
.629 .533 .727 r
.56845 .72628 m .57025 .73193 L .56158 .73491 L p F P
0 g
s
.703 .515 .632 r
.52983 .78592 m .52956 .78423 L .52863 .78592 L closepath p F P
0 g
s
.634 .55 .742 r
.56531 .71702 m .56625 .71971 L .55678 .72203 L p F P
0 g
s
.634 .55 .742 r
.55678 .72203 m .55614 .7202 L .56531 .71702 L p F P
0 g
s
.651 .758 .928 r
.77679 .60349 m .76725 .60631 L .76516 .60372 L p F P
0 g
s
.651 .758 .928 r
.76725 .60631 m .77679 .60349 L .77886 .60608 L p F P
0 g
s
.624 .514 .708 r
.56354 .7434 m .56294 .74129 L .5724 .73898 L p F P
0 g
s
.627 .524 .717 r
.5705 .73271 m .5724 .73898 L .56294 .74129 L p F P
0 g
s
.65 .757 .928 r
.349 .60093 m .34017 .60374 L .34294 .60633 L p F P
0 g
s
.65 .757 .928 r
.34294 .60633 m .35175 .60353 L .349 .60093 L p F P
0 g
s
.651 .758 .928 r
.62581 .60635 m .63511 .60354 L .63741 .60614 L p F P
0 g
s
.651 .758 .928 r
.63511 .60354 m .62581 .60635 L .6235 .60376 L p F P
0 g
s
.65 .757 .928 r
.4909 .60095 m .48184 .60377 L .48437 .60636 L p F P
0 g
s
.65 .757 .928 r
.48437 .60636 m .49343 .60355 L .4909 .60095 L p F P
0 g
s
.767 .607 .681 r
.48739 .76525 m .49033 .76051 L .48565 .75968 L closepath p F P
0 g
s
.765 .617 .695 r
.48492 .75757 m .4874 .75383 L p .49033 .76051 L F P
0 g
s
.765 .617 .695 r
.49033 .76051 m .48565 .75968 L .48492 .75757 L p F P
0 g
s
.746 .564 .648 r
.4981 .77336 m .49556 .77854 L .50302 .77949 L p F P
0 g
s
.756 .577 .653 r
.49088 .77234 m .4981 .77336 L .49556 .77854 L p F P
0 g
s
.634 .548 .74 r
.56392 .713 m .56531 .71702 L .55614 .7202 L p F P
0 g
s
.634 .548 .74 r
.55614 .7202 m .55443 .71531 L .56392 .713 L p F P
0 g
s
.625 .516 .71 r
.5647 .74742 m .56354 .7434 L .57273 .74015 L p F P
0 g
s
.624 .514 .708 r
.5724 .73898 m .57273 .74015 L .56354 .7434 L p F P
0 g
s
.664 .484 .631 r
.5457 .77972 m .55106 .77922 L .55185 .78444 L p F P
0 g
s
.664 .484 .631 r
.55185 .78444 m .54129 .78544 L .5457 .77972 L p F P
0 g
s
.755 .659 .755 r
.4968 .70773 m .50316 .70904 L .49691 .71525 L p F P
0 g
s
.633 .485 .663 r
.55937 .76749 m .56096 .76653 L .55924 .76685 L closepath p F P
0 g
s
.65 .757 .928 r
.21868 .60062 m .21008 .60343 L .21305 .60603 L p F P
0 g
s
.65 .757 .928 r
.21305 .60603 m .22164 .60323 L .21868 .60062 L p F P
0 g
s
.651 .758 .928 r
.77886 .60608 m .78843 .60327 L .79048 .60586 L p F P
0 g
s
.651 .758 .928 r
.78843 .60327 m .77886 .60608 L .77679 .60349 L p F P
0 g
s
.65 .757 .928 r
.36059 .60071 m .35175 .60353 L .35449 .60612 L p F P
0 g
s
.65 .757 .928 r
.35449 .60612 m .36333 .60332 L .36059 .60071 L p F P
0 g
s
.732 .54 .633 r
.50914 .7853 m .50528 .78503 L .50435 .77964 L p F P
0 g
s
.747 .551 .629 r
.50302 .77949 m .50435 .77964 L .50528 .78503 L p F P
0 g
s
.651 .758 .928 r
.63741 .60614 m .64673 .60332 L .64901 .60592 L p F P
0 g
s
.651 .758 .928 r
.64673 .60332 m .63741 .60614 L .63511 .60354 L p F P
0 g
s
.65 .757 .928 r
.50252 .60073 m .49343 .60355 L .49595 .60614 L p F P
0 g
s
.65 .757 .928 r
.49595 .60614 m .50503 .60334 L .50252 .60073 L p F P
0 g
s
.634 .486 .664 r
.56038 .77239 m .55937 .76749 L .56096 .76653 L p F P
0 g
s
.636 .557 .749 r
.56285 .71006 m .56392 .713 L .55443 .71531 L p F P
0 g
s
.636 .557 .749 r
.55443 .71531 m .55368 .71326 L .56285 .71006 L p F P
0 g
s
.621 .506 .701 r
.56603 .75232 m .5647 .74742 L .57414 .7451 L p F P
0 g
s
.625 .516 .71 r
.57273 .74015 m .57414 .7451 L .5647 .74742 L p F P
0 g
s
.772 .621 .692 r
.48492 .75757 m .4874 .75383 L .48333 .75301 L closepath p F P
0 g
s
.77 .631 .706 r
.48244 .75067 m .48503 .74698 L p .4874 .75383 L F P
0 g
s
.77 .631 .706 r
.4874 .75383 m .48333 .75301 L .48244 .75067 L p F P
0 g
s
.775 .65 .724 r
.48749 .73432 m .48911 .73231 L .48692 .72732 L p F P
0 g
s
.758 .65 .741 r
.49576 .71643 m .49691 .71525 L .49505 .71489 L closepath p F P
0 g
s
.755 .659 .755 r
.49326 .71128 m .4968 .70773 L p .49691 .71525 L F P
0 g
s
.755 .659 .755 r
.49691 .71525 m .49505 .71489 L .49326 .71128 L p F P
0 g
s
.7 .497 .61 r
.52863 .78592 m .52983 .78592 L .53042 .79097 L p F P
0 g
s
.7 .497 .61 r
.53042 .79097 m .52663 .79098 L .52863 .78592 L p F P
0 g
s
.705 .502 .612 r
.51807 .78583 m .52863 .78592 L .52663 .79098 L p F P
0 g
s
.684 .485 .612 r
.52983 .78592 m .54112 .78545 L p .53882 .79063 L F P
0 g
s
.684 .485 .612 r
.53882 .79063 m .53042 .79097 L .52983 .78592 L p F P
0 g
s
.747 .551 .629 r
.50528 .78503 m .50098 .78455 L .50302 .77949 L p F P
0 g
s
.752 .558 .633 r
.49556 .77854 m .50302 .77949 L .50098 .78455 L p F P
0 g
s
.65 .757 .928 r
.23026 .60042 m .22164 .60323 L .22459 .60582 L p F P
0 g
s
.65 .757 .928 r
.22459 .60582 m .2332 .60302 L .23026 .60042 L p F P
0 g
s
.651 .758 .928 r
.79048 .60586 m .80006 .60304 L .8021 .60563 L p F P
0 g
s
.651 .758 .928 r
.80006 .60304 m .79048 .60586 L .78843 .60327 L p F P
0 g
s
.769 .654 .736 r
.49147 .72122 m .49576 .71643 L .49505 .71489 L p F P
0 g
s
.65 .757 .928 r
.37219 .6005 m .36333 .60332 L .36605 .60591 L p F P
0 g
s
.65 .757 .928 r
.36605 .60591 m .37491 .6031 L .37219 .6005 L p F P
0 g
s
.651 .758 .928 r
.64901 .60592 m .65835 .60311 L .66061 .6057 L p F P
0 g
s
.651 .758 .928 r
.65835 .60311 m .64901 .60592 L .64673 .60332 L p F P
0 g
s
.65 .757 .928 r
.50753 .60593 m .51663 .60312 L .51911 .60571 L p F P
0 g
s
.65 .757 .928 r
.51414 .60052 m .50503 .60334 L .50753 .60593 L p F P
0 g
s
.65 .757 .928 r
.50753 .60593 m .51663 .60312 L .51414 .60052 L p F P
0 g
s
.636 .556 .747 r
.56143 .70613 m .56285 .71006 L .55368 .71326 L p F P
0 g
s
.636 .556 .747 r
.55368 .71326 m .55192 .70844 L .56143 .70613 L p F P
0 g
s
.705 .502 .612 r
.51797 .78608 m .51807 .78583 L p .52663 .79098 L F P
0 g
s
.709 .506 .611 r
.51797 .78608 m .51807 .78583 L .51794 .78583 L closepath p F P
0 g
s
.721 .514 .609 r
.51794 .78583 m .50914 .7853 L p .51636 .79081 L F P
0 g
s
.721 .514 .609 r
.51636 .79081 m .51797 .78608 L .51794 .78583 L p F P
0 g
s
.634 .486 .664 r
.56096 .76653 m .5691 .76497 L p .56038 .77239 L F P
0 g
s
.635 .497 .678 r
.5691 .76497 m .56853 .7625 L .56096 .76653 L closepath p F P
0 g
s
.637 .5 .679 r
.56779 .75927 m .56853 .7625 L .56096 .76653 L p F P
0 g
s
.705 .502 .612 r
.52663 .79098 m .51855 .79092 L .51797 .78608 L p F P
0 g
s
.721 .514 .609 r
.51855 .79092 m .51797 .78608 L .51636 .79081 L closepath p F P
0 g
s
.779 .657 .729 r
.48182 .73282 m .48749 .73432 L .48318 .73997 L p F P
0 g
s
.775 .65 .724 r
.48623 .72714 m .48182 .73282 L .48749 .73432 L p F P
0 g
s
.775 .65 .724 r
.48692 .72732 m .48623 .72714 L p .48749 .73432 L F P
0 g
s
.65 .757 .928 r
.24184 .60021 m .2332 .60302 L .23613 .60562 L p F P
0 g
s
.65 .757 .928 r
.23613 .60562 m .24476 .60282 L .24184 .60021 L p F P
0 g
s
.651 .758 .928 r
.8021 .60563 m .8117 .60281 L .81372 .60541 L p F P
0 g
s
.651 .758 .928 r
.8117 .60281 m .8021 .60563 L .80006 .60304 L p F P
0 g
s
.65 .757 .928 r
.3838 .60028 m .37491 .6031 L .37762 .6057 L p F P
0 g
s
.65 .757 .928 r
.37762 .6057 m .3865 .60289 L .3838 .60028 L p F P
0 g
s
.651 .758 .928 r
.66061 .6057 m .66997 .60289 L .67221 .60548 L p F P
0 g
s
.651 .758 .928 r
.66997 .60289 m .66061 .6057 L .65835 .60311 L p F P
0 g
s
.651 .757 .928 r
.51911 .60571 m .52823 .6029 L .5307 .6055 L p F P
0 g
s
.713 .613 .743 r
.51911 .60571 m .52823 .6029 L .52577 .59604 L p F P
0 g
s
.713 .613 .743 r
.51663 .60312 m .51911 .60571 L p .52577 .59604 L F P
0 g
s
.646 .471 .633 r
.55106 .77922 m .56136 .77779 L p .55984 .78335 L F P
0 g
s
.646 .471 .633 r
.55984 .78335 m .55185 .78444 L .55106 .77922 L p F P
0 g
s
.652 .488 .649 r
.56038 .77239 m .56136 .77779 L .55106 .77922 L p F P
0 g
s
.622 .508 .703 r
.56633 .75343 m .56603 .75232 L .57522 .7491 L p F P
0 g
s
.621 .506 .701 r
.57414 .7451 m .57522 .7491 L .56603 .75232 L p F P
0 g
s
.769 .654 .736 r
.49505 .71489 m .49092 .71383 L p .49147 .72122 L F P
0 g
s
.773 .666 .744 r
.49505 .71489 m .49326 .71128 L .49092 .71383 L closepath p F P
0 g
s
.618 .494 .69 r
.56779 .75927 m .56633 .75343 L .57577 .7511 L p F P
0 g
s
.622 .508 .703 r
.57522 .7491 m .57577 .7511 L .56633 .75343 L p F P
0 g
s
.777 .635 .703 r
.48244 .75067 m .48503 .74698 L .48063 .74598 L closepath p F P
0 g
s
.774 .644 .718 r
.47995 .74436 m .48318 .73997 L p .48503 .74698 L F P
0 g
s
.774 .644 .718 r
.48503 .74698 m .48063 .74598 L .47995 .74436 L p F P
0 g
s
.651 .758 .928 r
.81372 .60541 m .82335 .60259 L .82534 .60518 L p F P
0 g
s
.651 .758 .928 r
.82335 .60259 m .81372 .60541 L .8117 .60281 L p F P
0 g
s
.65 .757 .928 r
.25343 .60001 m .24476 .60282 L .24768 .60542 L p F P
0 g
s
.65 .757 .928 r
.24768 .60542 m .25633 .60261 L .25343 .60001 L p F P
0 g
s
.775 .658 .734 r
.49147 .72122 m .48662 .72668 L .48412 .72151 L p F P
0 g
s
.775 .658 .734 r
.48412 .72151 m .48562 .71977 L .49147 .72122 L p F P
0 g
s
.769 .654 .736 r
.49092 .71383 m .48562 .71977 L .49147 .72122 L p F P
0 g
s
.651 .758 .928 r
.67221 .60548 m .6816 .60267 L .68382 .60526 L p F P
0 g
s
.651 .758 .928 r
.6816 .60267 m .67221 .60548 L .66997 .60289 L p F P
0 g
s
.65 .757 .928 r
.3954 .60007 m .3865 .60289 L .38919 .60548 L p F P
0 g
s
.65 .757 .928 r
.38919 .60548 m .39808 .60267 L .3954 .60007 L p F P
0 g
s
.65 .757 .928 r
.5307 .6055 m .53984 .60269 L .54229 .60528 L p F P
0 g
s
.65 .757 .928 r
.53984 .60269 m .5307 .6055 L .52823 .6029 L p F P
0 g
s
.665 .47 .611 r
.54115 .7857 m .54129 .78544 L .54112 .78545 L closepath p F P
0 g
s
.684 .485 .612 r
.54112 .78545 m .54115 .7857 L .53882 .79063 L p F P
0 g
s
.665 .47 .611 r
.54129 .78544 m .55185 .78444 L p .54169 .79048 L F P
0 g
s
.665 .47 .611 r
.54169 .79048 m .54115 .7857 L .54129 .78544 L p F P
0 g
s
.779 .624 .688 r
.48565 .75968 m .48492 .75757 L .48384 .75928 L closepath p F P
0 g
s
.774 .611 .677 r
.48565 .75968 m .48384 .75928 L p .487 .76591 L F P
0 g
s
.774 .611 .677 r
.487 .76591 m .48739 .76525 L .48565 .75968 L p F P
0 g
s
.679 .48 .61 r
.54169 .79048 m .54115 .7857 L .53882 .79063 L closepath p F P
0 g
s
.651 .758 .928 r
.82534 .60518 m .83499 .60236 L .83697 .60495 L p F P
0 g
s
.651 .758 .928 r
.83499 .60236 m .82534 .60518 L .82335 .60259 L p F P
0 g
s
.774 .611 .677 r
.48763 .76604 m .48739 .76525 L .487 .76591 L closepath p F P
0 g
s
.762 .592 .667 r
.49088 .77234 m .48928 .77209 L .48763 .76604 L p F P
0 g
s
.777 .6 .661 r
.487 .76591 m .48763 .76604 L .48928 .77209 L p F P
0 g
s
.65 .757 .928 r
.26502 .5998 m .25633 .60261 L .25923 .60521 L p F P
0 g
s
.65 .757 .928 r
.25923 .60521 m .2679 .6024 L .26502 .5998 L p F P
0 g
s
.779 .624 .688 r
.48384 .75928 m .48492 .75757 L .48333 .75301 L p F P
0 g
s
.721 .514 .609 r
.50914 .7853 m .50738 .79029 L .51636 .79081 L p F P
0 g
s
.73 .526 .614 r
.50528 .78503 m .50914 .7853 L .50738 .79029 L p F P
0 g
s
.651 .758 .928 r
.68382 .60526 m .69323 .60245 L .69543 .60504 L p F P
0 g
s
.651 .758 .928 r
.69323 .60245 m .68382 .60526 L .6816 .60267 L p F P
0 g
s
.65 .757 .928 r
.40701 .59985 m .39808 .60267 L .40076 .60527 L p F P
0 g
s
.65 .757 .928 r
.40076 .60527 m .40968 .60246 L .40701 .59985 L p F P
0 g
s
.651 .758 .928 r
.54229 .60528 m .55145 .60247 L .55388 .60507 L p F P
0 g
s
.651 .757 .928 r
.55145 .60247 m .54229 .60528 L .53984 .60269 L p F P
0 g
s
.629 .472 .651 r
.56038 .77239 m .57024 .77052 L p .56872 .7764 L F P
0 g
s
.629 .472 .651 r
.56872 .7764 m .56136 .77779 L .56038 .77239 L p F P
0 g
s
.634 .486 .664 r
.5691 .76497 m .57024 .77052 L .56038 .77239 L p F P
0 g
s
.777 .6 .661 r
.48928 .77209 m .48439 .77111 L .487 .76591 L p F P
0 g
s
.782 .608 .664 r
.48091 .76457 m .487 .76591 L .48439 .77111 L p F P
0 g
s
.774 .611 .677 r
.48384 .75928 m .48091 .76457 L .487 .76591 L p F P
0 g
s
.756 .577 .653 r
.48984 .77449 m .49088 .77234 L p .49556 .77854 L F P
0 g
s
.763 .58 .651 r
.48984 .77449 m .49088 .77234 L .48928 .77209 L closepath p F P
0 g
s
.779 .661 .733 r
.48692 .72732 m .48662 .72668 L .48623 .72714 L closepath p F P
0 g
s
.779 .624 .688 r
.48333 .75301 m .48122 .7525 L p .48384 .75928 L F P
0 g
s
.784 .637 .699 r
.48333 .75301 m .48244 .75067 L .48122 .7525 L closepath p F P
0 g
s
.651 .758 .928 r
.83697 .60495 m .84664 .60213 L .8486 .60472 L p F P
0 g
s
.651 .758 .928 r
.84664 .60213 m .83697 .60495 L .83499 .60236 L p F P
0 g
s
.65 .757 .928 r
.27661 .59959 m .2679 .6024 L .27078 .605 L p F P
0 g
s
.65 .757 .928 r
.27078 .605 m .27948 .6022 L .27661 .59959 L p F P
0 g
s
.651 .758 .928 r
.69543 .60504 m .70486 .60223 L .70705 .60482 L p F P
0 g
s
.651 .758 .928 r
.70486 .60223 m .69543 .60504 L .69323 .60245 L p F P
0 g
s
.65 .757 .928 r
.41863 .59964 m .40968 .60246 L .41233 .60506 L p F P
0 g
s
.65 .757 .928 r
.41233 .60506 m .42127 .60224 L .41863 .59964 L p F P
0 g
s
.651 .758 .928 r
.55388 .60507 m .56307 .60225 L .56548 .60485 L p F P
0 g
s
.651 .758 .928 r
.56307 .60225 m .55388 .60507 L .55145 .60247 L p F P
0 g
s
.782 .665 .735 r
.48623 .72714 m .48662 .72668 L .48412 .72151 L p F P
0 g
s
.73 .526 .614 r
.50738 .79029 m .50596 .79019 L .50528 .78503 L p F P
0 g
s
.748 .537 .61 r
.50098 .78455 m .50528 .78503 L .50596 .79019 L p F P
0 g
s
.788 .664 .727 r
.48087 .72555 m .48623 .72714 L .48182 .73282 L p F P
0 g
s
.782 .665 .735 r
.48412 .72151 m .48087 .72555 L .48623 .72714 L p F P
0 g
s
.779 .624 .688 r
.48122 .7525 m .47801 .75786 L .48384 .75928 L p F P
0 g
s
.787 .623 .678 r
.47801 .75786 m .48384 .75928 L .48091 .76457 L p F P
0 g
s
.615 .483 .679 r
.56853 .7625 m .56779 .75927 L .57723 .75695 L p F P
0 g
s
.618 .494 .69 r
.57577 .7511 m .57723 .75695 L .56779 .75927 L p F P
0 g
s
.783 .648 .714 r
.47995 .74436 m .48318 .73997 L .47747 .73852 L closepath p F P
0 g
s
.779 .657 .729 r
.47745 .73848 m .48182 .73282 L p .48318 .73997 L F P
0 g
s
.779 .657 .729 r
.48318 .73997 m .47747 .73852 L .47745 .73848 L p F P
0 g
s
.752 .558 .633 r
.50098 .78455 m .49345 .78362 L .49556 .77854 L p F P
0 g
s
.757 .563 .635 r
.49063 .77786 m .49556 .77854 L .49345 .78362 L p F P
0 g
s
.756 .577 .653 r
.49556 .77854 m .49063 .77786 L .48984 .77449 L p F P
0 g
s
.784 .638 .699 r
.48122 .7525 m .48244 .75067 L .48063 .74598 L p F P
0 g
s
.651 .758 .928 r
.8486 .60472 m .85829 .60189 L .86024 .60449 L p F P
0 g
s
.651 .758 .928 r
.85829 .60189 m .8486 .60472 L .84664 .60213 L p F P
0 g
s
.771 .586 .648 r
.48928 .77209 m .48439 .77111 L p .4885 .77748 L F P
0 g
s
.771 .586 .648 r
.4885 .77748 m .48984 .77449 L .48928 .77209 L p F P
0 g
s
.65 .757 .928 r
.28821 .59938 m .27948 .6022 L .28234 .60479 L p F P
0 g
s
.65 .757 .928 r
.28234 .60479 m .29106 .60199 L .28821 .59938 L p F P
0 g
s
.651 .758 .928 r
.70705 .60482 m .71649 .60201 L .71866 .6046 L p F P
0 g
s
.651 .758 .928 r
.71649 .60201 m .70705 .60482 L .70486 .60223 L p F P
0 g
s
.65 .757 .928 r
.43024 .59942 m .42127 .60224 L .42391 .60484 L p F P
0 g
s
.65 .757 .928 r
.42391 .60484 m .43287 .60203 L .43024 .59942 L p F P
0 g
s
.651 .758 .928 r
.56548 .60485 m .57468 .60203 L .57707 .60463 L p F P
0 g
s
.651 .758 .928 r
.57468 .60203 m .56548 .60485 L .56307 .60225 L p F P
0 g
s
.764 .663 .751 r
.49326 .71128 m .4968 .70773 L .49083 .70639 L closepath p F P
0 g
s
.65 .757 .928 r
.15777 .59901 m .14927 .60181 L .15233 .60441 L p F P
0 g
s
.65 .757 .928 r
.15233 .60441 m .16083 .60162 L .15777 .59901 L p F P
0 g
s
.651 .758 .928 r
.86024 .60449 m .86995 .60166 L .87187 .60425 L p F P
0 g
s
.651 .758 .928 r
.86995 .60166 m .86024 .60449 L .85829 .60189 L p F P
0 g
s
.774 .667 .745 r
.49092 .71383 m .49326 .71128 L .49083 .70639 L p F P
0 g
s
.65 .757 .928 r
.29981 .59917 m .29106 .60199 L .2939 .60459 L p F P
0 g
s
.65 .757 .928 r
.2939 .60459 m .30264 .60178 L .29981 .59917 L p F P
0 g
s
.651 .758 .928 r
.71866 .6046 m .72813 .60179 L .73028 .60438 L p F P
0 g
s
.651 .758 .928 r
.72813 .60179 m .71866 .6046 L .71649 .60201 L p F P
0 g
s
.65 .757 .928 r
.44186 .59921 m .43287 .60203 L .43549 .60463 L p F P
0 g
s
.65 .757 .928 r
.43549 .60463 m .44447 .60181 L .44186 .59921 L p F P
0 g
s
.651 .758 .928 r
.57707 .60463 m .5863 .60182 L .58868 .60441 L p F P
0 g
s
.651 .758 .928 r
.5863 .60182 m .57707 .60463 L .57468 .60203 L p F P
0 g
s
.098 0 .423 r
.52578 .59603 m .52577 .59604 L .52576 .59178 L p F P
0 g
s
.098 0 .423 r
.52576 .59178 m .52577 .59178 L .52578 .59603 L p F P
0 g
s
.666 .968 .791 r
.51663 .60312 m .51414 .60052 L p .52555 .59611 L F P
0 g
s
.666 .968 .791 r
.52576 .59603 m .52573 .59605 L .52555 .59611 L F
.52573 .59605 m .51663 .60312 L .52555 .59611 L F
.73 .474 .541 r
.52575 .59604 m .52577 .59604 L .52576 .59178 L p F P
0 g
s
.73 .474 .541 r
.52576 .59178 m .52575 .59178 L .52575 .59604 L p F P
0 g
s
.097 0 .422 r
.52576 .59177 m .52575 .59178 L .52575 .59604 L p F P
0 g
s
.73 .474 .54 r
.52576 .59177 m .52577 .59178 L .52578 .59603 L p F P
0 g
s
.73 .474 .54 r
.52578 .59603 m .52576 .59603 L .52576 .59177 L p F P
0 g
s
.097 0 .422 r
.52575 .59604 m .52576 .59603 L .52576 .59177 L p F P
0 g
s
.771 .586 .648 r
.49063 .77786 m .48984 .77449 L .4885 .77748 L closepath p F P
0 g
s
.791 .638 .691 r
.47565 .75099 m .48122 .7525 L .47801 .75786 L p F P
0 g
s
.784 .638 .699 r
.4791 .74557 m .47565 .75099 L .48122 .7525 L p F P
0 g
s
.784 .638 .699 r
.48063 .74598 m .4791 .74557 L p .48122 .7525 L F P
0 g
s
.65 .757 .928 r
.16935 .59881 m .16083 .60162 L .16388 .60422 L p F P
0 g
s
.65 .757 .928 r
.16388 .60422 m .17239 .60142 L .16935 .59881 L p F P
0 g
s
.651 .758 .928 r
.87187 .60425 m .88161 .60142 L .88351 .60401 L p F P
0 g
s
.651 .758 .928 r
.88161 .60142 m .87187 .60425 L .86995 .60166 L p F P
0 g
s
.775 .676 .754 r
.48546 .71226 m .49092 .71383 L .48562 .71977 L p F P
0 g
s
.774 .667 .745 r
.49068 .70634 m .48546 .71226 L .49092 .71383 L p F P
0 g
s
.774 .667 .745 r
.49083 .70639 m .49068 .70634 L p .49092 .71383 L F P
0 g
s
.615 .485 .68 r
.5691 .76497 m .56853 .7625 L .57773 .75913 L p F P
0 g
s
.615 .483 .679 r
.57723 .75695 m .57773 .75913 L .56853 .7625 L p F P
0 g
s
.788 .65 .71 r
.48063 .74598 m .47995 .74436 L .4791 .74557 L closepath p F P
0 g
s
.697 .478 .586 r
.52663 .79098 m .53042 .79097 L .53075 .7958 L p F P
0 g
s
.697 .478 .586 r
.53075 .7958 m .52551 .79581 L .52663 .79098 L p F P
0 g
s
.702 .482 .587 r
.51855 .79092 m .52663 .79098 L .52551 .79581 L p F P
0 g
s
.748 .537 .61 r
.50596 .79019 m .49949 .78946 L .50098 .78455 L p F P
0 g
s
.751 .544 .616 r
.49345 .78362 m .50098 .78455 L .49949 .78946 L p F P
0 g
s
.68 .464 .587 r
.53042 .79097 m .53882 .79063 L .53745 .79553 L p F P
0 g
s
.68 .464 .587 r
.53745 .79553 m .53075 .7958 L .53042 .79097 L p F P
0 g
s
.65 .757 .928 r
.31141 .59896 m .30264 .60178 L .30546 .60438 L p F P
0 g
s
.65 .757 .928 r
.30546 .60438 m .31422 .60156 L .31141 .59896 L p F P
0 g
s
.651 .758 .928 r
.73028 .60438 m .73977 .60156 L .7419 .60416 L p F P
0 g
s
.651 .758 .928 r
.73977 .60156 m .73028 .60438 L .72813 .60179 L p F P
0 g
s
.65 .757 .928 r
.45348 .59899 m .44447 .60181 L .44707 .60441 L p F P
0 g
s
.65 .757 .928 r
.44707 .60441 m .45607 .6016 L .45348 .59899 L p F P
0 g
s
.651 .758 .928 r
.58868 .60441 m .59792 .6016 L .60028 .6042 L p F P
0 g
s
.651 .758 .928 r
.59792 .6016 m .58868 .60441 L .5863 .60182 L p F P
0 g
s
.702 .482 .587 r
.52551 .79581 m .51889 .79576 L .51855 .79092 L p F P
0 g
s
.719 .496 .585 r
.51636 .79081 m .51855 .79092 L .51889 .79576 L p F P
0 g
s
.642 .454 .614 r
.55185 .78444 m .55984 .78335 L .55538 .78909 L p F P
0 g
s
.642 .454 .614 r
.55538 .78909 m .55245 .78949 L .55185 .78444 L p F P
0 g
s
.665 .47 .611 r
.55185 .78444 m .55245 .78949 L .54169 .79048 L p F P
0 g
s
.651 .758 .928 r
.88351 .60401 m .89327 .60118 L .89515 .60377 L p F P
0 g
s
.651 .758 .928 r
.89327 .60118 m .88351 .60401 L .88161 .60142 L p F P
0 g
s
.65 .757 .928 r
.18093 .59861 m .17239 .60142 L .17542 .60403 L p F P
0 g
s
.65 .757 .928 r
.17542 .60403 m .18396 .60123 L .18093 .59861 L p F P
0 g
s
.719 .496 .585 r
.51889 .79576 m .51541 .79559 L .51636 .79081 L p F P
0 g
s
.723 .501 .588 r
.50738 .79029 m .51636 .79081 L .51541 .79559 L p F P
0 g
s
.789 .651 .71 r
.4791 .74557 m .47995 .74436 L .47747 .73852 L p F P
0 g
s
.651 .758 .928 r
.7419 .60416 m .75142 .60134 L .75353 .60394 L p F P
0 g
s
.651 .758 .928 r
.75142 .60134 m .7419 .60416 L .73977 .60156 L p F P
0 g
s
.65 .757 .928 r
.32301 .59874 m .31422 .60156 L .31703 .60416 L p F P
0 g
s
.65 .757 .928 r
.31703 .60416 m .32581 .60135 L .32301 .59874 L p F P
0 g
s
.651 .758 .928 r
.60028 .6042 m .60955 .60138 L .61189 .60398 L p F P
0 g
s
.651 .758 .928 r
.60955 .60138 m .60028 .6042 L .59792 .6016 L p F P
0 g
s
.65 .757 .928 r
.46511 .59877 m .45607 .6016 L .45865 .6042 L p F P
0 g
s
.65 .757 .928 r
.45865 .6042 m .46768 .60138 L .46511 .59877 L p F P
0 g
s
.757 .563 .635 r
.49345 .78362 m .49168 .78338 L .49063 .77786 L p F P
0 g
s
.773 .574 .63 r
.4885 .77748 m .49063 .77786 L .49168 .78338 L p F P
0 g
s
.79 .66 .721 r
.48182 .73282 m .47745 .73848 L .47494 .7332 L p F P
0 g
s
.79 .66 .721 r
.47494 .7332 m .47639 .73126 L .48182 .73282 L p F P
0 g
s
.788 .664 .727 r
.48182 .73282 m .47639 .73126 L .48087 .72555 L p F P
0 g
s
.61 .47 .666 r
.57024 .77052 m .5691 .76497 L .57854 .76265 L p F P
0 g
s
.615 .485 .68 r
.57773 .75913 m .57854 .76265 L .5691 .76497 L p F P
0 g
s
.651 .758 .928 r
.89515 .60377 m .90493 .60093 L .9068 .60353 L p F P
0 g
s
.651 .758 .928 r
.90493 .60093 m .89515 .60377 L .89327 .60118 L p F P
0 g
s
.625 .456 .634 r
.5619 .78134 m .56872 .7764 L .56136 .77779 L closepath p F P
0 g
s
.646 .471 .633 r
.56136 .77779 m .5619 .78134 L .55984 .78335 L p F P
0 g
s
.65 .757 .928 r
.19252 .59842 m .18396 .60123 L .18697 .60383 L p F P
0 g
s
.65 .757 .928 r
.18697 .60383 m .19553 .60103 L .19252 .59842 L p F P
0 g
s
.675 .46 .586 r
.53882 .79063 m .54169 .79048 L .54202 .79529 L p F P
0 g
s
.675 .46 .586 r
.54202 .79529 m .53745 .79553 L .53882 .79063 L p F P
0 g
s
.607 .519 .73 r
.56845 .72628 m .57739 .7234 L p .57896 .73001 L F P
0 g
s
.607 .519 .73 r
.57896 .73001 m .57025 .73193 L .56845 .72628 L p F P
0 g
s
.609 .528 .739 r
.577 .72225 m .57739 .7234 L .56845 .72628 L p F P
0 g
s
.609 .528 .739 r
.56845 .72628 m .56778 .7243 L .577 .72225 L p F P
0 g
s
.604 .51 .721 r
.5724 .73898 m .5705 .73271 L .57896 .73001 L p F P
0 g
s
.607 .522 .732 r
.5705 .73271 m .57025 .73193 L .57896 .73001 L closepath p F P
0 g
s
.797 .651 .702 r
.47379 .74398 m .4791 .74557 L .47565 .75099 L p F P
0 g
s
.789 .651 .71 r
.47743 .73851 m .47379 .74398 L .4791 .74557 L p F P
0 g
s
.789 .651 .71 r
.47747 .73852 m .47743 .73851 L p .4791 .74557 L F P
0 g
s
.651 .758 .928 r
.75353 .60394 m .76306 .60112 L .76516 .60372 L p F P
0 g
s
.651 .758 .928 r
.76306 .60112 m .75353 .60394 L .75142 .60134 L p F P
0 g
s
.65 .757 .928 r
.33462 .59853 m .32581 .60135 L .3286 .60395 L p F P
0 g
s
.65 .757 .928 r
.3286 .60395 m .3374 .60114 L .33462 .59853 L p F P
0 g
s
.651 .758 .928 r
.61189 .60398 m .62118 .60116 L .6235 .60376 L p F P
0 g
s
.651 .758 .928 r
.62118 .60116 m .61189 .60398 L .60955 .60138 L p F P
0 g
s
.65 .757 .928 r
.47674 .59856 m .46768 .60138 L .47024 .60398 L p F P
0 g
s
.65 .757 .928 r
.47024 .60398 m .47929 .60117 L .47674 .59856 L p F P
0 g
s
.607 .526 .737 r
.57518 .7168 m .577 .72225 L .56778 .7243 L p F P
0 g
s
.607 .526 .737 r
.56778 .7243 m .56625 .71971 L .57518 .7168 L p F P
0 g
s
.78 .667 .738 r
.48412 .72151 m .48562 .71977 L .4829 .71902 L closepath p F P
0 g
s
.775 .676 .754 r
.48161 .71658 m .48546 .71226 L p .48562 .71977 L F P
0 g
s
.775 .676 .754 r
.48562 .71977 m .4829 .71902 L .48161 .71658 L p F P
0 g
s
.61 .535 .746 r
.57453 .71497 m .57518 .7168 L .56625 .71971 L p F P
0 g
s
.61 .535 .746 r
.56625 .71971 m .56531 .71702 L .57453 .71497 L p F P
0 g
s
.656 .445 .586 r
.54202 .79529 m .54169 .79048 L .55245 .78949 L p F P
0 g
s
.6 .499 .71 r
.57273 .74015 m .5724 .73898 L .58136 .73613 L p F P
0 g
s
.604 .51 .721 r
.57948 .72991 m .58136 .73613 L .5724 .73898 L p F P
0 g
s
.604 .51 .721 r
.57896 .73001 m .57948 .72991 L p .5724 .73898 L F P
0 g
s
.65 .757 .928 r
.20411 .59821 m .19553 .60103 L .19852 .60363 L p F P
0 g
s
.65 .757 .928 r
.19852 .60363 m .2071 .60083 L .20411 .59821 L p F P
0 g
s
.771 .586 .648 r
.48439 .77111 m .48214 .77622 L .4885 .77748 L p F P
0 g
s
.782 .599 .652 r
.47826 .76978 m .48439 .77111 L .48214 .77622 L p F P
0 g
s
.782 .608 .664 r
.48439 .77111 m .47826 .76978 L .48091 .76457 L p F P
0 g
s
.651 .758 .928 r
.76516 .60372 m .77471 .60089 L .77679 .60349 L p F P
0 g
s
.651 .758 .928 r
.77471 .60089 m .76516 .60372 L .76306 .60112 L p F P
0 g
s
.65 .757 .928 r
.34624 .59832 m .3374 .60114 L .34017 .60374 L p F P
0 g
s
.65 .757 .928 r
.34017 .60374 m .349 .60093 L .34624 .59832 L p F P
0 g
s
.601 .5 .712 r
.57414 .7451 m .57273 .74015 L .58196 .73825 L p F P
0 g
s
.6 .499 .71 r
.58136 .73613 m .58196 .73825 L .57273 .74015 L p F P
0 g
s
.789 .67 .733 r
.48087 .72555 m .48412 .72151 L .4829 .71902 L p F P
0 g
s
.651 .758 .928 r
.6235 .60376 m .63281 .60094 L .63511 .60354 L p F P
0 g
s
.651 .758 .928 r
.63281 .60094 m .6235 .60376 L .62118 .60116 L p F P
0 g
s
.65 .757 .928 r
.48837 .59834 m .47929 .60117 L .48184 .60377 L p F P
0 g
s
.65 .757 .928 r
.48184 .60377 m .4909 .60095 L .48837 .59834 L p F P
0 g
s
.609 .533 .744 r
.57282 .71006 m .57453 .71497 L .56531 .71702 L p F P
0 g
s
.609 .533 .744 r
.56531 .71702 m .56392 .713 L .57282 .71006 L p F P
0 g
s
.773 .574 .63 r
.49168 .78338 m .48668 .78248 L .4885 .77748 L p F P
0 g
s
.778 .581 .633 r
.48214 .77622 m .4885 .77748 L .48668 .78248 L p F P
0 g
s
.786 .618 .673 r
.47503 .76316 m .48091 .76457 L .47826 .76978 L p F P
0 g
s
.787 .623 .678 r
.48091 .76457 m .47503 .76316 L .47801 .75786 L p F P
0 g
s
.723 .501 .588 r
.51541 .79559 m .50636 .79508 L .50738 .79029 L p F P
0 g
s
.728 .506 .589 r
.50596 .79019 m .50738 .79029 L .50636 .79508 L p F P
0 g
s
.65 .757 .928 r
.21571 .59801 m .2071 .60083 L .21008 .60343 L p F P
0 g
s
.65 .757 .928 r
.21008 .60343 m .21868 .60062 L .21571 .59801 L p F P
0 g
s
.611 .542 .753 r
.57207 .708 m .57282 .71006 L .56392 .713 L p F P
0 g
s
.611 .542 .753 r
.56392 .713 m .56285 .71006 L .57207 .708 L p F P
0 g
s
.651 .758 .928 r
.78637 .60067 m .77679 .60349 L .77471 .60089 L p F P
0 g
s
.651 .758 .928 r
.77679 .60349 m .78637 .60067 L .78843 .60327 L p F P
0 g
s
.65 .757 .928 r
.35785 .5981 m .349 .60093 L .35175 .60353 L p F P
0 g
s
.65 .757 .928 r
.35175 .60353 m .36059 .60071 L .35785 .5981 L p F P
0 g
s
.651 .758 .928 r
.63511 .60354 m .64445 .60072 L .64673 .60332 L p F P
0 g
s
.651 .758 .928 r
.64445 .60072 m .63511 .60354 L .63281 .60094 L p F P
0 g
s
.728 .506 .589 r
.50636 .79508 m .50633 .79508 L .50596 .79019 L p F P
0 g
s
.747 .52 .586 r
.49949 .78946 m .50596 .79019 L .50633 .79508 L p F P
0 g
s
.65 .757 .928 r
.5 .59812 m .4909 .60095 L .49343 .60355 L p F P
0 g
s
.65 .757 .928 r
.49343 .60355 m .50252 .60073 L .5 .59812 L p F P
0 g
s
.598 .491 .703 r
.57522 .7491 m .57414 .7451 L .58313 .74228 L p F P
0 g
s
.601 .5 .712 r
.58196 .73825 m .58313 .74228 L .57414 .7451 L p F P
0 g
s
.751 .544 .616 r
.49226 .78744 m .49345 .78362 L p .49949 .78946 L F P
0 g
s
.757 .548 .615 r
.49226 .78744 m .49345 .78362 L .49168 .78338 L closepath p F P
0 g
s
.61 .54 .751 r
.57031 .70316 m .57207 .708 L .56285 .71006 L p F P
0 g
s
.61 .54 .751 r
.56285 .71006 m .56143 .70613 L .57031 .70316 L p F P
0 g
s
.65 .757 .928 r
.22731 .59781 m .21868 .60062 L .22164 .60323 L p F P
0 g
s
.65 .757 .928 r
.22164 .60323 m .23026 .60042 L .22731 .59781 L p F P
0 g
s
.791 .634 .687 r
.47239 .75637 m .47801 .75786 L .47503 .76316 L p F P
0 g
s
.791 .638 .691 r
.47801 .75786 m .47239 .75637 L .47565 .75099 L p F P
0 g
s
.651 .758 .928 r
.78843 .60327 m .79802 .60044 L .80006 .60304 L p F P
0 g
s
.651 .758 .928 r
.79802 .60044 m .78843 .60327 L .78637 .60067 L p F P
0 g
s
.786 .683 .751 r
.48561 .70465 m .49068 .70634 L .48546 .71226 L p F P
0 g
s
.792 .663 .72 r
.47747 .73852 m .47745 .73848 L .47743 .73851 L closepath p F P
0 g
s
.65 .757 .928 r
.36947 .59789 m .36059 .60071 L .36333 .60332 L p F P
0 g
s
.65 .757 .928 r
.36333 .60332 m .37219 .6005 L .36947 .59789 L p F P
0 g
s
.795 .667 .723 r
.47743 .73851 m .47745 .73848 L .47494 .7332 L p F P
0 g
s
.651 .758 .928 r
.64673 .60332 m .65608 .6005 L .65835 .60311 L p F P
0 g
s
.651 .758 .928 r
.65608 .6005 m .64673 .60332 L .64445 .60072 L p F P
0 g
s
.802 .665 .711 r
.47238 .73683 m .47743 .73851 L .47379 .74398 L p F P
0 g
s
.795 .667 .723 r
.47494 .7332 m .47238 .73683 L .47743 .73851 L p F P
0 g
s
.65 .757 .928 r
.51164 .59791 m .50252 .60073 L .50503 .60334 L p F P
0 g
s
.65 .757 .928 r
.50503 .60334 m .51414 .60052 L .51164 .59791 L p F P
0 g
s
.79 .678 .741 r
.47577 .72388 m .48087 .72555 L .47639 .73126 L p F P
0 g
s
.789 .67 .733 r
.48029 .71816 m .47577 .72388 L .48087 .72555 L p F P
0 g
s
.789 .67 .733 r
.4829 .71902 m .48029 .71816 L p .48087 .72555 L F P
0 g
s
.599 .493 .705 r
.57577 .7511 m .57522 .7491 L .58446 .7472 L p F P
0 g
s
.598 .491 .703 r
.58313 .74228 m .58446 .7472 L .57522 .7491 L p F P
0 g
s
.65 .757 .928 r
.23891 .5976 m .23026 .60042 L .2332 .60302 L p F P
0 g
s
.65 .757 .928 r
.2332 .60302 m .24184 .60021 L .23891 .5976 L p F P
0 g
s
.651 .758 .928 r
.80006 .60304 m .80968 .60021 L .8117 .60281 L p F P
0 g
s
.651 .758 .928 r
.80968 .60021 m .80006 .60304 L .79802 .60044 L p F P
0 g
s
.625 .457 .634 r
.56216 .78301 m .5619 .78134 L .56872 .7764 L p F P
0 g
s
.643 .469 .633 r
.56216 .78301 m .5619 .78134 L .55984 .78335 L closepath p F P
0 g
s
.607 .457 .652 r
.57106 .77499 m .57024 .77052 L .57969 .7682 L p F P
0 g
s
.61 .47 .666 r
.57854 .76265 m .57969 .7682 L .57024 .77052 L p F P
0 g
s
.629 .472 .651 r
.57024 .77052 m .57106 .77499 L .56872 .7764 L p F P
0 g
s
.792 .681 .742 r
.4829 .71902 m .48161 .71658 L .48029 .71816 L closepath p F P
0 g
s
.767 .555 .612 r
.49168 .78338 m .48668 .78248 L p .49194 .78854 L F P
0 g
s
.767 .555 .612 r
.49194 .78854 m .49226 .78744 L .49168 .78338 L p F P
0 g
s
.65 .757 .928 r
.38109 .59767 m .37219 .6005 L .37491 .6031 L p F P
0 g
s
.65 .757 .928 r
.37491 .6031 m .3838 .60028 L .38109 .59767 L p F P
0 g
s
.651 .758 .928 r
.65835 .60311 m .66772 .60028 L .66997 .60289 L p F P
0 g
s
.651 .758 .928 r
.66772 .60028 m .65835 .60311 L .65608 .6005 L p F P
0 g
s
.713 .613 .743 r
.52577 .59604 m .52575 .59604 L .51663 .60312 L p F P
0 g
s
.666 .968 .791 r
.52576 .59603 m .52575 .59604 L .51663 .60312 L p F P
0 g
s
.637 .448 .61 r
.55984 .78335 m .56216 .78301 L .56273 .78802 L p F P
0 g
s
.637 .448 .61 r
.56273 .78802 m .55538 .78909 L .55984 .78335 L p F P
0 g
s
.596 .48 .692 r
.57723 .75695 m .57577 .7511 L .58477 .74831 L p F P
0 g
s
.599 .493 .705 r
.58446 .7472 m .58477 .74831 L .57577 .7511 L p F P
0 g
s
.651 .758 .928 r
.8117 .60281 m .82134 .59999 L .82335 .60259 L p F P
0 g
s
.651 .758 .928 r
.82134 .59999 m .8117 .60281 L .80968 .60021 L p F P
0 g
s
.65 .757 .928 r
.25051 .59739 m .24184 .60021 L .24476 .60282 L p F P
0 g
s
.65 .757 .928 r
.24476 .60282 m .25343 .60001 L .25051 .59739 L p F P
0 g
s
.795 .649 .701 r
.47029 .74942 m .47565 .75099 L .47239 .75637 L p F P
0 g
s
.797 .651 .702 r
.47565 .75099 m .47029 .74942 L .47379 .74398 L p F P
0 g
s
.651 .758 .928 r
.66997 .60289 m .67937 .60006 L .6816 .60267 L p F P
0 g
s
.651 .758 .928 r
.67937 .60006 m .66997 .60289 L .66772 .60028 L p F P
0 g
s
.65 .757 .928 r
.39272 .59746 m .3838 .60028 L .3865 .60289 L p F P
0 g
s
.65 .757 .928 r
.3865 .60289 m .3954 .60007 L .39272 .59746 L p F P
0 g
s
.65 .757 .928 r
.52823 .6029 m .53739 .60008 L .53984 .60269 L p F P
0 g
s
.624 .547 .748 r
.52577 .59604 m .52823 .6029 L .53739 .60008 L p F P
0 g
s
.787 .681 .747 r
.48546 .71226 m .48161 .71658 L .47909 .71195 L p F P
0 g
s
.787 .681 .747 r
.47909 .71195 m .48027 .7106 L .48546 .71226 L p F P
0 g
s
.786 .683 .751 r
.48546 .71226 m .48027 .7106 L .48561 .70465 L p F P
0 g
s
.636 .431 .588 r
.55245 .78949 m .55538 .78909 L .55286 .79431 L p F P
0 g
s
.636 .431 .588 r
.55286 .79431 m .5528 .79432 L .55245 .78949 L p F P
0 g
s
.656 .445 .586 r
.55245 .78949 m .5528 .79432 L .54202 .79529 L p F P
0 g
s
.651 .758 .928 r
.82335 .60259 m .83301 .59976 L .83499 .60236 L p F P
0 g
s
.651 .758 .928 r
.83301 .59976 m .82335 .60259 L .82134 .59999 L p F P
0 g
s
.747 .52 .586 r
.50633 .79508 m .49864 .79421 L .49949 .78946 L p F P
0 g
s
.749 .522 .587 r
.49243 .78862 m .49949 .78946 L .49864 .79421 L p F P
0 g
s
.751 .544 .616 r
.49949 .78946 m .49243 .78862 L .49226 .78744 L p F P
0 g
s
.616 .433 .611 r
.56273 .78802 m .56216 .78301 L .572 .78111 L p F P
0 g
s
.625 .457 .634 r
.57123 .77592 m .572 .78111 L .56216 .78301 L p F P
0 g
s
.625 .457 .634 r
.56872 .7764 m .57123 .77592 L p .56216 .78301 L F P
0 g
s
.65 .757 .928 r
.26212 .59718 m .25343 .60001 L .25633 .60261 L p F P
0 g
s
.65 .757 .928 r
.25633 .60261 m .26502 .5998 L .26212 .59718 L p F P
0 g
s
.651 .758 .928 r
.6816 .60267 m .69102 .59984 L .69323 .60245 L p F P
0 g
s
.651 .758 .928 r
.69102 .59984 m .6816 .60267 L .67937 .60006 L p F P
0 g
s
.65 .757 .928 r
.40434 .59724 m .3954 .60007 L .39808 .60267 L p F P
0 g
s
.65 .757 .928 r
.39808 .60267 m .40701 .59985 L .40434 .59724 L p F P
0 g
s
.651 .757 .928 r
.53984 .60269 m .54901 .59987 L .55145 .60247 L p F P
0 g
s
.651 .757 .928 r
.54901 .59987 m .53984 .60269 L .53739 .60008 L p F P
0 g
s
.693 .452 .554 r
.52551 .79581 m .53075 .7958 L .53078 .80035 L p F P
0 g
s
.693 .452 .554 r
.53078 .80035 m .52544 .80036 L .52551 .79581 L p F P
0 g
s
.697 .455 .554 r
.51889 .79576 m .52551 .79581 L .52544 .80036 L p F P
0 g
s
.674 .436 .554 r
.53075 .7958 m .53745 .79553 L .53738 .80009 L p F P
0 g
s
.674 .436 .554 r
.53738 .80009 m .53078 .80035 L .53075 .7958 L p F P
0 g
s
.697 .455 .554 r
.52544 .80036 m .5189 .80031 L .51889 .79576 L p F P
0 g
s
.716 .471 .554 r
.51541 .79559 m .51889 .79576 L .5189 .80031 L p F P
0 g
s
.627 .471 .652 r
.57123 .77592 m .57106 .77499 L .56872 .7764 L closepath p F P
0 g
s
.651 .758 .928 r
.83499 .60236 m .84467 .59952 L .84664 .60213 L p F P
0 g
s
.651 .758 .928 r
.84467 .59952 m .83499 .60236 L .83301 .59976 L p F P
0 g
s
.65 .757 .928 r
.27373 .59697 m .26502 .5998 L .2679 .6024 L p F P
0 g
s
.65 .757 .928 r
.2679 .6024 m .27661 .59959 L .27373 .59697 L p F P
0 g
s
.651 .758 .928 r
.69323 .60245 m .70267 .59962 L .70486 .60223 L p F P
0 g
s
.651 .758 .928 r
.70267 .59962 m .69323 .60245 L .69102 .59984 L p F P
0 g
s
.65 .757 .928 r
.41597 .59703 m .40701 .59985 L .40968 .60246 L p F P
0 g
s
.65 .757 .928 r
.40968 .60246 m .41863 .59964 L .41597 .59703 L p F P
0 g
s
.624 .547 .748 r
.53492 .59747 m .52578 .59603 L .52577 .59604 L p F P
0 g
s
.624 .547 .748 r
.53739 .60008 m .53492 .59747 L p .52577 .59604 L F P
0 g
s
.651 .758 .928 r
.55145 .60247 m .56065 .59965 L .56307 .60225 L p F P
0 g
s
.651 .757 .928 r
.56065 .59965 m .55145 .60247 L .54901 .59987 L p F P
0 g
s
.011 0 0 r
.53492 .59747 m .52578 .59603 L .52576 .59603 L p F P
0 g
s
.011 0 0 r
.53245 .59485 m .53492 .59747 L p .52576 .59603 L F P
0 g
s
.011 0 0 r
.52576 .59603 m .52328 .59769 L .53245 .59485 L p F P
0 g
s
.65 .757 .928 r
.52328 .59769 m .53245 .59485 L .53245 .59485 L p F P
0 g
s
.666 .968 .791 r
.52328 .59769 m .52576 .59603 L p .51415 .60051 L F P
0 g
s
.65 .757 .928 r
.53245 .59485 m .52997 .59222 L p .52328 .59769 L F P
0 g
s
.666 .968 .791 r
.51414 .60052 m .52328 .59769 L p .51415 .60051 L F P
0 g
s
.795 .669 .725 r
.47494 .7332 m .47639 .73126 L .47357 .73036 L closepath p F P
0 g
s
.79 .678 .741 r
.47242 .72816 m .47577 .72388 L p .47639 .73126 L F P
0 g
s
.79 .678 .741 r
.47639 .73126 m .47357 .73036 L .47242 .72816 L p F P
0 g
s
.795 .686 .745 r
.48029 .71816 m .48161 .71658 L .47909 .71195 L p F P
0 g
s
.596 .48 .692 r
.58477 .74831 m .58624 .75417 L .57723 .75695 L p F P
0 g
s
.591 .467 .679 r
.57773 .75913 m .57723 .75695 L .58624 .75417 L p F P
0 g
s
.716 .471 .554 r
.5189 .80031 m .51534 .80014 L .51541 .79559 L p F P
0 g
s
.719 .474 .554 r
.50636 .79508 m .51541 .79559 L .51534 .80014 L p F P
0 g
s
.778 .581 .633 r
.48668 .78248 m .48027 .78123 L .48214 .77622 L p F P
0 g
s
.782 .587 .636 r
.47593 .77491 m .48214 .77622 L .48027 .78123 L p F P
0 g
s
.782 .599 .652 r
.48214 .77622 m .47593 .77491 L .47826 .76978 L p F P
0 g
s
.787 .606 .655 r
.47382 .76874 m .47826 .76978 L .47593 .77491 L p F P
0 g
s
.786 .618 .673 r
.4732 .76676 m .47503 .76316 L p .47826 .76978 L F P
0 g
s
.786 .618 .673 r
.47826 .76978 m .47382 .76874 L .4732 .76676 L p F P
0 g
s
.651 .758 .928 r
.84664 .60213 m .85634 .59929 L .85829 .60189 L p F P
0 g
s
.651 .758 .928 r
.85634 .59929 m .84664 .60213 L .84467 .59952 L p F P
0 g
s
.631 .425 .586 r
.55538 .78909 m .56273 .78802 L .56307 .79283 L p F P
0 g
s
.631 .425 .586 r
.56307 .79283 m .55286 .79431 L .55538 .78909 L p F P
0 g
s
.669 .432 .554 r
.53745 .79553 m .54202 .79529 L .54206 .79985 L p F P
0 g
s
.669 .432 .554 r
.54206 .79985 m .53738 .80009 L .53745 .79553 L p F P
0 g
s
.8 .665 .714 r
.46871 .74232 m .47379 .74398 L .47029 .74942 L p F P
0 g
s
.802 .665 .711 r
.47379 .74398 m .46871 .74232 L .47238 .73683 L p F P
0 g
s
.65 .757 .928 r
.28535 .59676 m .27661 .59959 L .27948 .6022 L p F P
0 g
s
.65 .757 .928 r
.27948 .6022 m .28821 .59938 L .28535 .59676 L p F P
0 g
s
.651 .758 .928 r
.70486 .60223 m .71432 .5994 L .71649 .60201 L p F P
0 g
s
.651 .758 .928 r
.71432 .5994 m .70486 .60223 L .70267 .59962 L p F P
0 g
s
.65 .757 .928 r
.42761 .59681 m .41863 .59964 L .42127 .60224 L p F P
0 g
s
.65 .757 .928 r
.42127 .60224 m .43024 .59942 L .42761 .59681 L p F P
0 g
s
.651 .758 .928 r
.56307 .60225 m .57228 .59943 L .57468 .60203 L p F P
0 g
s
.651 .758 .928 r
.57228 .59943 m .56307 .60225 L .56065 .59965 L p F P
0 g
s
.8 .687 .74 r
.47552 .71638 m .48029 .71816 L .47577 .72388 L p F P
0 g
s
.795 .686 .745 r
.47909 .71195 m .47552 .71638 L .48029 .71816 L p F P
0 g
s
.607 .458 .653 r
.57123 .77592 m .57106 .77499 L .58027 .77142 L p F P
0 g
s
.607 .457 .652 r
.57969 .7682 m .58027 .77142 L .57106 .77499 L p F P
0 g
s
.802 .672 .72 r
.47238 .73683 m .47494 .7332 L .47357 .73036 L p F P
0 g
s
.65 .757 .928 r
.1547 .59638 m .14619 .5992 L .14927 .60181 L p F P
0 g
s
.65 .757 .928 r
.14927 .60181 m .15777 .59901 L .1547 .59638 L p F P
0 g
s
.794 .623 .67 r
.4732 .76676 m .47503 .76316 L .47178 .76232 L closepath p F P
0 g
s
.791 .634 .687 r
.47071 .75937 m .47239 .75637 L p .47503 .76316 L F P
0 g
s
.791 .634 .687 r
.47503 .76316 m .47178 .76232 L .47071 .75937 L p F P
0 g
s
.767 .555 .612 r
.48668 .78248 m .48535 .78735 L .49194 .78854 L p F P
0 g
s
.777 .566 .613 r
.48027 .78123 m .48668 .78248 L .48535 .78735 L p F P
0 g
s
.651 .758 .928 r
.85829 .60189 m .86802 .59905 L .86995 .60166 L p F P
0 g
s
.651 .758 .928 r
.86802 .59905 m .85829 .60189 L .85634 .59929 L p F P
0 g
s
.767 .555 .612 r
.49243 .78862 m .49226 .78744 L .49194 .78854 L closepath p F P
0 g
s
.592 .469 .681 r
.57854 .76265 m .57773 .75913 L .58698 .75741 L p F P
0 g
s
.591 .467 .679 r
.58624 .75417 m .58698 .75741 L .57773 .75913 L p F P
0 g
s
.65 .757 .928 r
.29696 .59655 m .28821 .59938 L .29106 .60199 L p F P
0 g
s
.65 .757 .928 r
.29106 .60199 m .29981 .59917 L .29696 .59655 L p F P
0 g
s
.651 .758 .928 r
.71649 .60201 m .72597 .59918 L .72813 .60179 L p F P
0 g
s
.651 .758 .928 r
.72597 .59918 m .71649 .60201 L .71432 .5994 L p F P
0 g
s
.649 .417 .553 r
.54202 .79529 m .5528 .79432 L p .55275 .79888 L F P
0 g
s
.649 .417 .553 r
.55275 .79888 m .54206 .79985 L .54202 .79529 L p F P
0 g
s
.65 .757 .928 r
.43924 .59659 m .43024 .59942 L .43287 .60203 L p F P
0 g
s
.65 .757 .928 r
.43287 .60203 m .44186 .59921 L .43924 .59659 L p F P
0 g
s
.651 .758 .928 r
.57468 .60203 m .58392 .59921 L .5863 .60182 L p F P
0 g
s
.651 .758 .928 r
.58392 .59921 m .57468 .60203 L .57228 .59943 L p F P
0 g
s
.6 .436 .632 r
.572 .78111 m .57123 .77592 L .58067 .7736 L p F P
0 g
s
.607 .458 .653 r
.58027 .77142 m .58067 .7736 L .57123 .77592 L p F P
0 g
s
.65 .757 .928 r
.1663 .59619 m .15777 .59901 L .16083 .60162 L p F P
0 g
s
.65 .757 .928 r
.16083 .60162 m .16935 .59881 L .1663 .59619 L p F P
0 g
s
.651 .758 .928 r
.86995 .60166 m .87969 .59882 L .88161 .60142 L p F P
0 g
s
.651 .758 .928 r
.87969 .59882 m .86995 .60166 L .86802 .59905 L p F P
0 g
s
.65 .757 .928 r
.30858 .59634 m .29981 .59917 L .30264 .60178 L p F P
0 g
s
.65 .757 .928 r
.30264 .60178 m .31141 .59896 L .30858 .59634 L p F P
0 g
s
.651 .758 .928 r
.72813 .60179 m .73763 .59896 L .73977 .60156 L p F P
0 g
s
.651 .758 .928 r
.73763 .59896 m .72813 .60179 L .72597 .59918 L p F P
0 g
s
.65 .757 .928 r
.45088 .59638 m .44186 .59921 L .44447 .60181 L p F P
0 g
s
.65 .757 .928 r
.44447 .60181 m .45348 .59899 L .45088 .59638 L p F P
0 g
s
.651 .758 .928 r
.59556 .59899 m .5863 .60182 L .58392 .59921 L p F P
0 g
s
.651 .758 .928 r
.5863 .60182 m .59556 .59899 L .59792 .6016 L p F P
0 g
s
.719 .474 .554 r
.50633 .79642 m .50636 .79508 L p .51534 .80014 L F P
0 g
s
.725 .479 .554 r
.50633 .79642 m .50636 .79508 L .50633 .79508 L closepath p F P
0 g
s
.739 .49 .553 r
.50633 .79508 m .49864 .79421 L p .50627 .79963 L F P
0 g
s
.739 .49 .553 r
.50627 .79963 m .50633 .79642 L .50633 .79508 L p F P
0 g
s
.749 .522 .587 r
.49864 .79421 m .4928 .79352 L .49243 .78862 L p F P
0 g
s
.767 .536 .584 r
.49194 .78854 m .49243 .78862 L .4928 .79352 L p F P
0 g
s
.795 .649 .701 r
.46822 .75287 m .47029 .74942 L p .47239 .75637 L F P
0 g
s
.795 .649 .701 r
.47239 .75637 m .46929 .75548 L .46822 .75287 L p F P
0 g
s
.799 .639 .683 r
.47071 .75937 m .47239 .75637 L .46929 .75548 L closepath p F P
0 g
s
.651 .758 .928 r
.88161 .60142 m .89137 .59858 L .89327 .60118 L p F P
0 g
s
.651 .758 .928 r
.89137 .59858 m .88161 .60142 L .87969 .59882 L p F P
0 g
s
.767 .536 .584 r
.4928 .79352 m .49119 .79326 L .49194 .78854 L p F P
0 g
s
.774 .543 .585 r
.48535 .78735 m .49194 .78854 L .49119 .79326 L p F P
0 g
s
.65 .757 .928 r
.1779 .59599 m .16935 .59881 L .17239 .60142 L p F P
0 g
s
.65 .757 .928 r
.17239 .60142 m .18093 .59861 L .1779 .59599 L p F P
0 g
s
.651 .758 .928 r
.73977 .60156 m .7493 .59873 L .75142 .60134 L p F P
0 g
s
.651 .758 .928 r
.7493 .59873 m .73977 .60156 L .73763 .59896 L p F P
0 g
s
.65 .757 .928 r
.32021 .59613 m .31141 .59896 L .31422 .60156 L p F P
0 g
s
.65 .757 .928 r
.31422 .60156 m .32301 .59874 L .32021 .59613 L p F P
0 g
s
.651 .758 .928 r
.59792 .6016 m .6072 .59877 L .60955 .60138 L p F P
0 g
s
.651 .758 .928 r
.6072 .59877 m .59792 .6016 L .59556 .59899 L p F P
0 g
s
.65 .757 .928 r
.46253 .59616 m .45348 .59899 L .45607 .6016 L p F P
0 g
s
.65 .757 .928 r
.45607 .6016 m .46511 .59877 L .46253 .59616 L p F P
0 g
s
.588 .455 .668 r
.57969 .7682 m .57854 .76265 L .58756 .75989 L p F P
0 g
s
.592 .469 .681 r
.58698 .75741 m .58756 .75989 L .57854 .76265 L p F P
0 g
s
.786 .699 .768 r
.48084 .70285 m .48561 .70465 L .48027 .7106 L p F P
0 g
s
.808 .674 .717 r
.46757 .73508 m .47238 .73683 L .46871 .74232 L p F P
0 g
s
.802 .672 .72 r
.47138 .72956 m .46757 .73508 L .47238 .73683 L p F P
0 g
s
.802 .672 .72 r
.47357 .73036 m .47138 .72956 L p .47238 .73683 L F P
0 g
s
.651 .758 .928 r
.89327 .60118 m .90305 .59833 L .90493 .60093 L p F P
0 g
s
.651 .758 .928 r
.90305 .59833 m .89327 .60118 L .89137 .59858 L p F P
0 g
s
.805 .683 .73 r
.47357 .73036 m .47242 .72816 L .47138 .72956 L closepath p F P
0 g
s
.65 .757 .928 r
.18951 .59579 m .18093 .59861 L .18396 .60123 L p F P
0 g
s
.65 .757 .928 r
.18396 .60123 m .19252 .59842 L .18951 .59579 L p F P
0 g
s
.802 .683 .733 r
.47577 .72388 m .47242 .72816 L .4699 .72347 L p F P
0 g
s
.802 .683 .733 r
.4699 .72347 m .47092 .72213 L .47577 .72388 L p F P
0 g
s
.8 .687 .74 r
.47577 .72388 m .47092 .72213 L .47552 .71638 L p F P
0 g
s
.651 .758 .928 r
.75142 .60134 m .76096 .59851 L .76306 .60112 L p F P
0 g
s
.651 .758 .928 r
.76096 .59851 m .75142 .60134 L .7493 .59873 L p F P
0 g
s
.65 .757 .928 r
.33184 .59591 m .32301 .59874 L .32581 .60135 L p F P
0 g
s
.65 .757 .928 r
.32581 .60135 m .33462 .59853 L .33184 .59591 L p F P
0 g
s
.651 .758 .928 r
.60955 .60138 m .61885 .59855 L .62118 .60116 L p F P
0 g
s
.651 .758 .928 r
.61885 .59855 m .60955 .60138 L .6072 .59877 L p F P
0 g
s
.65 .757 .928 r
.47417 .59594 m .46511 .59877 L .46768 .60138 L p F P
0 g
s
.65 .757 .928 r
.46768 .60138 m .47674 .59856 L .47417 .59594 L p F P
0 g
s
.65 .757 .928 r
.20112 .59559 m .19252 .59842 L .19553 .60103 L p F P
0 g
s
.65 .757 .928 r
.19553 .60103 m .20411 .59821 L .20112 .59559 L p F P
0 g
s
.8 .627 .666 r
.47178 .76232 m .46952 .76164 L p .47243 .76836 L F P
0 g
s
.8 .627 .666 r
.47243 .76836 m .4732 .76676 L .47178 .76232 L p F P
0 g
s
.804 .64 .679 r
.47178 .76232 m .47071 .75937 L .46952 .76164 L closepath p F P
0 g
s
.651 .758 .928 r
.76306 .60112 m .77263 .59829 L .77471 .60089 L p F P
0 g
s
.651 .758 .928 r
.77263 .59829 m .76306 .60112 L .76096 .59851 L p F P
0 g
s
.8 .626 .666 r
.47382 .76874 m .4732 .76676 L .47243 .76836 L closepath p F P
0 g
s
.804 .655 .697 r
.46822 .75287 m .47029 .74942 L .46624 .74813 L closepath p F P
0 g
s
.8 .665 .714 r
.46571 .74696 m .46871 .74232 L p .47029 .74942 L F P
0 g
s
.8 .665 .714 r
.47029 .74942 m .46624 .74813 L .46571 .74696 L p F P
0 g
s
.65 .757 .928 r
.34347 .5957 m .33462 .59853 L .3374 .60114 L p F P
0 g
s
.65 .757 .928 r
.3374 .60114 m .34624 .59832 L .34347 .5957 L p F P
0 g
s
.719 .474 .554 r
.51534 .80014 m .50634 .79964 L .50633 .79642 L p F P
0 g
s
.738 .49 .553 r
.50634 .79964 m .50633 .79642 L .50627 .79963 L closepath p F P
0 g
s
.787 .606 .655 r
.47593 .77491 m .47547 .7748 L .47382 .76874 L p F P
0 g
s
.803 .615 .647 r
.47243 .76836 m .47382 .76874 L .47547 .7748 L p F P
0 g
s
.651 .758 .928 r
.62118 .60116 m .6305 .59833 L .63281 .60094 L p F P
0 g
s
.651 .758 .928 r
.6305 .59833 m .62118 .60116 L .61885 .59855 L p F P
0 g
s
.65 .757 .928 r
.48582 .59572 m .47674 .59856 L .47929 .60117 L p F P
0 g
s
.65 .757 .928 r
.47929 .60117 m .48837 .59834 L .48582 .59572 L p F P
0 g
s
.609 .409 .585 r
.56307 .79283 m .56273 .78802 L .57259 .78613 L p F P
0 g
s
.616 .433 .611 r
.572 .78111 m .57259 .78613 L .56273 .78802 L p F P
0 g
s
.602 .508 .719 r
.57948 .72991 m .57896 .73001 L .57946 .72985 L closepath p F P
0 g
s
.607 .519 .73 r
.57739 .7234 m .57946 .72985 L .57896 .73001 L p F P
0 g
s
.793 .691 .752 r
.47909 .71195 m .48027 .7106 L .47785 .70974 L closepath p F P
0 g
s
.786 .699 .768 r
.47657 .7076 m .48084 .70285 L p .48027 .7106 L F P
0 g
s
.786 .699 .768 r
.48027 .7106 m .47785 .70974 L .47657 .7076 L p F P
0 g
s
.806 .642 .679 r
.46952 .76164 m .47071 .75937 L .46929 .75548 L p F P
0 g
s
.65 .757 .928 r
.21273 .59539 m .20411 .59821 L .2071 .60083 L p F P
0 g
s
.65 .757 .928 r
.2071 .60083 m .21571 .59801 L .21273 .59539 L p F P
0 g
s
.651 .758 .928 r
.77471 .60089 m .7843 .59806 L .78637 .60067 L p F P
0 g
s
.651 .758 .928 r
.7843 .59806 m .77471 .60089 L .77263 .59829 L p F P
0 g
s
.65 .757 .928 r
.3551 .59548 m .34624 .59832 L .349 .60093 L p F P
0 g
s
.65 .757 .928 r
.349 .60093 m .35785 .5981 L .3551 .59548 L p F P
0 g
s
.651 .758 .928 r
.63281 .60094 m .64215 .59811 L .64445 .60072 L p F P
0 g
s
.651 .758 .928 r
.64215 .59811 m .63281 .60094 L .6305 .59833 L p F P
0 g
s
.65 .757 .928 r
.49748 .59551 m .48837 .59834 L .4909 .60095 L p F P
0 g
s
.65 .757 .928 r
.4909 .60095 m .5 .59812 L .49748 .59551 L p F P
0 g
s
.627 .399 .553 r
.55282 .79565 m .55286 .79431 L .5528 .79432 L closepath p F P
0 g
s
.649 .417 .553 r
.5528 .79432 m .55282 .79565 L .55275 .79888 L p F P
0 g
s
.626 .399 .553 r
.55286 .79431 m .56307 .79283 L p .55286 .79887 L F P
0 g
s
.626 .399 .553 r
.55286 .79887 m .55282 .79565 L .55286 .79431 L p F P
0 g
s
.576 .491 .723 r
.57948 .72991 m .57946 .72985 L .58789 .72641 L p F P
0 g
s
.581 .505 .734 r
.58628 .72145 m .58789 .72641 L .57946 .72985 L p F P
0 g
s
.581 .505 .734 r
.58128 .72181 m .58628 .72145 L p .57946 .72985 L F P
0 g
s
.581 .505 .734 r
.57946 .72985 m .57739 .7234 L .58128 .72181 L p F P
0 g
s
.577 .494 .724 r
.58136 .73613 m .57948 .72991 L .58877 .72928 L p F P
0 g
s
.576 .491 .723 r
.58789 .72641 m .58877 .72928 L .57948 .72991 L p F P
0 g
s
.585 .516 .744 r
.57739 .7234 m .577 .72225 L .58128 .72181 L closepath p F P
0 g
s
.585 .514 .741 r
.58128 .72181 m .577 .72225 L .57518 .7168 L p F P
0 g
s
.803 .694 .744 r
.47552 .71638 m .47909 .71195 L .47785 .70974 L p F P
0 g
s
.782 .587 .636 r
.47565 .77568 m .47593 .77491 L p .48027 .78123 L F P
0 g
s
.79 .592 .634 r
.47565 .77568 m .47593 .77491 L .47547 .7748 L closepath p F P
0 g
s
.808 .688 .733 r
.47138 .72956 m .47242 .72816 L .4699 .72347 L p F P
0 g
s
.739 .49 .553 r
.49864 .79421 m .49856 .79876 L .50627 .79963 L p F P
0 g
s
.746 .497 .553 r
.4928 .79352 m .49864 .79421 L .49856 .79876 L p F P
0 g
s
.65 .757 .928 r
.22435 .59519 m .21571 .59801 L .21868 .60062 L p F P
0 g
s
.65 .757 .928 r
.21868 .60062 m .22731 .59781 L .22435 .59519 L p F P
0 g
s
.651 .758 .928 r
.79597 .59783 m .78637 .60067 L .7843 .59806 L p F P
0 g
s
.651 .758 .928 r
.78637 .60067 m .79597 .59783 L .79802 .60044 L p F P
0 g
s
.585 .514 .741 r
.57518 .7168 m .58127 .71426 L p .58128 .72181 L F P
0 g
s
.586 .523 .751 r
.57518 .7168 m .57453 .71497 L .58127 .71426 L closepath p F P
0 g
s
.809 .655 .692 r
.46929 .75548 m .46822 .75287 L .46713 .75477 L closepath p F P
0 g
s
.806 .642 .679 r
.46929 .75548 m .46713 .75477 L p .46952 .76164 L F P
0 g
s
.575 .484 .714 r
.58196 .73825 m .58136 .73613 L .58984 .73276 L p F P
0 g
s
.577 .494 .724 r
.58877 .72928 m .58984 .73276 L .58136 .73613 L p F P
0 g
s
.803 .615 .647 r
.47547 .7748 m .47041 .77341 L .47243 .76836 L p F P
0 g
s
.809 .623 .65 r
.46716 .76677 m .47243 .76836 L .47041 .77341 L p F P
0 g
s
.8 .627 .666 r
.46952 .76164 m .46716 .76677 L .47243 .76836 L p F P
0 g
s
.65 .757 .928 r
.36674 .59527 m .35785 .5981 L .36059 .60071 L p F P
0 g
s
.65 .757 .928 r
.36059 .60071 m .36947 .59789 L .36674 .59527 L p F P
0 g
s
.798 .598 .63 r
.47547 .7748 m .47041 .77341 L p .47425 .77987 L F P
0 g
s
.798 .598 .63 r
.47425 .77987 m .47565 .77568 L .47547 .7748 L p F P
0 g
s
.651 .758 .928 r
.64445 .60072 m .65381 .59789 L .65608 .6005 L p F P
0 g
s
.651 .758 .928 r
.65381 .59789 m .64445 .60072 L .64215 .59811 L p F P
0 g
s
.65 .757 .928 r
.50913 .59529 m .5 .59812 L .50252 .60073 L p F P
0 g
s
.65 .757 .928 r
.50252 .60073 m .51164 .59791 L .50913 .59529 L p F P
0 g
s
.777 .566 .613 r
.48535 .78735 m .47888 .78612 L .48027 .78123 L p F P
0 g
s
.783 .572 .615 r
.47669 .78048 m .48027 .78123 L .47888 .78612 L p F P
0 g
s
.782 .587 .636 r
.48027 .78123 m .47669 .78048 L .47565 .77568 L p F P
0 g
s
.585 .521 .749 r
.58127 .71426 m .57453 .71497 L .57282 .71006 L p F P
0 g
s
.577 .487 .716 r
.58313 .74228 m .58196 .73825 L .59126 .73761 L p F P
0 g
s
.575 .484 .714 r
.58984 .73276 m .59126 .73761 L .58196 .73825 L p F P
0 g
s
.815 .688 .725 r
.46684 .72772 m .47138 .72956 L .46757 .73508 L p F P
0 g
s
.808 .688 .733 r
.4699 .72347 m .46684 .72772 L .47138 .72956 L p F P
0 g
s
.798 .597 .63 r
.47669 .78048 m .47565 .77568 L .47425 .77987 L closepath p F P
0 g
s
.593 .416 .612 r
.57259 .78613 m .572 .78111 L .58146 .7788 L p F P
0 g
s
.6 .436 .632 r
.58067 .7736 m .58146 .7788 L .572 .78111 L p F P
0 g
s
.582 .439 .652 r
.58027 .77142 m .57969 .7682 L .58872 .76545 L p F P
0 g
s
.588 .455 .668 r
.58756 .75989 m .58872 .76545 L .57969 .7682 L p F P
0 g
s
.65 .757 .928 r
.23597 .59498 m .22731 .59781 L .23026 .60042 L p F P
0 g
s
.65 .757 .928 r
.23026 .60042 m .23891 .5976 L .23597 .59498 L p F P
0 g
s
.651 .758 .928 r
.79802 .60044 m .80765 .59761 L .80968 .60021 L p F P
0 g
s
.651 .758 .928 r
.80765 .59761 m .79802 .60044 L .79597 .59783 L p F P
0 g
s
.65 .757 .928 r
.37837 .59505 m .36947 .59789 L .37219 .6005 L p F P
0 g
s
.65 .757 .928 r
.37219 .6005 m .38109 .59767 L .37837 .59505 L p F P
0 g
s
.651 .758 .928 r
.65608 .6005 m .66547 .59767 L .66772 .60028 L p F P
0 g
s
.651 .758 .928 r
.66547 .59767 m .65608 .6005 L .65381 .59789 L p F P
0 g
s
.651 .758 .928 r
.52079 .59507 m .51164 .59791 L .51414 .60052 L p F P
0 g
s
.651 .758 .928 r
.51414 .60052 m .52328 .59769 L .52079 .59507 L p F P
0 g
s
.684 .414 .508 r
.52544 .80036 m .53078 .80035 L .53042 .80457 L p F P
0 g
s
.684 .414 .508 r
.53042 .80457 m .52667 .80457 L .52544 .80036 L p F P
0 g
s
.688 .416 .506 r
.5189 .80031 m .52544 .80036 L .52667 .80457 L p F P
0 g
s
.663 .396 .506 r
.53078 .80035 m .53738 .80009 L .5389 .80423 L p F P
0 g
s
.663 .396 .506 r
.5389 .80423 m .53042 .80457 L .53078 .80035 L p F P
0 g
s
.811 .668 .706 r
.46871 .74232 m .46571 .74696 L .46318 .74164 L p F P
0 g
s
.811 .668 .706 r
.46318 .74164 m .46384 .74059 L .46871 .74232 L p F P
0 g
s
.808 .674 .717 r
.46871 .74232 m .46384 .74059 L .46757 .73508 L p F P
0 g
s
.585 .521 .749 r
.57282 .71006 m .57949 .7072 L p .58127 .71426 L F P
0 g
s
.586 .529 .758 r
.57282 .71006 m .57207 .708 L .57949 .7072 L closepath p F P
0 g
s
.814 .64 .667 r
.46448 .75998 m .46952 .76164 L .46716 .76677 L p F P
0 g
s
.806 .642 .679 r
.46713 .75477 m .46448 .75998 L .46952 .76164 L p F P
0 g
s
.688 .416 .506 r
.52667 .80457 m .51852 .80451 L .5189 .80031 L p F P
0 g
s
.709 .435 .508 r
.51534 .80014 m .5189 .80031 L .51852 .80451 L p F P
0 g
s
.577 .479 .706 r
.58313 .74228 m .59166 .73897 L p .58837 .74693 L F P
0 g
s
.577 .479 .706 r
.58837 .74693 m .58446 .7472 L .58313 .74228 L p F P
0 g
s
.577 .487 .716 r
.59126 .73761 m .59166 .73897 L .58313 .74228 L p F P
0 g
s
.81 .657 .693 r
.46713 .75477 m .46822 .75287 L .46624 .74813 L p F P
0 g
s
.774 .543 .585 r
.49119 .79326 m .48458 .79207 L .48535 .78735 L p F P
0 g
s
.776 .547 .588 r
.47888 .78612 m .48535 .78735 L .48458 .79207 L p F P
0 g
s
.651 .758 .928 r
.80968 .60021 m .81933 .59738 L .82134 .59999 L p F P
0 g
s
.651 .758 .928 r
.81933 .59738 m .80968 .60021 L .80765 .59761 L p F P
0 g
s
.65 .757 .928 r
.24759 .59477 m .23891 .5976 L .24184 .60021 L p F P
0 g
s
.65 .757 .928 r
.24184 .60021 m .25051 .59739 L .24759 .59477 L p F P
0 g
s
.801 .702 .756 r
.47101 .71452 m .47552 .71638 L .47092 .72213 L p F P
0 g
s
.803 .694 .744 r
.47557 .70879 m .47101 .71452 L .47552 .71638 L p F P
0 g
s
.803 .694 .744 r
.47785 .70974 m .47557 .70879 L p .47552 .71638 L F P
0 g
s
.644 .413 .553 r
.55286 .79887 m .55282 .79565 L .55275 .79888 L closepath p F P
0 g
s
.651 .758 .928 r
.66772 .60028 m .67713 .59745 L .67937 .60006 L p F P
0 g
s
.651 .758 .928 r
.67713 .59745 m .66772 .60028 L .66547 .59767 L p F P
0 g
s
.65 .757 .928 r
.39002 .59484 m .38109 .59767 L .3838 .60028 L p F P
0 g
s
.65 .757 .928 r
.3838 .60028 m .39272 .59746 L .39002 .59484 L p F P
0 g
s
.586 .528 .756 r
.57949 .7072 m .57207 .708 L .57031 .70316 L p F P
0 g
s
.709 .435 .508 r
.51852 .80451 m .51635 .80441 L .51534 .80014 L p F P
0 g
s
.713 .435 .503 r
.50634 .79964 m .51534 .80014 L .51635 .80441 L p F P
0 g
s
.658 .393 .508 r
.53738 .80009 m .54206 .79985 L .54175 .80408 L p F P
0 g
s
.658 .393 .508 r
.54175 .80408 m .5389 .80423 L .53738 .80009 L p F P
0 g
s
.651 .758 .928 r
.82134 .59999 m .83101 .59715 L .83301 .59976 L p F P
0 g
s
.651 .758 .928 r
.83101 .59715 m .82134 .59999 L .81933 .59738 L p F P
0 g
s
.65 .757 .928 r
.25921 .59456 m .25051 .59739 L .25343 .60001 L p F P
0 g
s
.65 .757 .928 r
.25343 .60001 m .26212 .59718 L .25921 .59456 L p F P
0 g
s
.805 .704 .754 r
.47785 .70974 m .47657 .7076 L .47557 .70879 L closepath p F P
0 g
s
.651 .758 .928 r
.67937 .60006 m .6888 .59723 L .69102 .59984 L p F P
0 g
s
.651 .758 .928 r
.6888 .59723 m .67937 .60006 L .67713 .59745 L p F P
0 g
s
.65 .757 .928 r
.40166 .59462 m .39272 .59746 L .3954 .60007 L p F P
0 g
s
.65 .757 .928 r
.3954 .60007 m .40434 .59724 L .40166 .59462 L p F P
0 g
s
.651 .757 .928 r
.53739 .60008 m .54657 .59725 L .54901 .59987 L p F P
0 g
s
.651 .757 .928 r
.54657 .59725 m .53739 .60008 L .53492 .59747 L p F P
0 g
s
.577 .48 .708 r
.58477 .74831 m .58446 .7472 L .58837 .74693 L closepath p F P
0 g
s
.746 .497 .553 r
.49856 .79876 m .49279 .79809 L .4928 .79352 L p F P
0 g
s
.766 .513 .551 r
.49119 .79326 m .4928 .79352 L .49279 .79809 L p F P
0 g
s
.819 .656 .681 r
.46232 .75304 m .46713 .75477 L .46448 .75998 L p F P
0 g
s
.81 .657 .693 r
.46522 .74776 m .46232 .75304 L .46713 .75477 L p F P
0 g
s
.81 .657 .693 r
.46624 .74813 m .46522 .74776 L p .46713 .75477 L F P
0 g
s
.571 .465 .694 r
.58624 .75417 m .58477 .74831 L .58837 .74693 L p F P
0 g
s
.586 .528 .756 r
.57031 .70316 m .57612 .70059 L p .57949 .7072 L F P
0 g
s
.651 .758 .928 r
.83301 .59976 m .8427 .59691 L .84467 .59952 L p F P
0 g
s
.651 .758 .928 r
.8427 .59691 m .83301 .59976 L .83101 .59715 L p F P
0 g
s
.65 .757 .928 r
.27084 .59435 m .26212 .59718 L .26502 .5998 L p F P
0 g
s
.65 .757 .928 r
.26502 .5998 m .27373 .59697 L .27084 .59435 L p F P
0 g
s
.637 .375 .505 r
.54175 .80408 m .54206 .79985 L .55275 .79888 L p F P
0 g
s
.783 .572 .615 r
.47888 .78612 m .47755 .78585 L .47669 .78048 L p F P
0 g
s
.8 .584 .609 r
.47425 .77987 m .47669 .78048 L .47755 .78585 L p F P
0 g
s
.651 .758 .928 r
.69102 .59984 m .70046 .59701 L .70267 .59962 L p F P
0 g
s
.651 .758 .928 r
.70046 .59701 m .69102 .59984 L .6888 .59723 L p F P
0 g
s
.65 .757 .928 r
.41331 .5944 m .40434 .59724 L .40701 .59985 L p F P
0 g
s
.65 .757 .928 r
.40701 .59985 m .41597 .59703 L .41331 .5944 L p F P
0 g
s
.583 .44 .653 r
.58067 .7736 m .58027 .77142 L .58955 .76993 L p F P
0 g
s
.582 .439 .652 r
.58872 .76545 m .58955 .76993 L .58027 .77142 L p F P
0 g
s
.651 .757 .928 r
.54901 .59987 m .55822 .59703 L .56065 .59965 L p F P
0 g
s
.651 .757 .928 r
.55822 .59703 m .54901 .59987 L .54657 .59725 L p F P
0 g
s
.813 .669 .705 r
.46624 .74813 m .46571 .74696 L .46522 .74776 L closepath p F P
0 g
s
.766 .513 .551 r
.49279 .79809 m .4911 .79781 L .49119 .79326 L p F P
0 g
s
.773 .518 .55 r
.48458 .79207 m .49119 .79326 L .4911 .79781 L p F P
0 g
s
.651 .758 .928 r
.84467 .59952 m .85439 .59668 L .85634 .59929 L p F P
0 g
s
.651 .758 .928 r
.85439 .59668 m .84467 .59952 L .8427 .59691 L p F P
0 g
s
.65 .757 .928 r
.28248 .59414 m .27373 .59697 L .27661 .59959 L p F P
0 g
s
.65 .757 .928 r
.27661 .59959 m .28535 .59676 L .28248 .59414 L p F P
0 g
s
.713 .435 .503 r
.50631 .79989 m .50634 .79964 L p .51635 .80441 L F P
0 g
s
.733 .459 .514 r
.50631 .79989 m .50627 .79963 L .50634 .79964 L closepath p F P
0 g
s
.651 .758 .928 r
.70267 .59962 m .71214 .59679 L .71432 .5994 L p F P
0 g
s
.651 .758 .928 r
.71214 .59679 m .70267 .59962 L .70046 .59701 L p F P
0 g
s
.74 .458 .502 r
.50627 .79963 m .50631 .79989 L .50587 .80379 L p F P
0 g
s
.74 .458 .502 r
.49856 .79876 m .50627 .79963 L p .50587 .80379 L F P
0 g
s
.65 .757 .928 r
.42496 .59419 m .41597 .59703 L .41863 .59964 L p F P
0 g
s
.65 .757 .928 r
.41863 .59964 m .42761 .59681 L .42496 .59419 L p F P
0 g
s
.651 .758 .928 r
.56065 .59965 m .56987 .59681 L .57228 .59943 L p F P
0 g
s
.651 .757 .928 r
.56987 .59681 m .56065 .59965 L .55822 .59703 L p F P
0 g
s
.801 .708 .762 r
.48084 .70285 m .47657 .7076 L .47403 .70359 L p F P
0 g
s
.801 .708 .762 r
.47403 .70359 m .47636 .70097 L .48084 .70285 L p F P
0 g
s
.811 .688 .728 r
.463 .73326 m .46757 .73508 L .46384 .74059 L p F P
0 g
s
.815 .688 .725 r
.46757 .73508 m .463 .73326 L .46684 .72772 L p F P
0 g
s
.649 .757 .928 r
.15162 .59376 m .14311 .59658 L .14619 .5992 L p F P
0 g
s
.649 .757 .928 r
.14619 .5992 m .1547 .59638 L .15162 .59376 L p F P
0 g
s
.809 .694 .738 r
.4699 .72347 m .47092 .72213 L .46864 .72122 L closepath p F P
0 g
s
.801 .702 .756 r
.46736 .71909 m .47101 .71452 L p .47092 .72213 L F P
0 g
s
.801 .702 .756 r
.47092 .72213 m .46864 .72122 L .46736 .71909 L p F P
0 g
s
.816 .674 .707 r
.46522 .74776 m .46571 .74696 L .46318 .74164 L p F P
0 g
s
.713 .435 .503 r
.51635 .80441 m .50733 .80389 L .50631 .79989 L p F P
0 g
s
.716 .437 .501 r
.50733 .80389 m .50587 .80379 L .50631 .79989 L closepath p F P
0 g
s
.651 .758 .928 r
.85634 .59929 m .86608 .59644 L .86802 .59905 L p F P
0 g
s
.651 .758 .928 r
.86608 .59644 m .85634 .59929 L .85439 .59668 L p F P
0 g
s
.65 .757 .928 r
.29411 .59393 m .28535 .59676 L .28821 .59938 L p F P
0 g
s
.65 .757 .928 r
.28821 .59938 m .29696 .59655 L .29411 .59393 L p F P
0 g
s
.651 .758 .928 r
.71432 .5994 m .72381 .59657 L .72597 .59918 L p F P
0 g
s
.651 .758 .928 r
.72381 .59657 m .71432 .5994 L .71214 .59679 L p F P
0 g
s
.65 .757 .928 r
.43662 .59397 m .42761 .59681 L .43024 .59942 L p F P
0 g
s
.65 .757 .928 r
.43024 .59942 m .43924 .59659 L .43662 .59397 L p F P
0 g
s
.651 .758 .928 r
.57228 .59943 m .58153 .5966 L .58392 .59921 L p F P
0 g
s
.651 .758 .928 r
.58153 .5966 m .57228 .59943 L .56987 .59681 L p F P
0 g
s
.576 .419 .632 r
.58146 .7788 m .58067 .7736 L .58973 .77086 L p F P
0 g
s
.583 .44 .653 r
.58955 .76993 m .58973 .77086 L .58067 .7736 L p F P
0 g
s
.824 .672 .694 r
.46064 .74595 m .46522 .74776 L .46232 .75304 L p F P
0 g
s
.816 .674 .707 r
.46318 .74164 m .46064 .74595 L .46522 .74776 L p F P
0 g
s
.816 .696 .732 r
.46684 .72772 m .4699 .72347 L .46864 .72122 L p F P
0 g
s
.65 .757 .928 r
.16324 .59356 m .1547 .59638 L .15777 .59901 L p F P
0 g
s
.65 .757 .928 r
.15777 .59901 m .1663 .59619 L .16324 .59356 L p F P
0 g
s
.571 .465 .694 r
.59377 .74682 m .59481 .75091 L .58624 .75417 L p F P
0 g
s
.571 .465 .694 r
.58837 .74693 m .59377 .74682 L p .58624 .75417 L F P
0 g
s
.569 .454 .682 r
.58624 .75417 m .59481 .75091 L p .59468 .75724 L F P
0 g
s
.569 .454 .682 r
.59468 .75724 m .58698 .75741 L .58624 .75417 L p F P
0 g
s
.651 .758 .928 r
.86802 .59905 m .87777 .5962 L .87969 .59882 L p F P
0 g
s
.651 .758 .928 r
.87777 .5962 m .86802 .59905 L .86608 .59644 L p F P
0 g
s
.598 .376 .55 r
.56313 .79738 m .56307 .79283 L .57294 .79095 L p F P
0 g
s
.609 .409 .585 r
.57259 .78613 m .57294 .79095 L .56307 .79283 L p F P
0 g
s
.626 .399 .553 r
.56307 .79283 m .56313 .79738 L .55286 .79887 L p F P
0 g
s
.65 .757 .928 r
.30575 .59371 m .29696 .59655 L .29981 .59917 L p F P
0 g
s
.65 .757 .928 r
.29981 .59917 m .30858 .59634 L .30575 .59371 L p F P
0 g
s
.651 .758 .928 r
.72597 .59918 m .73549 .59634 L .73763 .59896 L p F P
0 g
s
.651 .758 .928 r
.73549 .59634 m .72597 .59918 L .72381 .59657 L p F P
0 g
s
.81 .713 .758 r
.47557 .70879 m .47657 .7076 L .47403 .70359 L p F P
0 g
s
.65 .757 .928 r
.44828 .59375 m .43924 .59659 L .44186 .59921 L p F P
0 g
s
.65 .757 .928 r
.44186 .59921 m .45088 .59638 L .44828 .59375 L p F P
0 g
s
.651 .758 .928 r
.58392 .59921 m .59319 .59638 L .59556 .59899 L p F P
0 g
s
.651 .758 .928 r
.59319 .59638 m .58392 .59921 L .58153 .5966 L p F P
0 g
s
.578 .503 .734 r
.58628 .72145 m .58128 .72181 L .58579 .71992 L closepath p F P
0 g
s
.585 .514 .741 r
.58381 .71407 m .58579 .71992 L .58128 .72181 L p F P
0 g
s
.585 .514 .741 r
.58127 .71426 m .58381 .71407 L p .58128 .72181 L F P
0 g
s
.8 .584 .609 r
.47755 .78585 m .47305 .78471 L .47425 .77987 L p F P
0 g
s
.806 .591 .611 r
.46876 .77836 m .47425 .77987 L .47305 .78471 L p F P
0 g
s
.798 .598 .63 r
.47041 .77341 m .46876 .77836 L .47425 .77987 L p F P
0 g
s
.81 .612 .634 r
.46512 .77183 m .47041 .77341 L .46876 .77836 L p F P
0 g
s
.809 .623 .65 r
.47041 .77341 m .46512 .77183 L .46716 .76677 L p F P
0 g
s
.65 .757 .928 r
.17486 .59336 m .1663 .59619 L .16935 .59881 L p F P
0 g
s
.65 .757 .928 r
.16935 .59881 m .1779 .59599 L .17486 .59336 L p F P
0 g
s
.651 .758 .928 r
.87969 .59882 m .88947 .59596 L .89137 .59858 L p F P
0 g
s
.651 .758 .928 r
.88947 .59596 m .87969 .59882 L .87777 .5962 L p F P
0 g
s
.814 .711 .752 r
.47138 .70682 m .47557 .70879 L .47101 .71452 L p F P
0 g
s
.81 .713 .758 r
.47403 .70359 m .47138 .70682 L .47557 .70879 L p F P
0 g
s
.65 .757 .928 r
.31739 .5935 m .30858 .59634 L .31141 .59896 L p F P
0 g
s
.65 .757 .928 r
.31141 .59896 m .32021 .59613 L .31739 .5935 L p F P
0 g
s
.651 .758 .928 r
.73763 .59896 m .74717 .59612 L .7493 .59873 L p F P
0 g
s
.651 .758 .928 r
.74717 .59612 m .73763 .59896 L .73549 .59634 L p F P
0 g
s
.65 .757 .928 r
.45994 .59353 m .45088 .59638 L .45348 .59899 L p F P
0 g
s
.65 .757 .928 r
.45348 .59899 m .46253 .59616 L .45994 .59353 L p F P
0 g
s
.651 .758 .928 r
.60485 .59616 m .59556 .59899 L .59319 .59638 L p F P
0 g
s
.651 .758 .928 r
.59556 .59899 m .60485 .59616 L .6072 .59877 L p F P
0 g
s
.584 .391 .585 r
.57294 .79095 m .57259 .78613 L .58205 .78383 L p F P
0 g
s
.593 .416 .612 r
.58146 .7788 m .58205 .78383 L .57259 .78613 L p F P
0 g
s
.815 .631 .654 r
.46209 .76513 m .46716 .76677 L .46512 .77183 L p F P
0 g
s
.814 .64 .667 r
.46716 .76677 m .46209 .76513 L .46448 .75998 L p F P
0 g
s
.776 .547 .588 r
.48458 .79207 m .47804 .79086 L .47888 .78612 L p F P
0 g
s
.782 .553 .589 r
.47755 .78585 m .47888 .78612 L .47804 .79086 L p F P
0 g
s
.651 .758 .928 r
.89137 .59858 m .90117 .59572 L .90305 .59833 L p F P
0 g
s
.651 .758 .928 r
.90117 .59572 m .89137 .59858 L .88947 .59596 L p F P
0 g
s
.65 .757 .928 r
.18648 .59317 m .1779 .59599 L .18093 .59861 L p F P
0 g
s
.65 .757 .928 r
.18093 .59861 m .18951 .59579 L .18648 .59317 L p F P
0 g
s
.569 .455 .684 r
.58756 .75989 m .58698 .75741 L .59468 .75724 L closepath p F P
0 g
s
.634 .378 .513 r
.55285 .79912 m .55275 .79888 L .55286 .79887 L closepath p F P
0 g
s
.637 .375 .505 r
.55275 .79888 m .55285 .79912 L p .54175 .80408 L F P
0 g
s
.651 .758 .928 r
.7493 .59873 m .75885 .59589 L .76096 .59851 L p F P
0 g
s
.651 .758 .928 r
.75885 .59589 m .7493 .59873 L .74717 .59612 L p F P
0 g
s
.65 .757 .928 r
.32904 .59329 m .32021 .59613 L .32301 .59874 L p F P
0 g
s
.65 .757 .928 r
.32301 .59874 m .33184 .59591 L .32904 .59329 L p F P
0 g
s
.607 .351 .504 r
.55286 .79887 m .56313 .79738 L .56286 .80163 L p F P
0 g
s
.607 .351 .504 r
.55285 .79912 m .55286 .79887 L p .56286 .80163 L F P
0 g
s
.651 .758 .928 r
.6072 .59877 m .61651 .59594 L .61885 .59855 L p F P
0 g
s
.651 .758 .928 r
.61651 .59594 m .6072 .59877 L .60485 .59616 L p F P
0 g
s
.65 .757 .928 r
.4716 .59332 m .46253 .59616 L .46511 .59877 L p F P
0 g
s
.65 .757 .928 r
.46511 .59877 m .47417 .59594 L .4716 .59332 L p F P
0 g
s
.74 .458 .502 r
.50587 .80379 m .49945 .80305 L .49856 .79876 L p F P
0 g
s
.74 .459 .504 r
.49279 .79809 m .49856 .79876 L .49945 .80305 L p F P
0 g
s
.782 .553 .589 r
.47804 .79086 m .47802 .79086 L .47755 .78585 L p F P
0 g
s
.802 .567 .582 r
.47305 .78471 m .47755 .78585 L .47802 .79086 L p F P
0 g
s
.607 .351 .504 r
.56286 .80163 m .5555 .8027 L .55285 .79912 L p F P
0 g
s
.612 .352 .499 r
.5555 .8027 m .55255 .80309 L .55285 .79912 L closepath p F P
0 g
s
.637 .375 .505 r
.55285 .79912 m .55255 .80309 L .54175 .80408 L p F P
0 g
s
.65 .757 .928 r
.19811 .59296 m .18951 .59579 L .19252 .59842 L p F P
0 g
s
.65 .757 .928 r
.19252 .59842 m .20112 .59559 L .19811 .59296 L p F P
0 g
s
.82 .699 .73 r
.46255 .72581 m .46684 .72772 L .463 .73326 L p F P
0 g
s
.816 .696 .732 r
.46648 .72025 m .46255 .72581 L .46684 .72772 L p F P
0 g
s
.816 .696 .732 r
.46864 .72122 m .46648 .72025 L p .46684 .72772 L F P
0 g
s
.819 .649 .671 r
.45964 .75826 m .46448 .75998 L .46209 .76513 L p F P
0 g
s
.819 .656 .681 r
.46448 .75998 m .45964 .75826 L .46232 .75304 L p F P
0 g
s
.651 .758 .928 r
.76096 .59851 m .77054 .59567 L .77263 .59829 L p F P
0 g
s
.651 .758 .928 r
.77054 .59567 m .76096 .59851 L .75885 .59589 L p F P
0 g
s
.65 .757 .928 r
.34069 .59307 m .33184 .59591 L .33462 .59853 L p F P
0 g
s
.65 .757 .928 r
.33462 .59853 m .34347 .5957 L .34069 .59307 L p F P
0 g
s
.818 .678 .709 r
.46318 .74164 m .46384 .74059 L .46239 .74003 L closepath p F P
0 g
s
.811 .688 .728 r
.46065 .73677 m .463 .73326 L p .46384 .74059 L F P
0 g
s
.811 .688 .728 r
.46384 .74059 m .46239 .74003 L .46065 .73677 L p F P
0 g
s
.817 .706 .743 r
.46864 .72122 m .46736 .71909 L .46648 .72025 L closepath p F P
0 g
s
.651 .758 .928 r
.61885 .59855 m .62818 .59572 L .6305 .59833 L p F P
0 g
s
.651 .758 .928 r
.62818 .59572 m .61885 .59855 L .61651 .59594 L p F P
0 g
s
.65 .757 .928 r
.48327 .5931 m .47417 .59594 L .47674 .59856 L p F P
0 g
s
.65 .757 .928 r
.47674 .59856 m .48582 .59572 L .48327 .5931 L p F P
0 g
s
.562 .438 .668 r
.58872 .76545 m .58756 .75989 L .59468 .75724 L p F P
0 g
s
.569 .464 .695 r
.59377 .74682 m .58837 .74693 L .59332 .74501 L closepath p F P
0 g
s
.577 .479 .706 r
.59166 .73897 m .59332 .74501 L .58837 .74693 L p F P
0 g
s
.65 .757 .928 r
.20974 .59276 m .20112 .59559 L .20411 .59821 L p F P
0 g
s
.65 .757 .928 r
.20411 .59821 m .21273 .59539 L .20974 .59276 L p F P
0 g
s
.773 .518 .55 r
.4911 .79781 m .4845 .79662 L .48458 .79207 L p F P
0 g
s
.774 .52 .551 r
.47804 .79086 m .48458 .79207 L .4845 .79662 L p F P
0 g
s
.651 .758 .928 r
.77263 .59829 m .78223 .59544 L .7843 .59806 L p F P
0 g
s
.651 .758 .928 r
.78223 .59544 m .77263 .59829 L .77054 .59567 L p F P
0 g
s
.65 .757 .928 r
.35234 .59286 m .34347 .5957 L .34624 .59832 L p F P
0 g
s
.65 .757 .928 r
.34624 .59832 m .3551 .59548 L .35234 .59286 L p F P
0 g
s
.824 .68 .704 r
.46064 .74595 m .46318 .74164 L .46239 .74003 L p F P
0 g
s
.651 .758 .928 r
.6305 .59833 m .63985 .5955 L .64215 .59811 L p F P
0 g
s
.651 .758 .928 r
.63985 .5955 m .6305 .59833 L .62818 .59572 L p F P
0 g
s
.65 .757 .928 r
.49494 .59288 m .48582 .59572 L .48837 .59834 L p F P
0 g
s
.65 .757 .928 r
.48837 .59834 m .49748 .59551 L .49494 .59288 L p F P
0 g
s
.816 .71 .749 r
.47101 .71452 m .46736 .71909 L .46481 .71506 L p F P
0 g
s
.816 .71 .749 r
.46481 .71506 m .46676 .71258 L .47101 .71452 L p F P
0 g
s
.814 .711 .752 r
.47101 .71452 m .46676 .71258 L .47138 .70682 L p F P
0 g
s
.65 .757 .928 r
.22138 .59255 m .21273 .59539 L .21571 .59801 L p F P
0 g
s
.65 .757 .928 r
.21571 .59801 m .22435 .59519 L .22138 .59255 L p F P
0 g
s
.651 .758 .928 r
.7843 .59806 m .79392 .59522 L .79597 .59783 L p F P
0 g
s
.651 .758 .928 r
.79392 .59522 m .7843 .59806 L .78223 .59544 L p F P
0 g
s
.65 .757 .928 r
.36399 .59264 m .3551 .59548 L .35785 .5981 L p F P
0 g
s
.65 .757 .928 r
.35785 .5981 m .36674 .59527 L .36399 .59264 L p F P
0 g
s
.651 .758 .928 r
.64215 .59811 m .65153 .59528 L .65381 .59789 L p F P
0 g
s
.651 .758 .928 r
.65153 .59528 m .64215 .59811 L .63985 .5955 L p F P
0 g
s
.65 .757 .928 r
.50662 .59266 m .49748 .59551 L .5 .59812 L p F P
0 g
s
.65 .757 .928 r
.5 .59812 m .50913 .59529 L .50662 .59266 L p F P
0 g
s
.825 .666 .686 r
.45772 .75124 m .46232 .75304 L .45964 .75826 L p F P
0 g
s
.824 .672 .694 r
.46232 .75304 m .45772 .75124 L .46064 .74595 L p F P
0 g
s
.579 .511 .743 r
.58381 .71407 m .58127 .71426 L .58354 .71328 L closepath p F P
0 g
s
.585 .521 .749 r
.58134 .70705 m .58354 .71328 L .58127 .71426 L p F P
0 g
s
.585 .521 .749 r
.57949 .7072 m .58134 .70705 L p .58127 .71426 L F P
0 g
s
.568 .398 .612 r
.58205 .78383 m .58146 .7788 L .59052 .77607 L p F P
0 g
s
.576 .419 .632 r
.58973 .77086 m .59052 .77607 L .58146 .7788 L p F P
0 g
s
.824 .68 .704 r
.46239 .74003 m .4594 .73873 L p .46064 .74595 L F P
0 g
s
.825 .692 .717 r
.46239 .74003 m .46065 .73677 L .4594 .73873 L closepath p F P
0 g
s
.65 .757 .928 r
.23301 .59235 m .22435 .59519 L .22731 .59781 L p F P
0 g
s
.65 .757 .928 r
.22731 .59781 m .23597 .59498 L .23301 .59235 L p F P
0 g
s
.651 .758 .928 r
.80562 .59499 m .79597 .59783 L .79392 .59522 L p F P
0 g
s
.651 .758 .928 r
.79597 .59783 m .80562 .59499 L .80765 .59761 L p F P
0 g
s
.668 .356 .437 r
.52667 .80457 m .53042 .80457 L .52959 .80835 L p F P
0 g
s
.668 .356 .437 r
.52959 .80835 m .52957 .80835 L .52667 .80457 L p F P
0 g
s
.664 .329 .397 r
.51852 .80451 m .52667 .80457 L .52957 .80835 L p F P
0 g
s
.644 .333 .431 r
.52959 .80835 m .53042 .80457 L .5389 .80423 L p F P
0 g
s
.65 .757 .928 r
.37565 .59242 m .36674 .59527 L .36947 .59789 L p F P
0 g
s
.65 .757 .928 r
.36947 .59789 m .37837 .59505 L .37565 .59242 L p F P
0 g
s
.651 .758 .928 r
.65381 .59789 m .66321 .59505 L .66547 .59767 L p F P
0 g
s
.651 .758 .928 r
.66321 .59505 m .65381 .59789 L .65153 .59528 L p F P
0 g
s
.651 .757 .928 r
.51829 .59244 m .50913 .59529 L .51164 .59791 L p F P
0 g
s
.651 .757 .928 r
.51164 .59791 m .52079 .59507 L .51829 .59244 L p F P
0 g
s
.74 .459 .504 r
.49945 .80305 m .4923 .80223 L .49279 .79809 L p F P
0 g
s
.763 .48 .505 r
.4911 .79781 m .49279 .79809 L .4923 .80223 L p F P
0 g
s
.664 .329 .397 r
.51793 .80712 m .51852 .80451 L p .52957 .80835 L F P
0 g
s
.697 .385 .444 r
.51793 .80712 m .51635 .80441 L .51852 .80451 L closepath p F P
0 g
s
.699 .37 .417 r
.51635 .80441 m .51793 .80712 L .51757 .80822 L p F P
0 g
s
.699 .37 .417 r
.50733 .80389 m .51635 .80441 L p .51757 .80822 L F P
0 g
s
.65 .757 .928 r
.24465 .59214 m .23597 .59498 L .23891 .5976 L p F P
0 g
s
.65 .757 .928 r
.23891 .5976 m .24759 .59477 L .24465 .59214 L p F P
0 g
s
.651 .758 .928 r
.80765 .59761 m .81731 .59476 L .81933 .59738 L p F P
0 g
s
.651 .758 .928 r
.81731 .59476 m .80765 .59761 L .80562 .59499 L p F P
0 g
s
.65 .757 .928 r
.38731 .59221 m .37837 .59505 L .38109 .59767 L p F P
0 g
s
.65 .757 .928 r
.38109 .59767 m .39002 .59484 L .38731 .59221 L p F P
0 g
s
.651 .758 .928 r
.66547 .59767 m .67489 .59483 L .67713 .59745 L p F P
0 g
s
.651 .758 .928 r
.67489 .59483 m .66547 .59767 L .66321 .59505 L p F P
0 g
s
.822 .714 .746 r
.46648 .72025 m .46736 .71909 L .46481 .71506 L p F P
0 g
s
.65 .757 .928 r
.52997 .59222 m .52079 .59507 L .52328 .59769 L p F P
0 g
s
.824 .694 .72 r
.463 .73326 m .46065 .73677 L .4581 .7322 L p F P
0 g
s
.824 .694 .72 r
.4581 .7322 m .45865 .73136 L .463 .73326 L p F P
0 g
s
.82 .699 .73 r
.463 .73326 m .45865 .73136 L .46255 .72581 L p F P
0 g
s
.808 .719 .767 r
.47636 .70097 m .47403 .70359 L .47148 .69975 L p F P
0 g
s
.808 .719 .767 r
.47148 .69975 m .47216 .69899 L .47636 .70097 L p F P
0 g
s
.763 .48 .505 r
.4923 .80223 m .49181 .80215 L .4911 .79781 L p F P
0 g
s
.771 .483 .497 r
.4845 .79662 m .4911 .79781 L .49181 .80215 L p F P
0 g
s
.641 .339 .443 r
.54124 .80674 m .5389 .80423 L .54175 .80408 L closepath p F P
0 g
s
.644 .333 .431 r
.5389 .80423 m .54124 .80674 L p .52959 .80835 L F P
0 g
s
.651 .758 .928 r
.81933 .59738 m .82902 .59453 L .83101 .59715 L p F P
0 g
s
.651 .758 .928 r
.82902 .59453 m .81933 .59738 L .81731 .59476 L p F P
0 g
s
.828 .713 .737 r
.46246 .71824 m .46648 .72025 L .46255 .72581 L p F P
0 g
s
.822 .714 .746 r
.46481 .71506 m .46246 .71824 L .46648 .72025 L p F P
0 g
s
.65 .757 .928 r
.2563 .59193 m .24759 .59477 L .25051 .59739 L p F P
0 g
s
.65 .757 .928 r
.25051 .59739 m .25921 .59456 L .2563 .59193 L p F P
0 g
s
.559 .425 .654 r
.58872 .76545 m .59735 .76224 L p .59194 .77006 L F P
0 g
s
.559 .425 .654 r
.59194 .77006 m .58955 .76993 L .58872 .76545 L p F P
0 g
s
.562 .438 .668 r
.59631 .75731 m .59735 .76224 L .58872 .76545 L p F P
0 g
s
.562 .438 .668 r
.59468 .75724 m .59631 .75731 L p .58872 .76545 L F P
0 g
s
.806 .591 .611 r
.47305 .78471 m .46753 .7832 L .46876 .77836 L p F P
0 g
s
.811 .598 .614 r
.46342 .7768 m .46876 .77836 L .46753 .7832 L p F P
0 g
s
.81 .612 .634 r
.46876 .77836 m .46342 .7768 L .46512 .77183 L p F P
0 g
s
.651 .758 .928 r
.67713 .59745 m .68657 .59461 L .6888 .59723 L p F P
0 g
s
.651 .758 .928 r
.68657 .59461 m .67713 .59745 L .67489 .59483 L p F P
0 g
s
.65 .757 .928 r
.39898 .59199 m .39002 .59484 L .39272 .59746 L p F P
0 g
s
.65 .757 .928 r
.39272 .59746 m .40166 .59462 L .39898 .59199 L p F P
0 g
s
.651 .757 .928 r
.53492 .59747 m .54412 .59463 L .54657 .59725 L p F P
0 g
s
.651 .757 .928 r
.54166 .592 m .53245 .59485 L .53492 .59747 L p F P
0 g
s
.651 .757 .928 r
.53492 .59747 m .54412 .59463 L .54166 .592 L p F P
0 g
s
.815 .622 .642 r
.45999 .7702 m .46512 .77183 L .46342 .7768 L p F P
0 g
s
.815 .631 .654 r
.46512 .77183 m .45999 .7702 L .46209 .76513 L p F P
0 g
s
.818 .722 .759 r
.47138 .70682 m .47403 .70359 L .47148 .69975 L p F P
0 g
s
.579 .519 .752 r
.58134 .70705 m .57949 .7072 L .58113 .70647 L closepath p F P
0 g
s
.586 .528 .756 r
.57887 .70037 m .58113 .70647 L .57949 .7072 L p F P
0 g
s
.586 .528 .756 r
.57612 .70059 m .57887 .70037 L p .57949 .7072 L F P
0 g
s
.831 .682 .698 r
.45628 .74407 m .46064 .74595 L .45772 .75124 L p F P
0 g
s
.824 .68 .704 r
.4594 .73873 m .45628 .74407 L .46064 .74595 L p F P
0 g
s
.802 .567 .582 r
.47802 .79086 m .47235 .78941 L .47305 .78471 L p F P
0 g
s
.807 .573 .584 r
.46753 .7832 m .47305 .78471 L .47235 .78941 L p F P
0 g
s
.604 .287 .406 r
.54175 .80408 m .55255 .80309 L .55174 .80687 L p F P
0 g
s
.604 .287 .406 r
.54124 .80674 m .54175 .80408 L p .55174 .80687 L F P
0 g
s
.651 .758 .928 r
.83101 .59715 m .84072 .59429 L .8427 .59691 L p F P
0 g
s
.651 .758 .928 r
.84072 .59429 m .83101 .59715 L .82902 .59453 L p F P
0 g
s
.65 .757 .928 r
.26795 .59172 m .25921 .59456 L .26212 .59718 L p F P
0 g
s
.65 .757 .928 r
.26212 .59718 m .27084 .59435 L .26795 .59172 L p F P
0 g
s
.651 .758 .928 r
.6888 .59723 m .69826 .59439 L .70046 .59701 L p F P
0 g
s
.651 .758 .928 r
.69826 .59439 m .6888 .59723 L .68657 .59461 L p F P
0 g
s
.65 .757 .928 r
.41064 .59177 m .40166 .59462 L .40434 .59724 L p F P
0 g
s
.65 .757 .928 r
.40434 .59724 m .41331 .5944 L .41064 .59177 L p F P
0 g
s
.651 .757 .928 r
.54657 .59725 m .55579 .59441 L .55822 .59703 L p F P
0 g
s
.651 .757 .928 r
.55579 .59441 m .54657 .59725 L .54412 .59463 L p F P
0 g
s
.579 .527 .761 r
.57887 .70037 m .57612 .70059 L .57854 .69947 L closepath p F P
0 g
s
.554 .482 .728 r
.58789 .72641 m .59582 .72242 L p .5963 .72962 L F P
0 g
s
.554 .482 .728 r
.5963 .72962 m .58877 .72928 L .58789 .72641 L p F P
0 g
s
.554 .49 .739 r
.59563 .72184 m .59582 .72242 L .58789 .72641 L p F P
0 g
s
.554 .49 .739 r
.58789 .72641 m .58628 .72145 L .59563 .72184 L p F P
0 g
s
.549 .486 .737 r
.59364 .71582 m .59563 .72184 L .58628 .72145 L p F P
0 g
s
.549 .486 .737 r
.58628 .72145 m .58579 .71992 L .59364 .71582 L p F P
0 g
s
.553 .497 .747 r
.59315 .71444 m .59364 .71582 L .58579 .71992 L p F P
0 g
s
.553 .497 .747 r
.58579 .71992 m .58381 .71407 L .59315 .71444 L p F P
0 g
s
.82 .642 .661 r
.4572 .76342 m .46209 .76513 L .45999 .7702 L p F P
0 g
s
.819 .649 .671 r
.46209 .76513 m .4572 .76342 L .45964 .75826 L p F P
0 g
s
.699 .37 .417 r
.51757 .80822 m .50995 .80773 L .50733 .80389 L p F P
0 g
s
.699 .37 .417 r
.50587 .80379 m .50733 .80389 L .50995 .80773 L p F P
0 g
s
.554 .483 .73 r
.58984 .73276 m .58877 .72928 L .5963 .72962 L closepath p F P
0 g
s
.571 .355 .548 r
.57302 .79551 m .57294 .79095 L .58242 .78865 L p F P
0 g
s
.584 .391 .585 r
.58205 .78383 m .58242 .78865 L .57294 .79095 L p F P
0 g
s
.598 .376 .55 r
.57294 .79095 m .57302 .79551 L .56313 .79738 L p F P
0 g
s
.651 .758 .928 r
.8427 .59691 m .85243 .59406 L .85439 .59668 L p F P
0 g
s
.651 .758 .928 r
.85243 .59406 m .8427 .59691 L .84072 .59429 L p F P
0 g
s
.581 .329 .499 r
.56286 .80163 m .56313 .79738 L .57302 .79551 L p F P
0 g
s
.554 .474 .72 r
.58984 .73276 m .5963 .72962 L p .5942 .73776 L F P
0 g
s
.554 .474 .72 r
.5942 .73776 m .59126 .73761 L .58984 .73276 L p F P
0 g
s
.65 .757 .928 r
.2796 .59151 m .27084 .59435 L .27373 .59697 L p F P
0 g
s
.65 .757 .928 r
.27373 .59697 m .28248 .59414 L .2796 .59151 L p F P
0 g
s
.651 .758 .928 r
.70046 .59701 m .70995 .59417 L .71214 .59679 L p F P
0 g
s
.651 .758 .928 r
.70995 .59417 m .70046 .59701 L .69826 .59439 L p F P
0 g
s
.65 .757 .928 r
.42231 .59156 m .41331 .5944 L .41597 .59703 L p F P
0 g
s
.65 .757 .928 r
.41597 .59703 m .42496 .59419 L .42231 .59156 L p F P
0 g
s
.651 .757 .928 r
.55822 .59703 m .56746 .59419 L .56987 .59681 L p F P
0 g
s
.651 .757 .928 r
.56746 .59419 m .55822 .59703 L .55579 .59441 L p F P
0 g
s
.699 .37 .417 r
.50995 .80773 m .5048 .8074 L .50587 .80379 L p F P
0 g
s
.728 .399 .424 r
.49945 .80305 m .50587 .80379 L .5048 .8074 L p F P
0 g
s
.774 .52 .551 r
.47801 .7922 m .47804 .79086 L p .4845 .79662 L F P
0 g
s
.782 .527 .55 r
.47801 .7922 m .47804 .79086 L .47802 .79086 L closepath p F P
0 g
s
.795 .538 .549 r
.47802 .79086 m .47235 .78941 L p .47793 .79542 L F P
0 g
s
.795 .538 .549 r
.47793 .79542 m .47801 .7922 L .47802 .79086 L p F P
0 g
s
.548 .493 .746 r
.59128 .70906 m .59315 .71444 L .58381 .71407 L p F P
0 g
s
.548 .493 .746 r
.58381 .71407 m .58354 .71328 L .59128 .70906 L p F P
0 g
s
.82 .724 .758 r
.46748 .70477 m .47138 .70682 L .46676 .71258 L p F P
0 g
s
.818 .722 .759 r
.47148 .69975 m .46748 .70477 L .47138 .70682 L p F P
0 g
s
.552 .504 .756 r
.59067 .70739 m .59128 .70906 L .58354 .71328 L p F P
0 g
s
.552 .504 .756 r
.58354 .71328 m .58134 .70705 L .59067 .70739 L p F P
0 g
s
.829 .697 .719 r
.4594 .73873 m .46065 .73677 L .4581 .7322 L p F P
0 g
s
.649 .757 .928 r
.14853 .59112 m .14001 .59395 L .14311 .59658 L p F P
0 g
s
.649 .757 .928 r
.14311 .59658 m .15162 .59376 L .14853 .59112 L p F P
0 g
s
.651 .758 .928 r
.85439 .59668 m .86414 .59382 L .86608 .59644 L p F P
0 g
s
.651 .758 .928 r
.86414 .59382 m .85439 .59668 L .85243 .59406 L p F P
0 g
s
.554 .476 .722 r
.59166 .73897 m .59126 .73761 L .5942 .73776 L closepath p F P
0 g
s
.65 .757 .928 r
.29125 .59129 m .28248 .59414 L .28535 .59676 L p F P
0 g
s
.65 .757 .928 r
.28535 .59676 m .29411 .59393 L .29125 .59129 L p F P
0 g
s
.651 .758 .928 r
.71214 .59679 m .72164 .59394 L .72381 .59657 L p F P
0 g
s
.651 .758 .928 r
.72164 .59394 m .71214 .59679 L .70995 .59417 L p F P
0 g
s
.65 .757 .928 r
.43399 .59134 m .42496 .59419 L .42761 .59681 L p F P
0 g
s
.65 .757 .928 r
.42761 .59681 m .43662 .59397 L .43399 .59134 L p F P
0 g
s
.651 .758 .928 r
.56987 .59681 m .57913 .59397 L .58153 .5966 L p F P
0 g
s
.651 .758 .928 r
.57913 .59397 m .56987 .59681 L .56746 .59419 L p F P
0 g
s
.548 .461 .709 r
.59332 .74501 m .59166 .73897 L .5942 .73776 L p F P
0 g
s
.65 .757 .928 r
.16017 .59092 m .15162 .59376 L .1547 .59638 L p F P
0 g
s
.65 .757 .928 r
.1547 .59638 m .16324 .59356 L .16017 .59092 L p F P
0 g
s
.825 .661 .679 r
.455 .75647 m .45964 .75826 L .4572 .76342 L p F P
0 g
s
.825 .666 .686 r
.45964 .75826 m .455 .75647 L .45772 .75124 L p F P
0 g
s
.651 .758 .928 r
.86608 .59644 m .87585 .59359 L .87777 .5962 L p F P
0 g
s
.651 .758 .928 r
.87585 .59359 m .86608 .59644 L .86414 .59382 L p F P
0 g
s
.547 .5 .755 r
.58876 .70212 m .59067 .70739 L .58134 .70705 L p F P
0 g
s
.547 .5 .755 r
.58134 .70705 m .58113 .70647 L .58876 .70212 L p F P
0 g
s
.65 .757 .928 r
.30291 .59108 m .29411 .59393 L .29696 .59655 L p F P
0 g
s
.65 .757 .928 r
.29696 .59655 m .30575 .59371 L .30291 .59108 L p F P
0 g
s
.651 .758 .928 r
.72381 .59657 m .73334 .59372 L .73549 .59634 L p F P
0 g
s
.651 .758 .928 r
.73334 .59372 m .72381 .59657 L .72164 .59394 L p F P
0 g
s
.65 .757 .928 r
.44566 .59112 m .43662 .59397 L .43924 .59659 L p F P
0 g
s
.65 .757 .928 r
.43924 .59659 m .44828 .59375 L .44566 .59112 L p F P
0 g
s
.651 .758 .928 r
.58153 .5966 m .59081 .59375 L .59319 .59638 L p F P
0 g
s
.651 .758 .928 r
.59081 .59375 m .58153 .5966 L .57913 .59397 L p F P
0 g
s
.551 .511 .765 r
.5882 .70067 m .58876 .70212 L .58113 .70647 L p F P
0 g
s
.551 .511 .765 r
.58113 .70647 m .57887 .70037 L .5882 .70067 L p F P
0 g
s
.823 .714 .745 r
.4585 .72381 m .46255 .72581 L .45865 .73136 L p F P
0 g
s
.828 .713 .737 r
.46255 .72581 m .4585 .72381 L .46246 .71824 L p F P
0 g
s
.837 .697 .709 r
.45528 .73677 m .4594 .73873 L .45628 .74407 L p F P
0 g
s
.829 .697 .719 r
.4581 .7322 m .45528 .73677 L .4594 .73873 L p F P
0 g
s
.559 .425 .655 r
.58973 .77086 m .58955 .76993 L .59194 .77006 L closepath p F P
0 g
s
.65 .757 .928 r
.17181 .59073 m .16324 .59356 L .1663 .59619 L p F P
0 g
s
.65 .757 .928 r
.1663 .59619 m .17486 .59336 L .17181 .59073 L p F P
0 g
s
.651 .758 .928 r
.87777 .5962 m .88757 .59334 L .88947 .59596 L p F P
0 g
s
.651 .758 .928 r
.88757 .59334 m .87777 .5962 L .87585 .59359 L p F P
0 g
s
.65 .757 .928 r
.31457 .59087 m .30575 .59371 L .30858 .59634 L p F P
0 g
s
.65 .757 .928 r
.30858 .59634 m .31739 .5935 L .31457 .59087 L p F P
0 g
s
.651 .758 .928 r
.73549 .59634 m .74503 .5935 L .74717 .59612 L p F P
0 g
s
.651 .758 .928 r
.74503 .5935 m .73549 .59634 L .73334 .59372 L p F P
0 g
s
.774 .52 .551 r
.4845 .79662 m .47799 .79543 L .47801 .7922 L p F P
0 g
s
.794 .537 .549 r
.47799 .79543 m .47801 .7922 L .47793 .79542 L closepath p F P
0 g
s
.65 .757 .928 r
.45734 .5909 m .44828 .59375 L .45088 .59638 L p F P
0 g
s
.65 .757 .928 r
.45088 .59638 m .45994 .59353 L .45734 .5909 L p F P
0 g
s
.651 .758 .928 r
.59319 .59638 m .60249 .59353 L .60485 .59616 L p F P
0 g
s
.651 .758 .928 r
.60249 .59353 m .59319 .59638 L .59081 .59375 L p F P
0 g
s
.557 .37 .584 r
.58242 .78865 m .58205 .78383 L .59112 .7811 L p F P
0 g
s
.568 .398 .612 r
.59052 .77607 m .59112 .7811 L .58205 .78383 L p F P
0 g
s
.546 .449 .696 r
.59332 .74501 m .6014 .7412 L p .60175 .74773 L F P
0 g
s
.546 .449 .696 r
.60175 .74773 m .59377 .74682 L .59332 .74501 L p F P
0 g
s
.548 .461 .709 r
.60063 .73846 m .6014 .7412 L .59332 .74501 L p F P
0 g
s
.548 .461 .709 r
.5942 .73776 m .60063 .73846 L p .59332 .74501 L F P
0 g
s
.549 .401 .632 r
.59052 .77607 m .58973 .77086 L .59194 .77006 L p F P
0 g
s
.651 .758 .928 r
.88947 .59596 m .89928 .5931 L .90117 .59572 L p F P
0 g
s
.651 .758 .928 r
.89928 .5931 m .88947 .59596 L .88757 .59334 L p F P
0 g
s
.65 .757 .928 r
.18345 .59053 m .17486 .59336 L .1779 .59599 L p F P
0 g
s
.65 .757 .928 r
.1779 .59599 m .18648 .59317 L .18345 .59053 L p F P
0 g
s
.584 .276 .413 r
.55255 .80309 m .5555 .8027 L .56212 .8055 L p F P
0 g
s
.584 .276 .413 r
.56212 .8055 m .55174 .80687 L .55255 .80309 L p F P
0 g
s
.771 .483 .497 r
.49181 .80215 m .48527 .80095 L .4845 .79662 L p F P
0 g
s
.771 .481 .495 r
.47799 .79543 m .4845 .79662 L .48527 .80095 L p F P
0 g
s
.824 .721 .752 r
.46676 .71258 m .46481 .71506 L .46225 .71123 L p F P
0 g
s
.824 .721 .752 r
.46225 .71123 m .46278 .71055 L .46676 .71258 L p F P
0 g
s
.82 .724 .758 r
.46676 .71258 m .46278 .71055 L .46748 .70477 L p F P
0 g
s
.728 .399 .424 r
.5048 .8074 m .50159 .80703 L .49945 .80305 L p F P
0 g
s
.727 .385 .401 r
.4923 .80223 m .49945 .80305 L .50159 .80703 L p F P
0 g
s
.651 .758 .928 r
.74717 .59612 m .75674 .59327 L .75885 .59589 L p F P
0 g
s
.651 .758 .928 r
.75674 .59327 m .74717 .59612 L .74503 .5935 L p F P
0 g
s
.65 .757 .928 r
.32623 .59065 m .31739 .5935 L .32021 .59613 L p F P
0 g
s
.65 .757 .928 r
.32021 .59613 m .32904 .59329 L .32623 .59065 L p F P
0 g
s
.651 .758 .928 r
.61417 .59331 m .60485 .59616 L .60249 .59353 L p F P
0 g
s
.651 .758 .928 r
.60485 .59616 m .61417 .59331 L .61651 .59594 L p F P
0 g
s
.65 .757 .928 r
.46903 .59068 m .45994 .59353 L .46253 .59616 L p F P
0 g
s
.65 .757 .928 r
.46253 .59616 m .4716 .59332 L .46903 .59068 L p F P
0 g
s
.546 .451 .698 r
.59481 .75091 m .59377 .74682 L .60175 .74773 L closepath p F P
0 g
s
.547 .508 .764 r
.58605 .69498 m .5882 .70067 L .57887 .70037 L p F P
0 g
s
.547 .508 .764 r
.57887 .70037 m .57854 .69947 L .58605 .69498 L p F P
0 g
s
.829 .679 .697 r
.45333 .74937 m .45772 .75124 L .455 .75647 L p F P
0 g
s
.831 .682 .698 r
.45772 .75124 m .45333 .74937 L .45628 .74407 L p F P
0 g
s
.65 .757 .928 r
.1951 .59033 m .18648 .59317 L .18951 .59579 L p F P
0 g
s
.65 .757 .928 r
.18951 .59579 m .19811 .59296 L .1951 .59033 L p F P
0 g
s
.651 .758 .928 r
.75885 .59589 m .76844 .59305 L .77054 .59567 L p F P
0 g
s
.651 .758 .928 r
.76844 .59305 m .75885 .59589 L .75674 .59327 L p F P
0 g
s
.65 .757 .928 r
.3379 .59044 m .32904 .59329 L .33184 .59591 L p F P
0 g
s
.65 .757 .928 r
.33184 .59591 m .34069 .59307 L .3379 .59044 L p F P
0 g
s
.651 .758 .928 r
.61651 .59594 m .62586 .59309 L .62818 .59572 L p F P
0 g
s
.651 .758 .928 r
.62586 .59309 m .61651 .59594 L .61417 .59331 L p F P
0 g
s
.65 .757 .928 r
.48071 .59046 m .4716 .59332 L .47417 .59594 L p F P
0 g
s
.65 .757 .928 r
.47417 .59594 m .48327 .5931 L .48071 .59046 L p F P
0 g
s
.83 .723 .747 r
.46246 .71824 m .46481 .71506 L .46225 .71123 L p F P
0 g
s
.65 .757 .928 r
.20675 .59012 m .19811 .59296 L .20112 .59559 L p F P
0 g
s
.65 .757 .928 r
.20112 .59559 m .20974 .59276 L .20675 .59012 L p F P
0 g
s
.581 .284 .429 r
.5555 .8027 m .56286 .80163 L .56216 .80549 L p F P
0 g
s
.581 .284 .429 r
.56216 .80549 m .56212 .8055 L .5555 .8027 L p F P
0 g
s
.651 .758 .928 r
.77054 .59567 m .78015 .59282 L .78223 .59544 L p F P
0 g
s
.651 .758 .928 r
.78015 .59282 m .77054 .59567 L .76844 .59305 L p F P
0 g
s
.664 .329 .397 r
.52957 .80835 m .51902 .80824 L .51793 .80712 L p F P
0 g
s
.666 .329 .393 r
.51902 .80824 m .51757 .80822 L .51793 .80712 L closepath p F P
0 g
s
.811 .598 .614 r
.46753 .7832 m .46214 .78166 L .46342 .7768 L p F P
0 g
s
.817 .605 .616 r
.45936 .77553 m .46342 .7768 L .46214 .78166 L p F P
0 g
s
.815 .622 .642 r
.45883 .77358 m .45999 .7702 L p .46342 .7768 L F P
0 g
s
.815 .622 .642 r
.46342 .7768 m .45936 .77553 L .45883 .77358 L p F P
0 g
s
.65 .757 .928 r
.34957 .59022 m .34069 .59307 L .34347 .5957 L p F P
0 g
s
.65 .757 .928 r
.34347 .5957 m .35234 .59286 L .34957 .59022 L p F P
0 g
s
.651 .758 .928 r
.62818 .59572 m .63755 .59287 L .63985 .5955 L p F P
0 g
s
.651 .758 .928 r
.63755 .59287 m .62818 .59572 L .62586 .59309 L p F P
0 g
s
.65 .757 .928 r
.4924 .59024 m .48327 .5931 L .48582 .59572 L p F P
0 g
s
.65 .757 .928 r
.48582 .59572 m .49494 .59288 L .4924 .59024 L p F P
0 g
s
.54 .438 .687 r
.59618 .75667 m .59481 .75091 L .60175 .74773 L p F P
0 g
s
.569 .454 .682 r
.59481 .75091 m .59618 .75667 L .59468 .75724 L p F P
0 g
s
.807 .573 .584 r
.47235 .78941 m .46681 .78792 L .46753 .7832 L p F P
0 g
s
.811 .579 .586 r
.46214 .78166 m .46753 .7832 L .46681 .78792 L p F P
0 g
s
.824 .629 .638 r
.45883 .77358 m .45999 .7702 L .45767 .7694 L closepath p F P
0 g
s
.82 .642 .661 r
.45635 .76553 m .4572 .76342 L p .45999 .7702 L F P
0 g
s
.82 .642 .661 r
.45999 .7702 m .45767 .7694 L .45635 .76553 L p F P
0 g
s
.65 .757 .928 r
.2184 .58992 m .20974 .59276 L .21273 .59539 L p F P
0 g
s
.65 .757 .928 r
.21273 .59539 m .22138 .59255 L .2184 .58992 L p F P
0 g
s
.559 .436 .668 r
.59631 .75731 m .59468 .75724 L .59618 .75667 L closepath p F P
0 g
s
.832 .705 .724 r
.4581 .7322 m .45865 .73136 L .4572 .73067 L closepath p F P
0 g
s
.823 .714 .745 r
.45554 .72806 m .4585 .72381 L p .45865 .73136 L F P
0 g
s
.823 .714 .745 r
.45865 .73136 m .4572 .73067 L .45554 .72806 L p F P
0 g
s
.651 .758 .928 r
.78223 .59544 m .79186 .59259 L .79392 .59522 L p F P
0 g
s
.651 .758 .928 r
.79186 .59259 m .78223 .59544 L .78015 .59282 L p F P
0 g
s
.65 .757 .928 r
.36124 .59 m .35234 .59286 L .3551 .59548 L p F P
0 g
s
.65 .757 .928 r
.3551 .59548 m .36399 .59264 L .36124 .59 L p F P
0 g
s
.815 .732 .773 r
.47148 .69975 m .47216 .69899 L .47019 .69795 L closepath p F P
0 g
s
.651 .758 .928 r
.63985 .5955 m .64924 .59265 L .65153 .59528 L p F P
0 g
s
.651 .758 .928 r
.64924 .59265 m .63985 .5955 L .63755 .59287 L p F P
0 g
s
.65 .757 .928 r
.50409 .59002 m .49494 .59288 L .49748 .59551 L p F P
0 g
s
.65 .757 .928 r
.49748 .59551 m .50662 .59266 L .50409 .59002 L p F P
0 g
s
.544 .461 .712 r
.60063 .73846 m .5942 .73776 L .59969 .73509 L closepath p F P
0 g
s
.554 .474 .72 r
.59812 .72979 m .59969 .73509 L .5942 .73776 L p F P
0 g
s
.554 .474 .72 r
.5963 .72962 m .59812 .72979 L p .5942 .73776 L F P
0 g
s
.828 .734 .761 r
.46748 .70477 m .47148 .69975 L .47019 .69795 L p F P
0 g
s
.549 .401 .632 r
.59194 .77006 m .59893 .77124 L p .59052 .77607 L F P
0 g
s
.548 .403 .636 r
.59893 .77124 m .59194 .77006 L .59836 .76767 L closepath p F P
0 g
s
.559 .425 .654 r
.59735 .76224 m .59836 .76767 L .59194 .77006 L p F P
0 g
s
.838 .706 .718 r
.45528 .73677 m .4581 .7322 L .4572 .73067 L p F P
0 g
s
.795 .538 .549 r
.47235 .78941 m .47226 .79396 L .47793 .79542 L p F P
0 g
s
.808 .548 .546 r
.46681 .78792 m .47235 .78941 L .47226 .79396 L p F P
0 g
s
.835 .725 .743 r
.45868 .71616 m .46246 .71824 L .4585 .72381 L p F P
0 g
s
.83 .723 .747 r
.46225 .71123 m .45868 .71616 L .46246 .71824 L p F P
0 g
s
.65 .757 .928 r
.23005 .58971 m .22138 .59255 L .22435 .59519 L p F P
0 g
s
.65 .757 .928 r
.22435 .59519 m .23301 .59235 L .23005 .58971 L p F P
0 g
s
.651 .758 .928 r
.79392 .59522 m .80357 .59236 L .80562 .59499 L p F P
0 g
s
.651 .758 .928 r
.80357 .59236 m .79392 .59522 L .79186 .59259 L p F P
0 g
s
.604 .287 .406 r
.55174 .80687 m .54293 .80771 L .54124 .80674 L p F P
0 g
s
.608 .281 .391 r
.54293 .80771 m .54094 .80787 L .54124 .80674 L closepath p F P
0 g
s
.644 .333 .431 r
.54124 .80674 m .54094 .80787 L .52959 .80835 L p F P
0 g
s
.837 .692 .703 r
.45214 .74212 m .45628 .74407 L .45333 .74937 L p F P
0 g
s
.837 .697 .709 r
.45628 .74407 m .45214 .74212 L .45528 .73677 L p F P
0 g
s
.65 .757 .928 r
.37292 .58979 m .36399 .59264 L .36674 .59527 L p F P
0 g
s
.65 .757 .928 r
.36674 .59527 m .37565 .59242 L .37292 .58979 L p F P
0 g
s
.651 .758 .928 r
.65153 .59528 m .66094 .59243 L .66321 .59505 L p F P
0 g
s
.651 .758 .928 r
.66094 .59243 m .65153 .59528 L .64924 .59265 L p F P
0 g
s
.65 .757 .928 r
.51579 .58981 m .50662 .59266 L .50913 .59529 L p F P
0 g
s
.65 .757 .928 r
.50913 .59529 m .51829 .59244 L .51579 .58981 L p F P
0 g
s
.727 .385 .401 r
.49211 .80293 m .4923 .80223 L p .50159 .80703 L F P
0 g
s
.756 .438 .448 r
.49211 .80293 m .49181 .80215 L .4923 .80223 L closepath p F P
0 g
s
.83 .648 .657 r
.45635 .76553 m .4572 .76342 L .45537 .76273 L closepath p F P
0 g
s
.825 .661 .679 r
.45384 .75898 m .455 .75647 L p .4572 .76342 L F P
0 g
s
.825 .661 .679 r
.4572 .76342 m .45537 .76273 L .45384 .75898 L p F P
0 g
s
.762 .424 .414 r
.49181 .80215 m .49211 .80293 L .49106 .80573 L p F P
0 g
s
.762 .424 .414 r
.48527 .80095 m .49181 .80215 L p .49106 .80573 L F P
0 g
s
.65 .757 .928 r
.24171 .5895 m .23301 .59235 L .23597 .59498 L p F P
0 g
s
.65 .757 .928 r
.23597 .59498 m .24465 .59214 L .24171 .5895 L p F P
0 g
s
.651 .758 .928 r
.81529 .59213 m .80562 .59499 L .80357 .59236 L p F P
0 g
s
.651 .758 .928 r
.80562 .59499 m .81529 .59213 L .81731 .59476 L p F P
0 g
s
.65 .757 .928 r
.3846 .58957 m .37565 .59242 L .37837 .59505 L p F P
0 g
s
.65 .757 .928 r
.37837 .59505 m .38731 .59221 L .3846 .58957 L p F P
0 g
s
.651 .758 .928 r
.66321 .59505 m .67264 .59221 L .67489 .59483 L p F P
0 g
s
.651 .758 .928 r
.67264 .59221 m .66321 .59505 L .66094 .59243 L p F P
0 g
s
.65 .757 .928 r
.52749 .58959 m .51829 .59244 L .52079 .59507 L p F P
0 g
s
.65 .757 .928 r
.52079 .59507 m .52997 .59222 L .52749 .58959 L p F P
0 g
s
.551 .303 .493 r
.57276 .79975 m .57302 .79551 L .58251 .79322 L p F P
0 g
s
.571 .355 .548 r
.58242 .78865 m .58251 .79322 L .57302 .79551 L p F P
0 g
s
.581 .329 .499 r
.57302 .79551 m .57276 .79975 L .56286 .80163 L p F P
0 g
s
.536 .42 .668 r
.59618 .75667 m .60433 .75294 L p .60449 .75907 L F P
0 g
s
.536 .42 .668 r
.60449 .75907 m .59631 .75731 L .59618 .75667 L p F P
0 g
s
.54 .438 .687 r
.60316 .748 m .60433 .75294 L .59618 .75667 L p F P
0 g
s
.54 .438 .687 r
.60175 .74773 m .60316 .748 L p .59618 .75667 L F P
0 g
s
.54 .378 .611 r
.59112 .7811 m .59052 .77607 L .5992 .77292 L p F P
0 g
s
.549 .401 .632 r
.59893 .77124 m .5992 .77292 L .59052 .77607 L p F P
0 g
s
.651 .758 .928 r
.81731 .59476 m .82701 .5919 L .82902 .59453 L p F P
0 g
s
.651 .758 .928 r
.82701 .5919 m .81731 .59476 L .81529 .59213 L p F P
0 g
s
.65 .757 .928 r
.25337 .58929 m .24465 .59214 L .24759 .59477 L p F P
0 g
s
.65 .757 .928 r
.24759 .59477 m .2563 .59193 L .25337 .58929 L p F P
0 g
s
.771 .481 .495 r
.47796 .79567 m .47799 .79543 L p .48527 .80095 L F P
0 g
s
.792 .508 .506 r
.47796 .79567 m .47793 .79542 L .47799 .79543 L closepath p F P
0 g
s
.651 .758 .928 r
.67489 .59483 m .68434 .59198 L .68657 .59461 L p F P
0 g
s
.651 .758 .928 r
.68434 .59198 m .67489 .59483 L .67264 .59221 L p F P
0 g
s
.802 .51 .493 r
.47793 .79542 m .47796 .79567 L .47735 .79948 L p F P
0 g
s
.802 .51 .493 r
.47226 .79396 m .47793 .79542 L p .47735 .79948 L F P
0 g
s
.65 .757 .928 r
.39628 .58935 m .38731 .59221 L .39002 .59484 L p F P
0 g
s
.65 .757 .928 r
.39002 .59484 m .39898 .59199 L .39628 .58935 L p F P
0 g
s
.645 .29 .356 r
.52958 .80837 m .52957 .80835 L .52959 .80835 L closepath p F P
0 g
s
.616 .209 .248 r
.52957 .80835 m .52958 .80837 L .5278 .81128 L p F P
0 g
s
.616 .209 .248 r
.51902 .80824 m .52957 .80835 L p .5278 .81128 L F P
0 g
s
.582 .184 .254 r
.52959 .80835 m .54094 .80787 L .53928 .81089 L p F P
0 g
s
.582 .184 .254 r
.52958 .80837 m .52959 .80835 L p .53928 .81089 L F P
0 g
s
.651 .757 .928 r
.53919 .58936 m .52997 .59222 L .53245 .59485 L p F P
0 g
s
.651 .757 .928 r
.53245 .59485 m .54166 .592 L .53919 .58936 L p F P
0 g
s
.582 .184 .254 r
.53928 .81089 m .53673 .811 L .52958 .80837 L p F P
0 g
s
.581 .171 .229 r
.53673 .811 m .5278 .81128 L .52958 .80837 L closepath p F P
0 g
s
.535 .421 .669 r
.59735 .76224 m .59631 .75731 L .60449 .75907 L closepath p F P
0 g
s
.838 .706 .718 r
.4572 .73067 m .45468 .72935 L p .45528 .73677 L F P
0 g
s
.837 .716 .731 r
.4572 .73067 m .45554 .72806 L .45468 .72935 L closepath p F P
0 g
s
.82 .741 .777 r
.46385 .70262 m .46748 .70477 L .46278 .71055 L p F P
0 g
s
.828 .734 .761 r
.46841 .69688 m .46385 .70262 L .46748 .70477 L p F P
0 g
s
.828 .734 .761 r
.47019 .69795 m .46841 .69688 L p .46748 .70477 L F P
0 g
s
.616 .209 .248 r
.5278 .81128 m .52485 .81124 L .51902 .80824 L p F P
0 g
s
.616 .205 .24 r
.51757 .80822 m .51902 .80824 L .52485 .81124 L p F P
0 g
s
.771 .481 .495 r
.48527 .80095 m .47872 .79974 L .47796 .79567 L p F P
0 g
s
.776 .484 .493 r
.47872 .79974 m .47735 .79948 L .47796 .79567 L closepath p F P
0 g
s
.836 .668 .675 r
.45384 .75898 m .455 .75647 L .45231 .75535 L closepath p F P
0 g
s
.829 .679 .697 r
.4513 .75328 m .45333 .74937 L p .455 .75647 L F P
0 g
s
.829 .679 .697 r
.455 .75647 m .45231 .75535 L .4513 .75328 L p F P
0 g
s
.832 .633 .634 r
.45767 .7694 m .45523 .76846 L p .45832 .77516 L F P
0 g
s
.832 .633 .634 r
.45832 .77516 m .45883 .77358 L .45767 .7694 L p F P
0 g
s
.834 .648 .651 r
.45767 .7694 m .45635 .76553 L .45523 .76846 L closepath p F P
0 g
s
.616 .205 .24 r
.52485 .81124 m .5157 .81109 L .51757 .80822 L p F P
0 g
s
.655 .248 .261 r
.50995 .80773 m .51757 .80822 L .5157 .81109 L p F P
0 g
s
.651 .758 .928 r
.82902 .59453 m .83873 .59167 L .84072 .59429 L p F P
0 g
s
.651 .758 .928 r
.83873 .59167 m .82902 .59453 L .82701 .5919 L p F P
0 g
s
.65 .757 .928 r
.26504 .58908 m .2563 .59193 L .25921 .59456 L p F P
0 g
s
.65 .757 .928 r
.25921 .59456 m .26795 .59172 L .26504 .58908 L p F P
0 g
s
.727 .385 .401 r
.50159 .80703 m .49405 .8061 L .49211 .80293 L p F P
0 g
s
.727 .386 .4 r
.49405 .8061 m .49106 .80573 L .49211 .80293 L closepath p F P
0 g
s
.651 .758 .928 r
.68657 .59461 m .69604 .59176 L .69826 .59439 L p F P
0 g
s
.651 .758 .928 r
.69604 .59176 m .68657 .59461 L .68434 .59198 L p F P
0 g
s
.65 .757 .928 r
.40796 .58913 m .39898 .59199 L .40166 .59462 L p F P
0 g
s
.65 .757 .928 r
.40166 .59462 m .41064 .59177 L .40796 .58913 L p F P
0 g
s
.651 .757 .928 r
.54412 .59463 m .55334 .59178 L .55579 .59441 L p F P
0 g
s
.651 .757 .928 r
.55089 .58914 m .54166 .592 L .54412 .59463 L p F P
0 g
s
.651 .757 .928 r
.54412 .59463 m .55334 .59178 L .55089 .58914 L p F P
0 g
s
.837 .651 .652 r
.45523 .76846 m .45635 .76553 L .45537 .76273 L p F P
0 g
s
.552 .257 .421 r
.56216 .80549 m .56286 .80163 L .57276 .79975 L p F P
0 g
s
.541 .332 .545 r
.58251 .79322 m .58242 .78865 L .5915 .78593 L p F P
0 g
s
.557 .37 .584 r
.59112 .7811 m .5915 .78593 L .58242 .78865 L p F P
0 g
s
.837 .651 .652 r
.45537 .76273 m .45269 .7616 L p .45523 .76846 L F P
0 g
s
.839 .666 .668 r
.45537 .76273 m .45384 .75898 L .45269 .7616 L closepath p F P
0 g
s
.651 .758 .928 r
.84072 .59429 m .85046 .59143 L .85243 .59406 L p F P
0 g
s
.651 .758 .928 r
.85046 .59143 m .84072 .59429 L .83873 .59167 L p F P
0 g
s
.83 .63 .633 r
.45936 .77553 m .45883 .77358 L .45832 .77516 L closepath p F P
0 g
s
.65 .757 .928 r
.27671 .58887 m .26795 .59172 L .27084 .59435 L p F P
0 g
s
.65 .757 .928 r
.27084 .59435 m .2796 .59151 L .27671 .58887 L p F P
0 g
s
.651 .758 .928 r
.69826 .59439 m .70775 .59154 L .70995 .59417 L p F P
0 g
s
.651 .758 .928 r
.70775 .59154 m .69826 .59439 L .69604 .59176 L p F P
0 g
s
.65 .757 .928 r
.41965 .58892 m .41064 .59177 L .41331 .5944 L p F P
0 g
s
.65 .757 .928 r
.41331 .5944 m .42231 .59156 L .41965 .58892 L p F P
0 g
s
.651 .757 .928 r
.55579 .59441 m .56503 .59156 L .56746 .59419 L p F P
0 g
s
.651 .757 .928 r
.56503 .59156 m .55579 .59441 L .55334 .59178 L p F P
0 g
s
.844 .708 .713 r
.45138 .73474 m .45528 .73677 L .45214 .74212 L p F P
0 g
s
.838 .706 .718 r
.45468 .72935 m .45138 .73474 L .45528 .73677 L p F P
0 g
s
.838 .723 .737 r
.4585 .72381 m .45554 .72806 L .45297 .72425 L p F P
0 g
s
.838 .723 .737 r
.45297 .72425 m .45469 .72174 L .4585 .72381 L p F P
0 g
s
.835 .725 .743 r
.4585 .72381 m .45469 .72174 L .45868 .71616 L p F P
0 g
s
.649 .757 .928 r
.14544 .58847 m .1369 .59131 L .14001 .59395 L p F P
0 g
s
.649 .757 .928 r
.14001 .59395 m .14853 .59112 L .14544 .58847 L p F P
0 g
s
.817 .605 .616 r
.46214 .78166 m .46048 .78115 L .45936 .77553 L p F P
0 g
s
.834 .616 .607 r
.45832 .77516 m .45936 .77553 L .46048 .78115 L p F P
0 g
s
.549 .149 .236 r
.53928 .81089 m .54094 .80787 L .54293 .80771 L p F P
0 g
s
.651 .758 .928 r
.85243 .59406 m .86219 .5912 L .86414 .59382 L p F P
0 g
s
.651 .758 .928 r
.86219 .5912 m .85243 .59406 L .85046 .59143 L p F P
0 g
s
.65 .757 .928 r
.28838 .58865 m .2796 .59151 L .28248 .59414 L p F P
0 g
s
.65 .757 .928 r
.28248 .59414 m .29125 .59129 L .28838 .58865 L p F P
0 g
s
.651 .758 .928 r
.70995 .59417 m .71946 .59131 L .72164 .59394 L p F P
0 g
s
.651 .758 .928 r
.71946 .59131 m .70995 .59417 L .70775 .59154 L p F P
0 g
s
.65 .757 .928 r
.43134 .5887 m .42231 .59156 L .42496 .59419 L p F P
0 g
s
.65 .757 .928 r
.42496 .59419 m .43399 .59134 L .43134 .5887 L p F P
0 g
s
.651 .758 .928 r
.56746 .59419 m .57673 .59134 L .57913 .59397 L p F P
0 g
s
.651 .757 .928 r
.57673 .59134 m .56746 .59419 L .56503 .59156 L p F P
0 g
s
.655 .248 .261 r
.5157 .81109 m .51467 .81103 L .50995 .80773 L p F P
0 g
s
.605 .133 .108 r
.5048 .8074 m .50995 .80773 L .51467 .81103 L p F P
0 g
s
.557 .18 .281 r
.5505 .80965 m .54293 .80771 L .55174 .80687 L closepath p F P
0 g
s
.549 .149 .236 r
.54293 .80771 m .5505 .80965 L p .53928 .81089 L F P
0 g
s
.65 .757 .928 r
.15709 .58828 m .14853 .59112 L .15162 .59376 L p F P
0 g
s
.65 .757 .928 r
.15162 .59376 m .16017 .59092 L .15709 .58828 L p F P
0 g
s
.651 .758 .928 r
.86414 .59382 m .87392 .59096 L .87585 .59359 L p F P
0 g
s
.651 .758 .928 r
.87392 .59096 m .86414 .59382 L .86219 .5912 L p F P
0 g
s
.831 .734 .757 r
.46225 .71123 m .46278 .71055 L .46105 .70956 L closepath p F P
0 g
s
.82 .741 .777 r
.45968 .70775 m .46385 .70262 L p .46278 .71055 L F P
0 g
s
.82 .741 .777 r
.46278 .71055 m .46105 .70956 L .45968 .70775 L p F P
0 g
s
.842 .685 .688 r
.45333 .74937 m .4513 .75328 L .44875 .7482 L p F P
0 g
s
.842 .685 .688 r
.44875 .7482 m .44914 .74744 L .45333 .74937 L p F P
0 g
s
.837 .692 .703 r
.45333 .74937 m .44914 .74744 L .45214 .74212 L p F P
0 g
s
.842 .67 .669 r
.45269 .7616 m .45384 .75898 L .45231 .75535 L p F P
0 g
s
.65 .757 .928 r
.30006 .58844 m .29125 .59129 L .29411 .59393 L p F P
0 g
s
.65 .757 .928 r
.29411 .59393 m .30291 .59108 L .30006 .58844 L p F P
0 g
s
.651 .758 .928 r
.72164 .59394 m .73118 .59109 L .73334 .59372 L p F P
0 g
s
.651 .758 .928 r
.73118 .59109 m .72164 .59394 L .71946 .59131 L p F P
0 g
s
.65 .757 .928 r
.44304 .58848 m .43399 .59134 L .43662 .59397 L p F P
0 g
s
.65 .757 .928 r
.43662 .59397 m .44566 .59112 L .44304 .58848 L p F P
0 g
s
.651 .758 .928 r
.57913 .59397 m .58842 .59112 L .59081 .59375 L p F P
0 g
s
.651 .758 .928 r
.58842 .59112 m .57913 .59397 L .57673 .59134 L p F P
0 g
s
.84 .735 .748 r
.45868 .71616 m .46225 .71123 L .46105 .70956 L p F P
0 g
s
.528 .404 .655 r
.59836 .76767 m .59735 .76224 L .60449 .75907 L p F P
0 g
s
.811 .579 .586 r
.46681 .78792 m .46136 .78639 L .46214 .78166 L p F P
0 g
s
.819 .587 .587 r
.46048 .78115 m .46214 .78166 L .46136 .78639 L p F P
0 g
s
.834 .616 .607 r
.46048 .78115 m .45721 .77998 L .45832 .77516 L p F P
0 g
s
.842 .625 .608 r
.45372 .77338 m .45832 .77516 L .45721 .77998 L p F P
0 g
s
.832 .633 .634 r
.45523 .76846 m .45372 .77338 L .45832 .77516 L p F P
0 g
s
.65 .757 .928 r
.16875 .58808 m .16017 .59092 L .16324 .59356 L p F P
0 g
s
.65 .757 .928 r
.16324 .59356 m .17181 .59073 L .16875 .58808 L p F P
0 g
s
.651 .758 .928 r
.87585 .59359 m .88565 .59072 L .88757 .59334 L p F P
0 g
s
.651 .758 .928 r
.88565 .59072 m .87585 .59359 L .87392 .59096 L p F P
0 g
s
.762 .424 .414 r
.49106 .80573 m .48714 .80499 L .48527 .80095 L p F P
0 g
s
.762 .415 .396 r
.47872 .79974 m .48527 .80095 L .48714 .80499 L p F P
0 g
s
.65 .757 .928 r
.31173 .58822 m .30291 .59108 L .30575 .59371 L p F P
0 g
s
.65 .757 .928 r
.30575 .59371 m .31457 .59087 L .31173 .58822 L p F P
0 g
s
.651 .758 .928 r
.73334 .59372 m .74289 .59086 L .74503 .5935 L p F P
0 g
s
.651 .758 .928 r
.74289 .59086 m .73334 .59372 L .73118 .59109 L p F P
0 g
s
.65 .757 .928 r
.45474 .58826 m .44566 .59112 L .44828 .59375 L p F P
0 g
s
.65 .757 .928 r
.44828 .59375 m .45734 .5909 L .45474 .58826 L p F P
0 g
s
.651 .758 .928 r
.59081 .59375 m .60012 .5909 L .60249 .59353 L p F P
0 g
s
.651 .758 .928 r
.60012 .5909 m .59081 .59375 L .58842 .59112 L p F P
0 g
s
.605 .133 .108 r
.50373 .80919 m .5048 .8074 L p .51467 .81103 L F P
0 g
s
.7 .312 .31 r
.50373 .80919 m .50159 .80703 L .5048 .8074 L closepath p F P
0 g
s
.808 .548 .546 r
.47226 .79396 m .4667 .79247 L .46681 .78792 L p F P
0 g
s
.811 .552 .547 r
.46136 .78639 m .46681 .78792 L .4667 .79247 L p F P
0 g
s
.545 .469 .721 r
.59812 .72979 m .5963 .72962 L .59784 .72884 L closepath p F P
0 g
s
.554 .482 .728 r
.59582 .72242 m .59784 .72884 L .5963 .72962 L p F P
0 g
s
.846 .647 .632 r
.45083 .76661 m .45523 .76846 L .45372 .77338 L p F P
0 g
s
.837 .651 .652 r
.45269 .7616 m .45083 .76661 L .45523 .76846 L p F P
0 g
s
.651 .758 .928 r
.88757 .59334 m .89739 .59047 L .89928 .5931 L p F P
0 g
s
.651 .758 .928 r
.89739 .59047 m .88757 .59334 L .88565 .59072 L p F P
0 g
s
.65 .757 .928 r
.18041 .58788 m .17181 .59073 L .17486 .59336 L p F P
0 g
s
.65 .757 .928 r
.17486 .59336 m .18345 .59053 L .18041 .58788 L p F P
0 g
s
.843 .726 .734 r
.45468 .72935 m .45554 .72806 L .45297 .72425 L p F P
0 g
s
.651 .758 .928 r
.74503 .5935 m .75461 .59064 L .75674 .59327 L p F P
0 g
s
.651 .758 .928 r
.75461 .59064 m .74503 .5935 L .74289 .59086 L p F P
0 g
s
.65 .757 .928 r
.32342 .58801 m .31457 .59087 L .31739 .5935 L p F P
0 g
s
.65 .757 .928 r
.31739 .5935 m .32623 .59065 L .32342 .58801 L p F P
0 g
s
.651 .758 .928 r
.60249 .59353 m .61182 .59068 L .61417 .59331 L p F P
0 g
s
.651 .758 .928 r
.61182 .59068 m .60249 .59353 L .60012 .5909 L p F P
0 g
s
.65 .757 .928 r
.46644 .58804 m .45734 .5909 L .45994 .59353 L p F P
0 g
s
.65 .757 .928 r
.45994 .59353 m .46903 .59068 L .46644 .58804 L p F P
0 g
s
.842 .67 .669 r
.45231 .75535 m .45065 .7546 L p .45269 .7616 L F P
0 g
s
.842 .683 .685 r
.45231 .75535 m .4513 .75328 L .45065 .7546 L closepath p F P
0 g
s
.65 .757 .928 r
.19207 .58768 m .18345 .59053 L .18648 .59317 L p F P
0 g
s
.65 .757 .928 r
.18648 .59317 m .1951 .59033 L .19207 .58768 L p F P
0 g
s
.85 .723 .723 r
.45101 .72724 m .45468 .72935 L .45138 .73474 L p F P
0 g
s
.843 .726 .734 r
.45297 .72425 m .45101 .72724 L .45468 .72935 L p F P
0 g
s
.819 .587 .587 r
.46136 .78639 m .46108 .7863 L .46048 .78115 L p F P
0 g
s
.838 .6 .579 r
.45721 .77998 m .46048 .78115 L .46108 .7863 L p F P
0 g
s
.651 .758 .928 r
.75674 .59327 m .76634 .59041 L .76844 .59305 L p F P
0 g
s
.651 .758 .928 r
.76634 .59041 m .75674 .59327 L .75461 .59064 L p F P
0 g
s
.65 .757 .928 r
.3351 .58779 m .32623 .59065 L .32904 .59329 L p F P
0 g
s
.65 .757 .928 r
.32904 .59329 m .3379 .59044 L .3351 .58779 L p F P
0 g
s
.683 .248 .211 r
.50159 .80703 m .50373 .80919 L .50272 .81012 L p F P
0 g
s
.683 .248 .211 r
.49405 .8061 m .50159 .80703 L p .50272 .81012 L F P
0 g
s
.651 .758 .928 r
.62353 .59046 m .61417 .59331 L .61182 .59068 L p F P
0 g
s
.651 .758 .928 r
.61417 .59331 m .62353 .59046 L .62586 .59309 L p F P
0 g
s
.65 .757 .928 r
.47814 .58782 m .46903 .59068 L .4716 .59332 L p F P
0 g
s
.65 .757 .928 r
.4716 .59332 m .48071 .59046 L .47814 .58782 L p F P
0 g
s
.527 .348 .582 r
.5915 .78593 m .59112 .7811 L .5998 .77796 L p F P
0 g
s
.54 .378 .611 r
.5992 .77292 m .5998 .77796 L .59112 .7811 L p F P
0 g
s
.839 .753 .768 r
.46509 .69463 m .46841 .69688 L .46385 .70262 L p F P
0 g
s
.851 .667 .652 r
.44849 .75969 m .45269 .7616 L .45083 .76661 L p F P
0 g
s
.842 .67 .669 r
.45065 .7546 m .44849 .75969 L .45269 .7616 L p F P
0 g
s
.802 .51 .493 r
.47735 .79948 m .47291 .79833 L .47226 .79396 L p F P
0 g
s
.807 .511 .488 r
.4667 .79247 m .47226 .79396 L .47291 .79833 L p F P
0 g
s
.65 .757 .928 r
.20374 .58747 m .1951 .59033 L .19811 .59296 L p F P
0 g
s
.65 .757 .928 r
.19811 .59296 m .20675 .59012 L .20374 .58747 L p F P
0 g
s
.842 .707 .715 r
.44821 .74011 m .45214 .74212 L .44914 .74744 L p F P
0 g
s
.844 .708 .713 r
.45214 .74212 m .44821 .74011 L .45138 .73474 L p F P
0 g
s
.465 .041 .149 r
.55174 .80687 m .56212 .8055 L p .5606 .80855 L F P
0 g
s
.465 .041 .149 r
.5505 .80965 m .55174 .80687 L p .5606 .80855 L F P
0 g
s
.651 .758 .928 r
.76844 .59305 m .77806 .59018 L .78015 .59282 L p F P
0 g
s
.651 .758 .928 r
.77806 .59018 m .76844 .59305 L .76634 .59041 L p F P
0 g
s
.65 .757 .928 r
.34679 .58758 m .3379 .59044 L .34069 .59307 L p F P
0 g
s
.65 .757 .928 r
.34069 .59307 m .34957 .59022 L .34679 .58758 L p F P
0 g
s
.651 .758 .928 r
.62586 .59309 m .63523 .59024 L .63755 .59287 L p F P
0 g
s
.651 .758 .928 r
.63523 .59024 m .62586 .59309 L .62353 .59046 L p F P
0 g
s
.65 .757 .928 r
.48985 .5876 m .48071 .59046 L .48327 .5931 L p F P
0 g
s
.65 .757 .928 r
.48327 .5931 m .4924 .59024 L .48985 .5876 L p F P
0 g
s
.842 .738 .749 r
.45516 .71399 m .45868 .71616 L .45469 .72174 L p F P
0 g
s
.84 .735 .748 r
.45918 .7084 m .45516 .71399 L .45868 .71616 L p F P
0 g
s
.84 .735 .748 r
.46105 .70956 m .45918 .7084 L p .45868 .71616 L F P
0 g
s
.846 .689 .687 r
.45065 .7546 m .4513 .75328 L .44875 .7482 L p F P
0 g
s
.837 .743 .76 r
.46105 .70956 m .45968 .70775 L .45918 .7084 L closepath p F P
0 g
s
.65 .757 .928 r
.21541 .58727 m .20675 .59012 L .20974 .59276 L p F P
0 g
s
.65 .757 .928 r
.20974 .59276 m .2184 .58992 L .21541 .58727 L p F P
0 g
s
.651 .758 .928 r
.78015 .59282 m .78979 .58996 L .79186 .59259 L p F P
0 g
s
.651 .758 .928 r
.78979 .58996 m .78015 .59282 L .77806 .59018 L p F P
0 g
s
.65 .757 .928 r
.35848 .58736 m .34957 .59022 L .35234 .59286 L p F P
0 g
s
.65 .757 .928 r
.35234 .59286 m .36124 .59 L .35848 .58736 L p F P
0 g
s
.651 .758 .928 r
.63755 .59287 m .64695 .59001 L .64924 .59265 L p F P
0 g
s
.651 .758 .928 r
.64695 .59001 m .63755 .59287 L .63523 .59024 L p F P
0 g
s
.65 .757 .928 r
.50156 .58738 m .4924 .59024 L .49494 .59288 L p F P
0 g
s
.65 .757 .928 r
.49494 .59288 m .50409 .59002 L .50156 .58738 L p F P
0 g
s
.521 .465 .735 r
.59784 .72884 m .59582 .72242 L .59656 .72197 L p F P
0 g
s
.528 .481 .747 r
.59582 .72242 m .59563 .72184 L .59656 .72197 L closepath p F P
0 g
s
.529 .479 .745 r
.59656 .72197 m .59563 .72184 L .59364 .71582 L p F P
0 g
s
.521 .455 .722 r
.59784 .72884 m .60528 .72428 L p .60597 .73141 L F P
0 g
s
.521 .455 .722 r
.60597 .73141 m .59812 .72979 L .59784 .72884 L p F P
0 g
s
.521 .465 .735 r
.60506 .72361 m .60528 .72428 L .59784 .72884 L p F P
0 g
s
.521 .465 .735 r
.59656 .72197 m .60506 .72361 L p .59784 .72884 L F P
0 g
s
.521 .456 .724 r
.59969 .73509 m .59812 .72979 L .60597 .73141 L closepath p F P
0 g
s
.523 .385 .635 r
.59836 .76767 m .60659 .76401 L p .60107 .77211 L F P
0 g
s
.523 .385 .635 r
.60107 .77211 m .59893 .77124 L .59836 .76767 L p F P
0 g
s
.528 .404 .655 r
.60574 .75949 m .60659 .76401 L .59836 .76767 L p F P
0 g
s
.528 .404 .655 r
.60449 .75907 m .60574 .75949 L p .59836 .76767 L F P
0 g
s
.529 .479 .745 r
.59364 .71582 m .59533 .71473 L p .59656 .72197 L F P
0 g
s
.527 .488 .756 r
.59364 .71582 m .59315 .71444 L .59533 .71473 L closepath p F P
0 g
s
.65 .757 .928 r
.22708 .58706 m .2184 .58992 L .22138 .59255 L p F P
0 g
s
.65 .757 .928 r
.22138 .59255 m .23005 .58971 L .22708 .58706 L p F P
0 g
s
.651 .758 .928 r
.79186 .59259 m .80153 .58973 L .80357 .59236 L p F P
0 g
s
.651 .758 .928 r
.80153 .58973 m .79186 .59259 L .78979 .58996 L p F P
0 g
s
.65 .757 .928 r
.37018 .58714 m .36124 .59 L .36399 .59264 L p F P
0 g
s
.65 .757 .928 r
.36399 .59264 m .37292 .58979 L .37018 .58714 L p F P
0 g
s
.528 .486 .754 r
.59533 .71473 m .59315 .71444 L .59128 .70906 L p F P
0 g
s
.651 .758 .928 r
.64924 .59265 m .65866 .58979 L .66094 .59243 L p F P
0 g
s
.651 .758 .928 r
.65866 .58979 m .64924 .59265 L .64695 .59001 L p F P
0 g
s
.65 .757 .928 r
.51328 .58716 m .50409 .59002 L .50662 .59266 L p F P
0 g
s
.65 .757 .928 r
.50662 .59266 m .51579 .58981 L .51328 .58716 L p F P
0 g
s
.856 .685 .67 r
.44666 .75262 m .45065 .7546 L .44849 .75969 L p F P
0 g
s
.846 .689 .687 r
.44875 .7482 m .44666 .75262 L .45065 .7546 L p F P
0 g
s
.521 .447 .713 r
.59969 .73509 m .60597 .73141 L p .60468 .73935 L F P
0 g
s
.521 .447 .713 r
.60468 .73935 m .60063 .73846 L .59969 .73509 L p F P
0 g
s
.65 .757 .928 r
.23876 .58685 m .23005 .58971 L .23301 .59235 L p F P
0 g
s
.65 .757 .928 r
.23301 .59235 m .24171 .5895 L .23876 .58685 L p F P
0 g
s
.651 .758 .928 r
.80357 .59236 m .81326 .5895 L .81529 .59213 L p F P
0 g
s
.651 .758 .928 r
.81326 .5895 m .80357 .59236 L .80153 .58973 L p F P
0 g
s
.838 .753 .77 r
.46385 .70262 m .45968 .70775 L .45709 .7046 L p F P
0 g
s
.838 .753 .77 r
.45709 .7046 m .4605 .70038 L .46385 .70262 L p F P
0 g
s
.839 .753 .768 r
.46385 .70262 m .4605 .70038 L .46509 .69463 L p F P
0 g
s
.65 .757 .928 r
.38187 .58692 m .37292 .58979 L .37565 .59242 L p F P
0 g
s
.65 .757 .928 r
.37565 .59242 m .3846 .58957 L .38187 .58692 L p F P
0 g
s
.651 .758 .928 r
.66094 .59243 m .67038 .58957 L .67264 .59221 L p F P
0 g
s
.651 .758 .928 r
.67038 .58957 m .66094 .59243 L .65866 .58979 L p F P
0 g
s
.651 .757 .928 r
.52499 .58694 m .51579 .58981 L .51829 .59244 L p F P
0 g
s
.651 .757 .928 r
.51829 .59244 m .52749 .58959 L .52499 .58694 L p F P
0 g
s
.528 .486 .754 r
.59128 .70906 m .59325 .70773 L p .59533 .71473 L F P
0 g
s
.526 .495 .765 r
.59128 .70906 m .59067 .70739 L .59325 .70773 L closepath p F P
0 g
s
.515 .221 .406 r
.57205 .80359 m .57276 .79975 L .58226 .79746 L p F P
0 g
s
.552 .257 .421 r
.57276 .79975 m .57205 .80359 L .56216 .80549 L p F P
0 g
s
.551 .303 .493 r
.58251 .79322 m .58226 .79746 L .57276 .79975 L p F P
0 g
s
.762 .415 .396 r
.48714 .80499 m .48074 .80374 L .47872 .79974 L p F P
0 g
s
.761 .415 .399 r
.47735 .79948 m .47872 .79974 L .48074 .80374 L p F P
0 g
s
.518 .469 .741 r
.60506 .72361 m .59656 .72197 L .60315 .71773 L closepath p F P
0 g
s
.529 .479 .745 r
.60257 .71605 m .60315 .71773 L .59656 .72197 L p F P
0 g
s
.529 .479 .745 r
.59533 .71473 m .60257 .71605 L p .59656 .72197 L F P
0 g
s
.516 .275 .487 r
.58226 .79746 m .58251 .79322 L .5916 .7905 L p F P
0 g
s
.541 .332 .545 r
.5915 .78593 m .5916 .7905 L .58251 .79322 L p F P
0 g
s
.521 .448 .715 r
.6014 .7412 m .60063 .73846 L .60468 .73935 L closepath p F P
0 g
s
.526 .493 .763 r
.59325 .70773 m .59067 .70739 L .58876 .70212 L p F P
0 g
s
.651 .758 .928 r
.825 .58926 m .81529 .59213 L .81326 .5895 L p F P
0 g
s
.651 .758 .928 r
.81529 .59213 m .825 .58926 L .82701 .5919 L p F P
0 g
s
.65 .757 .928 r
.25044 .58664 m .24171 .5895 L .24465 .59214 L p F P
0 g
s
.65 .757 .928 r
.24465 .59214 m .25337 .58929 L .25044 .58664 L p F P
0 g
s
.683 .248 .211 r
.50272 .81012 m .49832 .8095 L .49405 .8061 L p F P
0 g
s
.617 .121 .051 r
.49106 .80573 m .49405 .8061 L .49832 .8095 L p F P
0 g
s
.651 .758 .928 r
.67264 .59221 m .6821 .58935 L .68434 .59198 L p F P
0 g
s
.651 .758 .928 r
.6821 .58935 m .67264 .59221 L .67038 .58957 L p F P
0 g
s
.65 .757 .928 r
.39357 .58671 m .3846 .58957 L .38731 .59221 L p F P
0 g
s
.65 .757 .928 r
.38731 .59221 m .39628 .58935 L .39357 .58671 L p F P
0 g
s
.651 .757 .928 r
.53671 .58672 m .52749 .58959 L .52997 .59222 L p F P
0 g
s
.651 .757 .928 r
.52997 .59222 m .53919 .58936 L .53671 .58672 L p F P
0 g
s
.535 .433 .686 r
.60316 .748 m .60175 .74773 L .60296 .74716 L closepath p F P
0 g
s
.546 .449 .696 r
.6014 .7412 m .60296 .74716 L .60175 .74773 L p F P
0 g
s
.851 .72 .718 r
.4477 .73264 m .45138 .73474 L .44821 .74011 L p F P
0 g
s
.85 .723 .723 r
.45138 .73474 m .4477 .73264 L .45101 .72724 L p F P
0 g
s
.514 .433 .703 r
.60296 .74716 m .6014 .7412 L .60468 .73935 L p F P
0 g
s
.847 .735 .74 r
.45469 .72174 m .45297 .72425 L .45038 .72068 L p F P
0 g
s
.847 .735 .74 r
.45038 .72068 m .45113 .71959 L .45469 .72174 L p F P
0 g
s
.842 .738 .749 r
.45469 .72174 m .45113 .71959 L .45516 .71399 L p F P
0 g
s
.761 .415 .399 r
.48074 .80374 m .47592 .80282 L .47735 .79948 L p F P
0 g
s
.795 .454 .411 r
.47291 .79833 m .47735 .79948 L .47592 .80282 L p F P
0 g
s
.651 .758 .928 r
.82701 .5919 m .83674 .58903 L .83873 .59167 L p F P
0 g
s
.651 .758 .928 r
.83674 .58903 m .82701 .5919 L .825 .58926 L p F P
0 g
s
.65 .757 .928 r
.26212 .58643 m .25337 .58929 L .2563 .59193 L p F P
0 g
s
.65 .757 .928 r
.2563 .59193 m .26504 .58908 L .26212 .58643 L p F P
0 g
s
.838 .6 .579 r
.46108 .7863 m .45655 .78468 L .45721 .77998 L p F P
0 g
s
.845 .607 .579 r
.4526 .7782 m .45721 .77998 L .45655 .78468 L p F P
0 g
s
.842 .625 .608 r
.45721 .77998 m .4526 .7782 L .45372 .77338 L p F P
0 g
s
.651 .758 .928 r
.68434 .59198 m .69382 .58912 L .69604 .59176 L p F P
0 g
s
.651 .758 .928 r
.69382 .58912 m .68434 .59198 L .6821 .58935 L p F P
0 g
s
.65 .757 .928 r
.40528 .58649 m .39628 .58935 L .39898 .59199 L p F P
0 g
s
.65 .757 .928 r
.39898 .59199 m .40796 .58913 L .40528 .58649 L p F P
0 g
s
.651 .757 .928 r
.54844 .5865 m .53919 .58936 L .54166 .592 L p F P
0 g
s
.651 .757 .928 r
.54166 .592 m .55089 .58914 L .54844 .5865 L p F P
0 g
s
.811 .552 .547 r
.4667 .79247 m .46122 .79095 L .46136 .78639 L p F P
0 g
s
.819 .559 .546 r
.46108 .7863 m .46136 .78639 L .46122 .79095 L p F P
0 g
s
.526 .493 .763 r
.58876 .70212 m .5904 .70094 L p .59325 .70773 L F P
0 g
s
.524 .502 .774 r
.58876 .70212 m .5882 .70067 L .5904 .70094 L closepath p F P
0 g
s
.85 .633 .609 r
.4493 .77154 m .45372 .77338 L .4526 .7782 L p F P
0 g
s
.846 .647 .632 r
.45372 .77338 m .4493 .77154 L .45083 .76661 L p F P
0 g
s
.85 .696 .691 r
.44875 .7482 m .44914 .74744 L .44806 .7469 L closepath p F P
0 g
s
.842 .707 .715 r
.44619 .74373 m .44821 .74011 L p .44914 .74744 L F P
0 g
s
.842 .707 .715 r
.44914 .74744 m .44806 .7469 L .44619 .74373 L p F P
0 g
s
.819 .559 .546 r
.46122 .79095 m .46105 .7909 L .46108 .7863 L p F P
0 g
s
.841 .577 .54 r
.45655 .78468 m .46108 .7863 L .46105 .7909 L p F P
0 g
s
.651 .758 .928 r
.83873 .59167 m .84848 .5888 L .85046 .59143 L p F P
0 g
s
.651 .758 .928 r
.84848 .5888 m .83873 .59167 L .83674 .58903 L p F P
0 g
s
.617 .121 .051 r
.48949 .80772 m .49106 .80573 L p .49832 .8095 L F P
0 g
s
.733 .329 .285 r
.48949 .80772 m .48714 .80499 L .49106 .80573 L closepath p F P
0 g
s
.523 .386 .636 r
.5992 .77292 m .59893 .77124 L .60107 .77211 L closepath p F P
0 g
s
.65 .757 .928 r
.27381 .58622 m .26504 .58908 L .26795 .59172 L p F P
0 g
s
.65 .757 .928 r
.26795 .59172 m .27671 .58887 L .27381 .58622 L p F P
0 g
s
.844 .755 .765 r
.45918 .7084 m .45968 .70775 L .45709 .7046 L p F P
0 g
s
.651 .758 .928 r
.69604 .59176 m .70555 .5889 L .70775 .59154 L p F P
0 g
s
.651 .758 .928 r
.70555 .5889 m .69604 .59176 L .69382 .58912 L p F P
0 g
s
.65 .757 .928 r
.41698 .58627 m .40796 .58913 L .41064 .59177 L p F P
0 g
s
.65 .757 .928 r
.41064 .59177 m .41965 .58892 L .41698 .58627 L p F P
0 g
s
.524 .5 .772 r
.5904 .70094 m .5882 .70067 L .58605 .69498 L p F P
0 g
s
.651 .757 .928 r
.55334 .59178 m .5626 .58892 L .56503 .59156 L p F P
0 g
s
.651 .757 .928 r
.56016 .58628 m .55089 .58914 L .55334 .59178 L p F P
0 g
s
.651 .757 .928 r
.55334 .59178 m .5626 .58892 L .56016 .58628 L p F P
0 g
s
.851 .753 .754 r
.45592 .70614 m .45918 .7084 L .45516 .71399 L p F P
0 g
s
.844 .755 .765 r
.45709 .7046 m .45592 .70614 L .45918 .7084 L p F P
0 g
s
.649 .757 .928 r
.14233 .58582 m .13379 .58866 L .1369 .59131 L p F P
0 g
s
.649 .757 .928 r
.1369 .59131 m .14544 .58847 L .14233 .58582 L p F P
0 g
s
.856 .697 .685 r
.44666 .75262 m .44875 .7482 L .44806 .7469 L p F P
0 g
s
.852 .736 .735 r
.45101 .72724 m .45297 .72425 L .45038 .72068 L p F P
0 g
s
.651 .758 .928 r
.85046 .59143 m .86023 .58856 L .86219 .5912 L p F P
0 g
s
.651 .758 .928 r
.86023 .58856 m .85046 .59143 L .84848 .5888 L p F P
0 g
s
.65 .757 .928 r
.2855 .586 m .27671 .58887 L .2796 .59151 L p F P
0 g
s
.65 .757 .928 r
.2796 .59151 m .28838 .58865 L .2855 .586 L p F P
0 g
s
.854 .656 .634 r
.44662 .76471 m .45083 .76661 L .4493 .77154 L p F P
0 g
s
.851 .667 .652 r
.45083 .76661 m .44662 .76471 L .44849 .75969 L p F P
0 g
s
.651 .758 .928 r
.70775 .59154 m .71728 .58867 L .71946 .59131 L p F P
0 g
s
.651 .758 .928 r
.71728 .58867 m .70775 .59154 L .70555 .5889 L p F P
0 g
s
.514 .433 .703 r
.61009 .74093 m .61061 .74285 L .60296 .74716 L p F P
0 g
s
.514 .433 .703 r
.60468 .73935 m .61009 .74093 L p .60296 .74716 L F P
0 g
s
.511 .418 .686 r
.60296 .74716 m .61061 .74285 L p .60955 .75011 L F P
0 g
s
.511 .418 .686 r
.60955 .75011 m .60316 .748 L .60296 .74716 L p F P
0 g
s
.549 .207 .342 r
.56216 .80551 m .56212 .8055 L .56216 .80549 L closepath p F P
0 g
s
.465 .041 .149 r
.56212 .8055 m .56216 .80551 L .5606 .80855 L p F P
0 g
s
.65 .757 .928 r
.42869 .58605 m .41965 .58892 L .42231 .59156 L p F P
0 g
s
.65 .757 .928 r
.42231 .59156 m .43134 .5887 L .42869 .58605 L p F P
0 g
s
.512 .173 .329 r
.56216 .80551 m .56216 .80549 L .57205 .80359 L p F P
0 g
s
.651 .757 .928 r
.56503 .59156 m .57431 .5887 L .57673 .59134 L p F P
0 g
s
.651 .757 .928 r
.57431 .5887 m .56503 .59156 L .5626 .58892 L p F P
0 g
s
.516 .477 .751 r
.60257 .71605 m .59533 .71473 L .60084 .711 L closepath p F P
0 g
s
.528 .486 .754 r
.60009 .70891 m .60084 .711 L .59533 .71473 L p F P
0 g
s
.528 .486 .754 r
.59325 .70773 m .60009 .70891 L p .59533 .71473 L F P
0 g
s
.512 .173 .329 r
.57205 .80359 m .57146 .80525 L .56216 .80551 L p F P
0 g
s
.468 .071 .203 r
.5606 .80855 m .56216 .80551 L .57146 .80525 L p F P
0 g
s
.807 .511 .488 r
.47291 .79833 m .46739 .79682 L .4667 .79247 L p F P
0 g
s
.81 .512 .485 r
.46122 .79095 m .4667 .79247 L .46739 .79682 L p F P
0 g
s
.51 .418 .687 r
.60433 .75294 m .60316 .748 L .60955 .75011 L closepath p F P
0 g
s
.65 .757 .928 r
.154 .58562 m .14544 .58847 L .14853 .59112 L p F P
0 g
s
.65 .757 .928 r
.14853 .59112 m .15709 .58828 L .154 .58562 L p F P
0 g
s
.508 .306 .541 r
.5916 .7905 m .5915 .78593 L .60019 .78278 L p F P
0 g
s
.527 .348 .582 r
.5998 .77796 m .60019 .78278 L .5915 .78593 L p F P
0 g
s
.651 .758 .928 r
.86219 .5912 m .87198 .58832 L .87392 .59096 L p F P
0 g
s
.651 .758 .928 r
.87198 .58832 m .86219 .5912 L .86023 .58856 L p F P
0 g
s
.51 .356 .608 r
.60107 .77211 m .5992 .77292 L .5998 .77796 L p F P
0 g
s
.65 .757 .928 r
.2972 .58579 m .28838 .58865 L .29125 .59129 L p F P
0 g
s
.65 .757 .928 r
.29125 .59129 m .30006 .58844 L .2972 .58579 L p F P
0 g
s
.651 .758 .928 r
.71946 .59131 m .72901 .58845 L .73118 .59109 L p F P
0 g
s
.651 .758 .928 r
.72901 .58845 m .71946 .59131 L .71728 .58867 L p F P
0 g
s
.65 .757 .928 r
.44041 .58583 m .43134 .5887 L .43399 .59134 L p F P
0 g
s
.65 .757 .928 r
.43399 .59134 m .44304 .58848 L .44041 .58583 L p F P
0 g
s
.651 .758 .928 r
.57673 .59134 m .58603 .58848 L .58842 .59112 L p F P
0 g
s
.651 .757 .928 r
.58603 .58848 m .57673 .59134 L .57431 .5887 L p F P
0 g
s
.605 .133 .108 r
.51467 .81103 m .50615 .81036 L .50373 .80919 L p F P
0 g
s
.606 .14 .12 r
.50615 .81036 m .50272 .81012 L .50373 .80919 L closepath p F P
0 g
s
.856 .697 .685 r
.44806 .7469 m .4453 .7454 L p .44666 .75262 L F P
0 g
s
.854 .709 .701 r
.44806 .7469 m .44619 .74373 L .4453 .7454 L closepath p F P
0 g
s
.524 .5 .772 r
.58605 .69498 m .58688 .69434 L p .5904 .70094 L F P
0 g
s
.65 .757 .928 r
.16568 .58543 m .15709 .58828 L .16017 .59092 L p F P
0 g
s
.65 .757 .928 r
.16017 .59092 m .16875 .58808 L .16568 .58543 L p F P
0 g
s
.651 .758 .928 r
.87392 .59096 m .88373 .58808 L .88565 .59072 L p F P
0 g
s
.651 .758 .928 r
.88373 .58808 m .87392 .59096 L .87198 .58832 L p F P
0 g
s
.65 .757 .928 r
.30889 .58557 m .30006 .58844 L .30291 .59108 L p F P
0 g
s
.65 .757 .928 r
.30291 .59108 m .31173 .58822 L .30889 .58557 L p F P
0 g
s
.651 .758 .928 r
.73118 .59109 m .74075 .58822 L .74289 .59086 L p F P
0 g
s
.651 .758 .928 r
.74075 .58822 m .73118 .59109 L .72901 .58845 L p F P
0 g
s
.65 .757 .928 r
.45212 .58561 m .44304 .58848 L .44566 .59112 L p F P
0 g
s
.65 .757 .928 r
.44566 .59112 m .45474 .58826 L .45212 .58561 L p F P
0 g
s
.651 .758 .928 r
.58842 .59112 m .59774 .58826 L .60012 .5909 L p F P
0 g
s
.651 .758 .928 r
.59774 .58826 m .58842 .59112 L .58603 .58848 L p F P
0 g
s
.859 .677 .655 r
.44448 .75771 m .44849 .75969 L .44662 .76471 L p F P
0 g
s
.856 .685 .67 r
.44849 .75969 m .44448 .75771 L .44666 .75262 L p F P
0 g
s
.858 .736 .727 r
.44757 .72506 m .45101 .72724 L .4477 .73264 L p F P
0 g
s
.852 .736 .735 r
.45038 .72068 m .44757 .72506 L .45101 .72724 L p F P
0 g
s
.651 .758 .928 r
.88565 .59072 m .89549 .58783 L .89739 .59047 L p F P
0 g
s
.651 .758 .928 r
.89549 .58783 m .88565 .59072 L .88373 .58808 L p F P
0 g
s
.515 .485 .761 r
.60009 .70891 m .59325 .70773 L .59835 .70408 L closepath p F P
0 g
s
.526 .493 .763 r
.59761 .70214 m .59835 .70408 L .59325 .70773 L p F P
0 g
s
.526 .493 .763 r
.5904 .70094 m .59761 .70214 L p .59325 .70773 L F P
0 g
s
.65 .757 .928 r
.17735 .58523 m .16875 .58808 L .17181 .59073 L p F P
0 g
s
.65 .757 .928 r
.17181 .59073 m .18041 .58788 L .17735 .58523 L p F P
0 g
s
.721 .275 .191 r
.48714 .80499 m .48949 .80772 L .4887 .80822 L p F P
0 g
s
.721 .275 .191 r
.48074 .80374 m .48714 .80499 L p .4887 .80822 L F P
0 g
s
.856 .715 .706 r
.44821 .74011 m .44619 .74373 L .4436 .73964 L p F P
0 g
s
.856 .715 .706 r
.4436 .73964 m .44449 .73802 L .44821 .74011 L p F P
0 g
s
.851 .72 .718 r
.44821 .74011 m .44449 .73802 L .4477 .73264 L p F P
0 g
s
.651 .758 .928 r
.74289 .59086 m .75249 .588 L .75461 .59064 L p F P
0 g
s
.651 .758 .928 r
.75249 .588 m .74289 .59086 L .74075 .58822 L p F P
0 g
s
.65 .757 .928 r
.32059 .58536 m .31173 .58822 L .31457 .59087 L p F P
0 g
s
.65 .757 .928 r
.31457 .59087 m .32342 .58801 L .32059 .58536 L p F P
0 g
s
.651 .758 .928 r
.60012 .5909 m .60946 .58804 L .61182 .59068 L p F P
0 g
s
.651 .758 .928 r
.60946 .58804 m .60012 .5909 L .59774 .58826 L p F P
0 g
s
.65 .757 .928 r
.46384 .58539 m .45474 .58826 L .45734 .5909 L p F P
0 g
s
.65 .757 .928 r
.45734 .5909 m .46644 .58804 L .46384 .58539 L p F P
0 g
s
.847 .768 .774 r
.46206 .69228 m .46509 .69463 L .4605 .70038 L p F P
0 g
s
.503 .404 .675 r
.60557 .75858 m .60433 .75294 L .60955 .75011 L p F P
0 g
s
.536 .42 .668 r
.60433 .75294 m .60557 .75858 L .60449 .75907 L p F P
0 g
s
.795 .454 .411 r
.47592 .80282 m .47449 .80244 L .47291 .79833 L p F P
0 g
s
.802 .449 .39 r
.46739 .79682 m .47291 .79833 L .47449 .80244 L p F P
0 g
s
.65 .757 .928 r
.18904 .58502 m .18041 .58788 L .18345 .59053 L p F P
0 g
s
.65 .757 .928 r
.18345 .59053 m .19207 .58768 L .18904 .58502 L p F P
0 g
s
.472 0 0 r
.5271 .81186 m .5278 .81128 L .53673 .811 L p F P
0 g
s
.521 .029 .027 r
.5271 .81186 m .52485 .81124 L .5278 .81128 L closepath p F P
0 g
s
.849 .751 .755 r
.45189 .71174 m .45516 .71399 L .45113 .71959 L p F P
0 g
s
.851 .753 .754 r
.45516 .71399 m .45189 .71174 L .45592 .70614 L p F P
0 g
s
.528 .037 .034 r
.52485 .81124 m .5271 .81186 L p .51541 .81134 L F P
0 g
s
.528 .037 .034 r
.51541 .81134 m .5157 .81109 L .52485 .81124 L p F P
0 g
s
.651 .758 .928 r
.75461 .59064 m .76423 .58777 L .76634 .59041 L p F P
0 g
s
.651 .758 .928 r
.76423 .58777 m .75461 .59064 L .75249 .588 L p F P
0 g
s
.65 .757 .928 r
.3323 .58514 m .32342 .58801 L .32623 .59065 L p F P
0 g
s
.65 .757 .928 r
.32623 .59065 m .3351 .58779 L .3323 .58514 L p F P
0 g
s
.651 .758 .928 r
.61182 .59068 m .62119 .58782 L .62353 .59046 L p F P
0 g
s
.651 .758 .928 r
.62119 .58782 m .61182 .59068 L .60946 .58804 L p F P
0 g
s
.65 .757 .928 r
.47557 .58517 m .46644 .58804 L .46903 .59068 L p F P
0 g
s
.65 .757 .928 r
.46903 .59068 m .47814 .58782 L .47557 .58517 L p F P
0 g
s
.513 .493 .772 r
.59761 .70214 m .5904 .70094 L .59565 .69693 L closepath p F P
0 g
s
.524 .5 .772 r
.59514 .69566 m .59565 .69693 L .5904 .70094 L p F P
0 g
s
.524 .5 .772 r
.58688 .69434 m .59514 .69566 L p .5904 .70094 L F P
0 g
s
.51 .501 .782 r
.59514 .69566 m .58688 .69434 L .59272 .68955 L closepath p F P
0 g
s
.583 .101 .076 r
.51541 .81134 m .51467 .81103 L .5157 .81109 L closepath p F P
0 g
s
.65 .757 .928 r
.20072 .58482 m .19207 .58768 L .1951 .59033 L p F P
0 g
s
.65 .757 .928 r
.1951 .59033 m .20374 .58747 L .20072 .58482 L p F P
0 g
s
.651 .758 .928 r
.76634 .59041 m .77597 .58754 L .77806 .59018 L p F P
0 g
s
.651 .758 .928 r
.77597 .58754 m .76634 .59041 L .76423 .58777 L p F P
0 g
s
.65 .757 .928 r
.344 .58492 m .3351 .58779 L .3379 .59044 L p F P
0 g
s
.65 .757 .928 r
.3379 .59044 m .34679 .58758 L .344 .58492 L p F P
0 g
s
.51 .356 .608 r
.5998 .77796 m .60575 .7754 L .60107 .77211 L p F P
0 g
s
.506 .357 .613 r
.60744 .76928 m .60107 .77211 L .60575 .7754 L p F P
0 g
s
.523 .385 .635 r
.60659 .76401 m .60744 .76928 L .60107 .77211 L p F P
0 g
s
.418 0 0 r
.51467 .81103 m .51541 .81134 L .51288 .81198 L p F P
0 g
s
.418 0 0 r
.50615 .81036 m .51467 .81103 L p .51298 .81193 L F P
0 g
s
.418 0 0 r
.51243 .81187 m .50615 .81036 L p .51298 .81193 L F P
0 g
s
.093 .635 .848 r
.50615 .81036 m .51288 .81198 L .51102 .81144 L p F P
0 g
s
.093 .635 .848 r
.50117 .81077 m .50272 .81012 L p .51102 .81144 L F P
0 g
s
.093 .635 .848 r
.51102 .81144 m .50899 .8112 L .50235 .81084 L p F P
0 g
s
.093 .635 .848 r
.50235 .81084 m .50117 .81077 L p .50279 .81088 L F P
0 g
s
.093 .635 .848 r
.51102 .81144 m .50235 .81084 L .50279 .81088 L F
.418 0 0 r
.51288 .81198 m .51243 .81187 L p .51298 .81193 L F P
0 g
s
.651 .758 .928 r
.62353 .59046 m .63291 .58759 L .63523 .59024 L p F P
0 g
s
.651 .758 .928 r
.63291 .58759 m .62353 .59046 L .62119 .58782 L p F P
0 g
s
.65 .757 .928 r
.48729 .58495 m .47814 .58782 L .48071 .59046 L p F P
0 g
s
.65 .757 .928 r
.48071 .59046 m .48985 .5876 L .48729 .58495 L p F P
0 g
s
.49 .011 .045 r
.53881 .81137 m .53673 .811 L .53928 .81089 L closepath p F P
0 g
s
.472 0 0 r
.53673 .811 m .53881 .81137 L p .5271 .81186 L F P
0 g
s
.864 .696 .672 r
.44286 .75057 m .44666 .75262 L .44448 .75771 L p F P
0 g
s
.856 .697 .685 r
.4453 .7454 m .44286 .75057 L .44666 .75262 L p F P
0 g
s
.523 .4 .654 r
.60574 .75949 m .60449 .75907 L .60557 .75858 L closepath p F P
0 g
s
.443 0 .012 r
.53881 .81137 m .53928 .81089 L .55021 .80999 L p F P
0 g
s
.549 .149 .236 r
.5505 .80965 m .55021 .80999 L .53928 .81089 L p F P
0 g
s
.65 .757 .928 r
.21241 .58461 m .20374 .58747 L .20675 .59012 L p F P
0 g
s
.65 .757 .928 r
.20675 .59012 m .21541 .58727 L .21241 .58461 L p F P
0 g
s
.651 .758 .928 r
.77806 .59018 m .78772 .58731 L .78979 .58996 L p F P
0 g
s
.651 .758 .928 r
.78772 .58731 m .77806 .59018 L .77597 .58754 L p F P
0 g
s
.65 .757 .928 r
.35571 .58471 m .34679 .58758 L .34957 .59022 L p F P
0 g
s
.65 .757 .928 r
.34957 .59022 m .35848 .58736 L .35571 .58471 L p F P
0 g
s
.651 .758 .928 r
.63523 .59024 m .64464 .58737 L .64695 .59001 L p F P
0 g
s
.651 .758 .928 r
.64464 .58737 m .63523 .59024 L .63291 .58759 L p F P
0 g
s
.65 .757 .928 r
.49902 .58473 m .48985 .5876 L .4924 .59024 L p F P
0 g
s
.65 .757 .928 r
.4924 .59024 m .50156 .58738 L .49902 .58473 L p F P
0 g
s
.509 .433 .706 r
.61009 .74093 m .60468 .73935 L .60899 .73682 L closepath p F P
0 g
s
.521 .447 .713 r
.60757 .73184 m .60899 .73682 L .60468 .73935 L p F P
0 g
s
.521 .447 .713 r
.60597 .73141 m .60757 .73184 L p .60468 .73935 L F P
0 g
s
.65 .757 .928 r
.2241 .5844 m .21541 .58727 L .2184 .58992 L p F P
0 g
s
.65 .757 .928 r
.2184 .58992 m .22708 .58706 L .2241 .5844 L p F P
0 g
s
.846 .768 .776 r
.4605 .70038 m .45709 .7046 L .4545 .70171 L p F P
0 g
s
.846 .768 .776 r
.4545 .70171 m .45745 .69805 L .4605 .70038 L p F P
0 g
s
.847 .768 .774 r
.4605 .70038 m .45745 .69805 L .46206 .69228 L p F P
0 g
s
.651 .758 .928 r
.78979 .58996 m .79947 .58708 L .80153 .58973 L p F P
0 g
s
.651 .758 .928 r
.79947 .58708 m .78979 .58996 L .78772 .58731 L p F P
0 g
s
.86 .718 .703 r
.4453 .7454 m .44619 .74373 L .4436 .73964 L p F P
0 g
s
.65 .757 .928 r
.36742 .58449 m .35848 .58736 L .36124 .59 L p F P
0 g
s
.65 .757 .928 r
.36124 .59 m .37018 .58714 L .36742 .58449 L p F P
0 g
s
.651 .758 .928 r
.64695 .59001 m .65638 .58715 L .65866 .58979 L p F P
0 g
s
.651 .758 .928 r
.65638 .58715 m .64695 .59001 L .64464 .58737 L p F P
0 g
s
.845 .607 .579 r
.45655 .78468 m .45194 .7829 L .4526 .7782 L p F P
0 g
s
.853 .615 .579 r
.44816 .77637 m .4526 .7782 L .45194 .7829 L p F P
0 g
s
.85 .633 .609 r
.4526 .7782 m .44816 .77637 L .4493 .77154 L p F P
0 g
s
.65 .757 .928 r
.51075 .58451 m .50156 .58738 L .50409 .59002 L p F P
0 g
s
.65 .757 .928 r
.50409 .59002 m .51328 .58716 L .51075 .58451 L p F P
0 g
s
.841 .577 .54 r
.46105 .7909 m .45644 .78924 L .45655 .78468 L p F P
0 g
s
.848 .583 .537 r
.45194 .7829 m .45655 .78468 L .45644 .78924 L p F P
0 g
s
.528 .037 .034 r
.5271 .81186 m .525 .81224 L p .51541 .81134 L F P
0 g
s
.528 .037 .034 r
.525 .81224 m .52464 .81231 L p .52363 .8122 L F P
0 g
s
.528 .037 .034 r
.51541 .81134 m .525 .81224 L .52363 .8122 L F
.52449 .8123 m .51541 .81134 L p .52464 .81231 L F P
0 g
s
.528 .037 .034 r
.52464 .81231 m .52461 .81231 L .52449 .8123 L p F P
0 g
s
.326 .768 .963 r
.51541 .81134 m .52461 .81231 L .52345 .81188 L p F P
0 g
s
.326 .768 .963 r
.51288 .81198 m .51541 .81134 L p .52345 .81188 L F P
0 g
s
.288 .758 .94 r
.51846 .81163 m .51102 .81144 L .51248 .81186 L p F P
0 g
s
.288 .758 .94 r
.51248 .81186 m .51288 .81198 L .514 .81191 L p F P
0 g
s
.288 .758 .94 r
.514 .81191 m .51846 .81163 L p .51248 .81186 L F P
0 g
s
.326 .768 .963 r
.52345 .81188 m .51846 .81163 L .514 .81191 L p F P
0 g
s
.326 .768 .963 r
.514 .81191 m .51288 .81198 L p .51528 .81196 L F P
0 g
s
.326 .768 .963 r
.52345 .81188 m .514 .81191 L .51528 .81196 L F
.853 .737 .734 r
.44424 .73047 m .4477 .73264 L .44449 .73802 L p F P
0 g
s
.858 .736 .727 r
.4477 .73264 m .44424 .73047 L .44757 .72506 L p F P
0 g
s
.465 .041 .149 r
.5606 .80855 m .5526 .80969 L .5505 .80965 L p F P
0 g
s
.43 0 .048 r
.5526 .80969 m .55021 .80999 L .5505 .80965 L closepath p F P
0 g
s
.65 .757 .928 r
.2358 .5842 m .22708 .58706 L .23005 .58971 L p F P
0 g
s
.65 .757 .928 r
.23005 .58971 m .23876 .58685 L .2358 .5842 L p F P
0 g
s
.498 .383 .653 r
.60557 .75858 m .61331 .75437 L p .61051 .76197 L F P
0 g
s
.498 .383 .653 r
.61051 .76197 m .60574 .75949 L .60557 .75858 L p F P
0 g
s
.503 .404 .675 r
.61266 .75146 m .61331 .75437 L .60557 .75858 L p F P
0 g
s
.503 .404 .675 r
.60955 .75011 m .61266 .75146 L p .60557 .75858 L F P
0 g
s
.651 .758 .928 r
.80153 .58973 m .81122 .58685 L .81326 .5895 L p F P
0 g
s
.651 .758 .928 r
.81122 .58685 m .80153 .58973 L .79947 .58708 L p F P
0 g
s
.857 .643 .611 r
.44507 .76964 m .4493 .77154 L .44816 .77637 L p F P
0 g
s
.854 .656 .634 r
.4493 .77154 m .44507 .76964 L .44662 .76471 L p F P
0 g
s
.65 .757 .928 r
.37914 .58427 m .37018 .58714 L .37292 .58979 L p F P
0 g
s
.65 .757 .928 r
.37292 .58979 m .38187 .58692 L .37914 .58427 L p F P
0 g
s
.651 .758 .928 r
.65866 .58979 m .66811 .58692 L .67038 .58957 L p F P
0 g
s
.651 .758 .928 r
.66811 .58692 m .65866 .58979 L .65638 .58715 L p F P
0 g
s
.651 .757 .928 r
.52249 .58429 m .51328 .58716 L .51579 .58981 L p F P
0 g
s
.651 .757 .928 r
.51579 .58981 m .52499 .58694 L .52249 .58429 L p F P
0 g
s
.474 .184 .392 r
.58156 .80129 m .58226 .79746 L .59137 .79475 L p F P
0 g
s
.516 .275 .487 r
.5916 .7905 m .59137 .79475 L .58226 .79746 L p F P
0 g
s
.515 .221 .406 r
.58226 .79746 m .58156 .80129 L .57205 .80359 L p F P
0 g
s
.856 .748 .744 r
.45113 .71959 m .45038 .72068 L .44778 .7174 L p F P
0 g
s
.856 .748 .744 r
.44778 .7174 m .44782 .71735 L .45113 .71959 L p F P
0 g
s
.849 .751 .755 r
.45113 .71959 m .44782 .71735 L .45189 .71174 L p F P
0 g
s
.81 .512 .485 r
.46739 .79682 m .46192 .7953 L .46122 .79095 L p F P
0 g
s
.816 .516 .483 r
.46105 .7909 m .46122 .79095 L .46192 .7953 L p F P
0 g
s
.495 .324 .579 r
.60575 .7754 m .5998 .77796 L .60019 .78278 L p F P
0 g
s
.816 .516 .483 r
.46192 .7953 m .46022 .7948 L .46105 .7909 L p F P
0 g
s
.842 .543 .483 r
.45644 .78924 m .46105 .7909 L .46022 .7948 L p F P
0 g
s
.093 .635 .848 r
.50272 .81012 m .50615 .81036 L p .51102 .81144 L F P
0 g
s
.497 .383 .654 r
.60659 .76401 m .60574 .75949 L .61051 .76197 L closepath p F P
0 g
s
.86 .718 .703 r
.4436 .73964 m .44171 .74328 L .4453 .7454 L p F P
0 g
s
.869 .714 .687 r
.44171 .74328 m .4453 .7454 L .44286 .75057 L p F P
0 g
s
.651 .758 .928 r
.81326 .5895 m .82298 .58662 L .825 .58926 L p F P
0 g
s
.651 .758 .928 r
.82298 .58662 m .81326 .5895 L .81122 .58685 L p F P
0 g
s
.65 .757 .928 r
.2475 .58398 m .23876 .58685 L .24171 .5895 L p F P
0 g
s
.65 .757 .928 r
.24171 .5895 m .25044 .58664 L .2475 .58398 L p F P
0 g
s
.651 .758 .928 r
.67038 .58957 m .67985 .5867 L .6821 .58935 L p F P
0 g
s
.651 .758 .928 r
.67985 .5867 m .67038 .58957 L .66811 .58692 L p F P
0 g
s
.65 .757 .928 r
.39086 .58405 m .38187 .58692 L .3846 .58957 L p F P
0 g
s
.65 .757 .928 r
.3846 .58957 m .39357 .58671 L .39086 .58405 L p F P
0 g
s
.861 .748 .737 r
.44757 .72506 m .45038 .72068 L .44778 .7174 L p F P
0 g
s
.651 .757 .928 r
.53423 .58406 m .52499 .58694 L .52749 .58959 L p F P
0 g
s
.651 .757 .928 r
.52749 .58959 m .53671 .58672 L .53423 .58406 L p F P
0 g
s
.721 .275 .191 r
.4887 .80822 m .48444 .8073 L .48074 .80374 L p F P
0 g
s
.684 .198 .089 r
.47592 .80282 m .48074 .80374 L .48444 .8073 L p F P
0 g
s
.853 .769 .768 r
.45592 .70614 m .45709 .7046 L .4545 .70171 L p F P
0 g
s
.862 .667 .637 r
.44259 .76274 m .44662 .76471 L .44507 .76964 L p F P
0 g
s
.859 .677 .655 r
.44662 .76471 m .44259 .76274 L .44448 .75771 L p F P
0 g
s
.472 0 0 r
.53881 .81137 m .53634 .81207 L .5271 .81186 L p F P
0 g
s
.388 .804 .976 r
.5271 .81186 m .53634 .81207 L .53516 .81166 L p F P
0 g
s
.388 .804 .976 r
.52461 .81231 m .5271 .81186 L p .53516 .81166 L F P
0 g
s
.565 .032 0 r
.50117 .81077 m .49832 .8095 L .50272 .81012 L closepath p F P
0 g
s
.651 .758 .928 r
.83474 .58639 m .825 .58926 L .82298 .58662 L p F P
0 g
s
.651 .758 .928 r
.825 .58926 m .83474 .58639 L .83674 .58903 L p F P
0 g
s
.65 .757 .928 r
.2592 .58377 m .25044 .58664 L .25337 .58929 L p F P
0 g
s
.65 .757 .928 r
.25337 .58929 m .26212 .58643 L .2592 .58377 L p F P
0 g
s
.457 .106 .28 r
.57146 .80525 m .57205 .80359 L .58156 .80129 L p F P
0 g
s
.651 .758 .928 r
.6821 .58935 m .69159 .58648 L .69382 .58912 L p F P
0 g
s
.651 .758 .928 r
.69159 .58648 m .6821 .58935 L .67985 .5867 L p F P
0 g
s
.65 .757 .928 r
.40258 .58383 m .39357 .58671 L .39628 .58935 L p F P
0 g
s
.65 .757 .928 r
.39628 .58935 m .40528 .58649 L .40258 .58383 L p F P
0 g
s
.651 .757 .928 r
.54597 .58384 m .53671 .58672 L .53919 .58936 L p F P
0 g
s
.651 .757 .928 r
.53919 .58936 m .54844 .5865 L .54597 .58384 L p F P
0 g
s
.443 0 .012 r
.55021 .80999 m .54807 .81121 L .53881 .81137 L p F P
0 g
s
.333 .798 .932 r
.53881 .81137 m .54807 .81121 L .5463 .8109 L p F P
0 g
s
.333 .798 .932 r
.53634 .81207 m .53881 .81137 L p .5463 .8109 L F P
0 g
s
.859 .767 .759 r
.45292 .70379 m .45592 .70614 L .45189 .71174 L p F P
0 g
s
.853 .769 .768 r
.4545 .70171 m .45292 .70379 L .45592 .70614 L p F P
0 g
s
.237 0 0 r
.54807 .81121 m .55021 .80999 L .5526 .80969 L p F P
0 g
s
.479 .245 .48 r
.59137 .79475 m .5916 .7905 L .60031 .78736 L p F P
0 g
s
.508 .306 .541 r
.60019 .78278 m .60031 .78736 L .5916 .7905 L p F P
0 g
s
.651 .758 .928 r
.83674 .58903 m .8465 .58615 L .84848 .5888 L p F P
0 g
s
.651 .758 .928 r
.8465 .58615 m .83674 .58903 L .83474 .58639 L p F P
0 g
s
.65 .757 .928 r
.2709 .58356 m .26212 .58643 L .26504 .58908 L p F P
0 g
s
.65 .757 .928 r
.26504 .58908 m .27381 .58622 L .2709 .58356 L p F P
0 g
s
.651 .758 .928 r
.69382 .58912 m .70334 .58625 L .70555 .5889 L p F P
0 g
s
.651 .758 .928 r
.70334 .58625 m .69382 .58912 L .69159 .58648 L p F P
0 g
s
.65 .757 .928 r
.41431 .58361 m .40528 .58649 L .40796 .58913 L p F P
0 g
s
.65 .757 .928 r
.40796 .58913 m .41698 .58627 L .41431 .58361 L p F P
0 g
s
.651 .757 .928 r
.55771 .58362 m .54844 .5865 L .55089 .58914 L p F P
0 g
s
.651 .757 .928 r
.55089 .58914 m .56016 .58628 L .55771 .58362 L p F P
0 g
s
.802 .449 .39 r
.47449 .80244 m .46909 .80091 L .46739 .79682 L p F P
0 g
s
.802 .441 .374 r
.46192 .7953 m .46739 .79682 L .46909 .80091 L p F P
0 g
s
.649 .757 .928 r
.13921 .58315 m .13066 .58601 L .13379 .58866 L p F P
0 g
s
.649 .757 .928 r
.13379 .58866 m .14233 .58582 L .13921 .58315 L p F P
0 g
s
.651 .758 .928 r
.84848 .5888 m .85827 .58591 L .86023 .58856 L p F P
0 g
s
.651 .758 .928 r
.85827 .58591 m .84848 .5888 L .8465 .58615 L p F P
0 g
s
.65 .757 .928 r
.28261 .58334 m .27381 .58622 L .27671 .58887 L p F P
0 g
s
.65 .757 .928 r
.27671 .58887 m .2855 .586 L .28261 .58334 L p F P
0 g
s
.651 .758 .928 r
.70555 .5889 m .71509 .58603 L .71728 .58867 L p F P
0 g
s
.651 .758 .928 r
.71509 .58603 m .70555 .5889 L .70334 .58625 L p F P
0 g
s
.365 0 0 r
.55978 .80937 m .5526 .80969 L .5606 .80855 L closepath p F P
0 g
s
.237 0 0 r
.5526 .80969 m .55978 .80937 L p .54807 .81121 L F P
0 g
s
.65 .757 .928 r
.42604 .58339 m .41698 .58627 L .41965 .58892 L p F P
0 g
s
.65 .757 .928 r
.41965 .58892 m .42869 .58605 L .42604 .58339 L p F P
0 g
s
.651 .757 .928 r
.5626 .58892 m .57189 .58605 L .57431 .5887 L p F P
0 g
s
.651 .757 .928 r
.56946 .5834 m .56016 .58628 L .5626 .58892 L p F P
0 g
s
.651 .757 .928 r
.5626 .58892 m .57189 .58605 L .56946 .5834 L p F P
0 g
s
.867 .688 .658 r
.44067 .75567 m .44448 .75771 L .44259 .76274 L p F P
0 g
s
.864 .696 .672 r
.44448 .75771 m .44067 .75567 L .44286 .75057 L p F P
0 g
s
.65 .757 .928 r
.1509 .58296 m .14233 .58582 L .14544 .58847 L p F P
0 g
s
.65 .757 .928 r
.14544 .58847 m .154 .58562 L .1509 .58296 L p F P
0 g
s
.651 .758 .928 r
.86023 .58856 m .87004 .58568 L .87198 .58832 L p F P
0 g
s
.651 .758 .928 r
.87004 .58568 m .86023 .58856 L .85827 .58591 L p F P
0 g
s
.65 .757 .928 r
.29433 .58313 m .2855 .586 L .28838 .58865 L p F P
0 g
s
.65 .757 .928 r
.28838 .58865 m .2972 .58579 L .29433 .58313 L p F P
0 g
s
.651 .758 .928 r
.71728 .58867 m .72684 .5858 L .72901 .58845 L p F P
0 g
s
.651 .758 .928 r
.72684 .5858 m .71728 .58867 L .71509 .58603 L p F P
0 g
s
.379 0 0 r
.49832 .8095 m .50117 .81077 L .49861 .81056 L p F P
0 g
s
.379 0 0 r
.49096 .80852 m .49832 .8095 L p .49845 .80997 L F P
0 g
s
.379 0 0 r
.4986 .81052 m .49494 .80956 L .49845 .80997 L F
.49494 .80956 m .49096 .80852 L .49845 .80997 L F
.4983 .81047 m .49096 .80852 L p .4986 .81052 L F P
0 g
s
.379 0 0 r
.49861 .81056 m .4983 .81047 L p .4986 .81052 L F P
0 g
s
.166 .658 .919 r
.49096 .80852 m .49861 .81056 L .49753 .81005 L p F P
0 g
s
.166 .658 .919 r
.4887 .80822 m .49096 .80852 L p .49529 .80953 L F P
0 g
s
.166 .658 .919 r
.49753 .81005 m .49463 .80945 L .49529 .80953 L F
.49463 .80945 m .4887 .80822 L .49529 .80953 L F
.438 0 0 r
.48444 .8073 m .4869 .80867 L .48431 .80824 L p F P
0 g
s
0 .568 .77 r
.48447 .80826 m .4883 .80879 L .48431 .80824 L F
.166 .658 .919 r
.4869 .80867 m .4887 .80822 L p .49753 .81005 L F P
0 g
s
.6 .056 0 r
.4869 .80867 m .48444 .8073 L .4887 .80822 L closepath p F P
0 g
s
0 .568 .77 r
.49404 .80927 m .49072 .80899 L p .48447 .80826 L F P
0 g
s
0 .568 .77 r
.49072 .80899 m .4883 .80879 L p .48447 .80826 L F P
0 g
s
0 .568 .77 r
.4883 .80879 m .4869 .80867 L .48598 .80851 L p F P
0 g
s
0 .568 .77 r
.48598 .80851 m .48431 .80824 L p .4883 .80879 L F P
0 g
s
.166 .658 .919 r
.49753 .81005 m .49404 .80927 L .4883 .80879 L p F P
0 g
s
.166 .658 .919 r
.4883 .80879 m .4869 .80867 L p .48997 .80907 L F P
0 g
s
.166 .658 .919 r
.49753 .81005 m .4883 .80879 L .48997 .80907 L F
.617 .121 .051 r
.49832 .8095 m .49096 .80852 L .48949 .80772 L p F P
0 g
s
.65 .757 .928 r
.43777 .58317 m .42869 .58605 L .43134 .5887 L p F P
0 g
s
.65 .757 .928 r
.43134 .5887 m .44041 .58583 L .43777 .58317 L p F P
0 g
s
.651 .757 .928 r
.57431 .5887 m .58362 .58583 L .58603 .58848 L p F P
0 g
s
.651 .757 .928 r
.58362 .58583 m .57431 .5887 L .57189 .58605 L p F P
0 g
s
.866 .749 .731 r
.44436 .7228 m .44757 .72506 L .44424 .73047 L p F P
0 g
s
.861 .748 .737 r
.44778 .7174 m .44436 .7228 L .44757 .72506 L p F P
0 g
s
.487 .361 .634 r
.61051 .76197 m .60659 .76401 L .60744 .76928 L p F P
0 g
s
.864 .727 .709 r
.4436 .73964 m .44449 .73802 L .44103 .73588 L closepath p F P
0 g
s
.853 .737 .734 r
.44101 .73585 m .44424 .73047 L p .44449 .73802 L F P
0 g
s
.853 .737 .734 r
.44449 .73802 m .44103 .73588 L .44101 .73585 L p F P
0 g
s
.618 .124 .058 r
.49096 .80852 m .4887 .80822 L .48949 .80772 L closepath p F P
0 g
s
.65 .757 .928 r
.1626 .58276 m .154 .58562 L .15709 .58828 L p F P
0 g
s
.65 .757 .928 r
.15709 .58828 m .16568 .58543 L .1626 .58276 L p F P
0 g
s
.651 .758 .928 r
.87198 .58832 m .88181 .58543 L .88373 .58808 L p F P
0 g
s
.651 .758 .928 r
.88181 .58543 m .87198 .58832 L .87004 .58568 L p F P
0 g
s
.509 .442 .717 r
.60757 .73184 m .60597 .73141 L .60722 .73064 L closepath p F P
0 g
s
.521 .455 .722 r
.60528 .72428 m .60722 .73064 L .60597 .73141 L p F P
0 g
s
.65 .757 .928 r
.30604 .58291 m .2972 .58579 L .30006 .58844 L p F P
0 g
s
.65 .757 .928 r
.30006 .58844 m .30889 .58557 L .30604 .58291 L p F P
0 g
s
.651 .758 .928 r
.72901 .58845 m .73859 .58558 L .74075 .58822 L p F P
0 g
s
.651 .758 .928 r
.73859 .58558 m .72901 .58845 L .72684 .5858 L p F P
0 g
s
.684 .198 .089 r
.47524 .8036 m .47592 .80282 L p .48444 .8073 L F P
0 g
s
.775 .38 .306 r
.47524 .8036 m .47449 .80244 L .47592 .80282 L closepath p F P
0 g
s
.65 .757 .928 r
.4495 .58295 m .44041 .58583 L .44304 .58848 L p F P
0 g
s
.65 .757 .928 r
.44304 .58848 m .45212 .58561 L .4495 .58295 L p F P
0 g
s
.651 .758 .928 r
.58603 .58848 m .59536 .58561 L .59774 .58826 L p F P
0 g
s
.651 .757 .928 r
.59536 .58561 m .58603 .58848 L .58362 .58583 L p F P
0 g
s
.651 .758 .928 r
.88373 .58808 m .89358 .58519 L .89549 .58783 L p F P
0 g
s
.651 .758 .928 r
.89358 .58519 m .88373 .58808 L .88181 .58543 L p F P
0 g
s
.65 .757 .928 r
.17429 .58256 m .16568 .58543 L .16875 .58808 L p F P
0 g
s
.65 .757 .928 r
.16875 .58808 m .17735 .58523 L .17429 .58256 L p F P
0 g
s
.855 .784 .781 r
.45931 .68984 m .46206 .69228 L .45745 .69805 L p F P
0 g
s
.85 .769 .773 r
.44887 .7094 m .45189 .71174 L .44782 .71735 L p F P
0 g
s
.859 .767 .759 r
.45189 .71174 m .44887 .7094 L .45292 .70379 L p F P
0 g
s
.651 .758 .928 r
.74075 .58822 m .75035 .58535 L .75249 .588 L p F P
0 g
s
.651 .758 .928 r
.75035 .58535 m .74075 .58822 L .73859 .58558 L p F P
0 g
s
.65 .757 .928 r
.31776 .5827 m .30889 .58557 L .31173 .58822 L p F P
0 g
s
.65 .757 .928 r
.31173 .58822 m .32059 .58536 L .31776 .5827 L p F P
0 g
s
.651 .758 .928 r
.59774 .58826 m .6071 .58539 L .60946 .58804 L p F P
0 g
s
.651 .758 .928 r
.6071 .58539 m .59774 .58826 L .59536 .58561 L p F P
0 g
s
.65 .757 .928 r
.46124 .58273 m .45212 .58561 L .45474 .58826 L p F P
0 g
s
.65 .757 .928 r
.45474 .58826 m .46384 .58539 L .46124 .58273 L p F P
0 g
s
.869 .728 .703 r
.44171 .74328 m .4436 .73964 L .44103 .73588 L p F P
0 g
s
.872 .708 .675 r
.43927 .74845 m .44286 .75057 L .44067 .75567 L p F P
0 g
s
.869 .714 .687 r
.44286 .75057 m .43927 .74845 L .44171 .74328 L p F P
0 g
s
.65 .757 .928 r
.18599 .58236 m .17735 .58523 L .18041 .58788 L p F P
0 g
s
.65 .757 .928 r
.18041 .58788 m .18904 .58502 L .18599 .58236 L p F P
0 g
s
.651 .758 .928 r
.75249 .588 m .76211 .58512 L .76423 .58777 L p F P
0 g
s
.651 .758 .928 r
.76211 .58512 m .75249 .588 L .75035 .58535 L p F P
0 g
s
.765 .327 .21 r
.47449 .80244 m .47524 .8036 L .47307 .80492 L p F P
0 g
s
.765 .327 .21 r
.46909 .80091 m .47449 .80244 L p .47307 .80492 L F P
0 g
s
.65 .757 .928 r
.32948 .58248 m .32059 .58536 L .32342 .58801 L p F P
0 g
s
.65 .757 .928 r
.32342 .58801 m .3323 .58514 L .32948 .58248 L p F P
0 g
s
.651 .758 .928 r
.60946 .58804 m .61884 .58516 L .62119 .58782 L p F P
0 g
s
.651 .758 .928 r
.61884 .58516 m .60946 .58804 L .6071 .58539 L p F P
0 g
s
.65 .757 .928 r
.47298 .58251 m .46384 .58539 L .46644 .58804 L p F P
0 g
s
.65 .757 .928 r
.46644 .58804 m .47557 .58517 L .47298 .58251 L p F P
0 g
s
.848 .583 .537 r
.45644 .78924 m .45183 .78746 L .45194 .7829 L p F P
0 g
s
.856 .59 .536 r
.44748 .78108 m .45194 .7829 L .45183 .78746 L p F P
0 g
s
.853 .615 .579 r
.45194 .7829 m .44748 .78108 L .44816 .77637 L p F P
0 g
s
.86 .624 .58 r
.4439 .77448 m .44816 .77637 L .44748 .78108 L p F P
0 g
s
.857 .643 .611 r
.44816 .77637 m .4439 .77448 L .44507 .76964 L p F P
0 g
s
.65 .757 .928 r
.1977 .58215 m .18904 .58502 L .19207 .58768 L p F P
0 g
s
.65 .757 .928 r
.19207 .58768 m .20072 .58482 L .1977 .58215 L p F P
0 g
s
.474 .28 .536 r
.60031 .78736 m .60019 .78278 L .60847 .77925 L p F P
0 g
s
.495 .324 .579 r
.60019 .78278 m .60847 .77925 L .60575 .7754 L p F P
0 g
s
.651 .758 .928 r
.76423 .58777 m .77387 .58489 L .77597 .58754 L p F P
0 g
s
.651 .758 .928 r
.77387 .58489 m .76423 .58777 L .76211 .58512 L p F P
0 g
s
.65 .757 .928 r
.34121 .58226 m .3323 .58514 L .3351 .58779 L p F P
0 g
s
.65 .757 .928 r
.3351 .58779 m .344 .58492 L .34121 .58226 L p F P
0 g
s
.483 .438 .73 r
.60588 .72384 m .60528 .72428 L .60722 .73064 L p F P
0 g
s
.494 .456 .744 r
.60528 .72428 m .60506 .72361 L .60588 .72384 L closepath p F P
0 g
s
.651 .758 .928 r
.62119 .58782 m .63059 .58494 L .63291 .58759 L p F P
0 g
s
.651 .758 .928 r
.63059 .58494 m .62119 .58782 L .61884 .58516 L p F P
0 g
s
.495 .455 .742 r
.60588 .72384 m .60506 .72361 L .60315 .71773 L p F P
0 g
s
.65 .757 .928 r
.48473 .58229 m .47557 .58517 L .47814 .58782 L p F P
0 g
s
.65 .757 .928 r
.47814 .58782 m .48729 .58495 L .48473 .58229 L p F P
0 g
s
.842 .543 .483 r
.46022 .7948 m .45698 .79363 L .45644 .78924 L p F P
0 g
s
.85 .547 .476 r
.45183 .78746 m .45644 .78924 L .45698 .79363 L p F P
0 g
s
.495 .455 .742 r
.60315 .71773 m .6046 .71659 L p .60588 .72384 L F P
0 g
s
.492 .464 .754 r
.60315 .71773 m .60257 .71605 L .6046 .71659 L closepath p F P
0 g
s
.493 .463 .752 r
.6046 .71659 m .60257 .71605 L .60084 .711 L p F P
0 g
s
.865 .653 .614 r
.44101 .76768 m .44507 .76964 L .4439 .77448 L p F P
0 g
s
.862 .667 .637 r
.44507 .76964 m .44101 .76768 L .44259 .76274 L p F P
0 g
s
.485 .427 .717 r
.60722 .73064 m .61306 .72633 L p .61312 .73393 L F P
0 g
s
.485 .427 .717 r
.61312 .73393 m .60757 .73184 L .60722 .73064 L p F P
0 g
s
.483 .438 .73 r
.60722 .73064 m .61306 .72633 L .60588 .72384 L p F P
0 g
s
.65 .757 .928 r
.2094 .58195 m .20072 .58482 L .20374 .58747 L p F P
0 g
s
.65 .757 .928 r
.20374 .58747 m .21241 .58461 L .2094 .58195 L p F P
0 g
s
.497 .401 .676 r
.61266 .75146 m .60955 .75011 L .61205 .7487 L closepath p F P
0 g
s
.511 .418 .686 r
.61061 .74285 m .61205 .7487 L .60955 .75011 L p F P
0 g
s
.651 .758 .928 r
.77597 .58754 m .78564 .58466 L .78772 .58731 L p F P
0 g
s
.651 .758 .928 r
.78564 .58466 m .77597 .58754 L .77387 .58489 L p F P
0 g
s
.457 .106 .28 r
.58156 .80129 m .58079 .80342 L .57146 .80525 L p F P
0 g
s
.368 0 .095 r
.57056 .8067 m .57146 .80525 L .58079 .80342 L p F P
0 g
s
.468 .071 .203 r
.57146 .80525 m .57056 .8067 L .5606 .80855 L p F P
0 g
s
.65 .757 .928 r
.35293 .58204 m .344 .58492 L .34679 .58758 L p F P
0 g
s
.65 .757 .928 r
.34679 .58758 m .35571 .58471 L .35293 .58204 L p F P
0 g
s
.31 0 0 r
.55978 .80937 m .5606 .80855 L .57056 .8067 L p F P
0 g
s
.484 .427 .718 r
.60899 .73682 m .60757 .73184 L .61312 .73393 L closepath p F P
0 g
s
.651 .758 .928 r
.63291 .58759 m .64233 .58472 L .64464 .58737 L p F P
0 g
s
.651 .758 .928 r
.64233 .58472 m .63291 .58759 L .63059 .58494 L p F P
0 g
s
.65 .757 .928 r
.49647 .58207 m .48729 .58495 L .48985 .5876 L p F P
0 g
s
.65 .757 .928 r
.48985 .5876 m .49902 .58473 L .49647 .58207 L p F P
0 g
s
.855 .784 .782 r
.45745 .69805 m .4545 .70171 L .45188 .69909 L p F P
0 g
s
.855 .784 .782 r
.45188 .69909 m .45468 .69562 L .45745 .69805 L p F P
0 g
s
.855 .784 .781 r
.45745 .69805 m .45468 .69562 L .45931 .68984 L p F P
0 g
s
.493 .463 .752 r
.60084 .711 m .60258 .70955 L p .6046 .71659 L F P
0 g
s
.489 .471 .764 r
.60084 .711 m .60009 .70891 L .60258 .70955 L closepath p F P
0 g
s
.869 .747 .726 r
.44424 .73047 m .44101 .73585 L .43839 .73261 L p F P
0 g
s
.869 .747 .726 r
.43839 .73261 m .44101 .72822 L .44424 .73047 L p F P
0 g
s
.866 .749 .731 r
.44424 .73047 m .44101 .72822 L .44436 .7228 L p F P
0 g
s
.65 .757 .928 r
.22111 .58174 m .21241 .58461 L .21541 .58727 L p F P
0 g
s
.65 .757 .928 r
.21541 .58727 m .2241 .5844 L .22111 .58174 L p F P
0 g
s
.651 .758 .928 r
.78772 .58731 m .79741 .58443 L .79947 .58708 L p F P
0 g
s
.651 .758 .928 r
.79741 .58443 m .78772 .58731 L .78564 .58466 L p F P
0 g
s
.65 .757 .928 r
.36467 .58182 m .35571 .58471 L .35848 .58736 L p F P
0 g
s
.65 .757 .928 r
.35848 .58736 m .36742 .58449 L .36467 .58182 L p F P
0 g
s
.651 .758 .928 r
.64464 .58737 m .65408 .58449 L .65638 .58715 L p F P
0 g
s
.651 .758 .928 r
.65408 .58449 m .64464 .58737 L .64233 .58472 L p F P
0 g
s
.65 .757 .928 r
.50823 .58184 m .49902 .58473 L .50156 .58738 L p F P
0 g
s
.65 .757 .928 r
.50156 .58738 m .51075 .58451 L .50823 .58184 L p F P
0 g
s
.49 .47 .762 r
.60258 .70955 m .60009 .70891 L .59835 .70408 L p F P
0 g
s
.865 .763 .749 r
.44778 .7174 m .44782 .71735 L .44759 .71718 L closepath p F P
0 g
s
.85 .769 .773 r
.44517 .71453 m .44887 .7094 L p .44782 .71735 L F P
0 g
s
.85 .769 .773 r
.44782 .71735 m .44759 .71718 L .44517 .71453 L p F P
0 g
s
.871 .762 .739 r
.44436 .7228 m .44778 .7174 L .44759 .71718 L p F P
0 g
s
.479 .441 .738 r
.61209 .719 m .60588 .72384 L .61306 .72633 L p F P
0 g
s
.495 .455 .742 r
.61208 .71897 m .61209 .719 L .60588 .72384 L p F P
0 g
s
.495 .455 .742 r
.6046 .71659 m .61208 .71897 L p .60588 .72384 L F P
0 g
s
.486 .418 .706 r
.60899 .73682 m .61312 .73393 L p .61221 .74178 L F P
0 g
s
.486 .418 .706 r
.61221 .74178 m .61009 .74093 L .60899 .73682 L p F P
0 g
s
.802 .441 .374 r
.46909 .80091 m .46372 .79936 L .46192 .7953 L p F P
0 g
s
.801 .442 .377 r
.46022 .7948 m .46192 .7953 L .46372 .79936 L p F P
0 g
s
.473 .333 .61 r
.60809 .77436 m .60744 .76928 L .61517 .76526 L p F P
0 g
s
.506 .357 .613 r
.60575 .7754 m .60809 .77436 L .60744 .76928 L p F P
0 g
s
.487 .361 .634 r
.60744 .76928 m .61517 .76526 L .61051 .76197 L p F P
0 g
s
.869 .728 .703 r
.441 .73586 m .43833 .74109 L .44171 .74328 L p F P
0 g
s
.869 .728 .703 r
.44103 .73588 m .441 .73586 L p .44171 .74328 L F P
0 g
s
.877 .726 .69 r
.43833 .74109 m .44171 .74328 L .43927 .74845 L p F P
0 g
s
.87 .678 .64 r
.43875 .76071 m .44259 .76274 L .44101 .76768 L p F P
0 g
s
.867 .688 .658 r
.44259 .76274 m .43875 .76071 L .44067 .75567 L p F P
0 g
s
.65 .757 .928 r
.23283 .58153 m .2241 .5844 L .22708 .58706 L p F P
0 g
s
.65 .757 .928 r
.22708 .58706 m .2358 .5842 L .23283 .58153 L p F P
0 g
s
.651 .758 .928 r
.79947 .58708 m .80918 .5842 L .81122 .58685 L p F P
0 g
s
.651 .758 .928 r
.80918 .5842 m .79947 .58708 L .79741 .58443 L p F P
0 g
s
.871 .762 .739 r
.44759 .71718 m .44483 .71502 L p .44436 .7228 L F P
0 g
s
.864 .768 .754 r
.44759 .71718 m .44517 .71453 L .44483 .71502 L closepath p F P
0 g
s
.65 .757 .928 r
.3764 .58161 m .36742 .58449 L .37018 .58714 L p F P
0 g
s
.65 .757 .928 r
.37018 .58714 m .37914 .58427 L .3764 .58161 L p F P
0 g
s
.651 .758 .928 r
.65638 .58715 m .66584 .58427 L .66811 .58692 L p F P
0 g
s
.651 .758 .928 r
.66584 .58427 m .65638 .58715 L .65408 .58449 L p F P
0 g
s
.651 .757 .928 r
.51998 .58162 m .51075 .58451 L .51328 .58716 L p F P
0 g
s
.651 .757 .928 r
.51328 .58716 m .52249 .58429 L .51998 .58162 L p F P
0 g
s
.684 .198 .089 r
.48444 .8073 m .47832 .80596 L .47524 .8036 L p F P
0 g
s
.683 .208 .116 r
.47832 .80596 m .47307 .80492 L .47524 .8036 L closepath p F P
0 g
s
.862 .783 .772 r
.45292 .70379 m .4545 .70171 L .45188 .69909 L p F P
0 g
s
.49 .47 .762 r
.59835 .70408 m .59988 .7027 L p .60258 .70955 L F P
0 g
s
.487 .479 .774 r
.59835 .70408 m .59761 .70214 L .59988 .7027 L closepath p F P
0 g
s
.65 .757 .928 r
.24454 .58132 m .2358 .5842 L .23876 .58685 L p F P
0 g
s
.65 .757 .928 r
.23876 .58685 m .2475 .58398 L .24454 .58132 L p F P
0 g
s
.651 .758 .928 r
.81122 .58685 m .82096 .58397 L .82298 .58662 L p F P
0 g
s
.651 .758 .928 r
.82096 .58397 m .81122 .58685 L .80918 .5842 L p F P
0 g
s
.484 .419 .708 r
.61061 .74285 m .61009 .74093 L .61221 .74178 L closepath p F P
0 g
s
.65 .757 .928 r
.38814 .58139 m .37914 .58427 L .38187 .58692 L p F P
0 g
s
.65 .757 .928 r
.38187 .58692 m .39086 .58405 L .38814 .58139 L p F P
0 g
s
.651 .758 .928 r
.66811 .58692 m .6776 .58405 L .67985 .5867 L p F P
0 g
s
.651 .758 .928 r
.6776 .58405 m .66811 .58692 L .66584 .58427 L p F P
0 g
s
.651 .757 .928 r
.53174 .5814 m .52249 .58429 L .52499 .58694 L p F P
0 g
s
.651 .757 .928 r
.52499 .58694 m .53423 .58406 L .53174 .5814 L p F P
0 g
s
.487 .478 .773 r
.59988 .7027 m .59761 .70214 L .59565 .69693 L p F P
0 g
s
.489 .323 .581 r
.60809 .77436 m .60575 .7754 L .60847 .77925 L p F P
0 g
s
0 .56 .73 r
.50899 .8112 m .50117 .81077 L .49861 .81056 L p F P
0 g
s
.473 .398 .691 r
.61221 .74178 m .61061 .74285 L .61205 .7487 L p F P
0 g
s
.651 .758 .928 r
.82298 .58662 m .83274 .58373 L .83474 .58639 L p F P
0 g
s
.651 .758 .928 r
.83274 .58373 m .82298 .58662 L .82096 .58397 L p F P
0 g
s
.868 .782 .764 r
.45017 .70137 m .45292 .70379 L .44887 .7094 L p F P
0 g
s
.862 .783 .772 r
.45188 .69909 m .45017 .70137 L .45292 .70379 L p F P
0 g
s
.65 .757 .928 r
.25626 .58111 m .2475 .58398 L .25044 .58664 L p F P
0 g
s
.65 .757 .928 r
.25044 .58664 m .2592 .58377 L .25626 .58111 L p F P
0 g
s
.801 .442 .377 r
.46372 .79936 m .45836 .79781 L .46022 .7948 L p F P
0 g
s
.836 .488 .396 r
.45698 .79363 m .46022 .7948 L .45836 .79781 L p F P
0 g
s
.403 .05 .248 r
.58079 .80342 m .58156 .80129 L .59069 .79859 L p F P
0 g
s
.474 .184 .392 r
.59137 .79475 m .59069 .79859 L .58156 .80129 L p F P
0 g
s
.651 .758 .928 r
.67985 .5867 m .68936 .58382 L .69159 .58648 L p F P
0 g
s
.651 .758 .928 r
.68936 .58382 m .67985 .5867 L .6776 .58405 L p F P
0 g
s
.65 .757 .928 r
.39988 .58117 m .39086 .58405 L .39357 .58671 L p F P
0 g
s
.65 .757 .928 r
.39357 .58671 m .40258 .58383 L .39988 .58117 L p F P
0 g
s
.651 .757 .928 r
.5435 .58118 m .53423 .58406 L .53671 .58672 L p F P
0 g
s
.651 .757 .928 r
.53671 .58672 m .54597 .58384 L .5435 .58118 L p F P
0 g
s
.431 .149 .382 r
.59069 .79859 m .59137 .79475 L .60009 .79162 L p F P
0 g
s
.479 .245 .48 r
.60031 .78736 m .60009 .79162 L .59137 .79475 L p F P
0 g
s
.875 .7 .661 r
.43706 .75356 m .44067 .75567 L .43875 .76071 L p F P
0 g
s
.872 .708 .675 r
.44067 .75567 m .43706 .75356 L .43927 .74845 L p F P
0 g
s
.651 .758 .928 r
.84452 .5835 m .83474 .58639 L .83274 .58373 L p F P
0 g
s
.651 .758 .928 r
.83474 .58639 m .84452 .5835 L .8465 .58615 L p F P
0 g
s
.479 .453 .751 r
.61208 .71897 m .6046 .71659 L .60981 .71228 L closepath p F P
0 g
s
.493 .463 .752 r
.60959 .71167 m .60981 .71228 L .6046 .71659 L p F P
0 g
s
.493 .463 .752 r
.60258 .70955 m .60959 .71167 L p .6046 .71659 L F P
0 g
s
.65 .757 .928 r
.26799 .58089 m .2592 .58377 L .26212 .58643 L p F P
0 g
s
.65 .757 .928 r
.26212 .58643 m .2709 .58356 L .26799 .58089 L p F P
0 g
s
.651 .758 .928 r
.69159 .58648 m .70112 .5836 L .70334 .58625 L p F P
0 g
s
.651 .758 .928 r
.70112 .5836 m .69159 .58648 L .68936 .58382 L p F P
0 g
s
.65 .757 .928 r
.41162 .58095 m .40258 .58383 L .40528 .58649 L p F P
0 g
s
.65 .757 .928 r
.40528 .58649 m .41431 .58361 L .41162 .58095 L p F P
0 g
s
.651 .757 .928 r
.55526 .58095 m .54597 .58384 L .54844 .5865 L p F P
0 g
s
.651 .757 .928 r
.54844 .5865 m .55771 .58362 L .55526 .58095 L p F P
0 g
s
.649 .757 .928 r
.13609 .58048 m .12753 .58334 L .13066 .58601 L p F P
0 g
s
.649 .757 .928 r
.13066 .58601 m .13921 .58315 L .13609 .58048 L p F P
0 g
s
.482 .362 .639 r
.61439 .75987 m .61051 .76197 L .61517 .76526 L p F P
0 g
s
.498 .383 .653 r
.61331 .75437 m .61439 .75987 L .61051 .76197 L p F P
0 g
s
.487 .478 .773 r
.59565 .69693 m .5966 .69601 L p .59988 .7027 L F P
0 g
s
.483 .486 .785 r
.59565 .69693 m .59514 .69566 L .5966 .69601 L closepath p F P
0 g
s
.651 .758 .928 r
.8465 .58615 m .8563 .58326 L .85827 .58591 L p F P
0 g
s
.651 .758 .928 r
.8563 .58326 m .8465 .58615 L .84452 .5835 L p F P
0 g
s
.65 .757 .928 r
.27972 .58068 m .2709 .58356 L .27381 .58622 L p F P
0 g
s
.65 .757 .928 r
.27381 .58622 m .28261 .58334 L .27972 .58068 L p F P
0 g
s
.765 .327 .21 r
.47307 .80492 m .47213 .80464 L .46909 .80091 L p F P
0 g
s
.754 .285 .132 r
.46372 .79936 m .46909 .80091 L .47213 .80464 L p F P
0 g
s
.865 .737 .719 r
.44103 .73588 m .44101 .73585 L .441 .73586 L closepath p F P
0 g
s
.651 .758 .928 r
.70334 .58625 m .71289 .58337 L .71509 .58603 L p F P
0 g
s
.651 .758 .928 r
.71289 .58337 m .70334 .58625 L .70112 .5836 L p F P
0 g
s
.65 .757 .928 r
.42337 .58073 m .41431 .58361 L .41698 .58627 L p F P
0 g
s
.65 .757 .928 r
.41698 .58627 m .42604 .58339 L .42337 .58073 L p F P
0 g
s
.873 .749 .723 r
.441 .73586 m .44101 .73585 L .43839 .73261 L p F P
0 g
s
.651 .757 .928 r
.56703 .58073 m .55771 .58362 L .56016 .58628 L p F P
0 g
s
.651 .757 .928 r
.56016 .58628 m .56946 .5834 L .56703 .58073 L p F P
0 g
s
.882 .743 .704 r
.43783 .7336 m .441 .73586 L .43833 .74109 L p F P
0 g
s
.873 .749 .723 r
.43839 .73261 m .43783 .7336 L .441 .73586 L p F P
0 g
s
.874 .763 .736 r
.44137 .72047 m .44436 .7228 L .44101 .72822 L p F P
0 g
s
.871 .762 .739 r
.44483 .71502 m .44137 .72047 L .44436 .7228 L p F P
0 g
s
.484 .486 .783 r
.5966 .69601 m .59514 .69566 L .59272 .68955 L p F P
0 g
s
.65 .757 .928 r
.14779 .58029 m .13921 .58315 L .14233 .58582 L p F P
0 g
s
.65 .757 .928 r
.14233 .58582 m .1509 .58296 L .14779 .58029 L p F P
0 g
s
.438 0 0 r
.47832 .80596 m .48444 .8073 L p .48432 .80816 L F P
0 g
s
.438 0 0 r
.48353 .80795 m .47832 .80596 L p .48432 .80816 L F P
0 g
s
0 .512 .814 r
.47832 .80596 m .48431 .80824 L .48267 .80747 L p F P
0 g
s
0 .512 .814 r
.48267 .80747 m .47608 .80572 L .47832 .80596 L F
.47307 .80492 m .47738 .80578 L p .47608 .80572 L F P
0 g
s
0 .512 .814 r
.47738 .80578 m .47832 .80596 L p .47608 .80572 L F P
0 g
s
.247 0 0 r
.4726 .80502 m .46998 .80482 L p .47431 .80564 L F P
0 g
s
0 .512 .814 r
.4726 .80502 m .47307 .80492 L p .48267 .80747 L F P
0 g
s
0 .512 .814 r
.48267 .80747 m .48077 .80687 L .47415 .80537 L p F P
0 g
s
0 .512 .814 r
.48267 .80747 m .47415 .80537 L .47497 .8056 L F
.247 0 0 r
.48077 .80687 m .47558 .8057 L p .47431 .80564 L F P
0 g
s
0 .512 .814 r
.47415 .80537 m .4726 .80502 L p .47497 .8056 L F P
0 g
s
.247 0 0 r
.47558 .8057 m .4726 .80502 L p .47431 .80564 L F P
0 g
s
.438 0 0 r
.48431 .80824 m .48353 .80795 L p .48432 .80816 L F P
0 g
s
.651 .758 .928 r
.85827 .58591 m .86809 .58302 L .87004 .58568 L p F P
0 g
s
.651 .758 .928 r
.86809 .58302 m .85827 .58591 L .8563 .58326 L p F P
0 g
s
.472 .384 .675 r
.61205 .7487 m .61804 .74471 L p .61541 .75304 L F P
0 g
s
.472 .384 .675 r
.61541 .75304 m .61266 .75146 L .61205 .7487 L p F P
0 g
s
.473 .398 .691 r
.61205 .7487 m .61804 .74471 L .61221 .74178 L p F P
0 g
s
.65 .757 .928 r
.29145 .58046 m .28261 .58334 L .2855 .586 L p F P
0 g
s
.65 .757 .928 r
.2855 .586 m .29433 .58313 L .29145 .58046 L p F P
0 g
s
.651 .758 .928 r
.71509 .58603 m .72466 .58314 L .72684 .5858 L p F P
0 g
s
.651 .758 .928 r
.72466 .58314 m .71509 .58603 L .71289 .58337 L p F P
0 g
s
.65 .757 .928 r
.43512 .5805 m .42604 .58339 L .42869 .58605 L p F P
0 g
s
.65 .757 .928 r
.42869 .58605 m .43777 .58317 L .43512 .5805 L p F P
0 g
s
.651 .757 .928 r
.57189 .58605 m .58121 .58317 L .58362 .58583 L p F P
0 g
s
.651 .757 .928 r
.5788 .58051 m .56946 .5834 L .57189 .58605 L p F P
0 g
s
.651 .757 .928 r
.57189 .58605 m .58121 .58317 L .5788 .58051 L p F P
0 g
s
.477 .462 .762 r
.60959 .71167 m .60258 .70955 L .60732 .70534 L closepath p F P
0 g
s
.49 .47 .762 r
.6071 .70477 m .60732 .70534 L .60258 .70955 L p F P
0 g
s
.49 .47 .762 r
.59988 .7027 m .6071 .70477 L p .60258 .70955 L F P
0 g
s
.31 0 0 r
.57056 .8067 m .5691 .80789 L .55978 .80937 L p F P
0 g
s
.366 .828 .912 r
.55978 .80937 m .5691 .80789 L .56698 .80786 L p F P
0 g
s
.237 0 0 r
.55978 .80937 m .55736 .80984 L .54807 .81121 L p F P
0 g
s
.366 .828 .912 r
.55736 .80984 m .55978 .80937 L p .56698 .80786 L F P
0 g
s
.65 .757 .928 r
.1595 .58009 m .1509 .58296 L .154 .58562 L p F P
0 g
s
.65 .757 .928 r
.154 .58562 m .1626 .58276 L .1595 .58009 L p F P
0 g
s
.856 .59 .536 r
.45183 .78746 m .44736 .78564 L .44748 .78108 L p F P
0 g
s
.863 .598 .535 r
.44318 .7792 m .44748 .78108 L .44736 .78564 L p F P
0 g
s
.86 .624 .58 r
.44748 .78108 m .44318 .7792 L .4439 .77448 L p F P
0 g
s
.651 .758 .928 r
.87004 .58568 m .87988 .58278 L .88181 .58543 L p F P
0 g
s
.651 .758 .928 r
.87988 .58278 m .87004 .58568 L .86809 .58302 L p F P
0 g
s
.65 .757 .928 r
.30318 .58025 m .29433 .58313 L .2972 .58579 L p F P
0 g
s
.65 .757 .928 r
.2972 .58579 m .30604 .58291 L .30318 .58025 L p F P
0 g
s
.651 .758 .928 r
.72684 .5858 m .73643 .58292 L .73859 .58558 L p F P
0 g
s
.651 .758 .928 r
.73643 .58292 m .72684 .5858 L .72466 .58314 L p F P
0 g
s
.65 .757 .928 r
.44687 .58028 m .43777 .58317 L .44041 .58583 L p F P
0 g
s
.65 .757 .928 r
.44041 .58583 m .4495 .58295 L .44687 .58028 L p F P
0 g
s
.651 .757 .928 r
.58362 .58583 m .59297 .58295 L .59536 .58561 L p F P
0 g
s
.651 .757 .928 r
.59297 .58295 m .58362 .58583 L .58121 .58317 L p F P
0 g
s
.868 .634 .582 r
.4398 .77254 m .4439 .77448 L .44318 .7792 L p F P
0 g
s
.865 .653 .614 r
.4439 .77448 m .4398 .77254 L .44101 .76768 L p F P
0 g
s
.881 .72 .679 r
.43588 .74627 m .43927 .74845 L .43706 .75356 L p F P
0 g
s
.877 .726 .69 r
.43927 .74845 m .43588 .74627 L .43833 .74109 L p F P
0 g
s
.85 .547 .476 r
.45698 .79363 m .4524 .79185 L .45183 .78746 L p F P
0 g
s
.857 .551 .469 r
.44736 .78564 m .45183 .78746 L .4524 .79185 L p F P
0 g
s
.867 .782 .764 r
.44887 .7094 m .44517 .71453 L .44254 .71193 L p F P
0 g
s
.867 .782 .764 r
.44254 .71193 m .44611 .70698 L .44887 .7094 L p F P
0 g
s
.868 .782 .764 r
.44887 .7094 m .44611 .70698 L .45017 .70137 L p F P
0 g
s
.864 .801 .787 r
.45931 .68984 m .45684 .68731 L .45222 .69309 L p F P
0 g
s
.864 .801 .787 r
.45222 .69309 m .45468 .69562 L .45931 .68984 L p F P
0 g
s
.65 .757 .928 r
.17122 .57989 m .1626 .58276 L .16568 .58543 L p F P
0 g
s
.65 .757 .928 r
.16568 .58543 m .17429 .58256 L .17122 .57989 L p F P
0 g
s
.651 .758 .928 r
.88181 .58543 m .89167 .58253 L .89358 .58519 L p F P
0 g
s
.651 .758 .928 r
.89167 .58253 m .88181 .58543 L .87988 .58278 L p F P
0 g
s
.453 .296 .577 r
.60852 .77922 m .60809 .77436 L .61594 .77027 L p F P
0 g
s
.473 .333 .61 r
.61532 .76544 m .61594 .77027 L .60809 .77436 L p F P
0 g
s
.473 .333 .61 r
.61517 .76526 m .61532 .76544 L p .60809 .77436 L F P
0 g
s
.489 .323 .581 r
.60847 .77925 m .60852 .77922 L .60809 .77436 L p F P
0 g
s
.442 .217 .475 r
.60865 .78381 m .60031 .78736 L .60009 .79162 L p F P
0 g
s
.474 .28 .536 r
.60855 .78057 m .60865 .78381 L .60031 .78736 L p F P
0 g
s
.474 .28 .536 r
.60847 .77925 m .60855 .78057 L p .60031 .78736 L F P
0 g
s
.471 .384 .676 r
.61331 .75437 m .61266 .75146 L .61541 .75304 L closepath p F P
0 g
s
.469 .4 .697 r
.61773 .73792 m .61221 .74178 L .61804 .74471 L p F P
0 g
s
.486 .418 .706 r
.61712 .73573 m .61773 .73792 L .61221 .74178 L p F P
0 g
s
.486 .418 .706 r
.61312 .73393 m .61712 .73573 L p .61221 .74178 L F P
0 g
s
.65 .757 .928 r
.31492 .58003 m .30604 .58291 L .30889 .58557 L p F P
0 g
s
.65 .757 .928 r
.30889 .58557 m .31776 .5827 L .31492 .58003 L p F P
0 g
s
.651 .758 .928 r
.73859 .58558 m .74821 .58269 L .75035 .58535 L p F P
0 g
s
.651 .758 .928 r
.74821 .58269 m .73859 .58558 L .73643 .58292 L p F P
0 g
s
.65 .757 .928 r
.45863 .58006 m .4495 .58295 L .45212 .58561 L p F P
0 g
s
.65 .757 .928 r
.45212 .58561 m .46124 .58273 L .45863 .58006 L p F P
0 g
s
.651 .758 .928 r
.59536 .58561 m .60473 .58273 L .6071 .58539 L p F P
0 g
s
.651 .758 .928 r
.60473 .58273 m .59536 .58561 L .59297 .58295 L p F P
0 g
s
.467 .459 .766 r
.59988 .7027 m .6071 .70477 L .60463 .69823 L p F P
0 g
s
.467 .459 .766 r
.60463 .69823 m .60456 .69821 L .59988 .7027 L p F P
0 g
s
.487 .478 .773 r
.5966 .69601 m .60456 .69821 L .59988 .7027 L p F P
0 g
s
.873 .666 .619 r
.43713 .76567 m .44101 .76768 L .4398 .77254 L p F P
0 g
s
.87 .678 .64 r
.44101 .76768 m .43713 .76567 L .43875 .76071 L p F P
0 g
s
.65 .757 .928 r
.18294 .57969 m .17429 .58256 L .17735 .58523 L p F P
0 g
s
.65 .757 .928 r
.17735 .58523 m .18599 .58236 L .18294 .57969 L p F P
0 g
s
.171 0 0 r
.5691 .80789 m .57056 .8067 L .58012 .80443 L p F P
0 g
s
.368 0 .095 r
.58079 .80342 m .58012 .80443 L .57056 .8067 L p F P
0 g
s
.388 .804 .976 r
.53516 .81166 m .52881 .81181 L .52461 .81231 L p F P
0 g
s
.403 .806 .982 r
.52881 .81181 m .52345 .81188 L .52461 .81231 L closepath p F P
0 g
s
.484 .486 .783 r
.59272 .68955 m .5928 .68947 L p .5966 .69601 L F P
0 g
s
.651 .758 .928 r
.75035 .58535 m .75999 .58246 L .76211 .58512 L p F P
0 g
s
.651 .758 .928 r
.75999 .58246 m .75035 .58535 L .74821 .58269 L p F P
0 g
s
.65 .757 .928 r
.32666 .57981 m .31776 .5827 L .32059 .58536 L p F P
0 g
s
.65 .757 .928 r
.32059 .58536 m .32948 .58248 L .32666 .57981 L p F P
0 g
s
.836 .488 .396 r
.45836 .79781 m .45834 .79781 L .45698 .79363 L p F P
0 g
s
.845 .486 .373 r
.4524 .79185 m .45698 .79363 L .45834 .79781 L p F P
0 g
s
.651 .758 .928 r
.6071 .58539 m .61649 .5825 L .61884 .58516 L p F P
0 g
s
.651 .758 .928 r
.61649 .5825 m .6071 .58539 L .60473 .58273 L p F P
0 g
s
.65 .757 .928 r
.47039 .57984 m .46124 .58273 L .46384 .58539 L p F P
0 g
s
.65 .757 .928 r
.46384 .58539 m .47298 .58251 L .47039 .57984 L p F P
0 g
s
.474 .484 .788 r
.6007 .69166 m .5966 .69601 L .60456 .69821 L p F P
0 g
s
.484 .486 .783 r
.5928 .68947 m .6007 .69166 L .5966 .69601 L p F P
0 g
s
.325 .797 .922 r
.5463 .8109 m .54807 .81121 L .55736 .80984 L p F P
0 g
s
.472 .495 .801 r
.5963 .68527 m .5928 .68947 L .6007 .69166 L p F P
0 g
s
.333 .798 .932 r
.5463 .8109 m .54168 .81132 L .53634 .81207 L p F P
0 g
s
.411 .817 .98 r
.54168 .81132 m .53516 .81166 L .53634 .81207 L closepath p F P
0 g
s
.65 .757 .928 r
.19466 .57948 m .18599 .58236 L .18904 .58502 L p F P
0 g
s
.65 .757 .928 r
.18904 .58502 m .1977 .58215 L .19466 .57948 L p F P
0 g
s
.651 .758 .928 r
.76211 .58512 m .77177 .58223 L .77387 .58489 L p F P
0 g
s
.651 .758 .928 r
.77177 .58223 m .76211 .58512 L .75999 .58246 L p F P
0 g
s
.65 .757 .928 r
.3384 .57959 m .32948 .58248 L .3323 .58514 L p F P
0 g
s
.65 .757 .928 r
.3323 .58514 m .34121 .58226 L .3384 .57959 L p F P
0 g
s
.651 .758 .928 r
.61884 .58516 m .62825 .58228 L .63059 .58494 L p F P
0 g
s
.651 .758 .928 r
.62825 .58228 m .61884 .58516 L .61649 .5825 L p F P
0 g
s
.65 .757 .928 r
.48215 .57962 m .47298 .58251 L .47557 .58517 L p F P
0 g
s
.65 .757 .928 r
.47557 .58517 m .48473 .58229 L .48215 .57962 L p F P
0 g
s
.458 .36 .656 r
.61541 .75304 m .61331 .75437 L .61439 .75987 L p F P
0 g
s
.878 .761 .729 r
.44101 .72822 m .43839 .73261 L .43576 .72969 L p F P
0 g
s
.878 .761 .729 r
.43576 .72969 m .43801 .72589 L .44101 .72822 L p F P
0 g
s
.874 .763 .736 r
.44101 .72822 m .43801 .72589 L .44137 .72047 L p F P
0 g
s
.65 .757 .928 r
.20639 .57927 m .1977 .58215 L .20072 .58482 L p F P
0 g
s
.65 .757 .928 r
.20072 .58482 m .2094 .58195 L .20639 .57927 L p F P
0 g
s
.651 .758 .928 r
.77387 .58489 m .78355 .582 L .78564 .58466 L p F P
0 g
s
.651 .758 .928 r
.78355 .582 m .77387 .58489 L .77177 .58223 L p F P
0 g
s
.878 .693 .649 r
.43511 .75861 m .43875 .76071 L .43713 .76567 L p F P
0 g
s
.875 .7 .661 r
.43875 .76071 m .43511 .75861 L .43706 .75356 L p F P
0 g
s
.863 .801 .788 r
.45188 .69909 m .45468 .69562 L .45222 .69309 L p F P
0 g
s
.65 .757 .928 r
.35015 .57937 m .34121 .58226 L .344 .58492 L p F P
0 g
s
.65 .757 .928 r
.344 .58492 m .35293 .58204 L .35015 .57937 L p F P
0 g
s
.651 .758 .928 r
.63059 .58494 m .64002 .58206 L .64233 .58472 L p F P
0 g
s
.651 .758 .928 r
.64002 .58206 m .63059 .58494 L .62825 .58228 L p F P
0 g
s
.65 .757 .928 r
.49392 .5794 m .48473 .58229 L .48729 .58495 L p F P
0 g
s
.65 .757 .928 r
.48729 .58495 m .49647 .58207 L .49392 .5794 L p F P
0 g
s
.872 .781 .758 r
.44483 .71502 m .44517 .71453 L .44254 .71193 L p F P
0 g
s
.886 .739 .693 r
.43515 .73883 m .43833 .74109 L .43588 .74627 L p F P
0 g
s
.882 .743 .704 r
.43833 .74109 m .43515 .73883 L .43783 .7336 L p F P
0 g
s
.881 .778 .744 r
.44208 .7126 m .44483 .71502 L .44137 .72047 L p F P
0 g
s
.872 .781 .758 r
.44254 .71193 m .44208 .7126 L .44483 .71502 L p F P
0 g
s
.65 .757 .928 r
.21811 .57907 m .2094 .58195 L .21241 .58461 L p F P
0 g
s
.65 .757 .928 r
.21241 .58461 m .22111 .58174 L .21811 .57907 L p F P
0 g
s
.651 .758 .928 r
.78564 .58466 m .79534 .58177 L .79741 .58443 L p F P
0 g
s
.651 .758 .928 r
.79534 .58177 m .78564 .58466 L .78355 .582 L p F P
0 g
s
.65 .757 .928 r
.3619 .57915 m .35293 .58204 L .35571 .58471 L p F P
0 g
s
.65 .757 .928 r
.35571 .58471 m .36467 .58182 L .3619 .57915 L p F P
0 g
s
.651 .758 .928 r
.64233 .58472 m .65179 .58183 L .65408 .58449 L p F P
0 g
s
.651 .758 .928 r
.65179 .58183 m .64233 .58472 L .64002 .58206 L p F P
0 g
s
.65 .757 .928 r
.50569 .57917 m .49647 .58207 L .49902 .58473 L p F P
0 g
s
.65 .757 .928 r
.49902 .58473 m .50823 .58184 L .50569 .57917 L p F P
0 g
s
.65 .757 .928 r
.22985 .57886 m .22111 .58174 L .2241 .5844 L p F P
0 g
s
.65 .757 .928 r
.2241 .5844 m .23283 .58153 L .22985 .57886 L p F P
0 g
s
.651 .758 .928 r
.79741 .58443 m .80713 .58154 L .80918 .5842 L p F P
0 g
s
.651 .758 .928 r
.80713 .58154 m .79741 .58443 L .79534 .58177 L p F P
0 g
s
.65 .757 .928 r
.37365 .57893 m .36467 .58182 L .36742 .58449 L p F P
0 g
s
.65 .757 .928 r
.36742 .58449 m .3764 .58161 L .37365 .57893 L p F P
0 g
s
.754 .285 .132 r
.47213 .80464 m .46707 .80301 L .46372 .79936 L p F P
0 g
s
.731 .239 .068 r
.45836 .79781 m .46372 .79936 L .46707 .80301 L p F P
0 g
s
.651 .758 .928 r
.65408 .58449 m .66356 .58161 L .66584 .58427 L p F P
0 g
s
.651 .758 .928 r
.66356 .58161 m .65408 .58449 L .65179 .58183 L p F P
0 g
s
.651 .757 .928 r
.51746 .57895 m .50823 .58184 L .51075 .58451 L p F P
0 g
s
.651 .757 .928 r
.51075 .58451 m .51998 .58162 L .51746 .57895 L p F P
0 g
s
.863 .801 .788 r
.45222 .69309 m .44926 .69676 L .45188 .69909 L p F P
0 g
s
.87 .799 .777 r
.45188 .69909 m .45017 .70137 L .44767 .69885 L p F P
0 g
s
.87 .799 .777 r
.44767 .69885 m .44926 .69676 L .45188 .69909 L p F P
0 g
s
.403 .05 .248 r
.59069 .79859 m .59012 .80025 L .58079 .80342 L p F P
0 g
s
.272 0 .021 r
.58012 .80443 m .58079 .80342 L .59012 .80025 L p F P
0 g
s
.65 .757 .928 r
.24158 .57864 m .23283 .58153 L .2358 .5842 L p F P
0 g
s
.65 .757 .928 r
.2358 .5842 m .24454 .58132 L .24158 .57864 L p F P
0 g
s
.651 .758 .928 r
.80918 .5842 m .81893 .58131 L .82096 .58397 L p F P
0 g
s
.651 .758 .928 r
.81893 .58131 m .80918 .5842 L .80713 .58154 L p F P
0 g
s
.687 .481 .602 r
.52998 .68851 m .53193 .68845 L .53246 .69341 L p F P
0 g
s
.687 .481 .602 r
.53246 .69341 m .5279 .69356 L .52998 .68851 L p F P
0 g
s
.703 .5 .61 r
.51998 .68845 m .52998 .68851 L .5279 .69356 L p F P
0 g
s
.65 .757 .928 r
.38541 .57871 m .3764 .58161 L .37914 .58427 L p F P
0 g
s
.65 .757 .928 r
.37914 .58427 m .38814 .58139 L .38541 .57871 L p F P
0 g
s
.651 .758 .928 r
.66584 .58427 m .67533 .58138 L .6776 .58405 L p F P
0 g
s
.651 .758 .928 r
.67533 .58138 m .66584 .58427 L .66356 .58161 L p F P
0 g
s
.651 .757 .928 r
.52924 .57873 m .51998 .58162 L .52249 .58429 L p F P
0 g
s
.651 .757 .928 r
.52249 .58429 m .53174 .5814 L .52924 .57873 L p F P
0 g
s
.884 .713 .664 r
.43365 .75139 m .43706 .75356 L .43511 .75861 L p F P
0 g
s
.881 .72 .679 r
.43706 .75356 m .43365 .75139 L .43588 .74627 L p F P
0 g
s
.703 .5 .61 r
.5279 .69356 m .52061 .69352 L .51998 .68845 L p F P
0 g
s
.739 .525 .604 r
.51936 .68839 m .51998 .68845 L .52061 .69352 L p F P
0 g
s
.622 .434 .606 r
.53246 .69341 m .53193 .68845 L .54203 .68659 L p F P
0 g
s
.739 .525 .604 r
.52061 .69352 m .51788 .69326 L .51936 .68839 L p F P
0 g
s
.768 .543 .593 r
.51198 .68732 m .51936 .68839 L .51788 .69326 L p F P
0 g
s
.47 .413 .712 r
.61712 .73573 m .61312 .73393 L .61603 .73179 L closepath p F P
0 g
s
.485 .427 .717 r
.61459 .72697 m .61603 .73179 L .61312 .73393 L p F P
0 g
s
.485 .427 .717 r
.61306 .72633 m .61459 .72697 L p .61312 .73393 L F P
0 g
s
.876 .797 .769 r
.45017 .70137 m .44767 .69885 L .44361 .70448 L p F P
0 g
s
.876 .797 .769 r
.44361 .70448 m .44611 .70698 L .45017 .70137 L p F P
0 g
s
.651 .758 .928 r
.82096 .58397 m .83072 .58107 L .83274 .58373 L p F P
0 g
s
.651 .758 .928 r
.83072 .58107 m .82096 .58397 L .81893 .58131 L p F P
0 g
s
.65 .757 .928 r
.25332 .57843 m .24454 .58132 L .2475 .58398 L p F P
0 g
s
.65 .757 .928 r
.2475 .58398 m .25626 .58111 L .25332 .57843 L p F P
0 g
s
.651 .758 .928 r
.6776 .58405 m .68711 .58116 L .68936 .58382 L p F P
0 g
s
.651 .758 .928 r
.68711 .58116 m .6776 .58405 L .67533 .58138 L p F P
0 g
s
.65 .757 .928 r
.39717 .57849 m .38814 .58139 L .39086 .58405 L p F P
0 g
s
.65 .757 .928 r
.39086 .58405 m .39988 .58117 L .39717 .57849 L p F P
0 g
s
.651 .757 .928 r
.54101 .5785 m .53174 .5814 L .53423 .58406 L p F P
0 g
s
.651 .757 .928 r
.53423 .58406 m .5435 .58118 L .54101 .5785 L p F P
0 g
s
.446 .337 .637 r
.61529 .76519 m .61439 .75987 L .61989 .75637 L p F P
0 g
s
.458 .36 .656 r
.61439 .75987 m .61989 .75637 L .61541 .75304 L p F P
0 g
s
.482 .362 .639 r
.61517 .76526 m .61529 .76519 L .61439 .75987 L p F P
0 g
s
.882 .761 .724 r
.43783 .7336 m .43839 .73261 L .43576 .72969 L p F P
0 g
s
.47 .818 .998 r
.5221 .81124 m .52345 .81188 L .52881 .81181 L p F P
0 g
s
.428 .798 .994 r
.5221 .81124 m .51846 .81163 L .52345 .81188 L closepath p F P
0 g
s
.651 .758 .928 r
.83274 .58373 m .84252 .58084 L .84452 .5835 L p F P
0 g
s
.651 .758 .928 r
.84252 .58084 m .83274 .58373 L .83072 .58107 L p F P
0 g
s
.65 .757 .928 r
.26506 .57822 m .25626 .58111 L .2592 .58377 L p F P
0 g
s
.65 .757 .928 r
.2592 .58377 m .26799 .58089 L .26506 .57822 L p F P
0 g
s
.462 .819 .996 r
.53385 .81107 m .52881 .81181 L .53516 .81166 L closepath p F P
0 g
s
.47 .818 .998 r
.52881 .81181 m .53385 .81107 L p .5221 .81124 L F P
0 g
s
.466 .274 .536 r
.60855 .78057 m .60847 .77925 L .60852 .77922 L closepath p F P
0 g
s
.651 .758 .928 r
.68936 .58382 m .6989 .58093 L .70112 .5836 L p F P
0 g
s
.651 .758 .928 r
.6989 .58093 m .68936 .58382 L .68711 .58116 L p F P
0 g
s
.65 .757 .928 r
.40893 .57827 m .39988 .58117 L .40258 .58383 L p F P
0 g
s
.65 .757 .928 r
.40258 .58383 m .41162 .58095 L .40893 .57827 L p F P
0 g
s
.651 .757 .928 r
.5528 .57828 m .5435 .58118 L .54597 .58384 L p F P
0 g
s
.651 .757 .928 r
.54597 .58384 m .55526 .58095 L .5528 .57828 L p F P
0 g
s
.433 .249 .53 r
.60852 .77922 m .61636 .77513 L p .60873 .78377 L F P
0 g
s
.433 .249 .53 r
.60873 .78377 m .60855 .78057 L .60852 .77922 L p F P
0 g
s
.453 .296 .577 r
.61594 .77027 m .61636 .77513 L .60852 .77922 L p F P
0 g
s
.863 .598 .535 r
.44736 .78564 m .44305 .78377 L .44318 .7792 L p F P
0 g
s
.871 .606 .535 r
.43905 .77727 m .44318 .7792 L .44305 .78377 L p F P
0 g
s
.868 .634 .582 r
.44318 .7792 m .43905 .77727 L .4398 .77254 L p F P
0 g
s
.891 .756 .706 r
.43486 .73127 m .43783 .7336 L .43515 .73883 L p F P
0 g
s
.882 .761 .724 r
.43576 .72969 m .43486 .73127 L .43783 .7336 L p F P
0 g
s
.649 .757 .928 r
.13295 .5778 m .12438 .58067 L .12753 .58334 L p F P
0 g
s
.649 .757 .928 r
.12753 .58334 m .13609 .58048 L .13295 .5778 L p F P
0 g
s
.857 .551 .469 r
.4524 .79185 m .44796 .79002 L .44736 .78564 L p F P
0 g
s
.864 .555 .463 r
.44305 .78377 m .44736 .78564 L .44796 .79002 L p F P
0 g
s
.651 .758 .928 r
.84452 .5835 m .85433 .5806 L .8563 .58326 L p F P
0 g
s
.651 .758 .928 r
.85433 .5806 m .84452 .5835 L .84252 .58084 L p F P
0 g
s
.479 .827 .997 r
.53385 .81107 m .53516 .81166 L .54168 .81132 L p F P
0 g
s
.453 .361 .661 r
.62057 .74961 m .61541 .75304 L .61989 .75637 L p F P
0 g
s
.472 .384 .675 r
.61968 .74576 m .62057 .74961 L .61541 .75304 L p F P
0 g
s
.472 .384 .675 r
.61804 .74471 m .61968 .74576 L p .61541 .75304 L F P
0 g
s
.883 .777 .74 r
.43861 .71806 m .44137 .72047 L .43801 .72589 L p F P
0 g
s
.881 .778 .744 r
.44137 .72047 m .43861 .71806 L .44208 .7126 L p F P
0 g
s
.65 .757 .928 r
.27681 .578 m .26799 .58089 L .2709 .58356 L p F P
0 g
s
.65 .757 .928 r
.2709 .58356 m .27972 .58068 L .27681 .578 L p F P
0 g
s
.393 .796 .984 r
.51846 .81163 m .5221 .81124 L p .51035 .81118 L F P
0 g
s
.393 .796 .984 r
.51035 .81118 m .51102 .81144 L .51846 .81163 L p F P
0 g
s
.651 .758 .928 r
.70112 .5836 m .71068 .58071 L .71289 .58337 L p F P
0 g
s
.651 .758 .928 r
.71068 .58071 m .70112 .5836 L .6989 .58093 L p F P
0 g
s
.879 .646 .582 r
.43779 .77151 m .4398 .77254 L .43905 .77727 L p F P
0 g
s
.873 .666 .619 r
.43657 .76797 m .43713 .76567 L p .4398 .77254 L F P
0 g
s
.873 .666 .619 r
.4398 .77254 m .43779 .77151 L .43657 .76797 L p F P
0 g
s
.359 .017 .241 r
.59012 .80025 m .59069 .79859 L .59946 .79549 L p F P
0 g
s
.431 .149 .382 r
.60009 .79162 m .59946 .79549 L .59069 .79859 L p F P
0 g
s
.65 .757 .928 r
.42069 .57805 m .41162 .58095 L .41431 .58361 L p F P
0 g
s
.65 .757 .928 r
.41431 .58361 m .42337 .58073 L .42069 .57805 L p F P
0 g
s
.651 .757 .928 r
.56458 .57806 m .55526 .58095 L .55771 .58362 L p F P
0 g
s
.651 .757 .928 r
.55771 .58362 m .56703 .58073 L .56458 .57806 L p F P
0 g
s
.649 .757 .928 r
.14467 .5776 m .13609 .58048 L .13921 .58315 L p F P
0 g
s
.649 .757 .928 r
.13921 .58315 m .14779 .58029 L .14467 .5776 L p F P
0 g
s
.651 .758 .928 r
.8563 .58326 m .86613 .58036 L .86809 .58302 L p F P
0 g
s
.651 .758 .928 r
.86613 .58036 m .8563 .58326 L .85433 .5806 L p F P
0 g
s
.297 .743 .962 r
.51035 .81118 m .50899 .8112 L .51102 .81144 L closepath p F P
0 g
s
.65 .757 .928 r
.28856 .57779 m .27972 .58068 L .28261 .58334 L p F P
0 g
s
.65 .757 .928 r
.28261 .58334 m .29145 .58046 L .28856 .57779 L p F P
0 g
s
.689 .175 .005 r
.4726 .80502 m .47213 .80464 L .47307 .80492 L closepath p F P
0 g
s
.651 .758 .928 r
.71289 .58337 m .72247 .58048 L .72466 .58314 L p F P
0 g
s
.651 .758 .928 r
.72247 .58048 m .71289 .58337 L .71068 .58071 L p F P
0 g
s
.65 .757 .928 r
.43246 .57783 m .42337 .58073 L .42604 .58339 L p F P
0 g
s
.65 .757 .928 r
.42604 .58339 m .43512 .5805 L .43246 .57783 L p F P
0 g
s
.651 .757 .928 r
.57637 .57783 m .56703 .58073 L .56946 .5834 L p F P
0 g
s
.651 .757 .928 r
.56946 .5834 m .5788 .58051 L .57637 .57783 L p F P
0 g
s
.89 .734 .681 r
.43269 .74402 m .43588 .74627 L .43365 .75139 L p F P
0 g
s
.886 .739 .693 r
.43588 .74627 m .43269 .74402 L .43515 .73883 L p F P
0 g
s
.845 .486 .373 r
.45834 .79781 m .45384 .796 L .4524 .79185 L p F P
0 g
s
.85 .482 .354 r
.44796 .79002 m .4524 .79185 L .45384 .796 L p F P
0 g
s
.65 .757 .928 r
.1564 .57741 m .14779 .58029 L .1509 .58296 L p F P
0 g
s
.65 .757 .928 r
.1509 .58296 m .1595 .58009 L .1564 .57741 L p F P
0 g
s
.421 .827 .977 r
.54561 .81068 m .54168 .81132 L .5463 .8109 L closepath p F P
0 g
s
.479 .827 .997 r
.54168 .81132 m .54561 .81068 L p .53385 .81107 L F P
0 g
s
.651 .758 .928 r
.86809 .58302 m .87794 .58012 L .87988 .58278 L p F P
0 g
s
.651 .758 .928 r
.87794 .58012 m .86809 .58302 L .86613 .58036 L p F P
0 g
s
.886 .676 .613 r
.43657 .76797 m .43713 .76567 L .43532 .76464 L closepath p F P
0 g
s
.878 .693 .649 r
.43401 .76199 m .43511 .75861 L p .43713 .76567 L F P
0 g
s
.878 .693 .649 r
.43713 .76567 m .43532 .76464 L .43401 .76199 L p F P
0 g
s
.65 .757 .928 r
.30031 .57757 m .29145 .58046 L .29433 .58313 L p F P
0 g
s
.65 .757 .928 r
.29433 .58313 m .30318 .58025 L .30031 .57757 L p F P
0 g
s
.651 .758 .928 r
.72466 .58314 m .73426 .58025 L .73643 .58292 L p F P
0 g
s
.651 .758 .928 r
.73426 .58025 m .72466 .58314 L .72247 .58048 L p F P
0 g
s
.434 .25 .531 r
.60865 .78381 m .60855 .78057 L .60873 .78377 L closepath p F P
0 g
s
.65 .757 .928 r
.44423 .57761 m .43512 .5805 L .43777 .58317 L p F P
0 g
s
.65 .757 .928 r
.43777 .58317 m .44687 .58028 L .44423 .57761 L p F P
0 g
s
.876 .797 .769 r
.44254 .71193 m .44611 .70698 L .44361 .70448 L p F P
0 g
s
0 .56 .73 r
.49861 .81056 m .50147 .81026 L .50899 .8112 L p F P
0 g
s
.428 .798 .994 r
.50147 .81026 m .49753 .81005 L .49861 .81056 L closepath p F P
0 g
s
.651 .757 .928 r
.58121 .58317 m .59057 .58028 L .59297 .58295 L p F P
0 g
s
.651 .757 .928 r
.58816 .57761 m .5788 .58051 L .58121 .58317 L p F P
0 g
s
.651 .757 .928 r
.58121 .58317 m .59057 .58028 L .58816 .57761 L p F P
0 g
s
.518 .794 .996 r
.50899 .8112 m .51035 .81118 L .50782 .80937 L p F P
0 g
s
.518 .794 .996 r
.50782 .80937 m .50147 .81026 L .50899 .8112 L p F P
0 g
s
.39 .118 .376 r
.60607 .78909 m .60009 .79162 L .59946 .79549 L p F P
0 g
s
.442 .217 .475 r
.60864 .78406 m .60865 .78381 L p .60009 .79162 L F P
0 g
s
.442 .217 .475 r
.60009 .79162 m .60607 .78909 L .60864 .78406 L p F P
0 g
s
.589 .019 0 r
.47213 .80464 m .4726 .80502 L .46998 .80482 L p F P
0 g
s
.589 .019 0 r
.46998 .80482 m .46707 .80301 L .47213 .80464 L p F P
0 g
s
.768 .543 .593 r
.51788 .69326 m .51094 .69206 L .51198 .68732 L p F P
0 g
s
.824 .593 .589 r
.50662 .68565 m .51198 .68732 L .51094 .69206 L p F P
0 g
s
.65 .757 .928 r
.16814 .57721 m .1595 .58009 L .1626 .58276 L p F P
0 g
s
.65 .757 .928 r
.1626 .58276 m .17122 .57989 L .16814 .57721 L p F P
0 g
s
.651 .758 .928 r
.87988 .58278 m .88975 .57987 L .89167 .58253 L p F P
0 g
s
.651 .758 .928 r
.88975 .57987 m .87988 .58278 L .87794 .58012 L p F P
0 g
s
.873 .818 .792 r
.45684 .68731 m .45467 .68468 L .45005 .69046 L p F P
0 g
s
.873 .818 .792 r
.45005 .69046 m .45222 .69309 L .45684 .68731 L p F P
0 g
s
.65 .757 .928 r
.31207 .57735 m .30318 .58025 L .30604 .58291 L p F P
0 g
s
.65 .757 .928 r
.30604 .58291 m .31492 .58003 L .31207 .57735 L p F P
0 g
s
.651 .758 .928 r
.73643 .58292 m .74606 .58002 L .74821 .58269 L p F P
0 g
s
.651 .758 .928 r
.74606 .58002 m .73643 .58292 L .73426 .58025 L p F P
0 g
s
.469 .423 .724 r
.61459 .72697 m .61306 .72633 L .61415 .72549 L closepath p F P
0 g
s
.479 .441 .738 r
.61306 .72633 m .61415 .72549 L .61209 .719 L p F P
0 g
s
.65 .757 .928 r
.45601 .57739 m .44687 .58028 L .4495 .58295 L p F P
0 g
s
.65 .757 .928 r
.4495 .58295 m .45863 .58006 L .45601 .57739 L p F P
0 g
s
.651 .758 .928 r
.59297 .58295 m .60234 .58006 L .60473 .58273 L p F P
0 g
s
.651 .757 .928 r
.60234 .58006 m .59297 .58295 L .59057 .58028 L p F P
0 g
s
.058 0 0 r
.57844 .80569 m .58012 .80443 L .58924 .8017 L p F P
0 g
s
.272 0 .021 r
.59012 .80025 m .58924 .8017 L .58012 .80443 L p F P
0 g
s
.171 0 0 r
.58012 .80443 m .57844 .80569 L .5691 .80789 L p F P
0 g
s
.65 .757 .928 r
.17987 .577 m .17122 .57989 L .17429 .58256 L p F P
0 g
s
.65 .757 .928 r
.17429 .58256 m .18294 .57969 L .17987 .577 L p F P
0 g
s
.446 .839 .981 r
.54561 .81068 m .5463 .8109 L .55688 .80961 L p F P
0 g
s
.325 .797 .922 r
.55736 .80984 m .55688 .80961 L .5463 .8109 L p F P
0 g
s
.463 .325 .608 r
.61532 .76544 m .61517 .76526 L .61529 .76519 L closepath p F P
0 g
s
.688 .485 .607 r
.5279 .69356 m .53246 .69341 L .53305 .69843 L p F P
0 g
s
.688 .485 .607 r
.53305 .69843 m .52563 .69867 L .5279 .69356 L p F P
0 g
s
.704 .503 .614 r
.52061 .69352 m .5279 .69356 L .52563 .69867 L p F P
0 g
s
.651 .758 .928 r
.74821 .58269 m .75785 .5798 L .75999 .58246 L p F P
0 g
s
.651 .758 .928 r
.75785 .5798 m .74821 .58269 L .74606 .58002 L p F P
0 g
s
.65 .757 .928 r
.32382 .57713 m .31492 .58003 L .31776 .5827 L p F P
0 g
s
.65 .757 .928 r
.31776 .5827 m .32666 .57981 L .32382 .57713 L p F P
0 g
s
.731 .239 .068 r
.45835 .79782 m .45836 .79781 L p .46707 .80301 L F P
0 g
s
.819 .421 .296 r
.45835 .79782 m .45834 .79781 L .45836 .79781 L closepath p F P
0 g
s
.651 .758 .928 r
.60473 .58273 m .61412 .57984 L .61649 .5825 L p F P
0 g
s
.651 .758 .928 r
.61412 .57984 m .60473 .58273 L .60234 .58006 L p F P
0 g
s
.65 .757 .928 r
.46779 .57716 m .45863 .58006 L .46124 .58273 L p F P
0 g
s
.65 .757 .928 r
.46124 .58273 m .47039 .57984 L .46779 .57716 L p F P
0 g
s
.813 .381 .217 r
.45834 .79781 m .45835 .79782 L .45567 .79887 L p F P
0 g
s
.813 .381 .217 r
.45567 .79887 m .45384 .796 L .45834 .79781 L p F P
0 g
s
.731 .239 .068 r
.46707 .80301 m .46201 .80137 L .45835 .79782 L p F P
0 g
s
.73 .251 .11 r
.46201 .80137 m .45835 .79782 L .45567 .79887 L p F P
0 g
s
.704 .503 .614 r
.52563 .69867 m .52129 .69864 L .52061 .69352 L p F P
0 g
s
.74 .529 .607 r
.51788 .69326 m .52061 .69352 L .52129 .69864 L p F P
0 g
s
.434 .304 .604 r
.61529 .76519 m .62264 .76053 L p .61785 .76911 L F P
0 g
s
.434 .304 .604 r
.61785 .76911 m .61532 .76544 L .61529 .76519 L p F P
0 g
s
.446 .337 .637 r
.62234 .75881 m .62264 .76053 L .61529 .76519 L p F P
0 g
s
.446 .337 .637 r
.61989 .75637 m .62234 .75881 L p .61529 .76519 L F P
0 g
s
.892 .701 .638 r
.43511 .75861 m .43401 .76199 L .43142 .75721 L p F P
0 g
s
.892 .701 .638 r
.43142 .75721 m .43166 .75645 L .43511 .75861 L p F P
0 g
s
.884 .713 .664 r
.43511 .75861 m .43166 .75645 L .43365 .75139 L p F P
0 g
s
.433 .304 .604 r
.61594 .77027 m .61532 .76544 L .61785 .76911 L closepath p F P
0 g
s
.62 .436 .611 r
.53305 .69843 m .53246 .69341 L .5425 .69149 L p F P
0 g
s
.622 .434 .606 r
.54203 .68659 m .5425 .69149 L .53246 .69341 L p F P
0 g
s
.65 .757 .928 r
.19161 .5768 m .18294 .57969 L .18599 .58236 L p F P
0 g
s
.65 .757 .928 r
.18599 .58236 m .19466 .57948 L .19161 .5768 L p F P
0 g
s
.335 .815 .871 r
.56698 .80786 m .5691 .80789 L .57844 .80569 L p F P
0 g
s
.393 .796 .984 r
.5221 .81124 m .51959 .80917 L .51035 .81118 L p F P
0 g
s
.663 .74 .907 r
.51959 .80917 m .51035 .81118 L .50782 .80937 L p F P
0 g
s
.651 .758 .928 r
.75999 .58246 m .76966 .57957 L .77177 .58223 L p F P
0 g
s
.651 .758 .928 r
.76966 .57957 m .75999 .58246 L .75785 .5798 L p F P
0 g
s
.65 .757 .928 r
.33559 .57691 m .32666 .57981 L .32948 .58248 L p F P
0 g
s
.65 .757 .928 r
.32948 .58248 m .3384 .57959 L .33559 .57691 L p F P
0 g
s
.651 .758 .928 r
.61649 .5825 m .62591 .57961 L .62825 .58228 L p F P
0 g
s
.651 .758 .928 r
.62591 .57961 m .61649 .5825 L .61412 .57984 L p F P
0 g
s
.65 .757 .928 r
.47957 .57694 m .47039 .57984 L .47298 .58251 L p F P
0 g
s
.65 .757 .928 r
.47298 .58251 m .48215 .57962 L .47957 .57694 L p F P
0 g
s
.887 .775 .732 r
.43801 .72589 m .43576 .72969 L .43311 .72708 L p F P
0 g
s
.887 .775 .732 r
.43311 .72708 m .43524 .72349 L .43801 .72589 L p F P
0 g
s
.883 .777 .74 r
.43801 .72589 m .43524 .72349 L .43861 .71806 L p F P
0 g
s
.879 .646 .582 r
.43905 .77727 m .43901 .77725 L .43779 .77151 L p F P
0 g
s
.893 .653 .57 r
.43599 .7705 m .43779 .77151 L .43901 .77725 L p F P
0 g
s
.886 .671 .606 r
.43779 .77151 m .43657 .76797 L .43599 .7705 L closepath p F P
0 g
s
.74 .529 .607 r
.52129 .69864 m .51633 .69816 L .51788 .69326 L p F P
0 g
s
.778 .558 .601 r
.51094 .69206 m .51788 .69326 L .51633 .69816 L p F P
0 g
s
.895 .752 .696 r
.43218 .73651 m .43515 .73883 L .43269 .74402 L p F P
0 g
s
.891 .756 .706 r
.43515 .73883 m .43218 .73651 L .43486 .73127 L p F P
0 g
s
.65 .757 .928 r
.20336 .57659 m .19466 .57948 L .1977 .58215 L p F P
0 g
s
.65 .757 .928 r
.1977 .58215 m .20639 .57927 L .20336 .57659 L p F P
0 g
s
.892 .678 .606 r
.43599 .7705 m .43657 .76797 L .43532 .76464 L p F P
0 g
s
.876 .797 .769 r
.44361 .70448 m .43989 .70962 L .44254 .71193 L p F P
0 g
s
.88 .796 .763 r
.44254 .71193 m .44208 .7126 L .43955 .7101 L p F P
0 g
s
.88 .796 .763 r
.43955 .7101 m .43989 .70962 L .44254 .71193 L p F P
0 g
s
.651 .758 .928 r
.77177 .58223 m .78146 .57934 L .78355 .582 L p F P
0 g
s
.651 .758 .928 r
.78146 .57934 m .77177 .58223 L .76966 .57957 L p F P
0 g
s
.65 .757 .928 r
.34735 .57669 m .3384 .57959 L .34121 .58226 L p F P
0 g
s
.65 .757 .928 r
.34121 .58226 m .35015 .57937 L .34735 .57669 L p F P
0 g
s
.651 .758 .928 r
.62825 .58228 m .63769 .57939 L .64002 .58206 L p F P
0 g
s
.651 .758 .928 r
.63769 .57939 m .62825 .58228 L .62591 .57961 L p F P
0 g
s
.65 .757 .928 r
.49135 .57672 m .48215 .57962 L .48473 .58229 L p F P
0 g
s
.65 .757 .928 r
.48473 .58229 m .49392 .5794 L .49135 .57672 L p F P
0 g
s
.515 .35 .595 r
.5425 .69149 m .54203 .68659 L .55049 .68303 L p F P
0 g
s
.871 .818 .794 r
.44926 .69676 m .45222 .69309 L .45005 .69046 L p F P
0 g
s
.47 .818 .998 r
.53385 .81107 m .53136 .80895 L .5221 .81124 L p F P
0 g
s
.668 .732 .897 r
.53136 .80895 m .5221 .81124 L .51959 .80917 L p F P
0 g
s
.889 .793 .748 r
.44208 .7126 m .43955 .7101 L .43608 .71557 L p F P
0 g
s
.889 .793 .748 r
.43608 .71557 m .43861 .71806 L .44208 .7126 L p F P
0 g
s
.65 .757 .928 r
.21511 .57638 m .20639 .57927 L .2094 .58195 L p F P
0 g
s
.65 .757 .928 r
.2094 .58195 m .21811 .57907 L .21511 .57638 L p F P
0 g
s
.651 .758 .928 r
.78355 .582 m .79327 .5791 L .79534 .58177 L p F P
0 g
s
.651 .758 .928 r
.79327 .5791 m .78355 .582 L .78146 .57934 L p F P
0 g
s
.65 .757 .928 r
.35912 .57647 m .35015 .57937 L .35293 .58204 L p F P
0 g
s
.65 .757 .928 r
.35293 .58204 m .3619 .57915 L .35912 .57647 L p F P
0 g
s
.892 .678 .606 r
.43532 .76464 m .43354 .76356 L p .43599 .7705 L F P
0 g
s
.889 .695 .634 r
.43532 .76464 m .43401 .76199 L .43354 .76356 L closepath p F P
0 g
s
.439 .416 .737 r
.61211 .71898 m .61209 .719 L .61415 .72549 L p F P
0 g
s
.454 .44 .753 r
.61209 .719 m .61208 .71897 L .61211 .71898 L closepath p F P
0 g
s
.456 .439 .751 r
.61211 .71898 m .61208 .71897 L .60981 .71228 L p F P
0 g
s
.651 .758 .928 r
.64002 .58206 m .64948 .57916 L .65179 .58183 L p F P
0 g
s
.651 .758 .928 r
.64948 .57916 m .64002 .58206 L .63769 .57939 L p F P
0 g
s
.65 .757 .928 r
.50314 .57649 m .49392 .5794 L .49647 .58207 L p F P
0 g
s
.65 .757 .928 r
.49647 .58207 m .50569 .57917 L .50314 .57649 L p F P
0 g
s
.48 .805 1 r
.50147 .81026 m .50782 .80937 L p .49605 .80927 L F P
0 g
s
.48 .805 1 r
.49605 .80927 m .49753 .81005 L .50147 .81026 L p F P
0 g
s
.439 .416 .737 r
.61415 .72549 m .61801 .72184 L .61211 .71898 L p F P
0 g
s
.439 .428 .75 r
.61634 .71466 m .61211 .71898 L .61801 .72184 L p F P
0 g
s
.456 .439 .751 r
.61018 .71189 m .61634 .71466 L .61211 .71898 L p F P
0 g
s
.456 .439 .751 r
.60981 .71228 m .61018 .71189 L p .61211 .71898 L F P
0 g
s
.443 .407 .723 r
.61415 .72549 m .61801 .72184 L p .61895 .72922 L F P
0 g
s
.443 .407 .723 r
.61895 .72922 m .61459 .72697 L .61415 .72549 L p F P
0 g
s
.479 .827 .997 r
.54561 .81068 m .54313 .8088 L .53385 .81107 L p F P
0 g
s
.662 .738 .906 r
.54313 .8088 m .53385 .81107 L .53136 .80895 L p F P
0 g
s
.442 .407 .725 r
.61603 .73179 m .61459 .72697 L .61895 .72922 L closepath p F P
0 g
s
.366 .828 .912 r
.56698 .80786 m .56186 .80887 L .55736 .80984 L p F P
0 g
s
.528 .848 .998 r
.56186 .80887 m .55688 .80961 L .55736 .80984 L closepath p F P
0 g
s
.65 .757 .928 r
.22686 .57617 m .21811 .57907 L .22111 .58174 L p F P
0 g
s
.65 .757 .928 r
.22111 .58174 m .22985 .57886 L .22686 .57617 L p F P
0 g
s
.651 .758 .928 r
.79534 .58177 m .80508 .57887 L .80713 .58154 L p F P
0 g
s
.651 .758 .928 r
.80508 .57887 m .79534 .58177 L .79327 .5791 L p F P
0 g
s
.446 .839 .981 r
.55688 .80961 m .55491 .80854 L .54561 .81068 L p F P
0 g
s
.646 .765 .936 r
.55491 .80854 m .54561 .81068 L .54313 .8088 L p F P
0 g
s
.359 .017 .241 r
.59946 .79549 m .59945 .7955 L .59012 .80025 L p F P
0 g
s
.191 0 .004 r
.58924 .8017 m .59012 .80025 L .59945 .7955 L p F P
0 g
s
.451 .448 .764 r
.60981 .71228 m .60959 .71167 L .61018 .71189 L closepath p F P
0 g
s
.65 .757 .928 r
.37089 .57625 m .3619 .57915 L .36467 .58182 L p F P
0 g
s
.65 .757 .928 r
.36467 .58182 m .37365 .57893 L .37089 .57625 L p F P
0 g
s
.651 .758 .928 r
.65179 .58183 m .66127 .57894 L .66356 .58161 L p F P
0 g
s
.651 .758 .928 r
.66127 .57894 m .65179 .58183 L .64948 .57916 L p F P
0 g
s
.891 .731 .676 r
.43044 .74915 m .43365 .75139 L .43166 .75645 L p F P
0 g
s
.89 .734 .681 r
.43365 .75139 m .43044 .74915 L .43269 .74402 L p F P
0 g
s
.651 .757 .928 r
.51493 .57627 m .50569 .57917 L .50823 .58184 L p F P
0 g
s
.651 .757 .928 r
.50823 .58184 m .51746 .57895 L .51493 .57627 L p F P
0 g
s
.346 .74 .985 r
.49605 .80927 m .49404 .80927 L .49753 .81005 L closepath p F P
0 g
s
.453 .447 .762 r
.61018 .71189 m .60959 .71167 L .60732 .70534 L p F P
0 g
s
.445 .397 .711 r
.61603 .73179 m .61895 .72922 L p .61908 .73681 L F P
0 g
s
.445 .397 .711 r
.61908 .73681 m .61712 .73573 L .61603 .73179 L p F P
0 g
s
.871 .818 .794 r
.45005 .69046 m .44661 .6947 L .44926 .69676 L p F P
0 g
s
.877 .815 .784 r
.44926 .69676 m .44767 .69885 L .44543 .69625 L p F P
0 g
s
.877 .815 .784 r
.44543 .69625 m .44661 .6947 L .44926 .69676 L p F P
0 g
s
.65 .757 .928 r
.23861 .57596 m .22985 .57886 L .23283 .58153 L p F P
0 g
s
.65 .757 .928 r
.23283 .58153 m .24158 .57864 L .23861 .57596 L p F P
0 g
s
.456 .377 .678 r
.61968 .74576 m .61804 .74471 L .61925 .74386 L closepath p F P
0 g
s
.469 .4 .697 r
.61804 .74471 m .61925 .74386 L .61773 .73792 L p F P
0 g
s
.651 .758 .928 r
.80713 .58154 m .81689 .57864 L .81893 .58131 L p F P
0 g
s
.651 .758 .928 r
.81689 .57864 m .80713 .58154 L .80508 .57887 L p F P
0 g
s
.402 .19 .473 r
.60864 .78406 m .60873 .78377 L .60865 .78381 L closepath p F P
0 g
s
.65 .757 .928 r
.38267 .57603 m .37365 .57893 L .3764 .58161 L p F P
0 g
s
.65 .757 .928 r
.3764 .58161 m .38541 .57871 L .38267 .57603 L p F P
0 g
s
.651 .758 .928 r
.66356 .58161 m .67307 .57871 L .67533 .58138 L p F P
0 g
s
.651 .758 .928 r
.67307 .57871 m .66356 .58161 L .66127 .57894 L p F P
0 g
s
.651 .757 .928 r
.52673 .57605 m .51746 .57895 L .51998 .58162 L p F P
0 g
s
.651 .757 .928 r
.51998 .58162 m .52924 .57873 L .52673 .57605 L p F P
0 g
s
.871 .606 .535 r
.439 .77861 m .43905 .77727 L p .44305 .78377 L F P
0 g
s
.884 .618 .53 r
.439 .77861 m .43905 .77727 L .43901 .77725 L closepath p F P
0 g
s
.891 .774 .726 r
.43486 .73127 m .43576 .72969 L .43311 .72708 L p F P
0 g
s
.864 .555 .463 r
.44796 .79002 m .44365 .78815 L .44305 .78377 L p F P
0 g
s
.872 .56 .457 r
.43898 .78189 m .44305 .78377 L .44365 .78815 L p F P
0 g
s
.871 .606 .535 r
.44305 .78377 m .43898 .78189 L .439 .77861 L p F P
0 g
s
.892 .625 .527 r
.43901 .77725 m .43536 .77521 L p .43889 .78185 L F P
0 g
s
.892 .625 .527 r
.43889 .78185 m .439 .77861 L .43901 .77725 L p F P
0 g
s
.893 .653 .57 r
.43901 .77725 m .43536 .77521 L .43599 .7705 L p F P
0 g
s
.344 .134 .445 r
.60873 .78377 m .6165 .77972 L p .60842 .78805 L F P
0 g
s
.344 .134 .445 r
.60842 .78805 m .60864 .78406 L .60873 .78377 L p F P
0 g
s
.433 .249 .53 r
.61636 .77513 m .6165 .77972 L .60873 .78377 L p F P
0 g
s
.443 .398 .713 r
.61773 .73792 m .61712 .73573 L .61908 .73681 L closepath p F P
0 g
s
.427 .2 .465 r
.60607 .78909 m .60842 .78805 L .60864 .78406 L closepath p F P
0 g
s
.651 .758 .928 r
.81893 .58131 m .8287 .5784 L .83072 .58107 L p F P
0 g
s
.651 .758 .928 r
.8287 .5784 m .81893 .58131 L .81689 .57864 L p F P
0 g
s
.65 .757 .928 r
.25037 .57575 m .24158 .57864 L .24454 .58132 L p F P
0 g
s
.65 .757 .928 r
.24454 .58132 m .25332 .57843 L .25037 .57575 L p F P
0 g
s
.884 .814 .774 r
.44767 .69885 m .44543 .69625 L .44137 .70188 L p F P
0 g
s
.884 .814 .774 r
.44137 .70188 m .44361 .70448 L .44767 .69885 L p F P
0 g
s
.896 .704 .634 r
.43354 .76356 m .43401 .76199 L .43142 .75721 L p F P
0 g
s
.438 .439 .763 r
.61399 .70768 m .61018 .71189 L .61634 .71466 L p F P
0 g
s
.453 .447 .762 r
.60765 .70497 m .61399 .70768 L .61018 .71189 L p F P
0 g
s
.453 .447 .762 r
.60732 .70534 m .60765 .70497 L p .61018 .71189 L F P
0 g
s
.651 .758 .928 r
.67533 .58138 m .68486 .57849 L .68711 .58116 L p F P
0 g
s
.651 .758 .928 r
.68486 .57849 m .67533 .58138 L .67307 .57871 L p F P
0 g
s
.65 .757 .928 r
.39444 .57581 m .38541 .57871 L .38814 .58139 L p F P
0 g
s
.65 .757 .928 r
.38814 .58139 m .39717 .57849 L .39444 .57581 L p F P
0 g
s
.448 .456 .775 r
.60732 .70534 m .6071 .70477 L .60765 .70497 L closepath p F P
0 g
s
.651 .757 .928 r
.53853 .57582 m .52924 .57873 L .53174 .5814 L p F P
0 g
s
.651 .757 .928 r
.53174 .5814 m .54101 .5785 L .53853 .57582 L p F P
0 g
s
.429 .375 .695 r
.61908 .73681 m .61773 .73792 L .61925 .74386 L p F P
0 g
s
.449 .456 .774 r
.60765 .70497 m .6071 .70477 L .60463 .69823 L p F P
0 g
s
.903 .664 .567 r
.43248 .76838 m .43599 .7705 L .43536 .77521 L p F P
0 g
s
.892 .678 .606 r
.43354 .76356 m .43248 .76838 L .43599 .7705 L p F P
0 g
s
.559 .84 .997 r
.55491 .80854 m .55688 .80961 L .56186 .80887 L p F P
0 g
s
.85 .482 .354 r
.45384 .796 m .44947 .79416 L .44796 .79002 L p F P
0 g
s
.855 .478 .334 r
.44365 .78815 m .44796 .79002 L .44947 .79416 L p F P
0 g
s
.824 .593 .589 r
.51094 .69206 m .50576 .69034 L .50662 .68565 L p F P
0 g
s
.86 .632 .592 r
.50389 .68436 m .50662 .68565 L .50576 .69034 L p F P
0 g
s
.688 .487 .61 r
.52563 .69867 m .53305 .69843 L .53366 .7035 L p F P
0 g
s
.688 .487 .61 r
.53366 .7035 m .52321 .70383 L .52563 .69867 L p F P
0 g
s
.704 .506 .618 r
.52129 .69864 m .52563 .69867 L .52321 .70383 L p F P
0 g
s
.651 .758 .928 r
.83072 .58107 m .84052 .57817 L .84252 .58084 L p F P
0 g
s
.651 .758 .928 r
.84052 .57817 m .83072 .58107 L .8287 .5784 L p F P
0 g
s
.9 .77 .709 r
.4321 .72887 m .43486 .73127 L .43218 .73651 L p F P
0 g
s
.891 .774 .726 r
.43311 .72708 m .4321 .72887 L .43486 .73127 L p F P
0 g
s
.704 .506 .618 r
.52321 .70383 m .52201 .70383 L .52129 .69864 L p F P
0 g
s
.741 .532 .61 r
.51633 .69816 m .52129 .69864 L .52201 .70383 L p F P
0 g
s
.44 0 0 r
.46707 .80301 m .46998 .80482 L .46735 .80386 L p F P
0 g
s
.44 0 0 r
.46732 .80378 m .46215 .80143 L .46707 .80301 L F
.46201 .80137 m .46553 .80251 L p .46215 .80143 L F P
0 g
s
.44 0 0 r
.46553 .80251 m .46707 .80301 L p .46215 .80143 L F P
0 g
s
.118 .577 .918 r
.45432 .79891 m .45689 .79974 L .45726 .79986 L p F P
0 g
s
.44 0 0 r
.46638 .80341 m .46201 .80137 L p .46732 .80378 L F P
0 g
s
.44 0 0 r
.46735 .80386 m .46638 .80341 L p .46732 .80378 L F P
0 g
s
0 .422 .773 r
.46201 .80137 m .46735 .80386 L .4654 .80278 L p F P
0 g
s
0 .422 .773 r
.45689 .79974 m .46201 .80137 L p .4654 .80278 L F P
0 g
s
0 .422 .773 r
.4654 .80278 m .4643 .80229 L .45726 .79986 L p F P
0 g
s
0 .422 .773 r
.45726 .79986 m .45689 .79974 L p .4574 .79992 L F P
0 g
s
.118 .577 .918 r
.45726 .79986 m .4643 .80229 L p .45495 .79913 L F P
0 g
s
.118 .577 .918 r
.45495 .79913 m .45432 .79891 L .45726 .79986 L F
0 .422 .773 r
.4654 .80278 m .45726 .79986 L .4574 .79992 L F
.65 .757 .928 r
.26213 .57553 m .25332 .57843 L .25626 .58111 L p F P
0 g
s
.65 .757 .928 r
.25626 .58111 m .26506 .57822 L .26213 .57553 L p F P
0 g
s
.651 .758 .928 r
.68711 .58116 m .69666 .57826 L .6989 .58093 L p F P
0 g
s
.651 .758 .928 r
.69666 .57826 m .68711 .58116 L .68486 .57849 L p F P
0 g
s
.65 .757 .928 r
.40622 .57559 m .39717 .57849 L .39988 .58117 L p F P
0 g
s
.65 .757 .928 r
.39988 .58117 m .40893 .57827 L .40622 .57559 L p F P
0 g
s
.651 .757 .928 r
.55033 .5756 m .54101 .5785 L .5435 .58118 L p F P
0 g
s
.651 .757 .928 r
.5435 .58118 m .5528 .57828 L .55033 .5756 L p F P
0 g
s
.778 .558 .601 r
.51633 .69816 m .50976 .69685 L .51094 .69206 L p F P
0 g
s
.822 .606 .61 r
.50576 .69034 m .51094 .69206 L .50976 .69685 L p F P
0 g
s
.649 .757 .928 r
.1298 .57511 m .12123 .57799 L .12438 .58067 L p F P
0 g
s
.649 .757 .928 r
.12438 .58067 m .13295 .5778 L .1298 .57511 L p F P
0 g
s
.411 .264 .569 r
.61785 .76911 m .61594 .77027 L .61636 .77513 L p F P
0 g
s
.892 .792 .744 r
.43861 .71806 m .43608 .71557 L .4327 .72101 L p F P
0 g
s
.892 .792 .744 r
.4327 .72101 m .43524 .72349 L .43861 .71806 L p F P
0 g
s
.651 .758 .928 r
.84252 .58084 m .85235 .57793 L .85433 .5806 L p F P
0 g
s
.651 .758 .928 r
.85235 .57793 m .84252 .58084 L .84052 .57817 L p F P
0 g
s
.436 .451 .777 r
.61101 .70086 m .60765 .70497 L .61399 .70768 L p F P
0 g
s
.449 .456 .774 r
.60463 .69823 m .61101 .70086 L .60765 .70497 L p F P
0 g
s
.616 .436 .615 r
.53305 .69843 m .54303 .69645 L p .53946 .70233 L F P
0 g
s
.616 .436 .615 r
.53946 .70233 m .53366 .7035 L .53305 .69843 L p F P
0 g
s
.62 .436 .611 r
.5425 .69149 m .54303 .69645 L .53305 .69843 L p F P
0 g
s
.65 .757 .928 r
.27389 .57532 m .26506 .57822 L .26799 .58089 L p F P
0 g
s
.65 .757 .928 r
.26799 .58089 m .27681 .578 L .27389 .57532 L p F P
0 g
s
.651 .758 .928 r
.6989 .58093 m .70847 .57803 L .71068 .58071 L p F P
0 g
s
.651 .758 .928 r
.70847 .57803 m .6989 .58093 L .69666 .57826 L p F P
0 g
s
.887 .62 .529 r
.43898 .78189 m .439 .77861 L .43889 .78185 L closepath p F P
0 g
s
.65 .757 .928 r
.41801 .57537 m .40893 .57827 L .41162 .58095 L p F P
0 g
s
.65 .757 .928 r
.41162 .58095 m .42069 .57805 L .41801 .57537 L p F P
0 g
s
.651 .757 .928 r
.56213 .57537 m .5528 .57828 L .55526 .58095 L p F P
0 g
s
.651 .757 .928 r
.55526 .58095 m .56458 .57806 L .56213 .57537 L p F P
0 g
s
.513 .781 .993 r
.49404 .80927 m .49605 .80927 L .49349 .80726 L p F P
0 g
s
.513 .781 .993 r
.49349 .80726 m .48784 .80796 L .49404 .80927 L p F P
0 g
s
0 .568 .77 r
.48431 .80824 m .48784 .80796 L .49404 .80927 L p F P
0 g
s
.9 .748 .684 r
.4297 .7417 m .43269 .74402 L .43044 .74915 L p F P
0 g
s
.895 .752 .696 r
.43269 .74402 m .4297 .7417 L .43218 .73651 L p F P
0 g
s
.472 .495 .801 r
.5997 .68626 m .5963 .68527 L p .6007 .69166 L F P
0 g
s
.453 .484 .801 r
.5997 .68626 m .5963 .68527 L .59822 .6828 L closepath p F P
0 g
s
.907 .692 .601 r
.4302 .76137 m .43354 .76356 L .43248 .76838 L p F P
0 g
s
.896 .704 .634 r
.43142 .75721 m .4302 .76137 L .43354 .76356 L p F P
0 g
s
.649 .757 .928 r
.14154 .57491 m .13295 .5778 L .13609 .58048 L p F P
0 g
s
.649 .757 .928 r
.13609 .58048 m .14467 .5776 L .14154 .57491 L p F P
0 g
s
.404 .784 .992 r
.48784 .80796 m .48267 .80747 L .48431 .80824 L closepath p F P
0 g
s
.651 .758 .928 r
.86417 .57769 m .85433 .5806 L .85235 .57793 L p F P
0 g
s
.651 .758 .928 r
.85433 .5806 m .86417 .57769 L .86613 .58036 L p F P
0 g
s
.65 .757 .928 r
.28566 .5751 m .27681 .578 L .27972 .58068 L p F P
0 g
s
.65 .757 .928 r
.27972 .58068 m .28856 .57779 L .28566 .5751 L p F P
0 g
s
.461 .463 .774 r
.60463 .69823 m .60456 .69821 L .6046 .69816 L closepath p F P
0 g
s
.474 .484 .788 r
.60216 .69211 m .6007 .69166 L p .60456 .69821 L F P
0 g
s
.474 .484 .788 r
.60456 .69821 m .6046 .69816 L .60216 .69211 L p F P
0 g
s
.651 .758 .928 r
.71068 .58071 m .72028 .57781 L .72247 .58048 L p F P
0 g
s
.651 .758 .928 r
.72028 .57781 m .71068 .58071 L .70847 .57803 L p F P
0 g
s
.65 .757 .928 r
.4298 .57515 m .42069 .57805 L .42337 .58073 L p F P
0 g
s
.65 .757 .928 r
.42337 .58073 m .43246 .57783 L .4298 .57515 L p F P
0 g
s
.651 .757 .928 r
.57394 .57515 m .56458 .57806 L .56703 .58073 L p F P
0 g
s
.651 .757 .928 r
.56703 .58073 m .57637 .57783 L .57394 .57515 L p F P
0 g
s
.428 .359 .677 r
.61925 .74386 m .62389 .74002 L p .62261 .74801 L F P
0 g
s
.428 .359 .677 r
.62261 .74801 m .61968 .74576 L .61925 .74386 L p F P
0 g
s
.429 .375 .695 r
.61925 .74386 m .62389 .74002 L .61908 .73681 L p F P
0 g
s
.457 .474 .788 r
.60216 .69211 m .6007 .69166 L .60158 .69066 L closepath p F P
0 g
s
.472 .495 .801 r
.6007 .69166 m .60158 .69066 L .5997 .68626 L p F P
0 g
s
.429 .444 .774 r
.61101 .70086 m .60463 .69823 L .6046 .69816 L p F P
0 g
s
.429 .444 .774 r
.6046 .69816 m .60748 .6942 L p .61101 .70086 L F P
0 g
s
.424 .454 .787 r
.6046 .69816 m .60216 .69211 L .60748 .6942 L closepath p F P
0 g
s
.741 .532 .61 r
.52201 .70383 m .51469 .70309 L .51633 .69816 L p F P
0 g
s
.788 .572 .608 r
.50976 .69685 m .51633 .69816 L .51469 .70309 L p F P
0 g
s
.804 .341 .134 r
.45384 .796 m .45567 .79887 L .45432 .79891 L p F P
0 g
s
.804 .341 .134 r
.44947 .79416 m .45384 .796 L p .45432 .79891 L F P
0 g
s
.65 .757 .928 r
.15329 .57472 m .14467 .5776 L .14779 .58029 L p F P
0 g
s
.65 .757 .928 r
.14779 .58029 m .1564 .57741 L .15329 .57472 L p F P
0 g
s
.651 .758 .928 r
.86613 .58036 m .876 .57744 L .87794 .58012 L p F P
0 g
s
.651 .758 .928 r
.876 .57744 m .86613 .58036 L .86417 .57769 L p F P
0 g
s
.523 .36 .602 r
.54303 .69645 m .5425 .69149 L .55104 .68801 L p F P
0 g
s
.515 .35 .595 r
.55049 .68303 m .55104 .68801 L .5425 .69149 L p F P
0 g
s
.65 .757 .928 r
.29743 .57488 m .28856 .57779 L .29145 .58046 L p F P
0 g
s
.65 .757 .928 r
.29145 .58046 m .30031 .57757 L .29743 .57488 L p F P
0 g
s
.651 .758 .928 r
.72247 .58048 m .73209 .57758 L .73426 .58025 L p F P
0 g
s
.651 .758 .928 r
.73209 .57758 m .72247 .58048 L .72028 .57781 L p F P
0 g
s
.65 .757 .928 r
.44159 .57492 m .43246 .57783 L .43512 .5805 L p F P
0 g
s
.65 .757 .928 r
.43512 .5805 m .44423 .57761 L .44159 .57492 L p F P
0 g
s
.651 .757 .928 r
.58575 .57493 m .57637 .57783 L .5788 .58051 L p F P
0 g
s
.651 .757 .928 r
.5788 .58051 m .58816 .57761 L .58575 .57493 L p F P
0 g
s
.874 .816 .789 r
.44361 .70448 m .44137 .70188 L .43726 .70753 L p F P
0 g
s
.874 .816 .789 r
.43989 .70962 m .44361 .70448 L p .43726 .70753 L F P
0 g
s
.43 .851 .955 r
.56669 .8078 m .56186 .80887 L .56698 .80786 L closepath p F P
0 g
s
.559 .84 .997 r
.56186 .80887 m .56669 .8078 L p .55491 .80854 L F P
0 g
s
.427 .359 .678 r
.62057 .74961 m .61968 .74576 L .62261 .74801 L closepath p F P
0 g
s
.65 .757 .928 r
.16504 .57452 m .1564 .57741 L .1595 .58009 L p F P
0 g
s
.65 .757 .928 r
.1595 .58009 m .16814 .57721 L .16504 .57452 L p F P
0 g
s
.651 .758 .928 r
.87794 .58012 m .88783 .5772 L .88975 .57987 L p F P
0 g
s
.651 .758 .928 r
.88783 .5772 m .87794 .58012 L .876 .57744 L p F P
0 g
s
.65 .757 .928 r
.3092 .57466 m .30031 .57757 L .30318 .58025 L p F P
0 g
s
.65 .757 .928 r
.30318 .58025 m .31207 .57735 L .3092 .57466 L p F P
0 g
s
.651 .758 .928 r
.73426 .58025 m .7439 .57735 L .74606 .58002 L p F P
0 g
s
.651 .758 .928 r
.7439 .57735 m .73426 .58025 L .73209 .57758 L p F P
0 g
s
.65 .757 .928 r
.45338 .5747 m .44423 .57761 L .44687 .58028 L p F P
0 g
s
.65 .757 .928 r
.44687 .58028 m .45601 .57739 L .45338 .5747 L p F P
0 g
s
.651 .757 .928 r
.59057 .58028 m .59996 .57738 L .60234 .58006 L p F P
0 g
s
.651 .757 .928 r
.59756 .5747 m .58816 .57761 L .59057 .58028 L p F P
0 g
s
.651 .757 .928 r
.59057 .58028 m .59996 .57738 L .59756 .5747 L p F P
0 g
s
.881 .836 .797 r
.45467 .68468 m .45278 .68195 L .44817 .68774 L p F P
0 g
s
.881 .836 .797 r
.44817 .68774 m .45005 .69046 L .45467 .68468 L p F P
0 g
s
.39 .118 .376 r
.59946 .79549 m .59949 .79547 L .60607 .78909 L p F P
0 g
s
.361 .08 .346 r
.60842 .78805 m .60607 .78909 L .59949 .79547 L p F P
0 g
s
.903 .715 .638 r
.43142 .75721 m .43166 .75645 L .43042 .75559 L closepath p F P
0 g
s
.891 .731 .676 r
.4288 .75334 m .43044 .74915 L p .43166 .75645 L F P
0 g
s
.891 .731 .676 r
.43166 .75645 m .43042 .75559 L .4288 .75334 L p F P
0 g
s
.65 .757 .928 r
.1768 .57431 m .16814 .57721 L .17122 .57989 L p F P
0 g
s
.65 .757 .928 r
.17122 .57989 m .17987 .577 L .1768 .57431 L p F P
0 g
s
.423 .376 .701 r
.62424 .73229 m .61908 .73681 L .62389 .74002 L p F P
0 g
s
.445 .397 .711 r
.62424 .73228 m .62424 .73229 L .61908 .73681 L p F P
0 g
s
.445 .397 .711 r
.61895 .72922 m .62424 .73228 L p .61908 .73681 L F P
0 g
s
.437 .333 .638 r
.62234 .75881 m .61989 .75637 L .62171 .75516 L closepath p F P
0 g
s
.453 .361 .661 r
.61989 .75637 m .62171 .75516 L .62057 .74961 L p F P
0 g
s
.651 .758 .928 r
.74606 .58002 m .75572 .57712 L .75785 .5798 L p F P
0 g
s
.651 .758 .928 r
.75572 .57712 m .74606 .58002 L .7439 .57735 L p F P
0 g
s
.65 .757 .928 r
.32098 .57445 m .31207 .57735 L .31492 .58003 L p F P
0 g
s
.65 .757 .928 r
.31492 .58003 m .32382 .57713 L .32098 .57445 L p F P
0 g
s
.651 .758 .928 r
.60234 .58006 m .61175 .57716 L .61412 .57984 L p F P
0 g
s
.651 .758 .928 r
.61175 .57716 m .60234 .58006 L .59996 .57738 L p F P
0 g
s
.65 .757 .928 r
.46518 .57448 m .45601 .57739 L .45863 .58006 L p F P
0 g
s
.65 .757 .928 r
.45863 .58006 m .46779 .57716 L .46518 .57448 L p F P
0 g
s
.324 .004 .258 r
.59945 .7955 m .59949 .79547 L .59946 .79549 L closepath p F P
0 g
s
.149 0 .051 r
.59797 .79854 m .59945 .7955 L .59949 .79547 L p F P
0 g
s
.191 0 .004 r
.59945 .7955 m .59797 .79854 L .58924 .8017 L p F P
0 g
s
.149 0 .051 r
.59949 .79547 m .60771 .79184 L p .59797 .79854 L F P
0 g
s
.361 .08 .346 r
.59949 .79547 m .60771 .79184 L .60842 .78805 L p F P
0 g
s
.48 .805 1 r
.50782 .80937 m .50528 .80687 L .49605 .80927 L p F P
0 g
s
.678 .726 .886 r
.50528 .80687 m .49605 .80927 L .49349 .80726 L p F P
0 g
s
.907 .715 .63 r
.4302 .76137 m .43142 .75721 L .43042 .75559 L p F P
0 g
s
.65 .757 .928 r
.18856 .57411 m .17987 .577 L .18294 .57969 L p F P
0 g
s
.65 .757 .928 r
.18294 .57969 m .19161 .5768 L .18856 .57411 L p F P
0 g
s
.86 .632 .592 r
.50576 .69034 m .50511 .69004 L .50389 .68436 L p F P
0 g
s
.834 .615 .607 r
.50212 .68372 m .50389 .68436 L .50511 .69004 L p F P
0 g
s
.651 .758 .928 r
.75785 .5798 m .76754 .57689 L .76966 .57957 L p F P
0 g
s
.651 .758 .928 r
.76754 .57689 m .75785 .5798 L .75572 .57712 L p F P
0 g
s
.65 .757 .928 r
.33276 .57423 m .32382 .57713 L .32666 .57981 L p F P
0 g
s
.65 .757 .928 r
.32666 .57981 m .33559 .57691 L .33276 .57423 L p F P
0 g
s
.412 .333 .657 r
.62261 .74801 m .62057 .74961 L .62171 .75516 L p F P
0 g
s
.896 .791 .736 r
.43311 .72708 m .43524 .72349 L .4327 .72101 L p F P
0 g
s
.424 .454 .787 r
.60748 .6942 m .60216 .69211 L .60158 .69066 L p F P
0 g
s
.651 .758 .928 r
.61412 .57984 m .62355 .57693 L .62591 .57961 L p F P
0 g
s
.651 .758 .928 r
.62355 .57693 m .61412 .57984 L .61175 .57716 L p F P
0 g
s
.65 .757 .928 r
.47698 .57425 m .46779 .57716 L .47039 .57984 L p F P
0 g
s
.65 .757 .928 r
.47039 .57984 m .47957 .57694 L .47698 .57425 L p F P
0 g
s
.905 .766 .698 r
.42941 .73412 m .43218 .73651 L .4297 .7417 L p F P
0 g
s
.9 .77 .709 r
.43218 .73651 m .42941 .73412 L .4321 .72887 L p F P
0 g
s
.689 .505 .632 r
.52321 .70383 m .53366 .7035 L p .53269 .70876 L F P
0 g
s
.689 .505 .632 r
.52229 .70568 m .52321 .70383 L p .53269 .70876 L F P
0 g
s
.705 .51 .622 r
.52229 .70568 m .52321 .70383 L .52201 .70383 L closepath p F P
0 g
s
.717 .519 .62 r
.52201 .70383 m .51469 .70309 L p .52082 .70899 L F P
0 g
s
.717 .519 .62 r
.52082 .70899 m .52229 .70568 L .52201 .70383 L p F P
0 g
s
.411 .264 .569 r
.61636 .77513 m .6194 .77328 L .61785 .76911 L p F P
0 g
s
.402 .259 .57 r
.62333 .76564 m .61785 .76911 L .6194 .77328 L p F P
0 g
s
.434 .304 .604 r
.62264 .76053 m .62333 .76564 L .61785 .76911 L p F P
0 g
s
.003 0 0 r
.58781 .80289 m .58924 .8017 L .59797 .79854 L p F P
0 g
s
.058 0 0 r
.58924 .8017 m .58781 .80289 L .57844 .80569 L p F P
0 g
s
.65 .757 .928 r
.20032 .5739 m .19161 .5768 L .19466 .57948 L p F P
0 g
s
.65 .757 .928 r
.19466 .57948 m .20336 .57659 L .20032 .5739 L p F P
0 g
s
.663 .74 .907 r
.50782 .80937 m .51706 .80633 L .51959 .80917 L p F P
0 g
s
.693 .703 .855 r
.51706 .80633 m .50782 .80937 L .50528 .80687 L p F P
0 g
s
.424 .454 .787 r
.60158 .69066 m .60346 .68768 L p .60748 .6942 L F P
0 g
s
.418 .463 .8 r
.60158 .69066 m .5997 .68626 L .60346 .68768 L closepath p F P
0 g
s
.651 .758 .928 r
.76966 .57957 m .77936 .57666 L .78146 .57934 L p F P
0 g
s
.651 .758 .928 r
.77936 .57666 m .76966 .57957 L .76754 .57689 L p F P
0 g
s
.65 .757 .928 r
.34455 .57401 m .33559 .57691 L .3384 .57959 L p F P
0 g
s
.65 .757 .928 r
.3384 .57959 m .34735 .57669 L .34455 .57401 L p F P
0 g
s
.651 .758 .928 r
.62591 .57961 m .63536 .57671 L .63769 .57939 L p F P
0 g
s
.651 .758 .928 r
.63536 .57671 m .62591 .57961 L .62355 .57693 L p F P
0 g
s
.65 .757 .928 r
.48878 .57403 m .47957 .57694 L .48215 .57962 L p F P
0 g
s
.65 .757 .928 r
.48215 .57962 m .49135 .57672 L .48878 .57403 L p F P
0 g
s
.874 .816 .789 r
.43726 .70753 m .43743 .70772 L .43989 .70962 L p F P
0 g
s
.888 .81 .767 r
.43743 .70772 m .43989 .70962 L .43955 .7101 L closepath p F P
0 g
s
.45 .875 .923 r
.57653 .80554 m .57844 .80569 L .58781 .80289 L p F P
0 g
s
.335 .815 .871 r
.57844 .80569 m .57653 .80554 L .56698 .80786 L p F P
0 g
s
.899 .81 .752 r
.43955 .7101 m .43608 .71557 L .43377 .713 L p F P
0 g
s
.899 .81 .752 r
.43743 .70772 m .43955 .7101 L p .43377 .713 L F P
0 g
s
.65 .757 .928 r
.21209 .57369 m .20336 .57659 L .20639 .57927 L p F P
0 g
s
.65 .757 .928 r
.20639 .57927 m .21511 .57638 L .21209 .57369 L p F P
0 g
s
.872 .56 .457 r
.43891 .7821 m .43898 .78189 L p .44365 .78815 L F P
0 g
s
.889 .589 .473 r
.43891 .7821 m .43889 .78185 L .43898 .78189 L closepath p F P
0 g
s
.668 .732 .897 r
.51959 .80917 m .52885 .80599 L .53136 .80895 L p F P
0 g
s
.691 .689 .844 r
.52885 .80599 m .51959 .80917 L .51706 .80633 L p F P
0 g
s
.879 .836 .8 r
.44661 .6947 m .45005 .69046 L .44817 .68774 L p F P
0 g
s
.651 .758 .928 r
.78146 .57934 m .79118 .57643 L .79327 .5791 L p F P
0 g
s
.651 .758 .928 r
.79118 .57643 m .78146 .57934 L .77936 .57666 L p F P
0 g
s
.617 .44 .619 r
.53406 .7066 m .53946 .70233 L .53366 .7035 L closepath p F P
0 g
s
.689 .505 .632 r
.53366 .7035 m .53406 .7066 L .53269 .70876 L p F P
0 g
s
.65 .757 .928 r
.35633 .57378 m .34735 .57669 L .35015 .57937 L p F P
0 g
s
.65 .757 .928 r
.35015 .57937 m .35912 .57647 L .35633 .57378 L p F P
0 g
s
.651 .758 .928 r
.63769 .57939 m .64717 .57648 L .64948 .57916 L p F P
0 g
s
.651 .758 .928 r
.64717 .57648 m .63769 .57939 L .63536 .57671 L p F P
0 g
s
.9 .593 .456 r
.43889 .78185 m .43891 .7821 L .43744 .78522 L p F P
0 g
s
.9 .593 .456 r
.43521 .77978 m .43889 .78185 L p .43744 .78522 L F P
0 g
s
.892 .625 .527 r
.43536 .77521 m .43521 .77978 L .43889 .78185 L p F P
0 g
s
.65 .757 .928 r
.50059 .57381 m .49135 .57672 L .49392 .5794 L p F P
0 g
s
.65 .757 .928 r
.49392 .5794 m .50314 .57649 L .50059 .57381 L p F P
0 g
s
.46 .795 .999 r
.48784 .80796 m .49349 .80726 L p .48171 .80695 L F P
0 g
s
.46 .795 .999 r
.48171 .80695 m .48267 .80747 L .48784 .80796 L p F P
0 g
s
.906 .741 .665 r
.43044 .74915 m .4288 .75334 L .42615 .75016 L p F P
0 g
s
.906 .741 .665 r
.42615 .75016 m .42744 .74684 L .43044 .74915 L p F P
0 g
s
.9 .748 .684 r
.43044 .74915 m .42744 .74684 L .4297 .7417 L p F P
0 g
s
.73 .251 .11 r
.45567 .79887 m .45689 .79974 L .46201 .80137 L p F P
0 g
s
.822 .606 .61 r
.50549 .69163 m .50576 .69034 L p .50976 .69685 L F P
0 g
s
.859 .637 .6 r
.50549 .69163 m .50576 .69034 L .50511 .69004 L closepath p F P
0 g
s
.788 .572 .608 r
.51469 .70309 m .50847 .70169 L .50976 .69685 L p F P
0 g
s
.82 .608 .615 r
.50631 .6957 m .50976 .69685 L .50847 .70169 L p F P
0 g
s
.822 .606 .61 r
.50976 .69685 m .50631 .6957 L .50549 .69163 L p F P
0 g
s
.464 .868 .961 r
.56669 .8078 m .56698 .80786 L .57653 .80554 L p F P
0 g
s
.908 .639 .518 r
.43184 .77308 m .43536 .77521 L .43521 .77978 L p F P
0 g
s
.903 .664 .567 r
.43536 .77521 m .43184 .77308 L .43248 .76838 L p F P
0 g
s
.689 .505 .632 r
.53269 .70876 m .52285 .70912 L .52229 .70568 L p F P
0 g
s
.728 .531 .625 r
.52285 .70912 m .52229 .70568 L .52082 .70899 L closepath p F P
0 g
s
.872 .56 .457 r
.44365 .78815 m .43948 .78623 L .43891 .7821 L p F P
0 g
s
.882 .568 .45 r
.43948 .78623 m .43744 .78522 L .43891 .7821 L closepath p F P
0 g
s
.907 .715 .63 r
.43042 .75559 m .42848 .75421 L p .4302 .76137 L F P
0 g
s
.901 .729 .659 r
.43042 .75559 m .4288 .75334 L .42848 .75421 L closepath p F P
0 g
s
.65 .757 .928 r
.22386 .57348 m .21511 .57638 L .21811 .57907 L p F P
0 g
s
.65 .757 .928 r
.21811 .57907 m .22686 .57617 L .22386 .57348 L p F P
0 g
s
.662 .738 .906 r
.53136 .80895 m .54065 .80595 L .54313 .8088 L p F P
0 g
s
.682 .689 .85 r
.54065 .80595 m .53136 .80895 L .52885 .80599 L p F P
0 g
s
.834 .615 .607 r
.50511 .69004 m .50098 .6885 L .50212 .68372 L p F P
0 g
s
.883 .662 .598 r
.49816 .68163 m .50212 .68372 L .50098 .6885 L p F P
0 g
s
.651 .758 .928 r
.79327 .5791 m .80301 .57619 L .80508 .57887 L p F P
0 g
s
.651 .758 .928 r
.80301 .57619 m .79327 .5791 L .79118 .57643 L p F P
0 g
s
.38 .209 .52 r
.6194 .77328 m .61636 .77513 L .6165 .77972 L p F P
0 g
s
.65 .757 .928 r
.36812 .57356 m .35912 .57647 L .3619 .57915 L p F P
0 g
s
.65 .757 .928 r
.3619 .57915 m .37089 .57625 L .36812 .57356 L p F P
0 g
s
.651 .758 .928 r
.64948 .57916 m .65898 .57626 L .66127 .57894 L p F P
0 g
s
.651 .758 .928 r
.65898 .57626 m .64948 .57916 L .64717 .57648 L p F P
0 g
s
.651 .757 .928 r
.5124 .57358 m .50314 .57649 L .50569 .57917 L p F P
0 g
s
.651 .757 .928 r
.50569 .57917 m .51493 .57627 L .5124 .57358 L p F P
0 g
s
.855 .478 .334 r
.44947 .79416 m .44523 .79227 L .44365 .78815 L p F P
0 g
s
.86 .475 .314 r
.43948 .78623 m .44365 .78815 L .44523 .79227 L p F P
0 g
s
.299 .019 .308 r
.6163 .78398 m .60842 .78805 L .60771 .79184 L p F P
0 g
s
.344 .134 .445 r
.6165 .77972 m .6163 .78398 L .60842 .78805 L p F P
0 g
s
.896 .791 .736 r
.4327 .72101 m .43044 .72481 L .43311 .72708 L p F P
0 g
s
.9 .788 .729 r
.43311 .72708 m .43209 .72887 L .42954 .7264 L p F P
0 g
s
.9 .788 .729 r
.42954 .7264 m .43044 .72481 L .43311 .72708 L p F P
0 g
s
.247 0 0 r
.46998 .80482 m .47596 .80516 L .48077 .80687 L p F P
0 g
s
.173 .671 .914 r
.47596 .80516 m .46998 .80482 L .46735 .80386 L p F P
0 g
s
.65 .757 .928 r
.23563 .57327 m .22686 .57617 L .22985 .57886 L p F P
0 g
s
.65 .757 .928 r
.22985 .57886 m .23861 .57596 L .23563 .57327 L p F P
0 g
s
.651 .758 .928 r
.80508 .57887 m .81484 .57596 L .81689 .57864 L p F P
0 g
s
.651 .758 .928 r
.81484 .57596 m .80508 .57887 L .80301 .57619 L p F P
0 g
s
.646 .765 .936 r
.54313 .8088 m .55244 .8061 L .55491 .80854 L p F P
0 g
s
.668 .704 .874 r
.55244 .8061 m .54313 .8088 L .54065 .80595 L p F P
0 g
s
.825 .617 .622 r
.50511 .69004 m .50098 .6885 L p .50445 .69517 L F P
0 g
s
.825 .617 .622 r
.50445 .69517 m .50549 .69163 L .50511 .69004 L p F P
0 g
s
.717 .519 .62 r
.51469 .70309 m .51299 .70806 L .52082 .70899 L p F P
0 g
s
.789 .588 .628 r
.50847 .70169 m .51469 .70309 L .51299 .70806 L p F P
0 g
s
.427 .395 .721 r
.62424 .73228 m .61895 .72922 L .6224 .726 L closepath p F P
0 g
s
.443 .407 .723 r
.62171 .72383 m .6224 .726 L .61895 .72922 L p F P
0 g
s
.443 .407 .723 r
.61801 .72184 m .62171 .72383 L p .61895 .72922 L F P
0 g
s
.65 .757 .928 r
.37992 .57334 m .37089 .57625 L .37365 .57893 L p F P
0 g
s
.65 .757 .928 r
.37365 .57893 m .38267 .57603 L .37992 .57334 L p F P
0 g
s
.651 .758 .928 r
.66127 .57894 m .67079 .57603 L .67307 .57871 L p F P
0 g
s
.651 .758 .928 r
.67079 .57603 m .66127 .57894 L .65898 .57626 L p F P
0 g
s
.651 .757 .928 r
.52421 .57336 m .51493 .57627 L .51746 .57895 L p F P
0 g
s
.651 .757 .928 r
.51746 .57895 m .52673 .57605 L .52421 .57336 L p F P
0 g
s
.913 .675 .565 r
.42914 .76619 m .43248 .76838 L .43184 .77308 L p F P
0 g
s
.907 .692 .601 r
.43248 .76838 m .42914 .76619 L .4302 .76137 L p F P
0 g
s
.879 .836 .8 r
.44817 .68774 m .44395 .69291 L .44661 .6947 L p F P
0 g
s
.883 .831 .79 r
.44661 .6947 m .44543 .69625 L .44345 .69357 L p F P
0 g
s
.883 .831 .79 r
.44345 .69357 m .44395 .69291 L .44661 .6947 L p F P
0 g
s
.418 .463 .8 r
.60346 .68768 m .5997 .68626 L .59822 .6828 L p F P
0 g
s
.537 .374 .608 r
.54303 .69645 m .55164 .69304 L p .54724 .70008 L F P
0 g
s
.537 .374 .608 r
.54724 .70008 m .54334 .69912 L .54303 .69645 L p F P
0 g
s
.523 .36 .602 r
.55104 .68801 m .55164 .69304 L .54303 .69645 L p F P
0 g
s
.616 .436 .615 r
.54303 .69645 m .54334 .69912 L .53946 .70233 L p F P
0 g
s
.464 .868 .961 r
.57653 .80554 m .57604 .80541 L .56669 .8078 L p F P
0 g
s
.619 .815 .976 r
.57604 .80541 m .56669 .8078 L .56425 .80611 L p F P
0 g
s
.559 .84 .997 r
.56669 .8078 m .56425 .80611 L .55491 .80854 L p F P
0 g
s
.24 .678 .958 r
.48171 .80695 m .48077 .80687 L .48267 .80747 L closepath p F P
0 g
s
.651 .74 .915 r
.56425 .80611 m .55491 .80854 L .55244 .8061 L p F P
0 g
s
.806 .596 .618 r
.50631 .6957 m .50549 .69163 L .50445 .69517 L closepath p F P
0 g
s
.651 .758 .928 r
.81689 .57864 m .82668 .57572 L .8287 .5784 L p F P
0 g
s
.651 .758 .928 r
.82668 .57572 m .81689 .57864 L .81484 .57596 L p F P
0 g
s
.65 .757 .928 r
.2474 .57305 m .23861 .57596 L .24158 .57864 L p F P
0 g
s
.65 .757 .928 r
.24158 .57864 m .25037 .57575 L .2474 .57305 L p F P
0 g
s
.407 .312 .635 r
.62171 .75516 m .62632 .75156 L p .62335 .76 L F P
0 g
s
.407 .312 .635 r
.62335 .76 m .62234 .75881 L .62171 .75516 L p F P
0 g
s
.412 .333 .657 r
.62171 .75516 m .62632 .75156 L .62261 .74801 L p F P
0 g
s
.651 .758 .928 r
.67307 .57871 m .68261 .57581 L .68486 .57849 L p F P
0 g
s
.651 .758 .928 r
.68261 .57581 m .67307 .57871 L .67079 .57603 L p F P
0 g
s
.65 .757 .928 r
.39171 .57312 m .38267 .57603 L .38541 .57871 L p F P
0 g
s
.65 .757 .928 r
.38541 .57871 m .39444 .57581 L .39171 .57312 L p F P
0 g
s
.651 .757 .928 r
.53603 .57313 m .52673 .57605 L .52924 .57873 L p F P
0 g
s
.651 .757 .928 r
.52924 .57873 m .53853 .57582 L .53603 .57313 L p F P
0 g
s
.893 .83 .778 r
.44543 .69625 m .44345 .69357 L .43938 .6992 L p F P
0 g
s
.893 .83 .778 r
.43938 .6992 m .44137 .70188 L .44543 .69625 L p F P
0 g
s
.909 .784 .711 r
.43209 .72887 m .42954 .7264 L .42684 .73165 L p F P
0 g
s
.909 .784 .711 r
.42684 .73165 m .42941 .73412 L .43209 .72887 L p F P
0 g
s
.651 .758 .928 r
.8287 .5784 m .83852 .57549 L .84052 .57817 L p F P
0 g
s
.651 .758 .928 r
.83852 .57549 m .8287 .5784 L .82668 .57572 L p F P
0 g
s
.65 .757 .928 r
.25918 .57284 m .25037 .57575 L .25332 .57843 L p F P
0 g
s
.65 .757 .928 r
.25332 .57843 m .26213 .57553 L .25918 .57284 L p F P
0 g
s
.804 .341 .134 r
.45432 .79891 m .45221 .79797 L .44947 .79416 L p F P
0 g
s
.792 .309 .068 r
.44523 .79227 m .44947 .79416 L .45221 .79797 L p F P
0 g
s
.651 .758 .928 r
.68486 .57849 m .69443 .57558 L .69666 .57826 L p F P
0 g
s
.651 .758 .928 r
.69443 .57558 m .68486 .57849 L .68261 .57581 L p F P
0 g
s
.65 .757 .928 r
.40351 .5729 m .39444 .57581 L .39717 .57849 L p F P
0 g
s
.65 .757 .928 r
.39717 .57849 m .40622 .57559 L .40351 .5729 L p F P
0 g
s
.651 .757 .928 r
.54785 .57291 m .53853 .57582 L .54101 .5785 L p F P
0 g
s
.651 .757 .928 r
.54101 .5785 m .55033 .5756 L .54785 .57291 L p F P
0 g
s
.627 .456 .632 r
.53437 .70867 m .53406 .7066 L .53946 .70233 L p F P
0 g
s
.68 .493 .626 r
.53437 .70867 m .53406 .7066 L .53269 .70876 L closepath p F P
0 g
s
.392 .268 .59 r
.55166 .68218 m .55049 .68303 L .55104 .68801 L p F P
0 g
s
.649 .757 .928 r
.12664 .57241 m .11806 .5753 L .12123 .57799 L p F P
0 g
s
.649 .757 .928 r
.12123 .57799 m .1298 .57511 L .12664 .57241 L p F P
0 g
s
.689 .506 .634 r
.52285 .70912 m .53269 .70876 L .52907 .71429 L p F P
0 g
s
.689 .506 .634 r
.52907 .71429 m .52374 .71448 L .52285 .70912 L p F P
0 g
s
.729 .533 .626 r
.52082 .70899 m .52285 .70912 L .52374 .71448 L p F P
0 g
s
.641 .092 0 r
.45689 .79974 m .45432 .79891 L .45567 .79887 L closepath p F P
0 g
s
.917 .704 .6 r
.42705 .75912 m .4302 .76137 L .42914 .76619 L p F P
0 g
s
.907 .715 .63 r
.42848 .75421 m .42705 .75912 L .4302 .76137 L p F P
0 g
s
.651 .758 .928 r
.84052 .57817 m .85036 .57525 L .85235 .57793 L p F P
0 g
s
.651 .758 .928 r
.85036 .57525 m .84052 .57817 L .83852 .57549 L p F P
0 g
s
.901 .808 .747 r
.43608 .71557 m .43377 .713 L .4304 .71845 L p F P
0 g
s
.901 .808 .747 r
.4304 .71845 m .4327 .72101 L .43608 .71557 L p F P
0 g
s
.91 .762 .686 r
.42692 .73932 m .4297 .7417 L .42744 .74684 L p F P
0 g
s
.905 .766 .698 r
.4297 .7417 m .42692 .73932 L .42941 .73412 L p F P
0 g
s
.65 .757 .928 r
.27097 .57262 m .26213 .57553 L .26506 .57822 L p F P
0 g
s
.65 .757 .928 r
.26506 .57822 m .27389 .57532 L .27097 .57262 L p F P
0 g
s
.651 .758 .928 r
.69666 .57826 m .70625 .57535 L .70847 .57803 L p F P
0 g
s
.651 .758 .928 r
.70625 .57535 m .69666 .57826 L .69443 .57558 L p F P
0 g
s
.729 .533 .626 r
.52374 .71448 m .51852 .71414 L .52082 .70899 L p F P
0 g
s
.76 .556 .621 r
.51299 .70806 m .52082 .70899 L .51852 .71414 L p F P
0 g
s
.65 .757 .928 r
.41532 .57268 m .40622 .57559 L .40893 .57827 L p F P
0 g
s
.65 .757 .928 r
.40893 .57827 m .41801 .57537 L .41532 .57268 L p F P
0 g
s
.651 .757 .928 r
.55967 .57268 m .55033 .5756 L .5528 .57828 L p F P
0 g
s
.651 .757 .928 r
.5528 .57828 m .56213 .57537 L .55967 .57268 L p F P
0 g
s
.418 .463 .8 r
.59822 .6828 m .59903 .68129 L p .60346 .68768 L F P
0 g
s
.649 .757 .928 r
.13841 .57221 m .1298 .57511 L .13295 .5778 L p F P
0 g
s
.649 .757 .928 r
.13295 .5778 m .14154 .57491 L .13841 .57221 L p F P
0 g
s
.627 .456 .632 r
.53946 .70233 m .54367 .70153 L p .53437 .70867 L F P
0 g
s
.623 .446 .623 r
.54367 .70153 m .54334 .69912 L .53946 .70233 L closepath p F P
0 g
s
.429 .744 .993 r
.48077 .80687 m .48171 .80695 L .47912 .80508 L p F P
0 g
s
.429 .744 .993 r
.47912 .80508 m .47596 .80516 L .48077 .80687 L p F P
0 g
s
.651 .758 .928 r
.85235 .57793 m .8622 .57501 L .86417 .57769 L p F P
0 g
s
.651 .758 .928 r
.8622 .57501 m .85235 .57793 L .85036 .57525 L p F P
0 g
s
.65 .757 .928 r
.28275 .57241 m .27389 .57532 L .27681 .578 L p F P
0 g
s
.65 .757 .928 r
.27681 .578 m .28566 .5751 L .28275 .57241 L p F P
0 g
s
.405 .332 .662 r
.62727 .74418 m .62261 .74801 L .62632 .75156 L p F P
0 g
s
.428 .359 .677 r
.62682 .74236 m .62727 .74418 L .62261 .74801 L p F P
0 g
s
.428 .359 .677 r
.62389 .74002 m .62682 .74236 L p .62261 .74801 L F P
0 g
s
.651 .758 .928 r
.70847 .57803 m .71807 .57512 L .72028 .57781 L p F P
0 g
s
.651 .758 .928 r
.71807 .57512 m .70847 .57803 L .70625 .57535 L p F P
0 g
s
.65 .757 .928 r
.42712 .57245 m .41801 .57537 L .42069 .57805 L p F P
0 g
s
.65 .757 .928 r
.42069 .57805 m .4298 .57515 L .42712 .57245 L p F P
0 g
s
.651 .757 .928 r
.5715 .57246 m .56213 .57537 L .56458 .57806 L p F P
0 g
s
.651 .757 .928 r
.56458 .57806 m .57394 .57515 L .5715 .57246 L p F P
0 g
s
.82 .608 .615 r
.50847 .70169 m .50752 .70137 L .50631 .6957 L p F P
0 g
s
.808 .599 .62 r
.50445 .69517 m .50631 .6957 L .50752 .70137 L p F P
0 g
s
.425 .406 .734 r
.62171 .72383 m .61801 .72184 L .62035 .7195 L closepath p F P
0 g
s
.439 .428 .75 r
.6192 .7161 m .61634 .71466 L p .61801 .72184 L F P
0 g
s
.439 .428 .75 r
.61801 .72184 m .62035 .7195 L .6192 .7161 L p F P
0 g
s
.681 .495 .629 r
.53269 .70876 m .53437 .70867 L .53519 .71395 L p F P
0 g
s
.681 .495 .629 r
.53519 .71395 m .52907 .71429 L .53269 .70876 L p F P
0 g
s
.91 .741 .659 r
.42848 .75421 m .4288 .75334 L .42615 .75016 L p F P
0 g
s
.534 .383 .623 r
.54367 .70153 m .54334 .69912 L .54724 .70008 L closepath p F P
0 g
s
.65 .757 .928 r
.15017 .57202 m .14154 .57491 L .14467 .5776 L p F P
0 g
s
.65 .757 .928 r
.14467 .5776 m .15329 .57472 L .15017 .57202 L p F P
0 g
s
.624 .456 .634 r
.53519 .71395 m .53437 .70867 L .5444 .70671 L p F P
0 g
s
.627 .456 .632 r
.54367 .70153 m .5444 .70671 L .53437 .70867 L p F P
0 g
s
.651 .758 .928 r
.87405 .57476 m .86417 .57769 L .8622 .57501 L p F P
0 g
s
.651 .758 .928 r
.86417 .57769 m .87405 .57476 L .876 .57744 L p F P
0 g
s
.406 .312 .635 r
.62264 .76053 m .62234 .75881 L .62335 .76 L closepath p F P
0 g
s
.65 .757 .928 r
.29454 .57219 m .28566 .5751 L .28856 .57779 L p F P
0 g
s
.65 .757 .928 r
.28856 .57779 m .29743 .57488 L .29454 .57219 L p F P
0 g
s
.651 .758 .928 r
.72028 .57781 m .7299 .57489 L .73209 .57758 L p F P
0 g
s
.651 .758 .928 r
.7299 .57489 m .72028 .57781 L .71807 .57512 L p F P
0 g
s
.65 .757 .928 r
.43893 .57223 m .4298 .57515 L .43246 .57783 L p F P
0 g
s
.65 .757 .928 r
.43246 .57783 m .44159 .57492 L .43893 .57223 L p F P
0 g
s
.651 .757 .928 r
.58332 .57223 m .57394 .57515 L .57637 .57783 L p F P
0 g
s
.651 .757 .928 r
.57637 .57783 m .58575 .57493 L .58332 .57223 L p F P
0 g
s
.65 .757 .928 r
.16194 .57182 m .15329 .57472 L .1564 .57741 L p F P
0 g
s
.65 .757 .928 r
.1564 .57741 m .16504 .57452 L .16194 .57182 L p F P
0 g
s
.92 .73 .628 r
.42552 .75189 m .42848 .75421 L .42705 .75912 L p F P
0 g
s
.91 .741 .659 r
.42615 .75016 m .42552 .75189 L .42848 .75421 L p F P
0 g
s
.651 .758 .928 r
.876 .57744 m .8859 .57452 L .88783 .5772 L p F P
0 g
s
.651 .758 .928 r
.8859 .57452 m .876 .57744 L .87405 .57476 L p F P
0 g
s
.893 .832 .78 r
.44137 .70188 m .43938 .6992 L .4353 .70485 L p F P
0 g
s
.893 .832 .78 r
.4353 .70485 m .43726 .70753 L .44137 .70188 L p F P
0 g
s
.46 .795 .999 r
.49349 .80726 m .49092 .80475 L .48171 .80695 L p F P
0 g
s
.671 .737 .9 r
.49092 .80475 m .48171 .80695 L .47912 .80508 L p F P
0 g
s
.65 .757 .928 r
.30633 .57197 m .29743 .57488 L .30031 .57757 L p F P
0 g
s
.65 .757 .928 r
.30031 .57757 m .3092 .57466 L .30633 .57197 L p F P
0 g
s
.651 .758 .928 r
.73209 .57758 m .74174 .57466 L .7439 .57735 L p F P
0 g
s
.651 .758 .928 r
.74174 .57466 m .73209 .57758 L .7299 .57489 L p F P
0 g
s
.65 .757 .928 r
.45074 .57201 m .44159 .57492 L .44423 .57761 L p F P
0 g
s
.65 .757 .928 r
.44423 .57761 m .45338 .5747 L .45074 .57201 L p F P
0 g
s
.651 .757 .928 r
.59516 .57201 m .58575 .57493 L .58816 .57761 L p F P
0 g
s
.651 .757 .928 r
.58816 .57761 m .59756 .5747 L .59516 .57201 L p F P
0 g
s
.36 .255 .598 r
.55714 .67758 m .55166 .68218 L .55381 .68601 L p F P
0 g
s
.392 .268 .59 r
.55104 .68801 m .55381 .68601 L .55166 .68218 L p F P
0 g
s
.65 .757 .928 r
.17372 .57161 m .16504 .57452 L .16814 .57721 L p F P
0 g
s
.65 .757 .928 r
.16814 .57721 m .1768 .57431 L .17372 .57161 L p F P
0 g
s
.808 .599 .62 r
.50752 .70137 m .50299 .70006 L .50445 .69517 L p F P
0 g
s
.851 .638 .614 r
.49978 .6933 m .50445 .69517 L .50299 .70006 L p F P
0 g
s
.825 .617 .622 r
.50098 .6885 m .49978 .6933 L .50445 .69517 L p F P
0 g
s
.789 .588 .628 r
.50798 .70341 m .50847 .70169 L p .51299 .70806 L F P
0 g
s
.82 .61 .619 r
.50798 .70341 m .50847 .70169 L .50752 .70137 L closepath p F P
0 g
s
.381 .27 .601 r
.62335 .76 m .62264 .76053 L .62333 .76564 L p F P
0 g
s
.651 .758 .928 r
.7439 .57735 m .75357 .57443 L .75572 .57712 L p F P
0 g
s
.651 .758 .928 r
.75357 .57443 m .7439 .57735 L .74174 .57466 L p F P
0 g
s
.65 .757 .928 r
.31813 .57175 m .3092 .57466 L .31207 .57735 L p F P
0 g
s
.65 .757 .928 r
.31207 .57735 m .32098 .57445 L .31813 .57175 L p F P
0 g
s
.651 .758 .928 r
.59996 .57738 m .60938 .57447 L .61175 .57716 L p F P
0 g
s
.651 .757 .928 r
.60699 .57178 m .59756 .5747 L .59996 .57738 L p F P
0 g
s
.651 .757 .928 r
.59996 .57738 m .60938 .57447 L .60699 .57178 L p F P
0 g
s
.65 .757 .928 r
.46256 .57178 m .45338 .5747 L .45601 .57739 L p F P
0 g
s
.65 .757 .928 r
.45601 .57739 m .46518 .57448 L .46256 .57178 L p F P
0 g
s
.422 .416 .748 r
.6192 .7161 m .61634 .71466 L .61808 .71278 L closepath p F P
0 g
s
.438 .439 .763 r
.6167 .70895 m .61399 .70768 L p .61634 .71466 L F P
0 g
s
.438 .439 .763 r
.61634 .71466 m .61808 .71278 L .6167 .70895 L p F P
0 g
s
.888 .672 .604 r
.49717 .68636 m .50098 .6885 L .49978 .6933 L p F P
0 g
s
.883 .662 .598 r
.50098 .6885 m .49717 .68636 L .49816 .68163 L p F P
0 g
s
.891 .86 .804 r
.45278 .68195 m .44817 .68774 L .44658 .68492 L p F P
0 g
s
.891 .86 .804 r
.45199 .68055 m .45278 .68195 L p .44658 .68492 L F P
0 g
s
.535 .387 .627 r
.5444 .70671 m .54367 .70153 L .54724 .70008 L p F P
0 g
s
.76 .556 .621 r
.51852 .71414 m .51121 .71305 L .51299 .70806 L p F P
0 g
s
.788 .589 .631 r
.50875 .70707 m .51299 .70806 L .51121 .71305 L p F P
0 g
s
.789 .588 .628 r
.51299 .70806 m .50875 .70707 L .50798 .70341 L p F P
0 g
s
.65 .757 .928 r
.18549 .57141 m .1768 .57431 L .17987 .577 L p F P
0 g
s
.65 .757 .928 r
.17987 .577 m .18856 .57411 L .18549 .57141 L p F P
0 g
s
.678 .726 .886 r
.5031 .80425 m .50528 .80687 L p .49349 .80726 L F P
0 g
s
.678 .726 .886 r
.49349 .80726 m .50163 .80421 L .5031 .80425 L p F P
0 g
s
.708 .711 .85 r
.50163 .80421 m .49349 .80726 L .49092 .80475 L p F P
0 g
s
.651 .758 .928 r
.75572 .57712 m .76541 .5742 L .76754 .57689 L p F P
0 g
s
.651 .758 .928 r
.76541 .5742 m .75572 .57712 L .75357 .57443 L p F P
0 g
s
.65 .757 .928 r
.32993 .57153 m .32098 .57445 L .32382 .57713 L p F P
0 g
s
.65 .757 .928 r
.32382 .57713 m .33276 .57423 L .32993 .57153 L p F P
0 g
s
.914 .781 .7 r
.42941 .73412 m .42684 .73165 L .42435 .73686 L p F P
0 g
s
.914 .781 .7 r
.42435 .73686 m .42692 .73932 L .42941 .73412 L p F P
0 g
s
.651 .758 .928 r
.61175 .57716 m .6212 .57425 L .62355 .57693 L p F P
0 g
s
.651 .758 .928 r
.6212 .57425 m .61175 .57716 L .60938 .57447 L p F P
0 g
s
.65 .757 .928 r
.47438 .57156 m .46518 .57448 L .46779 .57716 L p F P
0 g
s
.65 .757 .928 r
.46779 .57716 m .47698 .57425 L .47438 .57156 L p F P
0 g
s
.689 .507 .636 r
.52374 .71448 m .52907 .71429 L .5254 .71984 L p F P
0 g
s
.689 .507 .636 r
.5254 .71984 m .52465 .71986 L .52374 .71448 L p F P
0 g
s
.729 .534 .627 r
.51852 .71414 m .52374 .71448 L .52465 .71986 L p F P
0 g
s
.905 .807 .74 r
.43044 .72481 m .4327 .72101 L .4304 .71845 L p F P
0 g
s
.794 .595 .632 r
.50752 .70137 m .50299 .70006 L p .50682 .70663 L F P
0 g
s
.794 .595 .632 r
.50682 .70663 m .50798 .70341 L .50752 .70137 L p F P
0 g
s
.38 .209 .52 r
.6165 .77972 m .61962 .77783 L .6194 .77328 L p F P
0 g
s
.367 .2 .518 r
.62377 .77052 m .6194 .77328 L .61962 .77783 L p F P
0 g
s
.402 .259 .57 r
.6194 .77328 m .62377 .77052 L .62333 .76564 L p F P
0 g
s
.693 .703 .855 r
.51644 .80547 m .51706 .80633 L p .50528 .80687 L F P
0 g
s
.693 .703 .855 r
.50528 .80687 m .50904 .80521 L .51644 .80547 L p F P
0 g
s
.699 .735 .879 r
.50528 .80687 m .50904 .80521 L .5031 .80425 L closepath p F P
0 g
s
.9 .593 .456 r
.43744 .78522 m .43565 .78421 L .43521 .77978 L p F P
0 g
s
.911 .601 .446 r
.4317 .77766 m .43521 .77978 L .43565 .78421 L p F P
0 g
s
.908 .639 .518 r
.43521 .77978 m .4317 .77766 L .43184 .77308 L p F P
0 g
s
.691 .689 .844 r
.52861 .80562 m .52885 .80599 L p .51706 .80633 L F P
0 g
s
.691 .689 .844 r
.51706 .80633 m .51876 .80558 L .52861 .80562 L p F P
0 g
s
.695 .705 .856 r
.51706 .80633 m .51876 .80558 L .51644 .80547 L closepath p F P
0 g
s
.65 .757 .928 r
.19727 .5712 m .18856 .57411 L .19161 .5768 L p F P
0 g
s
.65 .757 .928 r
.19161 .5768 m .20032 .5739 L .19727 .5712 L p F P
0 g
s
.929 .713 .589 r
.49516 .67924 m .49816 .68163 L .49717 .68636 L p F P
0 g
s
.334 .129 .446 r
.61962 .77783 m .6165 .77972 L .6163 .78398 L p F P
0 g
s
.651 .758 .928 r
.76754 .57689 m .77725 .57397 L .77936 .57666 L p F P
0 g
s
.651 .758 .928 r
.77725 .57397 m .76754 .57689 L .76541 .5742 L p F P
0 g
s
.65 .757 .928 r
.34173 .57131 m .33276 .57423 L .33559 .57691 L p F P
0 g
s
.65 .757 .928 r
.33559 .57691 m .34455 .57401 L .34173 .57131 L p F P
0 g
s
.651 .758 .928 r
.62355 .57693 m .63302 .57402 L .63536 .57671 L p F P
0 g
s
.651 .758 .928 r
.63302 .57402 m .62355 .57693 L .6212 .57425 L p F P
0 g
s
.86 .475 .314 r
.44523 .79227 m .44112 .79034 L .43948 .78623 L p F P
0 g
s
.861 .459 .273 r
.43744 .78522 m .43948 .78623 L .44112 .79034 L p F P
0 g
s
.65 .757 .928 r
.4862 .57133 m .47698 .57425 L .47957 .57694 L p F P
0 g
s
.65 .757 .928 r
.47957 .57694 m .48878 .57403 L .4862 .57133 L p F P
0 g
s
.681 .496 .63 r
.52907 .71429 m .53519 .71395 L .53602 .71924 L p F P
0 g
s
.681 .496 .63 r
.53602 .71924 m .5254 .71984 L .52907 .71429 L p F P
0 g
s
.893 .814 .763 r
.43723 .70758 m .43726 .70753 L .43743 .70772 L closepath p F P
0 g
s
.899 .81 .752 r
.43377 .713 m .43723 .70758 L .43743 .70772 L p F P
0 g
s
.919 .649 .513 r
.4285 .7709 m .43184 .77308 L .4317 .77766 L p F P
0 g
s
.913 .675 .565 r
.43184 .77308 m .4285 .7709 L .42914 .76619 L p F P
0 g
s
.682 .689 .85 r
.54013 .80517 m .54065 .80595 L p .52885 .80599 L F P
0 g
s
.682 .689 .85 r
.52885 .80599 m .5299 .80556 L .54013 .80517 L p F P
0 g
s
.681 .687 .849 r
.52885 .80599 m .5299 .80556 L .52861 .80562 L closepath p F P
0 g
s
.381 .27 .601 r
.62333 .76564 m .62555 .76399 L .62335 .76 L p F P
0 g
s
.373 .267 .603 r
.6294 .7553 m .62335 .76 L .62555 .76399 L p F P
0 g
s
.407 .312 .635 r
.62632 .75156 m .6294 .7553 L .62335 .76 L p F P
0 g
s
.419 .427 .762 r
.6167 .70895 m .61399 .70768 L .61557 .7058 L closepath p F P
0 g
s
.436 .451 .777 r
.61422 .70228 m .61101 .70086 L p .61399 .70768 L F P
0 g
s
.436 .451 .777 r
.61399 .70768 m .61557 .7058 L .61422 .70228 L p F P
0 g
s
.786 .586 .629 r
.50875 .70707 m .50798 .70341 L .50682 .70663 L closepath p F P
0 g
s
.397 .276 .597 r
.55381 .68601 m .55104 .68801 L .55164 .69304 L p F P
0 g
s
.003 0 0 r
.59797 .79854 m .59719 .79936 L .58781 .80289 L p F P
0 g
s
.5 .904 .912 r
.58572 .80284 m .58781 .80289 L .59719 .79936 L p F P
0 g
s
.45 .875 .923 r
.58781 .80289 m .58572 .80284 L .57653 .80554 L p F P
0 g
s
.65 .757 .928 r
.20906 .57099 m .20032 .5739 L .20336 .57659 L p F P
0 g
s
.65 .757 .928 r
.20336 .57659 m .21209 .57369 L .20906 .57099 L p F P
0 g
s
.917 .756 .666 r
.42744 .74684 m .42615 .75016 L .42348 .74748 L p F P
0 g
s
.917 .756 .666 r
.42348 .74748 m .42465 .74446 L .42744 .74684 L p F P
0 g
s
.91 .762 .686 r
.42744 .74684 m .42465 .74446 L .42692 .73932 L p F P
0 g
s
.729 .534 .627 r
.52465 .71986 m .51619 .7193 L .51852 .71414 L p F P
0 g
s
.763 .575 .642 r
.51121 .71305 m .51852 .71414 L .51619 .7193 L p F P
0 g
s
.651 .758 .928 r
.77936 .57666 m .7891 .57374 L .79118 .57643 L p F P
0 g
s
.651 .758 .928 r
.7891 .57374 m .77936 .57666 L .77725 .57397 L p F P
0 g
s
.65 .757 .928 r
.35354 .57109 m .34455 .57401 L .34735 .57669 L p F P
0 g
s
.65 .757 .928 r
.34735 .57669 m .35633 .57378 L .35354 .57109 L p F P
0 g
s
.651 .758 .928 r
.63536 .57671 m .64484 .5738 L .64717 .57648 L p F P
0 g
s
.651 .758 .928 r
.64484 .5738 m .63536 .57671 L .63302 .57402 L p F P
0 g
s
.65 .757 .928 r
.49803 .57111 m .48878 .57403 L .49135 .57672 L p F P
0 g
s
.65 .757 .928 r
.49135 .57672 m .50059 .57381 L .49803 .57111 L p F P
0 g
s
.902 .832 .767 r
.43723 .70758 m .43726 .70753 L .4353 .70485 L p F P
0 g
s
.902 .832 .767 r
.4353 .70485 m .43455 .70595 L .43723 .70758 L p F P
0 g
s
.906 .828 .758 r
.43723 .70758 m .43377 .713 L .4317 .71036 L p F P
0 g
s
.906 .828 .758 r
.4317 .71036 m .43455 .70595 L .43723 .70758 L p F P
0 g
s
.681 .688 .851 r
.5299 .80556 m .52861 .80562 L .52634 .80225 L p F P
0 g
s
.69 .692 .847 r
.52861 .80562 m .52634 .80225 L .51876 .80558 L closepath p F P
0 g
s
.694 .707 .857 r
.52382 .79789 m .52634 .80225 L .51876 .80558 L p F P
0 g
s
.694 .707 .857 r
.51454 .80283 m .52382 .79789 L p .51876 .80558 L F P
0 g
s
.694 .707 .857 r
.51876 .80558 m .51644 .80547 L .51454 .80283 L p F P
0 g
s
.418 .463 .8 r
.59903 .68129 m .60559 .68387 L .60346 .68768 L p F P
0 g
s
.411 .484 .824 r
.60063 .6776 m .59903 .68129 L .60559 .68387 L p F P
0 g
s
.681 .69 .852 r
.54013 .80517 m .53815 .80223 L .5299 .80556 L closepath p F P
0 g
s
.681 .688 .851 r
.53564 .79778 m .53815 .80223 L .5299 .80556 L p F P
0 g
s
.681 .688 .851 r
.52634 .80225 m .53564 .79778 L p .5299 .80556 L F P
0 g
s
.515 .884 .976 r
.57604 .80541 m .57653 .80554 L .58572 .80284 L p F P
0 g
s
.668 .704 .874 r
.551 .80411 m .55244 .8061 L p .54065 .80595 L F P
0 g
s
.668 .704 .874 r
.54065 .80595 m .54436 .80465 L .551 .80411 L p F P
0 g
s
.665 .682 .856 r
.54065 .80595 m .54436 .80465 L .54013 .80517 L closepath p F P
0 g
s
.617 .452 .636 r
.53519 .71395 m .54516 .71192 L p .54561 .71723 L F P
0 g
s
.617 .452 .636 r
.54561 .71723 m .53602 .71924 L .53519 .71395 L p F P
0 g
s
.624 .456 .634 r
.5444 .70671 m .54516 .71192 L .53519 .71395 L p F P
0 g
s
.416 .438 .776 r
.61422 .70228 m .61101 .70086 L .61278 .69852 L closepath p F P
0 g
s
.429 .444 .774 r
.61174 .69599 m .61278 .69852 L .61101 .70086 L p F P
0 g
s
.429 .444 .774 r
.60748 .6942 m .61174 .69599 L p .61101 .70086 L F P
0 g
s
.65 .757 .928 r
.22085 .57078 m .21209 .57369 L .21511 .57638 L p F P
0 g
s
.65 .757 .928 r
.21511 .57638 m .22386 .57348 L .22085 .57078 L p F P
0 g
s
.651 .758 .928 r
.79118 .57643 m .80094 .57351 L .80301 .57619 L p F P
0 g
s
.651 .758 .928 r
.80094 .57351 m .79118 .57643 L .7891 .57374 L p F P
0 g
s
.873 .855 .821 r
.44817 .68774 m .44658 .68492 L .44181 .69076 L p F P
0 g
s
.873 .855 .821 r
.44395 .69291 m .44817 .68774 L p .44181 .69076 L F P
0 g
s
.65 .757 .928 r
.36535 .57087 m .35633 .57378 L .35912 .57647 L p F P
0 g
s
.65 .757 .928 r
.35912 .57647 m .36812 .57356 L .36535 .57087 L p F P
0 g
s
.651 .758 .928 r
.64717 .57648 m .65667 .57357 L .65898 .57626 L p F P
0 g
s
.651 .758 .928 r
.65667 .57357 m .64717 .57648 L .64484 .5738 L p F P
0 g
s
.691 .706 .859 r
.51644 .80547 m .51454 .80283 L .50904 .80521 L closepath p F P
0 g
s
.651 .757 .928 r
.50986 .57089 m .50059 .57381 L .50314 .57649 L p F P
0 g
s
.651 .757 .928 r
.50314 .57649 m .5124 .57358 L .50986 .57089 L p F P
0 g
s
.118 .577 .918 r
.45299 .79868 m .45432 .79891 L p .4643 .80229 L F P
0 g
s
.695 .154 0 r
.45299 .79868 m .45221 .79797 L .45432 .79891 L closepath p F P
0 g
s
.924 .687 .561 r
.42599 .76395 m .42914 .76619 L .4285 .7709 L p F P
0 g
s
.917 .704 .6 r
.42914 .76619 m .42599 .76395 L .42705 .75912 L p F P
0 g
s
.41 .354 .684 r
.62682 .74236 m .62389 .74002 L .62584 .73832 L closepath p F P
0 g
s
.423 .376 .701 r
.62389 .74002 m .62584 .73832 L .62424 .73229 L p F P
0 g
s
.424 .454 .787 r
.60346 .68768 m .60927 .68999 L p .60748 .6942 L F P
0 g
s
.396 .451 .8 r
.60346 .68768 m .60927 .68999 L .60681 .68439 L p F P
0 g
s
.396 .451 .8 r
.60681 .68439 m .60559 .68387 L .60346 .68768 L p F P
0 g
s
.411 .449 .79 r
.61174 .69599 m .60748 .6942 L .60967 .69091 L closepath p F P
0 g
s
.424 .454 .787 r
.60927 .68999 m .60967 .69091 L .60748 .6942 L p F P
0 g
s
.792 .309 .068 r
.45221 .79797 m .44814 .79604 L .44523 .79227 L p F P
0 g
s
.775 .274 .005 r
.44112 .79034 m .44523 .79227 L .44814 .79604 L p F P
0 g
s
.65 .757 .928 r
.23264 .57057 m .22386 .57348 L .22686 .57617 L p F P
0 g
s
.65 .757 .928 r
.22686 .57617 m .23563 .57327 L .23264 .57057 L p F P
0 g
s
.651 .758 .928 r
.80301 .57619 m .81279 .57327 L .81484 .57596 L p F P
0 g
s
.651 .758 .928 r
.81279 .57327 m .80301 .57619 L .80094 .57351 L p F P
0 g
s
.65 .757 .928 r
.37716 .57064 m .36812 .57356 L .37089 .57625 L p F P
0 g
s
.65 .757 .928 r
.37089 .57625 m .37992 .57334 L .37716 .57064 L p F P
0 g
s
.651 .758 .928 r
.65898 .57626 m .66851 .57334 L .67079 .57603 L p F P
0 g
s
.651 .758 .928 r
.66851 .57334 m .65898 .57626 L .65667 .57357 L p F P
0 g
s
.651 .757 .928 r
.52169 .57066 m .5124 .57358 L .51493 .57627 L p F P
0 g
s
.651 .757 .928 r
.51493 .57627 m .52421 .57336 L .52169 .57066 L p F P
0 g
s
.905 .807 .74 r
.4304 .71845 m .42775 .72287 L .43044 .72481 L p F P
0 g
s
.907 .803 .733 r
.43044 .72481 m .42954 .7264 L .42719 .72386 L p F P
0 g
s
.907 .803 .733 r
.42719 .72386 m .42775 .72287 L .43044 .72481 L p F P
0 g
s
.699 .736 .879 r
.51201 .79879 m .51454 .80283 L .50904 .80521 L p F P
0 g
s
.699 .736 .879 r
.50273 .80381 m .51201 .79879 L p .50904 .80521 L F P
0 g
s
.699 .736 .879 r
.50904 .80521 m .5031 .80425 L .50273 .80381 L p F P
0 g
s
.788 .589 .631 r
.51121 .71305 m .50998 .71277 L .50875 .70707 L p F P
0 g
s
.788 .588 .63 r
.50682 .70663 m .50875 .70707 L .50998 .71277 L p F P
0 g
s
.651 .74 .915 r
.55244 .8061 m .56179 .80332 L .56425 .80611 L p F P
0 g
s
.654 .697 .877 r
.56115 .80235 m .56179 .80332 L .55244 .8061 L p F P
0 g
s
.654 .697 .877 r
.55244 .8061 m .551 .80411 L .56115 .80235 L p F P
0 g
s
.665 .684 .858 r
.54436 .80465 m .54013 .80517 L .53815 .80223 L p F P
0 g
s
.533 .772 .986 r
.47596 .80516 m .47912 .80508 L .47653 .8028 L p F P
0 g
s
.533 .772 .986 r
.47653 .8028 m .47072 .80357 L .47596 .80516 L p F P
0 g
s
.173 .671 .914 r
.46735 .80386 m .47072 .80357 L .47596 .80516 L p F P
0 g
s
.651 .758 .928 r
.81484 .57596 m .82465 .57304 L .82668 .57572 L p F P
0 g
s
.651 .758 .928 r
.82465 .57304 m .81484 .57596 L .81279 .57327 L p F P
0 g
s
.65 .757 .928 r
.24443 .57035 m .23563 .57327 L .23861 .57596 L p F P
0 g
s
.65 .757 .928 r
.23861 .57596 m .2474 .57305 L .24443 .57035 L p F P
0 g
s
.006 0 0 r
.59719 .79936 m .60444 .7958 L .59797 .79854 L closepath p F P
0 g
s
.149 0 .051 r
.60657 .79462 m .60444 .7958 L .59797 .79854 L p F P
0 g
s
.149 0 .051 r
.60771 .79184 m .60657 .79462 L p .59797 .79854 L F P
0 g
s
.651 .758 .928 r
.67079 .57603 m .68034 .57312 L .68261 .57581 L p F P
0 g
s
.651 .758 .928 r
.68034 .57312 m .67079 .57603 L .66851 .57334 L p F P
0 g
s
.65 .757 .928 r
.38897 .57042 m .37992 .57334 L .38267 .57603 L p F P
0 g
s
.65 .757 .928 r
.38267 .57603 m .39171 .57312 L .38897 .57042 L p F P
0 g
s
.651 .757 .928 r
.53352 .57043 m .52421 .57336 L .52673 .57605 L p F P
0 g
s
.651 .757 .928 r
.52673 .57605 m .53603 .57313 L .53352 .57043 L p F P
0 g
s
.69 .509 .638 r
.52479 .72072 m .5254 .71984 L .52465 .71986 L closepath p F P
0 g
s
.707 .521 .635 r
.52465 .71986 m .51619 .7193 L p .5222 .72526 L F P
0 g
s
.707 .521 .635 r
.5222 .72526 m .52479 .72072 L .52465 .71986 L p F P
0 g
s
.927 .717 .598 r
.42409 .75681 m .42705 .75912 L .42599 .76395 L p F P
0 g
s
.92 .73 .628 r
.42705 .75912 m .42409 .75681 L .42552 .75189 L p F P
0 g
s
.515 .884 .976 r
.58572 .80284 m .58543 .80278 L .57604 .80541 L p F P
0 g
s
.613 .825 .982 r
.58543 .80278 m .57604 .80541 L .57361 .8036 L p F P
0 g
s
.619 .815 .976 r
.56425 .80611 m .57361 .8036 L .57604 .80541 L p F P
0 g
s
.651 .758 .928 r
.82668 .57572 m .8365 .5728 L .83852 .57549 L p F P
0 g
s
.651 .758 .928 r
.8365 .5728 m .82668 .57572 L .82465 .57304 L p F P
0 g
s
.177 0 .111 r
.60657 .79462 m .6142 .78854 L .60771 .79184 L closepath p F P
0 g
s
.299 .019 .308 r
.61588 .78665 m .6163 .78398 L p .60771 .79184 L F P
0 g
s
.299 .019 .308 r
.60771 .79184 m .6142 .78854 L .61588 .78665 L p F P
0 g
s
.918 .799 .713 r
.42954 .7264 m .42719 .72386 L .42448 .72912 L p F P
0 g
s
.918 .799 .713 r
.42448 .72912 m .42684 .73165 L .42954 .7264 L p F P
0 g
s
.65 .757 .928 r
.25623 .57014 m .2474 .57305 L .25037 .57575 L p F P
0 g
s
.65 .757 .928 r
.25037 .57575 m .25918 .57284 L .25623 .57014 L p F P
0 g
s
.645 .73 .911 r
.57361 .8036 m .56425 .80611 L .56179 .80332 L p F P
0 g
s
.679 .509 .65 r
.5254 .71984 m .53602 .71924 L p .53502 .72476 L F P
0 g
s
.679 .509 .65 r
.52479 .72072 m .5254 .71984 L p .53502 .72476 L F P
0 g
s
.873 .855 .821 r
.44181 .69076 m .44253 .69209 L .44395 .69291 L p F P
0 g
s
.89 .847 .794 r
.44253 .69209 m .44395 .69291 L .44345 .69357 L closepath p F P
0 g
s
.353 .224 .562 r
.62555 .76399 m .62333 .76564 L .62377 .77052 L p F P
0 g
s
.651 .758 .928 r
.68261 .57581 m .69218 .57289 L .69443 .57558 L p F P
0 g
s
.651 .758 .928 r
.69218 .57289 m .68261 .57581 L .68034 .57312 L p F P
0 g
s
.878 .867 .824 r
.45065 .67985 m .45133 .67908 L .45199 .68055 L closepath p F P
0 g
s
.891 .86 .804 r
.44658 .68492 m .45065 .67985 L .45199 .68055 L p F P
0 g
s
.65 .757 .928 r
.40079 .5702 m .39171 .57312 L .39444 .57581 L p F P
0 g
s
.65 .757 .928 r
.39444 .57581 m .40351 .5729 L .40079 .5702 L p F P
0 g
s
.651 .757 .928 r
.54536 .57021 m .53603 .57313 L .53853 .57582 L p F P
0 g
s
.651 .757 .928 r
.53853 .57582 m .54785 .57291 L .54536 .57021 L p F P
0 g
s
.538 .39 .628 r
.54516 .71192 m .5444 .70671 L .55301 .7033 L p F P
0 g
s
.535 .387 .627 r
.55269 .70123 m .55301 .7033 L .5444 .70671 L p F P
0 g
s
.535 .387 .627 r
.54724 .70008 m .55269 .70123 L p .5444 .70671 L F P
0 g
s
.861 .459 .273 r
.43609 .78597 m .43744 .78522 L p .44112 .79034 L F P
0 g
s
.894 .54 .367 r
.43609 .78597 m .43565 .78421 L .43744 .78522 L closepath p F P
0 g
s
.649 .756 .928 r
.12348 .5697 m .11488 .5726 L .11806 .5753 L p F P
0 g
s
.649 .756 .928 r
.11806 .5753 m .12664 .57241 L .12348 .5697 L p F P
0 g
s
.902 .853 .784 r
.44345 .69357 m .43938 .6992 L .43765 .69644 L p F P
0 g
s
.902 .853 .784 r
.44253 .69209 m .44345 .69357 L p .43765 .69644 L F P
0 g
s
.788 .588 .63 r
.50998 .71277 m .50502 .71164 L .50682 .70663 L p F P
0 g
s
.826 .621 .626 r
.5015 .70496 m .50682 .70663 L .50502 .71164 L p F P
0 g
s
.794 .595 .632 r
.50299 .70006 m .5015 .70496 L .50682 .70663 L p F P
0 g
s
.538 .383 .619 r
.55269 .70123 m .54724 .70008 L .55228 .69812 L closepath p F P
0 g
s
.537 .374 .608 r
.55164 .69304 m .55228 .69812 L .54724 .70008 L p F P
0 g
s
.858 .649 .618 r
.49853 .69812 m .50299 .70006 L .5015 .70496 L p F P
0 g
s
.851 .638 .614 r
.50299 .70006 m .49853 .69812 L .49978 .6933 L p F P
0 g
s
.921 .754 .658 r
.42552 .75189 m .42615 .75016 L .42348 .74748 L p F P
0 g
s
.679 .509 .65 r
.53502 .72476 m .52569 .72539 L .52479 .72072 L p F P
0 g
s
.719 .536 .642 r
.52569 .72539 m .52479 .72072 L .5222 .72526 L closepath p F P
0 g
s
.92 .778 .687 r
.42692 .73932 m .42435 .73686 L .42208 .74201 L p F P
0 g
s
.92 .778 .687 r
.42208 .74201 m .42465 .74446 L .42692 .73932 L p F P
0 g
s
.447 .782 .998 r
.47072 .80357 m .4654 .80278 L .46735 .80386 L closepath p F P
0 g
s
.651 .758 .928 r
.83852 .57549 m .84836 .57256 L .85036 .57525 L p F P
0 g
s
.651 .758 .928 r
.84836 .57256 m .83852 .57549 L .8365 .5728 L p F P
0 g
s
.65 .757 .928 r
.26803 .56992 m .25918 .57284 L .26213 .57553 L p F P
0 g
s
.65 .757 .928 r
.26213 .57553 m .27097 .57262 L .26803 .56992 L p F P
0 g
s
.651 .758 .928 r
.69443 .57558 m .70402 .57266 L .70625 .57535 L p F P
0 g
s
.651 .758 .928 r
.70402 .57266 m .69443 .57558 L .69218 .57289 L p F P
0 g
s
.65 .757 .928 r
.41261 .56997 m .40351 .5729 L .40622 .57559 L p F P
0 g
s
.65 .757 .928 r
.40622 .57559 m .41532 .57268 L .41261 .56997 L p F P
0 g
s
.651 .757 .928 r
.5572 .56998 m .54785 .57291 L .55033 .5756 L p F P
0 g
s
.651 .757 .928 r
.55033 .5756 m .55967 .57268 L .5572 .56998 L p F P
0 g
s
.763 .575 .642 r
.51047 .71502 m .51121 .71305 L p .51619 .7193 L F P
0 g
s
.788 .59 .634 r
.51047 .71502 m .51121 .71305 L .50998 .71277 L closepath p F P
0 g
s
.668 .704 .874 r
.551 .80411 m .54996 .8027 L .54436 .80465 L closepath p F P
0 g
s
.665 .684 .858 r
.54747 .79843 m .54996 .8027 L .54436 .80465 L p F P
0 g
s
.665 .684 .858 r
.53815 .80223 m .54747 .79843 L p .54436 .80465 L F P
0 g
s
.91 .824 .75 r
.43377 .713 m .4317 .71036 L .42833 .71581 L p F P
0 g
s
.91 .824 .75 r
.42833 .71581 m .4304 .71845 L .43377 .713 L p F P
0 g
s
.649 .757 .928 r
.13526 .56951 m .12664 .57241 L .1298 .57511 L p F P
0 g
s
.649 .757 .928 r
.1298 .57511 m .13841 .57221 L .13526 .56951 L p F P
0 g
s
.398 .389 .732 r
.62035 .7195 m .62184 .71764 L p .62338 .72487 L F P
0 g
s
.398 .389 .732 r
.62338 .72487 m .62171 .72383 L .62035 .7195 L p F P
0 g
s
.393 .399 .747 r
.62035 .7195 m .6192 .7161 L .62184 .71764 L closepath p F P
0 g
s
.892 .68 .609 r
.49609 .69113 m .49978 .6933 L .49853 .69812 L p F P
0 g
s
.888 .672 .604 r
.49978 .6933 m .49609 .69113 L .49717 .68636 L p F P
0 g
s
.396 .389 .734 r
.6224 .726 m .62171 .72383 L .62338 .72487 L closepath p F P
0 g
s
.651 .758 .928 r
.85036 .57525 m .86023 .57232 L .8622 .57501 L p F P
0 g
s
.651 .758 .928 r
.86023 .57232 m .85036 .57525 L .84836 .57256 L p F P
0 g
s
.401 .378 .719 r
.6224 .726 m .62338 .72487 L p .62425 .73228 L F P
0 g
s
.401 .378 .719 r
.62425 .73228 m .62424 .73228 L .6224 .726 L p F P
0 g
s
.65 .757 .928 r
.27984 .5697 m .27097 .57262 L .27389 .57532 L p F P
0 g
s
.65 .757 .928 r
.27389 .57532 m .28275 .57241 L .27984 .5697 L p F P
0 g
s
.61 .042 0 r
.45221 .79797 m .45299 .79868 L .45033 .79772 L p F P
0 g
s
.61 .042 0 r
.45033 .79772 m .44814 .79604 L .45221 .79797 L p F P
0 g
s
.651 .758 .928 r
.70625 .57535 m .71587 .57243 L .71807 .57512 L p F P
0 g
s
.651 .758 .928 r
.71587 .57243 m .70625 .57535 L .70402 .57266 L p F P
0 g
s
.394 .399 .746 r
.62184 .71764 m .6192 .7161 L .61808 .71278 L p F P
0 g
s
.65 .757 .928 r
.42444 .56975 m .41532 .57268 L .41801 .57537 L p F P
0 g
s
.65 .757 .928 r
.41801 .57537 m .42712 .57245 L .42444 .56975 L p F P
0 g
s
.651 .757 .928 r
.56905 .56976 m .55967 .57268 L .56213 .57537 L p F P
0 g
s
.651 .757 .928 r
.56213 .57537 m .5715 .57246 L .56905 .56976 L p F P
0 g
s
.394 .399 .746 r
.61808 .71278 m .61968 .71059 L p .62184 .71764 L F P
0 g
s
.389 .41 .761 r
.61808 .71278 m .6167 .70895 L .61968 .71059 L closepath p F P
0 g
s
.771 .58 .64 r
.50998 .71277 m .50502 .71164 L p .50914 .71814 L F P
0 g
s
.771 .58 .64 r
.50914 .71814 m .51047 .71502 L .50998 .71277 L p F P
0 g
s
.65 .757 .928 r
.14704 .56931 m .13841 .57221 L .14154 .57491 L p F P
0 g
s
.65 .757 .928 r
.14154 .57491 m .15017 .57202 L .14704 .56931 L p F P
0 g
s
.707 .521 .635 r
.51619 .7193 m .51381 .72448 L .5222 .72526 L p F P
0 g
s
.763 .575 .644 r
.51124 .71851 m .51619 .7193 L .51381 .72448 L p F P
0 g
s
.763 .575 .642 r
.51619 .7193 m .51124 .71851 L .51047 .71502 L p F P
0 g
s
.651 .758 .928 r
.8622 .57501 m .87209 .57207 L .87405 .57476 L p F P
0 g
s
.651 .758 .928 r
.87209 .57207 m .8622 .57501 L .86023 .57232 L p F P
0 g
s
.618 .454 .637 r
.5366 .72289 m .54561 .71723 L .53602 .71924 L closepath p F P
0 g
s
.679 .509 .65 r
.53602 .71924 m .5366 .72289 L .53502 .72476 L p F P
0 g
s
.401 .283 .602 r
.55614 .68981 m .55164 .69304 L .55228 .69812 L p F P
0 g
s
.397 .276 .597 r
.55164 .69304 m .55614 .68981 L .55381 .68601 L p F P
0 g
s
.65 .757 .928 r
.29164 .56948 m .28275 .57241 L .28566 .5751 L p F P
0 g
s
.65 .757 .928 r
.28566 .5751 m .29454 .57219 L .29164 .56948 L p F P
0 g
s
.651 .758 .928 r
.71807 .57512 m .72771 .5722 L .7299 .57489 L p F P
0 g
s
.651 .758 .928 r
.72771 .5722 m .71807 .57512 L .71587 .57243 L p F P
0 g
s
.65 .757 .928 r
.43627 .56953 m .42712 .57245 L .4298 .57515 L p F P
0 g
s
.65 .757 .928 r
.4298 .57515 m .43893 .57223 L .43627 .56953 L p F P
0 g
s
.651 .757 .928 r
.58089 .56953 m .5715 .57246 L .57394 .57515 L p F P
0 g
s
.651 .757 .928 r
.57394 .57515 m .58332 .57223 L .58089 .56953 L p F P
0 g
s
.399 .378 .72 r
.62424 .73229 m .62424 .73228 L .62425 .73228 L closepath p F P
0 g
s
.376 .345 .697 r
.62425 .73228 m .62424 .73229 L .62584 .73832 L p F P
0 g
s
.376 .345 .697 r
.62584 .73832 m .62833 .73571 L .62425 .73228 L p F P
0 g
s
.378 .36 .713 r
.62786 .72818 m .62425 .73228 L .62833 .73571 L p F P
0 g
s
.401 .378 .719 r
.62338 .72487 m .62786 .72818 L .62425 .73228 L p F P
0 g
s
.93 .743 .628 r
.42274 .74951 m .42552 .75189 L .42409 .75681 L p F P
0 g
s
.921 .754 .658 r
.42348 .74748 m .42274 .74951 L .42552 .75189 L p F P
0 g
s
.676 .729 .89 r
.5031 .80425 m .50273 .80381 L .50163 .80421 L closepath p F P
0 g
s
.93 .719 .596 r
.49421 .68397 m .49717 .68636 L .49609 .69113 L p F P
0 g
s
.929 .713 .589 r
.49717 .68636 m .49421 .68397 L .49516 .67924 L p F P
0 g
s
.708 .711 .85 r
.49092 .80475 m .49379 .80333 L .50163 .80421 L p F P
0 g
s
.672 .696 .864 r
.50018 .80026 m .49379 .80333 L .50163 .80421 L p F P
0 g
s
.672 .696 .864 r
.50163 .80421 m .50273 .80381 L .50018 .80026 L p F P
0 g
s
.65 .757 .928 r
.15883 .56911 m .15017 .57202 L .15329 .57472 L p F P
0 g
s
.65 .757 .928 r
.15329 .57472 m .16194 .57182 L .15883 .56911 L p F P
0 g
s
.39 .409 .76 r
.61968 .71059 m .6167 .70895 L .61557 .7058 L p F P
0 g
s
.651 .758 .928 r
.87405 .57476 m .88396 .57183 L .8859 .57452 L p F P
0 g
s
.651 .758 .928 r
.88396 .57183 m .87405 .57476 L .87209 .57207 L p F P
0 g
s
.65 .757 .928 r
.30346 .56927 m .29454 .57219 L .29743 .57488 L p F P
0 g
s
.65 .757 .928 r
.29743 .57488 m .30633 .57197 L .30346 .56927 L p F P
0 g
s
.651 .758 .928 r
.7299 .57489 m .73957 .57197 L .74174 .57466 L p F P
0 g
s
.651 .758 .928 r
.73957 .57197 m .7299 .57489 L .72771 .5722 L p F P
0 g
s
.77 .579 .64 r
.51124 .71851 m .51047 .71502 L .50914 .71814 L closepath p F P
0 g
s
.65 .757 .928 r
.4481 .5693 m .43893 .57223 L .44159 .57492 L p F P
0 g
s
.65 .757 .928 r
.44159 .57492 m .45074 .57201 L .4481 .5693 L p F P
0 g
s
.651 .757 .928 r
.59274 .5693 m .58332 .57223 L .58575 .57493 L p F P
0 g
s
.651 .757 .928 r
.58575 .57493 m .59516 .57201 L .59274 .5693 L p F P
0 g
s
.663 .703 .876 r
.55931 .79957 m .56115 .80235 L .551 .80411 L p F P
0 g
s
.663 .703 .876 r
.551 .80411 m .54996 .8027 L .55931 .79957 L p F P
0 g
s
.711 .644 .78 r
.52382 .79789 m .51454 .80283 L .51201 .79879 L p F P
0 g
s
.697 .633 .781 r
.53564 .79778 m .52634 .80225 L .52382 .79789 L p F P
0 g
s
.334 .129 .446 r
.6163 .78398 m .6182 .78284 L .61962 .77783 L p F P
0 g
s
.315 .112 .437 r
.62392 .77512 m .61962 .77783 L .6182 .78284 L p F P
0 g
s
.367 .2 .518 r
.61962 .77783 m .62392 .77512 L .62377 .77052 L p F P
0 g
s
.39 .409 .76 r
.61557 .7058 m .61694 .70369 L p .61968 .71059 L F P
0 g
s
.385 .42 .774 r
.61557 .7058 m .61422 .70228 L .61694 .70369 L closepath p F P
0 g
s
.65 .757 .928 r
.17062 .56891 m .16194 .57182 L .16504 .57452 L p F P
0 g
s
.65 .757 .928 r
.16504 .57452 m .17372 .57161 L .17062 .56891 L p F P
0 g
s
.901 .85 .783 r
.43938 .6992 m .43765 .69644 L .4336 .70208 L p F P
0 g
s
.901 .85 .783 r
.4336 .70208 m .4353 .70485 L .43938 .6992 L p F P
0 g
s
.671 .737 .9 r
.47912 .80508 m .48835 .80183 L .49092 .80475 L p F P
0 g
s
.702 .719 .862 r
.48835 .80183 m .47912 .80508 L .47653 .8028 L p F P
0 g
s
.679 .51 .65 r
.52569 .72539 m .53502 .72476 L .52994 .73073 L p F P
0 g
s
.679 .51 .65 r
.52994 .73073 m .52676 .73094 L .52569 .72539 L p F P
0 g
s
.719 .536 .642 r
.5222 .72526 m .52569 .72539 L .52676 .73094 L p F P
0 g
s
.721 .664 .794 r
.51201 .79879 m .50273 .80381 L .50018 .80026 L p F P
0 g
s
.388 .304 .64 r
.62846 .74981 m .62632 .75156 L .6294 .7553 L p F P
0 g
s
.405 .332 .662 r
.62632 .75156 m .62846 .74981 L .62727 .74418 L p F P
0 g
s
.65 .757 .928 r
.31527 .56905 m .30633 .57197 L .3092 .57466 L p F P
0 g
s
.65 .757 .928 r
.3092 .57466 m .31813 .57175 L .31527 .56905 L p F P
0 g
s
.651 .758 .928 r
.74174 .57466 m .75142 .57174 L .75357 .57443 L p F P
0 g
s
.651 .758 .928 r
.75142 .57174 m .74174 .57466 L .73957 .57197 L p F P
0 g
s
.65 .757 .928 r
.45993 .56908 m .45074 .57201 L .45338 .5747 L p F P
0 g
s
.65 .757 .928 r
.45338 .5747 m .46256 .57178 L .45993 .56908 L p F P
0 g
s
.651 .757 .928 r
.6046 .56908 m .59516 .57201 L .59756 .5747 L p F P
0 g
s
.651 .757 .928 r
.59756 .5747 m .60699 .57178 L .6046 .56908 L p F P
0 g
s
.118 .577 .918 r
.4643 .80229 m .46034 .80033 L .45299 .79868 L p F P
0 g
s
0 .5 .791 r
.46034 .80033 m .45299 .79868 L .45033 .79772 L p F P
0 g
s
.366 .265 .606 r
.55781 .68267 m .55381 .68601 L .55614 .68981 L p F P
0 g
s
.36 .255 .598 r
.55381 .68601 m .55781 .68267 L .55714 .67758 L p F P
0 g
s
.911 .601 .446 r
.43565 .78421 m .43215 .78209 L .4317 .77766 L p F P
0 g
s
.921 .608 .434 r
.42836 .77549 m .4317 .77766 L .43215 .78209 L p F P
0 g
s
.919 .649 .513 r
.4317 .77766 m .42836 .77549 L .4285 .7709 L p F P
0 g
s
.902 .534 .331 r
.43565 .78421 m .43609 .78597 L .43338 .78634 L p F P
0 g
s
.902 .534 .331 r
.43215 .78209 m .43565 .78421 L p .43338 .78634 L F P
0 g
s
.719 .536 .642 r
.52676 .73094 m .51911 .73065 L .5222 .72526 L p F P
0 g
s
.743 .567 .655 r
.51381 .72448 m .5222 .72526 L .51911 .73065 L p F P
0 g
s
.741 .735 .846 r
.49379 .80333 m .49092 .80475 L .48835 .80183 L p F P
0 g
s
.381 .335 .681 r
.62584 .73832 m .62833 .73571 L p .62801 .74345 L F P
0 g
s
.381 .335 .681 r
.62801 .74345 m .62682 .74236 L .62584 .73832 L p F P
0 g
s
.65 .757 .928 r
.18242 .5687 m .17372 .57161 L .1768 .57431 L p F P
0 g
s
.65 .757 .928 r
.1768 .57431 m .18549 .57141 L .18242 .5687 L p F P
0 g
s
.68 .632 .795 r
.54747 .79843 m .53815 .80223 L .53564 .79778 L p F P
0 g
s
.651 .758 .928 r
.75357 .57443 m .76328 .57151 L .76541 .5742 L p F P
0 g
s
.651 .758 .928 r
.76328 .57151 m .75357 .57443 L .75142 .57174 L p F P
0 g
s
.65 .757 .928 r
.32709 .56882 m .31813 .57175 L .32098 .57445 L p F P
0 g
s
.65 .757 .928 r
.32098 .57445 m .32993 .57153 L .32709 .56882 L p F P
0 g
s
.651 .758 .928 r
.60938 .57447 m .61883 .57155 L .6212 .57425 L p F P
0 g
s
.651 .757 .928 r
.61646 .56885 m .60699 .57178 L .60938 .57447 L p F P
0 g
s
.651 .757 .928 r
.60938 .57447 m .61883 .57155 L .61646 .56885 L p F P
0 g
s
.65 .757 .928 r
.47177 .56885 m .46256 .57178 L .46518 .57448 L p F P
0 g
s
.65 .757 .928 r
.46518 .57448 m .47438 .57156 L .47177 .56885 L p F P
0 g
s
.924 .796 .702 r
.42684 .73165 m .42448 .72912 L .42199 .73433 L p F P
0 g
s
.924 .796 .702 r
.42199 .73433 m .42435 .73686 L .42684 .73165 L p F P
0 g
s
.386 .42 .774 r
.61694 .70369 m .61422 .70228 L .61278 .69852 L p F P
0 g
s
.972 .768 .57 r
.49516 .67924 m .49303 .67659 L .49203 .68133 L p F P
0 g
s
.972 .768 .57 r
.49203 .68133 m .49421 .68397 L .49516 .67924 L p F P
0 g
s
.763 .575 .644 r
.51381 .72448 m .51253 .72428 L .51124 .71851 L p F P
0 g
s
.771 .58 .64 r
.50914 .71814 m .51124 .71851 L .51253 .72428 L p F P
0 g
s
.93 .66 .506 r
.42534 .76866 m .4285 .7709 L .42836 .77549 L p F P
0 g
s
.924 .687 .561 r
.4285 .7709 m .42534 .76866 L .42599 .76395 L p F P
0 g
s
.263 .014 .335 r
.61588 .78665 m .6182 .78284 L .6163 .78398 L closepath p F P
0 g
s
0 0 0 r
.60444 .7958 m .59719 .79936 L .59484 .7998 L p F P
0 g
s
.5 .904 .912 r
.59719 .79936 m .59484 .7998 L p .58572 .80284 L F P
0 g
s
.551 .401 .63 r
.54516 .71192 m .55385 .70859 L p .54621 .71706 L F P
0 g
s
.551 .401 .63 r
.54621 .71706 m .54591 .71704 L .54516 .71192 L p F P
0 g
s
.538 .39 .628 r
.55301 .7033 m .55385 .70859 L .54516 .71192 L p F P
0 g
s
.617 .452 .636 r
.54516 .71192 m .54591 .71704 L .54561 .71723 L p F P
0 g
s
.914 .823 .743 r
.42775 .72287 m .4304 .71845 L .42833 .71581 L p F P
0 g
s
.65 .757 .928 r
.19422 .56849 m .18549 .57141 L .18856 .57411 L p F P
0 g
s
.65 .757 .928 r
.18856 .57411 m .19727 .5712 L .19422 .56849 L p F P
0 g
s
.486 .788 .998 r
.47072 .80357 m .47653 .8028 L p .46472 .80236 L F P
0 g
s
.486 .788 .998 r
.46472 .80236 m .4654 .80278 L .47072 .80357 L p F P
0 g
s
.627 .471 .651 r
.53692 .72462 m .5366 .72289 L .54561 .71723 L p F P
0 g
s
.675 .503 .645 r
.53692 .72462 m .5366 .72289 L .53502 .72476 L closepath p F P
0 g
s
.651 .758 .928 r
.76541 .5742 m .77514 .57128 L .77725 .57397 L p F P
0 g
s
.651 .758 .928 r
.77514 .57128 m .76541 .5742 L .76328 .57151 L p F P
0 g
s
.65 .757 .928 r
.33891 .5686 m .32993 .57153 L .33276 .57423 L p F P
0 g
s
.65 .757 .928 r
.33276 .57423 m .34173 .57131 L .33891 .5686 L p F P
0 g
s
.884 .886 .829 r
.45065 .67985 m .45133 .67908 L .45035 .67606 L p F P
0 g
s
.651 .758 .928 r
.6212 .57425 m .63067 .57133 L .63302 .57402 L p F P
0 g
s
.651 .758 .928 r
.63067 .57133 m .6212 .57425 L .61883 .57155 L p F P
0 g
s
.65 .757 .928 r
.48361 .56863 m .47438 .57156 L .47698 .57425 L p F P
0 g
s
.65 .757 .928 r
.47698 .57425 m .4862 .57133 L .48361 .56863 L p F P
0 g
s
.378 .375 .729 r
.62666 .72084 m .62338 .72487 L .62786 .72818 L p F P
0 g
s
.398 .389 .732 r
.62184 .71764 m .62666 .72084 L .62338 .72487 L p F P
0 g
s
.884 .886 .829 r
.45035 .67606 m .44797 .67872 L .45065 .67985 L p F P
0 g
s
.894 .879 .813 r
.45065 .67985 m .44658 .68492 L .44528 .682 L p F P
0 g
s
.894 .879 .813 r
.44528 .682 m .44797 .67872 L .45065 .67985 L p F P
0 g
s
.894 .859 .799 r
.44128 .69145 m .44181 .69076 L .44253 .69209 L closepath p F P
0 g
s
.902 .853 .784 r
.43765 .69644 m .44128 .69145 L .44253 .69209 L p F P
0 g
s
.775 .274 .005 r
.44814 .79604 m .4442 .79406 L .44112 .79034 L p F P
0 g
s
.753 .235 0 r
.43715 .78836 m .44112 .79034 L .4442 .79406 L p F P
0 g
s
.861 .459 .273 r
.44112 .79034 m .43715 .78836 L .43609 .78597 L p F P
0 g
s
.928 .771 .666 r
.42348 .74748 m .42465 .74446 L .42208 .74201 L p F P
0 g
s
.65 .757 .928 r
.20602 .56828 m .19727 .5712 L .20032 .5739 L p F P
0 g
s
.65 .757 .928 r
.20032 .5739 m .20906 .57099 L .20602 .56828 L p F P
0 g
s
.675 .504 .646 r
.53502 .72476 m .53692 .72462 L .53794 .73012 L p F P
0 g
s
.675 .504 .646 r
.53794 .73012 m .52994 .73073 L .53502 .72476 L p F P
0 g
s
.651 .758 .928 r
.77725 .57397 m .787 .57104 L .7891 .57374 L p F P
0 g
s
.651 .758 .928 r
.787 .57104 m .77725 .57397 L .77514 .57128 L p F P
0 g
s
.379 .334 .682 r
.62727 .74418 m .62682 .74236 L .62801 .74345 L closepath p F P
0 g
s
.771 .58 .64 r
.50502 .71164 m .50322 .71665 L .50914 .71814 L p F P
0 g
s
.835 .633 .63 r
.49999 .70988 m .50502 .71164 L .50322 .71665 L p F P
0 g
s
.826 .621 .626 r
.50502 .71164 m .49999 .70988 L .5015 .70496 L p F P
0 g
s
.65 .757 .928 r
.35073 .56838 m .34173 .57131 L .34455 .57401 L p F P
0 g
s
.65 .757 .928 r
.34455 .57401 m .35354 .57109 L .35073 .56838 L p F P
0 g
s
.651 .758 .928 r
.63302 .57402 m .64252 .5711 L .64484 .5738 L p F P
0 g
s
.651 .758 .928 r
.64252 .5711 m .63302 .57402 L .63067 .57133 L p F P
0 g
s
.386 .42 .774 r
.61278 .69852 m .61368 .69693 L p .61694 .70369 L F P
0 g
s
.38 .431 .788 r
.61278 .69852 m .61174 .69599 L .61368 .69693 L closepath p F P
0 g
s
.65 .757 .928 r
.49546 .5684 m .4862 .57133 L .48878 .57403 L p F P
0 g
s
.65 .757 .928 r
.48878 .57403 m .49803 .57111 L .49546 .5684 L p F P
0 g
s
.741 .735 .846 r
.48835 .80183 m .48848 .80175 L .49379 .80333 L p F P
0 g
s
.698 .686 .835 r
.49763 .79635 m .48848 .80175 L .49379 .80333 L p F P
0 g
s
.698 .686 .835 r
.49379 .80333 m .50018 .80026 L .49763 .79635 L p F P
0 g
s
.662 .64 .817 r
.55931 .79957 m .54996 .8027 L .54747 .79843 L p F P
0 g
s
.771 .58 .64 r
.51253 .72428 m .50694 .72327 L .50914 .71814 L p F P
0 g
s
.807 .61 .637 r
.50322 .71665 m .50914 .71814 L .50694 .72327 L p F P
0 g
s
.353 .224 .562 r
.62377 .77052 m .62685 .76824 L .62555 .76399 L p F P
0 g
s
.343 .218 .562 r
.63019 .76041 m .62555 .76399 L .62685 .76824 L p F P
0 g
s
.373 .267 .603 r
.6295 .7555 m .6294 .7553 L p .62555 .76399 L F P
0 g
s
.373 .267 .603 r
.62555 .76399 m .63019 .76041 L .6295 .7555 L p F P
0 g
s
.313 .159 .506 r
.62685 .76824 m .62377 .77052 L .62392 .77512 L p F P
0 g
s
.935 .699 .557 r
.42302 .76164 m .42599 .76395 L .42534 .76866 L p F P
0 g
s
.927 .717 .598 r
.42599 .76395 m .42302 .76164 L .42409 .75681 L p F P
0 g
s
.625 .47 .653 r
.53794 .73012 m .53692 .72462 L .54689 .72259 L p F P
0 g
s
.627 .471 .651 r
.54593 .71716 m .54689 .72259 L .53692 .72462 L p F P
0 g
s
.627 .471 .651 r
.54561 .71723 m .54593 .71716 L p .53692 .72462 L F P
0 g
s
.865 .659 .622 r
.49724 .70297 m .5015 .70496 L .49999 .70988 L p F P
0 g
s
.858 .649 .618 r
.5015 .70496 m .49724 .70297 L .49853 .69812 L p F P
0 g
s
.65 .757 .928 r
.21783 .56807 m .20906 .57099 L .21209 .57369 L p F P
0 g
s
.65 .757 .928 r
.21209 .57369 m .22085 .57078 L .21783 .56807 L p F P
0 g
s
.651 .758 .928 r
.7891 .57374 m .79887 .57081 L .80094 .57351 L p F P
0 g
s
.651 .758 .928 r
.79887 .57081 m .7891 .57374 L .787 .57104 L p F P
0 g
s
.65 .757 .928 r
.36256 .56816 m .35354 .57109 L .35633 .57378 L p F P
0 g
s
.65 .757 .928 r
.35633 .57378 m .36535 .57087 L .36256 .56816 L p F P
0 g
s
.355 .299 .656 r
.62801 .74345 m .62727 .74418 L .62846 .74981 L p F P
0 g
s
.651 .758 .928 r
.64484 .5738 m .65436 .57087 L .65667 .57357 L p F P
0 g
s
.651 .758 .928 r
.65436 .57087 m .64484 .5738 L .64252 .5711 L p F P
0 g
s
.651 .757 .928 r
.5073 .56818 m .49803 .57111 L .50059 .57381 L p F P
0 g
s
.651 .757 .928 r
.50059 .57381 m .50986 .57089 L .5073 .56818 L p F P
0 g
s
.909 .85 .772 r
.43455 .70595 m .4353 .70485 L .4336 .70208 L p F P
0 g
s
.743 .567 .655 r
.51298 .72626 m .51381 .72448 L p .51911 .73065 L F P
0 g
s
.763 .576 .646 r
.51298 .72626 m .51381 .72448 L .51253 .72428 L closepath p F P
0 g
s
.679 .511 .651 r
.52731 .73379 m .52994 .73073 L .52676 .73094 L closepath p F P
0 g
s
.698 .523 .647 r
.52676 .73094 m .51911 .73065 L p .52536 .73655 L F P
0 g
s
.698 .523 .647 r
.52536 .73655 m .52731 .73379 L .52676 .73094 L p F P
0 g
s
.38 .431 .788 r
.61368 .69693 m .61174 .69599 L .60967 .69091 L p F P
0 g
s
.65 .757 .928 r
.22964 .56786 m .22085 .57078 L .22386 .57348 L p F P
0 g
s
.65 .757 .928 r
.22386 .57348 m .23264 .57057 L .22964 .56786 L p F P
0 g
s
.651 .758 .928 r
.80094 .57351 m .81074 .57058 L .81279 .57327 L p F P
0 g
s
.651 .758 .928 r
.81074 .57058 m .80094 .57351 L .79887 .57081 L p F P
0 g
s
.896 .688 .613 r
.49494 .69593 m .49853 .69812 L .49724 .70297 L p F P
0 g
s
.892 .68 .609 r
.49853 .69812 m .49494 .69593 L .49609 .69113 L p F P
0 g
s
.459 .327 .614 r
.55228 .69812 m .55863 .69358 L p .55409 .7026 L F P
0 g
s
.459 .327 .614 r
.55409 .7026 m .55269 .70123 L .55228 .69812 L p F P
0 g
s
.401 .283 .602 r
.55228 .69812 m .55863 .69358 L .55614 .68981 L p F P
0 g
s
.65 .757 .928 r
.37439 .56794 m .36535 .57087 L .36812 .57356 L p F P
0 g
s
.65 .757 .928 r
.36812 .57356 m .37716 .57064 L .37439 .56794 L p F P
0 g
s
.651 .758 .928 r
.65667 .57357 m .66621 .57065 L .66851 .57334 L p F P
0 g
s
.651 .758 .928 r
.66621 .57065 m .65667 .57357 L .65436 .57087 L p F P
0 g
s
.909 .85 .772 r
.4336 .70208 m .43185 .70461 L .43455 .70595 L p F P
0 g
s
.912 .845 .764 r
.43455 .70595 m .4317 .71036 L .42986 .70764 L p F P
0 g
s
.912 .845 .764 r
.42986 .70764 m .43185 .70461 L .43455 .70595 L p F P
0 g
s
.651 .757 .928 r
.51915 .56795 m .50986 .57089 L .5124 .57358 L p F P
0 g
s
.651 .757 .928 r
.5124 .57358 m .52169 .57066 L .51915 .56795 L p F P
0 g
s
.868 .461 .255 r
.43715 .78836 m .43338 .78634 L .43609 .78597 L closepath p F P
0 g
s
.753 .571 .649 r
.51253 .72428 m .50694 .72327 L p .5112 .72974 L F P
0 g
s
.753 .571 .649 r
.5112 .72974 m .51298 .72626 L .51253 .72428 L p F P
0 g
s
.894 .876 .811 r
.44658 .68492 m .44528 .682 L .44057 .68784 L p F P
0 g
s
.894 .876 .811 r
.44057 .68784 m .44181 .69076 L .44658 .68492 L p F P
0 g
s
.527 .896 .967 r
.58543 .80278 m .59029 .80126 L .58572 .80284 L closepath p F P
0 g
s
.5 .904 .912 r
.59484 .7998 m .59029 .80126 L .58572 .80284 L p F P
0 g
s
.377 .389 .746 r
.62476 .71369 m .62184 .71764 L .62666 .72084 L p F P
0 g
s
.394 .399 .746 r
.61968 .71059 m .62476 .71369 L .62184 .71764 L p F P
0 g
s
.69 .527 .661 r
.52994 .73073 m .53794 .73012 L p .52792 .73658 L F P
0 g
s
.69 .527 .661 r
.52792 .73658 m .52731 .73379 L .52994 .73073 L p F P
0 g
s
.65 .757 .928 r
.24145 .56764 m .23264 .57057 L .23563 .57327 L p F P
0 g
s
.65 .757 .928 r
.23563 .57327 m .24443 .57035 L .24145 .56764 L p F P
0 g
s
.651 .758 .928 r
.81279 .57327 m .82261 .57034 L .82465 .57304 L p F P
0 g
s
.651 .758 .928 r
.82261 .57034 m .81279 .57327 L .81074 .57058 L p F P
0 g
s
.645 .73 .911 r
.56179 .80332 m .57116 .80069 L .57361 .8036 L p F P
0 g
s
.645 .672 .861 r
.57074 .80003 m .57116 .80069 L .56179 .80332 L p F P
0 g
s
.645 .672 .861 r
.56179 .80332 m .56115 .80235 L .57074 .80003 L p F P
0 g
s
.169 .617 .937 r
.46472 .80236 m .4643 .80229 L .4654 .80278 L closepath p F P
0 g
s
.65 .757 .928 r
.38623 .56771 m .37716 .57064 L .37992 .57334 L p F P
0 g
s
.65 .757 .928 r
.37992 .57334 m .38897 .57042 L .38623 .56771 L p F P
0 g
s
.651 .758 .928 r
.66851 .57334 m .67807 .57042 L .68034 .57312 L p F P
0 g
s
.651 .758 .928 r
.67807 .57042 m .66851 .57334 L .66621 .57065 L p F P
0 g
s
.651 .757 .928 r
.53101 .56773 m .52169 .57066 L .52421 .57336 L p F P
0 g
s
.651 .757 .928 r
.52421 .57336 m .53352 .57043 L .53101 .56773 L p F P
0 g
s
.743 .567 .655 r
.51911 .73065 m .51388 .73011 L .51298 .72626 L p F P
0 g
s
.698 .523 .647 r
.51911 .73065 m .51601 .73605 L .52536 .73655 L p F P
0 g
s
.743 .567 .656 r
.51388 .73011 m .51911 .73065 L .51601 .73605 L p F P
0 g
s
.914 .823 .743 r
.42833 .71581 m .42505 .72123 L .42775 .72287 L p F P
0 g
s
.914 .819 .738 r
.42775 .72287 m .42719 .72386 L .42504 .72125 L p F P
0 g
s
.914 .819 .738 r
.42504 .72125 m .42505 .72123 L .42775 .72287 L p F P
0 g
s
.938 .73 .596 r
.4213 .75444 m .42409 .75681 L .42302 .76164 L p F P
0 g
s
.93 .743 .628 r
.42409 .75681 m .4213 .75444 L .42274 .74951 L p F P
0 g
s
.757 .575 .651 r
.51388 .73011 m .51298 .72626 L .5112 .72974 L closepath p F P
0 g
s
.651 .758 .928 r
.82465 .57304 m .83448 .5701 L .8365 .5728 L p F P
0 g
s
.651 .758 .928 r
.83448 .5701 m .82465 .57304 L .82261 .57034 L p F P
0 g
s
.65 .757 .928 r
.25327 .56743 m .24443 .57035 L .2474 .57305 L p F P
0 g
s
.65 .757 .928 r
.2474 .57305 m .25623 .57014 L .25327 .56743 L p F P
0 g
s
.697 .633 .781 r
.53443 .79527 m .53564 .79778 L p .52382 .79789 L F P
0 g
s
.697 .633 .781 r
.52382 .79789 m .52817 .79541 L .53443 .79527 L p F P
0 g
s
.7 .641 .787 r
.52382 .79789 m .52817 .79541 L .52259 .79545 L closepath p F P
0 g
s
.711 .644 .78 r
.52259 .79545 m .52382 .79789 L p .51201 .79879 L F P
0 g
s
.505 0 0 r
.44814 .79604 m .45033 .79772 L .44766 .79635 L p F P
0 g
s
.505 0 0 r
.44766 .79635 m .4442 .79406 L .44814 .79604 L p F P
0 g
s
.651 .758 .928 r
.68034 .57312 m .68993 .57019 L .69218 .57289 L p F P
0 g
s
.651 .758 .928 r
.68993 .57019 m .68034 .57312 L .67807 .57042 L p F P
0 g
s
.65 .757 .928 r
.39806 .56749 m .38897 .57042 L .39171 .57312 L p F P
0 g
s
.65 .757 .928 r
.39171 .57312 m .40079 .5702 L .39806 .56749 L p F P
0 g
s
.928 .771 .666 r
.42208 .74201 m .42079 .74533 L .42348 .74748 L p F P
0 g
s
.93 .768 .658 r
.42348 .74748 m .42274 .74951 L .42015 .74707 L p F P
0 g
s
.93 .768 .658 r
.42015 .74707 m .42079 .74533 L .42348 .74748 L p F P
0 g
s
.651 .757 .928 r
.54286 .5675 m .53352 .57043 L .53603 .57313 L p F P
0 g
s
.651 .757 .928 r
.53603 .57313 m .54536 .57021 L .54286 .5675 L p F P
0 g
s
.93 .723 .602 r
.49316 .68873 m .49609 .69113 L .49494 .69593 L p F P
0 g
s
.93 .719 .596 r
.49609 .69113 m .49316 .68873 L .49421 .68397 L p F P
0 g
s
.71 .54 .656 r
.52792 .73658 m .52731 .73379 L .52536 .73655 L closepath p F P
0 g
s
.927 .814 .715 r
.42719 .72386 m .42504 .72125 L .42233 .72652 L p F P
0 g
s
.927 .814 .715 r
.42233 .72652 m .42448 .72912 L .42719 .72386 L p F P
0 g
s
.649 .756 .928 r
.1203 .56698 m .1117 .56989 L .11488 .5726 L p F P
0 g
s
.649 .756 .928 r
.11488 .5726 m .12348 .5697 L .1203 .56698 L p F P
0 g
s
.093 0 .208 r
.6182 .78284 m .62371 .77937 L p .61562 .78778 L F P
0 g
s
.093 0 .208 r
.61562 .78778 m .61588 .78665 L .6182 .78284 L p F P
0 g
s
.315 .112 .437 r
.6182 .78284 m .62371 .77937 L .62392 .77512 L p F P
0 g
s
.711 .644 .78 r
.51201 .79879 m .5175 .79529 L .52259 .79545 L p F P
0 g
s
.721 .668 .797 r
.51201 .79879 m .5175 .79529 L .50966 .79462 L closepath p F P
0 g
s
.721 .664 .794 r
.50966 .79462 m .51201 .79879 L p .50018 .80026 L F P
0 g
s
.596 .853 .993 r
.59029 .80126 m .58543 .80278 L .58301 .80108 L p F P
0 g
s
.613 .825 .982 r
.57361 .8036 m .58301 .80108 L .58543 .80278 L p F P
0 g
s
.355 .299 .656 r
.62846 .74981 m .63116 .74717 L .62801 .74345 L p F P
0 g
s
.353 .307 .667 r
.63203 .73926 m .62801 .74345 L .63116 .74717 L p F P
0 g
s
.381 .335 .681 r
.62833 .73571 m .63203 .73926 L .62801 .74345 L p F P
0 g
s
.624 .463 .644 r
.54593 .71716 m .54591 .71704 L .54561 .71723 L closepath p F P
0 g
s
.651 .758 .928 r
.8365 .5728 m .84636 .56986 L .84836 .57256 L p F P
0 g
s
.651 .758 .928 r
.84636 .56986 m .8365 .5728 L .83448 .5701 L p F P
0 g
s
.93 .794 .688 r
.42435 .73686 m .42199 .73433 L .41972 .73949 L p F P
0 g
s
.93 .794 .688 r
.41972 .73949 m .42208 .74201 L .42435 .73686 L p F P
0 g
s
.55 .413 .647 r
.54593 .71716 m .54591 .71704 L .54621 .71706 L closepath p F P
0 g
s
.65 .757 .928 r
.26509 .56721 m .25623 .57014 L .25918 .57284 L p F P
0 g
s
.65 .757 .928 r
.25918 .57284 m .26803 .56992 L .26509 .56721 L p F P
0 g
s
.635 .735 .92 r
.58301 .80108 m .57361 .8036 L .57116 .80069 L p F P
0 g
s
.552 .416 .649 r
.54689 .72259 m .54593 .71716 L .54621 .71706 L p F P
0 g
s
.651 .758 .928 r
.69218 .57289 m .70179 .56996 L .70402 .57266 L p F P
0 g
s
.651 .758 .928 r
.70179 .56996 m .69218 .57289 L .68993 .57019 L p F P
0 g
s
.65 .757 .928 r
.4099 .56727 m .40079 .5702 L .40351 .5729 L p F P
0 g
s
.65 .757 .928 r
.40351 .5729 m .41261 .56997 L .4099 .56727 L p F P
0 g
s
.651 .757 .928 r
.55473 .56727 m .54536 .57021 L .54785 .57291 L p F P
0 g
s
.651 .757 .928 r
.54785 .57291 m .5572 .56998 L .55473 .56727 L p F P
0 g
s
.68 .632 .795 r
.54541 .79428 m .54747 .79843 L p .53564 .79778 L F P
0 g
s
.68 .632 .795 r
.53564 .79778 m .5426 .7945 L .54541 .79428 L p F P
0 g
s
.677 .623 .788 r
.53564 .79778 m .5426 .7945 L .53443 .79527 L closepath p F P
0 g
s
.375 .403 .762 r
.62223 .70672 m .61968 .71059 L .62476 .71369 L p F P
0 g
s
.39 .409 .76 r
.61694 .70369 m .62223 .70672 L .61968 .71059 L p F P
0 g
s
0 0 0 r
.6063 .79495 m .60444 .7958 L p .59484 .7998 L F P
0 g
s
.029 0 0 r
.60444 .7958 m .6063 .79495 L .60657 .79462 L closepath p F P
0 g
s
.38 .431 .788 r
.60967 .69091 m .60996 .69031 L p .61368 .69693 L F P
0 g
s
.374 .442 .802 r
.60967 .69091 m .60927 .68999 L .60996 .69031 L closepath p F P
0 g
s
.648 .676 .862 r
.56869 .79682 m .57074 .80003 L .56115 .80235 L p F P
0 g
s
.648 .676 .862 r
.56115 .80235 m .55931 .79957 L .56869 .79682 L p F P
0 g
s
.649 .757 .928 r
.1321 .56679 m .12348 .5697 L .12664 .57241 L p F P
0 g
s
.649 .757 .928 r
.12664 .57241 m .13526 .56951 L .1321 .56679 L p F P
0 g
s
.331 .687 .98 r
.4643 .80229 m .46472 .80236 L .46209 .80046 L p F P
0 g
s
.331 .687 .98 r
.46209 .80046 m .46034 .80033 L .4643 .80229 L p F P
0 g
s
.552 .416 .649 r
.54621 .71706 m .55529 .71756 L p .54689 .72259 L F P
0 g
s
.552 .408 .639 r
.55529 .71756 m .54621 .71706 L .55469 .71391 L closepath p F P
0 g
s
.551 .401 .63 r
.55385 .70859 m .55469 .71391 L .54621 .71706 L p F P
0 g
s
.333 .267 .631 r
.63116 .74717 m .62846 .74981 L .62947 .75525 L p F P
0 g
s
.388 .304 .64 r
.6294 .7553 m .62947 .75525 L .62846 .74981 L p F P
0 g
s
.619 .466 .653 r
.53794 .73012 m .54784 .72803 L p .54219 .73493 L F P
0 g
s
.619 .466 .653 r
.54219 .73493 m .53897 .73563 L .53794 .73012 L p F P
0 g
s
.69 .527 .661 r
.53794 .73012 m .53897 .73563 L .52792 .73658 L p F P
0 g
s
.625 .47 .653 r
.54689 .72259 m .54784 .72803 L .53794 .73012 L p F P
0 g
s
.651 .758 .928 r
.84836 .57256 m .85824 .56962 L .86023 .57232 L p F P
0 g
s
.651 .758 .928 r
.85824 .56962 m .84836 .57256 L .84636 .56986 L p F P
0 g
s
.743 .567 .656 r
.51601 .73605 m .51525 .73598 L .51388 .73011 L p F P
0 g
s
.758 .576 .65 r
.5112 .72974 m .51388 .73011 L .51525 .73598 L p F P
0 g
s
.901 .877 .803 r
.44128 .69145 m .44181 .69076 L .44057 .68784 L p F P
0 g
s
.65 .757 .928 r
.27691 .56699 m .26803 .56992 L .27097 .57262 L p F P
0 g
s
.65 .757 .928 r
.27097 .57262 m .27984 .5697 L .27691 .56699 L p F P
0 g
s
.371 .442 .804 r
.60996 .69031 m .60927 .68999 L .60681 .68439 L p F P
0 g
s
.651 .758 .928 r
.70402 .57266 m .71365 .56973 L .71587 .57243 L p F P
0 g
s
.651 .758 .928 r
.71365 .56973 m .70402 .57266 L .70179 .56996 L p F P
0 g
s
.65 .757 .928 r
.42175 .56704 m .41261 .56997 L .41532 .57268 L p F P
0 g
s
.65 .757 .928 r
.41532 .57268 m .42444 .56975 L .42175 .56704 L p F P
0 g
s
.411 .484 .824 r
.60435 .6791 m .60063 .6776 L p .60559 .68387 L F P
0 g
s
.379 .466 .824 r
.60435 .6791 m .60063 .6776 L .60196 .67408 L closepath p F P
0 g
s
.651 .757 .928 r
.56659 .56705 m .5572 .56998 L .55967 .57268 L p F P
0 g
s
.651 .757 .928 r
.55967 .57268 m .56905 .56976 L .56659 .56705 L p F P
0 g
s
.44 .326 .627 r
.55301 .7033 m .55269 .70123 L .55409 .7026 L closepath p F P
0 g
s
.918 .84 .752 r
.4317 .71036 m .42986 .70764 L .42648 .7131 L p F P
0 g
s
.918 .84 .752 r
.42648 .7131 m .42833 .71581 L .4317 .71036 L p F P
0 g
s
.224 .159 .569 r
.55741 .67726 m .55714 .67758 L .55781 .68267 L p F P
0 g
s
.672 .515 .664 r
.52792 .73658 m .53897 .73563 L p .53349 .74193 L F P
0 g
s
.672 .515 .664 r
.53349 .74193 m .52916 .74232 L .52792 .73658 L p F P
0 g
s
.71 .54 .656 r
.52536 .73655 m .52792 .73658 L .52916 .74232 L p F P
0 g
s
.721 .664 .794 r
.50018 .80026 m .50903 .79457 L .50966 .79462 L p F P
0 g
s
.733 .654 .77 r
.50903 .79457 m .50018 .80026 L .49763 .79635 L p F P
0 g
s
.901 .877 .803 r
.44057 .68784 m .43858 .69035 L .44128 .69145 L p F P
0 g
s
.906 .871 .792 r
.44128 .69145 m .43765 .69644 L .43618 .69358 L p F P
0 g
s
.906 .871 .792 r
.43618 .69358 m .43858 .69035 L .44128 .69145 L p F P
0 g
s
.71 .54 .656 r
.52916 .74232 m .52137 .74221 L .52536 .73655 L p F P
0 g
s
.727 .563 .668 r
.51601 .73605 m .52536 .73655 L .52137 .74221 L p F P
0 g
s
.65 .757 .928 r
.1439 .56659 m .13526 .56951 L .13841 .57221 L p F P
0 g
s
.65 .757 .928 r
.13841 .57221 m .14704 .56931 L .1439 .56659 L p F P
0 g
s
.486 .788 .998 r
.47653 .8028 m .47393 .80023 L .46472 .80236 L p F P
0 g
s
.66 .746 .913 r
.47393 .80023 m .46472 .80236 L .46209 .80046 L p F P
0 g
s
.651 .758 .928 r
.86023 .57232 m .87013 .56938 L .87209 .57207 L p F P
0 g
s
.651 .758 .928 r
.87013 .56938 m .86023 .57232 L .85824 .56962 L p F P
0 g
s
.373 .418 .779 r
.6191 .69991 m .61694 .70369 L .62223 .70672 L p F P
0 g
s
.386 .42 .774 r
.61368 .69693 m .6191 .69991 L .61694 .70369 L p F P
0 g
s
0 0 0 r
.6063 .79495 m .60657 .79462 L .6142 .78854 L p F P
0 g
s
.65 .757 .928 r
.28874 .56677 m .27984 .5697 L .28275 .57241 L p F P
0 g
s
.65 .757 .928 r
.28275 .57241 m .29164 .56948 L .28874 .56677 L p F P
0 g
s
.7 .643 .789 r
.52817 .79541 m .52259 .79545 L .5213 .79292 L p F P
0 g
s
.711 .647 .784 r
.52259 .79545 m .5213 .79292 L .5175 .79529 L closepath p F P
0 g
s
.968 .769 .582 r
.49421 .68397 m .49203 .68133 L .49094 .68611 L p F P
0 g
s
.968 .769 .582 r
.49094 .68611 m .49316 .68873 L .49421 .68397 L p F P
0 g
s
.651 .758 .928 r
.71587 .57243 m .72552 .5695 L .72771 .5722 L p F P
0 g
s
.651 .758 .928 r
.72552 .5695 m .71587 .57243 L .71365 .56973 L p F P
0 g
s
.65 .757 .928 r
.43359 .56682 m .42444 .56975 L .42712 .57245 L p F P
0 g
s
.65 .757 .928 r
.42712 .57245 m .43627 .56953 L .43359 .56682 L p F P
0 g
s
.651 .757 .928 r
.57846 .56682 m .56905 .56976 L .5715 .57246 L p F P
0 g
s
.651 .757 .928 r
.5715 .57246 m .58089 .56953 L .57846 .56682 L p F P
0 g
s
.94 .756 .626 r
.42274 .74951 m .42015 .74707 L .41871 .752 L p F P
0 g
s
.94 .756 .626 r
.41871 .752 m .4213 .75444 L .42274 .74951 L p F P
0 g
s
.697 .635 .783 r
.53443 .79527 m .53313 .79261 L .52817 .79541 L closepath p F P
0 g
s
.7 .643 .789 r
.53086 .78734 m .53313 .79261 L .52817 .79541 L p F P
0 g
s
.7 .643 .789 r
.5297 .78735 m .53086 .78734 L p .52817 .79541 L F P
0 g
s
.7 .643 .789 r
.5213 .79292 m .5297 .78735 L p .52817 .79541 L F P
0 g
s
.753 .571 .649 r
.50694 .72327 m .50475 .72841 L .5112 .72974 L p F P
0 g
s
.817 .624 .641 r
.5014 .72167 m .50694 .72327 L .50475 .72841 L p F P
0 g
s
.807 .61 .637 r
.50694 .72327 m .5014 .72167 L .50322 .71665 L p F P
0 g
s
.386 .454 .808 r
.60681 .68439 m .60559 .68387 L .6061 .68281 L closepath p F P
0 g
s
.411 .484 .824 r
.60559 .68387 m .6061 .68281 L .60435 .6791 L p F P
0 g
s
.844 .645 .634 r
.49844 .71482 m .50322 .71665 L .5014 .72167 L p F P
0 g
s
.835 .633 .63 r
.50322 .71665 m .49844 .71482 L .49999 .70988 L p F P
0 g
s
.65 .757 .928 r
.15571 .56639 m .14704 .56931 L .15017 .57202 L p F P
0 g
s
.65 .757 .928 r
.15017 .57202 m .15883 .56911 L .15571 .56639 L p F P
0 g
s
.758 .576 .65 r
.51525 .73598 m .50853 .73502 L .5112 .72974 L p F P
0 g
s
.792 .605 .648 r
.50475 .72841 m .5112 .72974 L .50853 .73502 L p F P
0 g
s
.651 .758 .928 r
.87209 .57207 m .88202 .56913 L .88396 .57183 L p F P
0 g
s
.651 .758 .928 r
.88202 .56913 m .87209 .57207 L .87013 .56938 L p F P
0 g
s
.371 .433 .795 r
.61545 .69324 m .61368 .69693 L .6191 .69991 L p F P
0 g
s
.38 .431 .788 r
.60996 .69031 m .61545 .69324 L .61368 .69693 L p F P
0 g
s
.224 .159 .569 r
.55781 .68267 m .55894 .68128 L .55741 .67726 L p F P
0 g
s
.044 .025 .508 r
.55988 .67328 m .55741 .67726 L .55894 .68128 L p F P
0 g
s
.721 .669 .798 r
.51878 .78739 m .5213 .79292 L .5175 .79529 L p F P
0 g
s
.721 .669 .798 r
.50947 .79429 m .51878 .78739 L p .5175 .79529 L F P
0 g
s
.721 .669 .798 r
.5175 .79529 m .50966 .79462 L .50947 .79429 L p F P
0 g
s
.677 .626 .79 r
.5426 .7945 m .53443 .79527 L .53313 .79261 L p F P
0 g
s
.662 .64 .817 r
.54747 .79843 m .55682 .79497 L .55931 .79957 L p F P
0 g
s
.662 .622 .799 r
.55578 .7927 m .55682 .79497 L .54747 .79843 L p F P
0 g
s
.662 .622 .799 r
.54747 .79843 m .54541 .79428 L .55578 .7927 L p F P
0 g
s
.65 .757 .928 r
.30057 .56655 m .29164 .56948 L .29454 .57219 L p F P
0 g
s
.65 .757 .928 r
.29454 .57219 m .30346 .56927 L .30057 .56655 L p F P
0 g
s
.259 0 .271 r
.6142 .78854 m .61562 .78778 L .61588 .78665 L closepath p F P
0 g
s
.651 .758 .928 r
.72771 .5722 m .73739 .56927 L .73957 .57197 L p F P
0 g
s
.651 .758 .928 r
.73739 .56927 m .72771 .5722 L .72552 .5695 L p F P
0 g
s
.367 .447 .811 r
.61134 .68671 m .60996 .69031 L .61545 .69324 L p F P
0 g
s
.371 .442 .804 r
.60681 .68439 m .61134 .68671 L .60996 .69031 L p F P
0 g
s
.65 .757 .928 r
.44544 .56659 m .43627 .56953 L .43893 .57223 L p F P
0 g
s
.65 .757 .928 r
.43893 .57223 m .4481 .5693 L .44544 .56659 L p F P
0 g
s
.651 .757 .928 r
.59032 .56659 m .58089 .56953 L .58332 .57223 L p F P
0 g
s
.651 .757 .928 r
.58332 .57223 m .59274 .5693 L .59032 .56659 L p F P
0 g
s
.741 .735 .846 r
.48835 .80183 m .48848 .80175 L .48824 .80168 L closepath p F P
0 g
s
.702 .719 .862 r
.48824 .80168 m .48835 .80183 L p .47653 .8028 L F P
0 g
s
.902 .534 .331 r
.43338 .78634 m .43335 .78632 L .43215 .78209 L p F P
0 g
s
.909 .536 .308 r
.42882 .77991 m .43215 .78209 L .43335 .78632 L p F P
0 g
s
.921 .608 .434 r
.43215 .78209 m .42882 .77991 L .42836 .77549 L p F P
0 g
s
.741 .735 .846 r
.49529 .7925 m .49763 .79635 L .48848 .80175 L p F P
0 g
s
.741 .735 .846 r
.49467 .79241 m .49529 .7925 L p .48848 .80175 L F P
0 g
s
.741 .735 .846 r
.48578 .79857 m .49467 .79241 L p .48848 .80175 L F P
0 g
s
.741 .735 .846 r
.48848 .80175 m .48824 .80168 L .48578 .79857 L p F P
0 g
s
.931 .616 .422 r
.4252 .77325 m .42836 .77549 L .42882 .77991 L p F P
0 g
s
.93 .66 .506 r
.42836 .77549 m .4252 .77325 L .42534 .76866 L p F P
0 g
s
.871 .669 .626 r
.49589 .70785 m .49999 .70988 L .49844 .71482 L p F P
0 g
s
.865 .659 .622 r
.49999 .70988 m .49589 .70785 L .49724 .70297 L p F P
0 g
s
.443 .33 .63 r
.55409 .7026 m .55301 .7033 L .55385 .70859 L p F P
0 g
s
.65 .757 .928 r
.16752 .56619 m .15883 .56911 L .16194 .57182 L p F P
0 g
s
.65 .757 .928 r
.16194 .57182 m .17062 .56891 L .16752 .56619 L p F P
0 g
s
.702 .719 .862 r
.47653 .8028 m .48078 .80082 L .48824 .80168 L p F P
0 g
s
.699 .723 .869 r
.48824 .80168 m .48578 .79857 L .48078 .80082 L closepath p F P
0 g
s
0 0 0 r
.6142 .78854 m .61562 .78778 L p .6063 .79495 L F P
0 g
s
.727 .563 .668 r
.51549 .73696 m .51601 .73605 L p .52137 .74221 L F P
0 g
s
.743 .568 .657 r
.51549 .73696 m .51601 .73605 L .51525 .73598 L closepath p F P
0 g
s
.736 .748 .861 r
.48078 .80082 m .47653 .8028 L .47393 .80023 L p F P
0 g
s
.65 .757 .928 r
.3124 .56633 m .30346 .56927 L .30633 .57197 L p F P
0 g
s
.65 .757 .928 r
.30633 .57197 m .31527 .56905 L .3124 .56633 L p F P
0 g
s
.651 .758 .928 r
.73957 .57197 m .74926 .56904 L .75142 .57174 L p F P
0 g
s
.651 .758 .928 r
.74926 .56904 m .73957 .57197 L .73739 .56927 L p F P
0 g
s
.65 .757 .928 r
.4573 .56637 m .4481 .5693 L .45074 .57201 L p F P
0 g
s
.65 .757 .928 r
.45074 .57201 m .45993 .56908 L .4573 .56637 L p F P
0 g
s
.651 .757 .928 r
.6022 .56637 m .59274 .5693 L .59516 .57201 L p F P
0 g
s
.651 .757 .928 r
.59516 .57201 m .6046 .56908 L .6022 .56637 L p F P
0 g
s
.739 .566 .658 r
.51525 .73598 m .50853 .73502 L p .51275 .74151 L F P
0 g
s
.739 .566 .658 r
.51275 .74151 m .51549 .73696 L .51525 .73598 L p F P
0 g
s
0 0 0 r
.60426 .79616 m .6063 .79495 L .61413 .7908 L p F P
0 g
s
0 0 0 r
.61562 .78778 m .61413 .7908 L .6063 .79495 L p F P
0 g
s
0 0 0 r
.59484 .7998 m .60426 .79616 L .6063 .79495 L p F P
0 g
s
.65 .757 .928 r
.17933 .56598 m .17062 .56891 L .17372 .57161 L p F P
0 g
s
.65 .757 .928 r
.17372 .57161 m .18242 .5687 L .17933 .56598 L p F P
0 g
s
.753 .235 0 r
.4442 .79406 m .44039 .79203 L .43715 .78836 L p F P
0 g
s
.725 .194 0 r
.43338 .78634 m .43715 .78836 L .44039 .79203 L p F P
0 g
s
.941 .671 .499 r
.42237 .76636 m .42534 .76866 L .4252 .77325 L p F P
0 g
s
.935 .699 .557 r
.42534 .76866 m .42237 .76636 L .42302 .76164 L p F P
0 g
s
.727 .563 .668 r
.52137 .74221 m .51674 .74194 L .51549 .73696 L p F P
0 g
s
.746 .574 .662 r
.51674 .74194 m .51549 .73696 L .51275 .74151 L closepath p F P
0 g
s
.651 .758 .928 r
.75142 .57174 m .76114 .56881 L .76328 .57151 L p F P
0 g
s
.651 .758 .928 r
.76114 .56881 m .75142 .57174 L .74926 .56904 L p F P
0 g
s
.65 .757 .928 r
.32424 .56611 m .31527 .56905 L .31813 .57175 L p F P
0 g
s
.65 .757 .928 r
.31813 .57175 m .32709 .56882 L .32424 .56611 L p F P
0 g
s
.651 .757 .928 r
.61407 .56614 m .6046 .56908 L .60699 .57178 L p F P
0 g
s
.651 .757 .928 r
.60699 .57178 m .61646 .56885 L .61407 .56614 L p F P
0 g
s
.65 .757 .928 r
.46915 .56614 m .45993 .56908 L .46256 .57178 L p F P
0 g
s
.65 .757 .928 r
.46256 .57178 m .47177 .56885 L .46915 .56614 L p F P
0 g
s
.91 .867 .784 r
.43765 .69644 m .43618 .69358 L .43215 .69923 L p F P
0 g
s
.91 .867 .784 r
.43215 .69923 m .4336 .70208 L .43765 .69644 L p F P
0 g
s
.71 .603 .736 r
.5297 .78735 m .5213 .79292 L .51878 .78739 L p F P
0 g
s
.9 .695 .617 r
.49374 .70075 m .49724 .70297 L .49589 .70785 L p F P
0 g
s
.896 .688 .613 r
.49724 .70297 m .49374 .70075 L .49494 .69593 L p F P
0 g
s
.252 .064 .419 r
.62706 .77281 m .62392 .77512 L .62371 .77937 L p F P
0 g
s
.313 .159 .506 r
.62392 .77512 m .62706 .77281 L .62685 .76824 L p F P
0 g
s
.672 .515 .665 r
.52983 .74541 m .53349 .74193 L .52916 .74232 L closepath p F P
0 g
s
.715 .563 .681 r
.52916 .74232 m .52983 .74541 L .52747 .74817 L p F P
0 g
s
.715 .563 .681 r
.52137 .74221 m .52916 .74232 L p .52747 .74817 L F P
0 g
s
.371 .272 .612 r
.55853 .68783 m .55614 .68981 L .55863 .69358 L p F P
0 g
s
.366 .265 .606 r
.55614 .68981 m .55853 .68783 L .55781 .68267 L p F P
0 g
s
.553 .417 .649 r
.54784 .72803 m .54689 .72259 L .55561 .7193 L p F P
0 g
s
.552 .416 .649 r
.55529 .71756 m .55561 .7193 L .54689 .72259 L p F P
0 g
s
.355 .325 .687 r
.63172 .73194 m .62833 .73571 L .63203 .73926 L p F P
0 g
s
.378 .36 .713 r
.63149 .73117 m .62786 .72818 L p .62833 .73571 L F P
0 g
s
.378 .36 .713 r
.62833 .73571 m .63172 .73194 L .63149 .73117 L p F P
0 g
s
.933 .812 .702 r
.42448 .72912 m .42233 .72652 L .41984 .73173 L p F P
0 g
s
.933 .812 .702 r
.41984 .73173 m .42199 .73433 L .42448 .72912 L p F P
0 g
s
.65 .757 .928 r
.19115 .56577 m .18242 .5687 L .18549 .57141 L p F P
0 g
s
.65 .757 .928 r
.18549 .57141 m .19422 .56849 L .19115 .56577 L p F P
0 g
s
.715 .563 .681 r
.518 .74701 m .52137 .74221 L p .52747 .74817 L F P
0 g
s
.727 .563 .668 r
.518 .74701 m .52137 .74221 L .51674 .74194 L closepath p F P
0 g
s
.596 .853 .993 r
.59436 .79958 m .59029 .80126 L p .58301 .80108 L F P
0 g
s
.611 .878 .991 r
.59029 .80126 m .59436 .79958 L .59484 .7998 L closepath p F P
0 g
s
.999 .827 .526 r
.49303 .67659 m .49186 .67363 L .4907 .67843 L p F P
0 g
s
.999 .827 .526 r
.4907 .67843 m .49203 .68133 L .49303 .67659 L p F P
0 g
s
.619 .468 .655 r
.53914 .73655 m .54219 .73493 L .53897 .73563 L closepath p F P
0 g
s
.672 .515 .664 r
.53897 .73563 m .53914 .73655 L .53349 .74193 L p F P
0 g
s
.677 .626 .79 r
.53313 .79261 m .54245 .78756 L p .5426 .7945 L F P
0 g
s
.684 .607 .763 r
.54207 .78655 m .54245 .78756 L .53313 .79261 L p F P
0 g
s
.684 .607 .763 r
.53313 .79261 m .53086 .78734 L .54207 .78655 L p F P
0 g
s
.651 .758 .928 r
.76328 .57151 m .77302 .56857 L .77514 .57128 L p F P
0 g
s
.651 .758 .928 r
.77302 .56857 m .76328 .57151 L .76114 .56881 L p F P
0 g
s
.358 .257 .601 r
.6295 .7555 m .6294 .7553 L .62947 .75525 L closepath p F P
0 g
s
.65 .757 .928 r
.33608 .56589 m .32709 .56882 L .32993 .57153 L p F P
0 g
s
.65 .757 .928 r
.32993 .57153 m .33891 .5686 L .33608 .56589 L p F P
0 g
s
.344 .428 .804 r
.61134 .68671 m .60681 .68439 L .6061 .68281 L p F P
0 g
s
.651 .758 .928 r
.61883 .57155 m .62832 .56862 L .63067 .57133 L p F P
0 g
s
.651 .758 .928 r
.62595 .56591 m .61646 .56885 L .61883 .57155 L p F P
0 g
s
.651 .758 .928 r
.61883 .57155 m .62832 .56862 L .62595 .56591 L p F P
0 g
s
.65 .757 .928 r
.48101 .56592 m .47177 .56885 L .47438 .57156 L p F P
0 g
s
.65 .757 .928 r
.47438 .57156 m .48361 .56863 L .48101 .56592 L p F P
0 g
s
.719 .668 .799 r
.50966 .79462 m .50947 .79429 L .50903 .79457 L closepath p F P
0 g
s
.319 .229 .594 r
.62947 .75525 m .63377 .75105 L p .63131 .75938 L F P
0 g
s
.319 .229 .594 r
.63131 .75938 m .6295 .7555 L .62947 .75525 L p F P
0 g
s
.333 .267 .631 r
.62947 .75525 m .63377 .75105 L .63116 .74717 L p F P
0 g
s
.733 .654 .77 r
.49763 .79635 m .50106 .79371 L .50903 .79457 L p F P
0 g
s
.71 .647 .784 r
.50694 .78933 m .50106 .79371 L .50903 .79457 L p F P
0 g
s
.71 .647 .784 r
.50903 .79457 m .50947 .79429 L .50694 .78933 L p F P
0 g
s
.913 .843 .762 r
.42833 .71581 m .42648 .7131 L .42322 .71853 L p F P
0 g
s
.913 .843 .762 r
.42505 .72123 m .42833 .71581 L p .42322 .71853 L F P
0 g
s
.319 .229 .594 r
.63019 .76041 m .6295 .7555 L .63131 .75938 L closepath p F P
0 g
s
.727 .619 .737 r
.51878 .78739 m .50947 .79429 L .50694 .78933 L p F P
0 g
s
.65 .757 .928 r
.20297 .56556 m .19422 .56849 L .19727 .5712 L p F P
0 g
s
.65 .757 .928 r
.19727 .5712 m .20602 .56828 L .20297 .56556 L p F P
0 g
s
.628 .486 .669 r
.54017 .74132 m .53914 .73655 L .54219 .73493 L p F P
0 g
s
.67 .513 .663 r
.54017 .74132 m .53914 .73655 L .53349 .74193 L closepath p F P
0 g
s
.68 .633 .795 r
.54541 .79428 m .54496 .7934 L .5426 .7945 L closepath p F P
0 g
s
.677 .626 .79 r
.54245 .78756 m .54496 .7934 L .5426 .7945 L p F P
0 g
s
.939 .788 .667 r
.42079 .74533 m .42208 .74201 L .41972 .73949 L p F P
0 g
s
.645 .627 .817 r
.56869 .79682 m .55931 .79957 L .55682 .79497 L p F P
0 g
s
.3 .149 .503 r
.63066 .76532 m .62685 .76824 L .62706 .77281 L p F P
0 g
s
.343 .218 .562 r
.62685 .76824 m .63066 .76532 L .63019 .76041 L p F P
0 g
s
.651 .758 .928 r
.77514 .57128 m .7849 .56834 L .787 .57104 L p F P
0 g
s
.651 .758 .928 r
.7849 .56834 m .77514 .57128 L .77302 .56857 L p F P
0 g
s
.65 .757 .928 r
.34792 .56567 m .33891 .5686 L .34173 .57131 L p F P
0 g
s
.65 .757 .928 r
.34173 .57131 m .35073 .56838 L .34792 .56567 L p F P
0 g
s
.443 .33 .63 r
.55385 .70859 m .55779 .70604 L .55409 .7026 L p F P
0 g
s
.431 .329 .638 r
.56016 .69836 m .55409 .7026 L .55779 .70604 L p F P
0 g
s
.459 .327 .614 r
.55958 .69489 m .56016 .69836 L .55409 .7026 L p F P
0 g
s
.459 .327 .614 r
.55863 .69358 m .55958 .69489 L p .55409 .7026 L F P
0 g
s
.651 .758 .928 r
.63067 .57133 m .64018 .5684 L .64252 .5711 L p F P
0 g
s
.651 .758 .928 r
.64018 .5684 m .63067 .57133 L .62832 .56862 L p F P
0 g
s
.651 .757 .928 r
.49288 .56569 m .48361 .56863 L .4862 .57133 L p F P
0 g
s
.651 .757 .928 r
.4862 .57133 m .49546 .5684 L .49288 .56569 L p F P
0 g
s
.946 .712 .552 r
.42023 .75927 m .42302 .76164 L .42237 .76636 L p F P
0 g
s
.938 .73 .596 r
.42302 .76164 m .42023 .75927 L .4213 .75444 L p F P
0 g
s
0 .5 .791 r
.45033 .79772 m .45647 .79834 L .46034 .80033 L p F P
0 g
s
.211 .664 .948 r
.45647 .79834 m .45033 .79772 L .44766 .79635 L p F P
0 g
s
.727 .563 .668 r
.51674 .74194 m .51275 .74151 L p .51738 .74788 L F P
0 g
s
.727 .563 .668 r
.51738 .74788 m .518 .74701 L .51674 .74194 L p F P
0 g
s
.683 .533 .676 r
.53349 .74193 m .54017 .74132 L p .5305 .74815 L F P
0 g
s
.683 .533 .676 r
.5305 .74815 m .52983 .74541 L .53349 .74193 L p F P
0 g
s
.703 .546 .671 r
.5305 .74815 m .52983 .74541 L .52747 .74817 L closepath p F P
0 g
s
.344 .428 .804 r
.6061 .68281 m .60682 .6803 L p .61134 .68671 L F P
0 g
s
.337 .44 .819 r
.6061 .68281 m .60435 .6791 L .60682 .6803 L closepath p F P
0 g
s
.93 .728 .608 r
.49205 .69352 m .49494 .69593 L .49374 .70075 L p F P
0 g
s
.93 .723 .602 r
.49494 .69593 m .49205 .69352 L .49316 .68873 L p F P
0 g
s
.02 0 0 r
.62304 .78318 m .61562 .78778 L .61413 .7908 L p F P
0 g
s
.093 0 .208 r
.62371 .77937 m .62304 .78318 L .61562 .78778 L p F P
0 g
s
.65 .757 .928 r
.2148 .56535 m .20602 .56828 L .20906 .57099 L p F P
0 g
s
.65 .757 .928 r
.20906 .57099 m .21783 .56807 L .2148 .56535 L p F P
0 g
s
.651 .758 .928 r
.787 .57104 m .79678 .56811 L .79887 .57081 L p F P
0 g
s
.651 .758 .928 r
.79678 .56811 m .787 .57104 L .7849 .56834 L p F P
0 g
s
.668 .627 .8 r
.55431 .78952 m .55578 .7927 L .54541 .79428 L p F P
0 g
s
.668 .627 .8 r
.54541 .79428 m .54496 .7934 L .55431 .78952 L p F P
0 g
s
.65 .757 .928 r
.35977 .56544 m .35073 .56838 L .35354 .57109 L p F P
0 g
s
.65 .757 .928 r
.35354 .57109 m .36256 .56816 L .35977 .56544 L p F P
0 g
s
.651 .758 .928 r
.64252 .5711 m .65205 .56817 L .65436 .57087 L p F P
0 g
s
.651 .758 .928 r
.65205 .56817 m .64252 .5711 L .64018 .5684 L p F P
0 g
s
.736 .748 .861 r
.47393 .80023 m .47586 .79912 L .48078 .80082 L p F P
0 g
s
.696 .709 .858 r
.4832 .79508 m .47586 .79912 L .48078 .80082 L p F P
0 g
s
.696 .709 .858 r
.48078 .80082 m .48578 .79857 L .4832 .79508 L p F P
0 g
s
.651 .757 .928 r
.50474 .56546 m .49546 .5684 L .49803 .57111 L p F P
0 g
s
.651 .757 .928 r
.49803 .57111 m .5073 .56818 L .50474 .56546 L p F P
0 g
s
.225 .164 .575 r
.55894 .68128 m .55781 .68267 L .55853 .68783 L p F P
0 g
s
.887 .903 .833 r
.44797 .67872 m .45035 .67606 L .44965 .67294 L p F P
0 g
s
.703 .545 .671 r
.52747 .74817 m .5305 .74815 L .53194 .75408 L p F P
0 g
s
.703 .545 .671 r
.53194 .75408 m .5224 .75415 L .52747 .74817 L p F P
0 g
s
.715 .563 .681 r
.51826 .74795 m .52747 .74817 L .5224 .75415 L p F P
0 g
s
.715 .563 .681 r
.52747 .74817 m .51826 .74795 L .518 .74701 L p F P
0 g
s
.65 .757 .928 r
.22663 .56514 m .21783 .56807 L .22085 .57078 L p F P
0 g
s
.65 .757 .928 r
.22085 .57078 m .22964 .56786 L .22663 .56514 L p F P
0 g
s
.651 .758 .928 r
.79887 .57081 m .80867 .56787 L .81074 .57058 L p F P
0 g
s
.651 .758 .928 r
.80867 .56787 m .79887 .57081 L .79678 .56811 L p F P
0 g
s
.666 .522 .679 r
.5305 .74815 m .54139 .74703 L p .53493 .75376 L F P
0 g
s
.666 .522 .679 r
.53493 .75376 m .53194 .75408 L .5305 .74815 L p F P
0 g
s
.683 .533 .676 r
.54017 .74132 m .54139 .74703 L .5305 .74815 L p F P
0 g
s
.739 .566 .658 r
.50853 .73502 m .50588 .74031 L .51275 .74151 L p F P
0 g
s
.797 .625 .668 r
.50255 .73356 m .50853 .73502 L .50588 .74031 L p F P
0 g
s
.792 .605 .648 r
.50853 .73502 m .50255 .73356 L .50475 .72841 L p F P
0 g
s
.65 .757 .928 r
.37162 .56522 m .36256 .56816 L .36535 .57087 L p F P
0 g
s
.65 .757 .928 r
.36535 .57087 m .37439 .56794 L .37162 .56522 L p F P
0 g
s
.651 .758 .928 r
.65436 .57087 m .66392 .56794 L .66621 .57065 L p F P
0 g
s
.651 .758 .928 r
.66392 .56794 m .65436 .57087 L .65205 .56817 L p F P
0 g
s
.651 .757 .928 r
.51661 .56524 m .5073 .56818 L .50986 .57089 L p F P
0 g
s
.651 .757 .928 r
.50986 .57089 m .51915 .56795 L .51661 .56524 L p F P
0 g
s
.663 .588 .76 r
.55431 .78952 m .54496 .7934 L .54245 .78756 L p F P
0 g
s
.386 0 0 r
.4442 .79406 m .44766 .79635 L .44498 .79467 L p F P
0 g
s
.386 0 0 r
.44498 .79467 m .44039 .79203 L .4442 .79406 L p F P
0 g
s
.819 .639 .659 r
.49954 .72672 m .50475 .72841 L .50255 .73356 L p F P
0 g
s
.817 .624 .641 r
.50475 .72841 m .49954 .72672 L .5014 .72167 L p F P
0 g
s
.727 .563 .668 r
.51275 .74151 m .5095 .74697 L .51738 .74788 L p F P
0 g
s
.778 .616 .679 r
.50588 .74031 m .51275 .74151 L .5095 .74697 L p F P
0 g
s
.628 .486 .669 r
.54219 .73493 m .54888 .73355 L p .54017 .74132 L F P
0 g
s
.625 .479 .663 r
.54888 .73355 m .54847 .73156 L .54219 .73493 L closepath p F P
0 g
s
.619 .466 .653 r
.54784 .72803 m .54847 .73156 L .54219 .73493 L p F P
0 g
s
.915 .867 .777 r
.43185 .70461 m .4336 .70208 L .43215 .69923 L p F P
0 g
s
.887 .903 .833 r
.44965 .67294 m .44528 .67778 L .44797 .67872 L p F P
0 g
s
.894 .894 .821 r
.44797 .67872 m .44528 .682 L .44427 .67898 L p F P
0 g
s
.894 .894 .821 r
.44427 .67898 m .44528 .67778 L .44797 .67872 L p F P
0 g
s
.735 .575 .674 r
.51826 .74795 m .518 .74701 L .51738 .74788 L closepath p F P
0 g
s
.444 .332 .632 r
.55779 .70604 m .55385 .70859 L .55469 .71391 L p F P
0 g
s
.751 .691 .794 r
.49763 .79635 m .50106 .79371 L .49529 .7925 L closepath p F P
0 g
s
.702 .618 .759 r
.53086 .78734 m .53061 .78676 L .5297 .78735 L closepath p F P
0 g
s
.71 .603 .736 r
.51878 .78739 m .51897 .78725 L .5297 .78735 L p F P
0 g
s
.691 .593 .742 r
.52809 .78021 m .51897 .78725 L .5297 .78735 L p F P
0 g
s
.691 .593 .742 r
.5297 .78735 m .53061 .78676 L .52809 .78021 L p F P
0 g
s
.65 .757 .928 r
.23846 .56492 m .22964 .56786 L .23264 .57057 L p F P
0 g
s
.65 .757 .928 r
.23264 .57057 m .24145 .56764 L .23846 .56492 L p F P
0 g
s
.651 .758 .928 r
.81074 .57058 m .82056 .56763 L .82261 .57034 L p F P
0 g
s
.651 .758 .928 r
.82056 .56763 m .81074 .57058 L .80867 .56787 L p F P
0 g
s
.715 .563 .681 r
.5224 .75415 m .51991 .75409 L .51826 .74795 L p F P
0 g
s
.736 .575 .674 r
.51738 .74788 m .51826 .74795 L .51991 .75409 L p F P
0 g
s
.697 .615 .761 r
.53993 .78093 m .54207 .78655 L .53086 .78734 L p F P
0 g
s
.697 .615 .761 r
.53086 .78734 m .53061 .78676 L .53993 .78093 L p F P
0 g
s
.845 .657 .649 r
.49685 .71978 m .5014 .72167 L .49954 .72672 L p F P
0 g
s
.844 .645 .634 r
.5014 .72167 m .49685 .71978 L .49844 .71482 L p F P
0 g
s
.65 .757 .928 r
.38347 .565 m .37439 .56794 L .37716 .57064 L p F P
0 g
s
.65 .757 .928 r
.37716 .57064 m .38623 .56771 L .38347 .565 L p F P
0 g
s
.651 .758 .928 r
.66621 .57065 m .67579 .56771 L .67807 .57042 L p F P
0 g
s
.651 .758 .928 r
.67579 .56771 m .66621 .57065 L .66392 .56794 L p F P
0 g
s
.651 .757 .928 r
.52849 .56501 m .51915 .56795 L .52169 .57066 L p F P
0 g
s
.651 .757 .928 r
.52169 .57066 m .53101 .56773 L .52849 .56501 L p F P
0 g
s
.736 .575 .674 r
.51991 .75409 m .51338 .75356 L .51738 .74788 L p F P
0 g
s
.763 .595 .67 r
.5095 .74697 m .51738 .74788 L .51338 .75356 L p F P
0 g
s
.621 .48 .669 r
.54017 .74132 m .55005 .7392 L p .54739 .74571 L F P
0 g
s
.621 .48 .669 r
.54739 .74571 m .54139 .74703 L .54017 .74132 L p F P
0 g
s
.628 .486 .669 r
.54888 .73355 m .55005 .7392 L .54017 .74132 L p F P
0 g
s
.949 .744 .593 r
.4213 .75444 m .41871 .752 L .41763 .75684 L p F P
0 g
s
.949 .744 .593 r
.41763 .75684 m .42023 .75927 L .4213 .75444 L p F P
0 g
s
.358 .346 .71 r
.63149 .73117 m .62786 .72818 L .62992 .72569 L closepath p F P
0 g
s
.378 .375 .729 r
.62894 .72256 m .62666 .72084 L p .62786 .72818 L F P
0 g
s
.378 .375 .729 r
.62786 .72818 m .62992 .72569 L .62894 .72256 L p F P
0 g
s
.716 .616 .744 r
.51878 .78739 m .51897 .78725 L .51871 .78724 L closepath p F P
0 g
s
.727 .619 .737 r
.51871 .78724 m .51878 .78739 L p .50694 .78933 L F P
0 g
s
.689 .574 .72 r
.53993 .78093 m .53061 .78676 L .52809 .78021 L p F P
0 g
s
.716 .617 .746 r
.52805 .78011 m .52809 .78021 L .51897 .78725 L p F P
0 g
s
.716 .617 .746 r
.5178 .77991 m .52805 .78011 L p .51897 .78725 L F P
0 g
s
.716 .617 .746 r
.51625 .78132 m .5178 .77991 L p .51897 .78725 L F P
0 g
s
.716 .617 .746 r
.51897 .78725 m .51871 .78724 L .51625 .78132 L p F P
0 g
s
.727 .619 .737 r
.50694 .78933 m .50999 .78666 L .51871 .78724 L p F P
0 g
s
.727 .622 .741 r
.51871 .78724 m .51625 .78132 L .50999 .78666 L closepath p F P
0 g
s
.965 .769 .591 r
.49316 .68873 m .49094 .68611 L .48979 .69091 L p F P
0 g
s
.965 .769 .591 r
.48979 .69091 m .49205 .69352 L .49316 .68873 L p F P
0 g
s
.43 .724 .987 r
.46034 .80033 m .46209 .80046 L .45946 .79832 L p F P
0 g
s
.43 .724 .987 r
.45946 .79832 m .45647 .79834 L .46034 .80033 L p F P
0 g
s
.635 .735 .92 r
.57116 .80069 m .58057 .79828 L .58301 .80108 L p F P
0 g
s
.635 .661 .858 r
.57993 .79729 m .58057 .79828 L .57116 .80069 L p F P
0 g
s
.635 .661 .858 r
.57116 .80069 m .57074 .80003 L .57993 .79729 L p F P
0 g
s
.651 .758 .928 r
.82261 .57034 m .83246 .56739 L .83448 .5701 L p F P
0 g
s
.651 .758 .928 r
.83246 .56739 m .82261 .57034 L .82056 .56763 L p F P
0 g
s
.65 .757 .928 r
.25029 .56471 m .24145 .56764 L .24443 .57035 L p F P
0 g
s
.65 .757 .928 r
.24443 .57035 m .25327 .56743 L .25029 .56471 L p F P
0 g
s
.75 .691 .795 r
.50536 .78603 m .50694 .78933 L .50106 .79371 L p F P
0 g
s
.75 .691 .795 r
.50245 .78567 m .50536 .78603 L p .50106 .79371 L F P
0 g
s
.75 .691 .795 r
.49508 .79214 m .50245 .78567 L p .50106 .79371 L F P
0 g
s
.75 .691 .795 r
.50106 .79371 m .49529 .7925 L .49508 .79214 L p F P
0 g
s
.563 .424 .65 r
.54784 .72803 m .55665 .72481 L p .55479 .73137 L F P
0 g
s
.563 .424 .65 r
.55479 .73137 m .54847 .73156 L .54784 .72803 L p F P
0 g
s
.553 .417 .649 r
.55561 .7193 m .55665 .72481 L .54784 .72803 L p F P
0 g
s
.651 .758 .928 r
.67807 .57042 m .68767 .56748 L .68993 .57019 L p F P
0 g
s
.651 .758 .928 r
.68767 .56748 m .67807 .57042 L .67579 .56771 L p F P
0 g
s
.65 .757 .928 r
.39533 .56477 m .38623 .56771 L .38897 .57042 L p F P
0 g
s
.65 .757 .928 r
.38897 .57042 m .39806 .56749 L .39533 .56477 L p F P
0 g
s
.651 .757 .928 r
.54036 .56478 m .53101 .56773 L .53352 .57043 L p F P
0 g
s
.651 .757 .928 r
.53352 .57043 m .54286 .5675 L .54036 .56478 L p F P
0 g
s
.649 .756 .928 r
.11711 .56425 m .1085 .56717 L .1117 .56989 L p F P
0 g
s
.649 .756 .928 r
.1117 .56989 m .1203 .56698 L .11711 .56425 L p F P
0 g
s
.902 .894 .811 r
.44528 .682 m .44427 .67898 L .4396 .68481 L p F P
0 g
s
.902 .894 .811 r
.4396 .68481 m .44057 .68784 L .44528 .682 L p F P
0 g
s
.873 .68 .639 r
.49449 .71275 m .49844 .71482 L .49685 .71978 L p F P
0 g
s
.871 .669 .626 r
.49844 .71482 m .49449 .71275 L .49589 .70785 L p F P
0 g
s
.656 .891 .982 r
.59436 .79958 m .59484 .7998 L .60426 .79616 L p F P
0 g
s
.915 .867 .777 r
.43215 .69923 m .42913 .70353 L .43185 .70461 L p F P
0 g
s
.917 .861 .77 r
.43185 .70461 m .42986 .70764 L .42824 .70484 L p F P
0 g
s
.917 .861 .77 r
.42824 .70484 m .42913 .70353 L .43185 .70461 L p F P
0 g
s
.939 .788 .667 r
.41972 .73949 m .41806 .7437 L .42079 .74533 L p F P
0 g
s
.94 .783 .66 r
.42079 .74533 m .42015 .74707 L .41774 .74457 L p F P
0 g
s
.94 .783 .66 r
.41774 .74457 m .41806 .7437 L .42079 .74533 L p F P
0 g
s
.705 .566 .695 r
.5224 .75415 m .53194 .75408 L p .52777 .76032 L F P
0 g
s
.705 .566 .695 r
.52052 .75637 m .5224 .75415 L p .52777 .76032 L F P
0 g
s
.715 .563 .681 r
.52052 .75637 m .5224 .75415 L .51991 .75409 L closepath p F P
0 g
s
.651 .758 .928 r
.83448 .5701 m .84436 .56715 L .84636 .56986 L p F P
0 g
s
.651 .758 .928 r
.84436 .56715 m .83448 .5701 L .83246 .56739 L p F P
0 g
s
.335 .44 .82 r
.60682 .6803 m .60435 .6791 L .60196 .67408 L p F P
0 g
s
.65 .757 .928 r
.26213 .56449 m .25327 .56743 L .25623 .57014 L p F P
0 g
s
.65 .757 .928 r
.25623 .57014 m .26509 .56721 L .26213 .56449 L p F P
0 g
s
.718 .564 .68 r
.51991 .75409 m .51338 .75356 L p .51742 .76011 L F P
0 g
s
.718 .564 .68 r
.51742 .76011 m .52052 .75637 L .51991 .75409 L p F P
0 g
s
.651 .758 .928 r
.68993 .57019 m .69955 .56725 L .70179 .56996 L p F P
0 g
s
.651 .758 .928 r
.69955 .56725 m .68993 .57019 L .68767 .56748 L p F P
0 g
s
.65 .757 .928 r
.40718 .56455 m .39806 .56749 L .40079 .5702 L p F P
0 g
s
.65 .757 .928 r
.40079 .5702 m .4099 .56727 L .40718 .56455 L p F P
0 g
s
.913 .843 .762 r
.42322 .71853 m .42502 .72122 L .42505 .72123 L p F P
0 g
s
.922 .833 .74 r
.42502 .72122 m .42505 .72123 L .42504 .72125 L closepath p F P
0 g
s
.651 .757 .928 r
.55224 .56456 m .54286 .5675 L .54536 .57021 L p F P
0 g
s
.651 .757 .928 r
.54536 .57021 m .55473 .56727 L .55224 .56456 L p F P
0 g
s
.666 .522 .679 r
.53236 .7558 m .53493 .75376 L .53194 .75408 L closepath p F P
0 g
s
.705 .566 .695 r
.53194 .75408 m .53236 .7558 L .52777 .76032 L p F P
0 g
s
.936 .835 .72 r
.42504 .72125 m .42233 .72652 L .42039 .72384 L p F P
0 g
s
.936 .835 .72 r
.42502 .72122 m .42504 .72125 L p .42039 .72384 L F P
0 g
s
.632 .662 .861 r
.57811 .79451 m .57993 .79729 L .57074 .80003 L p F P
0 g
s
.632 .662 .861 r
.57074 .80003 m .56869 .79682 L .57811 .79451 L p F P
0 g
s
.933 .84 .73 r
.42232 .72017 m .42322 .71853 L .42502 .72122 L closepath p F P
0 g
s
.936 .835 .72 r
.42039 .72384 m .42232 .72017 L .42502 .72122 L p F P
0 g
s
.94 .809 .688 r
.42199 .73433 m .41984 .73173 L .41757 .73689 L p F P
0 g
s
.94 .809 .688 r
.41757 .73689 m .41972 .73949 L .42199 .73433 L p F P
0 g
s
.649 .757 .928 r
.12893 .56406 m .1203 .56698 L .12348 .5697 L p F P
0 g
s
.649 .757 .928 r
.12348 .5697 m .1321 .56679 L .12893 .56406 L p F P
0 g
s
.651 .758 .928 r
.84636 .56986 m .85626 .56691 L .85824 .56962 L p F P
0 g
s
.651 .758 .928 r
.85626 .56691 m .84636 .56986 L .84436 .56715 L p F P
0 g
s
.705 .566 .695 r
.52777 .76032 m .52169 .76035 L .52052 .75637 L p F P
0 g
s
.727 .578 .688 r
.52169 .76035 m .52052 .75637 L .51742 .76011 L closepath p F P
0 g
s
.596 .853 .993 r
.58301 .80108 m .59244 .79848 L .59436 .79958 L p F P
0 g
s
.623 .758 .943 r
.59244 .79848 m .58301 .80108 L .58057 .79828 L p F P
0 g
s
.65 .757 .928 r
.27398 .56427 m .26509 .56721 L .26803 .56992 L p F P
0 g
s
.65 .757 .928 r
.26803 .56992 m .27691 .56699 L .27398 .56427 L p F P
0 g
s
.663 .533 .695 r
.53236 .7558 m .53493 .75376 L p .54406 .75889 L F P
0 g
s
.663 .533 .695 r
.54406 .75889 m .53355 .76018 L .53236 .7558 L p F P
0 g
s
.698 .554 .687 r
.53355 .76018 m .53236 .7558 L .52777 .76032 L closepath p F P
0 g
s
.651 .758 .928 r
.70179 .56996 m .71143 .56702 L .71365 .56973 L p F P
0 g
s
.651 .758 .928 r
.71143 .56702 m .70179 .56996 L .69955 .56725 L p F P
0 g
s
.65 .757 .928 r
.41905 .56432 m .4099 .56727 L .41261 .56997 L p F P
0 g
s
.65 .757 .928 r
.41261 .56997 m .42175 .56704 L .41905 .56432 L p F P
0 g
s
.651 .757 .928 r
.56412 .56433 m .55473 .56727 L .5572 .56998 L p F P
0 g
s
.651 .757 .928 r
.5572 .56998 m .56659 .56705 L .56412 .56433 L p F P
0 g
s
.744 .65 .756 r
.50694 .78933 m .50999 .78666 L .50536 .78603 L closepath p F P
0 g
s
.75 .676 .78 r
.49467 .79241 m .48578 .79857 L .4832 .79508 L p F P
0 g
s
.689 .574 .72 r
.53946 .7795 m .53993 .78093 L p .52809 .78021 L F P
0 g
s
.689 .574 .72 r
.52809 .78021 m .52824 .7801 L .53946 .7795 L p F P
0 g
s
.691 .578 .724 r
.52809 .78021 m .52824 .7801 L .52805 .78011 L closepath p F P
0 g
s
.282 .174 .549 r
.63131 .75938 m .63019 .76041 L .63066 .76532 L p F P
0 g
s
.691 .579 .725 r
.52824 .7801 m .52805 .78011 L .52568 .77328 L p F P
0 g
s
.713 .591 .718 r
.52522 .77328 m .52568 .77328 L .52805 .78011 L p F P
0 g
s
.713 .591 .718 r
.52805 .78011 m .5178 .77991 L .52522 .77328 L p F P
0 g
s
.689 .575 .722 r
.53946 .7795 m .53741 .77347 L .52824 .7801 L closepath p F P
0 g
s
.691 .579 .725 r
.53721 .77279 m .53741 .77347 L .52824 .7801 L p F P
0 g
s
.691 .579 .725 r
.52568 .77328 m .53721 .77279 L p .52824 .7801 L F P
0 g
s
.743 .65 .757 r
.51566 .77979 m .51625 .78132 L .50999 .78666 L p F P
0 g
s
.743 .65 .757 r
.50916 .77923 m .51566 .77979 L p .50999 .78666 L F P
0 g
s
.743 .65 .757 r
.5044 .78403 m .50916 .77923 L p .50999 .78666 L F P
0 g
s
.743 .65 .757 r
.50999 .78666 m .50536 .78603 L .5044 .78403 L p F P
0 g
s
.903 .702 .621 r
.49247 .70561 m .49589 .70785 L .49449 .71275 L p F P
0 g
s
.9 .695 .617 r
.49589 .70785 m .49247 .70561 L .49374 .70075 L p F P
0 g
s
.649 .757 .928 r
.14075 .56386 m .1321 .56679 L .13526 .56951 L p F P
0 g
s
.649 .757 .928 r
.13526 .56951 m .1439 .56659 L .14075 .56386 L p F P
0 g
s
.663 .588 .76 r
.55253 .78503 m .55431 .78952 L p .54245 .78756 L F P
0 g
s
.663 .588 .76 r
.54245 .78756 m .54593 .78596 L .55253 .78503 L p F P
0 g
s
.658 .572 .747 r
.54245 .78756 m .54593 .78596 L .54207 .78655 L closepath p F P
0 g
s
.705 .565 .694 r
.52304 .76502 m .52777 .76032 L .52169 .76035 L closepath p F P
0 g
s
.709 .567 .693 r
.52169 .76035 m .51742 .76011 L p .52146 .76665 L F P
0 g
s
.709 .567 .693 r
.52146 .76665 m .52304 .76502 L .52169 .76035 L p F P
0 g
s
.663 .533 .695 r
.53493 .75376 m .5428 .75293 L p .54406 .75889 L F P
0 g
s
.667 .524 .68 r
.5428 .75293 m .54168 .74838 L .53493 .75376 L closepath p F P
0 g
s
.666 .522 .679 r
.54139 .74703 m .54168 .74838 L .53493 .75376 L p F P
0 g
s
.698 .572 .71 r
.52777 .76032 m .53355 .76018 L p .53328 .76646 L F P
0 g
s
.698 .572 .71 r
.52304 .76502 m .52777 .76032 L p .53328 .76646 L F P
0 g
s
.651 .758 .928 r
.85824 .56962 m .86816 .56667 L .87013 .56938 L p F P
0 g
s
.651 .758 .928 r
.86816 .56667 m .85824 .56962 L .85626 .56691 L p F P
0 g
s
.325 .264 .634 r
.63456 .74368 m .63116 .74717 L .63377 .75105 L p F P
0 g
s
.353 .307 .667 r
.6341 .7417 m .63203 .73926 L p .63116 .74717 L F P
0 g
s
.353 .307 .667 r
.63116 .74717 m .63456 .74368 L .6341 .7417 L p F P
0 g
s
.658 .574 .75 r
.54593 .78596 m .54207 .78655 L .53993 .78093 L p F P
0 g
s
.645 .627 .817 r
.55682 .79497 m .5662 .79209 L .56869 .79682 L p F P
0 g
s
.64 .596 .789 r
.56547 .79044 m .5662 .79209 L .55682 .79497 L p F P
0 g
s
.64 .596 .789 r
.55682 .79497 m .55578 .7927 L .56547 .79044 L p F P
0 g
s
.65 .757 .928 r
.28582 .56405 m .27691 .56699 L .27984 .5697 L p F P
0 g
s
.65 .757 .928 r
.27984 .5697 m .28874 .56677 L .28582 .56405 L p F P
0 g
s
.651 .758 .928 r
.71365 .56973 m .72331 .56679 L .72552 .5695 L p F P
0 g
s
.651 .758 .928 r
.72331 .56679 m .71365 .56973 L .71143 .56702 L p F P
0 g
s
.65 .757 .928 r
.43091 .5641 m .42175 .56704 L .42444 .56975 L p F P
0 g
s
.65 .757 .928 r
.42444 .56975 m .43359 .56682 L .43091 .5641 L p F P
0 g
s
.355 .359 .726 r
.62894 .72256 m .62666 .72084 L .6279 .7192 L closepath p F P
0 g
s
.377 .389 .746 r
.62642 .71484 m .62476 .71369 L p .62666 .72084 L F P
0 g
s
.377 .389 .746 r
.62666 .72084 m .6279 .7192 L .62642 .71484 L p F P
0 g
s
.651 .757 .928 r
.57601 .5641 m .56659 .56705 L .56905 .56976 L p F P
0 g
s
.651 .757 .928 r
.56905 .56976 m .57846 .56682 L .57601 .5641 L p F P
0 g
s
.725 .61 .728 r
.51625 .78132 m .5178 .77991 L .51566 .77979 L closepath p F P
0 g
s
.95 .771 .624 r
.42015 .74707 m .41774 .74457 L .41629 .7495 L p F P
0 g
s
.95 .771 .624 r
.41629 .7495 m .41871 .752 L .42015 .74707 L p F P
0 g
s
.725 .611 .73 r
.51549 .77289 m .52522 .77328 L .5178 .77991 L p F P
0 g
s
.725 .611 .73 r
.51372 .77476 m .51549 .77289 L p .5178 .77991 L F P
0 g
s
.725 .611 .73 r
.5178 .77991 m .51566 .77979 L .51372 .77476 L p F P
0 g
s
.909 .536 .308 r
.43335 .78632 m .43004 .78414 L .42882 .77991 L p F P
0 g
s
.916 .537 .285 r
.42567 .77767 m .42882 .77991 L .43004 .78414 L p F P
0 g
s
.931 .616 .422 r
.42882 .77991 m .42567 .77767 L .4252 .77325 L p F P
0 g
s
.926 .857 .753 r
.42986 .70764 m .42824 .70484 L .42487 .7103 L p F P
0 g
s
.926 .857 .753 r
.42487 .7103 m .42648 .7131 L .42986 .70764 L p F P
0 g
s
.663 .531 .694 r
.53489 .76512 m .54406 .75889 L .53355 .76018 L closepath p F P
0 g
s
.698 .572 .71 r
.53355 .76018 m .53489 .76512 L .53328 .76646 L p F P
0 g
s
.66 .746 .913 r
.46209 .80046 m .47132 .79746 L .47393 .80023 L p F P
0 g
s
.691 .739 .888 r
.47132 .79746 m .46209 .80046 L .45946 .79832 L p F P
0 g
s
.621 .481 .67 r
.54168 .74838 m .54739 .74571 L .54139 .74703 L closepath p F P
0 g
s
.628 .863 .987 r
.59244 .79848 m .59436 .79958 L .60256 .79582 L p F P
0 g
s
.656 .891 .982 r
.60426 .79616 m .60256 .79582 L .59436 .79958 L p F P
0 g
s
.698 .572 .71 r
.53328 .76646 m .52359 .76673 L .52304 .76502 L p F P
0 g
s
.72 .584 .703 r
.52359 .76673 m .52304 .76502 L .52146 .76665 L closepath p F P
0 g
s
.698 .571 .708 r
.52557 .77297 m .53328 .76646 L .52359 .76673 L closepath p F P
0 g
s
.702 .573 .707 r
.52359 .76673 m .52146 .76665 L p .52522 .77328 L F P
0 g
s
.702 .573 .707 r
.52522 .77328 m .52557 .77297 L .52359 .76673 L p F P
0 g
s
.997 .824 .549 r
.49203 .68133 m .4907 .67843 L .48949 .68325 L p F P
0 g
s
.997 .824 .549 r
.48949 .68325 m .49094 .68611 L .49203 .68133 L p F P
0 g
s
.65 .757 .928 r
.15258 .56366 m .1439 .56659 L .14704 .56931 L p F P
0 g
s
.65 .757 .928 r
.14704 .56931 m .15571 .56639 L .15258 .56366 L p F P
0 g
s
.564 .438 .668 r
.54888 .73355 m .54847 .73156 L .55479 .73137 L closepath p F P
0 g
s
.708 .59 .721 r
.53527 .76638 m .53721 .77279 L .52568 .77328 L p F P
0 g
s
.708 .59 .721 r
.53328 .76646 m .53527 .76638 L p .52568 .77328 L F P
0 g
s
.708 .59 .721 r
.52568 .77328 m .52557 .77297 L .53328 .76646 L p F P
0 g
s
.713 .593 .72 r
.52568 .77328 m .52557 .77297 L .52522 .77328 L closepath p F P
0 g
s
.702 .573 .707 r
.52146 .76665 m .51549 .77289 L .52522 .77328 L p F P
0 g
s
.718 .564 .68 r
.51338 .75356 m .50945 .75922 L .51742 .76011 L p F P
0 g
s
.761 .609 .69 r
.50628 .75243 m .51338 .75356 L .50945 .75922 L p F P
0 g
s
.763 .595 .67 r
.51338 .75356 m .50628 .75243 L .5095 .74697 L p F P
0 g
s
.651 .758 .928 r
.87013 .56938 m .88007 .56642 L .88202 .56913 L p F P
0 g
s
.651 .758 .928 r
.88007 .56642 m .87013 .56938 L .86816 .56667 L p F P
0 g
s
.941 .624 .408 r
.42222 .77095 m .4252 .77325 L .42567 .77767 L p F P
0 g
s
.941 .671 .499 r
.4252 .77325 m .42222 .77095 L .42237 .76636 L p F P
0 g
s
.777 .615 .679 r
.50394 .7458 m .5095 .74697 L .50628 .75243 L p F P
0 g
s
.778 .616 .679 r
.50361 .74479 m .50588 .74031 L p .5095 .74697 L F P
0 g
s
.778 .616 .679 r
.5095 .74697 m .50394 .7458 L .50361 .74479 L p F P
0 g
s
.709 .567 .693 r
.51742 .76011 m .5126 .76602 L .52146 .76665 L p F P
0 g
s
.747 .607 .702 r
.50945 .75922 m .51742 .76011 L .5126 .76602 L p F P
0 g
s
.225 .164 .575 r
.55853 .68783 m .56055 .6853 L .55894 .68128 L p F P
0 g
s
.004 .012 .513 r
.56096 .67744 m .55894 .68128 L .56055 .6853 L p F P
0 g
s
.044 .025 .508 r
.55894 .68128 m .56096 .67744 L .55988 .67328 L p F P
0 g
s
.905 .894 .807 r
.43858 .69035 m .44057 .68784 L .4396 .68481 L p F P
0 g
s
.734 .615 .726 r
.51566 .77979 m .51372 .77476 L .50916 .77923 L closepath p F P
0 g
s
.735 .607 .715 r
.5126 .76602 m .52146 .76665 L .51549 .77289 L p F P
0 g
s
.227 .169 .581 r
.56055 .6853 m .55853 .68783 L .55929 .69303 L p F P
0 g
s
.371 .272 .612 r
.55863 .69358 m .55929 .69303 L .55853 .68783 L p F P
0 g
s
.65 .757 .928 r
.29767 .56383 m .28874 .56677 L .29164 .56948 L p F P
0 g
s
.65 .757 .928 r
.29164 .56948 m .30057 .56655 L .29767 .56383 L p F P
0 g
s
.725 .194 0 r
.43335 .78634 m .43338 .78634 L p .44039 .79203 L F P
0 g
s
.874 .45 .198 r
.43335 .78634 m .43335 .78632 L .43338 .78634 L closepath p F P
0 g
s
.651 .758 .928 r
.72552 .5695 m .7352 .56656 L .73739 .56927 L p F P
0 g
s
.651 .758 .928 r
.7352 .56656 m .72552 .5695 L .72331 .56679 L p F P
0 g
s
.65 .757 .928 r
.44278 .56387 m .43359 .56682 L .43627 .56953 L p F P
0 g
s
.65 .757 .928 r
.43627 .56953 m .44544 .56659 L .44278 .56387 L p F P
0 g
s
.651 .757 .928 r
.5879 .56387 m .57846 .56682 L .58089 .56953 L p F P
0 g
s
.651 .757 .928 r
.58089 .56953 m .59032 .56659 L .5879 .56387 L p F P
0 g
s
.87 .431 .145 r
.43335 .78632 m .43335 .78634 L .43064 .78534 L p F P
0 g
s
.87 .431 .145 r
.43064 .78534 m .43004 .78414 L .43335 .78632 L p F P
0 g
s
.725 .194 0 r
.44039 .79203 m .43673 .78996 L .43335 .78634 L p F P
0 g
s
.727 .197 0 r
.43673 .78996 m .43335 .78634 L .43064 .78534 L p F P
0 g
s
.797 .626 .669 r
.50361 .74479 m .50588 .74031 L .50182 .73922 L closepath p F P
0 g
s
.797 .625 .668 r
.50109 .73692 m .50255 .73356 L p .50588 .74031 L F P
0 g
s
.797 .625 .668 r
.50588 .74031 m .50182 .73922 L .50109 .73692 L p F P
0 g
s
.761 .757 .849 r
.47586 .79912 m .47393 .80023 L .47132 .79746 L p F P
0 g
s
.629 .5 .686 r
.5428 .75293 m .54168 .74838 L .54739 .74571 L p F P
0 g
s
.65 .757 .928 r
.1644 .56346 m .15571 .56639 L .15883 .56911 L p F P
0 g
s
.65 .757 .928 r
.15883 .56911 m .16752 .56619 L .1644 .56346 L p F P
0 g
s
.486 .363 .637 r
.55469 .71391 m .56157 .70948 L p .55689 .71853 L F P
0 g
s
.486 .363 .637 r
.55689 .71853 m .55529 .71756 L .55469 .71391 L p F P
0 g
s
.444 .332 .632 r
.55469 .71391 m .56157 .70948 L .55779 .70604 L p F P
0 g
s
.693 .564 .704 r
.53527 .76638 m .53489 .76512 L .53328 .76646 L closepath p F P
0 g
s
.93 .732 .612 r
.49086 .69834 m .49374 .70075 L .49247 .70561 L p F P
0 g
s
.93 .728 .608 r
.49374 .70075 m .49086 .69834 L .49205 .69352 L p F P
0 g
s
.65 .757 .928 r
.30952 .56361 m .30057 .56655 L .30346 .56927 L p F P
0 g
s
.65 .757 .928 r
.30346 .56927 m .3124 .56633 L .30952 .56361 L p F P
0 g
s
.651 .758 .928 r
.73739 .56927 m .7471 .56633 L .74926 .56904 L p F P
0 g
s
.651 .758 .928 r
.7471 .56633 m .73739 .56927 L .7352 .56656 L p F P
0 g
s
.643 .6 .791 r
.5637 .78649 m .56547 .79044 L .55578 .7927 L p F P
0 g
s
.643 .6 .791 r
.55578 .7927 m .55431 .78952 L .5637 .78649 L p F P
0 g
s
.65 .757 .928 r
.45465 .56365 m .44544 .56659 L .4481 .5693 L p F P
0 g
s
.65 .757 .928 r
.4481 .5693 m .4573 .56637 L .45465 .56365 L p F P
0 g
s
.651 .757 .928 r
.59979 .56365 m .59032 .56659 L .59274 .5693 L p F P
0 g
s
.651 .757 .928 r
.59274 .5693 m .6022 .56637 L .59979 .56365 L p F P
0 g
s
.819 .64 .66 r
.50109 .73692 m .50255 .73356 L .49964 .73257 L closepath p F P
0 g
s
.819 .639 .659 r
.49856 .72931 m .49954 .72672 L p .50255 .73356 L F P
0 g
s
.819 .639 .659 r
.50255 .73356 m .49964 .73257 L .49856 .72931 L p F P
0 g
s
.673 .552 .709 r
.53527 .76638 m .53489 .76512 L .54406 .75889 L p F P
0 g
s
.564 .439 .668 r
.55005 .7392 m .54888 .73355 L .55479 .73137 L p F P
0 g
s
.658 .574 .75 r
.53993 .78093 m .54394 .77884 L p .54593 .78596 L F P
0 g
s
.659 .556 .728 r
.53993 .78093 m .54394 .77884 L .53946 .7795 L closepath p F P
0 g
s
.66 .543 .711 r
.53527 .76638 m .54596 .76507 L p .53896 .77255 L F P
0 g
s
.66 .543 .711 r
.53896 .77255 m .53721 .77279 L .53527 .76638 L p F P
0 g
s
.673 .552 .709 r
.54424 .75886 m .54596 .76507 L .53527 .76638 L p F P
0 g
s
.673 .552 .709 r
.54406 .75889 m .54424 .75886 L p .53527 .76638 L F P
0 g
s
.952 .682 .49 r
.41957 .764 m .42237 .76636 L .42222 .77095 L p F P
0 g
s
.946 .712 .552 r
.42237 .76636 m .41957 .764 L .42023 .75927 L p F P
0 g
s
.659 .558 .73 r
.54394 .77884 m .53946 .7795 L .53741 .77347 L p F P
0 g
s
.905 .894 .807 r
.4396 .68481 m .43587 .68946 L .43858 .69035 L p F P
0 g
s
.908 .886 .799 r
.43858 .69035 m .43618 .69358 L .43497 .69064 L p F P
0 g
s
.908 .886 .799 r
.43497 .69064 m .43587 .68946 L .43858 .69035 L p F P
0 g
s
.74 .649 .759 r
.50536 .78603 m .5044 .78403 L .50245 .78567 L closepath p F P
0 g
s
.735 .606 .714 r
.51372 .77476 m .51549 .77289 L .51297 .77267 L closepath p F P
0 g
s
.735 .607 .715 r
.51119 .76775 m .5126 .76602 L p .51549 .77289 L F P
0 g
s
.735 .607 .715 r
.51549 .77289 m .51297 .77267 L .51119 .76775 L p F P
0 g
s
.65 .757 .928 r
.17624 .56326 m .16752 .56619 L .17062 .56891 L p F P
0 g
s
.65 .757 .928 r
.17062 .56891 m .17933 .56598 L .17624 .56326 L p F P
0 g
s
.761 .757 .849 r
.47132 .79746 m .47168 .79722 L .47586 .79912 L p F P
0 g
s
.719 .709 .839 r
.48062 .79145 m .47168 .79722 L .47586 .79912 L p F P
0 g
s
.719 .709 .839 r
.47586 .79912 m .4832 .79508 L .48062 .79145 L p F P
0 g
s
.352 .373 .743 r
.62642 .71484 m .62476 .71369 L .62561 .71243 L closepath p F P
0 g
s
.375 .403 .762 r
.62392 .7078 m .62223 .70672 L p .62476 .71369 L F P
0 g
s
.375 .403 .762 r
.62476 .71369 m .62561 .71243 L .62392 .7078 L p F P
0 g
s
.663 .587 .76 r
.55253 .78503 m .5518 .78324 L .54593 .78596 L closepath p F P
0 g
s
.658 .574 .75 r
.54998 .77804 m .5518 .78324 L .54593 .78596 L p F P
0 g
s
.658 .574 .75 r
.54394 .77884 m .54998 .77804 L p .54593 .78596 L F P
0 g
s
.252 .064 .419 r
.62371 .77937 m .62592 .77775 L .62706 .77281 L p F P
0 g
s
.235 .048 .411 r
.63082 .76993 m .62706 .77281 L .62592 .77775 L p F P
0 g
s
.3 .149 .503 r
.62706 .77281 m .63082 .76993 L .63066 .76532 L p F P
0 g
s
.651 .758 .928 r
.74926 .56904 m .75899 .5661 L .76114 .56881 L p F P
0 g
s
.651 .758 .928 r
.75899 .5661 m .74926 .56904 L .7471 .56633 L p F P
0 g
s
.65 .757 .928 r
.32138 .56339 m .3124 .56633 L .31527 .56905 L p F P
0 g
s
.65 .757 .928 r
.31527 .56905 m .32424 .56611 L .32138 .56339 L p F P
0 g
s
.153 0 .277 r
.62592 .77775 m .62371 .77937 L .62304 .78318 L p F P
0 g
s
.651 .757 .928 r
.61168 .56342 m .6022 .56637 L .6046 .56908 L p F P
0 g
s
.651 .757 .928 r
.6046 .56908 m .61407 .56614 L .61168 .56342 L p F P
0 g
s
.66 .542 .71 r
.53741 .77347 m .53896 .77255 L .53721 .77279 L closepath p F P
0 g
s
.65 .757 .928 r
.46653 .56342 m .4573 .56637 L .45993 .56908 L p F P
0 g
s
.65 .757 .928 r
.45993 .56908 m .46915 .56614 L .46653 .56342 L p F P
0 g
s
.732 .685 .805 r
.49529 .7925 m .49508 .79214 L .49467 .79241 L closepath p F P
0 g
s
.727 .602 .717 r
.50916 .77923 m .51372 .77476 L .51297 .77267 L p F P
0 g
s
.659 .558 .73 r
.53741 .77347 m .53896 .77255 L p .54394 .77884 L F P
0 g
s
.844 .658 .651 r
.49856 .72931 m .49954 .72672 L .49727 .72574 L closepath p F P
0 g
s
.845 .657 .649 r
.49603 .72226 m .49685 .71978 L p .49954 .72672 L F P
0 g
s
.845 .657 .649 r
.49954 .72672 m .49727 .72574 L .49603 .72226 L p F P
0 g
s
.75 .676 .78 r
.4832 .79508 m .488 .79119 L .49467 .79241 L p F P
0 g
s
.727 .672 .796 r
.49252 .78767 m .488 .79119 L .49467 .79241 L p F P
0 g
s
.727 .672 .796 r
.49467 .79241 m .49508 .79214 L .49252 .78767 L p F P
0 g
s
.727 .602 .717 r
.51297 .77267 m .50736 .77206 L p .50916 .77923 L F P
0 g
s
.743 .611 .712 r
.51297 .77267 m .51119 .76775 L .50736 .77206 L closepath p F P
0 g
s
.65 .757 .928 r
.18807 .56305 m .17933 .56598 L .18242 .5687 L p F P
0 g
s
.65 .757 .928 r
.18242 .5687 m .19115 .56577 L .18807 .56305 L p F P
0 g
s
.758 .631 .719 r
.50916 .77923 m .5044 .78403 L .50186 .77843 L p F P
0 g
s
.758 .631 .719 r
.50186 .77843 m .50214 .77809 L .50916 .77923 L p F P
0 g
s
.727 .602 .717 r
.50736 .77206 m .50214 .77809 L .50916 .77923 L p F P
0 g
s
.758 .651 .743 r
.50245 .78567 m .49508 .79214 L .49252 .78767 L p F P
0 g
s
.335 .44 .82 r
.60196 .67408 m .60198 .67399 L p .60682 .6803 L F P
0 g
s
.625 .496 .685 r
.54422 .75878 m .5428 .75293 L .55264 .75077 L p F P
0 g
s
.663 .533 .695 r
.5428 .75293 m .54422 .75878 L .54406 .75889 L p F P
0 g
s
.629 .5 .686 r
.55124 .74489 m .55264 .75077 L .5428 .75293 L p F P
0 g
s
.629 .5 .686 r
.54739 .74571 m .55124 .74489 L p .5428 .75293 L F P
0 g
s
.651 .758 .928 r
.76114 .56881 m .77089 .56586 L .77302 .56857 L p F P
0 g
s
.651 .758 .928 r
.77089 .56586 m .76114 .56881 L .75899 .5661 L p F P
0 g
s
.65 .757 .928 r
.33324 .56317 m .32424 .56611 L .32709 .56882 L p F P
0 g
s
.65 .757 .928 r
.32709 .56882 m .33608 .56589 L .33324 .56317 L p F P
0 g
s
.747 .606 .701 r
.51119 .76775 m .5126 .76602 L .51052 .76578 L closepath p F P
0 g
s
.747 .607 .702 r
.50867 .76036 m .50945 .75922 L p .5126 .76602 L F P
0 g
s
.747 .607 .702 r
.5126 .76602 m .51052 .76578 L .50867 .76036 L p F P
0 g
s
.651 .757 .928 r
.62358 .56319 m .61407 .56614 L .61646 .56885 L p F P
0 g
s
.651 .757 .928 r
.61646 .56885 m .62595 .56591 L .62358 .56319 L p F P
0 g
s
.65 .757 .928 r
.47841 .56319 m .46915 .56614 L .47177 .56885 L p F P
0 g
s
.65 .757 .928 r
.47177 .56885 m .48101 .56592 L .47841 .56319 L p F P
0 g
s
.335 .44 .82 r
.60198 .67399 m .60748 .67688 L .60682 .6803 L p F P
0 g
s
.294 .434 .832 r
.60222 .67067 m .60198 .67399 L .60748 .67688 L p F P
0 g
s
.659 .558 .73 r
.53896 .77255 m .54785 .77143 L p .54394 .77884 L F P
0 g
s
.664 .55 .716 r
.54785 .77143 m .54675 .76795 L .53896 .77255 L closepath p F P
0 g
s
.66 .543 .711 r
.54596 .76507 m .54675 .76795 L .53896 .77255 L p F P
0 g
s
.758 .651 .743 r
.49252 .78767 m .49567 .78447 L .50245 .78567 L p F P
0 g
s
.734 .638 .752 r
.50186 .77843 m .49567 .78447 L .50245 .78567 L p F P
0 g
s
.734 .638 .752 r
.50245 .78567 m .5044 .78403 L .50186 .77843 L p F P
0 g
s
.282 .174 .549 r
.63066 .76532 m .63243 .76369 L .63131 .75938 L p F P
0 g
s
.273 .171 .552 r
.63574 .75512 m .63131 .75938 L .63243 .76369 L p F P
0 g
s
.319 .229 .594 r
.63377 .75105 m .63574 .75512 L .63131 .75938 L p F P
0 g
s
.942 .827 .702 r
.42233 .72652 m .42039 .72384 L .41789 .72906 L p F P
0 g
s
.942 .827 .702 r
.41789 .72906 m .41984 .73173 L .42233 .72652 L p F P
0 g
s
.65 .757 .928 r
.19992 .56284 m .19115 .56577 L .19422 .56849 L p F P
0 g
s
.65 .757 .928 r
.19422 .56849 m .20297 .56556 L .19992 .56284 L p F P
0 g
s
.917 .884 .785 r
.43618 .69358 m .43497 .69064 L .43094 .69629 L p F P
0 g
s
.917 .884 .785 r
.43094 .69629 m .43215 .69923 L .43618 .69358 L p F P
0 g
s
.376 .281 .619 r
.55958 .69489 m .55863 .69358 L .55929 .69303 L closepath p F P
0 g
s
.349 .387 .759 r
.62392 .7078 m .62223 .70672 L .62303 .70536 L closepath p F P
0 g
s
.373 .418 .779 r
.62143 .70129 m .6191 .69991 L p .62223 .70672 L F P
0 g
s
.373 .418 .779 r
.62223 .70672 m .62303 .70536 L .62143 .70129 L p F P
0 g
s
.957 .725 .547 r
.42023 .75927 m .41763 .75684 L .41697 .76157 L p F P
0 g
s
.957 .725 .547 r
.41697 .76157 m .41957 .764 L .42023 .75927 L p F P
0 g
s
.651 .758 .928 r
.77302 .56857 m .78279 .56563 L .7849 .56834 L p F P
0 g
s
.651 .758 .928 r
.78279 .56563 m .77302 .56857 L .77089 .56586 L p F P
0 g
s
.65 .757 .928 r
.3451 .56294 m .33608 .56589 L .33891 .5686 L p F P
0 g
s
.65 .757 .928 r
.33891 .5686 m .34792 .56567 L .3451 .56294 L p F P
0 g
s
.736 .601 .706 r
.50736 .77206 m .51119 .76775 L .51052 .76578 L p F P
0 g
s
.651 .758 .928 r
.62832 .56862 m .63784 .56568 L .64018 .5684 L p F P
0 g
s
.651 .758 .928 r
.63548 .56296 m .62595 .56591 L .62832 .56862 L p F P
0 g
s
.651 .758 .928 r
.62832 .56862 m .63784 .56568 L .63548 .56296 L p F P
0 g
s
.651 .757 .928 r
.49029 .56297 m .48101 .56592 L .48361 .56863 L p F P
0 g
s
.651 .757 .928 r
.48361 .56863 m .49288 .56569 L .49029 .56297 L p F P
0 g
s
.962 .769 .598 r
.49205 .69352 m .48979 .69091 L .48857 .69575 L p F P
0 g
s
.962 .769 .598 r
.48857 .69575 m .49086 .69834 L .49205 .69352 L p F P
0 g
s
.761 .609 .69 r
.50867 .76036 m .50945 .75922 L .50823 .75903 L closepath p F P
0 g
s
.761 .609 .69 r
.50614 .75267 m .50628 .75243 L p .50945 .75922 L F P
0 g
s
.761 .609 .69 r
.50945 .75922 m .50823 .75903 L .50614 .75267 L p F P
0 g
s
.638 .571 .763 r
.56228 .78282 m .5637 .78649 L .55431 .78952 L p F P
0 g
s
.638 .571 .763 r
.55431 .78952 m .55253 .78503 L .56228 .78282 L p F P
0 g
s
.872 .681 .642 r
.49603 .72226 m .49685 .71978 L .49445 .71849 L closepath p F P
0 g
s
.873 .68 .639 r
.49348 .71612 m .49449 .71275 L p .49685 .71978 L F P
0 g
s
.873 .68 .639 r
.49685 .71978 m .49445 .71849 L .49348 .71612 L p F P
0 g
s
.944 .809 .681 r
.41972 .73949 m .41757 .73689 L .41555 .74199 L p F P
0 g
s
.944 .809 .681 r
.41806 .7437 m .41972 .73949 L p .41555 .74199 L F P
0 g
s
.736 .601 .706 r
.51052 .76578 m .50503 .76503 L p .50736 .77206 L F P
0 g
s
.753 .61 .699 r
.51052 .76578 m .50867 .76036 L .50503 .76503 L closepath p F P
0 g
s
.626 .623 .828 r
.57811 .79451 m .56869 .79682 L .5662 .79209 L p F P
0 g
s
.344 .428 .804 r
.60682 .6803 m .61243 .68319 L .61134 .68671 L p F P
0 g
s
.341 .457 .833 r
.60748 .67688 m .60682 .6803 L .61243 .68319 L p F P
0 g
s
0 .288 .686 r
.44039 .79203 m .44498 .79467 L .44231 .79277 L p F P
0 g
s
0 .288 .686 r
.44231 .79277 m .43673 .78996 L .44039 .79203 L p F P
0 g
s
.663 .567 .737 r
.54998 .77804 m .54928 .77607 L .54394 .77884 L closepath p F P
0 g
s
.659 .558 .73 r
.54785 .77143 m .54928 .77607 L .54394 .77884 L p F P
0 g
s
.931 .859 .748 r
.42648 .7131 m .42487 .7103 L .42163 .71573 L p F P
0 g
s
.931 .859 .748 r
.42163 .71573 m .42322 .71853 L .42648 .7131 L p F P
0 g
s
.65 .757 .928 r
.21176 .56262 m .20297 .56556 L .20602 .56828 L p F P
0 g
s
.65 .757 .928 r
.20602 .56828 m .2148 .56535 L .21176 .56262 L p F P
0 g
s
.942 .848 .415 r
.49186 .67363 m .49181 .67247 L .49049 .67569 L p F P
0 g
s
.942 .848 .415 r
.49049 .67569 m .4907 .67843 L .49186 .67363 L p F P
0 g
s
.651 .758 .928 r
.7849 .56834 m .79469 .56539 L .79678 .56811 L p F P
0 g
s
.651 .758 .928 r
.79469 .56539 m .7849 .56834 L .78279 .56563 L p F P
0 g
s
.474 .367 .653 r
.55561 .7193 m .55529 .71756 L .55689 .71853 L closepath p F P
0 g
s
.344 .4 .776 r
.62143 .70129 m .6191 .69991 L .62011 .69792 L closepath p F P
0 g
s
.371 .433 .795 r
.61896 .69519 m .61545 .69324 L p .6191 .69991 L F P
0 g
s
.371 .433 .795 r
.6191 .69991 m .62011 .69792 L .61896 .69519 L p F P
0 g
s
.65 .757 .928 r
.35696 .56272 m .34792 .56567 L .35073 .56838 L p F P
0 g
s
.65 .757 .928 r
.35073 .56838 m .35977 .56544 L .35696 .56272 L p F P
0 g
s
.651 .758 .928 r
.64018 .5684 m .64972 .56545 L .65205 .56817 L p F P
0 g
s
.651 .758 .928 r
.64972 .56545 m .64018 .5684 L .63784 .56568 L p F P
0 g
s
.651 .757 .928 r
.50218 .56274 m .49288 .56569 L .49546 .5684 L p F P
0 g
s
.651 .757 .928 r
.49546 .5684 m .50474 .56546 L .50218 .56274 L p F P
0 g
s
.748 .602 .696 r
.50503 .76503 m .50867 .76036 L .50823 .75903 L p F P
0 g
s
.748 .602 .696 r
.50823 .75903 m .50245 .75807 L p .50503 .76503 L F P
0 g
s
.763 .611 .689 r
.50823 .75903 m .50614 .75267 L .50245 .75807 L closepath p F P
0 g
s
.367 .447 .811 r
.61648 .6894 m .61134 .68671 L p .61545 .69324 L F P
0 g
s
.319 .416 .804 r
.61134 .68671 m .61648 .6894 L .61402 .68407 L p F P
0 g
s
.319 .416 .804 r
.61402 .68407 m .61243 .68319 L .61134 .68671 L p F P
0 g
s
.777 .616 .68 r
.50614 .75267 m .50628 .75243 L .50605 .75238 L closepath p F P
0 g
s
.777 .615 .679 r
.50628 .75243 m .50605 .75238 L .50394 .7458 L p F P
0 g
s
.333 .293 .664 r
.6341 .7417 m .63203 .73926 L .63324 .73792 L closepath p F P
0 g
s
.355 .325 .687 r
.63203 .73926 m .63324 .73792 L .63172 .73194 L p F P
0 g
s
.338 .414 .793 r
.61896 .69519 m .61545 .69324 L .61678 .69005 L closepath p F P
0 g
s
.367 .447 .811 r
.61545 .69324 m .61678 .69005 L .61648 .6894 L p F P
0 g
s
.761 .607 .687 r
.50245 .75807 m .50614 .75267 L .50605 .75238 L p F P
0 g
s
.761 .607 .687 r
.50605 .75238 m .49981 .75112 L p .50245 .75807 L F P
0 g
s
.776 .614 .68 r
.5031 .74563 m .50394 .7458 L .50605 .75238 L p F P
0 g
s
.776 .614 .68 r
.50605 .75238 m .49981 .75112 L .5031 .74563 L p F P
0 g
s
.775 .614 .68 r
.50394 .7458 m .50361 .74479 L .5031 .74563 L closepath p F P
0 g
s
.775 .615 .68 r
.5031 .74563 m .50361 .74479 L .50182 .73922 L p F P
0 g
s
.789 .621 .673 r
.50182 .73922 m .50109 .73692 L .50008 .73879 L closepath p F P
0 g
s
.794 .628 .675 r
.50008 .73879 m .50109 .73692 L .49964 .73257 L p F P
0 g
s
.775 .615 .68 r
.50182 .73922 m .50008 .73879 L p .5031 .74563 L F P
0 g
s
.572 .444 .667 r
.55005 .7392 m .55891 .73604 L p .55469 .74366 L F P
0 g
s
.572 .444 .667 r
.55469 .74366 m .55103 .74398 L .55005 .7392 L p F P
0 g
s
.564 .439 .668 r
.55787 .73126 m .55891 .73604 L .55005 .7392 L p F P
0 g
s
.564 .439 .668 r
.55479 .73137 m .55787 .73126 L p .55005 .7392 L F P
0 g
s
.621 .48 .669 r
.55005 .7392 m .55103 .74398 L .54739 .74571 L p F P
0 g
s
.768 .646 .728 r
.50063 .77083 m .50736 .77206 L .50214 .77809 L p F P
0 g
s
.736 .601 .706 r
.50503 .76503 m .50063 .77083 L .50736 .77206 L p F P
0 g
s
.65 .757 .928 r
.22361 .56241 m .2148 .56535 L .21783 .56807 L p F P
0 g
s
.65 .757 .928 r
.21783 .56807 m .22663 .56514 L .22361 .56241 L p F P
0 g
s
.499 .746 .983 r
.45647 .79834 m .45946 .79832 L .45682 .79601 L p F P
0 g
s
.499 .746 .983 r
.45682 .79601 m .45261 .79633 L .45647 .79834 L p F P
0 g
s
.211 .664 .948 r
.44766 .79635 m .45261 .79633 L .45647 .79834 L p F P
0 g
s
.665 .536 .698 r
.54424 .75886 m .54422 .75878 L .54406 .75889 L closepath p F P
0 g
s
.651 .758 .928 r
.79678 .56811 m .8066 .56516 L .80867 .56787 L p F P
0 g
s
.651 .758 .928 r
.8066 .56516 m .79678 .56811 L .79469 .56539 L p F P
0 g
s
.631 .516 .704 r
.54424 .75886 m .54422 .75878 L .55358 .75479 L p F P
0 g
s
.625 .496 .685 r
.55264 .75077 m .55358 .75479 L .54422 .75878 L p F P
0 g
s
.63 .515 .703 r
.54596 .76507 m .54424 .75886 L .5541 .75673 L p F P
0 g
s
.631 .516 .704 r
.55358 .75479 m .5541 .75673 L .54424 .75886 L p F P
0 g
s
.794 .628 .675 r
.49964 .73257 m .49732 .73188 L p .50008 .73879 L F P
0 g
s
.806 .633 .667 r
.49964 .73257 m .49856 .72931 L .49732 .73188 L closepath p F P
0 g
s
.65 .757 .928 r
.36883 .56249 m .35977 .56544 L .36256 .56816 L p F P
0 g
s
.65 .757 .928 r
.36256 .56816 m .37162 .56522 L .36883 .56249 L p F P
0 g
s
.627 .494 .681 r
.55124 .74489 m .55103 .74398 L .54739 .74571 L closepath p F P
0 g
s
.651 .758 .928 r
.65205 .56817 m .66161 .56522 L .66392 .56794 L p F P
0 g
s
.651 .758 .928 r
.66161 .56522 m .65205 .56817 L .64972 .56545 L p F P
0 g
s
.651 .757 .928 r
.51406 .56251 m .50474 .56546 L .5073 .56818 L p F P
0 g
s
.651 .757 .928 r
.5073 .56818 m .51661 .56524 L .51406 .56251 L p F P
0 g
s
.387 .735 .991 r
.45261 .79633 m .44766 .79635 L .44498 .79467 L p F P
0 g
s
.816 .646 .672 r
.49732 .73188 m .49856 .72931 L .49727 .72574 L p F P
0 g
s
.806 .641 .678 r
.49722 .74415 m .5031 .74563 L .49981 .75112 L p F P
0 g
s
.775 .615 .68 r
.50008 .73879 m .49722 .74415 L .5031 .74563 L p F P
0 g
s
.335 .252 .612 r
.55929 .69303 m .56225 .6893 L p .56109 .69737 L F P
0 g
s
.335 .252 .612 r
.56109 .69737 m .55958 .69489 L .55929 .69303 L p F P
0 g
s
.227 .169 .581 r
.55929 .69303 m .56225 .6893 L .56055 .6853 L p F P
0 g
s
.902 .704 .626 r
.49449 .71275 m .49348 .71612 L .49092 .71126 L p F P
0 g
s
.902 .704 .626 r
.49092 .71126 m .49114 .71049 L .49449 .71275 L p F P
0 g
s
.903 .702 .621 r
.49449 .71275 m .49114 .71049 L .49247 .70561 L p F P
0 g
s
0 0 .329 r
.56028 .66989 m .55988 .67328 L .56096 .67744 L p F P
0 g
s
.475 .369 .654 r
.55689 .71853 m .55561 .7193 L .55665 .72481 L p F P
0 g
s
.23 .098 .485 r
.63243 .76369 m .63066 .76532 L .63082 .76993 L p F P
0 g
s
.64 .575 .766 r
.56118 .78004 m .56228 .78282 L .55253 .78503 L p F P
0 g
s
.64 .575 .766 r
.55253 .78503 m .5518 .78324 L .56118 .78004 L p F P
0 g
s
.65 .757 .928 r
.23546 .5622 m .22663 .56514 L .22964 .56786 L p F P
0 g
s
.65 .757 .928 r
.22964 .56786 m .23846 .56492 L .23546 .5622 L p F P
0 g
s
.651 .758 .928 r
.80867 .56787 m .81851 .56492 L .82056 .56763 L p F P
0 g
s
.651 .758 .928 r
.81851 .56492 m .80867 .56787 L .8066 .56516 L p F P
0 g
s
.65 .757 .928 r
.3807 .56227 m .37162 .56522 L .37439 .56794 L p F P
0 g
s
.65 .757 .928 r
.37439 .56794 m .38347 .565 L .3807 .56227 L p F P
0 g
s
.651 .758 .928 r
.66392 .56794 m .6735 .56499 L .67579 .56771 L p F P
0 g
s
.651 .758 .928 r
.6735 .56499 m .66392 .56794 L .66161 .56522 L p F P
0 g
s
.323 .339 .722 r
.6279 .7192 m .62919 .717 L p .6309 .72421 L F P
0 g
s
.323 .339 .722 r
.6309 .72421 m .62894 .72256 L .6279 .7192 L p F P
0 g
s
.319 .352 .739 r
.6279 .7192 m .62642 .71484 L .62919 .717 L closepath p F P
0 g
s
.651 .757 .928 r
.52596 .56229 m .51661 .56524 L .51915 .56795 L p F P
0 g
s
.651 .757 .928 r
.51915 .56795 m .52849 .56501 L .52596 .56229 L p F P
0 g
s
.432 .331 .64 r
.56109 .70375 m .55779 .70604 L .56157 .70948 L p F P
0 g
s
.431 .329 .638 r
.55779 .70604 m .56109 .70375 L .56016 .69836 L p F P
0 g
s
0 0 0 r
.61413 .7908 m .61369 .79128 L .60426 .79616 L p F P
0 g
s
.682 .952 .954 r
.60256 .79582 m .60426 .79616 L .61369 .79128 L p F P
0 g
s
.816 .646 .672 r
.49727 .72574 m .49487 .72486 L p .49732 .73188 L F P
0 g
s
.825 .649 .664 r
.49727 .72574 m .49603 .72226 L .49487 .72486 L closepath p F P
0 g
s
.322 .339 .723 r
.62992 .72569 m .62894 .72256 L .6309 .72421 L closepath p F P
0 g
s
.959 .758 .588 r
.41871 .752 m .41629 .7495 L .41521 .75435 L p F P
0 g
s
.959 .758 .588 r
.41521 .75435 m .41763 .75684 L .41871 .752 L p F P
0 g
s
.327 .326 .706 r
.62992 .72569 m .6309 .72421 L p .63197 .7316 L F P
0 g
s
.327 .326 .706 r
.63197 .7316 m .63149 .73117 L .62992 .72569 L p F P
0 g
s
.319 .352 .739 r
.62919 .717 m .62642 .71484 L .62561 .71243 L p F P
0 g
s
.634 .549 .741 r
.55975 .77584 m .56118 .78004 L .5518 .78324 L p F P
0 g
s
.634 .549 .741 r
.5518 .78324 m .54998 .77804 L .55975 .77584 L p F P
0 g
s
.775 .699 .779 r
.488 .79119 m .4832 .79508 L .48062 .79145 L p F P
0 g
s
.823 .653 .671 r
.4948 .73713 m .50008 .73879 L .49722 .74415 L p F P
0 g
s
.794 .628 .675 r
.49732 .73188 m .4948 .73713 L .50008 .73879 L p F P
0 g
s
.626 .511 .702 r
.54675 .76795 m .54596 .76507 L .55574 .76286 L p F P
0 g
s
.63 .515 .703 r
.5541 .75673 m .55574 .76286 L .54596 .76507 L p F P
0 g
s
.651 .758 .928 r
.82056 .56763 m .83043 .56468 L .83246 .56739 L p F P
0 g
s
.651 .758 .928 r
.83043 .56468 m .82056 .56763 L .81851 .56492 L p F P
0 g
s
.65 .757 .928 r
.24731 .56198 m .23846 .56492 L .24145 .56764 L p F P
0 g
s
.65 .757 .928 r
.24145 .56764 m .25029 .56471 L .24731 .56198 L p F P
0 g
s
.319 .352 .739 r
.62561 .71243 m .62689 .70994 L p .62919 .717 L F P
0 g
s
.315 .365 .755 r
.62561 .71243 m .62392 .7078 L .62689 .70994 L closepath p F P
0 g
s
.651 .758 .928 r
.67579 .56771 m .6854 .56476 L .68767 .56748 L p F P
0 g
s
.651 .758 .928 r
.6854 .56476 m .67579 .56771 L .6735 .56499 L p F P
0 g
s
.782 .65 .716 r
.4987 .76368 m .50503 .76503 L .50063 .77083 L p F P
0 g
s
.748 .602 .696 r
.50245 .75807 m .4987 .76368 L .50503 .76503 L p F P
0 g
s
.65 .757 .928 r
.39258 .56205 m .38347 .565 L .38623 .56771 L p F P
0 g
s
.65 .757 .928 r
.38623 .56771 m .39533 .56477 L .39258 .56205 L p F P
0 g
s
.843 .672 .67 r
.49487 .72486 m .49603 .72226 L .49445 .71849 L p F P
0 g
s
.651 .757 .928 r
.53785 .56206 m .52849 .56501 L .53101 .56773 L p F P
0 g
s
.651 .757 .928 r
.53101 .56773 m .54036 .56478 L .53785 .56206 L p F P
0 g
s
.993 .82 .566 r
.49094 .68611 m .48949 .68325 L .48822 .68809 L p F P
0 g
s
.993 .82 .566 r
.48822 .68809 m .48979 .69091 L .49094 .68611 L p F P
0 g
s
.874 .92 .854 r
.44965 .67294 m .44925 .66972 L .44378 .67579 L p F P
0 g
s
.874 .92 .854 r
.44528 .67778 m .44965 .67294 L p .44378 .67579 L F P
0 g
s
.91 .886 .797 r
.43215 .69923 m .43094 .69629 L .42695 .70193 L p F P
0 g
s
.91 .886 .797 r
.42913 .70353 m .43215 .69923 L p .42695 .70193 L F P
0 g
s
.649 .756 .928 r
.11391 .56152 m .1053 .56444 L .1085 .56717 L p F P
0 g
s
.649 .756 .928 r
.1085 .56717 m .11711 .56425 L .11391 .56152 L p F P
0 g
s
.768 .646 .727 r
.50186 .77843 m .50214 .77809 L .50167 .778 L closepath p F P
0 g
s
.768 .646 .728 r
.49931 .77258 m .50063 .77083 L p .50214 .77809 L F P
0 g
s
.768 .646 .728 r
.50214 .77809 m .50167 .778 L .49931 .77258 L p F P
0 g
s
.307 .241 .617 r
.56016 .69836 m .55958 .69489 L .56109 .69737 L closepath p F P
0 g
s
.747 .637 .738 r
.49567 .78447 m .50186 .77843 L .50167 .778 L p F P
0 g
s
.633 .533 .722 r
.54785 .77143 m .54675 .76795 L .55612 .7643 L p F P
0 g
s
.626 .511 .702 r
.55574 .76286 m .55612 .7643 L .54675 .76795 L p F P
0 g
s
.636 .553 .743 r
.55866 .77266 m .55975 .77584 L .54998 .77804 L p F P
0 g
s
.636 .553 .743 r
.54998 .77804 m .54928 .77607 L .55866 .77266 L p F P
0 g
s
.775 .699 .779 r
.48062 .79145 m .4826 .7896 L .488 .79119 L p F P
0 g
s
.744 .674 .782 r
.48996 .78307 m .4826 .7896 L .488 .79119 L p F P
0 g
s
.744 .674 .782 r
.488 .79119 m .49252 .78767 L .48996 .78307 L p F P
0 g
s
.651 .758 .928 r
.83246 .56739 m .84234 .56444 L .84436 .56715 L p F P
0 g
s
.651 .758 .928 r
.84234 .56444 m .83246 .56739 L .83043 .56468 L p F P
0 g
s
.325 .326 .706 r
.63172 .73194 m .63149 .73117 L .63197 .7316 L closepath p F P
0 g
s
.63 .529 .721 r
.54928 .77607 m .54785 .77143 L .55763 .76923 L p F P
0 g
s
.633 .533 .722 r
.55612 .7643 m .55763 .76923 L .54785 .77143 L p F P
0 g
s
.65 .757 .928 r
.25917 .56176 m .25029 .56471 L .25327 .56743 L p F P
0 g
s
.65 .757 .928 r
.25327 .56743 m .26213 .56449 L .25917 .56176 L p F P
0 g
s
.623 .758 .943 r
.58057 .79828 m .59002 .796 L .59244 .79848 L p F P
0 g
s
.623 .663 .868 r
.58859 .79399 m .59002 .796 L .58057 .79828 L p F P
0 g
s
.623 .663 .868 r
.58057 .79828 m .57993 .79729 L .58859 .79399 L p F P
0 g
s
.747 .637 .738 r
.50167 .778 m .49539 .77688 L p .49567 .78447 L F P
0 g
s
.761 .643 .732 r
.50167 .778 m .49931 .77258 L .49539 .77688 L closepath p F P
0 g
s
.651 .758 .928 r
.68767 .56748 m .6973 .56453 L .69955 .56725 L p F P
0 g
s
.651 .758 .928 r
.6973 .56453 m .68767 .56748 L .6854 .56476 L p F P
0 g
s
.294 .284 .678 r
.63197 .7316 m .63172 .73194 L .63324 .73792 L p F P
0 g
s
.65 .757 .928 r
.40446 .56182 m .39533 .56477 L .39806 .56749 L p F P
0 g
s
.65 .757 .928 r
.39806 .56749 m .40718 .56455 L .40446 .56182 L p F P
0 g
s
.651 .757 .928 r
.54975 .56183 m .54036 .56478 L .54286 .5675 L p F P
0 g
s
.651 .757 .928 r
.54286 .5675 m .55224 .56456 L .54975 .56183 L p F P
0 g
s
.93 .736 .619 r
.48962 .70319 m .49247 .70561 L .49114 .71049 L p F P
0 g
s
.93 .732 .612 r
.49247 .70561 m .48962 .70319 L .49086 .69834 L p F P
0 g
s
.63 .529 .721 r
.55763 .76923 m .55866 .77266 L .54928 .77607 L p F P
0 g
s
.842 .668 .667 r
.4926 .73004 m .49732 .73188 L .4948 .73713 L p F P
0 g
s
.816 .646 .672 r
.49487 .72486 m .4926 .73004 L .49732 .73188 L p F P
0 g
s
.649 .756 .928 r
.12575 .56132 m .11711 .56425 L .1203 .56698 L p F P
0 g
s
.649 .756 .928 r
.1203 .56698 m .12893 .56406 L .12575 .56132 L p F P
0 g
s
.784 .673 .742 r
.49567 .78447 m .49252 .78767 L .48996 .78307 L p F P
0 g
s
.784 .673 .742 r
.48996 .78307 m .49007 .78294 L .49567 .78447 L p F P
0 g
s
.747 .637 .738 r
.49539 .77688 m .49007 .78294 L .49567 .78447 L p F P
0 g
s
.315 .365 .755 r
.62689 .70994 m .62392 .7078 L .62303 .70536 L p F P
0 g
s
.574 .461 .686 r
.55124 .74489 m .55103 .74398 L .55469 .74366 L closepath p F P
0 g
s
.651 .758 .928 r
.84436 .56715 m .85426 .5642 L .85626 .56691 L p F P
0 g
s
.651 .758 .928 r
.85426 .5642 m .84436 .56715 L .84234 .56444 L p F P
0 g
s
.65 .757 .928 r
.27103 .56154 m .26213 .56449 L .26509 .56721 L p F P
0 g
s
.65 .757 .928 r
.26509 .56721 m .27398 .56427 L .27103 .56154 L p F P
0 g
s
.798 .656 .706 r
.49659 .75658 m .50245 .75807 L .4987 .76368 L p F P
0 g
s
.761 .607 .687 r
.49981 .75112 m .49659 .75658 L .50245 .75807 L p F P
0 g
s
.651 .758 .928 r
.69955 .56725 m .7092 .5643 L .71143 .56702 L p F P
0 g
s
.651 .758 .928 r
.7092 .5643 m .69955 .56725 L .6973 .56453 L p F P
0 g
s
.65 .757 .928 r
.41634 .56159 m .40718 .56455 L .4099 .56727 L p F P
0 g
s
.65 .757 .928 r
.4099 .56727 m .41905 .56432 L .41634 .56159 L p F P
0 g
s
.874 .92 .854 r
.44378 .67579 m .44391 .6774 L .44528 .67778 L p F P
0 g
s
.898 .907 .823 r
.44391 .6774 m .44528 .67778 L .44427 .67898 L closepath p F P
0 g
s
.651 .757 .928 r
.56165 .5616 m .55224 .56456 L .55473 .56727 L p F P
0 g
s
.651 .757 .928 r
.55473 .56727 m .56412 .56433 L .56165 .5616 L p F P
0 g
s
.95 .825 .686 r
.41984 .73173 m .41789 .72906 L .41563 .73422 L p F P
0 g
s
.95 .825 .686 r
.41563 .73422 m .41757 .73689 L .41984 .73173 L p F P
0 g
s
.574 .46 .686 r
.55264 .75077 m .55124 .74489 L .55469 .74366 L p F P
0 g
s
.153 0 .277 r
.62304 .78318 m .62305 .78317 L .62592 .77775 L p F P
0 g
s
.065 0 .178 r
.63061 .77417 m .62592 .77775 L .62305 .78317 L p F P
0 g
s
.235 .048 .411 r
.62592 .77775 m .63061 .77417 L .63082 .76993 L p F P
0 g
s
.475 .369 .654 r
.55665 .72481 m .56208 .7216 L .55689 .71853 L p F P
0 g
s
.471 .37 .659 r
.56311 .71471 m .55689 .71853 L .56208 .7216 L p F P
0 g
s
.486 .363 .637 r
.56218 .71002 m .56311 .71471 L .55689 .71853 L p F P
0 g
s
.486 .363 .637 r
.56157 .70948 m .56218 .71002 L p .55689 .71853 L F P
0 g
s
.941 .857 .73 r
.42232 .72017 m .42322 .71853 L .42163 .71573 L p F P
0 g
s
.315 .365 .755 r
.62303 .70536 m .62404 .70304 L p .62689 .70994 L F P
0 g
s
.31 .379 .772 r
.62303 .70536 m .62143 .70129 L .62404 .70304 L closepath p F P
0 g
s
.944 .809 .681 r
.41555 .74199 m .41638 .74299 L .41806 .7437 L p F P
0 g
s
.948 .797 .659 r
.41638 .74299 m .41806 .7437 L .41774 .74457 L closepath p F P
0 g
s
.986 .835 .451 r
.49181 .67247 m .49125 .6705 L .49037 .67522 L p F P
0 g
s
.986 .835 .451 r
.49037 .67522 m .49049 .67569 L .49181 .67247 L p F P
0 g
s
.649 .757 .928 r
.13759 .56113 m .12893 .56406 L .1321 .56679 L p F P
0 g
s
.649 .757 .928 r
.1321 .56679 m .14075 .56386 L .13759 .56113 L p F P
0 g
s
.843 .672 .67 r
.49445 .71849 m .49282 .71773 L p .49487 .72486 L F P
0 g
s
.849 .672 .662 r
.49445 .71849 m .49348 .71612 L .49282 .71773 L closepath p F P
0 g
s
.916 .537 .285 r
.43004 .78414 m .42691 .7819 L .42567 .77767 L p F P
0 g
s
.921 .539 .26 r
.42269 .77538 m .42567 .77767 L .42691 .7819 L p F P
0 g
s
.941 .624 .408 r
.42567 .77767 m .42269 .77538 L .42222 .77095 L p F P
0 g
s
.908 .922 .815 r
.44427 .67898 m .4396 .68481 L .4389 .6817 L p F P
0 g
s
.908 .922 .815 r
.44391 .6774 m .44427 .67898 L p .4389 .6817 L F P
0 g
s
.294 .284 .678 r
.63324 .73792 m .63517 .7353 L .63197 .7316 L p F P
0 g
s
.283 .285 .685 r
.63449 .72779 m .63197 .7316 L .63517 .7353 L p F P
0 g
s
.327 .326 .706 r
.6309 .72421 m .63449 .72779 L .63197 .7316 L p F P
0 g
s
0 0 0 r
.61369 .79128 m .61579 .78977 L .61413 .7908 L closepath p F P
0 g
s
.02 0 0 r
.62304 .78319 m .62304 .78318 L p .61413 .7908 L F P
0 g
s
.02 0 0 r
.61413 .7908 m .61579 .78977 L .62304 .78319 L p F P
0 g
s
.651 .758 .928 r
.85626 .56691 m .86618 .56395 L .86816 .56667 L p F P
0 g
s
.651 .758 .928 r
.86618 .56395 m .85626 .56691 L .85426 .5642 L p F P
0 g
s
.628 .863 .987 r
.60256 .79582 m .6019 .79559 L .59244 .79848 L p F P
0 g
s
.61 .804 .974 r
.6019 .79559 m .59244 .79848 L .59002 .796 L p F P
0 g
s
.65 .757 .928 r
.28289 .56132 m .27398 .56427 L .27691 .56699 L p F P
0 g
s
.65 .757 .928 r
.27691 .56699 m .28582 .56405 L .28289 .56132 L p F P
0 g
s
.651 .758 .928 r
.71143 .56702 m .7211 .56407 L .72331 .56679 L p F P
0 g
s
.651 .758 .928 r
.7211 .56407 m .71143 .56702 L .7092 .5643 L p F P
0 g
s
.65 .757 .928 r
.42822 .56137 m .41905 .56432 L .42175 .56704 L p F P
0 g
s
.65 .757 .928 r
.42175 .56704 m .43091 .5641 L .42822 .56137 L p F P
0 g
s
.651 .757 .928 r
.57355 .56137 m .56412 .56433 L .56659 .56705 L p F P
0 g
s
.651 .757 .928 r
.56659 .56705 m .57601 .5641 L .57355 .56137 L p F P
0 g
s
.626 .623 .828 r
.5662 .79209 m .57563 .78988 L .57811 .79451 L p F P
0 g
s
.619 .58 .789 r
.57459 .7876 m .57563 .78988 L .5662 .79209 L p F P
0 g
s
.619 .58 .789 r
.5662 .79209 m .56547 .79044 L .57459 .7876 L p F P
0 g
s
.863 .413 .094 r
.43004 .78414 m .43064 .78534 L .42793 .78386 L p F P
0 g
s
.863 .413 .094 r
.42793 .78386 m .42691 .7819 L .43004 .78414 L p F P
0 g
s
.618 .663 .872 r
.58757 .79256 m .58859 .79399 L .57993 .79729 L p F P
0 g
s
.618 .663 .872 r
.57993 .79729 m .57811 .79451 L .58757 .79256 L p F P
0 g
s
.95 .633 .393 r
.41942 .76859 m .42222 .77095 L .42269 .77538 L p F P
0 g
s
.952 .682 .49 r
.42222 .77095 m .41942 .76859 L .41957 .764 L p F P
0 g
s
.762 .761 .851 r
.47132 .79746 m .47168 .79722 L .47068 .79674 L closepath p F P
0 g
s
.691 .739 .888 r
.47068 .79674 m .47132 .79746 L p .45946 .79832 L F P
0 g
s
.862 .687 .664 r
.49071 .72286 m .49487 .72486 L .4926 .73004 L p F P
0 g
s
.843 .672 .67 r
.49282 .71773 m .49071 .72286 L .49487 .72486 L p F P
0 g
s
.65 .757 .928 r
.14943 .56093 m .14075 .56386 L .1439 .56659 L p F P
0 g
s
.65 .757 .928 r
.1439 .56659 m .15258 .56366 L .14943 .56093 L p F P
0 g
s
.763 .76 .85 r
.47814 .78789 m .48062 .79145 L .47168 .79722 L p F P
0 g
s
.763 .76 .85 r
.4779 .78783 m .47814 .78789 L p .47168 .79722 L F P
0 g
s
.763 .76 .85 r
.46871 .79452 m .4779 .78783 L p .47168 .79722 L F P
0 g
s
.763 .76 .85 r
.47168 .79722 m .47068 .79674 L .46871 .79452 L p F P
0 g
s
.962 .789 .622 r
.41774 .74457 m .41629 .7495 L .41406 .74694 L p F P
0 g
s
.962 .789 .622 r
.41638 .74299 m .41774 .74457 L p .41406 .74694 L F P
0 g
s
.651 .758 .928 r
.86816 .56667 m .87811 .5637 L .88007 .56642 L p F P
0 g
s
.651 .758 .928 r
.87811 .5637 m .86816 .56667 L .86618 .56395 L p F P
0 g
s
.91 .886 .797 r
.42695 .70193 m .42735 .70297 L .42913 .70353 L p F P
0 g
s
.922 .874 .772 r
.42735 .70297 m .42913 .70353 L .42824 .70484 L closepath p F P
0 g
s
.475 .369 .654 r
.55769 .73034 m .55665 .72481 L .56208 .7216 L p F P
0 g
s
.563 .424 .65 r
.55665 .72481 m .55769 .73034 L .55479 .73137 L p F P
0 g
s
.815 .665 .697 r
.49442 .74949 m .49981 .75112 L .49659 .75658 L p F P
0 g
s
.806 .641 .678 r
.49981 .75112 m .49442 .74949 L .49722 .74415 L p F P
0 g
s
.564 .431 .658 r
.55787 .73126 m .55479 .73137 L .55769 .73034 L closepath p F P
0 g
s
.691 .739 .888 r
.45946 .79832 m .4652 .79593 L .47068 .79674 L p F P
0 g
s
.719 .761 .886 r
.4652 .79593 m .45946 .79832 L .45682 .79601 L p F P
0 g
s
.782 .65 .716 r
.49931 .77258 m .50063 .77083 L .49833 .77028 L closepath p F P
0 g
s
.782 .65 .716 r
.49677 .76661 m .4987 .76368 L p .50063 .77083 L F P
0 g
s
.782 .65 .716 r
.50063 .77083 m .49833 .77028 L .49677 .76661 L p F P
0 g
s
.874 .704 .669 r
.49282 .71773 m .49348 .71612 L .49092 .71126 L p F P
0 g
s
0 0 .515 r
.56219 .68157 m .56055 .6853 L .56225 .6893 L p F P
0 g
s
.004 .012 .513 r
.56055 .6853 m .56219 .68157 L .56096 .67744 L p F P
0 g
s
.65 .757 .928 r
.29476 .5611 m .28582 .56405 L .28874 .56677 L p F P
0 g
s
.65 .757 .928 r
.28874 .56677 m .29767 .56383 L .29476 .5611 L p F P
0 g
s
.296 .268 .657 r
.63324 .73792 m .63517 .7353 L p .6351 .74301 L F P
0 g
s
.296 .268 .657 r
.6351 .74301 m .6341 .7417 L .63324 .73792 L p F P
0 g
s
.651 .758 .928 r
.72331 .56679 m .73301 .56384 L .7352 .56656 L p F P
0 g
s
.651 .758 .928 r
.73301 .56384 m .72331 .56679 L .7211 .56407 L p F P
0 g
s
.65 .757 .928 r
.44011 .56114 m .43091 .5641 L .43359 .56682 L p F P
0 g
s
.65 .757 .928 r
.43359 .56682 m .44278 .56387 L .44011 .56114 L p F P
0 g
s
.651 .757 .928 r
.58546 .56114 m .57601 .5641 L .57846 .56682 L p F P
0 g
s
.651 .757 .928 r
.57846 .56682 m .5879 .56387 L .58546 .56114 L p F P
0 g
s
.296 .221 .6 r
.63561 .74918 m .63377 .75105 L .63574 .75512 L p F P
0 g
s
.325 .264 .634 r
.63377 .75105 m .63561 .74918 L .63456 .74368 L p F P
0 g
s
.941 .857 .73 r
.42163 .71573 m .41956 .7194 L .42232 .72017 L p F P
0 g
s
.941 .851 .725 r
.42232 .72017 m .42039 .72384 L .41865 .72109 L p F P
0 g
s
.941 .851 .725 r
.41865 .72109 m .41956 .7194 L .42232 .72017 L p F P
0 g
s
.307 .243 .62 r
.56109 .69737 m .56016 .69836 L .56109 .70375 L p F P
0 g
s
.959 .77 .605 r
.49086 .69834 m .48857 .69575 L .48729 .70061 L p F P
0 g
s
.959 .77 .605 r
.48729 .70061 m .48962 .70319 L .49086 .69834 L p F P
0 g
s
.617 .583 .792 r
.57313 .78441 m .57459 .7876 L .56547 .79044 L p F P
0 g
s
.617 .583 .792 r
.56547 .79044 m .5637 .78649 L .57313 .78441 L p F P
0 g
s
.65 .757 .928 r
.16128 .56072 m .15258 .56366 L .15571 .56639 L p F P
0 g
s
.65 .757 .928 r
.15571 .56639 m .1644 .56346 L .16128 .56072 L p F P
0 g
s
.31 .379 .772 r
.62404 .70304 m .62143 .70129 L .62011 .69792 L p F P
0 g
s
.935 .882 .756 r
.42824 .70484 m .42487 .7103 L .42349 .70743 L p F P
0 g
s
.935 .882 .756 r
.42735 .70297 m .42824 .70484 L p .42349 .70743 L F P
0 g
s
.65 .757 .928 r
.30663 .56088 m .29767 .56383 L .30057 .56655 L p F P
0 g
s
.65 .757 .928 r
.30057 .56655 m .30952 .56361 L .30663 .56088 L p F P
0 g
s
.651 .758 .928 r
.7352 .56656 m .74492 .56361 L .7471 .56633 L p F P
0 g
s
.651 .758 .928 r
.74492 .56361 m .7352 .56656 L .73301 .56384 L p F P
0 g
s
.65 .757 .928 r
.452 .56092 m .44278 .56387 L .44544 .56659 L p F P
0 g
s
.65 .757 .928 r
.44544 .56659 m .45465 .56365 L .452 .56092 L p F P
0 g
s
.651 .757 .928 r
.59737 .56092 m .5879 .56387 L .59032 .56659 L p F P
0 g
s
.651 .757 .928 r
.59032 .56659 m .59979 .56365 L .59737 .56092 L p F P
0 g
s
.758 .639 .729 r
.49539 .77688 m .49931 .77258 L .49833 .77028 L p F P
0 g
s
.962 .694 .48 r
.41957 .764 m .41697 .76157 L .41681 .76617 L p F P
0 g
s
.962 .694 .48 r
.41681 .76617 m .41942 .76859 L .41957 .764 L p F P
0 g
s
.935 .873 .451 r
.4907 .67843 m .48949 .68325 L .48903 .68008 L p F P
0 g
s
.935 .873 .451 r
.49049 .67569 m .4907 .67843 L p .48903 .68008 L F P
0 g
s
.577 .462 .685 r
.55358 .75479 m .55264 .75077 L .56157 .74769 L p F P
0 g
s
.574 .46 .686 r
.56044 .74313 m .56157 .74769 L .55264 .75077 L p F P
0 g
s
.574 .46 .686 r
.55469 .74366 m .56044 .74313 L p .55264 .75077 L F P
0 g
s
.65 .757 .928 r
.17313 .56052 m .1644 .56346 L .16752 .56619 L p F P
0 g
s
.65 .757 .928 r
.16752 .56619 m .17624 .56326 L .17313 .56052 L p F P
0 g
s
.834 .667 .675 r
.49232 .74238 m .49722 .74415 L .49442 .74949 L p F P
0 g
s
.823 .653 .671 r
.49722 .74415 m .49232 .74238 L .4948 .73713 L p F P
0 g
s
.651 .758 .928 r
.7471 .56633 m .75684 .56338 L .75899 .5661 L p F P
0 g
s
.651 .758 .928 r
.75684 .56338 m .7471 .56633 L .74492 .56361 L p F P
0 g
s
.65 .757 .928 r
.31851 .56066 m .30952 .56361 L .3124 .56633 L p F P
0 g
s
.65 .757 .928 r
.3124 .56633 m .32138 .56339 L .31851 .56066 L p F P
0 g
s
.687 .743 .893 r
.47068 .79674 m .46871 .79452 L .4652 .79593 L closepath p F P
0 g
s
.651 .757 .928 r
.60929 .56069 m .59979 .56365 L .6022 .56637 L p F P
0 g
s
.651 .757 .928 r
.6022 .56637 m .61168 .56342 L .60929 .56069 L p F P
0 g
s
.65 .757 .928 r
.4639 .56069 m .45465 .56365 L .4573 .56637 L p F P
0 g
s
.65 .757 .928 r
.4573 .56637 m .46653 .56342 L .4639 .56069 L p F P
0 g
s
.885 .713 .664 r
.48922 .71555 m .49282 .71773 L .49071 .72286 L p F P
0 g
s
.874 .704 .669 r
.49092 .71126 m .48922 .71555 L .49282 .71773 L p F P
0 g
s
.895 .912 .828 r
.4396 .68481 m .4389 .6817 L .43419 .68755 L p F P
0 g
s
.895 .912 .828 r
.43587 .68946 m .4396 .68481 L p .43419 .68755 L F P
0 g
s
.31 .379 .772 r
.62011 .69792 m .62069 .69627 L p .62404 .70304 L F P
0 g
s
.305 .392 .788 r
.62011 .69792 m .61896 .69519 L .62069 .69627 L closepath p F P
0 g
s
.791 .686 .749 r
.48974 .77535 m .49539 .77688 L .49007 .78294 L p F P
0 g
s
.758 .639 .729 r
.49443 .76946 m .48974 .77535 L .49539 .77688 L p F P
0 g
s
.758 .639 .729 r
.49833 .77028 m .49443 .76946 L p .49539 .77688 L F P
0 g
s
.295 .268 .658 r
.63456 .74368 m .6341 .7417 L .6351 .74301 L closepath p F P
0 g
s
.302 .326 .72 r
.63312 .72046 m .6309 .72421 L .63449 .72779 L p F P
0 g
s
.323 .339 .722 r
.62919 .717 m .63312 .72046 L .6309 .72421 L p F P
0 g
s
.65 .757 .928 r
.18499 .56031 m .17624 .56326 L .17933 .56598 L p F P
0 g
s
.65 .757 .928 r
.17933 .56598 m .18807 .56305 L .18499 .56031 L p F P
0 g
s
.772 .645 .722 r
.49833 .77028 m .49677 .76661 L .49443 .76946 L closepath p F P
0 g
s
.23 .098 .485 r
.63082 .76993 m .63264 .76827 L .63243 .76369 L p F P
0 g
s
.218 .09 .483 r
.63693 .75942 m .63243 .76369 L .63264 .76827 L p F P
0 g
s
.273 .171 .552 r
.63243 .76369 m .63693 .75942 L .63574 .75512 L p F P
0 g
s
.798 .656 .706 r
.49677 .76661 m .4987 .76368 L .49507 .76262 L closepath p F P
0 g
s
.798 .656 .706 r
.49422 .76063 m .49659 .75658 L p .4987 .76368 L F P
0 g
s
.798 .656 .706 r
.4987 .76368 m .49507 .76262 L .49422 .76063 L p F P
0 g
s
.651 .758 .928 r
.75899 .5661 m .76875 .56314 L .77089 .56586 L p F P
0 g
s
.651 .758 .928 r
.76875 .56314 m .75899 .5661 L .75684 .56338 L p F P
0 g
s
.65 .757 .928 r
.33038 .56043 m .32138 .56339 L .32424 .56611 L p F P
0 g
s
.65 .757 .928 r
.32424 .56611 m .33324 .56317 L .33038 .56043 L p F P
0 g
s
0 .39 .808 r
.43673 .78996 m .44231 .79277 L .44018 .79114 L p F P
0 g
s
.727 .197 0 r
.43064 .78534 m .43323 .78783 L .43673 .78996 L p F P
0 g
s
0 .39 .808 r
.43323 .78783 m .43673 .78996 L p .44018 .79114 L F P
0 g
s
.651 .757 .928 r
.6212 .56046 m .61168 .56342 L .61407 .56614 L p F P
0 g
s
.651 .757 .928 r
.61407 .56614 m .62358 .56319 L .6212 .56046 L p F P
0 g
s
.65 .757 .928 r
.47579 .56046 m .46653 .56342 L .46915 .56614 L p F P
0 g
s
.65 .757 .928 r
.46915 .56614 m .47841 .56319 L .47579 .56046 L p F P
0 g
s
.649 .101 0 r
.43323 .78783 m .43064 .78534 L .42793 .78386 L p F P
0 g
s
0 0 0 r
.61579 .78977 m .61369 .79128 L .61137 .79193 L p F P
0 g
s
.682 .952 .954 r
.61369 .79128 m .61137 .79193 L p .60256 .79582 L F P
0 g
s
.65 .757 .928 r
.19685 .5601 m .18807 .56305 L .19115 .56577 L p F P
0 g
s
.65 .757 .928 r
.19115 .56577 m .19992 .56284 L .19685 .5601 L p F P
0 g
s
.851 .68 .669 r
.49036 .73521 m .4948 .73713 L .49232 .74238 L p F P
0 g
s
.842 .668 .667 r
.4948 .73713 m .49036 .73521 L .4926 .73004 L p F P
0 g
s
.584 .483 .705 r
.5541 .75673 m .55358 .75479 L .563 .75356 L p F P
0 g
s
.577 .462 .685 r
.56157 .74769 m .563 .75356 L .55358 .75479 L p F P
0 g
s
.651 .758 .928 r
.77089 .56586 m .78067 .56291 L .78279 .56563 L p F P
0 g
s
.651 .758 .928 r
.78067 .56291 m .77089 .56586 L .76875 .56314 L p F P
0 g
s
.65 .757 .928 r
.34227 .56021 m .33324 .56317 L .33608 .56589 L p F P
0 g
s
.65 .757 .928 r
.33608 .56589 m .3451 .56294 L .34227 .56021 L p F P
0 g
s
0 0 0 r
.61579 .78977 m .62145 .78609 L .62304 .78319 L closepath p F P
0 g
s
0 0 0 r
.62145 .78609 m .61579 .78977 L p .61137 .79193 L F P
0 g
s
.258 .218 .621 r
.6351 .74301 m .63456 .74368 L .63561 .74918 L p F P
0 g
s
.651 .758 .928 r
.63313 .56023 m .62358 .56319 L .62595 .56591 L p F P
0 g
s
.651 .758 .928 r
.62595 .56591 m .63548 .56296 L .63313 .56023 L p F P
0 g
s
.651 .757 .928 r
.4877 .56023 m .47841 .56319 L .48101 .56592 L p F P
0 g
s
.651 .757 .928 r
.48101 .56592 m .49029 .56297 L .4877 .56023 L p F P
0 g
s
.037 0 .109 r
.62304 .78319 m .62305 .78317 L .62304 .78318 L closepath p F P
0 g
s
.967 .738 .539 r
.41763 .75684 m .41521 .75435 L .41454 .75908 L p F P
0 g
s
.967 .738 .539 r
.41454 .75908 m .41697 .76157 L .41763 .75684 L p F P
0 g
s
0 0 0 r
.62305 .78317 m .62906 .77854 L p .62145 .78609 L F P
0 g
s
0 0 0 r
.62145 .78609 m .62304 .78319 L .62305 .78317 L p F P
0 g
s
.065 0 .178 r
.63015 .77679 m .63061 .77417 L p .62305 .78317 L F P
0 g
s
.065 0 .178 r
.62305 .78317 m .62906 .77854 L .63015 .77679 L p F P
0 g
s
.547 .76 .976 r
.45261 .79633 m .45682 .79601 L .45417 .79358 L p F P
0 g
s
.547 .76 .976 r
.45417 .79358 m .44865 .79434 L .45261 .79633 L p F P
0 g
s
.387 .735 .991 r
.44498 .79467 m .44865 .79434 L .45261 .79633 L p F P
0 g
s
.574 .45 .674 r
.56044 .74313 m .55469 .74366 L .56014 .74177 L closepath p F P
0 g
s
.572 .444 .667 r
.55891 .73604 m .56014 .74177 L .55469 .74366 L p F P
0 g
s
.61 .551 .764 r
.57134 .7799 m .57313 .78441 L .5637 .78649 L p F P
0 g
s
.61 .551 .764 r
.5637 .78649 m .56228 .78282 L .57134 .7799 L p F P
0 g
s
.153 0 .385 r
.63264 .76827 m .63082 .76993 L .63061 .77417 L p F P
0 g
s
.951 .843 .701 r
.42039 .72384 m .41865 .72109 L .41615 .72632 L p F P
0 g
s
.951 .843 .701 r
.41615 .72632 m .41789 .72906 L .42039 .72384 L p F P
0 g
s
.989 .817 .579 r
.48979 .69091 m .48822 .68809 L .4869 .69296 L p F P
0 g
s
.989 .817 .579 r
.4869 .69296 m .48857 .69575 L .48979 .69091 L p F P
0 g
s
.304 .393 .788 r
.62069 .69627 m .61896 .69519 L .61678 .69005 L p F P
0 g
s
.584 .481 .703 r
.55574 .76286 m .5541 .75673 L .56302 .75364 L p F P
0 g
s
.584 .483 .705 r
.563 .75356 m .56302 .75364 L .5541 .75673 L p F P
0 g
s
.65 .757 .928 r
.20871 .55989 m .19992 .56284 L .20297 .56556 L p F P
0 g
s
.65 .757 .928 r
.20297 .56556 m .21176 .56262 L .20871 .55989 L p F P
0 g
s
.787 .723 .792 r
.48062 .79145 m .4826 .7896 L .47814 .78789 L closepath p F P
0 g
s
.788 .723 .792 r
.48985 .78288 m .48996 .78307 L .4826 .7896 L p F P
0 g
s
.788 .723 .792 r
.48416 .78149 m .48985 .78288 L p .4826 .7896 L F P
0 g
s
.788 .723 .792 r
.47803 .78773 m .48416 .78149 L p .4826 .7896 L F P
0 g
s
.788 .723 .792 r
.4826 .7896 m .47814 .78789 L .47803 .78773 L p F P
0 g
s
.508 .393 .657 r
.55769 .73034 m .5654 .72598 L p .56362 .73344 L F P
0 g
s
.508 .393 .657 r
.56362 .73344 m .55787 .73126 L .55769 .73034 L p F P
0 g
s
.475 .369 .654 r
.56478 .72316 m .5654 .72598 L .55769 .73034 L p F P
0 g
s
.475 .369 .654 r
.56208 .7216 m .56478 .72316 L p .55769 .73034 L F P
0 g
s
.651 .758 .928 r
.78279 .56563 m .7926 .56267 L .79469 .56539 L p F P
0 g
s
.651 .758 .928 r
.7926 .56267 m .78279 .56563 L .78067 .56291 L p F P
0 g
s
.65 .757 .928 r
.35415 .55999 m .3451 .56294 L .34792 .56567 L p F P
0 g
s
.65 .757 .928 r
.34792 .56567 m .35696 .56272 L .35415 .55999 L p F P
0 g
s
.651 .758 .928 r
.63784 .56568 m .64739 .56273 L .64972 .56545 L p F P
0 g
s
.651 .758 .928 r
.64505 .56 m .63548 .56296 L .63784 .56568 L p F P
0 g
s
.651 .758 .928 r
.63784 .56568 m .64739 .56273 L .64505 .56 L p F P
0 g
s
.895 .912 .828 r
.43419 .68755 m .4345 .68911 L .43587 .68946 L p F P
0 g
s
.912 .899 .801 r
.4345 .68911 m .43587 .68946 L .43497 .69064 L closepath p F P
0 g
s
.958 .823 .667 r
.41757 .73689 m .41563 .73422 L .41363 .73932 L p F P
0 g
s
.958 .823 .667 r
.41363 .73932 m .41555 .74199 L .41757 .73689 L p F P
0 g
s
.651 .757 .928 r
.4996 .56001 m .49029 .56297 L .49288 .56569 L p F P
0 g
s
.651 .757 .928 r
.49288 .56569 m .50218 .56274 L .4996 .56001 L p F P
0 g
s
.307 .243 .62 r
.56109 .70375 m .56348 .7012 L .56109 .69737 L p F P
0 g
s
.165 .147 .591 r
.56402 .6933 m .56109 .69737 L .56348 .7012 L p F P
0 g
s
.335 .252 .612 r
.56225 .6893 m .56402 .6933 L .56109 .69737 L p F P
0 g
s
.791 .686 .749 r
.48996 .78307 m .49007 .78294 L .48985 .78288 L closepath p F P
0 g
s
.791 .686 .749 r
.48739 .77836 m .48974 .77535 L p .49007 .78294 L F P
0 g
s
.791 .686 .749 r
.49007 .78294 m .48985 .78288 L .48739 .77836 L p F P
0 g
s
.771 .645 .722 r
.49443 .76946 m .49677 .76661 L .49507 .76262 L p F P
0 g
s
.815 .666 .697 r
.49422 .76063 m .49659 .75658 L .49172 .75487 L closepath p F P
0 g
s
.815 .665 .697 r
.49167 .75477 m .49442 .74949 L p .49659 .75658 L F P
0 g
s
.815 .665 .697 r
.49659 .75658 m .49172 .75487 L .49167 .75477 L p F P
0 g
s
.928 .738 .625 r
.49092 .71126 m .49114 .71049 L .48866 .70837 L closepath p F P
0 g
s
.93 .736 .619 r
.48834 .70796 m .48962 .70319 L p .49114 .71049 L F P
0 g
s
.93 .736 .619 r
.49114 .71049 m .48866 .70837 L .48834 .70796 L p F P
0 g
s
.769 .679 .763 r
.48985 .78288 m .48739 .77836 L .48416 .78149 L closepath p F P
0 g
s
.301 .344 .74 r
.6311 .71331 m .62919 .717 L .63312 .72046 L p F P
0 g
s
.319 .352 .739 r
.62689 .70994 m .6311 .71331 L .62919 .717 L p F P
0 g
s
.5 .401 .675 r
.55891 .73604 m .55787 .73126 L .56362 .73344 L closepath p F P
0 g
s
.65 .757 .928 r
.22058 .55967 m .21176 .56262 L .2148 .56535 L p F P
0 g
s
.65 .757 .928 r
.2148 .56535 m .22361 .56241 L .22058 .55967 L p F P
0 g
s
.606 .629 .848 r
.58757 .79256 m .57811 .79451 L .57563 .78988 L p F P
0 g
s
.924 .911 .789 r
.43497 .69064 m .43094 .69629 L .42999 .69326 L p F P
0 g
s
.924 .911 .789 r
.4345 .68911 m .43497 .69064 L p .42999 .69326 L F P
0 g
s
.609 .554 .767 r
.57061 .7781 m .57134 .7799 L .56228 .78282 L p F P
0 g
s
.609 .554 .767 r
.56228 .78282 m .56118 .78004 L .57061 .7781 L p F P
0 g
s
.651 .758 .928 r
.79469 .56539 m .80452 .56243 L .8066 .56516 L p F P
0 g
s
.651 .758 .928 r
.80452 .56243 m .79469 .56539 L .7926 .56267 L p F P
0 g
s
0 0 .419 r
.56118 .67411 m .56096 .67744 L .56219 .68157 L p F P
0 g
s
0 0 .329 r
.56096 .67744 m .56118 .67411 L .56028 .66989 L p F P
0 g
s
.65 .757 .928 r
.36604 .55976 m .35696 .56272 L .35977 .56544 L p F P
0 g
s
.65 .757 .928 r
.35977 .56544 m .36883 .56249 L .36604 .55976 L p F P
0 g
s
.651 .758 .928 r
.64972 .56545 m .6593 .5625 L .66161 .56522 L p F P
0 g
s
.651 .758 .928 r
.6593 .5625 m .64972 .56545 L .64739 .56273 L p F P
0 g
s
.651 .757 .928 r
.51151 .55978 m .50218 .56274 L .50474 .56546 L p F P
0 g
s
.651 .757 .928 r
.50474 .56546 m .51406 .56251 L .51151 .55978 L p F P
0 g
s
.307 .244 .621 r
.56348 .7012 m .56109 .70375 L .56203 .70916 L p F P
0 g
s
.432 .331 .64 r
.56157 .70948 m .56203 .70916 L .56109 .70375 L p F P
0 g
s
.719 .761 .886 r
.45682 .79601 m .46059 .79413 L .4652 .79593 L p F P
0 g
s
.687 .738 .89 r
.46609 .79151 m .46059 .79413 L .4652 .79593 L p F P
0 g
s
.687 .738 .89 r
.4652 .79593 m .46871 .79452 L .46609 .79151 L p F P
0 g
s
.895 .93 .832 r
.44257 .67717 m .44378 .67579 L .44391 .6774 L closepath p F P
0 g
s
.908 .922 .815 r
.4389 .6817 m .44257 .67717 L .44391 .6774 L p F P
0 g
s
.939 .875 .747 r
.42487 .7103 m .42349 .70743 L .42026 .71286 L p F P
0 g
s
.939 .875 .747 r
.42026 .71286 m .42163 .71573 L .42487 .7103 L p F P
0 g
s
.87 .697 .665 r
.48863 .72798 m .4926 .73004 L .49036 .73521 L p F P
0 g
s
.862 .687 .664 r
.4926 .73004 m .48863 .72798 L .49071 .72286 L p F P
0 g
s
.908 .747 .67 r
.48922 .71555 m .49092 .71126 L .48866 .70837 L p F P
0 g
s
.619 .909 .983 r
.6019 .79559 m .6059 .79409 L .60256 .79582 L closepath p F P
0 g
s
.682 .952 .954 r
.61137 .79193 m .6059 .79409 L .60256 .79582 L p F P
0 g
s
.65 .757 .928 r
.23245 .55946 m .22361 .56241 L .22663 .56514 L p F P
0 g
s
.65 .757 .928 r
.22663 .56514 m .23546 .5622 L .23245 .55946 L p F P
0 g
s
.811 .684 .725 r
.48891 .76788 m .49443 .76946 L .48974 .77535 L p F P
0 g
s
.771 .645 .722 r
.4931 .76213 m .48891 .76788 L .49443 .76946 L p F P
0 g
s
.771 .645 .722 r
.49507 .76262 m .4931 .76213 L p .49443 .76946 L F P
0 g
s
.294 .434 .832 r
.60748 .67688 m .60786 .67353 L .60222 .67067 L p F P
0 g
s
.313 .471 .857 r
.60214 .66744 m .60222 .67067 L .60786 .67353 L p F P
0 g
s
.651 .758 .928 r
.8066 .56516 m .81645 .56219 L .81851 .56492 L p F P
0 g
s
.651 .758 .928 r
.81645 .56219 m .8066 .56516 L .80452 .56243 L p F P
0 g
s
.588 .483 .702 r
.55612 .7643 m .55574 .76286 L .56476 .75987 L p F P
0 g
s
.584 .481 .703 r
.56302 .75364 m .56476 .75987 L .55574 .76286 L p F P
0 g
s
.65 .757 .928 r
.37793 .55954 m .36883 .56249 L .37162 .56522 L p F P
0 g
s
.65 .757 .928 r
.37162 .56522 m .3807 .56227 L .37793 .55954 L p F P
0 g
s
.651 .758 .928 r
.66161 .56522 m .67121 .56227 L .6735 .56499 L p F P
0 g
s
.651 .758 .928 r
.67121 .56227 m .66161 .56522 L .6593 .5625 L p F P
0 g
s
.651 .757 .928 r
.52342 .55955 m .51406 .56251 L .51661 .56524 L p F P
0 g
s
.651 .757 .928 r
.51661 .56524 m .52596 .56229 L .52342 .55955 L p F P
0 g
s
.602 .526 .742 r
.56879 .77288 m .57061 .7781 L .56118 .78004 L p F P
0 g
s
.602 .526 .742 r
.56118 .78004 m .55975 .77584 L .56879 .77288 L p F P
0 g
s
.258 .218 .621 r
.63561 .74918 m .63736 .74699 L .6351 .74301 L p F P
0 g
s
.246 .217 .627 r
.63796 .73913 m .6351 .74301 L .63736 .74699 L p F P
0 g
s
.296 .268 .657 r
.63517 .7353 m .63796 .73913 L .6351 .74301 L p F P
0 g
s
.593 .504 .724 r
.55763 .76923 m .55612 .7643 L .56555 .76275 L p F P
0 g
s
.588 .483 .702 r
.56476 .75987 m .56555 .76275 L .55612 .7643 L p F P
0 g
s
.961 .795 .632 r
.41531 .74275 m .41555 .74199 L .41638 .74299 L closepath p F P
0 g
s
.962 .789 .622 r
.41406 .74694 m .41531 .74275 L .41638 .74299 L p F P
0 g
s
.492 .763 .991 r
.44865 .79434 m .44498 .79467 L .44231 .79277 L p F P
0 g
s
.856 .777 .274 r
.49125 .6705 m .49151 .6671 L .49043 .67188 L p F P
0 g
s
.856 .777 .274 r
.49043 .67188 m .49037 .67522 L .49125 .6705 L p F P
0 g
s
.969 .772 .583 r
.41629 .7495 m .41406 .74694 L .41297 .75179 L p F P
0 g
s
.969 .772 .583 r
.41297 .75179 m .41521 .75435 L .41629 .7495 L p F P
0 g
s
.651 .758 .928 r
.81851 .56492 m .82839 .56196 L .83043 .56468 L p F P
0 g
s
.651 .758 .928 r
.82839 .56196 m .81851 .56492 L .81645 .56219 L p F P
0 g
s
.65 .757 .928 r
.24432 .55924 m .23546 .5622 L .23846 .56492 L p F P
0 g
s
.65 .757 .928 r
.23846 .56492 m .24731 .56198 L .24432 .55924 L p F P
0 g
s
.834 .668 .676 r
.49442 .74949 m .49167 .75477 L .48911 .74916 L p F P
0 g
s
.834 .668 .676 r
.48911 .74916 m .48984 .74763 L .49442 .74949 L p F P
0 g
s
.834 .667 .675 r
.49442 .74949 m .48984 .74763 L .49232 .74238 L p F P
0 g
s
.601 .528 .745 r
.56809 .77091 m .56879 .77288 L .55975 .77584 L p F P
0 g
s
.601 .528 .745 r
.55975 .77584 m .55866 .77266 L .56809 .77091 L p F P
0 g
s
.594 .503 .721 r
.55866 .77266 m .55763 .76923 L .56665 .76626 L p F P
0 g
s
.593 .504 .724 r
.56555 .76275 m .56665 .76626 L .55763 .76923 L p F P
0 g
s
.3 .362 .759 r
.62848 .70633 m .62689 .70994 L .6311 .71331 L p F P
0 g
s
.315 .365 .755 r
.62404 .70304 m .62848 .70633 L .62689 .70994 L p F P
0 g
s
.651 .758 .928 r
.6735 .56499 m .68312 .56204 L .6854 .56476 L p F P
0 g
s
.651 .758 .928 r
.68312 .56204 m .6735 .56499 L .67121 .56227 L p F P
0 g
s
.65 .757 .928 r
.38982 .55931 m .3807 .56227 L .38347 .565 L p F P
0 g
s
.65 .757 .928 r
.38347 .565 m .39258 .56205 L .38982 .55931 L p F P
0 g
s
.651 .757 .928 r
.53533 .55932 m .52596 .56229 L .52849 .56501 L p F P
0 g
s
.651 .757 .928 r
.52849 .56501 m .53785 .56206 L .53533 .55932 L p F P
0 g
s
.783 .65 .715 r
.49507 .76262 m .49422 .76063 L .4931 .76213 L closepath p F P
0 g
s
.649 .756 .928 r
.1107 .55877 m .10208 .56171 L .1053 .56444 L p F P
0 g
s
.649 .756 .928 r
.1053 .56444 m .11391 .56152 L .1107 .55877 L p F P
0 g
s
.594 .503 .721 r
.56665 .76626 m .56809 .77091 L .55866 .77266 L p F P
0 g
s
.341 .457 .833 r
.61156 .67899 m .60748 .67688 L p .61243 .68319 L F P
0 g
s
.283 .423 .827 r
.60748 .67688 m .61156 .67899 L .60911 .6742 L p F P
0 g
s
.283 .423 .827 r
.60911 .6742 m .60786 .67353 L .60748 .67688 L p F P
0 g
s
.304 .393 .788 r
.61678 .69005 m .61689 .68963 L p .62069 .69627 L F P
0 g
s
.3 .406 .804 r
.61678 .69005 m .61648 .6894 L .61689 .68963 L closepath p F P
0 g
s
.956 .77 .613 r
.48962 .70319 m .48729 .70061 L .48596 .70551 L p F P
0 g
s
.956 .77 .613 r
.48834 .70796 m .48962 .70319 L p .48596 .70551 L F P
0 g
s
.651 .758 .928 r
.83043 .56468 m .84032 .56171 L .84234 .56444 L p F P
0 g
s
.651 .758 .928 r
.84032 .56171 m .83043 .56468 L .82839 .56196 L p F P
0 g
s
.65 .757 .928 r
.2562 .55902 m .24731 .56198 L .25029 .56471 L p F P
0 g
s
.65 .757 .928 r
.25029 .56471 m .25917 .56176 L .2562 .55902 L p F P
0 g
s
.651 .758 .928 r
.6854 .56476 m .69504 .56181 L .6973 .56453 L p F P
0 g
s
.651 .758 .928 r
.69504 .56181 m .6854 .56476 L .68312 .56204 L p F P
0 g
s
.65 .757 .928 r
.40172 .55908 m .39258 .56205 L .39533 .56477 L p F P
0 g
s
.65 .757 .928 r
.39533 .56477 m .40446 .56182 L .40172 .55908 L p F P
0 g
s
.651 .757 .928 r
.54725 .55909 m .53785 .56206 L .54036 .56478 L p F P
0 g
s
.651 .757 .928 r
.54036 .56478 m .54975 .56183 L .54725 .55909 L p F P
0 g
s
.499 .4 .674 r
.56014 .74177 m .55891 .73604 L .56362 .73344 L p F P
0 g
s
.89 .719 .663 r
.48723 .72064 m .49071 .72286 L .48863 .72798 L p F P
0 g
s
.885 .713 .664 r
.49071 .72286 m .48723 .72064 L .48922 .71555 L p F P
0 g
s
.292 .407 .807 r
.61689 .68963 m .61648 .6894 L .61402 .68407 L p F P
0 g
s
.649 .756 .928 r
.12256 .55858 m .11391 .56152 L .11711 .56425 L p F P
0 g
s
.649 .756 .928 r
.11711 .56425 m .12575 .56132 L .12256 .55858 L p F P
0 g
s
.219 .167 .582 r
.63736 .74699 m .63561 .74918 L .63642 .75443 L p F P
0 g
s
.296 .221 .6 r
.63574 .75512 m .63642 .75443 L .63561 .74918 L p F P
0 g
s
.786 .654 .717 r
.4931 .76213 m .49422 .76063 L .49172 .75487 L p F P
0 g
s
.299 .38 .778 r
.6253 .6995 m .62404 .70304 L .62848 .70633 L p F P
0 g
s
.31 .379 .772 r
.62069 .69627 m .6253 .6995 L .62404 .70304 L p F P
0 g
s
.987 .866 .505 r
.48949 .68325 m .48903 .68008 L .48753 .685 L p F P
0 g
s
.987 .866 .505 r
.48753 .685 m .48822 .68809 L .48949 .68325 L p F P
0 g
s
.651 .758 .928 r
.84234 .56444 m .85226 .56147 L .85426 .5642 L p F P
0 g
s
.651 .758 .928 r
.85226 .56147 m .84234 .56444 L .84032 .56171 L p F P
0 g
s
.93 .889 .768 r
.42639 .70278 m .42695 .70193 L .42735 .70297 L closepath p F P
0 g
s
.935 .882 .756 r
.42349 .70743 m .42639 .70278 L .42735 .70297 L p F P
0 g
s
.65 .757 .928 r
.26808 .5588 m .25917 .56176 L .26213 .56449 L p F P
0 g
s
.65 .757 .928 r
.26213 .56449 m .27103 .56154 L .26808 .5588 L p F P
0 g
s
.304 .417 .812 r
.61402 .68407 m .61243 .68319 L .61282 .6815 L closepath p F P
0 g
s
.341 .457 .833 r
.61243 .68319 m .61282 .6815 L .61156 .67899 L p F P
0 g
s
.651 .758 .928 r
.6973 .56453 m .70696 .56158 L .7092 .5643 L p F P
0 g
s
.651 .758 .928 r
.70696 .56158 m .6973 .56453 L .69504 .56181 L p F P
0 g
s
.65 .757 .928 r
.41362 .55886 m .40446 .56182 L .40718 .56455 L p F P
0 g
s
.65 .757 .928 r
.40718 .56455 m .41634 .56159 L .41362 .55886 L p F P
0 g
s
.651 .757 .928 r
.55917 .55887 m .54975 .56183 L .55224 .56456 L p F P
0 g
s
.651 .757 .928 r
.55224 .56456 m .56165 .5616 L .55917 .55887 L p F P
0 g
s
.767 .711 .8 r
.4779 .78783 m .46871 .79452 L .46609 .79151 L p F P
0 g
s
.921 .539 .26 r
.42691 .7819 m .42394 .7796 L .42269 .77538 L p F P
0 g
s
.925 .54 .234 r
.41989 .77302 m .42269 .77538 L .42394 .7796 L p F P
0 g
s
.95 .633 .393 r
.42269 .77538 m .41989 .77302 L .41942 .76859 L p F P
0 g
s
.435 .336 .644 r
.56218 .71002 m .56157 .70948 L .56203 .70916 L closepath p F P
0 g
s
.925 .905 .784 r
.43094 .69629 m .42999 .69326 L .42604 .6989 L p F P
0 g
s
.925 .905 .784 r
.42604 .6989 m .42695 .70193 L .43094 .69629 L p F P
0 g
s
.811 .684 .724 r
.48974 .77535 m .48739 .77836 L .48482 .77368 L p F P
0 g
s
.811 .684 .724 r
.48482 .77368 m .48488 .7736 L .48974 .77535 L p F P
0 g
s
.811 .684 .725 r
.48974 .77535 m .48488 .7736 L .48891 .76788 L p F P
0 g
s
.296 .398 .797 r
.62161 .69282 m .62069 .69627 L .6253 .6995 L p F P
0 g
s
.304 .393 .788 r
.61689 .68963 m .62161 .69282 L .62069 .69627 L p F P
0 g
s
.649 .757 .928 r
.13442 .55838 m .12575 .56132 L .12893 .56406 L p F P
0 g
s
.649 .757 .928 r
.12893 .56406 m .13759 .56113 L .13442 .55838 L p F P
0 g
s
.61 .804 .974 r
.59002 .796 m .5995 .79366 L .6019 .79559 L p F P
0 g
s
.61 .68 .891 r
.59707 .79075 m .5995 .79366 L .59002 .796 L p F P
0 g
s
.61 .68 .891 r
.59327 .79148 m .59707 .79075 L p .59002 .796 L F P
0 g
s
.61 .68 .891 r
.59002 .796 m .58859 .79399 L .59327 .79148 L p F P
0 g
s
.854 .693 .682 r
.48812 .7404 m .49232 .74238 L .48984 .74763 L p F P
0 g
s
.851 .68 .669 r
.49232 .74238 m .48812 .7404 L .49036 .73521 L p F P
0 g
s
.817 .683 .715 r
.48782 .76048 m .4931 .76213 L .48891 .76788 L p F P
0 g
s
.786 .654 .717 r
.49162 .75484 m .48782 .76048 L .4931 .76213 L p F P
0 g
s
.786 .654 .717 r
.49172 .75487 m .49162 .75484 L p .4931 .76213 L F P
0 g
s
.693 .441 0 r
.55981 .66791 m .56028 .66989 L .56118 .67411 L p F P
0 g
s
.854 .397 .045 r
.42691 .7819 m .42793 .78386 L .42521 .78199 L p F P
0 g
s
.854 .397 .045 r
.42521 .78199 m .42394 .7796 L .42691 .7819 L p F P
0 g
s
.255 .378 .796 r
.61748 .68626 m .61689 .68963 L .62161 .69282 L p F P
0 g
s
.292 .407 .807 r
.61402 .68407 m .61748 .68626 L .61689 .68963 L p F P
0 g
s
.651 .758 .928 r
.85426 .5642 m .8642 .56123 L .86618 .56395 L p F P
0 g
s
.651 .758 .928 r
.8642 .56123 m .85426 .5642 L .85226 .56147 L p F P
0 g
s
.65 .757 .928 r
.27996 .55858 m .27103 .56154 L .27398 .56427 L p F P
0 g
s
.65 .757 .928 r
.27398 .56427 m .28289 .56132 L .27996 .55858 L p F P
0 g
s
.59 .871 .994 r
.6059 .79409 m .6019 .79559 L .5995 .79366 L p F P
0 g
s
.651 .758 .928 r
.7092 .5643 m .71888 .56135 L .7211 .56407 L p F P
0 g
s
.651 .758 .928 r
.71888 .56135 m .7092 .5643 L .70696 .56158 L p F P
0 g
s
.65 .757 .928 r
.42552 .55863 m .41634 .56159 L .41905 .56432 L p F P
0 g
s
.65 .757 .928 r
.41905 .56432 m .42822 .56137 L .42552 .55863 L p F P
0 g
s
.651 .757 .928 r
.57109 .55864 m .56165 .5616 L .56412 .56433 L p F P
0 g
s
.651 .757 .928 r
.56412 .56433 m .57355 .56137 L .57109 .55864 L p F P
0 g
s
.959 .841 .683 r
.41789 .72906 m .41615 .72632 L .4139 .73148 L p F P
0 g
s
.959 .841 .683 r
.4139 .73148 m .41563 .73422 L .41789 .72906 L p F P
0 g
s
.959 .641 .376 r
.41942 .76859 m .41681 .76617 L .41727 .7706 L p F P
0 g
s
.959 .641 .376 r
.41727 .7706 m .41989 .77302 L .41942 .76859 L p F P
0 g
s
.892 .944 .838 r
.44925 .66972 m .44918 .66639 L .44381 .67244 L p F P
0 g
s
.892 .944 .838 r
.44381 .67244 m .44378 .67579 L .44925 .66972 L p F P
0 g
s
.65 .757 .928 r
.14628 .55818 m .13759 .56113 L .14075 .56386 L p F P
0 g
s
.65 .757 .928 r
.14075 .56386 m .14943 .56093 L .14628 .55818 L p F P
0 g
s
.651 .758 .928 r
.86618 .56395 m .87615 .56098 L .87811 .5637 L p F P
0 g
s
.651 .758 .928 r
.87615 .56098 m .86618 .56395 L .8642 .56123 L p F P
0 g
s
.388 .303 .638 r
.56203 .70916 m .56589 .70504 L p .56486 .71308 L F P
0 g
s
.388 .303 .638 r
.56486 .71308 m .56218 .71002 L .56203 .70916 L p F P
0 g
s
.307 .244 .621 r
.56203 .70916 m .56589 .70504 L .56348 .7012 L p F P
0 g
s
.938 .878 .75 r
.42163 .71573 m .42026 .71286 L .41718 .71826 L p F P
0 g
s
.938 .878 .75 r
.41956 .7194 m .42163 .71573 L p .41718 .71826 L F P
0 g
s
.741 .773 .879 r
.46059 .79413 m .45682 .79601 L .45417 .79358 L p F P
0 g
s
.65 .757 .928 r
.29185 .55836 m .28289 .56132 L .28582 .56405 L p F P
0 g
s
.65 .757 .928 r
.28582 .56405 m .29476 .5611 L .29185 .55836 L p F P
0 g
s
.651 .758 .928 r
.7211 .56407 m .73081 .56111 L .73301 .56384 L p F P
0 g
s
.651 .758 .928 r
.73081 .56111 m .7211 .56407 L .71888 .56135 L p F P
0 g
s
.65 .757 .928 r
.43743 .5584 m .42822 .56137 L .43091 .5641 L p F P
0 g
s
.65 .757 .928 r
.43091 .5641 m .44011 .56114 L .43743 .5584 L p F P
0 g
s
.651 .757 .928 r
.58302 .55841 m .57355 .56137 L .57601 .5641 L p F P
0 g
s
.651 .757 .928 r
.57601 .5641 m .58546 .56114 L .58302 .55841 L p F P
0 g
s
.77 .681 .764 r
.48416 .78149 m .48739 .77836 L .48482 .77368 L p F P
0 g
s
.012 .067 .573 r
.56353 .68568 m .56225 .6893 L .56402 .6933 L p F P
0 g
s
0 0 .515 r
.56225 .6893 m .56353 .68568 L .56219 .68157 L p F P
0 g
s
.971 .812 .627 r
.41531 .74275 m .41555 .74199 L .41363 .73932 L p F P
0 g
s
.65 .757 .928 r
.15815 .55798 m .14943 .56093 L .15258 .56366 L p F P
0 g
s
.65 .757 .928 r
.15258 .56366 m .16128 .56072 L .15815 .55798 L p F P
0 g
s
.795 .696 .756 r
.48416 .78149 m .47803 .78773 L .47544 .78397 L p F P
0 g
s
.795 .696 .756 r
.47544 .78397 m .47914 .77979 L .48416 .78149 L p F P
0 g
s
.77 .681 .764 r
.48482 .77368 m .47914 .77979 L .48416 .78149 L p F P
0 g
s
.256 .161 .551 r
.63642 .75443 m .63574 .75512 L .63693 .75942 L p F P
0 g
s
.365 .298 .648 r
.56311 .71471 m .56218 .71002 L .56486 .71308 L closepath p F P
0 g
s
.914 .75 .665 r
.4863 .71316 m .48922 .71555 L .48723 .72064 L p F P
0 g
s
.908 .747 .67 r
.4883 .70808 m .4863 .71316 L .48922 .71555 L p F P
0 g
s
.908 .747 .67 r
.48866 .70837 m .4883 .70808 L p .48922 .71555 L F P
0 g
s
.153 0 .385 r
.63061 .77417 m .63171 .77316 L .63264 .76827 L p F P
0 g
s
.122 0 .365 r
.63712 .76403 m .63264 .76827 L .63171 .77316 L p F P
0 g
s
.218 .09 .483 r
.637 .76077 m .63693 .75942 L p .63264 .76827 L F P
0 g
s
.218 .09 .483 r
.63264 .76827 m .63712 .76403 L .637 .76077 L p F P
0 g
s
.266 .259 .665 r
.63777 .73147 m .63517 .7353 L .63796 .73913 L p F P
0 g
s
.283 .285 .685 r
.63517 .7353 m .63777 .73147 L .63449 .72779 L p F P
0 g
s
.985 .813 .59 r
.48857 .69575 m .4869 .69296 L .48554 .69786 L p F P
0 g
s
.985 .813 .59 r
.48554 .69786 m .48729 .70061 L .48857 .69575 L p F P
0 g
s
.606 .629 .848 r
.57563 .78988 m .5851 .78826 L .58757 .79256 L p F P
0 g
s
.594 .573 .799 r
.58305 .78407 m .5851 .78826 L .57563 .78988 L p F P
0 g
s
.594 .573 .799 r
.57563 .78988 m .57459 .7876 L .58305 .78407 L p F P
0 g
s
.65 .757 .928 r
.30374 .55814 m .29476 .5611 L .29767 .56383 L p F P
0 g
s
.65 .757 .928 r
.29767 .56383 m .30663 .56088 L .30374 .55814 L p F P
0 g
s
.651 .758 .928 r
.73301 .56384 m .74274 .56088 L .74492 .56361 L p F P
0 g
s
.651 .758 .928 r
.74274 .56088 m .73301 .56384 L .73081 .56111 L p F P
0 g
s
.65 .757 .928 r
.44934 .55818 m .44011 .56114 L .44278 .56387 L p F P
0 g
s
.65 .757 .928 r
.44278 .56387 m .452 .56092 L .44934 .55818 L p F P
0 g
s
.651 .757 .928 r
.59495 .55818 m .58546 .56114 L .5879 .56387 L p F P
0 g
s
.651 .757 .928 r
.5879 .56387 m .59737 .56092 L .59495 .55818 L p F P
0 g
s
.916 .919 .803 r
.43313 .68892 m .43419 .68755 L .4345 .68911 L closepath p F P
0 g
s
.924 .911 .789 r
.42999 .69326 m .43313 .68892 L .4345 .68911 L p F P
0 g
s
.876 .706 .667 r
.48656 .73311 m .49036 .73521 L .48812 .7404 L p F P
0 g
s
.87 .697 .665 r
.49036 .73521 m .48656 .73311 L .48863 .72798 L p F P
0 g
s
.972 .706 .468 r
.41697 .76157 m .41454 .75908 L .41438 .76368 L p F P
0 g
s
.972 .706 .468 r
.41438 .76368 m .41681 .76617 L .41697 .76157 L p F P
0 g
s
.525 .418 .675 r
.56014 .74177 m .56804 .73761 L p .56731 .74471 L F P
0 g
s
.525 .418 .675 r
.56731 .74471 m .56044 .74313 L .56014 .74177 L p F P
0 g
s
.499 .4 .674 r
.56736 .73485 m .56804 .73761 L .56014 .74177 L p F P
0 g
s
.499 .4 .674 r
.56362 .73344 m .56736 .73485 L p .56014 .74177 L F P
0 g
s
.747 .713 .82 r
.47814 .78789 m .47803 .78773 L .4779 .78783 L closepath p F P
0 g
s
.971 .812 .627 r
.41363 .73932 m .41251 .74272 L .41531 .74275 L p F P
0 g
s
.97 .805 .623 r
.41531 .74275 m .41406 .74694 L .41202 .74431 L p F P
0 g
s
.97 .805 .623 r
.41202 .74431 m .41251 .74272 L .41531 .74275 L p F P
0 g
s
.65 .757 .928 r
.17002 .55777 m .16128 .56072 L .1644 .56346 L p F P
0 g
s
.65 .757 .928 r
.1644 .56346 m .17313 .56052 L .17002 .55777 L p F P
0 g
s
.896 .946 .832 r
.44257 .67717 m .44378 .67579 L .44381 .67244 L p F P
0 g
s
.797 .658 .71 r
.49172 .75487 m .49167 .75477 L .49162 .75484 L closepath p F P
0 g
s
0 .39 .808 r
.44018 .79114 m .43952 .79068 L .43323 .78783 L p F P
0 g
s
.649 .101 0 r
.42793 .78386 m .42994 .78563 L .43323 .78783 L p F P
0 g
s
0 .43 .846 r
.42994 .78563 m .43323 .78783 L .43952 .79068 L p F P
0 g
s
.767 .711 .8 r
.46609 .79151 m .47253 .78622 L .4779 .78783 L p F P
0 g
s
.746 .711 .818 r
.47544 .78397 m .47253 .78622 L .4779 .78783 L p F P
0 g
s
.746 .711 .818 r
.4779 .78783 m .47803 .78773 L .47544 .78397 L p F P
0 g
s
.802 .666 .713 r
.49162 .75484 m .49167 .75477 L .48911 .74916 L p F P
0 g
s
.651 .758 .928 r
.74492 .56361 m .75468 .56065 L .75684 .56338 L p F P
0 g
s
.651 .758 .928 r
.75468 .56065 m .74492 .56361 L .74274 .56088 L p F P
0 g
s
.65 .757 .928 r
.31563 .55792 m .30663 .56088 L .30952 .56361 L p F P
0 g
s
.65 .757 .928 r
.30952 .56361 m .31851 .56066 L .31563 .55792 L p F P
0 g
s
.827 .687 .709 r
.48665 .7531 m .49162 .75484 L .48782 .76048 L p F P
0 g
s
.802 .666 .713 r
.48911 .74916 m .48665 .7531 L .49162 .75484 L p F P
0 g
s
.651 .757 .928 r
.60688 .55795 m .59737 .56092 L .59979 .56365 L p F P
0 g
s
.651 .757 .928 r
.59979 .56365 m .60929 .56069 L .60688 .55795 L p F P
0 g
s
.65 .757 .928 r
.46125 .55795 m .452 .56092 L .45465 .56365 L p F P
0 g
s
.65 .757 .928 r
.45465 .56365 m .4639 .56069 L .46125 .55795 L p F P
0 g
s
.989 .845 .476 r
.49009 .67652 m .49037 .67522 L .49049 .67569 L closepath p F P
0 g
s
.935 .873 .451 r
.48903 .68008 m .49009 .67652 L .49049 .67569 L p F P
0 g
s
.581 .769 .969 r
.44865 .79434 m .45417 .79358 L .45152 .7911 L p F P
0 g
s
.581 .769 .969 r
.45152 .7911 m .44429 .79246 L .44865 .79434 L p F P
0 g
s
.492 .763 .991 r
.44231 .79277 m .44429 .79246 L .44865 .79434 L p F P
0 g
s
.896 .946 .832 r
.44381 .67244 m .43984 .67687 L .44257 .67717 L p F P
0 g
s
.904 .936 .823 r
.44257 .67717 m .4389 .6817 L .43849 .67848 L p F P
0 g
s
.904 .936 .823 r
.43849 .67848 m .43984 .67687 L .44257 .67717 L p F P
0 g
s
.52 .43 .694 r
.56157 .74769 m .56044 .74313 L .56731 .74471 L closepath p F P
0 g
s
.65 .757 .928 r
.18189 .55757 m .17313 .56052 L .17624 .56326 L p F P
0 g
s
.65 .757 .928 r
.17624 .56326 m .18499 .56031 L .18189 .55757 L p F P
0 g
s
.821 .699 .73 r
.48417 .76609 m .48891 .76788 L .48488 .7736 L p F P
0 g
s
.817 .683 .715 r
.48891 .76788 m .48417 .76609 L .48782 .76048 L p F P
0 g
s
.936 .906 .768 r
.42639 .70278 m .42695 .70193 L .42604 .6989 L p F P
0 g
s
.651 .758 .928 r
.75684 .56338 m .76661 .56041 L .76875 .56314 L p F P
0 g
s
.651 .758 .928 r
.76661 .56041 m .75684 .56338 L .75468 .56065 L p F P
0 g
s
.65 .757 .928 r
.32753 .55769 m .31851 .56066 L .32138 .56339 L p F P
0 g
s
.65 .757 .928 r
.32138 .56339 m .33038 .56043 L .32753 .55769 L p F P
0 g
s
.593 .575 .803 r
.58261 .78318 m .58305 .78407 L .57459 .7876 L p F P
0 g
s
.593 .575 .803 r
.57459 .7876 m .57313 .78441 L .58261 .78318 L p F P
0 g
s
.651 .757 .928 r
.61882 .55772 m .60929 .56069 L .61168 .56342 L p F P
0 g
s
.651 .757 .928 r
.61168 .56342 m .6212 .56046 L .61882 .55772 L p F P
0 g
s
.257 .388 .805 r
.61748 .68626 m .61402 .68407 L .61282 .6815 L p F P
0 g
s
.65 .757 .928 r
.47317 .55772 m .4639 .56069 L .46653 .56342 L p F P
0 g
s
.65 .757 .928 r
.46653 .56342 m .47579 .56046 L .47317 .55772 L p F P
0 g
s
.741 .773 .879 r
.45417 .79358 m .45678 .7921 L .46059 .79413 L p F P
0 g
s
.709 .744 .878 r
.46347 .78848 m .45678 .7921 L .46059 .79413 L p F P
0 g
s
.709 .744 .878 r
.46059 .79413 m .46609 .79151 L .46347 .78848 L p F P
0 g
s
.472 .372 .661 r
.56478 .72316 m .56208 .7216 L .56421 .7203 L closepath p F P
0 g
s
.471 .37 .659 r
.56208 .7216 m .56421 .7203 L .56311 .71471 L p F P
0 g
s
.59 .871 .994 r
.61025 .7915 m .6059 .79409 L p .5995 .79366 L F P
0 g
s
.641 .91 .982 r
.6059 .79409 m .61025 .7915 L .61137 .79193 L closepath p F P
0 g
s
.909 .745 .666 r
.48866 .70837 m .48834 .70796 L .4883 .70808 L closepath p F P
0 g
s
.936 .906 .768 r
.42604 .6989 m .42362 .70248 L .42639 .70278 L p F P
0 g
s
.937 .898 .763 r
.42639 .70278 m .42349 .70743 L .42233 .70447 L p F P
0 g
s
.937 .898 .763 r
.42233 .70447 m .42362 .70248 L .42639 .70278 L p F P
0 g
s
.65 .757 .928 r
.19377 .55735 m .18499 .56031 L .18807 .56305 L p F P
0 g
s
.65 .757 .928 r
.18807 .56305 m .19685 .5601 L .19377 .55735 L p F P
0 g
s
.938 .878 .75 r
.41718 .71826 m .41754 .71904 L .41956 .7194 L p F P
0 g
s
.946 .863 .725 r
.41754 .71904 m .41956 .7194 L .41865 .72109 L closepath p F P
0 g
s
.651 .758 .928 r
.76875 .56314 m .77855 .56018 L .78067 .56291 L p F P
0 g
s
.651 .758 .928 r
.77855 .56018 m .76875 .56314 L .76661 .56041 L p F P
0 g
s
.65 .757 .928 r
.33942 .55747 m .33038 .56043 L .33324 .56317 L p F P
0 g
s
.65 .757 .928 r
.33324 .56317 m .34227 .56021 L .33942 .55747 L p F P
0 g
s
.651 .757 .928 r
.63076 .55749 m .6212 .56046 L .62358 .56319 L p F P
0 g
s
.651 .757 .928 r
.62358 .56319 m .63313 .56023 L .63076 .55749 L p F P
0 g
s
.167 .097 .527 r
.63905 .75115 m .63642 .75443 L .63695 .75941 L p F P
0 g
s
.219 .167 .582 r
.63642 .75443 m .63905 .75115 L .63736 .74699 L p F P
0 g
s
.256 .161 .551 r
.63693 .75942 m .63695 .75941 L .63642 .75443 L p F P
0 g
s
.651 .757 .928 r
.48509 .55749 m .47579 .56046 L .47841 .56319 L p F P
0 g
s
.651 .757 .928 r
.47841 .56319 m .4877 .56023 L .48509 .55749 L p F P
0 g
s
.611 .682 .892 r
.58859 .79399 m .58757 .79256 L .59327 .79148 L closepath p F P
0 g
s
.04 0 .235 r
.63015 .77679 m .63171 .77316 L .63061 .77417 L closepath p F P
0 g
s
.895 .725 .664 r
.48526 .72574 m .48863 .72798 L .48656 .73311 L p F P
0 g
s
.89 .719 .663 r
.48863 .72798 m .48526 .72574 L .48723 .72064 L p F P
0 g
s
.903 .839 .38 r
.49037 .67522 m .49043 .67188 L .48922 .67671 L p F P
0 g
s
.903 .839 .38 r
.49009 .67652 m .49037 .67522 L p .48922 .67671 L F P
0 g
s
.977 .751 .531 r
.41521 .75435 m .41297 .75179 L .41231 .75653 L p F P
0 g
s
.977 .751 .531 r
.41231 .75653 m .41454 .75908 L .41521 .75435 L p F P
0 g
s
.65 .757 .928 r
.20565 .55714 m .19685 .5601 L .19992 .56284 L p F P
0 g
s
.65 .757 .928 r
.19992 .56284 m .20871 .55989 L .20565 .55714 L p F P
0 g
s
.541 .442 .692 r
.56157 .74769 m .56731 .74471 L p .56316 .75358 L F P
0 g
s
.541 .442 .692 r
.56316 .75358 m .563 .75356 L .56157 .74769 L p F P
0 g
s
.364 .298 .648 r
.56486 .71308 m .56311 .71471 L .56421 .7203 L p F P
0 g
s
.956 .77 .613 r
.48596 .70551 m .48802 .70776 L .48834 .70796 L p F P
0 g
s
.944 .796 .666 r
.48802 .70776 m .48834 .70796 L .4883 .70808 L closepath p F P
0 g
s
.651 .758 .928 r
.78067 .56291 m .79049 .55994 L .7926 .56267 L p F P
0 g
s
.651 .758 .928 r
.79049 .55994 m .78067 .56291 L .77855 .56018 L p F P
0 g
s
.556 .009 0 r
.42994 .78563 m .42793 .78386 L .42521 .78199 L p F P
0 g
s
.65 .757 .928 r
.35133 .55724 m .34227 .56021 L .3451 .56294 L p F P
0 g
s
.65 .757 .928 r
.3451 .56294 m .35415 .55999 L .35133 .55724 L p F P
0 g
s
.942 .797 .671 r
.4883 .70808 m .4863 .71316 L .48402 .71058 L p F P
0 g
s
.942 .797 .671 r
.48802 .70776 m .4883 .70808 L p .48402 .71058 L F P
0 g
s
.911 .932 .813 r
.4389 .6817 m .43849 .67848 L .43383 .68433 L p F P
0 g
s
.911 .932 .813 r
.43383 .68433 m .43419 .68755 L .4389 .6817 L p F P
0 g
s
.651 .758 .928 r
.6427 .55726 m .63313 .56023 L .63548 .56296 L p F P
0 g
s
.651 .758 .928 r
.63548 .56296 m .64505 .56 L .6427 .55726 L p F P
0 g
s
.651 .757 .928 r
.49701 .55727 m .4877 .56023 L .49029 .56297 L p F P
0 g
s
.651 .757 .928 r
.49029 .56297 m .4996 .56001 L .49701 .55727 L p F P
0 g
s
.853 .693 .683 r
.48911 .74916 m .48984 .74763 L .48785 .74664 L closepath p F P
0 g
s
.854 .693 .682 r
.48655 .74401 m .48812 .7404 L p .48984 .74763 L F P
0 g
s
.854 .693 .682 r
.48984 .74763 m .48785 .74664 L .48655 .74401 L p F P
0 g
s
.27 .283 .69 r
.63658 .7244 m .63449 .72779 L .63777 .73147 L p F P
0 g
s
.302 .326 .72 r
.63632 .72358 m .63312 .72046 L p .63449 .72779 L F P
0 g
s
.302 .326 .72 r
.63449 .72779 m .63658 .7244 L .63632 .72358 L p F P
0 g
s
0 0 .446 r
.56232 .67935 m .56219 .68157 L .56353 .68568 L p F P
0 g
s
0 0 .419 r
.56146 .67525 m .56118 .67411 L p .56219 .68157 L F P
0 g
s
0 0 .419 r
.56219 .68157 m .56232 .67935 L .56146 .67525 L p F P
0 g
s
.65 .757 .928 r
.21754 .55693 m .20871 .55989 L .21176 .56262 L p F P
0 g
s
.65 .757 .928 r
.21176 .56262 m .22058 .55967 L .21754 .55693 L p F P
0 g
s
.961 .867 .7 r
.41865 .72109 m .41615 .72632 L .41462 .72351 L p F P
0 g
s
.961 .867 .7 r
.41754 .71904 m .41865 .72109 L p .41462 .72351 L F P
0 g
s
.651 .758 .928 r
.7926 .56267 m .80244 .5597 L .80452 .56243 L p F P
0 g
s
.651 .758 .928 r
.80244 .5597 m .7926 .56267 L .79049 .55994 L p F P
0 g
s
.257 .388 .805 r
.61282 .6815 m .61296 .67981 L p .61748 .68626 L F P
0 g
s
.256 .404 .82 r
.61282 .6815 m .61156 .67899 L .61296 .67981 L closepath p F P
0 g
s
.994 .865 .535 r
.48822 .68809 m .48753 .685 L .48602 .68993 L p F P
0 g
s
.994 .865 .535 r
.48602 .68993 m .4869 .69296 L .48822 .68809 L p F P
0 g
s
.65 .757 .928 r
.36323 .55702 m .35415 .55999 L .35696 .56272 L p F P
0 g
s
.65 .757 .928 r
.35696 .56272 m .36604 .55976 L .36323 .55702 L p F P
0 g
s
.651 .758 .928 r
.64739 .56273 m .65698 .55977 L .6593 .5625 L p F P
0 g
s
.651 .758 .928 r
.65465 .55703 m .64505 .56 L .64739 .56273 L p F P
0 g
s
.651 .758 .928 r
.64739 .56273 m .65698 .55977 L .65465 .55703 L p F P
0 g
s
.651 .757 .928 r
.50894 .55704 m .4996 .56001 L .50218 .56274 L p F P
0 g
s
.651 .757 .928 r
.50218 .56274 m .51151 .55978 L .50894 .55704 L p F P
0 g
s
.968 .838 .661 r
.41563 .73422 m .4139 .73148 L .41192 .73658 L p F P
0 g
s
.968 .838 .661 r
.41192 .73658 m .41363 .73932 L .41563 .73422 L p F P
0 g
s
.579 .539 .775 r
.5801 .7773 m .58261 .78318 L .57313 .78441 L p F P
0 g
s
.579 .539 .775 r
.57656 .7776 m .5801 .7773 L p .57313 .78441 L F P
0 g
s
.579 .539 .775 r
.57313 .78441 m .57134 .7799 L .57656 .7776 L p F P
0 g
s
.198 .201 .637 r
.56587 .69729 m .56348 .7012 L .56589 .70504 L p F P
0 g
s
.165 .147 .591 r
.56348 .7012 m .56587 .69729 L .56402 .6933 L p F P
0 g
s
.954 .773 .62 r
.48573 .70628 m .48596 .70551 L .48802 .70776 L closepath p F P
0 g
s
.942 .797 .671 r
.48402 .71058 m .48573 .70628 L .48802 .70776 L p F P
0 g
s
.839 .703 .712 r
.48329 .75862 m .48782 .76048 L .48417 .76609 L p F P
0 g
s
.827 .687 .709 r
.48782 .76048 m .48329 .75862 L .48665 .7531 L p F P
0 g
s
.903 .839 .38 r
.48922 .67671 m .48919 .67894 L .49009 .67652 L p F P
0 g
s
.831 .819 .337 r
.48919 .67894 m .49009 .67652 L .48903 .68008 L closepath p F P
0 g
s
.65 .757 .928 r
.22943 .55671 m .22058 .55967 L .22361 .56241 L p F P
0 g
s
.65 .757 .928 r
.22361 .56241 m .23245 .55946 L .22943 .55671 L p F P
0 g
s
.651 .758 .928 r
.80452 .56243 m .81439 .55946 L .81645 .56219 L p F P
0 g
s
.651 .758 .928 r
.81439 .55946 m .80452 .56243 L .80244 .5597 L p F P
0 g
s
.823 .685 .712 r
.48665 .7531 m .48911 .74916 L .48785 .74664 L p F P
0 g
s
.65 .757 .928 r
.37514 .55679 m .36604 .55976 L .36883 .56249 L p F P
0 g
s
.65 .757 .928 r
.36883 .56249 m .37793 .55954 L .37514 .55679 L p F P
0 g
s
.651 .758 .928 r
.6593 .5625 m .66891 .55954 L .67121 .56227 L p F P
0 g
s
.651 .758 .928 r
.66891 .55954 m .6593 .5625 L .65698 .55977 L p F P
0 g
s
.651 .757 .928 r
.52087 .55681 m .51151 .55978 L .51406 .56251 L p F P
0 g
s
.651 .757 .928 r
.51406 .56251 m .52342 .55955 L .52087 .55681 L p F P
0 g
s
.82 .699 .731 r
.48482 .77368 m .48488 .7736 L .48474 .77354 L closepath p F P
0 g
s
.821 .699 .73 r
.48224 .76908 m .48417 .76609 L p .48488 .7736 L F P
0 g
s
.821 .699 .73 r
.48488 .7736 m .48474 .77354 L .48224 .76908 L p F P
0 g
s
.786 .689 .758 r
.47914 .77979 m .48482 .77368 L .48474 .77354 L p F P
0 g
s
.786 .689 .758 r
.48474 .77354 m .47979 .7719 L p .47914 .77979 L F P
0 g
s
.794 .691 .752 r
.48474 .77354 m .48224 .76908 L .47979 .7719 L closepath p F P
0 g
s
.693 .441 0 r
.56118 .67411 m .56107 .67364 L .55981 .66791 L p F P
0 g
s
0 0 .354 r
.55981 .66674 m .55981 .66791 L .56107 .67364 L p F P
0 g
s
.651 .758 .928 r
.81645 .56219 m .82634 .55922 L .82839 .56196 L p F P
0 g
s
.651 .758 .928 r
.82634 .55922 m .81645 .56219 L .81439 .55946 L p F P
0 g
s
.65 .757 .928 r
.24132 .55649 m .23245 .55946 L .23546 .5622 L p F P
0 g
s
.65 .757 .928 r
.23546 .5622 m .24432 .55924 L .24132 .55649 L p F P
0 g
s
.537 .458 .713 r
.56302 .75364 m .563 .75356 L .56316 .75358 L closepath p F P
0 g
s
.537 .457 .713 r
.56476 .75987 m .56302 .75364 L .56316 .75358 L p F P
0 g
s
.651 .758 .928 r
.67121 .56227 m .68084 .55931 L .68312 .56204 L p F P
0 g
s
.651 .758 .928 r
.68084 .55931 m .67121 .56227 L .66891 .55954 L p F P
0 g
s
.65 .757 .928 r
.38706 .55657 m .37793 .55954 L .3807 .56227 L p F P
0 g
s
.65 .757 .928 r
.3807 .56227 m .38982 .55931 L .38706 .55657 L p F P
0 g
s
.916 .752 .664 r
.48434 .71825 m .48723 .72064 L .48526 .72574 L p F P
0 g
s
.914 .75 .665 r
.48723 .72064 m .48434 .71825 L .4863 .71316 L p F P
0 g
s
.651 .757 .928 r
.5328 .55658 m .52342 .55955 L .52596 .56229 L p F P
0 g
s
.651 .757 .928 r
.52596 .56229 m .53533 .55932 L .5328 .55658 L p F P
0 g
s
.613 .633 .846 r
.59327 .79148 m .58757 .79256 L .5851 .78826 L p F P
0 g
s
.946 .891 .744 r
.42349 .70743 m .42233 .70447 L .41911 .70991 L p F P
0 g
s
.946 .891 .744 r
.41911 .70991 m .42026 .71286 L .42349 .70743 L p F P
0 g
s
.876 .707 .669 r
.48812 .7404 m .48655 .74401 L .48397 .73947 L p F P
0 g
s
.876 .707 .669 r
.48397 .73947 m .48447 .73825 L .48812 .7404 L p F P
0 g
s
.876 .706 .667 r
.48812 .7404 m .48447 .73825 L .48656 .73311 L p F P
0 g
s
.649 .756 .928 r
.10748 .55602 m .09885 .55896 L .10208 .56171 L p F P
0 g
s
.649 .756 .928 r
.10208 .56171 m .1107 .55877 L .10748 .55602 L p F P
0 g
s
.218 .174 .592 r
.64029 .7431 m .63736 .74699 L .63905 .75115 L p F P
0 g
s
.246 .217 .627 r
.63736 .74699 m .64029 .7431 L .63796 .73913 L p F P
0 g
s
.537 .457 .713 r
.56316 .75358 m .57249 .75469 L p .56476 .75987 L F P
0 g
s
.539 .455 .709 r
.57249 .75469 m .56316 .75358 L .57114 .74972 L closepath p F P
0 g
s
.541 .442 .692 r
.56993 .74531 m .57114 .74972 L .56316 .75358 L p F P
0 g
s
.541 .442 .692 r
.56731 .74471 m .56993 .74531 L p .56316 .75358 L F P
0 g
s
.978 .785 .576 r
.41406 .74694 m .41202 .74431 L .41092 .74917 L p F P
0 g
s
.978 .785 .576 r
.41092 .74917 m .41297 .75179 L .41406 .74694 L p F P
0 g
s
.918 .935 .802 r
.43313 .68892 m .43419 .68755 L .43383 .68433 L p F P
0 g
s
.555 .773 .98 r
.44429 .79246 m .44018 .79114 L .44231 .79277 L closepath p F P
0 g
s
.581 .543 .777 r
.57134 .7799 m .57061 .7781 L .57656 .7776 L closepath p F P
0 g
s
.788 .731 .8 r
.47253 .78622 m .46609 .79151 L .46347 .78848 L p F P
0 g
s
.651 .758 .928 r
.82839 .56196 m .8383 .55898 L .84032 .56171 L p F P
0 g
s
.651 .758 .928 r
.8383 .55898 m .82839 .56196 L .82634 .55922 L p F P
0 g
s
.65 .757 .928 r
.25321 .55628 m .24432 .55924 L .24731 .56198 L p F P
0 g
s
.65 .757 .928 r
.24731 .56198 m .2562 .55902 L .25321 .55628 L p F P
0 g
s
.27 .305 .714 r
.63632 .72358 m .63312 .72046 L .63453 .71786 L closepath p F P
0 g
s
.301 .344 .74 r
.63378 .71568 m .6311 .71331 L p .63312 .72046 L F P
0 g
s
.301 .344 .74 r
.63312 .72046 m .63453 .71786 L .63378 .71568 L p F P
0 g
s
.651 .758 .928 r
.68312 .56204 m .69278 .55907 L .69504 .56181 L p F P
0 g
s
.651 .758 .928 r
.69278 .55907 m .68312 .56204 L .68084 .55931 L p F P
0 g
s
.65 .757 .928 r
.39897 .55634 m .38982 .55931 L .39258 .56205 L p F P
0 g
s
.65 .757 .928 r
.39258 .56205 m .40172 .55908 L .39897 .55634 L p F P
0 g
s
.651 .757 .928 r
.54474 .55635 m .53533 .55932 L .53785 .56206 L p F P
0 g
s
.651 .757 .928 r
.53785 .56206 m .54725 .55909 L .54474 .55635 L p F P
0 g
s
.98 .809 .6 r
.48729 .70061 m .48554 .69786 L .48411 .70278 L p F P
0 g
s
.98 .809 .6 r
.48411 .70278 m .48596 .70551 L .48729 .70061 L p F P
0 g
s
.815 .715 .755 r
.47914 .77979 m .47544 .78397 L .47284 .78027 L p F P
0 g
s
.815 .715 .755 r
.47284 .78027 m .47477 .7779 L .47914 .77979 L p F P
0 g
s
.786 .689 .758 r
.47979 .7719 m .47477 .7779 L .47914 .77979 L p F P
0 g
s
0 0 .035 r
.63171 .77316 m .63616 .76892 L p .62987 .77789 L F P
0 g
s
0 0 .035 r
.62987 .77789 m .63015 .77679 L .63171 .77316 L p F P
0 g
s
.122 0 .365 r
.63711 .76428 m .63712 .76403 L p .63171 .77316 L F P
0 g
s
.122 0 .365 r
.63171 .77316 m .63616 .76892 L .63711 .76428 L p F P
0 g
s
.649 .756 .928 r
.11936 .55582 m .1107 .55877 L .11391 .56152 L p F P
0 g
s
.649 .756 .928 r
.11391 .56152 m .12256 .55858 L .11936 .55582 L p F P
0 g
s
.245 .404 .824 r
.61296 .67981 m .61156 .67899 L .60911 .6742 L p F P
0 g
s
.918 .935 .802 r
.43383 .68433 m .43038 .68871 L .43313 .68892 L p F P
0 g
s
.921 .925 .797 r
.43313 .68892 m .42999 .69326 L .4293 .69014 L p F P
0 g
s
.921 .925 .797 r
.4293 .69014 m .43038 .68871 L .43313 .68892 L p F P
0 g
s
0 0 0 r
.61137 .79193 m .62082 .78666 L .62145 .78609 L p F P
0 g
s
.735 .93 .954 r
.61025 .7915 m .61137 .79193 L .62082 .78666 L p F P
0 g
s
.58 .518 .75 r
.57656 .7776 m .57061 .7781 L .56879 .77288 L p F P
0 g
s
0 0 .191 r
.56146 .67525 m .56118 .67411 L .56107 .67364 L closepath p F P
0 g
s
.364 .298 .648 r
.56421 .7203 m .56805 .71672 L .56486 .71308 L p F P
0 g
s
.427 .342 .657 r
.56421 .7203 m .56805 .71672 L p .56678 .72482 L F P
0 g
s
.427 .342 .657 r
.56678 .72482 m .56478 .72316 L .56421 .7203 L p F P
0 g
s
.651 .758 .928 r
.84032 .56171 m .85025 .55874 L .85226 .56147 L p F P
0 g
s
.651 .758 .928 r
.85025 .55874 m .84032 .56171 L .8383 .55898 L p F P
0 g
s
.555 .467 .71 r
.56476 .75987 m .57288 .75596 L p .57346 .76304 L F P
0 g
s
.555 .467 .71 r
.57346 .76304 m .56555 .76275 L .56476 .75987 L p F P
0 g
s
.537 .457 .713 r
.57249 .75469 m .57288 .75596 L .56476 .75987 L p F P
0 g
s
.65 .757 .928 r
.26511 .55606 m .2562 .55902 L .25917 .56176 L p F P
0 g
s
.65 .757 .928 r
.25917 .56176 m .26808 .5588 L .26511 .55606 L p F P
0 g
s
.823 .685 .712 r
.48785 .74664 m .48556 .74568 L p .48665 .7531 L F P
0 g
s
.829 .686 .705 r
.48785 .74664 m .48655 .74401 L .48556 .74568 L closepath p F P
0 g
s
.499 .403 .677 r
.56736 .73485 m .56362 .73344 L .56667 .73174 L closepath p F P
0 g
s
.508 .393 .657 r
.5654 .72598 m .56667 .73174 L .56362 .73344 L p F P
0 g
s
.651 .758 .928 r
.69504 .56181 m .70472 .55884 L .70696 .56158 L p F P
0 g
s
.651 .758 .928 r
.70472 .55884 m .69504 .56181 L .69278 .55907 L p F P
0 g
s
.313 .471 .857 r
.60665 .66971 m .60214 .66744 L p .60786 .67353 L F P
0 g
s
.236 .433 .851 r
.60214 .66744 m .60665 .66971 L .6042 .66555 L p F P
0 g
s
.236 .433 .851 r
.6042 .66555 m .60174 .66429 L .60214 .66744 L p F P
0 g
s
.65 .757 .928 r
.41089 .55611 m .40172 .55908 L .40446 .56182 L p F P
0 g
s
.65 .757 .928 r
.40446 .56182 m .41362 .55886 L .41089 .55611 L p F P
0 g
s
.788 .731 .8 r
.46347 .78848 m .46802 .78438 L .47253 .78622 L p F P
0 g
s
.764 .719 .811 r
.47284 .78027 m .46802 .78438 L .47253 .78622 L p F P
0 g
s
.764 .719 .811 r
.47253 .78622 m .47544 .78397 L .47284 .78027 L p F P
0 g
s
.651 .757 .928 r
.55668 .55612 m .54725 .55909 L .54975 .56183 L p F P
0 g
s
.651 .757 .928 r
.54975 .56183 m .55917 .55887 L .55668 .55612 L p F P
0 g
s
.925 .54 .234 r
.42394 .7796 m .42114 .77724 L .41989 .77302 L p F P
0 g
s
.927 .541 .207 r
.41989 .77302 m .41727 .7706 L .41852 .77483 L p F P
0 g
s
.927 .541 .207 r
.41852 .77483 m .42114 .77724 L .41989 .77302 L p F P
0 g
s
.844 .384 .002 r
.42394 .7796 m .42521 .78199 L .4225 .77978 L p F P
0 g
s
.844 .384 .002 r
.4225 .77978 m .42114 .77724 L .42394 .7796 L p F P
0 g
s
.649 .756 .928 r
.13124 .55563 m .12256 .55858 L .12575 .56132 L p F P
0 g
s
.649 .756 .928 r
.12575 .56132 m .13442 .55838 L .13124 .55563 L p F P
0 g
s
.849 .709 .708 r
.48239 .75114 m .48665 .7531 L .48329 .75862 L p F P
0 g
s
.823 .685 .712 r
.48556 .74568 m .48239 .75114 L .48665 .7531 L p F P
0 g
s
.553 .485 .733 r
.56665 .76626 m .56555 .76275 L .57346 .76304 L closepath p F P
0 g
s
0 0 0 r
.62082 .78666 m .62312 .7848 L .62145 .78609 L closepath p F P
0 g
s
0 0 0 r
.62906 .77854 m .62312 .7848 L .62145 .78609 L p F P
0 g
s
.58 .518 .75 r
.56879 .77288 m .5735 .77074 L p .57656 .7776 L F P
0 g
s
.567 .513 .754 r
.56879 .77288 m .56809 .77091 L .5735 .77074 L closepath p F P
0 g
s
.651 .758 .928 r
.85226 .56147 m .86221 .55849 L .8642 .56123 L p F P
0 g
s
.651 .758 .928 r
.86221 .55849 m .85226 .56147 L .85025 .55874 L p F P
0 g
s
.568 .492 .729 r
.56665 .76626 m .57346 .76304 L p .5735 .77074 L F P
0 g
s
.568 .492 .729 r
.5735 .77074 m .56809 .77091 L .56665 .76626 L p F P
0 g
s
.65 .757 .928 r
.27701 .55583 m .26808 .5588 L .27103 .56154 L p F P
0 g
s
.65 .757 .928 r
.27103 .56154 m .27996 .55858 L .27701 .55583 L p F P
0 g
s
.651 .758 .928 r
.70696 .56158 m .71666 .55861 L .71888 .56135 L p F P
0 g
s
.651 .758 .928 r
.71666 .55861 m .70696 .56158 L .70472 .55884 L p F P
0 g
s
.65 .757 .928 r
.42282 .55588 m .41362 .55886 L .41634 .56159 L p F P
0 g
s
.65 .757 .928 r
.41634 .56159 m .42552 .55863 L .42282 .55588 L p F P
0 g
s
.651 .757 .928 r
.56862 .55589 m .55917 .55887 L .56165 .5616 L p F P
0 g
s
.651 .757 .928 r
.56165 .5616 m .57109 .55864 L .56862 .55589 L p F P
0 g
s
.966 .648 .357 r
.41681 .76617 m .41438 .76368 L .41484 .76812 L p F P
0 g
s
.966 .648 .357 r
.41484 .76812 m .41727 .7706 L .41681 .76617 L p F P
0 g
s
.65 .757 .928 r
.14312 .55543 m .13442 .55838 L .13759 .56113 L p F P
0 g
s
.65 .757 .928 r
.13759 .56113 m .14628 .55818 L .14312 .55543 L p F P
0 g
s
.266 .322 .734 r
.63378 .71568 m .6311 .71331 L .63217 .711 L closepath p F P
0 g
s
.3 .362 .759 r
.63127 .70858 m .62848 .70633 L p .6311 .71331 L F P
0 g
s
.3 .362 .759 r
.6311 .71331 m .63217 .711 L .63127 .70858 L p F P
0 g
s
.896 .733 .671 r
.48327 .73085 m .48656 .73311 L .48447 .73825 L p F P
0 g
s
.895 .725 .664 r
.48656 .73311 m .48327 .73085 L .48526 .72574 L p F P
0 g
s
0 0 .069 r
.49151 .6671 m .49383 .66307 L .4923 .66799 L p F P
0 g
s
0 0 .069 r
.4923 .66799 m .49043 .67188 L .49151 .6671 L p F P
0 g
s
.651 .758 .928 r
.8642 .56123 m .87418 .55824 L .87615 .56098 L p F P
0 g
s
.651 .758 .928 r
.87418 .55824 m .8642 .56123 L .86221 .55849 L p F P
0 g
s
.839 .703 .712 r
.48417 .76609 m .48224 .76908 L .47966 .7647 L p F P
0 g
s
.839 .703 .712 r
.47966 .7647 m .48001 .76412 L .48417 .76609 L p F P
0 g
s
.839 .703 .712 r
.48417 .76609 m .48001 .76412 L .48329 .75862 L p F P
0 g
s
.757 .78 .872 r
.45678 .7921 m .45417 .79358 L .45152 .7911 L p F P
0 g
s
.565 .774 .977 r
.44429 .79246 m .45152 .7911 L p .43963 .79071 L F P
0 g
s
.565 .774 .977 r
.43963 .79071 m .44018 .79114 L .44429 .79246 L p F P
0 g
s
.59 .871 .994 r
.5995 .79366 m .609 .79088 L .61025 .7915 L p F P
0 g
s
.6 .778 .966 r
.609 .79088 m .5995 .79366 L .59707 .79075 L p F P
0 g
s
0 0 .455 r
.56107 .67364 m .56099 .67088 L p .56254 .67821 L F P
0 g
s
0 0 .455 r
.56254 .67821 m .56146 .67525 L .56107 .67364 L p F P
0 g
s
0 0 .455 r
.56223 .67502 m .56254 .67821 L p .56106 .67122 L F P
0 g
s
0 0 .455 r
.56099 .67088 m .56223 .67502 L p .56106 .67122 L F P
0 g
s
0 0 .301 r
.56352 .67916 m .56223 .67502 L p .56232 .67539 L F P
0 g
s
0 0 .301 r
.56406 .68227 m .56352 .67916 L p .56232 .67539 L F P
0 g
s
0 0 .274 r
.56486 .68329 m .56352 .67916 L p .56364 .67958 L F P
0 g
s
0 0 .274 r
.5656 .68635 m .56486 .68329 L p .56364 .67958 L F P
0 g
s
0 0 .25 r
.56626 .68743 m .56486 .68329 L p .56502 .68378 L F P
0 g
s
0 0 .25 r
.56717 .69043 m .56626 .68743 L p .56502 .68378 L F P
0 g
s
.673 .356 0 r
.56626 .68743 m .56717 .69043 L .56878 .69451 L p F P
0 g
s
.846 .472 0 r
.56626 .68743 m .56771 .69156 L p .5675 .69109 L F P
0 g
s
0 0 .466 r
.5656 .68635 m .56524 .6897 L .56711 .69369 L p F P
0 g
s
0 .06 .575 r
.56406 .68227 m .5656 .68635 L .56524 .6897 L p F P
0 g
s
0 0 .466 r
.56711 .69369 m .56717 .69043 L .5656 .68635 L p F P
0 g
s
0 0 .25 r
.56486 .68329 m .5656 .68635 L .56717 .69043 L p F P
0 g
s
.846 .472 0 r
.56463 .68463 m .56626 .68743 L p .5675 .69109 L F P
0 g
s
.843 .479 0 r
.56486 .68329 m .56626 .68743 L p .56608 .68702 L F P
0 g
s
0 0 .301 r
.56223 .67502 m .56254 .67821 L .56406 .68227 L p F P
0 g
s
0 0 .274 r
.56352 .67916 m .56406 .68227 L .5656 .68635 L p F P
0 g
s
.843 .479 0 r
.56332 .68046 m .56486 .68329 L p .56608 .68702 L F P
0 g
s
.838 .484 0 r
.56352 .67916 m .56486 .68329 L p .56472 .68294 L F P
0 g
s
.838 .484 0 r
.56207 .67629 m .56352 .67916 L p .56472 .68294 L F P
0 g
s
.832 .489 0 r
.56223 .67502 m .56352 .67916 L p .5634 .67884 L F P
0 g
s
0 0 .354 r
.56107 .67364 m .56099 .67088 L p .55988 .66712 L F P
0 g
s
.832 .489 0 r
.56089 .67212 m .56223 .67502 L p .5634 .67884 L F P
0 g
s
.823 .493 0 r
.56099 .67088 m .56223 .67502 L p .56211 .67469 L F P
0 g
s
.823 .493 0 r
.55979 .66794 m .56099 .67088 L p .56211 .67469 L F P
0 g
s
0 0 .354 r
.56099 .67088 m .55981 .66674 L p .55988 .66712 L F P
0 g
s
.65 .757 .928 r
.28892 .55561 m .27996 .55858 L .28289 .56132 L p F P
0 g
s
.65 .757 .928 r
.28289 .56132 m .29185 .55836 L .28892 .55561 L p F P
0 g
s
.651 .758 .928 r
.71888 .56135 m .72861 .55838 L .73081 .56111 L p F P
0 g
s
.651 .758 .928 r
.72861 .55838 m .71888 .56135 L .71666 .55861 L p F P
0 g
s
.65 .757 .928 r
.43474 .55566 m .42552 .55863 L .42822 .56137 L p F P
0 g
s
.65 .757 .928 r
.42822 .56137 m .43743 .5584 L .43474 .55566 L p F P
0 g
s
.194 .072 .476 r
.637 .76077 m .63693 .75942 L .63695 .75941 L closepath p F P
0 g
s
.651 .757 .928 r
.58057 .55566 m .57109 .55864 L .57355 .56137 L p F P
0 g
s
.651 .757 .928 r
.57355 .56137 m .58302 .55841 L .58057 .55566 L p F P
0 g
s
.127 .023 .456 r
.63695 .75941 m .64006 .75551 L p .63715 .764 L F P
0 g
s
.127 .023 .456 r
.63715 .764 m .637 .76077 L .63695 .75941 L p F P
0 g
s
.167 .097 .527 r
.63695 .75941 m .64006 .75551 L .63905 .75115 L p F P
0 g
s
.409 .342 .671 r
.5654 .72598 m .56478 .72316 L .56678 .72482 L closepath p F P
0 g
s
.941 .79 .665 r
.4863 .71316 m .48402 .71058 L .48202 .71568 L p F P
0 g
s
.941 .79 .665 r
.48202 .71568 m .48434 .71825 L .4863 .71316 L p F P
0 g
s
.263 .424 .835 r
.60911 .6742 m .60786 .67353 L .6079 .67192 L closepath p F P
0 g
s
.313 .471 .857 r
.60786 .67353 m .6079 .67192 L .60665 .66971 L p F P
0 g
s
.967 .857 .679 r
.41615 .72632 m .41462 .72351 L .41237 .72867 L p F P
0 g
s
.967 .857 .679 r
.41237 .72867 m .4139 .73148 L .41615 .72632 L p F P
0 g
s
.65 .757 .928 r
.155 .55523 m .14628 .55818 L .14943 .56093 L p F P
0 g
s
.65 .757 .928 r
.14943 .56093 m .15815 .55798 L .155 .55523 L p F P
0 g
s
.028 .081 .583 r
.56484 .69082 m .56402 .6933 L .56587 .69729 L p F P
0 g
s
.012 .067 .573 r
.56405 .68713 m .56353 .68568 L p .56402 .6933 L F P
0 g
s
.012 .067 .573 r
.56402 .6933 m .56484 .69082 L .56405 .68713 L p F P
0 g
s
.851 .834 .362 r
.48903 .68008 m .48919 .67894 L .48788 .6822 L p F P
0 g
s
.851 .834 .362 r
.48788 .6822 m .48753 .685 L .48903 .68008 L p F P
0 g
s
.307 .284 .669 r
.56835 .70888 m .56486 .71308 L .56805 .71672 L p F P
0 g
s
.388 .303 .638 r
.56589 .70504 m .56835 .70888 L .56486 .71308 L p F P
0 g
s
.931 .92 .781 r
.42999 .69326 m .4293 .69014 L .42536 .69578 L p F P
0 g
s
.931 .92 .781 r
.42536 .69578 m .42604 .6989 L .42999 .69326 L p F P
0 g
s
0 0 .505 r
.56232 .67935 m .56146 .67525 L .56254 .67821 L closepath p F P
0 g
s
.65 .757 .928 r
.30083 .55539 m .29185 .55836 L .29476 .5611 L p F P
0 g
s
.65 .757 .928 r
.29476 .5611 m .30374 .55814 L .30083 .55539 L p F P
0 g
s
.651 .758 .928 r
.73081 .56111 m .74056 .55814 L .74274 .56088 L p F P
0 g
s
.651 .758 .928 r
.74056 .55814 m .73081 .56111 L .72861 .55838 L p F P
0 g
s
0 .43 .846 r
.43952 .79068 m .4365 .78841 L .42994 .78563 L p F P
0 g
s
.556 .009 0 r
.42521 .78199 m .42686 .78337 L .42994 .78563 L p F P
0 g
s
.007 .453 .868 r
.42686 .78337 m .42994 .78563 L .4365 .78841 L p F P
0 g
s
.843 .707 .712 r
.48556 .74568 m .48655 .74401 L .48397 .73947 L p F P
0 g
s
.65 .757 .928 r
.44667 .55543 m .43743 .5584 L .44011 .56114 L p F P
0 g
s
.65 .757 .928 r
.44011 .56114 m .44934 .55818 L .44667 .55543 L p F P
0 g
s
.651 .757 .928 r
.59252 .55543 m .58302 .55841 L .58546 .56114 L p F P
0 g
s
.651 .757 .928 r
.58546 .56114 m .59495 .55818 L .59252 .55543 L p F P
0 g
s
.812 .498 0 r
.55876 .66375 m .55981 .66674 L .56099 .67088 L p F P
0 g
s
.262 .338 .754 r
.63127 .70858 m .62848 .70633 L .62945 .70375 L closepath p F P
0 g
s
.299 .38 .778 r
.62877 .70208 m .6253 .6995 L p .62848 .70633 L F P
0 g
s
.299 .38 .778 r
.62848 .70633 m .62945 .70375 L .62877 .70208 L p F P
0 g
s
.975 .835 .641 r
.41363 .73932 m .41192 .73658 L .41025 .74159 L p F P
0 g
s
.975 .835 .641 r
.41251 .74272 m .41363 .73932 L p .41025 .74159 L F P
0 g
s
.65 .757 .928 r
.16689 .55502 m .15815 .55798 L .16128 .56072 L p F P
0 g
s
.65 .757 .928 r
.16128 .56072 m .17002 .55777 L .16689 .55502 L p F P
0 g
s
.757 .78 .872 r
.45152 .7911 m .45333 .78996 L .45678 .7921 L p F P
0 g
s
.728 .751 .871 r
.46084 .78549 m .45333 .78996 L .45678 .7921 L p F P
0 g
s
.728 .751 .871 r
.45678 .7921 m .46347 .78848 L .46084 .78549 L p F P
0 g
s
.98 .717 .454 r
.41454 .75908 m .41231 .75653 L .41214 .76113 L p F P
0 g
s
.98 .717 .454 r
.41214 .76113 m .41438 .76368 L .41454 .75908 L p F P
0 g
s
.951 .894 .735 r
.42026 .71286 m .41911 .70991 L .41606 .7153 L p F P
0 g
s
.951 .894 .735 r
.41606 .7153 m .41718 .71826 L .42026 .71286 L p F P
0 g
s
.257 .388 .805 r
.61296 .67981 m .61777 .68295 L .61748 .68626 L p F P
0 g
s
.213 .383 .816 r
.6129 .67659 m .61296 .67981 L .61777 .68295 L p F P
0 g
s
.245 .404 .824 r
.60911 .6742 m .6129 .67659 L .61296 .67981 L p F P
0 g
s
.65 .757 .928 r
.31274 .55517 m .30374 .55814 L .30663 .56088 L p F P
0 g
s
.65 .757 .928 r
.30663 .56088 m .31563 .55792 L .31274 .55517 L p F P
0 g
s
.651 .758 .928 r
.74274 .56088 m .75251 .55791 L .75468 .56065 L p F P
0 g
s
.651 .758 .928 r
.75251 .55791 m .74274 .56088 L .74056 .55814 L p F P
0 g
s
.041 0 .159 r
.62906 .77854 m .62987 .77789 L .63015 .77679 L closepath p F P
0 g
s
.65 .757 .928 r
.4586 .5552 m .44934 .55818 L .452 .56092 L p F P
0 g
s
.65 .757 .928 r
.452 .56092 m .46125 .55795 L .4586 .5552 L p F P
0 g
s
.651 .757 .928 r
.60447 .5552 m .59495 .55818 L .59737 .56092 L p F P
0 g
s
.651 .757 .928 r
.59737 .56092 m .60688 .55795 L .60447 .5552 L p F P
0 g
s
.997 .86 .559 r
.4869 .69296 m .48602 .68993 L .48448 .69489 L p F P
0 g
s
.997 .86 .559 r
.48448 .69489 m .48554 .69786 L .4869 .69296 L p F P
0 g
s
.408 .342 .671 r
.56678 .72482 m .5654 .72598 L .56667 .73174 L p F P
0 g
s
.799 .701 .756 r
.47979 .7719 m .48224 .76908 L .47966 .7647 L p F P
0 g
s
.231 .211 .629 r
.63976 .73653 m .63796 .73913 L .64029 .7431 L p F P
0 g
s
.266 .259 .665 r
.63891 .73307 m .63777 .73147 L p .63796 .73913 L F P
0 g
s
.266 .259 .665 r
.63796 .73913 m .63976 .73653 L .63891 .73307 L p F P
0 g
s
.257 .355 .773 r
.62877 .70208 m .6253 .6995 L .6263 .69604 L closepath p F P
0 g
s
.296 .398 .797 r
.62629 .69601 m .62161 .69282 L p .6253 .6995 L F P
0 g
s
.296 .398 .797 r
.6253 .6995 m .6263 .69604 L .62629 .69601 L p F P
0 g
s
.65 .757 .928 r
.17879 .55481 m .17002 .55777 L .17313 .56052 L p F P
0 g
s
.65 .757 .928 r
.17313 .56052 m .18189 .55757 L .17879 .55481 L p F P
0 g
s
.255 .378 .796 r
.62161 .69282 m .62226 .68942 L .61748 .68626 L p F P
0 g
s
.263 .405 .818 r
.61777 .68295 m .61748 .68626 L .62226 .68942 L p F P
0 g
s
.86 .721 .707 r
.48165 .74361 m .48556 .74568 L .48239 .75114 L p F P
0 g
s
.843 .707 .712 r
.48397 .73947 m .48165 .74361 L .48556 .74568 L p F P
0 g
s
.235 .357 .784 r
.62161 .69282 m .62629 .69601 L .62382 .69054 L p F P
0 g
s
.235 .357 .784 r
.62382 .69054 m .62226 .68942 L .62161 .69282 L p F P
0 g
s
.651 .758 .928 r
.75468 .56065 m .76446 .55767 L .76661 .56041 L p F P
0 g
s
.651 .758 .928 r
.76446 .55767 m .75468 .56065 L .75251 .55791 L p F P
0 g
s
.884 .97 .838 r
.44918 .66639 m .44381 .67244 L .44411 .66899 L p F P
0 g
s
.884 .97 .838 r
.44919 .66629 m .44918 .66639 L p .44411 .66899 L F P
0 g
s
.65 .757 .928 r
.32466 .55494 m .31563 .55792 L .31851 .56066 L p F P
0 g
s
.65 .757 .928 r
.31851 .56066 m .32753 .55769 L .32466 .55494 L p F P
0 g
s
.131 .026 .457 r
.63712 .76403 m .637 .76077 L .63715 .764 L closepath p F P
0 g
s
.651 .757 .928 r
.61643 .55497 m .60688 .55795 L .60929 .56069 L p F P
0 g
s
.651 .757 .928 r
.60929 .56069 m .61882 .55772 L .61643 .55497 L p F P
0 g
s
.65 .757 .928 r
.47054 .55497 m .46125 .55795 L .4639 .56069 L p F P
0 g
s
.65 .757 .928 r
.4639 .56069 m .47317 .55772 L .47054 .55497 L p F P
0 g
s
.917 .754 .665 r
.4824 .72334 m .48526 .72574 L .48327 .73085 L p F P
0 g
s
.916 .752 .664 r
.48526 .72574 m .4824 .72334 L .48434 .71825 L p F P
0 g
s
.864 .977 .854 r
.44653 .66636 m .45017 .66272 L .44919 .66629 L closepath p F P
0 g
s
.884 .97 .838 r
.44411 .66899 m .44653 .66636 L .44919 .66629 L p F P
0 g
s
0 0 0 r
.62987 .77789 m .62906 .77854 L .62312 .7848 L p F P
0 g
s
.831 .732 .755 r
.47537 .77001 m .47979 .7719 L .47477 .7779 L p F P
0 g
s
.799 .701 .756 r
.47966 .7647 m .47537 .77001 L .47979 .7719 L p F P
0 g
s
.65 .757 .928 r
.19068 .5546 m .18189 .55757 L .18499 .56031 L p F P
0 g
s
.65 .757 .928 r
.18499 .56031 m .19377 .55735 L .19068 .5546 L p F P
0 g
s
.958 .875 .711 r
.41678 .71903 m .41718 .71826 L .41754 .71904 L closepath p F P
0 g
s
.961 .867 .7 r
.41462 .72351 m .41678 .71903 L .41754 .71904 L p F P
0 g
s
.613 .633 .846 r
.5851 .78826 m .59461 .78698 L p .59327 .79148 L F P
0 g
s
.575 .579 .82 r
.59213 .78246 m .59461 .78698 L .5851 .78826 L p F P
0 g
s
.575 .579 .82 r
.58502 .78299 m .59213 .78246 L p .5851 .78826 L F P
0 g
s
.575 .579 .82 r
.5851 .78826 m .58305 .78407 L .58502 .78299 L p F P
0 g
s
.651 .758 .928 r
.76661 .56041 m .77642 .55744 L .77855 .56018 L p F P
0 g
s
.651 .758 .928 r
.77642 .55744 m .76661 .56041 L .76446 .55767 L p F P
0 g
s
.65 .757 .928 r
.33657 .55472 m .32753 .55769 L .33038 .56043 L p F P
0 g
s
.65 .757 .928 r
.33038 .56043 m .33942 .55747 L .33657 .55472 L p F P
0 g
s
.651 .757 .928 r
.62838 .55474 m .61882 .55772 L .6212 .56046 L p F P
0 g
s
.651 .757 .928 r
.6212 .56046 m .63076 .55749 L .62838 .55474 L p F P
0 g
s
.651 .757 .928 r
.48248 .55474 m .47317 .55772 L .47579 .56046 L p F P
0 g
s
.651 .757 .928 r
.47579 .56046 m .48509 .55749 L .48248 .55474 L p F P
0 g
s
.853 .722 .717 r
.47932 .75658 m .48329 .75862 L .48001 .76412 L p F P
0 g
s
.849 .709 .708 r
.48329 .75862 m .47932 .75658 L .48239 .75114 L p F P
0 g
s
0 0 .506 r
.56254 .67821 m .56232 .67935 L .56358 .68508 L p F P
0 g
s
0 0 .446 r
.56353 .68568 m .56358 .68508 L .56232 .67935 L p F P
0 g
s
.201 .385 .822 r
.6129 .67659 m .60911 .6742 L .6079 .67192 L p F P
0 g
s
.65 .757 .928 r
.20258 .55439 m .19377 .55735 L .19685 .5601 L p F P
0 g
s
.65 .757 .928 r
.19685 .5601 m .20565 .55714 L .20258 .55439 L p F P
0 g
s
0 0 0 r
.62312 .7848 m .62082 .78666 L .61851 .78706 L p F P
0 g
s
.735 .93 .954 r
.62082 .78666 m .61851 .78706 L p .61025 .7915 L F P
0 g
s
.657 .892 .981 r
.609 .79088 m .61418 .78886 L .61025 .7915 L closepath p F P
0 g
s
.735 .93 .954 r
.61851 .78706 m .61418 .78886 L .61025 .7915 L p F P
0 g
s
.613 .66 .872 r
.59707 .79075 m .59327 .79148 L .59656 .78997 L closepath p F P
0 g
s
.613 .633 .846 r
.59461 .78698 m .59656 .78997 L .59327 .79148 L p F P
0 g
s
.651 .758 .928 r
.77855 .56018 m .78838 .5572 L .79049 .55994 L p F P
0 g
s
.651 .758 .928 r
.78838 .5572 m .77855 .56018 L .77642 .55744 L p F P
0 g
s
.65 .757 .928 r
.3485 .55449 m .33942 .55747 L .34227 .56021 L p F P
0 g
s
.65 .757 .928 r
.34227 .56021 m .35133 .55724 L .3485 .55449 L p F P
0 g
s
.651 .758 .928 r
.64035 .55451 m .63076 .55749 L .63313 .56023 L p F P
0 g
s
.651 .758 .928 r
.63313 .56023 m .6427 .55726 L .64035 .55451 L p F P
0 g
s
.651 .757 .928 r
.49442 .55451 m .48509 .55749 L .4877 .56023 L p F P
0 g
s
.651 .757 .928 r
.4877 .56023 m .49701 .55727 L .49442 .55451 L p F P
0 g
s
.985 .764 .52 r
.41297 .75179 m .41092 .74917 L .41025 .75391 L p F P
0 g
s
.985 .764 .52 r
.41025 .75391 m .41231 .75653 L .41297 .75179 L p F P
0 g
s
0 0 0 r
.62312 .7848 m .62824 .78075 L .62987 .77789 L p F P
0 g
s
0 0 0 r
.62824 .78075 m .62312 .7848 L p .61851 .78706 L F P
0 g
s
.926 .923 .788 r
.42604 .6989 m .42536 .69578 L .42151 .70141 L p F P
0 g
s
.926 .923 .788 r
.42362 .70248 m .42604 .6989 L p .42151 .70141 L F P
0 g
s
.978 .811 .607 r
.48573 .70628 m .48596 .70551 L .48411 .70278 L p F P
0 g
s
0 0 .465 r
.56405 .68713 m .56353 .68568 L .56358 .68508 L closepath p F P
0 g
s
.879 .958 .85 r
.44381 .67244 m .44411 .66899 L .43864 .67508 L p F P
0 g
s
.879 .958 .85 r
.43984 .67687 m .44381 .67244 L p .43864 .67508 L F P
0 g
s
.65 .757 .928 r
.21449 .55417 m .20565 .55714 L .20871 .55989 L p F P
0 g
s
.65 .757 .928 r
.20871 .55989 m .21754 .55693 L .21449 .55417 L p F P
0 g
s
.651 .758 .928 r
.79049 .55994 m .80035 .55696 L .80244 .5597 L p F P
0 g
s
.651 .758 .928 r
.80035 .55696 m .79049 .55994 L .78838 .5572 L p F P
0 g
s
.65 .757 .928 r
.36042 .55426 m .35133 .55724 L .35415 .55999 L p F P
0 g
s
.65 .757 .928 r
.35415 .55999 m .36323 .55702 L .36042 .55426 L p F P
0 g
s
.651 .758 .928 r
.65231 .55427 m .6427 .55726 L .64505 .56 L p F P
0 g
s
.651 .758 .928 r
.64505 .56 m .65465 .55703 L .65231 .55427 L p F P
0 g
s
.651 .757 .928 r
.50637 .55429 m .49701 .55727 L .4996 .56001 L p F P
0 g
s
.651 .757 .928 r
.4996 .56001 m .50894 .55704 L .50637 .55429 L p F P
0 g
s
.904 .849 .397 r
.48919 .67894 m .48922 .67671 L .48789 .68159 L p F P
0 g
s
.904 .849 .397 r
.48789 .68159 m .48788 .6822 L .48919 .67894 L p F P
0 g
s
.464 0 0 r
.42686 .78337 m .42521 .78199 L .4225 .77978 L p F P
0 g
s
.458 .376 .675 r
.56667 .73174 m .57089 .72823 L p .56978 .73629 L F P
0 g
s
.458 .376 .675 r
.56978 .73629 m .56736 .73485 L .56667 .73174 L p F P
0 g
s
.408 .342 .671 r
.56667 .73174 m .57089 .72823 L .56678 .72482 L p F P
0 g
s
.156 .565 .931 r
.43963 .79071 m .43952 .79068 L .44018 .79114 L closepath p F P
0 g
s
.978 .811 .607 r
.48411 .70278 m .4831 .70616 L .48573 .70628 L p F P
0 g
s
.97 .854 .67 r
.48573 .70628 m .48402 .71058 L .48242 .70779 L p F P
0 g
s
.97 .854 .67 r
.48242 .70779 m .4831 .70616 L .48573 .70628 L p F P
0 g
s
.832 .731 .753 r
.47477 .7779 m .47284 .78027 L .47023 .7767 L p F P
0 g
s
.832 .731 .753 r
.47023 .7767 m .47086 .77587 L .47477 .7779 L p F P
0 g
s
.831 .732 .755 r
.47477 .7779 m .47086 .77587 L .47537 .77001 L p F P
0 g
s
0 0 0 r
.63354 .7743 m .62987 .77789 L .62824 .78075 L p F P
0 g
s
0 0 .035 r
.63616 .76892 m .63354 .7743 L .62987 .77789 L p F P
0 g
s
.895 .734 .673 r
.48397 .73947 m .48447 .73825 L .48184 .73638 L closepath p F P
0 g
s
.896 .733 .671 r
.48137 .7357 m .48327 .73085 L p .48447 .73825 L F P
0 g
s
.896 .733 .671 r
.48447 .73825 m .48184 .73638 L .48137 .7357 L p F P
0 g
s
.65 .757 .928 r
.22639 .55396 m .21754 .55693 L .22058 .55967 L p F P
0 g
s
.65 .757 .928 r
.22058 .55967 m .22943 .55671 L .22639 .55396 L p F P
0 g
s
.651 .758 .928 r
.80244 .5597 m .81232 .55672 L .81439 .55946 L p F P
0 g
s
.651 .758 .928 r
.81232 .55672 m .80244 .5597 L .80035 .55696 L p F P
0 g
s
.975 .835 .641 r
.41025 .74159 m .41108 .74295 L .41251 .74272 L p F P
0 g
s
.976 .816 .62 r
.41108 .74295 m .41251 .74272 L .41202 .74431 L closepath p F P
0 g
s
.65 .757 .928 r
.37235 .55404 m .36323 .55702 L .36604 .55976 L p F P
0 g
s
.65 .757 .928 r
.36604 .55976 m .37514 .55679 L .37235 .55404 L p F P
0 g
s
.651 .758 .928 r
.65698 .55977 m .6666 .55679 L .66891 .55954 L p F P
0 g
s
.651 .758 .928 r
.66428 .55404 m .65465 .55703 L .65698 .55977 L p F P
0 g
s
.651 .758 .928 r
.65698 .55977 m .6666 .55679 L .66428 .55404 L p F P
0 g
s
.651 .757 .928 r
.51832 .55406 m .50894 .55704 L .51151 .55978 L p F P
0 g
s
.651 .757 .928 r
.51151 .55978 m .52087 .55681 L .51832 .55406 L p F P
0 g
s
.804 .747 .799 r
.46802 .78438 m .46347 .78848 L .46084 .78549 L p F P
0 g
s
.879 .958 .85 r
.43864 .67508 m .43844 .67678 L .43984 .67687 L p F P
0 g
s
.904 .944 .822 r
.43844 .67678 m .43984 .67687 L .43849 .67848 L closepath p F P
0 g
s
.804 .747 .799 r
.46084 .78549 m .46405 .78237 L .46802 .78438 L p F P
0 g
s
.78 .73 .806 r
.47023 .7767 m .46405 .78237 L .46802 .78438 L p F P
0 g
s
.78 .73 .806 r
.46802 .78438 m .47284 .78027 L .47023 .7767 L p F P
0 g
s
.521 .43 .693 r
.56993 .74531 m .56731 .74471 L .56951 .74358 L closepath p F P
0 g
s
.525 .418 .675 r
.56804 .73761 m .56951 .74358 L .56731 .74471 L p F P
0 g
s
.976 .853 .655 r
.4139 .73148 m .41237 .72867 L .41041 .73377 L p F P
0 g
s
.976 .853 .655 r
.41041 .73377 m .41192 .73658 L .4139 .73148 L p F P
0 g
s
.964 .892 .708 r
.41678 .71903 m .41718 .71826 L .41606 .7153 L p F P
0 g
s
.204 .207 .64 r
.56743 .70237 m .56589 .70504 L .56835 .70888 L p F P
0 g
s
.198 .201 .637 r
.56663 .69884 m .56587 .69729 L p .56589 .70504 L F P
0 g
s
.198 .201 .637 r
.56589 .70504 m .56743 .70237 L .56663 .69884 L p F P
0 g
s
.234 .238 .658 r
.63891 .73307 m .63777 .73147 L .63831 .7306 L closepath p F P
0 g
s
.27 .283 .69 r
.63777 .73147 m .63831 .7306 L .63658 .7244 L p F P
0 g
s
.94 .787 .664 r
.48434 .71825 m .48202 .71568 L .48003 .72079 L p F P
0 g
s
.94 .787 .664 r
.48003 .72079 m .4824 .72334 L .48434 .71825 L p F P
0 g
s
.378 .341 .691 r
.57125 .72038 m .56678 .72482 L .57089 .72823 L p F P
0 g
s
.427 .342 .657 r
.56805 .71672 m .57125 .72038 L .56678 .72482 L p F P
0 g
s
.65 .757 .928 r
.23831 .55374 m .22943 .55671 L .23245 .55946 L p F P
0 g
s
.65 .757 .928 r
.23245 .55946 m .24132 .55649 L .23831 .55374 L p F P
0 g
s
.651 .758 .928 r
.81439 .55946 m .82429 .55648 L .82634 .55922 L p F P
0 g
s
.651 .758 .928 r
.82429 .55648 m .81439 .55946 L .81232 .55672 L p F P
0 g
s
.201 .385 .822 r
.6079 .67192 m .60771 .67032 L p .6129 .67659 L F P
0 g
s
.205 .404 .837 r
.6079 .67192 m .60665 .66971 L .60771 .67032 L closepath p F P
0 g
s
.65 .757 .928 r
.38428 .55381 m .37514 .55679 L .37793 .55954 L p F P
0 g
s
.65 .757 .928 r
.37793 .55954 m .38706 .55657 L .38428 .55381 L p F P
0 g
s
.651 .758 .928 r
.66891 .55954 m .67855 .55656 L .68084 .55931 L p F P
0 g
s
.651 .758 .928 r
.67855 .55656 m .66891 .55954 L .6666 .55679 L p F P
0 g
s
.651 .757 .928 r
.53027 .55383 m .52087 .55681 L .52342 .55955 L p F P
0 g
s
.651 .757 .928 r
.52342 .55955 m .5328 .55658 L .53027 .55383 L p F P
0 g
s
0 0 0 r
.49043 .67188 m .4923 .66799 L .49069 .67295 L p F P
0 g
s
0 0 0 r
.49069 .67295 m .48922 .67671 L .49043 .67188 L p F P
0 g
s
.649 .756 .928 r
.10425 .55325 m .09561 .5562 L .09885 .55896 L p F P
0 g
s
.649 .756 .928 r
.09885 .55896 m .10748 .55602 L .10425 .55325 L p F P
0 g
s
.91 .959 .809 r
.43849 .67848 m .43383 .68433 L .43373 .68101 L p F P
0 g
s
.91 .959 .809 r
.43844 .67678 m .43849 .67848 L p .43373 .68101 L F P
0 g
s
.581 .53 .762 r
.5801 .7773 m .57656 .7776 L .57972 .77628 L closepath p F P
0 g
s
.58 .518 .75 r
.57758 .77061 m .57972 .77628 L .57656 .7776 L p F P
0 g
s
.58 .518 .75 r
.5735 .77074 m .57758 .77061 L p .57656 .7776 L F P
0 g
s
0 .06 .575 r
.56358 .68508 m .56406 .68227 L p .56524 .6897 L F P
0 g
s
0 .06 .575 r
.56524 .6897 m .56405 .68713 L .56358 .68508 L p F P
0 g
s
0 0 .506 r
.56358 .68508 m .56406 .68227 L .56254 .67821 L p F P
0 g
s
.159 .093 .527 r
.64184 .74752 m .63905 .75115 L .64006 .75551 L p F P
0 g
s
.218 .174 .592 r
.64164 .74631 m .64029 .7431 L p .63905 .75115 L F P
0 g
s
.218 .174 .592 r
.63905 .75115 m .64184 .74752 L .64164 .74631 L p F P
0 g
s
.869 .73 .707 r
.47869 .74902 m .48239 .75114 L .47932 .75658 L p F P
0 g
s
.86 .721 .707 r
.48239 .75114 m .47869 .74902 L .48165 .74361 L p F P
0 g
s
.867 .735 .714 r
.48165 .74361 m .48397 .73947 L .48184 .73638 L p F P
0 g
s
.444 .38 .691 r
.56804 .73761 m .56736 .73485 L .56978 .73629 L closepath p F P
0 g
s
.926 .923 .788 r
.42151 .70141 m .42171 .70238 L .42362 .70248 L p F P
0 g
s
.939 .907 .762 r
.42171 .70238 m .42362 .70248 L .42233 .70447 L closepath p F P
0 g
s
.964 .892 .708 r
.41606 .7153 m .41397 .71927 L .41678 .71903 L p F P
0 g
s
.963 .884 .706 r
.41678 .71903 m .41462 .72351 L .41329 .72062 L p F P
0 g
s
.963 .884 .706 r
.41329 .72062 m .41397 .71927 L .41678 .71903 L p F P
0 g
s
.798 .83 .359 r
.48753 .685 m .48602 .68993 L .4862 .68658 L p F P
0 g
s
.798 .83 .359 r
.48788 .6822 m .48753 .685 L p .4862 .68658 L F P
0 g
s
.651 .758 .928 r
.82634 .55922 m .83626 .55624 L .8383 .55898 L p F P
0 g
s
.651 .758 .928 r
.83626 .55624 m .82634 .55922 L .82429 .55648 L p F P
0 g
s
.65 .757 .928 r
.25022 .55352 m .24132 .55649 L .24432 .55924 L p F P
0 g
s
.65 .757 .928 r
.24432 .55924 m .25321 .55628 L .25022 .55352 L p F P
0 g
s
.21 .589 .945 r
.43952 .79068 m .43963 .79071 L .43694 .78851 L p F P
0 g
s
.21 .589 .945 r
.43694 .78851 m .4365 .78841 L .43952 .79068 L p F P
0 g
s
.576 .583 .822 r
.58305 .78407 m .58261 .78318 L .58502 .78299 L closepath p F P
0 g
s
.651 .758 .928 r
.68084 .55931 m .69051 .55633 L .69278 .55907 L p F P
0 g
s
.651 .758 .928 r
.69051 .55633 m .68084 .55931 L .67855 .55656 L p F P
0 g
s
.65 .757 .928 r
.39622 .55358 m .38706 .55657 L .38982 .55931 L p F P
0 g
s
.65 .757 .928 r
.38982 .55931 m .39897 .55634 L .39622 .55358 L p F P
0 g
s
.651 .757 .928 r
.54222 .5536 m .5328 .55658 L .53533 .55932 L p F P
0 g
s
.651 .757 .928 r
.53533 .55932 m .54474 .55635 L .54222 .5536 L p F P
0 g
s
.565 .774 .977 r
.45152 .7911 m .44885 .78859 L .43963 .79071 L p F P
0 g
s
.628 .761 .943 r
.44885 .78859 m .43963 .79071 L .43694 .78851 L p F P
0 g
s
.649 .756 .928 r
.11615 .55306 m .10748 .55602 L .1107 .55877 L p F P
0 g
s
.649 .756 .928 r
.1107 .55877 m .11936 .55582 L .11615 .55306 L p F P
0 g
s
.988 .806 .57 r
.41202 .74431 m .41092 .74917 L .40906 .74648 L p F P
0 g
s
.988 .806 .57 r
.41108 .74295 m .41202 .74431 L p .40906 .74648 L F P
0 g
s
.568 .503 .743 r
.57758 .77061 m .5735 .77074 L .57709 .76917 L closepath p F P
0 g
s
.568 .492 .729 r
.57504 .7631 m .57709 .76917 L .5735 .77074 L p F P
0 g
s
.568 .492 .729 r
.57346 .76304 m .57504 .7631 L p .5735 .77074 L F P
0 g
s
.23 .298 .727 r
.63453 .71786 m .63378 .71568 L .63495 .71681 L closepath p F P
0 g
s
.233 .281 .707 r
.63453 .71786 m .63495 .71681 L p .63675 .72404 L F P
0 g
s
.233 .281 .707 r
.63675 .72404 m .63632 .72358 L .63453 .71786 L p F P
0 g
s
.852 .722 .719 r
.47966 .7647 m .48001 .76412 L .4789 .76351 L closepath p F P
0 g
s
.853 .722 .717 r
.47706 .76061 m .47932 .75658 L p .48001 .76412 L F P
0 g
s
.853 .722 .717 r
.48001 .76412 m .4789 .76351 L .47706 .76061 L p F P
0 g
s
.036 .083 .581 r
.56484 .69082 m .56405 .68713 L .56524 .6897 L closepath p F P
0 g
s
.651 .758 .928 r
.8383 .55898 m .84824 .55599 L .85025 .55874 L p F P
0 g
s
.651 .758 .928 r
.84824 .55599 m .8383 .55898 L .83626 .55624 L p F P
0 g
s
.233 .281 .707 r
.63658 .7244 m .63632 .72358 L .63675 .72404 L closepath p F P
0 g
s
.188 .228 .672 r
.63675 .72404 m .63658 .7244 L .63831 .7306 L p F P
0 g
s
.65 .757 .928 r
.26214 .5533 m .25321 .55628 L .2562 .55902 L p F P
0 g
s
.65 .757 .928 r
.2562 .55902 m .26511 .55606 L .26214 .5533 L p F P
0 g
s
.443 .379 .691 r
.56978 .73629 m .56804 .73761 L .56951 .74358 L p F P
0 g
s
.23 .298 .727 r
.63495 .71681 m .63378 .71568 L .63217 .711 L p F P
0 g
s
.046 0 .356 r
.63711 .76428 m .63715 .764 L .63712 .76403 L closepath p F P
0 g
s
.651 .758 .928 r
.69278 .55907 m .70246 .5561 L .70472 .55884 L p F P
0 g
s
.651 .758 .928 r
.70246 .5561 m .69278 .55907 L .69051 .55633 L p F P
0 g
s
.65 .757 .928 r
.40816 .55336 m .39897 .55634 L .40172 .55908 L p F P
0 g
s
.65 .757 .928 r
.40172 .55908 m .41089 .55611 L .40816 .55336 L p F P
0 g
s
.832 .373 0 r
.4225 .77978 m .42114 .77724 L .41852 .77483 L p F P
0 g
s
.651 .757 .928 r
.55418 .55337 m .54474 .55635 L .54725 .55909 L p F P
0 g
s
.651 .757 .928 r
.54725 .55909 m .55668 .55612 L .55418 .55337 L p F P
0 g
s
.578 .553 .79 r
.58502 .78299 m .58261 .78318 L .5801 .7773 L p F P
0 g
s
.816 .716 .755 r
.47537 .77001 m .47966 .7647 L .4789 .76351 L p F P
0 g
s
0 0 .252 r
.63715 .764 m .64026 .7601 L p .63687 .76823 L F P
0 g
s
0 0 .252 r
.63687 .76823 m .63711 .76428 L .63715 .764 L p F P
0 g
s
.127 .023 .456 r
.64006 .75551 m .64026 .7601 L .63715 .764 L p F P
0 g
s
.926 .541 .177 r
.41727 .7706 m .41484 .76812 L .41607 .77236 L p F P
0 g
s
.926 .541 .177 r
.41607 .77236 m .41852 .77483 L .41727 .7706 L p F P
0 g
s
.951 .917 .742 r
.42233 .70447 m .41911 .70991 L .41819 .70688 L p F P
0 g
s
.951 .917 .742 r
.42171 .70238 m .42233 .70447 L p .41819 .70688 L F P
0 g
s
.996 .855 .578 r
.48554 .69786 m .48448 .69489 L .48289 .69986 L p F P
0 g
s
.996 .855 .578 r
.48289 .69986 m .48411 .70278 L .48554 .69786 L p F P
0 g
s
.649 .756 .928 r
.12804 .55286 m .11936 .55582 L .12256 .55858 L p F P
0 g
s
.649 .756 .928 r
.12256 .55858 m .13124 .55563 L .12804 .55286 L p F P
0 g
s
.916 .755 .667 r
.48327 .73085 m .48137 .7357 L .47876 .73278 L p F P
0 g
s
.916 .755 .667 r
.47876 .73278 m .48044 .72845 L .48327 .73085 L p F P
0 g
s
.917 .754 .665 r
.48327 .73085 m .48044 .72845 L .4824 .72334 L p F P
0 g
s
.101 0 .355 r
.63616 .76892 m .63687 .76823 L .63711 .76428 L closepath p F P
0 g
s
.6 .778 .966 r
.59707 .79075 m .6066 .7887 L .609 .79088 L p F P
0 g
s
.591 .65 .877 r
.60417 .78566 m .6066 .7887 L .59707 .79075 L p F P
0 g
s
.591 .65 .877 r
.60308 .78581 m .60417 .78566 L p .59707 .79075 L F P
0 g
s
.591 .65 .877 r
.59707 .79075 m .59656 .78997 L .60308 .78581 L p F P
0 g
s
.23 .298 .727 r
.63217 .711 m .63258 .70974 L p .63495 .71681 L F P
0 g
s
.227 .315 .746 r
.63217 .711 m .63127 .70858 L .63258 .70974 L closepath p F P
0 g
s
.651 .758 .928 r
.85025 .55874 m .86022 .55575 L .86221 .55849 L p F P
0 g
s
.651 .758 .928 r
.86022 .55575 m .85025 .55874 L .84824 .55599 L p F P
0 g
s
.65 .757 .928 r
.27406 .55308 m .26511 .55606 L .26808 .5588 L p F P
0 g
s
.65 .757 .928 r
.26808 .5588 m .27701 .55583 L .27406 .55308 L p F P
0 g
s
.651 .758 .928 r
.70472 .55884 m .71443 .55586 L .71666 .55861 L p F P
0 g
s
.651 .758 .928 r
.71443 .55586 m .70472 .55884 L .70246 .5561 L p F P
0 g
s
.65 .757 .928 r
.4201 .55313 m .41089 .55611 L .41362 .55886 L p F P
0 g
s
.65 .757 .928 r
.41362 .55886 m .42282 .55588 L .4201 .55313 L p F P
0 g
s
.651 .757 .928 r
.56614 .55314 m .55668 .55612 L .55917 .55887 L p F P
0 g
s
.651 .757 .928 r
.55917 .55887 m .56862 .55589 L .56614 .55314 L p F P
0 g
s
.65 .757 .928 r
.13994 .55266 m .13124 .55563 L .13442 .55838 L p F P
0 g
s
.65 .757 .928 r
.13442 .55838 m .14312 .55543 L .13994 .55266 L p F P
0 g
s
.769 .786 .867 r
.45333 .78996 m .45152 .7911 L .44885 .78859 L p F P
0 g
s
.188 .228 .672 r
.63831 .7306 m .6396 .72784 L .63675 .72404 L p F P
0 g
s
.167 .223 .677 r
.63815 .72051 m .63675 .72404 L .6396 .72784 L p F P
0 g
s
.233 .281 .707 r
.63495 .71681 m .63815 .72051 L .63675 .72404 L p F P
0 g
s
.651 .758 .928 r
.86221 .55849 m .8722 .5555 L .87418 .55824 L p F P
0 g
s
.651 .758 .928 r
.8722 .5555 m .86221 .55849 L .86022 .55575 L p F P
0 g
s
.971 .655 .336 r
.41438 .76368 m .41214 .76113 L .41258 .76558 L p F P
0 g
s
.971 .655 .336 r
.41258 .76558 m .41484 .76812 L .41438 .76368 L p F P
0 g
s
.226 .315 .746 r
.63258 .70974 m .63127 .70858 L .62945 .70375 L p F P
0 g
s
.904 .949 .822 r
.43383 .68433 m .43373 .68101 L .4291 .68686 L p F P
0 g
s
.904 .949 .822 r
.43038 .68871 m .43383 .68433 L p .4291 .68686 L F P
0 g
s
.188 .206 .648 r
.63831 .7306 m .6396 .72784 L p .6404 .73535 L F P
0 g
s
.188 .206 .648 r
.6404 .73535 m .63891 .73307 L .63831 .7306 L p F P
0 g
s
.65 .757 .928 r
.28598 .55285 m .27701 .55583 L .27996 .55858 L p F P
0 g
s
.65 .757 .928 r
.27996 .55858 m .28892 .55561 L .28598 .55285 L p F P
0 g
s
.651 .758 .928 r
.71666 .55861 m .72639 .55563 L .72861 .55838 L p F P
0 g
s
.651 .758 .928 r
.72639 .55563 m .71666 .55861 L .71443 .55586 L p F P
0 g
s
.65 .757 .928 r
.43204 .5529 m .42282 .55588 L .42552 .55863 L p F P
0 g
s
.65 .757 .928 r
.42552 .55863 m .43474 .55566 L .43204 .5529 L p F P
0 g
s
.183 .403 .842 r
.60771 .67032 m .60665 .66971 L .6042 .66555 L p F P
0 g
s
.651 .757 .928 r
.57811 .5529 m .56862 .55589 L .57109 .55864 L p F P
0 g
s
.651 .757 .928 r
.57109 .55864 m .58057 .55566 L .57811 .5529 L p F P
0 g
s
.028 .08 .581 r
.56524 .6897 m .56484 .69082 L .56612 .69658 L p F P
0 g
s
.028 .081 .583 r
.56587 .69729 m .56612 .69658 L .56484 .69082 L p F P
0 g
s
.595 .867 .994 r
.61418 .78886 m .609 .79088 L .6066 .7887 L p F P
0 g
s
.007 .453 .868 r
.4365 .78841 m .4336 .78609 L .42686 .78337 L p F P
0 g
s
.035 .464 .879 r
.42402 .78103 m .42686 .78337 L .4336 .78609 L p F P
0 g
s
.464 0 0 r
.4225 .77978 m .42402 .78103 L .42686 .78337 L p F P
0 g
s
.65 .757 .928 r
.15185 .55246 m .14312 .55543 L .14628 .55818 L p F P
0 g
s
.65 .757 .928 r
.14628 .55818 m .155 .55523 L .15185 .55246 L p F P
0 g
s
.592 .653 .879 r
.59656 .78997 m .59461 .78698 L .60308 .78581 L closepath p F P
0 g
s
.816 .716 .755 r
.4789 .76351 m .47588 .76213 L p .47537 .77001 L F P
0 g
s
.821 .716 .75 r
.4789 .76351 m .47706 .76061 L .47588 .76213 L closepath p F P
0 g
s
.769 .786 .867 r
.44885 .78859 m .45011 .78774 L .45333 .78996 L p F P
0 g
s
.744 .761 .867 r
.4582 .78259 m .45011 .78774 L .45333 .78996 L p F P
0 g
s
.744 .761 .867 r
.45333 .78996 m .46084 .78549 L .4582 .78259 L p F P
0 g
s
.966 .836 .663 r
.48402 .71058 m .48242 .70779 L .48029 .71293 L p F P
0 g
s
.966 .836 .663 r
.48029 .71293 m .48202 .71568 L .48402 .71058 L p F P
0 g
s
.206 .429 .856 r
.60174 .66429 m .6042 .66555 L .60175 .66158 L p F P
0 g
s
.206 .429 .856 r
.60175 .66158 m .60104 .66121 L .60174 .66429 L p F P
0 g
s
.812 .498 0 r
.56099 .67088 m .55979 .66794 L .55876 .66375 L p F P
0 g
s
.88 .745 .709 r
.47829 .74138 m .48165 .74361 L .47869 .74902 L p F P
0 g
s
.867 .735 .714 r
.48122 .73598 m .47829 .74138 L .48165 .74361 L p F P
0 g
s
.867 .735 .714 r
.48184 .73638 m .48122 .73598 L p .48165 .74361 L F P
0 g
s
.65 .757 .928 r
.29791 .55263 m .28892 .55561 L .29185 .55836 L p F P
0 g
s
.65 .757 .928 r
.29185 .55836 m .30083 .55539 L .29791 .55263 L p F P
0 g
s
.651 .758 .928 r
.72861 .55838 m .73836 .5554 L .74056 .55814 L p F P
0 g
s
.651 .758 .928 r
.73836 .5554 m .72861 .55838 L .72639 .55563 L p F P
0 g
s
.65 .757 .928 r
.44399 .55267 m .43474 .55566 L .43743 .5584 L p F P
0 g
s
.65 .757 .928 r
.43743 .5584 m .44667 .55543 L .44399 .55267 L p F P
0 g
s
.651 .757 .928 r
.59008 .55267 m .58057 .55566 L .58302 .55841 L p F P
0 g
s
.651 .757 .928 r
.58302 .55841 m .59252 .55543 L .59008 .55267 L p F P
0 g
s
.036 .091 .59 r
.56663 .69884 m .56587 .69729 L .56612 .69658 L closepath p F P
0 g
s
.484 .406 .693 r
.56951 .74358 m .57501 .73942 L p .57464 .74727 L F P
0 g
s
.484 .406 .693 r
.57464 .74727 m .56993 .74531 L .56951 .74358 L p F P
0 g
s
.443 .379 .691 r
.56951 .74358 m .57501 .73942 L .56978 .73629 L p F P
0 g
s
.843 .747 .758 r
.47148 .76796 m .47537 .77001 L .47086 .77587 L p F P
0 g
s
.816 .716 .755 r
.47588 .76213 m .47148 .76796 L .47537 .77001 L p F P
0 g
s
.187 .206 .648 r
.63976 .73653 m .63891 .73307 L .6404 .73535 L closepath p F P
0 g
s
.65 .757 .928 r
.16376 .55226 m .155 .55523 L .15815 .55798 L p F P
0 g
s
.65 .757 .928 r
.15815 .55798 m .16689 .55502 L .16376 .55226 L p F P
0 g
s
.226 .315 .746 r
.62945 .70375 m .62969 .70281 L p .63258 .70974 L F P
0 g
s
.224 .333 .765 r
.62945 .70375 m .62877 .70208 L .62969 .70281 L closepath p F P
0 g
s
.65 .757 .928 r
.30984 .55241 m .30083 .55539 L .30374 .55814 L p F P
0 g
s
.65 .757 .928 r
.30374 .55814 m .31274 .55517 L .30984 .55241 L p F P
0 g
s
.651 .758 .928 r
.74056 .55814 m .75033 .55516 L .75251 .55791 L p F P
0 g
s
.651 .758 .928 r
.75033 .55516 m .74056 .55814 L .73836 .5554 L p F P
0 g
s
.473 .414 .711 r
.57114 .74972 m .56993 .74531 L .57464 .74727 L closepath p F P
0 g
s
.65 .757 .928 r
.45594 .55244 m .44667 .55543 L .44934 .55818 L p F P
0 g
s
.65 .757 .928 r
.44934 .55818 m .4586 .5552 L .45594 .55244 L p F P
0 g
s
.651 .757 .928 r
.60205 .55244 m .59252 .55543 L .59495 .55818 L p F P
0 g
s
.651 .757 .928 r
.59495 .55818 m .60447 .5552 L .60205 .55244 L p F P
0 g
s
.869 .73 .707 r
.47932 .75658 m .47706 .76061 L .47446 .75692 L p F P
0 g
s
.869 .73 .707 r
.47446 .75692 m .4758 .75441 L .47932 .75658 L p F P
0 g
s
.869 .73 .707 r
.47932 .75658 m .4758 .75441 L .47869 .74902 L p F P
0 g
s
.973 .872 .674 r
.41462 .72351 m .41329 .72062 L .41105 .72579 L p F P
0 g
s
.973 .872 .674 r
.41105 .72579 m .41237 .72867 L .41462 .72351 L p F P
0 g
s
.577 .574 .813 r
.59213 .78246 m .58502 .78299 L .59093 .77992 L closepath p F P
0 g
s
.578 .553 .79 r
.58964 .77723 m .59093 .77992 L .58502 .78299 L p F P
0 g
s
.578 .553 .79 r
.5801 .7773 m .58964 .77723 L p .58502 .78299 L F P
0 g
s
.987 .727 .439 r
.41231 .75653 m .41025 .75391 L .41007 .75852 L p F P
0 g
s
.987 .727 .439 r
.41007 .75852 m .41214 .76113 L .41231 .75653 L p F P
0 g
s
.54 .506 .767 r
.58738 .77189 m .58964 .77723 L .5801 .7773 L p F P
0 g
s
.54 .506 .767 r
.5801 .7773 m .57972 .77628 L .58738 .77189 L p F P
0 g
s
.904 .949 .822 r
.4291 .68686 m .42911 .68868 L .43038 .68871 L p F P
0 g
s
.922 .934 .796 r
.42911 .68868 m .43038 .68871 L .4293 .69014 L closepath p F P
0 g
s
.173 .251 .705 r
.63607 .71334 m .63495 .71681 L .63815 .72051 L p F P
0 g
s
.23 .298 .727 r
.63258 .70974 m .63607 .71334 L .63495 .71681 L p F P
0 g
s
.65 .757 .928 r
.17567 .55205 m .16689 .55502 L .17002 .55777 L p F P
0 g
s
.65 .757 .928 r
.17002 .55777 m .17879 .55481 L .17567 .55205 L p F P
0 g
s
.539 .508 .77 r
.58713 .7713 m .58738 .77189 L .57972 .77628 L p F P
0 g
s
.539 .508 .77 r
.57972 .77628 m .57758 .77061 L .58713 .7713 L p F P
0 g
s
.221 .332 .766 r
.62969 .70281 m .62877 .70208 L .6263 .69604 L p F P
0 g
s
.554 .479 .725 r
.57504 .7631 m .57346 .76304 L .57484 .76242 L closepath p F P
0 g
s
.555 .467 .71 r
.57288 .75596 m .57484 .76242 L .57346 .76304 L p F P
0 g
s
.651 .758 .928 r
.75251 .55791 m .76231 .55492 L .76446 .55767 L p F P
0 g
s
.651 .758 .928 r
.76231 .55492 m .75251 .55791 L .75033 .55516 L p F P
0 g
s
.986 .847 .621 r
.41192 .73658 m .41041 .73377 L .40876 .73878 L p F P
0 g
s
.986 .847 .621 r
.40876 .73878 m .41025 .74159 L .41192 .73658 L p F P
0 g
s
.65 .757 .928 r
.32178 .55218 m .31274 .55517 L .31563 .55792 L p F P
0 g
s
.65 .757 .928 r
.31563 .55792 m .32466 .55494 L .32178 .55218 L p F P
0 g
s
.938 .785 .665 r
.4824 .72334 m .48003 .72079 L .47804 .72591 L p F P
0 g
s
.938 .785 .665 r
.47804 .72591 m .48044 .72845 L .4824 .72334 L p F P
0 g
s
.31 .286 .67 r
.57015 .71408 m .56805 .71672 L .57125 .72038 L p F P
0 g
s
.307 .284 .669 r
.56922 .71019 m .56835 .70888 L p .56805 .71672 L F P
0 g
s
.307 .284 .669 r
.56805 .71672 m .57015 .71408 L .56922 .71019 L p F P
0 g
s
.651 .757 .928 r
.61402 .55221 m .60447 .5552 L .60688 .55795 L p F P
0 g
s
.651 .757 .928 r
.60688 .55795 m .61643 .55497 L .61402 .55221 L p F P
0 g
s
.65 .757 .928 r
.4679 .55221 m .4586 .5552 L .46125 .55795 L p F P
0 g
s
.65 .757 .928 r
.46125 .55795 m .47054 .55497 L .4679 .55221 L p F P
0 g
s
.138 .147 .605 r
.6404 .73535 m .63976 .73653 L .64094 .74217 L p F P
0 g
s
.231 .211 .629 r
.64029 .7431 m .64094 .74217 L .63976 .73653 L p F P
0 g
s
.937 .577 .174 r
.55672 .66104 m .55876 .66375 L .55979 .66794 L p F P
0 g
s
.507 .434 .709 r
.57114 .74972 m .57464 .74727 L p .57414 .75514 L F P
0 g
s
.507 .434 .709 r
.57414 .75514 m .57249 .75469 L .57114 .74972 L p F P
0 g
s
.186 .152 .584 r
.64164 .74631 m .64029 .7431 L .64094 .74217 L closepath p F P
0 g
s
.201 .385 .822 r
.60771 .67032 m .61255 .67344 L .6129 .67659 L p F P
0 g
s
.147 .376 .829 r
.607 .66726 m .60771 .67032 L .61255 .67344 L p F P
0 g
s
.183 .403 .842 r
.6042 .66555 m .607 .66726 L .60771 .67032 L p F P
0 g
s
.931 .947 .779 r
.4293 .69014 m .42536 .69578 L .42494 .69258 L p F P
0 g
s
.931 .947 .779 r
.42911 .68868 m .4293 .69014 L p .42494 .69258 L F P
0 g
s
.65 .757 .928 r
.18758 .55184 m .17879 .55481 L .18189 .55757 L p F P
0 g
s
.65 .757 .928 r
.18189 .55757 m .19068 .5546 L .18758 .55184 L p F P
0 g
s
.869 .734 .711 r
.48184 .73638 m .48137 .7357 L .48122 .73598 L closepath p F P
0 g
s
.651 .758 .928 r
.76446 .55767 m .77429 .55469 L .77642 .55744 L p F P
0 g
s
.651 .758 .928 r
.77429 .55469 m .76446 .55767 L .76231 .55492 L p F P
0 g
s
.65 .757 .928 r
.33372 .55196 m .32466 .55494 L .32753 .55769 L p F P
0 g
s
.65 .757 .928 r
.32753 .55769 m .33657 .55472 L .33372 .55196 L p F P
0 g
s
.957 .908 .729 r
.41911 .70991 m .41819 .70688 L .41516 .71227 L p F P
0 g
s
.957 .908 .729 r
.41516 .71227 m .41606 .7153 L .41911 .70991 L p F P
0 g
s
.651 .757 .928 r
.626 .55198 m .61643 .55497 L .61882 .55772 L p F P
0 g
s
.651 .757 .928 r
.61882 .55772 m .62838 .55474 L .626 .55198 L p F P
0 g
s
.651 .757 .928 r
.47986 .55198 m .47054 .55497 L .47317 .55772 L p F P
0 g
s
.651 .757 .928 r
.47317 .55772 m .48248 .55474 L .47986 .55198 L p F P
0 g
s
.989 .817 .578 r
.40966 .74392 m .41025 .74159 L .41108 .74295 L closepath p F P
0 g
s
.988 .806 .57 r
.40906 .74648 m .40966 .74392 L .41108 .74295 L p F P
0 g
s
.896 .967 .824 r
.43709 .67687 m .43864 .67508 L .43844 .67678 L closepath p F P
0 g
s
.91 .959 .809 r
.43373 .68101 m .43709 .67687 L .43844 .67678 L p F P
0 g
s
.427 .384 .707 r
.57464 .73209 m .56978 .73629 L .57501 .73942 L p F P
0 g
s
.458 .376 .675 r
.57438 .73114 m .57464 .73209 L .56978 .73629 L p F P
0 g
s
.458 .376 .675 r
.57089 .72823 m .57438 .73114 L p .56978 .73629 L F P
0 g
s
.154 .172 .626 r
.56612 .69658 m .56711 .69369 L p .56802 .70121 L F P
0 g
s
.154 .172 .626 r
.56802 .70121 m .56663 .69884 L .56612 .69658 L p F P
0 g
s
.028 .08 .581 r
.56612 .69658 m .56711 .69369 L .56524 .6897 L p F P
0 g
s
0 0 0 r
.48922 .67671 m .49069 .67295 L .48901 .67793 L p F P
0 g
s
0 0 0 r
.48901 .67793 m .48789 .68159 L .48922 .67671 L p F P
0 g
s
.945 .882 .476 r
.48602 .68993 m .4862 .68658 L .48435 .69163 L p F P
0 g
s
.945 .882 .476 r
.48435 .69163 m .48448 .69489 L .48602 .68993 L p F P
0 g
s
.65 .757 .928 r
.1995 .55162 m .19068 .5546 L .19377 .55735 L p F P
0 g
s
.65 .757 .928 r
.19377 .55735 m .20258 .55439 L .1995 .55162 L p F P
0 g
s
.171 .273 .728 r
.63342 .70633 m .63258 .70974 L .63607 .71334 L p F P
0 g
s
.226 .315 .746 r
.62969 .70281 m .63342 .70633 L .63258 .70974 L p F P
0 g
s
.651 .758 .928 r
.77642 .55744 m .78627 .55445 L .78838 .5572 L p F P
0 g
s
.651 .758 .928 r
.78627 .55445 m .77642 .55744 L .77429 .55469 L p F P
0 g
s
.842 .747 .759 r
.47023 .7767 m .47086 .77587 L .4685 .77447 L closepath p F P
0 g
s
.843 .747 .758 r
.46761 .7733 m .47148 .76796 L p .47086 .77587 L F P
0 g
s
.843 .747 .758 r
.47086 .77587 m .4685 .77447 L .46761 .7733 L p F P
0 g
s
.65 .757 .928 r
.34566 .55173 m .33657 .55472 L .33942 .55747 L p F P
0 g
s
.65 .757 .928 r
.33942 .55747 m .3485 .55449 L .34566 .55173 L p F P
0 g
s
.651 .757 .928 r
.63798 .55175 m .62838 .55474 L .63076 .55749 L p F P
0 g
s
.651 .757 .928 r
.63076 .55749 m .64035 .55451 L .63798 .55175 L p F P
0 g
s
.651 .757 .928 r
.49182 .55175 m .48248 .55474 L .48509 .55749 L p F P
0 g
s
.651 .757 .928 r
.48509 .55749 m .49442 .55451 L .49182 .55175 L p F P
0 g
s
.498 .447 .73 r
.57288 .75596 m .57249 .75469 L .57414 .75514 L closepath p F P
0 g
s
.213 .383 .816 r
.61777 .68295 m .6178 .6797 L .6129 .67659 L p F P
0 g
s
.227 .417 .841 r
.61255 .67344 m .6129 .67659 L .6178 .6797 L p F P
0 g
s
.518 .474 .747 r
.5846 .76468 m .58713 .7713 L .57758 .77061 L p F P
0 g
s
.518 .474 .747 r
.58445 .76466 m .5846 .76468 L p .57758 .77061 L F P
0 g
s
.518 .474 .747 r
.57758 .77061 m .57709 .76917 L .58445 .76466 L p F P
0 g
s
.497 .444 .729 r
.57484 .76242 m .57288 .75596 L .57414 .75514 L p F P
0 g
s
.519 .477 .749 r
.57709 .76917 m .57504 .7631 L .58445 .76466 L closepath p F P
0 g
s
.795 .742 .804 r
.46405 .78237 m .47023 .7767 L .4685 .77447 L p F P
0 g
s
.818 .76 .798 r
.46405 .78237 m .46084 .78549 L .4582 .78259 L p F P
0 g
s
.818 .76 .798 r
.4582 .78259 m .46047 .78025 L .46405 .78237 L p F P
0 g
s
.795 .742 .804 r
.46708 .77379 m .46047 .78025 L .46405 .78237 L p F P
0 g
s
.795 .742 .804 r
.4685 .77447 m .46708 .77379 L p .46405 .78237 L F P
0 g
s
.891 .767 .719 r
.48122 .73598 m .48137 .7357 L .47876 .73278 L p F P
0 g
s
.65 .757 .928 r
.21143 .55141 m .20258 .55439 L .20565 .55714 L p F P
0 g
s
.65 .757 .928 r
.20565 .55714 m .21449 .55417 L .21143 .55141 L p F P
0 g
s
.895 .769 .716 r
.47831 .73361 m .48122 .73598 L .47829 .74138 L p F P
0 g
s
.891 .767 .719 r
.47876 .73278 m .47831 .73361 L .48122 .73598 L p F P
0 g
s
.651 .758 .928 r
.78838 .5572 m .79825 .55421 L .80035 .55696 L p F P
0 g
s
.651 .758 .928 r
.79825 .55421 m .78838 .5572 L .78627 .55445 L p F P
0 g
s
.157 .173 .626 r
.56743 .70237 m .56663 .69884 L .56802 .70121 L closepath p F P
0 g
s
.65 .757 .928 r
.3576 .5515 m .3485 .55449 L .35133 .55724 L p F P
0 g
s
.65 .757 .928 r
.35133 .55724 m .36042 .55426 L .3576 .5515 L p F P
0 g
s
.651 .758 .928 r
.64997 .55151 m .64035 .55451 L .6427 .55726 L p F P
0 g
s
.651 .758 .928 r
.6427 .55726 m .65231 .55427 L .64997 .55151 L p F P
0 g
s
.525 .461 .727 r
.57484 .76242 m .58218 .75768 L p .58445 .76466 L F P
0 g
s
.525 .461 .727 r
.58445 .76466 m .57504 .7631 L .57484 .76242 L p F P
0 g
s
.497 .444 .729 r
.58207 .75736 m .58218 .75768 L .57484 .76242 L p F P
0 g
s
.497 .444 .729 r
.57414 .75514 m .58207 .75736 L p .57484 .76242 L F P
0 g
s
.651 .757 .928 r
.50378 .55153 m .49442 .55451 L .49701 .55727 L p F P
0 g
s
.651 .757 .928 r
.49701 .55727 m .50637 .55429 L .50378 .55153 L p F P
0 g
s
.992 .776 .509 r
.41092 .74917 m .40906 .74648 L .40838 .75123 L p F P
0 g
s
.992 .776 .509 r
.40838 .75123 m .41025 .75391 L .41092 .74917 L p F P
0 g
s
.595 .867 .994 r
.61742 .78659 m .61418 .78886 L p .6066 .7887 L F P
0 g
s
.661 .909 .979 r
.61418 .78886 m .61742 .78659 L .61851 .78706 L closepath p F P
0 g
s
.163 .289 .747 r
.63024 .69947 m .62969 .70281 L .63342 .70633 L p F P
0 g
s
.221 .332 .766 r
.62631 .69602 m .63024 .69947 L .62969 .70281 L p F P
0 g
s
.221 .332 .766 r
.6263 .69604 m .62631 .69602 L p .62969 .70281 L F P
0 g
s
.263 .405 .818 r
.62135 .68533 m .61777 .68295 L p .62226 .68942 L F P
0 g
s
.189 .36 .804 r
.61777 .68295 m .62135 .68533 L .61889 .68046 L p F P
0 g
s
.189 .36 .804 r
.61889 .68046 m .6178 .6797 L .61777 .68295 L p F P
0 g
s
0 .105 .595 r
.4225 .77978 m .42402 .78103 L .42144 .7786 L p F P
0 g
s
.832 .373 0 r
.41852 .77483 m .41979 .77723 L .4225 .77978 L p F P
0 g
s
0 .105 .595 r
.42144 .7786 m .41979 .77723 L .4225 .77978 L p F P
0 g
s
.99 .856 .611 r
.48411 .70278 m .48289 .69986 L .48126 .70485 L p F P
0 g
s
.99 .856 .611 r
.4831 .70616 m .48411 .70278 L p .48126 .70485 L F P
0 g
s
0 0 .166 r
.49383 .66307 m .49408 .66275 L .49338 .66658 L p F P
0 g
s
0 0 .166 r
.49338 .66658 m .4923 .66799 L .49383 .66307 L p F P
0 g
s
.831 .734 .757 r
.47588 .76213 m .47706 .76061 L .47446 .75692 L p F P
0 g
s
0 0 .143 r
.63687 .76823 m .63616 .76892 L .63354 .7743 L p F P
0 g
s
.65 .757 .928 r
.22335 .55119 m .21449 .55417 L .21754 .55693 L p F P
0 g
s
.65 .757 .928 r
.21754 .55693 m .22639 .55396 L .22335 .55119 L p F P
0 g
s
.886 .751 .708 r
.47545 .74676 m .47869 .74902 L .4758 .75441 L p F P
0 g
s
.88 .745 .709 r
.47869 .74902 m .47545 .74676 L .47829 .74138 L p F P
0 g
s
.651 .758 .928 r
.80035 .55696 m .81024 .55397 L .81232 .55672 L p F P
0 g
s
.651 .758 .928 r
.81024 .55397 m .80035 .55696 L .79825 .55421 L p F P
0 g
s
.221 .35 .783 r
.6263 .69604 m .62629 .69601 L .62631 .69602 L closepath p F P
0 g
s
.65 .757 .928 r
.36955 .55128 m .36042 .55426 L .36323 .55702 L p F P
0 g
s
.65 .757 .928 r
.36323 .55702 m .37235 .55404 L .36955 .55128 L p F P
0 g
s
.651 .758 .928 r
.66196 .55128 m .65231 .55427 L .65465 .55703 L p F P
0 g
s
.651 .758 .928 r
.65465 .55703 m .66428 .55404 L .66196 .55128 L p F P
0 g
s
.212 .354 .791 r
.62382 .69054 m .62226 .68942 L .62248 .68761 L closepath p F P
0 g
s
.263 .405 .818 r
.62226 .68942 m .62248 .68761 L .62135 .68533 L p F P
0 g
s
.209 .349 .787 r
.62631 .69602 m .62629 .69601 L .62382 .69054 L p F P
0 g
s
.651 .757 .928 r
.51575 .55129 m .50637 .55429 L .50894 .55704 L p F P
0 g
s
.651 .757 .928 r
.50894 .55704 m .51832 .55406 L .51575 .55129 L p F P
0 g
s
.149 .3 .763 r
.62657 .69274 m .62631 .69602 L .63024 .69947 L p F P
0 g
s
.209 .349 .787 r
.62382 .69054 m .62657 .69274 L .62631 .69602 L p F P
0 g
s
.849 .75 .753 r
.47214 .76003 m .47588 .76213 L .47148 .76796 L p F P
0 g
s
.831 .734 .757 r
.47446 .75692 m .47214 .76003 L .47588 .76213 L p F P
0 g
s
.085 0 .443 r
.64238 .75252 m .64006 .75551 L .64026 .7601 L p F P
0 g
s
.159 .093 .527 r
.64006 .75551 m .64238 .75252 L .64184 .74752 L p F P
0 g
s
.596 .615 .841 r
.60308 .78581 m .59461 .78698 L .59213 .78246 L p F P
0 g
s
.65 .757 .928 r
.23528 .55097 m .22639 .55396 L .22943 .55671 L p F P
0 g
s
.65 .757 .928 r
.22943 .55671 m .23831 .55374 L .23528 .55097 L p F P
0 g
s
.651 .758 .928 r
.81232 .55672 m .82223 .55373 L .82429 .55648 L p F P
0 g
s
.651 .758 .928 r
.82223 .55373 m .81232 .55672 L .81024 .55397 L p F P
0 g
s
.092 0 .265 r
.49408 .66275 m .49946 .65803 L .4973 .66315 L p F P
0 g
s
.092 0 .265 r
.4973 .66315 m .49338 .66658 L .49408 .66275 L p F P
0 g
s
.128 .112 .569 r
.64094 .74217 m .64242 .73941 L p .642 .74726 L F P
0 g
s
.128 .112 .569 r
.642 .74726 m .64164 .74631 L .64094 .74217 L p F P
0 g
s
.138 .147 .605 r
.64094 .74217 m .64242 .73941 L .6404 .73535 L p F P
0 g
s
.65 .757 .928 r
.3815 .55105 m .37235 .55404 L .37514 .55679 L p F P
0 g
s
.65 .757 .928 r
.37514 .55679 m .38428 .55381 L .3815 .55105 L p F P
0 g
s
.651 .758 .928 r
.6666 .55679 m .67625 .55381 L .67855 .55656 L p F P
0 g
s
.651 .758 .928 r
.67395 .55105 m .66428 .55404 L .6666 .55679 L p F P
0 g
s
.651 .758 .928 r
.6666 .55679 m .67625 .55381 L .67395 .55105 L p F P
0 g
s
.962 .827 .663 r
.48202 .71568 m .48029 .71293 L .47819 .71808 L p F P
0 g
s
.962 .827 .663 r
.47819 .71808 m .48003 .72079 L .48202 .71568 L p F P
0 g
s
.651 .757 .928 r
.52772 .55106 m .51832 .55406 L .52087 .55681 L p F P
0 g
s
.651 .757 .928 r
.52087 .55681 m .53027 .55383 L .52772 .55106 L p F P
0 g
s
.845 .983 .865 r
.45017 .66272 m .45144 .65895 L .44498 .66535 L p F P
0 g
s
.845 .983 .865 r
.44653 .66636 m .45017 .66272 L p .44498 .66535 L F P
0 g
s
.649 .756 .928 r
.10101 .55048 m .09236 .55344 L .09561 .5562 L p F P
0 g
s
.649 .756 .928 r
.09561 .5562 m .10425 .55325 L .10101 .55048 L p F P
0 g
s
.936 .94 .771 r
.42536 .69578 m .42494 .69258 L .42113 .6982 L p F P
0 g
s
.936 .94 .771 r
.42113 .6982 m .42151 .70141 L .42536 .69578 L p F P
0 g
s
.946 .926 .754 r
.42083 .70248 m .42151 .70141 L .42171 .70238 L closepath p F P
0 g
s
.951 .917 .742 r
.41819 .70688 m .42083 .70248 L .42171 .70238 L p F P
0 g
s
.152 .171 .626 r
.56802 .70121 m .56743 .70237 L .56876 .70819 L p F P
0 g
s
.204 .207 .64 r
.56835 .70888 m .56876 .70819 L .56743 .70237 L p F P
0 g
s
.243 .602 .952 r
.4365 .78841 m .43694 .78851 L .43424 .78623 L p F P
0 g
s
.243 .602 .952 r
.43424 .78623 m .4336 .78609 L .4365 .78841 L p F P
0 g
s
.133 .383 .838 r
.607 .66726 m .6042 .66555 L .60175 .66158 L p F P
0 g
s
.845 .983 .865 r
.44498 .66535 m .44457 .66644 L .44653 .66636 L p F P
0 g
s
.883 .971 .838 r
.44457 .66644 m .44653 .66636 L .44411 .66899 L closepath p F P
0 g
s
.651 .758 .928 r
.82429 .55648 m .83422 .55349 L .83626 .55624 L p F P
0 g
s
.651 .758 .928 r
.83422 .55349 m .82429 .55648 L .82223 .55373 L p F P
0 g
s
.65 .757 .928 r
.24722 .55075 m .23831 .55374 L .24132 .55649 L p F P
0 g
s
.65 .757 .928 r
.24132 .55649 m .25022 .55352 L .24722 .55075 L p F P
0 g
s
.208 .213 .644 r
.56922 .71019 m .56835 .70888 L .56876 .70819 L closepath p F P
0 g
s
.119 .141 .608 r
.64209 .73176 m .6404 .73535 L .64242 .73941 L p F P
0 g
s
.188 .206 .648 r
.6396 .72784 m .64209 .73176 L .6404 .73535 L p F P
0 g
s
.651 .758 .928 r
.67855 .55656 m .68823 .55358 L .69051 .55633 L p F P
0 g
s
.651 .758 .928 r
.68823 .55358 m .67855 .55656 L .67625 .55381 L p F P
0 g
s
.65 .757 .928 r
.39345 .55082 m .38428 .55381 L .38706 .55657 L p F P
0 g
s
.65 .757 .928 r
.38706 .55657 m .39622 .55358 L .39345 .55082 L p F P
0 g
s
.651 .757 .928 r
.5397 .55083 m .53027 .55383 L .5328 .55658 L p F P
0 g
s
.651 .757 .928 r
.5328 .55658 m .54222 .5536 L .5397 .55083 L p F P
0 g
s
.982 .867 .646 r
.41237 .72867 m .41105 .72579 L .40909 .73089 L p F P
0 g
s
.982 .867 .646 r
.40909 .73089 m .41041 .73377 L .41237 .72867 L p F P
0 g
s
.649 .756 .928 r
.11293 .55029 m .10425 .55325 L .10748 .55602 L p F P
0 g
s
.649 .756 .928 r
.10748 .55602 m .11615 .55306 L .11293 .55029 L p F P
0 g
s
.493 .45 .737 r
.58207 .75736 m .57414 .75514 L .58007 .75106 L closepath p F P
0 g
s
.507 .434 .709 r
.57951 .74933 m .58007 .75106 L .57414 .75514 L p F P
0 g
s
.507 .434 .709 r
.57464 .74727 m .57951 .74933 L p .57414 .75514 L F P
0 g
s
.628 .761 .943 r
.43694 .78851 m .44618 .78609 L .44885 .78859 L p F P
0 g
s
.636 .767 .942 r
.44618 .78609 m .43694 .78851 L .43424 .78623 L p F P
0 g
s
.879 .986 .822 r
.44411 .66899 m .43864 .67508 L .43935 .6715 L p F P
0 g
s
.879 .986 .822 r
.44457 .66644 m .44411 .66899 L p .43935 .6715 L F P
0 g
s
.651 .758 .928 r
.83626 .55624 m .84622 .55324 L .84824 .55599 L p F P
0 g
s
.651 .758 .928 r
.84622 .55324 m .83626 .55624 L .83422 .55349 L p F P
0 g
s
.65 .757 .928 r
.25915 .55053 m .25022 .55352 L .25321 .55628 L p F P
0 g
s
.65 .757 .928 r
.25321 .55628 m .26214 .5533 L .25915 .55053 L p F P
0 g
s
.958 .911 .727 r
.41606 .7153 m .41516 .71227 L .41234 .71761 L p F P
0 g
s
.958 .911 .727 r
.41397 .71927 m .41606 .7153 L p .41234 .71761 L F P
0 g
s
.911 .86 .417 r
.48738 .68332 m .48789 .68159 L .48788 .6822 L closepath p F P
0 g
s
.798 .83 .359 r
.4862 .68658 m .48738 .68332 L .48788 .6822 L p F P
0 g
s
.651 .758 .928 r
.69051 .55633 m .70021 .55334 L .70246 .5561 L p F P
0 g
s
.651 .758 .928 r
.70021 .55334 m .69051 .55633 L .68823 .55358 L p F P
0 g
s
.65 .757 .928 r
.40541 .55059 m .39622 .55358 L .39897 .55634 L p F P
0 g
s
.65 .757 .928 r
.39897 .55634 m .40816 .55336 L .40541 .55059 L p F P
0 g
s
.651 .757 .928 r
.55168 .5506 m .54222 .5536 L .54474 .55635 L p F P
0 g
s
.651 .757 .928 r
.54474 .55635 m .55418 .55337 L .55168 .5506 L p F P
0 g
s
0 0 .073 r
.63944 .76499 m .63687 .76823 L .63603 .77185 L p F P
0 g
s
0 0 .143 r
.63354 .7743 m .63603 .77185 L .63687 .76823 L p F P
0 g
s
0 0 .252 r
.64026 .7601 m .63944 .76499 L .63687 .76823 L p F P
0 g
s
.818 .363 0 r
.41979 .77723 m .41852 .77483 L .41607 .77236 L p F P
0 g
s
.937 .786 .667 r
.47876 .73278 m .48044 .72845 L .47804 .72591 L p F P
0 g
s
.649 .756 .928 r
.12484 .55009 m .11615 .55306 L .11936 .55582 L p F P
0 g
s
.649 .756 .928 r
.11936 .55582 m .12804 .55286 L .12484 .55009 L p F P
0 g
s
.922 .955 .792 r
.4276 .68886 m .4291 .68686 L .42911 .68868 L closepath p F P
0 g
s
.931 .947 .779 r
.42494 .69258 m .4276 .68886 L .42911 .68868 L p F P
0 g
s
.923 .54 .147 r
.41484 .76812 m .41258 .76558 L .41379 .76983 L p F P
0 g
s
.923 .54 .147 r
.41379 .76983 m .41607 .77236 L .41484 .76812 L p F P
0 g
s
0 0 0 r
.61851 .78706 m .62798 .78099 L .62824 .78075 L p F P
0 g
s
.773 .927 .936 r
.61742 .78659 m .61851 .78706 L .62798 .78099 L p F P
0 g
s
.651 .758 .928 r
.84824 .55599 m .85822 .553 L .86022 .55575 L p F P
0 g
s
.651 .758 .928 r
.85822 .553 m .84824 .55599 L .84622 .55324 L p F P
0 g
s
.994 .837 .578 r
.41025 .74159 m .40876 .73878 L .40749 .7437 L p F P
0 g
s
.994 .837 .578 r
.40966 .74392 m .41025 .74159 L p .40749 .7437 L F P
0 g
s
.65 .757 .928 r
.27109 .55031 m .26214 .5533 L .26511 .55606 L p F P
0 g
s
.65 .757 .928 r
.26511 .55606 m .27406 .55308 L .27109 .55031 L p F P
0 g
s
.651 .758 .928 r
.70246 .5561 m .71219 .55311 L .71443 .55586 L p F P
0 g
s
.651 .758 .928 r
.71219 .55311 m .70246 .5561 L .70021 .55334 L p F P
0 g
s
.65 .757 .928 r
.41737 .55036 m .40816 .55336 L .41089 .55611 L p F P
0 g
s
.65 .757 .928 r
.41089 .55611 m .4201 .55313 L .41737 .55036 L p F P
0 g
s
.651 .757 .928 r
.56366 .55037 m .55418 .55337 L .55668 .55612 L p F P
0 g
s
.651 .757 .928 r
.55668 .55612 m .56614 .55314 L .56366 .55037 L p F P
0 g
s
.778 .791 .863 r
.45011 .78774 m .44885 .78859 L .44618 .78609 L p F P
0 g
s
.378 .341 .69 r
.57438 .73114 m .57089 .72823 L .57308 .72602 L closepath p F P
0 g
s
.378 .341 .691 r
.5718 .72099 m .57125 .72038 L p .57089 .72823 L F P
0 g
s
.378 .341 .691 r
.57089 .72823 m .57308 .72602 L .5718 .72099 L p F P
0 g
s
.852 .748 .748 r
.47148 .76796 m .46761 .7733 L .46498 .77013 L p F P
0 g
s
.852 .748 .748 r
.46498 .77013 m .468 .76579 L .47148 .76796 L p F P
0 g
s
.849 .75 .753 r
.47148 .76796 m .468 .76579 L .47214 .76003 L p F P
0 g
s
.649 .757 .928 r
.13676 .54989 m .12804 .55286 L .13124 .55563 L p F P
0 g
s
.649 .757 .928 r
.13124 .55563 m .13994 .55266 L .13676 .54989 L p F P
0 g
s
.651 .758 .928 r
.86022 .55575 m .87022 .55275 L .8722 .5555 L p F P
0 g
s
.651 .758 .928 r
.87022 .55275 m .86022 .55575 L .85822 .553 L p F P
0 g
s
.778 .791 .863 r
.44618 .78609 m .44706 .78547 L .45011 .78774 L p F P
0 g
s
.757 .772 .865 r
.45554 .77979 m .44706 .78547 L .45011 .78774 L p F P
0 g
s
.757 .772 .865 r
.45011 .78774 m .4582 .78259 L .45554 .77979 L p F P
0 g
s
.898 .771 .712 r
.47542 .739 m .47829 .74138 L .47545 .74676 L p F P
0 g
s
.895 .769 .716 r
.47829 .74138 m .47542 .739 L .47831 .73361 L p F P
0 g
s
.65 .757 .928 r
.28304 .55009 m .27406 .55308 L .27701 .55583 L p F P
0 g
s
.65 .757 .928 r
.27701 .55583 m .28598 .55285 L .28304 .55009 L p F P
0 g
s
.99 .856 .611 r
.48126 .70485 m .48208 .70664 L .4831 .70616 L p F P
0 g
s
.983 .897 .648 r
.48208 .70664 m .4831 .70616 L .48242 .70779 L closepath p F P
0 g
s
.797 .742 .802 r
.4685 .77447 m .46761 .7733 L .46708 .77379 L closepath p F P
0 g
s
.651 .758 .928 r
.71443 .55586 m .72417 .55287 L .72639 .55563 L p F P
0 g
s
.651 .758 .928 r
.72417 .55287 m .71443 .55586 L .71219 .55311 L p F P
0 g
s
.65 .757 .928 r
.42934 .55014 m .4201 .55313 L .42282 .55588 L p F P
0 g
s
.65 .757 .928 r
.42282 .55588 m .43204 .5529 L .42934 .55014 L p F P
0 g
s
.651 .757 .928 r
.57564 .55014 m .56614 .55314 L .56862 .55589 L p F P
0 g
s
.651 .757 .928 r
.56862 .55589 m .57811 .5529 L .57564 .55014 L p F P
0 g
s
.891 .979 .817 r
.43709 .67687 m .43864 .67508 L .43935 .6715 L p F P
0 g
s
.256 .246 .655 r
.56876 .70819 m .5703 .70511 L p .57106 .71267 L F P
0 g
s
.256 .246 .655 r
.57106 .71267 m .56922 .71019 L .56876 .70819 L p F P
0 g
s
.152 .171 .626 r
.56876 .70819 m .5703 .70511 L .56802 .70121 L p F P
0 g
s
.035 .464 .879 r
.4336 .78609 m .43083 .78373 L .42402 .78103 L p F P
0 g
s
.054 .469 .885 r
.42402 .78103 m .42144 .7786 L .42819 .78132 L p F P
0 g
s
.054 .469 .885 r
.42819 .78132 m .43083 .78373 L .42402 .78103 L p F P
0 g
s
.973 .661 .314 r
.41214 .76113 m .41007 .75852 L .4105 .76298 L p F P
0 g
s
.973 .661 .314 r
.4105 .76298 m .41258 .76558 L .41214 .76113 L p F P
0 g
s
.823 .493 0 r
.56223 .67502 m .56089 .67212 L .55979 .66794 L p F P
0 g
s
.65 .757 .928 r
.14868 .54969 m .13994 .55266 L .14312 .55543 L p F P
0 g
s
.65 .757 .928 r
.14312 .55543 m .15185 .55246 L .14868 .54969 L p F P
0 g
s
.972 .89 .522 r
.48448 .69489 m .48435 .69163 L .48251 .69668 L p F P
0 g
s
.972 .89 .522 r
.48251 .69668 m .48289 .69986 L .48448 .69489 L p F P
0 g
s
.166 .324 .779 r
.62657 .69274 m .62382 .69054 L .62248 .68761 L p F P
0 g
s
.747 .793 .305 r
.48789 .68159 m .48901 .67793 L .48725 .68295 L p F P
0 g
s
.747 .793 .305 r
.48738 .68332 m .48789 .68159 L p .48725 .68295 L F P
0 g
s
.595 .867 .994 r
.6066 .7887 m .61615 .78592 L .61742 .78659 L p F P
0 g
s
.588 .777 .97 r
.61615 .78592 m .6066 .7887 L .60417 .78566 L p F P
0 g
s
.129 .112 .569 r
.64184 .74752 m .64164 .74631 L .642 .74726 L closepath p F P
0 g
s
0 0 0 r
.62824 .78075 m .62873 .78027 L .63354 .7743 L p F P
0 g
s
.529 .835 .518 r
.63603 .77185 m .63354 .7743 L .62873 .78027 L p F P
0 g
s
.885 .751 .708 r
.4758 .75441 m .47446 .75692 L .47184 .7537 L p F P
0 g
s
.885 .751 .708 r
.47184 .7537 m .47266 .75213 L .4758 .75441 L p F P
0 g
s
.886 .751 .708 r
.4758 .75441 m .47266 .75213 L .47545 .74676 L p F P
0 g
s
.65 .757 .928 r
.29498 .54986 m .28598 .55285 L .28892 .55561 L p F P
0 g
s
.65 .757 .928 r
.28892 .55561 m .29791 .55263 L .29498 .54986 L p F P
0 g
s
.651 .758 .928 r
.72639 .55563 m .73616 .55264 L .73836 .5554 L p F P
0 g
s
.651 .758 .928 r
.73616 .55264 m .72639 .55563 L .72417 .55287 L p F P
0 g
s
.947 .941 .748 r
.42083 .70248 m .42151 .70141 L .42113 .6982 L p F P
0 g
s
.65 .757 .928 r
.44131 .54991 m .43204 .5529 L .43474 .55566 L p F P
0 g
s
.65 .757 .928 r
.43474 .55566 m .44399 .55267 L .44131 .54991 L p F P
0 g
s
.891 .979 .817 r
.43935 .6715 m .43432 .67712 L .43709 .67687 L p F P
0 g
s
.9 .968 .817 r
.43709 .67687 m .43373 .68101 L .43392 .6776 L p F P
0 g
s
.9 .968 .817 r
.43392 .6776 m .43432 .67712 L .43709 .67687 L p F P
0 g
s
.651 .757 .928 r
.58763 .54991 m .57811 .5529 L .58057 .55566 L p F P
0 g
s
.651 .757 .928 r
.58057 .55566 m .59008 .55267 L .58763 .54991 L p F P
0 g
s
.143 .189 .651 r
.64105 .7243 m .6396 .72784 L .64209 .73176 L p F P
0 g
s
.167 .223 .677 r
.6396 .72784 m .64105 .7243 L .63815 .72051 L p F P
0 g
s
.244 .241 .657 r
.57015 .71408 m .56922 .71019 L .57106 .71267 L closepath p F P
0 g
s
.65 .757 .928 r
.16061 .54948 m .15185 .55246 L .155 .55523 L p F P
0 g
s
.65 .757 .928 r
.155 .55523 m .16376 .55226 L .16061 .54948 L p F P
0 g
s
.514 .836 .534 r
.62798 .78099 m .62873 .78027 L .62824 .78075 L closepath p F P
0 g
s
0 .022 .563 r
.56899 .6977 m .56802 .70121 L .5703 .70511 L p F P
0 g
s
.154 .172 .626 r
.56711 .69369 m .56899 .6977 L .56802 .70121 L p F P
0 g
s
.65 .757 .928 r
.30694 .54964 m .29791 .55263 L .30083 .55539 L p F P
0 g
s
.65 .757 .928 r
.30083 .55539 m .30984 .55241 L .30694 .54964 L p F P
0 g
s
.651 .758 .928 r
.73836 .5554 m .74815 .5524 L .75033 .55516 L p F P
0 g
s
.651 .758 .928 r
.74815 .5524 m .73836 .5554 L .73616 .55264 L p F P
0 g
s
.947 .941 .748 r
.42113 .6982 m .41801 .70295 L .42083 .70248 L p F P
0 g
s
.948 .932 .749 r
.42083 .70248 m .41819 .70688 L .4175 .70377 L p F P
0 g
s
.948 .932 .749 r
.4175 .70377 m .41801 .70295 L .42083 .70248 L p F P
0 g
s
.65 .757 .928 r
.45328 .54968 m .44399 .55267 L .44667 .55543 L p F P
0 g
s
.65 .757 .928 r
.44667 .55543 m .45594 .55244 L .45328 .54968 L p F P
0 g
s
.651 .757 .928 r
.59962 .54968 m .59008 .55267 L .59252 .55543 L p F P
0 g
s
.651 .757 .928 r
.59252 .55543 m .60205 .55244 L .59962 .54968 L p F P
0 g
s
.979 .906 .663 r
.48242 .70779 m .48029 .71293 L .47925 .70997 L p F P
0 g
s
.979 .906 .663 r
.48208 .70664 m .48242 .70779 L p .47925 .70997 L F P
0 g
s
.052 .017 .494 r
.642 .74726 m .64184 .74752 L .64238 .75252 L p F P
0 g
s
0 0 .142 r
.4923 .66799 m .49338 .66658 L .49262 .67037 L p F P
0 g
s
0 0 .142 r
.49262 .67037 m .49069 .67295 L .4923 .66799 L p F P
0 g
s
.958 .911 .727 r
.41234 .71761 m .41286 .71946 L .41397 .71927 L p F P
0 g
s
.966 .892 .704 r
.41286 .71946 m .41397 .71927 L .41329 .72062 L closepath p F P
0 g
s
.65 .757 .928 r
.17254 .54927 m .16376 .55226 L .16689 .55502 L p F P
0 g
s
.65 .757 .928 r
.16689 .55502 m .17567 .55205 L .17254 .54927 L p F P
0 g
s
.93 .562 .155 r
.55769 .66525 m .55979 .66794 L .56089 .67212 L p F P
0 g
s
.937 .577 .174 r
.55979 .66794 m .55769 .66525 L .55672 .66104 L p F P
0 g
s
.994 .837 .578 r
.40749 .7437 m .40824 .74514 L .40966 .74392 L p F P
0 g
s
.992 .814 .564 r
.40824 .74514 m .40966 .74392 L .40906 .74648 L closepath p F P
0 g
s
.651 .758 .928 r
.75033 .55516 m .76014 .55217 L .76231 .55492 L p F P
0 g
s
.651 .758 .928 r
.76014 .55217 m .75033 .55516 L .74815 .5524 L p F P
0 g
s
.65 .757 .928 r
.31889 .54941 m .30984 .55241 L .31274 .55517 L p F P
0 g
s
.65 .757 .928 r
.31274 .55517 m .32178 .55218 L .31889 .54941 L p F P
0 g
s
.651 .757 .928 r
.61161 .54944 m .60205 .55244 L .60447 .5552 L p F P
0 g
s
.651 .757 .928 r
.60447 .5552 m .61402 .55221 L .61161 .54944 L p F P
0 g
s
.65 .757 .928 r
.46525 .54945 m .45594 .55244 L .4586 .5552 L p F P
0 g
s
.65 .757 .928 r
.4586 .5552 m .4679 .55221 L .46525 .54945 L p F P
0 g
s
.596 .615 .841 r
.59213 .78246 m .60171 .78185 L p .60308 .78581 L F P
0 g
s
.545 .557 .817 r
.59924 .7774 m .60171 .78185 L .59213 .78246 L p F P
0 g
s
.545 .557 .817 r
.59475 .7773 m .59924 .7774 L p .59213 .78246 L F P
0 g
s
.545 .557 .817 r
.59213 .78246 m .59093 .77992 L .59475 .7773 L p F P
0 g
s
.172 .427 .862 r
.60175 .66158 m .60104 .66121 L .60052 .6597 L closepath p F P
0 g
s
.803 .756 .809 r
.46708 .77379 m .46761 .7733 L .46498 .77013 L p F P
0 g
s
.958 .82 .664 r
.48003 .72079 m .47819 .71808 L .47609 .72323 L p F P
0 g
s
.958 .82 .664 r
.47609 .72323 m .47804 .72591 L .48003 .72079 L p F P
0 g
s
.824 .774 .805 r
.46338 .77169 m .46708 .77379 L .46047 .78025 L p F P
0 g
s
.803 .756 .809 r
.46498 .77013 m .46338 .77169 L .46708 .77379 L p F P
0 g
s
.991 .736 .422 r
.41025 .75391 m .40838 .75123 L .40819 .75585 L p F P
0 g
s
.991 .736 .422 r
.40819 .75585 m .41007 .75852 L .41025 .75391 L p F P
0 g
s
.912 .966 .8 r
.43373 .68101 m .43392 .6776 L .42933 .68344 L p F P
0 g
s
.912 .966 .8 r
.42933 .68344 m .4291 .68686 L .43373 .68101 L p F P
0 g
s
.464 .418 .722 r
.57951 .74933 m .57464 .74727 L .57814 .74461 L closepath p F P
0 g
s
.484 .406 .693 r
.57695 .74058 m .57814 .74461 L .57464 .74727 L p F P
0 g
s
.484 .406 .693 r
.57501 .73942 m .57695 .74058 L p .57464 .74727 L F P
0 g
s
.052 .017 .494 r
.64238 .75252 m .64291 .75165 L .642 .74726 L p F P
0 g
s
.013 0 .485 r
.64394 .74363 m .642 .74726 L .64291 .75165 L p F P
0 g
s
.128 .112 .569 r
.64242 .73941 m .64394 .74363 L .642 .74726 L p F P
0 g
s
.166 .324 .779 r
.62248 .68761 m .62247 .68614 L p .62657 .69274 L F P
0 g
s
.171 .346 .798 r
.62248 .68761 m .62135 .68533 L .62247 .68614 L closepath p F P
0 g
s
.747 .793 .305 r
.48725 .68295 m .48654 .68546 L .48738 .68332 L p F P
0 g
s
.726 .783 .295 r
.48654 .68546 m .48738 .68332 L .4862 .68658 L closepath p F P
0 g
s
.65 .757 .928 r
.18448 .54906 m .17567 .55205 L .17879 .55481 L p F P
0 g
s
.65 .757 .928 r
.17879 .55481 m .18758 .55184 L .18448 .54906 L p F P
0 g
s
.849 .757 .76 r
.47214 .76003 m .47446 .75692 L .47184 .7537 L p F P
0 g
s
.24 .239 .656 r
.57106 .71267 m .57015 .71408 L .57156 .72 L p F P
0 g
s
.31 .286 .67 r
.57125 .72038 m .57156 .72 L .57015 .71408 L p F P
0 g
s
.935 .573 .298 r
.55672 .66104 m .55377 .65859 L .55479 .66279 L p F P
0 g
s
.935 .573 .298 r
.55479 .66279 m .55769 .66525 L .55672 .66104 L p F P
0 g
s
.651 .758 .928 r
.76231 .55492 m .77214 .55193 L .77429 .55469 L p F P
0 g
s
.651 .758 .928 r
.77214 .55193 m .76231 .55492 L .76014 .55217 L p F P
0 g
s
.65 .757 .928 r
.33085 .54919 m .32178 .55218 L .32466 .55494 L p F P
0 g
s
.65 .757 .928 r
.32466 .55494 m .33372 .55196 L .33085 .54919 L p F P
0 g
s
.651 .757 .928 r
.62361 .54921 m .61402 .55221 L .61643 .55497 L p F P
0 g
s
.651 .757 .928 r
.61643 .55497 m .626 .55198 L .62361 .54921 L p F P
0 g
s
.651 .757 .928 r
.47723 .54922 m .4679 .55221 L .47054 .55497 L p F P
0 g
s
.651 .757 .928 r
.47054 .55497 m .47986 .55198 L .47723 .54922 L p F P
0 g
s
.678 .974 .802 r
.62873 .78027 m .62798 .78099 L .62569 .78157 L p F P
0 g
s
.529 .835 .518 r
.63513 .77363 m .63603 .77185 L p .62873 .78027 L F P
0 g
s
.678 .974 .802 r
.62569 .78157 m .63264 .77618 L .62873 .78027 L p F P
0 g
s
.529 .835 .518 r
.62873 .78027 m .63264 .77618 L .63513 .77363 L p F P
0 g
s
.978 .896 .67 r
.41329 .72062 m .41105 .72579 L .40992 .72284 L p F P
0 g
s
.978 .896 .67 r
.41286 .71946 m .41329 .72062 L p .40992 .72284 L F P
0 g
s
.773 .927 .936 r
.62798 .78099 m .62569 .78157 L p .61742 .78659 L F P
0 g
s
.829 .772 .798 r
.46047 .78025 m .4582 .78259 L .45554 .77979 L p F P
0 g
s
.829 .772 .798 r
.45554 .77979 m .45719 .77803 L .46047 .78025 L p F P
0 g
s
.824 .774 .805 r
.46047 .78025 m .45719 .77803 L .46338 .77169 L p F P
0 g
s
.937 .786 .667 r
.47804 .72591 m .47613 .73077 L .47876 .73278 L p F P
0 g
s
.914 .806 .726 r
.47876 .73278 m .47831 .73361 L .47597 .73106 L p F P
0 g
s
.914 .806 .726 r
.47597 .73106 m .47613 .73077 L .47876 .73278 L p F P
0 g
s
.991 .86 .608 r
.41041 .73377 m .40909 .73089 L .40747 .7359 L p F P
0 g
s
.991 .86 .608 r
.40747 .7359 m .40876 .73878 L .41041 .73377 L p F P
0 g
s
.65 .757 .928 r
.19642 .54885 m .18758 .55184 L .19068 .5546 L p F P
0 g
s
.65 .757 .928 r
.19068 .5546 m .1995 .55162 L .19642 .54885 L p F P
0 g
s
.165 .238 .694 r
.63932 .71702 m .63815 .72051 L .64105 .7243 L p F P
0 g
s
.173 .251 .705 r
.63815 .72051 m .63932 .71702 L .63607 .71334 L p F P
0 g
s
.651 .758 .928 r
.77429 .55469 m .78414 .55169 L .78627 .55445 L p F P
0 g
s
.651 .758 .928 r
.78414 .55169 m .77429 .55469 L .77214 .55193 L p F P
0 g
s
.65 .757 .928 r
.34281 .54896 m .33372 .55196 L .33657 .55472 L p F P
0 g
s
.65 .757 .928 r
.33657 .55472 m .34566 .55173 L .34281 .54896 L p F P
0 g
s
.651 .757 .928 r
.63561 .54898 m .626 .55198 L .62838 .55474 L p F P
0 g
s
.651 .757 .928 r
.62838 .55474 m .63798 .55175 L .63561 .54898 L p F P
0 g
s
.651 .757 .928 r
.48921 .54899 m .47986 .55198 L .48248 .55474 L p F P
0 g
s
.651 .757 .928 r
.48248 .55474 m .49182 .55175 L .48921 .54899 L p F P
0 g
s
.312 .289 .672 r
.5718 .72099 m .57125 .72038 L .57156 .72 L closepath p F P
0 g
s
.133 .383 .838 r
.60175 .66158 m .60599 .66427 L .607 .66726 L p F P
0 g
s
.072 .361 .831 r
.60599 .66427 m .60175 .66158 L .60052 .6597 L p F P
0 g
s
.914 .801 .721 r
.47831 .73361 m .47597 .73106 L .47303 .73647 L p F P
0 g
s
.914 .801 .721 r
.47303 .73647 m .47542 .739 L .47831 .73361 L p F P
0 g
s
0 0 .309 r
.64257 .75716 m .64026 .7601 L .63944 .76499 L p F P
0 g
s
.085 0 .443 r
.64026 .7601 m .64257 .75716 L .64238 .75252 L p F P
0 g
s
.684 .893 .973 r
.61615 .78592 m .61991 .7843 L .61742 .78659 L closepath p F P
0 g
s
.773 .927 .936 r
.62569 .78157 m .61991 .7843 L .61742 .78659 L p F P
0 g
s
.65 .757 .928 r
.20836 .54863 m .1995 .55162 L .20258 .55439 L p F P
0 g
s
.65 .757 .928 r
.20258 .55439 m .21143 .55141 L .20836 .54863 L p F P
0 g
s
.147 .376 .829 r
.61255 .67344 m .61191 .67036 L .607 .66726 L p F P
0 g
s
.121 .378 .836 r
.60599 .66427 m .607 .66726 L .61191 .67036 L p F P
0 g
s
.547 .56 .82 r
.59093 .77992 m .58964 .77723 L .59475 .7773 L closepath p F P
0 g
s
.863 .767 .755 r
.46887 .75779 m .47214 .76003 L .468 .76579 L p F P
0 g
s
.849 .757 .76 r
.47184 .7537 m .46887 .75779 L .47214 .76003 L p F P
0 g
s
.651 .758 .928 r
.78627 .55445 m .79615 .55145 L .79825 .55421 L p F P
0 g
s
.651 .758 .928 r
.79615 .55145 m .78627 .55445 L .78414 .55169 L p F P
0 g
s
.901 .772 .71 r
.47262 .74437 m .47545 .74676 L .47266 .75213 L p F P
0 g
s
.898 .771 .712 r
.47545 .74676 m .47262 .74437 L .47542 .739 L p F P
0 g
s
.65 .757 .928 r
.35477 .54873 m .34566 .55173 L .3485 .55449 L p F P
0 g
s
.65 .757 .928 r
.3485 .55449 m .3576 .5515 L .35477 .54873 L p F P
0 g
s
.651 .758 .928 r
.64762 .54875 m .63798 .55175 L .64035 .55451 L p F P
0 g
s
.651 .758 .928 r
.64035 .55451 m .64997 .55151 L .64762 .54875 L p F P
0 g
s
.651 .757 .928 r
.50119 .54876 m .49182 .55175 L .49442 .55451 L p F P
0 g
s
.651 .757 .928 r
.49442 .55451 m .50378 .55153 L .50119 .54876 L p F P
0 g
s
0 .107 .618 r
.41979 .77723 m .42144 .7786 L .4191 .7761 L p F P
0 g
s
.818 .363 0 r
.41607 .77236 m .41709 .77433 L .41979 .77723 L p F P
0 g
s
0 .107 .618 r
.4191 .7761 m .41709 .77433 L .41979 .77723 L p F P
0 g
s
0 0 .441 r
.56717 .69043 m .56711 .69369 L .56899 .6977 L p F P
0 g
s
.96 .922 .721 r
.41819 .70688 m .4175 .70377 L .41448 .70916 L p F P
0 g
s
.96 .922 .721 r
.41448 .70916 m .41516 .71227 L .41819 .70688 L p F P
0 g
s
.156 .344 .8 r
.62247 .68614 m .62135 .68533 L .61889 .68046 L p F P
0 g
s
.65 .757 .928 r
.2203 .54842 m .21143 .55141 L .21449 .55417 L p F P
0 g
s
.65 .757 .928 r
.21449 .55417 m .22335 .55119 L .2203 .54842 L p F P
0 g
s
.651 .758 .928 r
.79825 .55421 m .80815 .55121 L .81024 .55397 L p F P
0 g
s
.651 .758 .928 r
.80815 .55121 m .79825 .55421 L .79615 .55145 L p F P
0 g
s
.65 .757 .928 r
.36674 .54851 m .3576 .5515 L .36042 .55426 L p F P
0 g
s
.65 .757 .928 r
.36042 .55426 m .36955 .55128 L .36674 .54851 L p F P
0 g
s
.651 .758 .928 r
.65962 .54851 m .64997 .55151 L .65231 .55427 L p F P
0 g
s
.651 .758 .928 r
.65231 .55427 m .66196 .55128 L .65962 .54851 L p F P
0 g
s
.651 .757 .928 r
.51318 .54852 m .50378 .55153 L .50637 .55429 L p F P
0 g
s
.651 .757 .928 r
.50637 .55429 m .51575 .55129 L .51318 .54852 L p F P
0 g
s
.919 .968 .785 r
.4276 .68886 m .4291 .68686 L .42933 .68344 L p F P
0 g
s
.327 .299 .675 r
.57156 .72 m .57383 .71645 L p .57464 .724 L F P
0 g
s
.327 .299 .675 r
.57464 .724 m .5718 .72099 L .57156 .72 L p F P
0 g
s
.24 .239 .656 r
.57156 .72 m .57383 .71645 L .57106 .71267 L p F P
0 g
s
.168 .264 .72 r
.63696 .70992 m .63607 .71334 L .63932 .71702 L p F P
0 g
s
.171 .273 .728 r
.63607 .71334 m .63696 .70992 L .63342 .70633 L p F P
0 g
s
.997 .787 .495 r
.40906 .74648 m .40824 .74514 L .4067 .74852 L p F P
0 g
s
.997 .787 .495 r
.4067 .74852 m .40838 .75123 L .40906 .74648 L p F P
0 g
s
.989 .858 .617 r
.48043 .70734 m .48126 .70485 L .48208 .70664 L closepath p F P
0 g
s
.979 .906 .663 r
.47925 .70997 m .48043 .70734 L .48208 .70664 L p F P
0 g
s
.31 .296 .681 r
.57308 .72602 m .5718 .72099 L .57464 .724 L closepath p F P
0 g
s
.65 .757 .928 r
.23225 .5482 m .22335 .55119 L .22639 .55396 L p F P
0 g
s
.65 .757 .928 r
.22639 .55396 m .23528 .55097 L .23225 .5482 L p F P
0 g
s
.651 .758 .928 r
.81024 .55397 m .82016 .55097 L .82223 .55373 L p F P
0 g
s
.651 .758 .928 r
.82016 .55097 m .81024 .55397 L .80815 .55121 L p F P
0 g
s
.134 .365 .823 r
.61255 .67344 m .61644 .67592 L .61399 .67172 L p F P
0 g
s
.134 .365 .823 r
.61399 .67172 m .61191 .67036 L .61255 .67344 L p F P
0 g
s
.227 .417 .841 r
.61644 .67592 m .61255 .67344 L p .6178 .6797 L F P
0 g
s
.65 .757 .928 r
.37871 .54828 m .36955 .55128 L .37235 .55404 L p F P
0 g
s
.65 .757 .928 r
.37235 .55404 m .3815 .55105 L .37871 .54828 L p F P
0 g
s
.651 .758 .928 r
.67163 .54828 m .66196 .55128 L .66428 .55404 L p F P
0 g
s
.651 .758 .928 r
.66428 .55404 m .67395 .55105 L .67163 .54828 L p F P
0 g
s
.651 .757 .928 r
.52517 .54829 m .51575 .55129 L .51832 .55406 L p F P
0 g
s
.651 .757 .928 r
.51832 .55406 m .52772 .55106 L .52517 .54829 L p F P
0 g
s
.649 .756 .928 r
.09776 .54769 m .08911 .55066 L .09236 .55344 L p F P
0 g
s
.649 .756 .928 r
.09236 .55344 m .10101 .55048 L .09776 .54769 L p F P
0 g
s
.26 .606 .954 r
.4336 .78609 m .43424 .78623 L .43154 .78387 L p F P
0 g
s
.26 .606 .954 r
.43154 .78387 m .43083 .78373 L .4336 .78609 L p F P
0 g
s
.986 .89 .557 r
.48289 .69986 m .48251 .69668 L .48064 .70175 L p F P
0 g
s
.986 .89 .557 r
.48064 .70175 m .48126 .70485 L .48289 .69986 L p F P
0 g
s
.743 .795 .311 r
.4862 .68658 m .48654 .68546 L .4852 .68873 L p F P
0 g
s
.743 .795 .311 r
.4852 .68873 m .48435 .69163 L .4862 .68658 L p F P
0 g
s
.919 .968 .785 r
.42933 .68344 m .42479 .68926 L .4276 .68886 L p F P
0 g
s
.923 .957 .787 r
.4276 .68886 m .42494 .69258 L .42477 .68928 L p F P
0 g
s
.923 .957 .787 r
.42477 .68928 m .42479 .68926 L .4276 .68886 L p F P
0 g
s
.651 .758 .928 r
.82223 .55373 m .83218 .55073 L .83422 .55349 L p F P
0 g
s
.651 .758 .928 r
.83218 .55073 m .82223 .55373 L .82016 .55097 L p F P
0 g
s
.65 .757 .928 r
.2442 .54798 m .23528 .55097 L .23831 .55374 L p F P
0 g
s
.65 .757 .928 r
.23831 .55374 m .24722 .55075 L .2442 .54798 L p F P
0 g
s
.552 .537 .792 r
.59475 .7773 m .58964 .77723 L .58738 .77189 L p F P
0 g
s
.078 0 .246 r
.49338 .66658 m .4973 .66315 L .49496 .66833 L p F P
0 g
s
.078 0 .246 r
.49496 .66833 m .49262 .67037 L .49338 .66658 L p F P
0 g
s
.651 .758 .928 r
.67625 .55381 m .68594 .55081 L .68823 .55358 L p F P
0 g
s
.651 .758 .928 r
.68365 .54804 m .67395 .55105 L .67625 .55381 L p F P
0 g
s
.651 .758 .928 r
.67625 .55381 m .68594 .55081 L .68365 .54804 L p F P
0 g
s
.65 .757 .928 r
.39068 .54805 m .3815 .55105 L .38428 .55381 L p F P
0 g
s
.65 .757 .928 r
.38428 .55381 m .39345 .55082 L .39068 .54805 L p F P
0 g
s
.651 .757 .928 r
.53716 .54806 m .52772 .55106 L .53027 .55383 L p F P
0 g
s
.651 .757 .928 r
.53027 .55383 m .5397 .55083 L .53716 .54806 L p F P
0 g
s
.169 .29 .746 r
.63401 .70298 m .63342 .70633 L .63696 .70992 L p F P
0 g
s
.163 .289 .747 r
.63342 .70633 m .63401 .70298 L .63024 .69947 L p F P
0 g
s
.649 .756 .928 r
.10969 .5475 m .10101 .55048 L .10425 .55325 L p F P
0 g
s
.649 .756 .928 r
.10425 .55325 m .11293 .55029 L .10969 .5475 L p F P
0 g
s
.98 .874 .658 r
.48029 .71293 m .47925 .70997 L .47694 .71518 L p F P
0 g
s
.98 .874 .658 r
.47694 .71518 m .47819 .71808 L .48029 .71293 L p F P
0 g
s
.427 .383 .707 r
.57695 .74058 m .57501 .73942 L .57633 .73829 L closepath p F P
0 g
s
.427 .384 .707 r
.57501 .73942 m .57633 .73829 L .57464 .73209 L p F P
0 g
s
.072 .079 .559 r
.64416 .73582 m .64242 .73941 L .64394 .74363 L p F P
0 g
s
.119 .141 .608 r
.64242 .73941 m .64416 .73582 L .64209 .73176 L p F P
0 g
s
.592 .65 .876 r
.60417 .78566 m .60308 .78581 L .60392 .78528 L closepath p F P
0 g
s
.596 .615 .841 r
.60171 .78185 m .60392 .78528 L .60308 .78581 L p F P
0 g
s
.161 .356 .809 r
.61889 .68046 m .6178 .6797 L .61767 .67813 L closepath p F P
0 g
s
.227 .417 .841 r
.6178 .6797 m .61767 .67813 L .61644 .67592 L p F P
0 g
s
.855 .992 .836 r
.44379 .66657 m .44498 .66535 L .44457 .66644 L closepath p F P
0 g
s
.879 .986 .822 r
.43935 .6715 m .44379 .66657 L .44457 .66644 L p F P
0 g
s
.636 .767 .942 r
.43424 .78623 m .4435 .78363 L .44618 .78609 L p F P
0 g
s
.638 .772 .944 r
.4435 .78363 m .43424 .78623 L .43154 .78387 L p F P
0 g
s
.651 .758 .928 r
.83422 .55349 m .84419 .55048 L .84622 .55324 L p F P
0 g
s
.651 .758 .928 r
.84419 .55048 m .83422 .55349 L .83218 .55073 L p F P
0 g
s
.975 .907 .68 r
.41112 .72017 m .41234 .71761 L .41286 .71946 L closepath p F P
0 g
s
.978 .896 .67 r
.40992 .72284 m .41112 .72017 L .41286 .71946 L p F P
0 g
s
.65 .757 .928 r
.25616 .54776 m .24722 .55075 L .25022 .55352 L p F P
0 g
s
.65 .757 .928 r
.25022 .55352 m .25915 .55053 L .25616 .54776 L p F P
0 g
s
.651 .758 .928 r
.68823 .55358 m .69794 .55058 L .70021 .55334 L p F P
0 g
s
.651 .758 .928 r
.69794 .55058 m .68823 .55358 L .68594 .55081 L p F P
0 g
s
.65 .757 .928 r
.40266 .54782 m .39345 .55082 L .39622 .55358 L p F P
0 g
s
.65 .757 .928 r
.39622 .55358 m .40541 .55059 L .40266 .54782 L p F P
0 g
s
.651 .757 .928 r
.54916 .54783 m .5397 .55083 L .54222 .5536 L p F P
0 g
s
.651 .757 .928 r
.54222 .5536 m .55168 .5506 L .54916 .54783 L p F P
0 g
s
.38 .342 .69 r
.57308 .72602 m .57464 .724 L p .57502 .73166 L F P
0 g
s
.38 .342 .69 r
.57502 .73166 m .57438 .73114 L .57308 .72602 L p F P
0 g
s
.072 .361 .831 r
.60052 .6597 m .59985 .65826 L p .60599 .66427 L F P
0 g
s
.866 .766 .751 r
.468 .76579 m .46498 .77013 L .46233 .76724 L p F P
0 g
s
.866 .766 .751 r
.46233 .76724 m .46487 .76351 L .468 .76579 L p F P
0 g
s
.863 .767 .755 r
.468 .76579 m .46487 .76351 L .46887 .75779 L p F P
0 g
s
0 0 .121 r
.49069 .67295 m .49262 .67037 L .49182 .67413 L p F P
0 g
s
0 0 .121 r
.49182 .67413 m .48901 .67793 L .49069 .67295 L p F P
0 g
s
.17 .316 .77 r
.63053 .69618 m .63024 .69947 L .63401 .70298 L p F P
0 g
s
.149 .3 .763 r
.63024 .69947 m .63053 .69618 L .62657 .69274 L p F P
0 g
s
0 0 .397 r
.64291 .75165 m .64238 .75252 L .64257 .75716 L p F P
0 g
s
.649 .756 .928 r
.12163 .54731 m .11293 .55029 L .11615 .55306 L p F P
0 g
s
.649 .756 .928 r
.11615 .55306 m .12484 .55009 L .12163 .54731 L p F P
0 g
s
.806 .36 0 r
.41709 .77433 m .41607 .77236 L .41379 .76983 L p F P
0 g
s
.049 .126 .623 r
.57258 .70902 m .57106 .71267 L .57383 .71645 L p F P
0 g
s
.256 .246 .655 r
.5703 .70511 m .57258 .70902 L .57106 .71267 L p F P
0 g
s
.166 .324 .779 r
.62247 .68614 m .62656 .68953 L .62657 .69274 L p F P
0 g
s
.1 .303 .78 r
.62217 .68299 m .62247 .68614 L .62656 .68953 L p F P
0 g
s
.156 .344 .8 r
.61889 .68046 m .62217 .68299 L .62247 .68614 L p F P
0 g
s
.952 .816 .673 r
.47804 .72591 m .47609 .72323 L .47398 .7284 L p F P
0 g
s
.952 .816 .673 r
.47613 .73077 m .47804 .72591 L p .47398 .7284 L F P
0 g
s
.127 .3 .77 r
.62656 .68953 m .62657 .69274 L .63053 .69618 L p F P
0 g
s
.651 .758 .928 r
.84622 .55324 m .85621 .55023 L .85822 .553 L p F P
0 g
s
.651 .758 .928 r
.85621 .55023 m .84622 .55324 L .84419 .55048 L p F P
0 g
s
.65 .757 .928 r
.26812 .54753 m .25915 .55053 L .26214 .5533 L p F P
0 g
s
.65 .757 .928 r
.26214 .5533 m .27109 .55031 L .26812 .54753 L p F P
0 g
s
.784 .796 .862 r
.44706 .78547 m .44618 .78609 L .4435 .78363 L p F P
0 g
s
.651 .758 .928 r
.70021 .55334 m .70994 .55035 L .71219 .55311 L p F P
0 g
s
.651 .758 .928 r
.70994 .55035 m .70021 .55334 L .69794 .55058 L p F P
0 g
s
.65 .757 .928 r
.41464 .54759 m .40541 .55059 L .40816 .55336 L p F P
0 g
s
.65 .757 .928 r
.40816 .55336 m .41737 .55036 L .41464 .54759 L p F P
0 g
s
.651 .757 .928 r
.56116 .5476 m .55168 .5506 L .55418 .55337 L p F P
0 g
s
.651 .757 .928 r
.55418 .55337 m .56366 .55037 L .56116 .5476 L p F P
0 g
s
.986 .88 .636 r
.41105 .72579 m .40992 .72284 L .40797 .72794 L p F P
0 g
s
.986 .88 .636 r
.40797 .72794 m .40909 .73089 L .41105 .72579 L p F P
0 g
s
.916 .538 .118 r
.41258 .76558 m .4105 .76298 L .41168 .76723 L p F P
0 g
s
.916 .538 .118 r
.41168 .76723 m .41379 .76983 L .41258 .76558 L p F P
0 g
s
.784 .796 .862 r
.4435 .78363 m .44416 .78315 L .44706 .78547 L p F P
0 g
s
.767 .784 .867 r
.45288 .77714 m .44416 .78315 L .44706 .78547 L p F P
0 g
s
.767 .784 .867 r
.44706 .78547 m .45554 .77979 L .45288 .77714 L p F P
0 g
s
.588 .777 .97 r
.60417 .78566 m .61375 .78376 L .61615 .78592 L p F P
0 g
s
.578 .643 .879 r
.61132 .78084 m .61375 .78376 L .60417 .78566 L p F P
0 g
s
.578 .643 .879 r
.60956 .78102 m .61132 .78084 L p .60417 .78566 L F P
0 g
s
.578 .643 .879 r
.60417 .78566 m .60392 .78528 L .60956 .78102 L p F P
0 g
s
.649 .756 .928 r
.13357 .54711 m .12484 .55009 L .12804 .55286 L p F P
0 g
s
.649 .756 .928 r
.12804 .55286 m .13676 .54989 L .13357 .54711 L p F P
0 g
s
.937 .953 .762 r
.42494 .69258 m .42477 .68928 L .42097 .69491 L p F P
0 g
s
.937 .953 .762 r
.42097 .69491 m .42113 .6982 L .42494 .69258 L p F P
0 g
s
.915 .797 .717 r
.47542 .739 m .47303 .73647 L .47018 .74186 L p F P
0 g
s
.915 .797 .717 r
.47018 .74186 m .47262 .74437 L .47542 .739 L p F P
0 g
s
.651 .758 .928 r
.85822 .553 m .86823 .54998 L .87022 .55275 L p F P
0 g
s
.651 .758 .928 r
.86823 .54998 m .85822 .553 L .85621 .55023 L p F P
0 g
s
.65 .757 .928 r
.28008 .54731 m .27109 .55031 L .27406 .55308 L p F P
0 g
s
.65 .757 .928 r
.27406 .55308 m .28304 .55009 L .28008 .54731 L p F P
0 g
s
.651 .758 .928 r
.71219 .55311 m .72194 .55011 L .72417 .55287 L p F P
0 g
s
.651 .758 .928 r
.72194 .55011 m .71219 .55311 L .70994 .55035 L p F P
0 g
s
.65 .757 .928 r
.42662 .54736 m .41737 .55036 L .4201 .55313 L p F P
0 g
s
.65 .757 .928 r
.4201 .55313 m .42934 .55014 L .42662 .54736 L p F P
0 g
s
.651 .757 .928 r
.57317 .54737 m .56366 .55037 L .56614 .55314 L p F P
0 g
s
.651 .757 .928 r
.56614 .55314 m .57564 .55014 L .57317 .54737 L p F P
0 g
s
.9 .772 .711 r
.47266 .75213 m .47184 .7537 L .4692 .75099 L p F P
0 g
s
.9 .772 .711 r
.4692 .75099 m .46985 .74974 L .47266 .75213 L p F P
0 g
s
.901 .772 .71 r
.47266 .75213 m .46985 .74974 L .47262 .74437 L p F P
0 g
s
.832 .489 0 r
.56352 .67916 m .56207 .67629 L .56089 .67212 L p F P
0 g
s
.579 .646 .88 r
.60392 .78528 m .60171 .78185 L .60956 .78102 L closepath p F P
0 g
s
.966 .924 .703 r
.41516 .71227 m .41448 .70916 L .41169 .7145 L p F P
0 g
s
.966 .924 .703 r
.41169 .7145 m .41234 .71761 L .41516 .71227 L p F P
0 g
s
.066 .469 .887 r
.42144 .7786 m .4191 .7761 L .42567 .77887 L p F P
0 g
s
.066 .469 .887 r
.42567 .77887 m .42819 .78132 L .42144 .7786 L p F P
0 g
s
.65 .757 .928 r
.14551 .54691 m .13676 .54989 L .13994 .55266 L p F P
0 g
s
.65 .757 .928 r
.13994 .55266 m .14868 .54969 L .14551 .54691 L p F P
0 g
s
.363 .341 .701 r
.57464 .73209 m .57438 .73114 L .57502 .73166 L closepath p F P
0 g
s
.998 .845 .554 r
.40876 .73878 m .40747 .7359 L .40623 .74081 L p F P
0 g
s
.998 .845 .554 r
.40623 .74081 m .40749 .7437 L .40876 .73878 L p F P
0 g
s
.361 .34 .701 r
.57502 .73166 m .57464 .73209 L .57633 .73829 L p F P
0 g
s
.552 .537 .792 r
.58738 .77189 m .58806 .7714 L p .59475 .7773 L F P
0 g
s
.524 .525 .798 r
.58738 .77189 m .58713 .7713 L .58806 .7714 L closepath p F P
0 g
s
.65 .757 .928 r
.29205 .54709 m .28304 .55009 L .28598 .55285 L p F P
0 g
s
.65 .757 .928 r
.28598 .55285 m .29498 .54986 L .29205 .54709 L p F P
0 g
s
.651 .758 .928 r
.72417 .55287 m .73395 .54987 L .73616 .55264 L p F P
0 g
s
.651 .758 .928 r
.73395 .54987 m .72417 .55287 L .72194 .55011 L p F P
0 g
s
.65 .757 .928 r
.43861 .54713 m .42934 .55014 L .43204 .5529 L p F P
0 g
s
.65 .757 .928 r
.43204 .5529 m .44131 .54991 L .43861 .54713 L p F P
0 g
s
.651 .757 .928 r
.58517 .54713 m .57564 .55014 L .57811 .5529 L p F P
0 g
s
.651 .757 .928 r
.57811 .5529 m .58763 .54991 L .58517 .54713 L p F P
0 g
s
0 0 0 r
.63513 .77363 m .6373 .77024 L .63603 .77185 L closepath p F P
0 g
s
0 0 .073 r
.63603 .77185 m .6373 .77024 L .63944 .76499 L p F P
0 g
s
.531 .505 .773 r
.58806 .7714 m .58713 .7713 L .5846 .76468 L p F P
0 g
s
.972 .665 .29 r
.41007 .75852 m .40819 .75585 L .4086 .76032 L p F P
0 g
s
.972 .665 .29 r
.4086 .76032 m .4105 .76298 L .41007 .75852 L p F P
0 g
s
.602 .884 .991 r
.61991 .7843 m .61615 .78592 L .61375 .78376 L p F P
0 g
s
.102 .318 .792 r
.62217 .68299 m .61889 .68046 L .61767 .67813 L p F P
0 g
s
.65 .757 .928 r
.15746 .5467 m .14868 .54969 L .15185 .55246 L p F P
0 g
s
.65 .757 .928 r
.15185 .55246 m .16061 .54948 L .15746 .5467 L p F P
0 g
s
.822 1 .828 r
.45144 .65895 m .44498 .66535 L .44675 .66142 L p F P
0 g
s
.822 1 .828 r
.45212 .65739 m .45144 .65895 L p .44675 .66142 L F P
0 g
s
.817 .773 .812 r
.46338 .77169 m .46498 .77013 L .46233 .76724 L p F P
0 g
s
.748 .8 .317 r
.48654 .68546 m .48725 .68295 L .48541 .688 L p F P
0 g
s
.748 .8 .317 r
.48541 .688 m .4852 .68873 L .48654 .68546 L p F P
0 g
s
.833 .785 .806 r
.46012 .76945 m .46338 .77169 L .45719 .77803 L p F P
0 g
s
.817 .773 .812 r
.46233 .76724 m .46012 .76945 L .46338 .77169 L p F P
0 g
s
1 .808 .496 r
.40824 .74514 m .40749 .7437 L .40669 .74849 L p F P
0 g
s
1 .808 .496 r
.40669 .74849 m .4067 .74852 L .40824 .74514 L p F P
0 g
s
.65 .757 .928 r
.30402 .54686 m .29498 .54986 L .29791 .55263 L p F P
0 g
s
.65 .757 .928 r
.29791 .55263 m .30694 .54964 L .30402 .54686 L p F P
0 g
s
.651 .758 .928 r
.73616 .55264 m .74596 .54964 L .74815 .5524 L p F P
0 g
s
.651 .758 .928 r
.74596 .54964 m .73616 .55264 L .73395 .54987 L p F P
0 g
s
.867 .782 .765 r
.46887 .75779 m .47184 .7537 L .4692 .75099 L p F P
0 g
s
.65 .757 .928 r
.4506 .5469 m .44131 .54991 L .44399 .55267 L p F P
0 g
s
.65 .757 .928 r
.44399 .55267 m .45328 .54968 L .4506 .5469 L p F P
0 g
s
.651 .757 .928 r
.59718 .5469 m .58763 .54991 L .59008 .55267 L p F P
0 g
s
.651 .757 .928 r
.59008 .55267 m .59962 .54968 L .59718 .5469 L p F P
0 g
s
.924 .549 .14 r
.55876 .66944 m .56089 .67212 L .56207 .67629 L p F P
0 g
s
.93 .562 .155 r
.56089 .67212 m .55876 .66944 L .55769 .66525 L p F P
0 g
s
0 0 0 r
.64231 .76136 m .63944 .76499 L .6373 .77024 L p F P
0 g
s
0 0 .309 r
.63944 .76499 m .64231 .76136 L .64257 .75716 L p F P
0 g
s
.102 .137 .612 r
.64362 .72821 m .64209 .73176 L .64416 .73582 L p F P
0 g
s
.143 .189 .651 r
.64209 .73176 m .64362 .72821 L .64105 .7243 L p F P
0 g
s
0 0 .397 r
.64257 .75716 m .64311 .75625 L .64291 .75165 L p F P
0 g
s
0 0 .375 r
.64486 .74803 m .64291 .75165 L .64311 .75625 L p F P
0 g
s
.013 0 .485 r
.64291 .75165 m .64486 .74803 L .64394 .74363 L p F P
0 g
s
.65 .757 .928 r
.16941 .54649 m .16061 .54948 L .16376 .55226 L p F P
0 g
s
.65 .757 .928 r
.16376 .55226 m .17254 .54927 L .16941 .54649 L p F P
0 g
s
.841 .998 .822 r
.44379 .66657 m .44498 .66535 L .44675 .66142 L p F P
0 g
s
.361 .34 .701 r
.57633 .73829 m .57917 .7351 L .57502 .73166 L p F P
0 g
s
.255 .278 .693 r
.57801 .72765 m .57502 .73166 L .57917 .7351 L p F P
0 g
s
.38 .342 .69 r
.57464 .724 m .57801 .72765 L .57502 .73166 L p F P
0 g
s
.651 .758 .928 r
.74815 .5524 m .75798 .5494 L .76014 .55217 L p F P
0 g
s
.651 .758 .928 r
.75798 .5494 m .74815 .5524 L .74596 .54964 L p F P
0 g
s
.65 .757 .928 r
.31599 .54664 m .30694 .54964 L .30984 .55241 L p F P
0 g
s
.65 .757 .928 r
.30984 .55241 m .31889 .54941 L .31599 .54664 L p F P
0 g
s
0 0 .55 r
.57089 .70171 m .5703 .70511 L .57258 .70902 L p F P
0 g
s
0 .022 .563 r
.5703 .70511 m .57089 .70171 L .56899 .6977 L p F P
0 g
s
.42 .379 .706 r
.57633 .73829 m .57917 .7351 L p .58016 .74259 L F P
0 g
s
.42 .379 .706 r
.58016 .74259 m .57695 .74058 L .57633 .73829 L p F P
0 g
s
.841 .998 .822 r
.44675 .66142 m .44102 .66711 L .44379 .66657 L p F P
0 g
s
.863 .992 .827 r
.44379 .66657 m .43935 .6715 L .44035 .66782 L p F P
0 g
s
.863 .992 .827 r
.44035 .66782 m .44102 .66711 L .44379 .66657 L p F P
0 g
s
.651 .757 .928 r
.6092 .54667 m .59962 .54968 L .60205 .55244 L p F P
0 g
s
.651 .757 .928 r
.60205 .55244 m .61161 .54944 L .6092 .54667 L p F P
0 g
s
.65 .757 .928 r
.46259 .54667 m .45328 .54968 L .45594 .55244 L p F P
0 g
s
.65 .757 .928 r
.45594 .55244 m .46525 .54945 L .46259 .54667 L p F P
0 g
s
.933 .562 .274 r
.55769 .66525 m .55479 .66279 L .55589 .66697 L p F P
0 g
s
.933 .562 .274 r
.55589 .66697 m .55876 .66944 L .55769 .66525 L p F P
0 g
s
.894 .542 .37 r
.55377 .65859 m .54982 .65643 L .55099 .66058 L p F P
0 g
s
.894 .542 .37 r
.55099 .66058 m .55479 .66279 L .55377 .65859 L p F P
0 g
s
.838 .784 .8 r
.45719 .77803 m .45554 .77979 L .45288 .77714 L p F P
0 g
s
.838 .784 .8 r
.45288 .77714 m .45417 .77574 L .45719 .77803 L p F P
0 g
s
.833 .785 .806 r
.45719 .77803 m .45417 .77574 L .46012 .76945 L p F P
0 g
s
.552 .537 .792 r
.58806 .7714 m .59674 .77234 L p .59475 .7773 L F P
0 g
s
.493 .483 .775 r
.58806 .7714 m .59674 .77234 L .59423 .76673 L p F P
0 g
s
.493 .483 .775 r
.59423 .76673 m .59404 .76668 L .58806 .7714 L p F P
0 g
s
.531 .505 .773 r
.5846 .76468 m .59404 .76668 L .58806 .7714 L p F P
0 g
s
.65 .757 .928 r
.18136 .54628 m .17254 .54927 L .17567 .55205 L p F P
0 g
s
.65 .757 .928 r
.17567 .55205 m .18448 .54906 L .18136 .54628 L p F P
0 g
s
.405 .381 .72 r
.57814 .74461 m .57695 .74058 L .58016 .74259 L closepath p F P
0 g
s
.517 .478 .752 r
.5846 .76468 m .58445 .76466 L .58457 .76458 L closepath p F P
0 g
s
.525 .461 .727 r
.58218 .75768 m .58457 .76458 L .58445 .76466 L p F P
0 g
s
.651 .758 .928 r
.76014 .55217 m .76999 .54916 L .77214 .55193 L p F P
0 g
s
.651 .758 .928 r
.76999 .54916 m .76014 .55217 L .75798 .5494 L p F P
0 g
s
.65 .757 .928 r
.32797 .54641 m .31889 .54941 L .32178 .55218 L p F P
0 g
s
.65 .757 .928 r
.32178 .55218 m .33085 .54919 L .32797 .54641 L p F P
0 g
s
0 0 0 r
.48435 .69163 m .48251 .69668 L .48328 .69315 L p F P
0 g
s
0 0 0 r
.4852 .68873 m .48435 .69163 L p .48328 .69315 L F P
0 g
s
.651 .757 .928 r
.62121 .54643 m .61161 .54944 L .61402 .55221 L p F P
0 g
s
.651 .757 .928 r
.61402 .55221 m .62361 .54921 L .62121 .54643 L p F P
0 g
s
.651 .757 .928 r
.47459 .54644 m .46525 .54945 L .4679 .55221 L p F P
0 g
s
.651 .757 .928 r
.4679 .55221 m .47723 .54922 L .47459 .54644 L p F P
0 g
s
.987 .899 .608 r
.48126 .70485 m .48064 .70175 L .47873 .70684 L p F P
0 g
s
.987 .899 .608 r
.48043 .70734 m .48126 .70485 L p .47873 .70684 L F P
0 g
s
.506 .471 .753 r
.59404 .76668 m .5846 .76468 L .58457 .76458 L p F P
0 g
s
.506 .471 .753 r
.58457 .76458 m .5901 .76 L p .59404 .76668 L F P
0 g
s
.47 .451 .755 r
.58242 .75747 m .58218 .75768 L .58457 .76458 L p F P
0 g
s
.47 .451 .755 r
.58457 .76458 m .5901 .76 L .58242 .75747 L p F P
0 g
s
.933 .955 .769 r
.42113 .6982 m .42097 .69491 L .41733 .70049 L p F P
0 g
s
.933 .955 .769 r
.41801 .70295 m .42113 .6982 L p .41733 .70049 L F P
0 g
s
.975 .861 .663 r
.47819 .71808 m .47694 .71518 L .47467 .72039 L p F P
0 g
s
.975 .861 .663 r
.47467 .72039 m .47609 .72323 L .47819 .71808 L p F P
0 g
s
.454 .412 .721 r
.57814 .74461 m .58016 .74259 L p .58115 .75008 L F P
0 g
s
.454 .412 .721 r
.58115 .75008 m .57951 .74933 L .57814 .74461 L p F P
0 g
s
.993 .748 .393 r
.40838 .75123 m .40819 .75585 L .40648 .75312 L p F P
0 g
s
.993 .748 .393 r
.4067 .74852 m .40838 .75123 L p .40648 .75312 L F P
0 g
s
.65 .757 .928 r
.19332 .54607 m .18448 .54906 L .18758 .55184 L p F P
0 g
s
.65 .757 .928 r
.18758 .55184 m .19642 .54885 L .19332 .54607 L p F P
0 g
s
.072 .361 .831 r
.59985 .65826 m .60467 .66137 L .60599 .66427 L p F P
0 g
s
.002 .342 .822 r
.59819 .65544 m .59985 .65826 L .60467 .66137 L p F P
0 g
s
.651 .758 .928 r
.77214 .55193 m .78201 .54892 L .78414 .55169 L p F P
0 g
s
.651 .758 .928 r
.78201 .54892 m .77214 .55193 L .76999 .54916 L p F P
0 g
s
.868 .986 .836 r
.43935 .6715 m .44035 .66782 L .43495 .67391 L p F P
0 g
s
.868 .986 .836 r
.43432 .67712 m .43935 .6715 L p .43495 .67391 L F P
0 g
s
.65 .757 .928 r
.33995 .54618 m .33085 .54919 L .33372 .55196 L p F P
0 g
s
.65 .757 .928 r
.33372 .55196 m .34281 .54896 L .33995 .54618 L p F P
0 g
s
0 .09 .62 r
.41709 .77433 m .4191 .7761 L .41698 .77353 L p F P
0 g
s
.806 .36 0 r
.41379 .76983 m .41438 .77103 L .41709 .77433 L p F P
0 g
s
0 .09 .62 r
.41698 .77353 m .41438 .77103 L .41709 .77433 L p F P
0 g
s
.875 .785 .759 r
.46602 .75541 m .46887 .75779 L .46487 .76351 L p F P
0 g
s
.867 .782 .765 r
.4692 .75099 m .46602 .75541 L .46887 .75779 L p F P
0 g
s
.651 .757 .928 r
.63323 .5462 m .62361 .54921 L .626 .55198 L p F P
0 g
s
.651 .757 .928 r
.626 .55198 m .63561 .54898 L .63323 .5462 L p F P
0 g
s
.102 .318 .792 r
.61767 .67813 m .61738 .67658 L p .62217 .68299 L F P
0 g
s
.117 .345 .812 r
.61767 .67813 m .61644 .67592 L .61738 .67658 L closepath p F P
0 g
s
.651 .757 .928 r
.48659 .54621 m .47723 .54922 L .47986 .55198 L p F P
0 g
s
.651 .757 .928 r
.47986 .55198 m .48921 .54899 L .48659 .54621 L p F P
0 g
s
.602 .884 .991 r
.62396 .78097 m .61991 .7843 L p .61375 .78376 L F P
0 g
s
.68 .931 .969 r
.61991 .7843 m .62396 .78097 L .62569 .78157 L closepath p F P
0 g
s
.441 .419 .738 r
.58007 .75106 m .57951 .74933 L .58115 .75008 L closepath p F P
0 g
s
.483 .443 .737 r
.58007 .75106 m .58115 .75008 L p .58242 .75747 L F P
0 g
s
.483 .443 .737 r
.58242 .75747 m .58207 .75736 L .58007 .75106 L p F P
0 g
s
.952 .816 .673 r
.47398 .7284 m .47565 .73057 L .47613 .73077 L p F P
0 g
s
.936 .845 .729 r
.47565 .73057 m .47613 .73077 L .47597 .73106 L closepath p F P
0 g
s
.472 .454 .757 r
.58218 .75768 m .58207 .75736 L .58242 .75747 L closepath p F P
0 g
s
.914 .795 .714 r
.47262 .74437 m .47018 .74186 L .46737 .74724 L p F P
0 g
s
.914 .795 .714 r
.46737 .74724 m .46985 .74974 L .47262 .74437 L p F P
0 g
s
.65 .757 .928 r
.20528 .54585 m .19642 .54885 L .1995 .55162 L p F P
0 g
s
.65 .757 .928 r
.1995 .55162 m .20836 .54863 L .20528 .54585 L p F P
0 g
s
.933 .846 .734 r
.47597 .73106 m .47303 .73647 L .47113 .73379 L p F P
0 g
s
.933 .846 .734 r
.47565 .73057 m .47597 .73106 L p .47113 .73379 L F P
0 g
s
.195 0 .33 r
.49946 .65803 m .50063 .65715 L .50004 .66109 L p F P
0 g
s
.195 0 .33 r
.50004 .66109 m .4973 .66315 L .49946 .65803 L p F P
0 g
s
.651 .758 .928 r
.78414 .55169 m .79403 .54868 L .79615 .55145 L p F P
0 g
s
.651 .758 .928 r
.79403 .54868 m .78414 .55169 L .78201 .54892 L p F P
0 g
s
0 0 .173 r
.48901 .67793 m .48725 .68295 L .49001 .67881 L p F P
0 g
s
0 0 .173 r
.49182 .67413 m .48901 .67793 L p .49001 .67881 L F P
0 g
s
.65 .757 .928 r
.35193 .54595 m .34281 .54896 L .34566 .55173 L p F P
0 g
s
.65 .757 .928 r
.34566 .55173 m .35477 .54873 L .35193 .54595 L p F P
0 g
s
.651 .757 .928 r
.64526 .54597 m .63561 .54898 L .63798 .55175 L p F P
0 g
s
.651 .757 .928 r
.63798 .55175 m .64762 .54875 L .64526 .54597 L p F P
0 g
s
.651 .757 .928 r
.49859 .54598 m .48921 .54899 L .49182 .55175 L p F P
0 g
s
.651 .757 .928 r
.49182 .55175 m .50119 .54876 L .49859 .54598 L p F P
0 g
s
.117 .18 .653 r
.64198 .72169 m .64105 .7243 L .64362 .72821 L p F P
0 g
s
.165 .238 .694 r
.64133 .71964 m .63932 .71702 L p .64105 .7243 L F P
0 g
s
.165 .238 .694 r
.64105 .7243 m .64198 .72169 L .64133 .71964 L p F P
0 g
s
.455 .461 .775 r
.58734 .753 m .58242 .75747 L .5901 .76 L p F P
0 g
s
.483 .443 .737 r
.58115 .75008 m .58734 .753 L .58242 .75747 L p F P
0 g
s
0 0 .417 r
.56878 .69451 m .56899 .6977 L .57089 .70171 L p F P
0 g
s
0 0 .441 r
.56899 .6977 m .56878 .69451 L .56717 .69043 L p F P
0 g
s
.97 .924 .688 r
.41234 .71761 m .41169 .7145 L .40913 .71978 L p F P
0 g
s
.97 .924 .688 r
.41112 .72017 m .41234 .71761 L p .40913 .71978 L F P
0 g
s
.994 .87 .593 r
.40909 .73089 m .40797 .72794 L .40636 .73296 L p F P
0 g
s
.994 .87 .593 r
.40636 .73296 m .40747 .7359 L .40909 .73089 L p F P
0 g
s
.65 .757 .928 r
.21724 .54563 m .20836 .54863 L .21143 .55141 L p F P
0 g
s
.65 .757 .928 r
.21143 .55141 m .2203 .54842 L .21724 .54563 L p F P
0 g
s
.651 .758 .928 r
.79615 .55145 m .80606 .54844 L .80815 .55121 L p F P
0 g
s
.651 .758 .928 r
.80606 .54844 m .79615 .55145 L .79403 .54868 L p F P
0 g
s
.65 .757 .928 r
.36392 .54573 m .35477 .54873 L .3576 .5515 L p F P
0 g
s
.65 .757 .928 r
.3576 .5515 m .36674 .54851 L .36392 .54573 L p F P
0 g
s
.543 .564 .826 r
.59924 .7774 m .59475 .7773 L .59802 .77492 L closepath p F P
0 g
s
.552 .537 .792 r
.59674 .77234 m .59802 .77492 L .59475 .7773 L p F P
0 g
s
.651 .758 .928 r
.65728 .54573 m .64762 .54875 L .64997 .55151 L p F P
0 g
s
.651 .758 .928 r
.64997 .55151 m .65962 .54851 L .65728 .54573 L p F P
0 g
s
.651 .757 .928 r
.5106 .54575 m .50119 .54876 L .50378 .55153 L p F P
0 g
s
.651 .757 .928 r
.50378 .55153 m .51318 .54852 L .5106 .54575 L p F P
0 g
s
.868 .986 .836 r
.43495 .67391 m .43398 .67717 L .43432 .67712 L p F P
0 g
s
.898 .974 .814 r
.43398 .67717 m .43432 .67712 L .43392 .6776 L closepath p F P
0 g
s
.894 .986 .792 r
.43392 .6776 m .42933 .68344 L .42983 .67993 L p F P
0 g
s
.894 .986 .792 r
.43398 .67717 m .43392 .6776 L p .42983 .67993 L F P
0 g
s
.121 .378 .836 r
.61191 .67036 m .61098 .66735 L .60599 .66427 L p F P
0 g
s
.149 .426 .865 r
.60467 .66137 m .60599 .66427 L .61098 .66735 L p F P
0 g
s
.65 .757 .928 r
.22921 .54541 m .2203 .54842 L .22335 .55119 L p F P
0 g
s
.65 .757 .928 r
.22335 .55119 m .23225 .5482 L .22921 .54541 L p F P
0 g
s
.651 .758 .928 r
.80815 .55121 m .81809 .5482 L .82016 .55097 L p F P
0 g
s
.651 .758 .928 r
.81809 .5482 m .80815 .55121 L .80606 .54844 L p F P
0 g
s
.2 .263 .705 r
.5766 .72026 m .57464 .724 L .57801 .72765 L p F P
0 g
s
.327 .299 .675 r
.57383 .71645 m .5766 .72026 L .57464 .724 L p F P
0 g
s
.65 .757 .928 r
.37591 .5455 m .36674 .54851 L .36955 .55128 L p F P
0 g
s
.65 .757 .928 r
.36955 .55128 m .37871 .54828 L .37591 .5455 L p F P
0 g
s
.651 .758 .928 r
.66931 .5455 m .65962 .54851 L .66196 .55128 L p F P
0 g
s
.651 .758 .928 r
.66196 .55128 m .67163 .54828 L .66931 .5455 L p F P
0 g
s
.987 .899 .608 r
.47873 .70684 m .47911 .70841 L .48043 .70734 L p F P
0 g
s
.97 .93 .629 r
.47911 .70841 m .48043 .70734 L .47925 .70997 L closepath p F P
0 g
s
.651 .757 .928 r
.52261 .54551 m .51318 .54852 L .51575 .55129 L p F P
0 g
s
.651 .757 .928 r
.51575 .55129 m .52517 .54829 L .52261 .54551 L p F P
0 g
s
.27 .605 .954 r
.43154 .78387 m .43083 .78373 L .42819 .78132 L p F P
0 g
s
0 0 .246 r
.64311 .75625 m .64257 .75716 L .64231 .76136 L p F P
0 g
s
.649 .756 .928 r
.0945 .5449 m .08584 .54788 L .08911 .55066 L p F P
0 g
s
.649 .756 .928 r
.08911 .55066 m .09776 .54769 L .0945 .5449 L p F P
0 g
s
.95 .816 .676 r
.47347 .72962 m .47398 .7284 L .47565 .73057 L closepath p F P
0 g
s
.933 .846 .734 r
.47113 .73379 m .47347 .72962 L .47565 .73057 L p F P
0 g
s
.584 .613 .848 r
.60956 .78102 m .60171 .78185 L .59924 .7774 L p F P
0 g
s
.933 .955 .769 r
.41733 .70049 m .41741 .70309 L .41801 .70295 L p F P
0 g
s
.948 .938 .746 r
.41741 .70309 m .41801 .70295 L .4175 .70377 L closepath p F P
0 g
s
.651 .758 .928 r
.82016 .55097 m .83012 .54796 L .83218 .55073 L p F P
0 g
s
.651 .758 .928 r
.83012 .54796 m .82016 .55097 L .81809 .5482 L p F P
0 g
s
.65 .757 .928 r
.24118 .54519 m .23225 .5482 L .23528 .55097 L p F P
0 g
s
.65 .757 .928 r
.23528 .55097 m .2442 .54798 L .24118 .54519 L p F P
0 g
s
.784 .998 .837 r
.45047 .65781 m .45384 .65482 L .45212 .65739 L closepath p F P
0 g
s
.822 1 .828 r
.44675 .66142 m .45047 .65781 L .45212 .65739 L p F P
0 g
s
.998 .816 .471 r
.40749 .7437 m .40623 .74081 L .40545 .7456 L p F P
0 g
s
.998 .816 .471 r
.40545 .7456 m .40669 .74849 L .40749 .7437 L p F P
0 g
s
.651 .758 .928 r
.68135 .54526 m .67163 .54828 L .67395 .55105 L p F P
0 g
s
.651 .758 .928 r
.67395 .55105 m .68365 .54804 L .68135 .54526 L p F P
0 g
s
.65 .757 .928 r
.3879 .54527 m .37871 .54828 L .3815 .55105 L p F P
0 g
s
.65 .757 .928 r
.3815 .55105 m .39068 .54805 L .3879 .54527 L p F P
0 g
s
.09 .34 .813 r
.61738 .67658 m .61644 .67592 L .61399 .67172 L p F P
0 g
s
.651 .757 .928 r
.53462 .54528 m .52517 .54829 L .52772 .55106 L p F P
0 g
s
.651 .757 .928 r
.52772 .55106 m .53716 .54806 L .53462 .54528 L p F P
0 g
s
.794 .933 .568 r
.63425 .77454 m .63513 .77363 L .6373 .77024 L p F P
0 g
s
.794 .933 .568 r
.6373 .77024 m .64022 .76639 L p .63425 .77454 L F P
0 g
s
0 0 0 r
.64218 .76206 m .64231 .76136 L p .6373 .77024 L F P
0 g
s
0 0 0 r
.6373 .77024 m .64022 .76639 L .64218 .76206 L p F P
0 g
s
.649 .756 .928 r
.10645 .54471 m .09776 .54769 L .10101 .55048 L p F P
0 g
s
.649 .756 .928 r
.10101 .55048 m .10969 .5475 L .10645 .54471 L p F P
0 g
s
.007 0 .489 r
.64575 .74002 m .64394 .74363 L .64486 .74803 L p F P
0 g
s
.072 .079 .559 r
.64394 .74363 m .64575 .74002 L .64416 .73582 L p F P
0 g
s
.954 .947 .717 r
.4175 .70377 m .41448 .70916 L .41402 .70598 L p F P
0 g
s
.954 .947 .717 r
.41741 .70309 m .4175 .70377 L p .41402 .70598 L F P
0 g
s
.113 .204 .68 r
.64133 .71964 m .63932 .71702 L .63987 .71507 L closepath p F P
0 g
s
.168 .264 .72 r
.63878 .71202 m .63696 .70992 L p .63932 .71702 L F P
0 g
s
.168 .264 .72 r
.63932 .71702 m .63987 .71507 L .63878 .71202 L p F P
0 g
s
.878 .992 .802 r
.43152 .67786 m .43495 .67391 L .43398 .67717 L closepath p F P
0 g
s
.894 .986 .792 r
.42983 .67993 m .43152 .67786 L .43398 .67717 L p F P
0 g
s
.877 .785 .755 r
.46487 .76351 m .46233 .76724 L .45968 .76466 L p F P
0 g
s
.877 .785 .755 r
.45968 .76466 m .46206 .76113 L .46487 .76351 L p F P
0 g
s
.875 .785 .759 r
.46487 .76351 m .46206 .76113 L .46602 .75541 L p F P
0 g
s
.651 .758 .928 r
.83218 .55073 m .84216 .54771 L .84419 .55048 L p F P
0 g
s
.651 .758 .928 r
.84216 .54771 m .83218 .55073 L .83012 .54796 L p F P
0 g
s
.638 .772 .944 r
.43154 .78387 m .44081 .78121 L .4435 .78363 L p F P
0 g
s
.637 .777 .948 r
.43811 .77884 m .42883 .78146 L .43154 .78387 L p F P
0 g
s
.637 .777 .948 r
.43154 .78387 m .44081 .78121 L .43811 .77884 L p F P
0 g
s
.27 .605 .954 r
.42819 .78132 m .42883 .78146 L .43154 .78387 L p F P
0 g
s
.65 .757 .928 r
.25316 .54497 m .2442 .54798 L .24722 .55075 L p F P
0 g
s
.65 .757 .928 r
.24722 .55075 m .25616 .54776 L .25316 .54497 L p F P
0 g
s
.97 .924 .688 r
.40913 .71978 m .40937 .721 L .41112 .72017 L p F P
0 g
s
.979 .902 .667 r
.40937 .721 m .41112 .72017 L .40992 .72284 L closepath p F P
0 g
s
.406 .143 .399 r
.50004 .66109 m .50063 .65715 L .50915 .65346 L p F P
0 g
s
.651 .758 .928 r
.68594 .55081 m .69566 .54781 L .69794 .55058 L p F P
0 g
s
.651 .758 .928 r
.69338 .54503 m .68365 .54804 L .68594 .55081 L p F P
0 g
s
.651 .758 .928 r
.68594 .55081 m .69566 .54781 L .69338 .54503 L p F P
0 g
s
.65 .757 .928 r
.3999 .54504 m .39068 .54805 L .39345 .55082 L p F P
0 g
s
.65 .757 .928 r
.39345 .55082 m .40266 .54782 L .3999 .54504 L p F P
0 g
s
.651 .757 .928 r
.54664 .54505 m .53716 .54806 L .5397 .55083 L p F P
0 g
s
.651 .757 .928 r
.5397 .55083 m .54916 .54783 L .54664 .54505 L p F P
0 g
s
.066 0 .229 r
.49262 .67037 m .49496 .66833 L .49246 .67357 L p F P
0 g
s
.066 0 .229 r
.49246 .67357 m .49182 .67413 L .49262 .67037 L p F P
0 g
s
.414 .424 .761 r
.58517 .74583 m .58115 .75008 L .58734 .753 L p F P
0 g
s
.454 .412 .721 r
.58016 .74259 m .58517 .74583 L .58115 .75008 L p F P
0 g
s
.649 .756 .928 r
.1184 .54451 m .10969 .5475 L .11293 .55029 L p F P
0 g
s
.649 .756 .928 r
.11293 .55029 m .12163 .54731 L .1184 .54451 L p F P
0 g
s
.089 .351 .821 r
.61191 .67036 m .61399 .67172 L .61154 .66773 L p F P
0 g
s
.089 .351 .821 r
.61154 .66773 m .61098 .66735 L .61191 .67036 L p F P
0 g
s
.815 .945 .909 r
.62396 .78097 m .62569 .78157 L .63264 .77618 L p F P
0 g
s
.787 .801 .864 r
.44416 .78315 m .4435 .78363 L .44081 .78121 L p F P
0 g
s
.651 .758 .928 r
.84419 .55048 m .8542 .54746 L .85621 .55023 L p F P
0 g
s
.651 .758 .928 r
.8542 .54746 m .84419 .55048 L .84216 .54771 L p F P
0 g
s
.65 .757 .928 r
.26514 .54475 m .25616 .54776 L .25915 .55053 L p F P
0 g
s
.65 .757 .928 r
.25915 .55053 m .26812 .54753 L .26514 .54475 L p F P
0 g
s
.787 .801 .864 r
.44081 .78121 m .44139 .78078 L .44416 .78315 L p F P
0 g
s
.775 .796 .87 r
.4502 .77466 m .44139 .78078 L .44416 .78315 L p F P
0 g
s
.775 .796 .87 r
.44416 .78315 m .45288 .77714 L .4502 .77466 L p F P
0 g
s
.651 .758 .928 r
.69794 .55058 m .70769 .54757 L .70994 .55035 L p F P
0 g
s
.651 .758 .928 r
.70769 .54757 m .69794 .55058 L .69566 .54781 L p F P
0 g
s
.65 .757 .928 r
.4119 .54481 m .40266 .54782 L .40541 .55059 L p F P
0 g
s
.65 .757 .928 r
.40541 .55059 m .41464 .54759 L .4119 .54481 L p F P
0 g
s
.651 .757 .928 r
.55866 .54482 m .54916 .54783 L .55168 .5506 L p F P
0 g
s
.651 .757 .928 r
.55168 .5506 m .56116 .5476 L .55866 .54482 L p F P
0 g
s
.797 .364 0 r
.41438 .77103 m .41379 .76983 L .41168 .76723 L p F P
0 g
s
.899 .978 .805 r
.42933 .68344 m .42983 .67993 L .42534 .68576 L p F P
0 g
s
.899 .978 .805 r
.42479 .68926 m .42933 .68344 L p .42534 .68576 L F P
0 g
s
.649 .756 .928 r
.13036 .54432 m .12163 .54731 L .12484 .55009 L p F P
0 g
s
.649 .756 .928 r
.12484 .55009 m .13357 .54711 L .13036 .54432 L p F P
0 g
s
.958 .943 .644 r
.47925 .70997 m .47694 .71518 L .47646 .71205 L p F P
0 g
s
.958 .943 .644 r
.47911 .70841 m .47925 .70997 L p .47646 .71205 L F P
0 g
s
.889 .884 .454 r
.48251 .69668 m .48328 .69315 L .48103 .69834 L p F P
0 g
s
.889 .884 .454 r
.48103 .69834 m .48064 .70175 L .48251 .69668 L p F P
0 g
s
.97 .85 .668 r
.47609 .72323 m .47467 .72039 L .47239 .72561 L p F P
0 g
s
.97 .85 .668 r
.47239 .72561 m .47398 .7284 L .47609 .72323 L p F P
0 g
s
.651 .758 .928 r
.85621 .55023 m .86624 .54721 L .86823 .54998 L p F P
0 g
s
.651 .758 .928 r
.86624 .54721 m .85621 .55023 L .8542 .54746 L p F P
0 g
s
.111 .228 .706 r
.63878 .71202 m .63696 .70992 L .63734 .70799 L closepath p F P
0 g
s
.169 .29 .746 r
.63627 .70529 m .63401 .70298 L p .63696 .70992 L F P
0 g
s
.169 .29 .746 r
.63696 .70992 m .63734 .70799 L .63627 .70529 L p F P
0 g
s
.931 .827 .722 r
.47303 .73647 m .47113 .73379 L .46815 .73922 L p F P
0 g
s
.931 .827 .722 r
.46815 .73922 m .47018 .74186 L .47303 .73647 L p F P
0 g
s
.65 .757 .928 r
.27712 .54453 m .26812 .54753 L .27109 .55031 L p F P
0 g
s
.65 .757 .928 r
.27109 .55031 m .28008 .54731 L .27712 .54453 L p F P
0 g
s
.914 .795 .715 r
.4692 .75099 m .46985 .74974 L .46737 .74724 L p F P
0 g
s
.838 .484 0 r
.56486 .68329 m .56332 .68046 L .56207 .67629 L p F P
0 g
s
.651 .758 .928 r
.70994 .55035 m .71971 .54734 L .72194 .55011 L p F P
0 g
s
.651 .758 .928 r
.71971 .54734 m .70994 .55035 L .70769 .54757 L p F P
0 g
s
.65 .757 .928 r
.4239 .54458 m .41464 .54759 L .41737 .55036 L p F P
0 g
s
.65 .757 .928 r
.41737 .55036 m .42662 .54736 L .4239 .54458 L p F P
0 g
s
.651 .757 .928 r
.57068 .54458 m .56116 .5476 L .56366 .55037 L p F P
0 g
s
.651 .757 .928 r
.56366 .55037 m .57317 .54737 L .57068 .54458 L p F P
0 g
s
0 0 0 r
.63264 .77618 m .63425 .77454 L .63513 .77363 L closepath p F P
0 g
s
.906 .536 .086 r
.4105 .76298 m .4086 .76032 L p .41166 .76721 L F P
0 g
s
.906 .536 .086 r
.41166 .76721 m .41168 .76723 L .4105 .76298 L p F P
0 g
s
.067 .174 .667 r
.57487 .71295 m .57383 .71645 L .5766 .72026 L p F P
0 g
s
.049 .126 .623 r
.57383 .71645 m .57487 .71295 L .57258 .70902 L p F P
0 g
s
.102 .318 .792 r
.61738 .67658 m .62158 .67991 L .62217 .68299 L p F P
0 g
s
.029 .295 .788 r
.6165 .67357 m .61738 .67658 L .62158 .67991 L p F P
0 g
s
.09 .34 .813 r
.61399 .67172 m .6165 .67357 L .61738 .67658 L p F P
0 g
s
.65 .757 .928 r
.14232 .54411 m .13357 .54711 L .13676 .54989 L p F P
0 g
s
.65 .757 .928 r
.13676 .54989 m .14551 .54691 L .14232 .54411 L p F P
0 g
s
0 0 .246 r
.64231 .76136 m .64247 .7611 L .64311 .75625 L p F P
0 g
s
0 0 .189 r
.64505 .75264 m .64311 .75625 L .64247 .7611 L p F P
0 g
s
0 0 .375 r
.64311 .75625 m .64505 .75264 L .64486 .74803 L p F P
0 g
s
.815 .945 .909 r
.63264 .77618 m .63425 .77454 L p .62396 .78097 L F P
0 g
s
.829 .793 .817 r
.46012 .76945 m .46233 .76724 L .45968 .76466 L p F P
0 g
s
.947 .955 .727 r
.41516 .70403 m .41733 .70049 L .41741 .70309 L closepath p F P
0 g
s
.954 .947 .717 r
.41402 .70598 m .41516 .70403 L .41741 .70309 L p F P
0 g
s
.65 .757 .928 r
.2891 .5443 m .28008 .54731 L .28304 .55009 L p F P
0 g
s
.65 .757 .928 r
.28304 .55009 m .29205 .54709 L .2891 .5443 L p F P
0 g
s
.185 0 .315 r
.4973 .66315 m .50004 .66109 L .49941 .665 L p F P
0 g
s
.185 0 .315 r
.49941 .665 m .49496 .66833 L .4973 .66315 L p F P
0 g
s
.651 .758 .928 r
.72194 .55011 m .73174 .5471 L .73395 .54987 L p F P
0 g
s
.651 .758 .928 r
.73174 .5471 m .72194 .55011 L .71971 .54734 L p F P
0 g
s
.064 .459 .883 r
.4191 .7761 m .41698 .77353 L .42329 .77637 L p F P
0 g
s
.064 .459 .883 r
.42329 .77637 m .42567 .77887 L .4191 .7761 L p F P
0 g
s
.65 .757 .928 r
.4359 .54435 m .42662 .54736 L .42934 .55014 L p F P
0 g
s
.65 .757 .928 r
.42934 .55014 m .43861 .54713 L .4359 .54435 L p F P
0 g
s
.84 .797 .81 r
.45727 .76709 m .46012 .76945 L .45417 .77574 L p F P
0 g
s
.829 .793 .817 r
.45968 .76466 m .45727 .76709 L .46012 .76945 L p F P
0 g
s
.651 .757 .928 r
.58271 .54435 m .57317 .54737 L .57564 .55014 L p F P
0 g
s
.651 .757 .928 r
.57564 .55014 m .58517 .54713 L .58271 .54435 L p F P
0 g
s
.108 .252 .731 r
.63627 .70529 m .63401 .70298 L .6343 .70038 L closepath p F P
0 g
s
.17 .316 .77 r
.63377 .69917 m .63053 .69618 L p .63401 .70298 L F P
0 g
s
.17 .316 .77 r
.63401 .70298 m .6343 .70038 L .63377 .69917 L p F P
0 g
s
.838 .495 .406 r
.54982 .65643 m .54803 .65577 L .54682 .65898 L p F P
0 g
s
.838 .495 .406 r
.54682 .65898 m .55099 .66058 L .54982 .65643 L p F P
0 g
s
.1 .303 .78 r
.62656 .68953 m .62629 .68637 L .62217 .68299 L p F P
0 g
s
.072 .301 .785 r
.62158 .67991 m .62217 .68299 L .62629 .68637 L p F P
0 g
s
.914 .795 .715 r
.46737 .74724 m .46655 .74882 L .4692 .75099 L p F P
0 g
s
.882 .811 .774 r
.4692 .75099 m .46602 .75541 L .46357 .75292 L p F P
0 g
s
.882 .811 .774 r
.46357 .75292 m .46655 .74882 L .4692 .75099 L p F P
0 g
s
.986 .901 .621 r
.40992 .72284 m .40797 .72794 L .40705 .72492 L p F P
0 g
s
.986 .901 .621 r
.40937 .721 m .40992 .72284 L p .40705 .72492 L F P
0 g
s
.65 .757 .928 r
.15429 .54391 m .14551 .54691 L .14868 .54969 L p F P
0 g
s
.65 .757 .928 r
.14868 .54969 m .15746 .5467 L .15429 .54391 L p F P
0 g
s
0 0 0 r
.48725 .68295 m .49001 .67881 L .48763 .68402 L p F P
0 g
s
0 0 0 r
.48763 .68402 m .48541 .688 L .48725 .68295 L p F P
0 g
s
.919 .537 .127 r
.55991 .67363 m .56207 .67629 L .56332 .68046 L p F P
0 g
s
.924 .549 .14 r
.56207 .67629 m .55991 .67363 L .55876 .66944 L p F P
0 g
s
.602 .884 .991 r
.61375 .78376 m .62334 .78069 L .62396 .78097 L p F P
0 g
s
.585 .802 .982 r
.62334 .78069 m .61375 .78376 L .61132 .78084 L p F P
0 g
s
.083 .257 .744 r
.63053 .69618 m .63377 .69917 L .63129 .69364 L p F P
0 g
s
.083 .257 .744 r
.63129 .69364 m .63058 .69295 L .63053 .69618 L p F P
0 g
s
.127 .3 .77 r
.63053 .69618 m .63058 .69295 L .62656 .68953 L p F P
0 g
s
.126 .322 .79 r
.62629 .68637 m .62656 .68953 L .63058 .69295 L p F P
0 g
s
.65 .757 .928 r
.30109 .54408 m .29205 .54709 L .29498 .54986 L p F P
0 g
s
.65 .757 .928 r
.29498 .54986 m .30402 .54686 L .30109 .54408 L p F P
0 g
s
.651 .758 .928 r
.73395 .54987 m .74376 .54686 L .74596 .54964 L p F P
0 g
s
.651 .758 .928 r
.74376 .54686 m .73395 .54987 L .73174 .5471 L p F P
0 g
s
.65 .757 .928 r
.44791 .54412 m .43861 .54713 L .44131 .54991 L p F P
0 g
s
.65 .757 .928 r
.44131 .54991 m .4506 .5469 L .44791 .54412 L p F P
0 g
s
.651 .757 .928 r
.59474 .54412 m .58517 .54713 L .58763 .54991 L p F P
0 g
s
.651 .757 .928 r
.58763 .54991 m .59718 .5469 L .59474 .54412 L p F P
0 g
s
.364 .382 .746 r
.58326 .73858 m .58016 .74259 L .58517 .74583 L p F P
0 g
s
.42 .379 .706 r
.57917 .7351 m .58326 .73858 L .58016 .74259 L p F P
0 g
s
.967 .668 .264 r
.40819 .75585 m .40648 .75312 L p .40776 .75898 L F P
0 g
s
.967 .668 .264 r
.40776 .75898 m .4086 .76032 L .40819 .75585 L p F P
0 g
s
.93 .553 .253 r
.55876 .66944 m .55589 .66697 L .55707 .67115 L p F P
0 g
s
.93 .553 .253 r
.55707 .67115 m .55991 .67363 L .55876 .66944 L p F P
0 g
s
.65 .757 .928 r
.16626 .5437 m .15746 .5467 L .16061 .54948 L p F P
0 g
s
.65 .757 .928 r
.16061 .54948 m .16941 .54649 L .16626 .5437 L p F P
0 g
s
.998 .852 .533 r
.40747 .7359 m .40636 .73296 L .40514 .73787 L p F P
0 g
s
.998 .852 .533 r
.40514 .73787 m .40623 .74081 L .40747 .7359 L p F P
0 g
s
.899 .537 .347 r
.55479 .66279 m .55099 .66058 L .55222 .66473 L p F P
0 g
s
.899 .537 .347 r
.55222 .66473 m .55589 .66697 L .55479 .66279 L p F P
0 g
s
.845 .796 .804 r
.45417 .77574 m .45288 .77714 L .4502 .77466 L p F P
0 g
s
.845 .796 .804 r
.4502 .77466 m .45137 .77337 L .45417 .77574 L p F P
0 g
s
.84 .797 .81 r
.45417 .77574 m .45137 .77337 L .45727 .76709 L p F P
0 g
s
.651 .758 .928 r
.74596 .54964 m .7558 .54663 L .75798 .5494 L p F P
0 g
s
.651 .758 .928 r
.7558 .54663 m .74596 .54964 L .74376 .54686 L p F P
0 g
s
.65 .757 .928 r
.31308 .54385 m .30402 .54686 L .30694 .54964 L p F P
0 g
s
.65 .757 .928 r
.30694 .54964 m .31599 .54664 L .31308 .54385 L p F P
0 g
s
.899 .978 .805 r
.42534 .68576 m .42478 .68926 L .42479 .68926 L p F P
0 g
s
.922 .964 .784 r
.42478 .68926 m .42479 .68926 L .42477 .68928 L closepath p F P
0 g
s
.044 .065 .557 r
.64507 .73377 m .64416 .73582 L .64575 .74002 L p F P
0 g
s
.102 .137 .612 r
.64392 .72883 m .64362 .72821 L p .64416 .73582 L F P
0 g
s
.102 .137 .612 r
.64416 .73582 m .64507 .73377 L .64392 .72883 L p F P
0 g
s
.651 .757 .928 r
.60677 .54388 m .59718 .5469 L .59962 .54968 L p F P
0 g
s
.651 .757 .928 r
.59962 .54968 m .6092 .54667 L .60677 .54388 L p F P
0 g
s
.65 .757 .928 r
.45993 .54388 m .4506 .5469 L .45328 .54968 L p F P
0 g
s
.65 .757 .928 r
.45328 .54968 m .46259 .54667 L .45993 .54388 L p F P
0 g
s
.922 .974 .758 r
.42477 .68928 m .42097 .69491 L .42107 .69153 L p F P
0 g
s
.922 .974 .758 r
.42478 .68926 m .42477 .68928 L p .42107 .69153 L F P
0 g
s
0 .056 .605 r
.41438 .77103 m .41698 .77353 L .41506 .77088 L p F P
0 g
s
.797 .364 0 r
.41168 .76723 m .41169 .76725 L .41438 .77103 L p F P
0 g
s
0 .056 .605 r
.41506 .77088 m .41169 .76725 L .41438 .77103 L p F P
0 g
s
.91 .981 .767 r
.42196 .69028 m .42534 .68576 L .42478 .68926 L closepath p F P
0 g
s
.922 .974 .758 r
.42107 .69153 m .42196 .69028 L .42478 .68926 L p F P
0 g
s
.966 .934 .69 r
.41448 .70916 m .41402 .70598 L .41124 .71132 L p F P
0 g
s
.966 .934 .69 r
.41124 .71132 m .41169 .7145 L .41448 .70916 L p F P
0 g
s
.65 .757 .928 r
.17823 .54349 m .16941 .54649 L .17254 .54927 L p F P
0 g
s
.65 .757 .928 r
.17254 .54927 m .18136 .54628 L .17823 .54349 L p F P
0 g
s
.584 .613 .848 r
.59924 .7774 m .60887 .77725 L p .60956 .78102 L F P
0 g
s
.521 .553 .828 r
.6064 .77311 m .60887 .77725 L .59924 .7774 L p F P
0 g
s
.521 .553 .828 r
.60068 .77262 m .6064 .77311 L p .59924 .7774 L F P
0 g
s
.521 .553 .828 r
.59924 .7774 m .59802 .77492 L .60068 .77262 L p F P
0 g
s
.651 .758 .928 r
.76783 .54639 m .75798 .5494 L .7558 .54663 L p F P
0 g
s
.651 .758 .928 r
.75798 .5494 m .76783 .54639 L .76999 .54916 L p F P
0 g
s
.65 .757 .928 r
.32508 .54362 m .31599 .54664 L .31889 .54941 L p F P
0 g
s
.65 .757 .928 r
.31889 .54941 m .32797 .54641 L .32508 .54362 L p F P
0 g
s
0 .048 .599 r
.57282 .70573 m .57258 .70902 L .57487 .71295 L p F P
0 g
s
0 0 .55 r
.57258 .70902 m .57282 .70573 L .57089 .70171 L p F P
0 g
s
.651 .757 .928 r
.61881 .54365 m .6092 .54667 L .61161 .54944 L p F P
0 g
s
.651 .757 .928 r
.61161 .54944 m .62121 .54643 L .61881 .54365 L p F P
0 g
s
.651 .757 .928 r
.47194 .54365 m .46259 .54667 L .46525 .54945 L p F P
0 g
s
.651 .757 .928 r
.46525 .54945 m .47459 .54644 L .47194 .54365 L p F P
0 g
s
.869 .533 .413 r
.54803 .65577 m .54528 .65443 L .54617 .65867 L p F P
0 g
s
.869 .533 .413 r
.54617 .65867 m .54682 .65898 L .54803 .65577 L p F P
0 g
s
.65 .757 .928 r
.19021 .54327 m .18136 .54628 L .18448 .54906 L p F P
0 g
s
.65 .757 .928 r
.18448 .54906 m .19332 .54607 L .19021 .54327 L p F P
0 g
s
.885 .804 .764 r
.46602 .75541 m .46357 .75292 L .45955 .75866 L p F P
0 g
s
.885 .804 .764 r
.45955 .75866 m .46206 .76113 L .46602 .75541 L p F P
0 g
s
.651 .758 .928 r
.76999 .54916 m .77987 .54615 L .78201 .54892 L p F P
0 g
s
.651 .758 .928 r
.77987 .54615 m .76999 .54916 L .76783 .54639 L p F P
0 g
s
.65 .757 .928 r
.33708 .54339 m .32797 .54641 L .33085 .54919 L p F P
0 g
s
.65 .757 .928 r
.33085 .54919 m .33995 .54618 L .33708 .54339 L p F P
0 g
s
.651 .757 .928 r
.63085 .54341 m .62121 .54643 L .62361 .54921 L p F P
0 g
s
.651 .757 .928 r
.62361 .54921 m .63323 .5462 L .63085 .54341 L p F P
0 g
s
.651 .757 .928 r
.48396 .54342 m .47459 .54644 L .47723 .54922 L p F P
0 g
s
.651 .757 .928 r
.47723 .54922 m .48659 .54621 L .48396 .54342 L p F P
0 g
s
.031 .314 .802 r
.6165 .67357 m .61399 .67172 L .61154 .66773 L p F P
0 g
s
.757 .81 .333 r
.48466 .68999 m .48541 .688 L .4852 .68873 L closepath p F P
0 g
s
0 0 0 r
.48328 .69315 m .48466 .68999 L .4852 .68873 L p F P
0 g
s
.65 .757 .928 r
.20219 .54306 m .19332 .54607 L .19642 .54885 L p F P
0 g
s
.65 .757 .928 r
.19642 .54885 m .20528 .54585 L .20219 .54306 L p F P
0 g
s
.002 .342 .822 r
.60467 .66137 m .60303 .65854 L .59819 .65544 L p F P
0 g
s
0 .329 .811 r
.59621 .6527 m .59819 .65544 L .60303 .65854 L p F P
0 g
s
.651 .758 .928 r
.78201 .54892 m .79192 .54591 L .79403 .54868 L p F P
0 g
s
.651 .758 .928 r
.79192 .54591 m .78201 .54892 L .77987 .54615 L p F P
0 g
s
.99 .752 .373 r
.40662 .74985 m .40669 .74849 L .4067 .74852 L closepath p F P
0 g
s
.993 .748 .393 r
.40648 .75312 m .40662 .74985 L .4067 .74852 L p F P
0 g
s
.65 .757 .928 r
.34908 .54316 m .33995 .54618 L .34281 .54896 L p F P
0 g
s
.65 .757 .928 r
.34281 .54896 m .35193 .54595 L .34908 .54316 L p F P
0 g
s
.928 .819 .718 r
.47018 .74186 m .46815 .73922 L .46523 .74464 L p F P
0 g
s
.928 .819 .718 r
.46523 .74464 m .46737 .74724 L .47018 .74186 L p F P
0 g
s
.651 .757 .928 r
.64289 .54318 m .63323 .5462 L .63561 .54898 L p F P
0 g
s
.651 .757 .928 r
.63561 .54898 m .64526 .54597 L .64289 .54318 L p F P
0 g
s
.651 .757 .928 r
.49599 .54319 m .48659 .54621 L .48921 .54899 L p F P
0 g
s
.651 .757 .928 r
.48921 .54899 m .49859 .54598 L .49599 .54319 L p F P
0 g
s
.978 .753 .336 r
.40669 .74849 m .40545 .7456 L .40526 .75023 L p F P
0 g
s
.978 .753 .336 r
.40662 .74985 m .40669 .74849 L p .40526 .75023 L F P
0 g
s
.98 .908 .654 r
.47694 .71518 m .47646 .71205 L .47389 .71735 L p F P
0 g
s
.98 .908 .654 r
.47389 .71735 m .47467 .72039 L .47694 .71518 L p F P
0 g
s
.297 .332 .729 r
.58138 .73132 m .57917 .7351 L .58326 .73858 L p F P
0 g
s
.255 .278 .693 r
.57917 .7351 m .58138 .73132 L .57801 .72765 L p F P
0 g
s
.968 .851 .671 r
.47347 .72962 m .47398 .7284 L .47239 .72561 L p F P
0 g
s
.65 .757 .928 r
.21417 .54284 m .20528 .54585 L .20836 .54863 L p F P
0 g
s
.65 .757 .928 r
.20836 .54863 m .21724 .54563 L .21417 .54284 L p F P
0 g
s
.651 .758 .928 r
.79403 .54868 m .80396 .54566 L .80606 .54844 L p F P
0 g
s
.651 .758 .928 r
.80396 .54566 m .79403 .54868 L .79192 .54591 L p F P
0 g
s
.061 .168 .664 r
.63987 .71507 m .64009 .71364 L p .64217 .72084 L F P
0 g
s
.061 .168 .664 r
.64217 .72084 m .64133 .71964 L .63987 .71507 L p F P
0 g
s
.066 .196 .691 r
.63987 .71507 m .63878 .71202 L .64009 .71364 L closepath p F P
0 g
s
.523 .556 .83 r
.59802 .77492 m .59674 .77234 L .60068 .77262 L closepath p F P
0 g
s
.986 .901 .613 r
.47773 .70946 m .47873 .70684 L .47911 .70841 L closepath p F P
0 g
s
.958 .943 .644 r
.47646 .71205 m .47773 .70946 L .47911 .70841 L p F P
0 g
s
.065 .17 .664 r
.64198 .72169 m .64133 .71964 L .64217 .72084 L closepath p F P
0 g
s
.939 .906 .518 r
.48064 .70175 m .48103 .69834 L .47878 .70354 L p F P
0 g
s
.939 .906 .518 r
.47878 .70354 m .47873 .70684 L .48064 .70175 L p F P
0 g
s
.65 .757 .928 r
.36109 .54294 m .35193 .54595 L .35477 .54873 L p F P
0 g
s
.65 .757 .928 r
.35477 .54873 m .36392 .54573 L .36109 .54294 L p F P
0 g
s
.651 .758 .928 r
.65494 .54294 m .64526 .54597 L .64762 .54875 L p F P
0 g
s
.651 .758 .928 r
.64762 .54875 m .65728 .54573 L .65494 .54294 L p F P
0 g
s
0 .095 .612 r
.64217 .72084 m .64198 .72169 L .64372 .72794 L p F P
0 g
s
.117 .18 .653 r
.64362 .72821 m .64372 .72794 L .64198 .72169 L p F P
0 g
s
.651 .757 .928 r
.50801 .54296 m .49859 .54598 L .50119 .54876 L p F P
0 g
s
.651 .757 .928 r
.50119 .54876 m .5106 .54575 L .50801 .54296 L p F P
0 g
s
0 0 .473 r
.57044 .6986 m .57089 .70171 L .57282 .70573 L p F P
0 g
s
0 0 .417 r
.57089 .70171 m .57044 .6986 L .56878 .69451 L p F P
0 g
s
.049 .101 .596 r
.64392 .72883 m .64362 .72821 L .64372 .72794 L closepath p F P
0 g
s
.06 .194 .691 r
.64009 .71364 m .63878 .71202 L .63734 .70799 L p F P
0 g
s
.176 0 .303 r
.49496 .66833 m .49941 .665 L .49874 .66888 L p F P
0 g
s
.176 0 .303 r
.49874 .66888 m .49246 .67357 L .49496 .66833 L p F P
0 g
s
.65 .757 .928 r
.22616 .54262 m .21724 .54563 L .2203 .54842 L p F P
0 g
s
.65 .757 .928 r
.2203 .54842 m .22921 .54541 L .22616 .54262 L p F P
0 g
s
.651 .758 .928 r
.80606 .54844 m .81601 .54542 L .81809 .5482 L p F P
0 g
s
.651 .758 .928 r
.81601 .54542 m .80606 .54844 L .80396 .54566 L p F P
0 g
s
.936 .966 .737 r
.42097 .69491 m .42107 .69153 L .41746 .69711 L p F P
0 g
s
.936 .966 .737 r
.41746 .69711 m .41733 .70049 L .42097 .69491 L p F P
0 g
s
.65 .757 .928 r
.3731 .54271 m .36392 .54573 L .36674 .54851 L p F P
0 g
s
.65 .757 .928 r
.36674 .54851 m .37591 .5455 L .3731 .54271 L p F P
0 g
s
.651 .758 .928 r
.66699 .54271 m .65728 .54573 L .65962 .54851 L p F P
0 g
s
.651 .758 .928 r
.65962 .54851 m .66931 .5455 L .66699 .54271 L p F P
0 g
s
.651 .757 .928 r
.52004 .54272 m .5106 .54575 L .51318 .54852 L p F P
0 g
s
.651 .757 .928 r
.51318 .54852 m .52261 .54551 L .52004 .54272 L p F P
0 g
s
.649 .756 .928 r
.09123 .54209 m .08256 .54508 L .08584 .54788 L p F P
0 g
s
.649 .756 .928 r
.08584 .54788 m .0945 .5449 L .09123 .54209 L p F P
0 g
s
.273 .601 .952 r
.42883 .78146 m .42819 .78132 L .42567 .77887 L p F P
0 g
s
0 0 .055 r
.64218 .76206 m .64247 .7611 L .64231 .76136 L closepath p F P
0 g
s
0 0 .377 r
.64673 .74441 m .64486 .74803 L .64505 .75264 L p F P
0 g
s
.007 0 .489 r
.64486 .74803 m .64673 .74441 L .64575 .74002 L p F P
0 g
s
.968 .851 .671 r
.47239 .72561 m .47079 .72925 L .47347 .72962 L p F P
0 g
s
.945 .89 .745 r
.47347 .72962 m .47113 .73379 L .46979 .73093 L p F P
0 g
s
.945 .89 .745 r
.46979 .73093 m .47079 .72925 L .47347 .72962 L p F P
0 g
s
.759 .996 .841 r
.45047 .65781 m .45384 .65482 L p .44916 .65729 L F P
0 g
s
.759 .996 .841 r
.44916 .65729 m .44836 .65834 L .45047 .65781 L p F P
0 g
s
.822 .999 .828 r
.44836 .65834 m .45047 .65781 L .44675 .66142 L closepath p F P
0 g
s
.759 .996 .841 r
.45384 .65482 m .45704 .65044 L .44916 .65729 L p F P
0 g
s
.747 .983 .752 r
.63288 .77515 m .63582 .77227 L .63425 .77454 L closepath p F P
0 g
s
.794 .933 .568 r
.64022 .76639 m .63582 .77227 L .63425 .77454 L p F P
0 g
s
.815 .945 .909 r
.63425 .77454 m .63288 .77515 L p .62396 .78097 L F P
0 g
s
.65 .757 .928 r
.23815 .5424 m .22921 .54541 L .23225 .5482 L p F P
0 g
s
.65 .757 .928 r
.23225 .5482 m .24118 .54519 L .23815 .5424 L p F P
0 g
s
.651 .758 .928 r
.81809 .5482 m .82806 .54518 L .83012 .54796 L p F P
0 g
s
.651 .758 .928 r
.82806 .54518 m .81809 .5482 L .81601 .54542 L p F P
0 g
s
.06 .194 .691 r
.63734 .70799 m .63746 .7066 L p .64009 .71364 L F P
0 g
s
.068 .223 .716 r
.63734 .70799 m .63627 .70529 L .63746 .7066 L closepath p F P
0 g
s
.816 .999 .841 r
.44675 .66142 m .44836 .65834 L p .44243 .66379 L F P
0 g
s
.816 .999 .841 r
.44102 .66711 m .44675 .66142 L p .44243 .66379 L F P
0 g
s
.993 .879 .576 r
.40797 .72794 m .40705 .72492 L .40544 .72994 L p F P
0 g
s
.993 .879 .576 r
.40544 .72994 m .40636 .73296 L .40797 .72794 L p F P
0 g
s
.65 .757 .928 r
.38511 .54248 m .37591 .5455 L .37871 .54828 L p F P
0 g
s
.65 .757 .928 r
.37871 .54828 m .3879 .54527 L .38511 .54248 L p F P
0 g
s
.651 .758 .928 r
.67904 .54247 m .66931 .5455 L .67163 .54828 L p F P
0 g
s
.651 .758 .928 r
.67163 .54828 m .68135 .54526 L .67904 .54247 L p F P
0 g
s
0 .052 .571 r
.64372 .72794 m .64441 .72484 L p .64549 .73232 L F P
0 g
s
0 .052 .571 r
.64549 .73232 m .64392 .72883 L .64372 .72794 L p F P
0 g
s
0 .095 .612 r
.64372 .72794 m .64441 .72484 L .64217 .72084 L p F P
0 g
s
.978 .753 .336 r
.40526 .75023 m .40645 .75305 L .40662 .74985 L p F P
0 g
s
.991 .75 .38 r
.40645 .75305 m .40662 .74985 L .40648 .75312 L closepath p F P
0 g
s
.651 .757 .928 r
.53207 .54249 m .52261 .54551 L .52517 .54829 L p F P
0 g
s
.651 .757 .928 r
.52517 .54829 m .53462 .54528 L .53207 .54249 L p F P
0 g
s
0 0 0 r
.48541 .688 m .48763 .68402 L .48522 .68926 L p F P
0 g
s
0 0 0 r
.48466 .68999 m .48541 .688 L p .48522 .68926 L F P
0 g
s
.649 .756 .928 r
.1032 .54191 m .0945 .5449 L .09776 .54769 L p F P
0 g
s
.649 .756 .928 r
.09776 .54769 m .10645 .54471 L .1032 .54191 L p F P
0 g
s
.149 .426 .865 r
.60909 .66409 m .60467 .66137 L p .61098 .66735 L F P
0 g
s
.016 .353 .829 r
.60467 .66137 m .60909 .66409 L .60665 .66079 L p F P
0 g
s
.016 .353 .829 r
.60665 .66079 m .60303 .65854 L .60467 .66137 L p F P
0 g
s
.888 .804 .76 r
.45968 .76466 m .46206 .76113 L .45955 .75866 L p F P
0 g
s
0 0 0 r
.64247 .7611 m .64434 .75751 L p .64137 .76486 L F P
0 g
s
0 0 0 r
.64137 .76486 m .64218 .76206 L .64247 .7611 L p F P
0 g
s
0 0 .189 r
.64247 .7611 m .64434 .75751 L .64505 .75264 L p F P
0 g
s
0 .054 .572 r
.64507 .73377 m .64392 .72883 L .64549 .73232 L closepath p F P
0 g
s
.97 .932 .662 r
.41169 .7145 m .41124 .71132 L .40873 .71659 L p F P
0 g
s
.97 .932 .662 r
.40873 .71659 m .40913 .71978 L .41169 .7145 L p F P
0 g
s
.574 .657 .893 r
.61132 .78084 m .60956 .78102 L .61072 .77995 L closepath p F P
0 g
s
.584 .613 .848 r
.60887 .77725 m .61072 .77995 L .60956 .78102 L p F P
0 g
s
.633 .78 .952 r
.4354 .77652 m .42611 .77897 L .42883 .78146 L p F P
0 g
s
.633 .78 .952 r
.42883 .78146 m .43811 .77884 L .4354 .77652 L p F P
0 g
s
.273 .601 .952 r
.42567 .77887 m .42611 .77897 L .42883 .78146 L p F P
0 g
s
0 0 .275 r
.56771 .69156 m .56878 .69451 L .57044 .6986 L p F P
0 g
s
.673 .356 0 r
.56878 .69451 m .56771 .69156 L .56626 .68743 L p F P
0 g
s
.651 .758 .928 r
.83012 .54796 m .84012 .54493 L .84216 .54771 L p F P
0 g
s
.651 .758 .928 r
.84012 .54493 m .83012 .54796 L .82806 .54518 L p F P
0 g
s
.65 .757 .928 r
.25014 .54218 m .24118 .54519 L .2442 .54798 L p F P
0 g
s
.65 .757 .928 r
.2442 .54798 m .25316 .54497 L .25014 .54218 L p F P
0 g
s
.72 .916 .961 r
.62334 .78069 m .62475 .77996 L .62396 .78097 L closepath p F P
0 g
s
.815 .945 .909 r
.63288 .77515 m .62475 .77996 L .62396 .78097 L p F P
0 g
s
.816 .999 .841 r
.44243 .66379 m .44057 .6672 L .44102 .66711 L p F P
0 g
s
.86 .994 .823 r
.44057 .6672 m .44102 .66711 L .44035 .66782 L closepath p F P
0 g
s
.651 .758 .928 r
.69109 .54224 m .68135 .54526 L .68365 .54804 L p F P
0 g
s
.651 .758 .928 r
.68365 .54804 m .69338 .54503 L .69109 .54224 L p F P
0 g
s
.65 .757 .928 r
.39712 .54225 m .3879 .54527 L .39068 .54805 L p F P
0 g
s
.65 .757 .928 r
.39068 .54805 m .3999 .54504 L .39712 .54225 L p F P
0 g
s
.651 .757 .928 r
.54411 .54226 m .53462 .54528 L .53716 .54806 L p F P
0 g
s
.651 .757 .928 r
.53716 .54806 m .54664 .54505 L .54411 .54226 L p F P
0 g
s
.842 .999 .795 r
.44035 .66782 m .43495 .67391 L .43632 .67011 L p F P
0 g
s
.842 .999 .795 r
.44057 .6672 m .44035 .66782 L p .43632 .67011 L F P
0 g
s
.531 .537 .807 r
.60068 .77262 m .59674 .77234 L .59423 .76673 L p F P
0 g
s
.649 .756 .928 r
.11517 .54171 m .10645 .54471 L .10969 .5475 L p F P
0 g
s
.649 .756 .928 r
.10969 .5475 m .1184 .54451 L .11517 .54171 L p F P
0 g
s
.981 .913 .629 r
.40823 .72193 m .40913 .71978 L .40937 .721 L closepath p F P
0 g
s
.986 .901 .621 r
.40705 .72492 m .40823 .72193 L .40937 .721 L p F P
0 g
s
.205 .267 .706 r
.57929 .72451 m .57801 .72765 L .58138 .73132 L p F P
0 g
s
.2 .263 .705 r
.57896 .72349 m .5766 .72026 L p .57801 .72765 L F P
0 g
s
.2 .263 .705 r
.57801 .72765 m .57929 .72451 L .57896 .72349 L p F P
0 g
s
.06 .22 .716 r
.63746 .7066 m .63627 .70529 L .6343 .70038 L p F P
0 g
s
.408 .139 .39 r
.49941 .665 m .50004 .66109 L .50865 .65747 L p F P
0 g
s
.406 .143 .399 r
.50915 .65346 m .50865 .65747 L .50004 .66109 L p F P
0 g
s
.827 .507 .448 r
.54528 .65443 m .53985 .65269 L .54092 .65687 L p F P
0 g
s
.827 .507 .448 r
.54092 .65687 m .54617 .65867 L .54528 .65443 L p F P
0 g
s
.789 .806 .866 r
.43877 .77836 m .43811 .77884 L .44081 .78121 L p F P
0 g
s
.789 .806 .866 r
.44081 .78121 m .44139 .78078 L .43877 .77836 L p F P
0 g
s
.651 .758 .928 r
.84216 .54771 m .85218 .54468 L .8542 .54746 L p F P
0 g
s
.651 .758 .928 r
.85218 .54468 m .84216 .54771 L .84012 .54493 L p F P
0 g
s
.65 .757 .928 r
.26214 .54196 m .25316 .54497 L .25616 .54776 L p F P
0 g
s
.65 .757 .928 r
.25616 .54776 m .26514 .54475 L .26214 .54196 L p F P
0 g
s
.779 .81 .878 r
.4502 .77466 m .44139 .78078 L .43877 .77836 L p F P
0 g
s
0 0 0 r
.64022 .76639 m .64137 .76486 L .64218 .76206 L closepath p F P
0 g
s
.651 .758 .928 r
.69566 .54781 m .70542 .54479 L .70769 .54757 L p F P
0 g
s
.651 .758 .928 r
.70315 .542 m .69338 .54503 L .69566 .54781 L p F P
0 g
s
.651 .758 .928 r
.69566 .54781 m .70542 .54479 L .70315 .542 L p F P
0 g
s
.65 .757 .928 r
.40914 .54202 m .3999 .54504 L .40266 .54782 L p F P
0 g
s
.65 .757 .928 r
.40266 .54782 m .4119 .54481 L .40914 .54202 L p F P
0 g
s
.651 .757 .928 r
.55615 .54202 m .54664 .54505 L .54916 .54783 L p F P
0 g
s
.651 .757 .928 r
.54916 .54783 m .55866 .54482 L .55615 .54202 L p F P
0 g
s
.992 .817 .443 r
.40623 .74081 m .40514 .73787 L .40439 .74265 L p F P
0 g
s
.992 .817 .443 r
.40439 .74265 m .40545 .7456 L .40623 .74081 L p F P
0 g
s
0 .08 .608 r
.64268 .71753 m .64217 .72084 L .64441 .72484 L p F P
0 g
s
.061 .168 .664 r
.64009 .71364 m .64268 .71753 L .64217 .72084 L p F P
0 g
s
.649 .756 .928 r
.12715 .54151 m .1184 .54451 L .12163 .54731 L p F P
0 g
s
.649 .756 .928 r
.12163 .54731 m .13036 .54432 L .12715 .54151 L p F P
0 g
s
.651 .758 .928 r
.8542 .54746 m .86424 .54443 L .86624 .54721 L p F P
0 g
s
.651 .758 .928 r
.86424 .54443 m .8542 .54746 L .85218 .54468 L p F P
0 g
s
.051 0 .208 r
.49152 .67544 m .49246 .67357 L .49182 .67413 L closepath p F P
0 g
s
0 0 .173 r
.49001 .67881 m .49152 .67544 L .49182 .67413 L p F P
0 g
s
.843 .479 0 r
.56626 .68743 m .56463 .68463 L .56332 .68046 L p F P
0 g
s
.65 .757 .928 r
.27414 .54173 m .26514 .54475 L .26812 .54753 L p F P
0 g
s
.65 .757 .928 r
.26812 .54753 m .27712 .54453 L .27414 .54173 L p F P
0 g
s
.651 .758 .928 r
.70769 .54757 m .71747 .54455 L .71971 .54734 L p F P
0 g
s
.651 .758 .928 r
.71747 .54455 m .70769 .54757 L .70542 .54479 L p F P
0 g
s
0 0 0 r
.48522 .68926 m .48381 .69197 L .48466 .68999 L p F P
0 g
s
0 0 0 r
.48381 .69197 m .48466 .68999 L .48328 .69315 L closepath p F P
0 g
s
.65 .757 .928 r
.42117 .54178 m .4119 .54481 L .41464 .54759 L p F P
0 g
s
.65 .757 .928 r
.41464 .54759 m .4239 .54458 L .42117 .54178 L p F P
0 g
s
.651 .757 .928 r
.56819 .54179 m .55866 .54482 L .56116 .5476 L p F P
0 g
s
.651 .757 .928 r
.56116 .5476 m .57068 .54458 L .56819 .54179 L p F P
0 g
s
.789 .373 0 r
.41169 .76725 m .41168 .76723 L .41166 .76721 L closepath p F P
0 g
s
0 .051 .598 r
.41169 .76725 m .41166 .76721 L p .41332 .76818 L F P
0 g
s
0 .051 .598 r
.41332 .76818 m .41506 .77088 L .41169 .76725 L p F P
0 g
s
.928 .819 .719 r
.46655 .74882 m .46737 .74724 L .46523 .74464 L p F P
0 g
s
.742 .355 0 r
.41008 .76449 m .41166 .76721 L .40903 .76208 L closepath p F P
0 g
s
.906 .536 .086 r
.4086 .76032 m .40903 .76208 L .41166 .76721 L p F P
0 g
s
0 .051 .598 r
.41166 .76721 m .41008 .76449 L .41332 .76818 L p F P
0 g
s
.888 .804 .76 r
.45955 .75866 m .457 .7624 L .45968 .76466 L p F P
0 g
s
.838 .814 .826 r
.45968 .76466 m .45727 .76709 L .45479 .76462 L p F P
0 g
s
.838 .814 .826 r
.45479 .76462 m .457 .7624 L .45968 .76466 L p F P
0 g
s
.043 .341 .82 r
.61154 .66773 m .61098 .66735 L .6104 .66599 L closepath p F P
0 g
s
.149 .426 .865 r
.61098 .66735 m .6104 .66599 L .60909 .66409 L p F P
0 g
s
.65 .757 .928 r
.13913 .54131 m .13036 .54432 L .13357 .54711 L p F P
0 g
s
.65 .757 .928 r
.13357 .54711 m .14232 .54411 L .13913 .54131 L p F P
0 g
s
.585 .802 .982 r
.61132 .78084 m .62095 .77879 L .62334 .78069 L p F P
0 g
s
.578 .659 .892 r
.61853 .77618 m .62095 .77879 L .61132 .78084 L p F P
0 g
s
.578 .659 .892 r
.6146 .7766 m .61853 .77618 L p .61132 .78084 L F P
0 g
s
.578 .659 .892 r
.61132 .78084 m .61072 .77995 L .6146 .7766 L p F P
0 g
s
.858 .996 .81 r
.43495 .67391 m .43632 .67011 L .43098 .6762 L p F P
0 g
s
.858 .996 .81 r
.43152 .67786 m .43495 .67391 L p .43098 .6762 L F P
0 g
s
.845 .808 .814 r
.45727 .76709 m .45479 .76462 L .44881 .77092 L p F P
0 g
s
.845 .808 .814 r
.44881 .77092 m .45137 .77337 L .45727 .76709 L p F P
0 g
s
.825 .467 .377 r
.55099 .66058 m .55222 .66473 L .54752 .66278 L p F P
0 g
s
.825 .467 .377 r
.54682 .65898 m .55099 .66058 L p .54752 .66278 L F P
0 g
s
.944 .863 .729 r
.47113 .73379 m .46979 .73093 L .46658 .73644 L p F P
0 g
s
.944 .863 .729 r
.46658 .73644 m .46815 .73922 L .47113 .73379 L p F P
0 g
s
.65 .757 .928 r
.28615 .54151 m .27712 .54453 L .28008 .54731 L p F P
0 g
s
.65 .757 .928 r
.28008 .54731 m .2891 .5443 L .28615 .54151 L p F P
0 g
s
.651 .758 .928 r
.71971 .54734 m .72951 .54432 L .73174 .5471 L p F P
0 g
s
.651 .758 .928 r
.72951 .54432 m .71971 .54734 L .71747 .54455 L p F P
0 g
s
0 0 .501 r
.64549 .73232 m .64507 .73377 L .64609 .73927 L p F P
0 g
s
.044 .065 .557 r
.64575 .74002 m .64609 .73927 L .64507 .73377 L p F P
0 g
s
.934 .968 .734 r
.41733 .70049 m .41746 .69711 L .41403 .70264 L p F P
0 g
s
.934 .968 .734 r
.41516 .70403 m .41733 .70049 L p .41403 .70264 L F P
0 g
s
.814 .999 .801 r
.43822 .66805 m .44243 .66379 L .44057 .6672 L closepath p F P
0 g
s
.842 .999 .795 r
.43632 .67011 m .43822 .66805 L .44057 .6672 L p F P
0 g
s
.65 .757 .928 r
.43319 .54155 m .4239 .54458 L .42662 .54736 L p F P
0 g
s
.65 .757 .928 r
.42662 .54736 m .4359 .54435 L .43319 .54155 L p F P
0 g
s
.651 .757 .928 r
.58024 .54156 m .57068 .54458 L .57317 .54737 L p F P
0 g
s
.651 .757 .928 r
.57317 .54737 m .58271 .54435 L .58024 .54156 L p F P
0 g
s
.913 .526 .115 r
.56112 .67781 m .56332 .68046 L .56463 .68463 L p F P
0 g
s
.919 .537 .127 r
.56332 .68046 m .56112 .67781 L .55991 .67363 L p F P
0 g
s
.979 .893 .666 r
.47467 .72039 m .47389 .71735 L .47136 .72265 L p F P
0 g
s
.979 .893 .666 r
.47136 .72265 m .47239 .72561 L .47467 .72039 L p F P
0 g
s
.9 .548 .075 r
.40903 .76208 m .4086 .76032 L .40776 .75898 L closepath p F P
0 g
s
.65 .757 .928 r
.15111 .54111 m .14232 .54411 L .14551 .54691 L p F P
0 g
s
.65 .757 .928 r
.14551 .54691 m .15429 .54391 L .15111 .54111 L p F P
0 g
s
.06 .22 .716 r
.6343 .70038 m .63431 .69969 L p .63746 .7066 L F P
0 g
s
.071 .25 .741 r
.6343 .70038 m .63377 .69917 L .63431 .69969 L closepath p F P
0 g
s
0 .12 .646 r
.64035 .71039 m .64009 .71364 L .64268 .71753 L p F P
0 g
s
.06 .194 .691 r
.63746 .7066 m .64035 .71039 L .64009 .71364 L p F P
0 g
s
.683 .849 .962 r
.62475 .77996 m .62334 .78069 L .62095 .77879 L p F P
0 g
s
.054 .441 .875 r
.41698 .77353 m .41506 .77088 L p .42282 .77584 L F P
0 g
s
.054 .441 .875 r
.42282 .77584 m .42329 .77637 L .41698 .77353 L p F P
0 g
s
.65 .757 .928 r
.29816 .54128 m .2891 .5443 L .29205 .54709 L p F P
0 g
s
.65 .757 .928 r
.29205 .54709 m .30109 .54408 L .29816 .54128 L p F P
0 g
s
.07 .176 .669 r
.57896 .72349 m .5766 .72026 L .57714 .71783 L closepath p F P
0 g
s
.067 .174 .667 r
.5764 .71551 m .57487 .71295 L p .5766 .72026 L F P
0 g
s
.067 .174 .667 r
.5766 .72026 m .57714 .71783 L .5764 .71551 L p F P
0 g
s
.651 .758 .928 r
.73174 .5471 m .74156 .54408 L .74376 .54686 L p F P
0 g
s
.651 .758 .928 r
.74156 .54408 m .73174 .5471 L .72951 .54432 L p F P
0 g
s
.928 .819 .719 r
.46523 .74464 m .46387 .74717 L .46655 .74882 L p F P
0 g
s
.893 .842 .787 r
.46655 .74882 m .46357 .75292 L .46154 .75029 L p F P
0 g
s
.893 .842 .787 r
.46154 .75029 m .46387 .74717 L .46655 .74882 L p F P
0 g
s
.65 .757 .928 r
.44522 .54132 m .4359 .54435 L .43861 .54713 L p F P
0 g
s
.65 .757 .928 r
.43861 .54713 m .44791 .54412 L .44522 .54132 L p F P
0 g
s
.651 .757 .928 r
.59229 .54132 m .58271 .54435 L .58517 .54713 L p F P
0 g
s
.651 .757 .928 r
.58517 .54713 m .59474 .54412 L .59229 .54132 L p F P
0 g
s
.903 .533 .326 r
.55589 .66697 m .55222 .66473 L .5535 .66888 L p F P
0 g
s
.903 .533 .326 r
.5535 .66888 m .55707 .67115 L .55589 .66697 L p F P
0 g
s
.927 .544 .233 r
.55991 .67363 m .55707 .67115 L .55831 .67533 L p F P
0 g
s
.927 .544 .233 r
.55831 .67533 m .56112 .67781 L .55991 .67363 L p F P
0 g
s
.031 .314 .802 r
.61154 .66773 m .61534 .67063 L .6165 .67357 L p F P
0 g
s
0 .283 .785 r
.61534 .67063 m .61154 .66773 L .6104 .66599 L p F P
0 g
s
.119 0 .21 r
.49246 .67357 m .49874 .66888 L p .49689 .67342 L F P
0 g
s
.119 0 .21 r
.49152 .67544 m .49246 .67357 L p .49689 .67342 L F P
0 g
s
.029 .295 .788 r
.62158 .67991 m .62073 .6769 L .6165 .67357 L p F P
0 g
s
0 .286 .786 r
.61534 .67063 m .6165 .67357 L .62073 .6769 L p F P
0 g
s
.96 .931 .6 r
.47873 .70684 m .47878 .70354 L .47651 .70875 L p F P
0 g
s
.96 .931 .6 r
.47773 .70946 m .47873 .70684 L p .47651 .70875 L F P
0 g
s
.65 .757 .928 r
.1631 .5409 m .15429 .54391 L .15746 .5467 L p F P
0 g
s
.65 .757 .928 r
.15746 .5467 m .16626 .5437 L .1631 .5409 L p F P
0 g
s
.858 .996 .81 r
.43098 .6762 m .43021 .67824 L .43152 .67786 L p F P
0 g
s
.894 .986 .792 r
.43021 .67824 m .43152 .67786 L .42983 .67993 L closepath p F P
0 g
s
.054 .245 .741 r
.63431 .69969 m .63377 .69917 L .63129 .69364 L p F P
0 g
s
.85 .808 .809 r
.4502 .77466 m .45137 .77337 L .44881 .77092 L p F P
0 g
s
.486 .492 .788 r
.59423 .76673 m .59404 .76668 L .59417 .76657 L closepath p F P
0 g
s
.506 .471 .753 r
.59171 .76056 m .59417 .76657 L .59404 .76668 L p F P
0 g
s
.506 .471 .753 r
.5901 .76 m .59171 .76056 L p .59404 .76668 L F P
0 g
s
.453 .458 .773 r
.59171 .76056 m .5901 .76 L .59112 .759 L closepath p F P
0 g
s
.455 .461 .775 r
.58918 .75389 m .58734 .753 L p .5901 .76 L F P
0 g
s
.455 .461 .775 r
.5901 .76 m .59112 .759 L .58918 .75389 L p F P
0 g
s
.65 .757 .928 r
.31017 .54105 m .30109 .54408 L .30402 .54686 L p F P
0 g
s
.65 .757 .928 r
.30402 .54686 m .31308 .54385 L .31017 .54105 L p F P
0 g
s
0 0 .479 r
.64609 .73927 m .64575 .74002 L .64673 .74441 L p F P
0 g
s
.651 .758 .928 r
.74376 .54686 m .75361 .54384 L .7558 .54663 L p F P
0 g
s
.651 .758 .928 r
.75361 .54384 m .74376 .54686 L .74156 .54408 L p F P
0 g
s
.683 .849 .962 r
.62095 .77879 m .62757 .77615 L .62475 .77996 L p F P
0 g
s
.705 .969 .932 r
.63055 .77486 m .62757 .77615 L .62475 .77996 L p F P
0 g
s
.705 .969 .932 r
.62475 .77996 m .63288 .77515 L .63055 .77486 L p F P
0 g
s
.57 .292 .455 r
.50865 .65747 m .50915 .65346 L .51945 .65151 L p F P
0 g
s
.579 .661 .893 r
.61072 .77995 m .60887 .77725 L .6146 .7766 L closepath p F P
0 g
s
.65 .757 .928 r
.45725 .54109 m .44791 .54412 L .4506 .5469 L p F P
0 g
s
.65 .757 .928 r
.4506 .5469 m .45993 .54388 L .45725 .54109 L p F P
0 g
s
.651 .757 .928 r
.60434 .54109 m .59474 .54412 L .59718 .5469 L p F P
0 g
s
.651 .757 .928 r
.59718 .5469 m .60677 .54388 L .60434 .54109 L p F P
0 g
s
.85 .808 .809 r
.44881 .77092 m .44752 .77233 L .4502 .77466 L p F P
0 g
s
.779 .81 .878 r
.43877 .77836 m .44752 .77233 L .4502 .77466 L p F P
0 g
s
.531 .537 .807 r
.59423 .76673 m .60392 .7685 L p .60068 .77262 L F P
0 g
s
.459 .476 .789 r
.60142 .76343 m .60392 .7685 L .59423 .76673 L p F P
0 g
s
.459 .476 .789 r
.59822 .76244 m .60142 .76343 L p .59423 .76673 L F P
0 g
s
.459 .476 .789 r
.59423 .76673 m .59417 .76657 L .59822 .76244 L p F P
0 g
s
.461 .479 .791 r
.59417 .76657 m .59171 .76056 L .59822 .76244 L closepath p F P
0 g
s
0 .149 .675 r
.63746 .7034 m .63746 .7066 L .64035 .71039 L p F P
0 g
s
.06 .22 .716 r
.63431 .69969 m .63746 .7034 L .63746 .7066 L p F P
0 g
s
.65 .757 .928 r
.17509 .54069 m .16626 .5437 L .16941 .54649 L p F P
0 g
s
.65 .757 .928 r
.16941 .54649 m .17823 .54349 L .17509 .54069 L p F P
0 g
s
.881 .992 .759 r
.42983 .67993 m .42534 .68576 L .42615 .68214 L p F P
0 g
s
.881 .992 .759 r
.43021 .67824 m .42983 .67993 L p .42615 .68214 L F P
0 g
s
.072 .301 .785 r
.62629 .68637 m .62577 .68328 L .62158 .67991 L p F P
0 g
s
.08 .333 .809 r
.62073 .6769 m .62158 .67991 L .62577 .68328 L p F P
0 g
s
.651 .758 .928 r
.7558 .54663 m .76567 .5436 L .76783 .54639 L p F P
0 g
s
.651 .758 .928 r
.76567 .5436 m .7558 .54663 L .75361 .54384 L p F P
0 g
s
.65 .757 .928 r
.32218 .54082 m .31308 .54385 L .31599 .54664 L p F P
0 g
s
.65 .757 .928 r
.31599 .54664 m .32508 .54362 L .32218 .54082 L p F P
0 g
s
.651 .757 .928 r
.61639 .54085 m .60677 .54388 L .6092 .54667 L p F P
0 g
s
.651 .757 .928 r
.6092 .54667 m .61881 .54365 L .61639 .54085 L p F P
0 g
s
.96 .676 .245 r
.4065 .75338 m .40648 .75312 L .40645 .75305 L closepath p F P
0 g
s
.967 .668 .264 r
.40648 .75312 m .4065 .75338 L .40776 .75898 L p F P
0 g
s
.651 .757 .928 r
.46929 .54086 m .45993 .54388 L .46259 .54667 L p F P
0 g
s
.651 .757 .928 r
.46259 .54667 m .47194 .54365 L .46929 .54086 L p F P
0 g
s
0 0 0 r
.48328 .69315 m .48381 .69197 L .4824 .69522 L p F P
0 g
s
0 0 0 r
.4824 .69522 m .48103 .69834 L .48328 .69315 L p F P
0 g
s
.972 .927 .63 r
.40913 .71978 m .40873 .71659 L .40651 .72178 L p F P
0 g
s
.972 .927 .63 r
.40823 .72193 m .40913 .71978 L p .40651 .72178 L F P
0 g
s
.706 .949 .664 r
.64137 .76486 m .64022 .76639 L .63582 .77227 L p F P
0 g
s
.899 .615 .111 r
.40645 .75305 m .40526 .75023 L .40582 .75466 L p F P
0 g
s
.899 .615 .111 r
.4065 .75338 m .40645 .75305 L p .40582 .75466 L F P
0 g
s
.934 .968 .734 r
.41403 .70264 m .41393 .70458 L .41516 .70403 L p F P
0 g
s
.953 .949 .715 r
.41393 .70458 m .41516 .70403 L .41402 .70598 L closepath p F P
0 g
s
.413 .422 .759 r
.58918 .75389 m .58734 .753 L .58842 .75177 L closepath p F P
0 g
s
.414 .424 .761 r
.58663 .74678 m .58517 .74583 L p .58734 .753 L F P
0 g
s
.414 .424 .761 r
.58734 .753 m .58842 .75177 L .58663 .74678 L p F P
0 g
s
.119 0 .21 r
.49689 .67342 m .4909 .67779 L .49152 .67544 L p F P
0 g
s
0 0 .098 r
.4909 .67779 m .49152 .67544 L .49001 .67881 L closepath p F P
0 g
s
.899 .615 .111 r
.40582 .75466 m .40704 .75754 L .4065 .75338 L p F P
0 g
s
.927 .629 .155 r
.40704 .75754 m .40776 .75898 L .4065 .75338 L closepath p F P
0 g
s
.65 .757 .928 r
.18709 .54047 m .17823 .54349 L .18136 .54628 L p F P
0 g
s
.65 .757 .928 r
.18136 .54628 m .19021 .54327 L .18709 .54047 L p F P
0 g
s
0 .171 .697 r
.63405 .69655 m .63431 .69969 L .63746 .7034 L p F P
0 g
s
.054 .245 .741 r
.63129 .69364 m .63405 .69655 L .63431 .69969 L p F P
0 g
s
.126 .322 .79 r
.62883 .68857 m .62629 .68637 L p .63058 .69295 L F P
0 g
s
.023 .257 .758 r
.62629 .68637 m .62883 .68857 L .62636 .68381 L p F P
0 g
s
.023 .257 .758 r
.62636 .68381 m .62577 .68328 L .62629 .68637 L p F P
0 g
s
.651 .758 .928 r
.76783 .54639 m .77773 .54336 L .77987 .54615 L p F P
0 g
s
.651 .758 .928 r
.77773 .54336 m .76783 .54639 L .76567 .5436 L p F P
0 g
s
.993 .857 .51 r
.40636 .73296 m .40544 .72994 L .40423 .73485 L p F P
0 g
s
.993 .857 .51 r
.40423 .73485 m .40514 .73787 L .40636 .73296 L p F P
0 g
s
.65 .757 .928 r
.3342 .5406 m .32508 .54362 L .32797 .54641 L p F P
0 g
s
.65 .757 .928 r
.32797 .54641 m .33708 .54339 L .3342 .5406 L p F P
0 g
s
.894 .825 .771 r
.46357 .75292 m .46154 .75029 L .45736 .75608 L p F P
0 g
s
.894 .825 .771 r
.45736 .75608 m .45955 .75866 L .46357 .75292 L p F P
0 g
s
.651 .757 .928 r
.62845 .54062 m .61881 .54365 L .62121 .54643 L p F P
0 g
s
.651 .757 .928 r
.62121 .54643 m .63085 .54341 L .62845 .54062 L p F P
0 g
s
.651 .757 .928 r
.48133 .54062 m .47194 .54365 L .47459 .54644 L p F P
0 g
s
.651 .757 .928 r
.47459 .54644 m .48396 .54342 L .48133 .54062 L p F P
0 g
s
0 .053 .603 r
.5764 .71551 m .57487 .71295 L .57493 .71109 L closepath p F P
0 g
s
0 .048 .599 r
.57384 .70778 m .57282 .70573 L p .57487 .71295 L F P
0 g
s
0 .048 .599 r
.57487 .71295 m .57493 .71109 L .57384 .70778 L p F P
0 g
s
.045 .246 .744 r
.63129 .69364 m .63058 .69295 L .63052 .69196 L closepath p F P
0 g
s
.126 .322 .79 r
.63058 .69295 m .63052 .69196 L .62883 .68857 L p F P
0 g
s
.65 .757 .928 r
.19909 .54026 m .19021 .54327 L .19332 .54607 L p F P
0 g
s
.65 .757 .928 r
.19332 .54607 m .20219 .54306 L .19909 .54026 L p F P
0 g
s
.651 .758 .928 r
.77987 .54615 m .78979 .54312 L .79192 .54591 L p F P
0 g
s
.651 .758 .928 r
.78979 .54312 m .77987 .54615 L .77773 .54336 L p F P
0 g
s
.65 .757 .928 r
.34622 .54037 m .33708 .54339 L .33995 .54618 L p F P
0 g
s
.65 .757 .928 r
.33995 .54618 m .34908 .54316 L .34622 .54037 L p F P
0 g
s
.651 .757 .928 r
.64052 .54038 m .63085 .54341 L .63323 .5462 L p F P
0 g
s
.651 .757 .928 r
.63323 .5462 m .64289 .54318 L .64052 .54038 L p F P
0 g
s
.651 .757 .928 r
.49337 .54039 m .48396 .54342 L .48659 .54621 L p F P
0 g
s
.651 .757 .928 r
.48659 .54621 m .49599 .54319 L .49337 .54039 L p F P
0 g
s
.96 .931 .6 r
.47651 .70875 m .47658 .71062 L .47773 .70946 L p F P
0 g
s
.933 .945 .606 r
.47658 .71062 m .47773 .70946 L .47646 .71205 L closepath p F P
0 g
s
.699 .329 0 r
.40903 .76208 m .40776 .75898 L p .40865 .76168 L F P
0 g
s
.699 .329 0 r
.40865 .76168 m .41008 .76449 L .40903 .76208 L p F P
0 g
s
.51 .569 .852 r
.6064 .77311 m .60068 .77262 L .6041 .76883 L closepath p F P
0 g
s
.531 .537 .807 r
.60392 .7685 m .6041 .76883 L .60068 .77262 L p F P
0 g
s
0 0 .18 r
.64694 .74905 m .64505 .75264 L .64434 .75751 L p F P
0 g
s
0 0 .377 r
.6468 .74576 m .64673 .74441 L p .64505 .75264 L F P
0 g
s
0 0 .377 r
.64505 .75264 m .64694 .74905 L .6468 .74576 L p F P
0 g
s
0 .329 .811 r
.60303 .65854 m .60108 .6558 L .59621 .6527 L p F P
0 g
s
0 .309 .79 r
.59392 .65005 m .59621 .6527 L .60108 .6558 L p F P
0 g
s
.761 .454 .466 r
.53985 .65269 m .53232 .65157 L .53383 .65562 L p F P
0 g
s
.761 .454 .466 r
.53383 .65562 m .54092 .65687 L .53985 .65269 L p F P
0 g
s
.952 .953 .674 r
.41402 .70598 m .41124 .71132 L .41101 .70806 L p F P
0 g
s
.952 .953 .674 r
.41393 .70458 m .41402 .70598 L p .41101 .70806 L F P
0 g
s
0 0 .404 r
.64687 .73659 m .64609 .73927 L .64674 .74439 L p F P
0 g
s
0 0 .501 r
.64609 .73927 m .64687 .73659 L .64549 .73232 L p F P
0 g
s
0 0 .479 r
.64673 .74441 m .64674 .74439 L .64609 .73927 L p F P
0 g
s
0 .283 .785 r
.6104 .66599 m .60962 .66445 L p .61534 .67063 L F P
0 g
s
.002 .327 .812 r
.6104 .66599 m .60909 .66409 L .60962 .66445 L closepath p F P
0 g
s
.65 .757 .928 r
.21109 .54004 m .20219 .54306 L .20528 .54585 L p F P
0 g
s
.65 .757 .928 r
.20528 .54585 m .21417 .54284 L .21109 .54004 L p F P
0 g
s
.939 .848 .726 r
.46815 .73922 m .46658 .73644 L .46347 .74192 L p F P
0 g
s
.939 .848 .726 r
.46347 .74192 m .46523 .74464 L .46815 .73922 L p F P
0 g
s
.651 .758 .928 r
.79192 .54591 m .80186 .54288 L .80396 .54566 L p F P
0 g
s
.651 .758 .928 r
.80186 .54288 m .79192 .54591 L .78979 .54312 L p F P
0 g
s
.65 .757 .928 r
.35825 .54014 m .34908 .54316 L .35193 .54595 L p F P
0 g
s
.65 .757 .928 r
.35193 .54595 m .36109 .54294 L .35825 .54014 L p F P
0 g
s
.651 .757 .928 r
.65258 .54015 m .64289 .54318 L .64526 .54597 L p F P
0 g
s
.651 .757 .928 r
.64526 .54597 m .65494 .54294 L .65258 .54015 L p F P
0 g
s
.651 .757 .928 r
.50541 .54016 m .49599 .54319 L .49859 .54598 L p F P
0 g
s
.651 .757 .928 r
.49859 .54598 m .50801 .54296 L .50541 .54016 L p F P
0 g
s
.362 .38 .745 r
.58663 .74678 m .58517 .74583 L .58595 .74477 L closepath p F P
0 g
s
.364 .382 .746 r
.58408 .73928 m .58326 .73858 L p .58517 .74583 L F P
0 g
s
.364 .382 .746 r
.58517 .74583 m .58595 .74477 L .58408 .73928 L p F P
0 g
s
.472 .469 .774 r
.59822 .76244 m .59171 .76056 L .59112 .759 L p F P
0 g
s
.972 .927 .63 r
.40651 .72178 m .40668 .72329 L .40823 .72193 L p F P
0 g
s
.985 .905 .616 r
.40668 .72329 m .40823 .72193 L .40705 .72492 L closepath p F P
0 g
s
.893 .989 .775 r
.42534 .68576 m .42615 .68214 L .42181 .68794 L p F P
0 g
s
.893 .989 .775 r
.42196 .69028 m .42534 .68576 L p .42181 .68794 L F P
0 g
s
0 0 .482 r
.57384 .70778 m .57282 .70573 L .57255 .70416 L closepath p F P
0 g
s
0 0 .473 r
.57129 .70062 m .57044 .6986 L p .57282 .70573 L F P
0 g
s
0 0 .473 r
.57282 .70573 m .57255 .70416 L .57129 .70062 L p F P
0 g
s
.65 .757 .928 r
.2231 .53982 m .21417 .54284 L .21724 .54563 L p F P
0 g
s
.65 .757 .928 r
.21724 .54563 m .22616 .54262 L .2231 .53982 L p F P
0 g
s
.651 .758 .928 r
.80396 .54566 m .81392 .54263 L .81601 .54542 L p F P
0 g
s
.651 .758 .928 r
.81392 .54263 m .80396 .54566 L .80186 .54288 L p F P
0 g
s
.472 .469 .774 r
.59112 .759 m .59393 .75584 L p .59822 .76244 L F P
0 g
s
.427 .444 .775 r
.59112 .759 m .58918 .75389 L .59393 .75584 L closepath p F P
0 g
s
.699 .329 0 r
.40776 .75898 m .40704 .75754 L .40865 .76168 L p F P
0 g
s
.65 .757 .928 r
.37028 .53991 m .36109 .54294 L .36392 .54573 L p F P
0 g
s
.65 .757 .928 r
.36392 .54573 m .3731 .54271 L .37028 .53991 L p F P
0 g
s
0 0 .491 r
.64626 .72897 m .64549 .73232 L .64687 .73659 L p F P
0 g
s
0 .052 .571 r
.64441 .72484 m .64626 .72897 L .64549 .73232 L p F P
0 g
s
.651 .758 .928 r
.66465 .53991 m .65494 .54294 L .65728 .54573 L p F P
0 g
s
.651 .758 .928 r
.65728 .54573 m .66699 .54271 L .66465 .53991 L p F P
0 g
s
0 .206 .722 r
.63405 .69655 m .63129 .69364 L .63052 .69196 L p F P
0 g
s
.651 .757 .928 r
.51746 .53993 m .50801 .54296 L .5106 .54575 L p F P
0 g
s
.651 .757 .928 r
.5106 .54575 m .52004 .54272 L .51746 .53993 L p F P
0 g
s
.649 .756 .928 r
.08795 .53928 m .07927 .54228 L .08256 .54508 L p F P
0 g
s
.649 .756 .928 r
.08256 .54508 m .09123 .54209 L .08795 .53928 L p F P
0 g
s
.765 .995 .865 r
.63582 .77227 m .63288 .77515 L .63055 .77486 L p F P
0 g
s
.765 .995 .865 r
.63055 .77486 m .63852 .76848 L .63582 .77227 L p F P
0 g
s
.706 .949 .664 r
.64005 .76683 m .64137 .76486 L p .63582 .77227 L F P
0 g
s
.706 .949 .664 r
.63582 .77227 m .63852 .76848 L .64005 .76683 L p F P
0 g
s
.969 .886 .692 r
.47239 .72561 m .47136 .72265 L .46883 .72796 L p F P
0 g
s
.969 .886 .692 r
.47079 .72925 m .47239 .72561 L p .46883 .72796 L F P
0 g
s
.962 .746 .301 r
.40545 .7456 m .40439 .74265 L .40421 .74728 L p F P
0 g
s
.962 .746 .301 r
.40421 .74728 m .40526 .75023 L .40545 .7456 L p F P
0 g
s
.825 .467 .377 r
.54752 .66278 m .54645 .65982 L .54682 .65898 L p F P
0 g
s
.867 .523 .396 r
.54645 .65982 m .54617 .65867 L .54682 .65898 L closepath p F P
0 g
s
.265 .589 .947 r
.42611 .77897 m .42567 .77887 L .42329 .77637 L p F P
0 g
s
.65 .757 .928 r
.23511 .5396 m .22616 .54262 L .22921 .54541 L p F P
0 g
s
.65 .757 .928 r
.22921 .54541 m .23815 .5424 L .23511 .5396 L p F P
0 g
s
.651 .758 .928 r
.81601 .54542 m .826 .54239 L .82806 .54518 L p F P
0 g
s
.651 .758 .928 r
.826 .54239 m .81601 .54542 L .81392 .54263 L p F P
0 g
s
.65 .757 .928 r
.38231 .53968 m .3731 .54271 L .37591 .5455 L p F P
0 g
s
.65 .757 .928 r
.37591 .5455 m .38511 .54248 L .38231 .53968 L p F P
0 g
s
.651 .758 .928 r
.67672 .53967 m .66699 .54271 L .66931 .5455 L p F P
0 g
s
.651 .758 .928 r
.66931 .5455 m .67904 .54247 L .67672 .53967 L p F P
0 g
s
0 0 .087 r
.49001 .67881 m .4909 .67779 L .48992 .68141 L p F P
0 g
s
0 0 .087 r
.48992 .68141 m .48763 .68402 L .49001 .67881 L p F P
0 g
s
.651 .757 .928 r
.52952 .53969 m .52004 .54272 L .52261 .54551 L p F P
0 g
s
.651 .757 .928 r
.52261 .54551 m .53207 .54249 L .52952 .53969 L p F P
0 g
s
.649 .756 .928 r
.09993 .53909 m .09123 .54209 L .0945 .5449 L p F P
0 g
s
.649 .756 .928 r
.0945 .5449 m .1032 .54191 L .09993 .53909 L p F P
0 g
s
.904 .954 .613 r
.47646 .71205 m .47389 .71735 L .47398 .71405 L p F P
0 g
s
.904 .954 .613 r
.47658 .71062 m .47646 .71205 L p .47398 .71405 L F P
0 g
s
.898 .824 .767 r
.457 .7624 m .45955 .75866 L .45736 .75608 L p F P
0 g
s
.623 .781 .957 r
.43268 .77423 m .42339 .77639 L .42611 .77897 L p F P
0 g
s
.623 .781 .957 r
.42611 .77897 m .4354 .77652 L .43268 .77423 L p F P
0 g
s
.265 .589 .947 r
.42329 .77637 m .42339 .77639 L .42611 .77897 L p F P
0 g
s
.824 .481 .407 r
.54617 .65867 m .54092 .65687 L .54213 .66103 L p F P
0 g
s
.824 .481 .407 r
.54645 .65982 m .54617 .65867 L p .54213 .66103 L F P
0 g
s
0 0 0 r
.48381 .69197 m .48522 .68926 L .48277 .69452 L p F P
0 g
s
0 0 0 r
.48277 .69452 m .4824 .69522 L .48381 .69197 L p F P
0 g
s
.651 .758 .928 r
.82806 .54518 m .83807 .54214 L .84012 .54493 L p F P
0 g
s
.651 .758 .928 r
.83807 .54214 m .82806 .54518 L .826 .54239 L p F P
0 g
s
0 .206 .722 r
.63052 .69196 m .63017 .68984 L p .63405 .69655 L F P
0 g
s
.009 .243 .75 r
.63052 .69196 m .62883 .68857 L .63017 .68984 L closepath p F P
0 g
s
.65 .757 .928 r
.24712 .53938 m .23815 .5424 L .24118 .54519 L p F P
0 g
s
.65 .757 .928 r
.24118 .54519 m .25014 .54218 L .24712 .53938 L p F P
0 g
s
0 0 .292 r
.57129 .70062 m .57044 .6986 L .56972 .69679 L closepath p F P
0 g
s
.833 .456 0 r
.56771 .69156 m .56875 .69439 L .56623 .68944 L p F P
0 g
s
0 0 .387 r
.56875 .69439 m .56623 .68944 L p .56851 .69384 L F P
0 g
s
0 0 .387 r
.56944 .69563 m .56875 .69439 L p .56851 .69384 L F P
0 g
s
0 0 .275 r
.56875 .69439 m .56771 .69156 L p .56921 .69542 L F P
0 g
s
0 0 .275 r
.57044 .6986 m .56875 .69439 L .56921 .69542 L F
.57044 .6986 m .56972 .69679 L .56875 .69439 L p F P
0 g
s
.296 .331 .728 r
.58408 .73928 m .58326 .73858 L .58364 .73793 L closepath p F P
0 g
s
.297 .332 .729 r
.58152 .73147 m .58138 .73132 L p .58326 .73858 L F P
0 g
s
.297 .332 .729 r
.58326 .73858 m .58364 .73793 L .58152 .73147 L p F P
0 g
s
.651 .758 .928 r
.6888 .53944 m .67904 .54247 L .68135 .54526 L p F P
0 g
s
.651 .758 .928 r
.68135 .54526 m .69109 .54224 L .6888 .53944 L p F P
0 g
s
.65 .757 .928 r
.39434 .53945 m .38511 .54248 L .3879 .54527 L p F P
0 g
s
.65 .757 .928 r
.3879 .54527 m .39712 .54225 L .39434 .53945 L p F P
0 g
s
.651 .757 .928 r
.54157 .53946 m .53207 .54249 L .53462 .54528 L p F P
0 g
s
.651 .757 .928 r
.53462 .54528 m .54411 .54226 L .54157 .53946 L p F P
0 g
s
.439 .438 .76 r
.59393 .75584 m .58918 .75389 L .58842 .75177 L p F P
0 g
s
.584 .631 .864 r
.6146 .7766 m .60887 .77725 L .6064 .77311 L p F P
0 g
s
.649 .756 .928 r
.11193 .5389 m .1032 .54191 L .10645 .54471 L p F P
0 g
s
.649 .756 .928 r
.10645 .54471 m .11517 .54171 L .11193 .5389 L p F P
0 g
s
0 .336 .815 r
.60303 .65854 m .60665 .66079 L .6042 .65775 L p F P
0 g
s
0 .336 .815 r
.6042 .65775 m .60108 .6558 L .60303 .65854 L p F P
0 g
s
.439 .438 .76 r
.58842 .75177 m .59063 .74896 L p .59393 .75584 L F P
0 g
s
.388 .407 .759 r
.58842 .75177 m .58663 .74678 L .59063 .74896 L closepath p F P
0 g
s
.789 .811 .87 r
.43628 .77589 m .4354 .77652 L .43811 .77884 L p F P
0 g
s
.789 .811 .87 r
.43811 .77884 m .43877 .77836 L .43628 .77589 L p F P
0 g
s
.651 .758 .928 r
.84012 .54493 m .85015 .54189 L .85218 .54468 L p F P
0 g
s
.651 .758 .928 r
.85015 .54189 m .84012 .54493 L .83807 .54214 L p F P
0 g
s
.65 .757 .928 r
.25914 .53915 m .25014 .54218 L .25316 .54497 L p F P
0 g
s
.65 .757 .928 r
.25316 .54497 m .26214 .54196 L .25914 .53915 L p F P
0 g
s
.893 .989 .775 r
.42181 .68794 m .42118 .69057 L .42196 .69028 L p F P
0 g
s
.921 .975 .757 r
.42118 .69057 m .42196 .69028 L .42107 .69153 L closepath p F P
0 g
s
.777 .822 .888 r
.44752 .77233 m .43877 .77836 L .43628 .77589 L p F P
0 g
s
.651 .758 .928 r
.70088 .5392 m .69109 .54224 L .69338 .54503 L p F P
0 g
s
.651 .758 .928 r
.69338 .54503 m .70315 .542 L .70088 .5392 L p F P
0 g
s
.65 .757 .928 r
.40638 .53921 m .39712 .54225 L .3999 .54504 L p F P
0 g
s
.65 .757 .928 r
.3999 .54504 m .40914 .54202 L .40638 .53921 L p F P
0 g
s
.651 .757 .928 r
.55363 .53922 m .54411 .54226 L .54664 .54505 L p F P
0 g
s
.651 .757 .928 r
.54664 .54505 m .55615 .54202 L .55363 .53922 L p F P
0 g
s
0 0 0 r
.48103 .69834 m .47878 .70354 L .48009 .69985 L p F P
0 g
s
0 0 0 r
.4824 .69522 m .48103 .69834 L p .48009 .69985 L F P
0 g
s
.746 .99 .795 r
.44771 .65859 m .44916 .65729 L .44836 .65834 L closepath p F P
0 g
s
.816 .999 .841 r
.44836 .65834 m .44771 .65859 L .44243 .66379 L p F P
0 g
s
.414 .138 .384 r
.49941 .665 m .5081 .66145 L p .50382 .66684 L F P
0 g
s
.414 .138 .384 r
.50382 .66684 m .49874 .66888 L .49941 .665 L p F P
0 g
s
.408 .139 .39 r
.50865 .65747 m .5081 .66145 L .49941 .665 L p F P
0 g
s
.649 .756 .928 r
.12392 .5387 m .11517 .54171 L .1184 .54451 L p F P
0 g
s
.649 .756 .928 r
.1184 .54451 m .12715 .54151 L .12392 .5387 L p F P
0 g
s
.981 .895 .554 r
.40705 .72492 m .40544 .72994 L .40472 .72686 L p F P
0 g
s
.981 .895 .554 r
.40668 .72329 m .40705 .72492 L p .40472 .72686 L F P
0 g
s
.859 .996 .766 r
.4287 .67892 m .43098 .6762 L .43021 .67824 L closepath p F P
0 g
s
.881 .992 .759 r
.42615 .68214 m .4287 .67892 L .43021 .67824 L p F P
0 g
s
.722 .412 .454 r
.53232 .65157 m .53168 .65151 L .53104 .65535 L p F P
0 g
s
.722 .412 .454 r
.53104 .65535 m .53383 .65562 L .53232 .65157 L p F P
0 g
s
.833 .456 0 r
.56623 .68944 m .566 .68879 L .56771 .69156 L p F P
0 g
s
.846 .472 0 r
.56771 .69156 m .566 .68879 L .56463 .68463 L p F P
0 g
s
.651 .758 .928 r
.85218 .54468 m .86223 .54164 L .86424 .54443 L p F P
0 g
s
.651 .758 .928 r
.86223 .54164 m .85218 .54468 L .85015 .54189 L p F P
0 g
s
0 0 0 r
.64434 .75751 m .64246 .76271 L .64137 .76486 L p F P
0 g
s
.69 .848 .429 r
.64005 .76683 m .64246 .76271 L .64137 .76486 L closepath p F P
0 g
s
.912 .98 .72 r
.42107 .69153 m .41746 .69711 L .41782 .69364 L p F P
0 g
s
.912 .98 .72 r
.42118 .69057 m .42107 .69153 L p .41782 .69364 L F P
0 g
s
.65 .757 .928 r
.27116 .53893 m .26214 .54196 L .26514 .54475 L p F P
0 g
s
.65 .757 .928 r
.26514 .54475 m .27414 .54173 L .27116 .53893 L p F P
0 g
s
0 .313 .803 r
.60962 .66445 m .60909 .66409 L .60665 .66079 L p F P
0 g
s
0 .015 .558 r
.64495 .72153 m .64441 .72484 L .64626 .72897 L p F P
0 g
s
0 .08 .608 r
.64441 .72484 m .64495 .72153 L .64268 .71753 L p F P
0 g
s
.657 .361 .459 r
.52144 .65145 m .51945 .65151 L .51889 .65546 L p F P
0 g
s
.57 .292 .455 r
.51945 .65151 m .51889 .65546 L .50865 .65747 L p F P
0 g
s
.673 .366 .445 r
.53168 .65151 m .52144 .65145 L .52357 .65531 L p F P
0 g
s
.673 .366 .445 r
.52357 .65531 m .53104 .65535 L .53168 .65151 L p F P
0 g
s
.651 .758 .928 r
.70542 .54479 m .71522 .54176 L .71747 .54455 L p F P
0 g
s
.651 .758 .928 r
.71296 .53896 m .70315 .542 L .70542 .54479 L p F P
0 g
s
.651 .758 .928 r
.70542 .54479 m .71522 .54176 L .71296 .53896 L p F P
0 g
s
.401 .404 .748 r
.59063 .74896 m .58663 .74678 L .58595 .74477 L p F P
0 g
s
.65 .757 .928 r
.41842 .53898 m .40914 .54202 L .4119 .54481 L p F P
0 g
s
.65 .757 .928 r
.4119 .54481 m .42117 .54178 L .41842 .53898 L p F P
0 g
s
.651 .757 .928 r
.56569 .53899 m .55615 .54202 L .55866 .54482 L p F P
0 g
s
.651 .757 .928 r
.55866 .54482 m .56819 .54179 L .56569 .53899 L p F P
0 g
s
.657 .361 .459 r
.51889 .65546 m .52357 .65531 L .52144 .65145 L p F P
0 g
s
.401 .404 .748 r
.58595 .74477 m .58787 .74193 L p .59063 .74896 L F P
0 g
s
.342 .368 .743 r
.58595 .74477 m .58408 .73928 L .58787 .74193 L closepath p F P
0 g
s
.65 .756 .928 r
.13592 .5385 m .12715 .54151 L .13036 .54432 L p F P
0 g
s
.65 .756 .928 r
.13036 .54432 m .13913 .54131 L .13592 .5385 L p F P
0 g
s
.857 .498 .371 r
.55222 .66473 m .54752 .66278 L .54903 .66686 L p F P
0 g
s
.857 .498 .371 r
.54903 .66686 m .5535 .66888 L .55222 .66473 L p F P
0 g
s
.898 .824 .767 r
.45736 .75608 m .45431 .76045 L .457 .7624 L p F P
0 g
s
.843 .836 .839 r
.457 .7624 m .45479 .76462 L .4527 .76202 L p F P
0 g
s
.843 .836 .839 r
.4527 .76202 m .45431 .76045 L .457 .7624 L p F P
0 g
s
.802 .455 .4 r
.54563 .66223 m .54645 .65982 L .54752 .66278 L closepath p F P
0 g
s
.824 .481 .407 r
.54213 .66103 m .54563 .66223 L .54645 .65982 L p F P
0 g
s
.964 .938 .641 r
.41124 .71132 m .41101 .70806 L .40852 .71333 L p F P
0 g
s
.964 .938 .641 r
.40852 .71333 m .40873 .71659 L .41124 .71132 L p F P
0 g
s
.206 .268 .707 r
.58152 .73147 m .58138 .73132 L .58143 .73118 L closepath p F P
0 g
s
.205 .267 .706 r
.58138 .73132 m .58143 .73118 L .57929 .72451 L p F P
0 g
s
.94 .848 .725 r
.46387 .74717 m .46523 .74464 L .46347 .74192 L p F P
0 g
s
.65 .757 .928 r
.28318 .5387 m .27414 .54173 L .27712 .54453 L p F P
0 g
s
.65 .757 .928 r
.27712 .54453 m .28615 .54151 L .28318 .5387 L p F P
0 g
s
.651 .758 .928 r
.71747 .54455 m .72728 .54153 L .72951 .54432 L p F P
0 g
s
.651 .758 .928 r
.72728 .54153 m .71747 .54455 L .71522 .54176 L p F P
0 g
s
.906 .512 .097 r
.5624 .68198 m .56463 .68463 L .566 .68879 L p F P
0 g
s
.913 .526 .115 r
.56463 .68463 m .5624 .68198 L .56112 .67781 L p F P
0 g
s
.969 .886 .692 r
.46883 .72796 m .46941 .72939 L .47079 .72925 L p F P
0 g
s
.953 .921 .738 r
.46941 .72939 m .47079 .72925 L .46979 .73093 L closepath p F P
0 g
s
.65 .757 .928 r
.43047 .53875 m .42117 .54178 L .4239 .54458 L p F P
0 g
s
.65 .757 .928 r
.4239 .54458 m .43319 .54155 L .43047 .53875 L p F P
0 g
s
.849 .821 .821 r
.45479 .76462 m .4527 .76202 L .44647 .7684 L p F P
0 g
s
.849 .821 .821 r
.44647 .7684 m .44881 .77092 L .45479 .76462 L p F P
0 g
s
.651 .757 .928 r
.57776 .53875 m .56819 .54179 L .57068 .54458 L p F P
0 g
s
.651 .757 .928 r
.57068 .54458 m .58024 .54156 L .57776 .53875 L p F P
0 g
s
.353 .368 .736 r
.58787 .74193 m .58408 .73928 L .58364 .73793 L p F P
0 g
s
.353 .368 .736 r
.58364 .73793 m .58537 .73482 L p .58787 .74193 L F P
0 g
s
.285 .324 .727 r
.58364 .73793 m .58152 .73147 L .58537 .73482 L closepath p F P
0 g
s
.942 .961 .68 r
.41227 .70572 m .41403 .70264 L .41393 .70458 L closepath p F P
0 g
s
.952 .953 .674 r
.41101 .70806 m .41227 .70572 L .41393 .70458 L p F P
0 g
s
.982 .815 .413 r
.40514 .73787 m .40423 .73485 L .40349 .73964 L p F P
0 g
s
.982 .815 .413 r
.40349 .73964 m .40439 .74265 L .40514 .73787 L p F P
0 g
s
.65 .757 .928 r
.14792 .53829 m .13913 .54131 L .14232 .54411 L p F P
0 g
s
.65 .757 .928 r
.14232 .54411 m .15111 .54111 L .14792 .53829 L p F P
0 g
s
.293 .325 .724 r
.58537 .73482 m .58152 .73147 L .58143 .73118 L p F P
0 g
s
.293 .325 .724 r
.58143 .73118 m .58293 .72769 L p .58537 .73482 L F P
0 g
s
.213 .272 .708 r
.57949 .72404 m .57929 .72451 L .58143 .73118 L p F P
0 g
s
.213 .272 .708 r
.58143 .73118 m .58293 .72769 L .57949 .72404 L p F P
0 g
s
.219 .276 .709 r
.57929 .72451 m .57896 .72349 L .57949 .72404 L closepath p F P
0 g
s
.217 .275 .709 r
.57949 .72404 m .57896 .72349 L .57714 .71783 L p F P
0 g
s
.128 .215 .686 r
.57714 .71783 m .5764 .71551 L .57745 .71681 L closepath p F P
0 g
s
.104 .207 .687 r
.57745 .71681 m .5764 .71551 L .57493 .71109 L p F P
0 g
s
.217 .275 .709 r
.57714 .71783 m .57745 .71681 L p .57949 .72404 L F P
0 g
s
.905 .529 .305 r
.55707 .67115 m .5535 .66888 L .55484 .67302 L p F P
0 g
s
.905 .529 .305 r
.55484 .67302 m .55831 .67533 L .55707 .67115 L p F P
0 g
s
0 .037 .593 r
.41008 .76449 m .40865 .76168 L .41172 .76542 L p F P
0 g
s
0 .037 .593 r
.41172 .76542 m .41332 .76818 L .41008 .76449 L p F P
0 g
s
.924 .535 .214 r
.56112 .67781 m .55831 .67533 L .55962 .67949 L p F P
0 g
s
.924 .535 .214 r
.55962 .67949 m .5624 .68198 L .56112 .67781 L p F P
0 g
s
.112 0 .201 r
.4909 .67779 m .49689 .67342 L .49316 .67905 L p F P
0 g
s
.112 0 .201 r
.49316 .67905 m .48992 .68141 L .4909 .67779 L p F P
0 g
s
0 .283 .785 r
.60962 .66445 m .6139 .66776 L .61534 .67063 L p F P
0 g
s
0 .253 .762 r
.60789 .66165 m .60962 .66445 L .6139 .66776 L p F P
0 g
s
0 .313 .803 r
.60665 .66079 m .60789 .66165 L .60962 .66445 L p F P
0 g
s
.65 .757 .928 r
.29521 .53847 m .28615 .54151 L .2891 .5443 L p F P
0 g
s
.65 .757 .928 r
.2891 .5443 m .29816 .54128 L .29521 .53847 L p F P
0 g
s
.651 .758 .928 r
.72951 .54432 m .73935 .54129 L .74156 .54408 L p F P
0 g
s
.651 .758 .928 r
.73935 .54129 m .72951 .54432 L .72728 .54153 L p F P
0 g
s
.104 .207 .687 r
.57493 .71109 m .57514 .70966 L p .57745 .71681 L F P
0 g
s
.007 .139 .653 r
.57493 .71109 m .57384 .70778 L .57514 .70966 L closepath p F P
0 g
s
.65 .757 .928 r
.44252 .53852 m .43319 .54155 L .4359 .54435 L p F P
0 g
s
.65 .757 .928 r
.4359 .54435 m .44522 .54132 L .44252 .53852 L p F P
0 g
s
.651 .757 .928 r
.58983 .53852 m .58024 .54156 L .58271 .54435 L p F P
0 g
s
.651 .757 .928 r
.58271 .54435 m .59229 .54132 L .58983 .53852 L p F P
0 g
s
0 0 .352 r
.6468 .74576 m .64673 .74441 L .64674 .74439 L closepath p F P
0 g
s
0 0 .299 r
.64674 .74439 m .6477 .74102 L p .64696 .74902 L F P
0 g
s
0 0 .299 r
.64696 .74902 m .6468 .74576 L .64674 .74439 L p F P
0 g
s
0 0 .404 r
.64674 .74439 m .6477 .74102 L .64687 .73659 L p F P
0 g
s
0 .111 .645 r
.57514 .70966 m .57384 .70778 L .57255 .70416 L p F P
0 g
s
0 .236 .748 r
.63017 .68984 m .62883 .68857 L .62636 .68381 L p F P
0 g
s
.65 .757 .928 r
.15993 .53809 m .15111 .54111 L .15429 .54391 L p F P
0 g
s
.65 .757 .928 r
.15429 .54391 m .1631 .5409 L .15993 .53809 L p F P
0 g
s
.947 .929 .752 r
.46979 .73093 m .46658 .73644 L .46558 .73348 L p F P
0 g
s
.947 .929 .752 r
.46941 .72939 m .46979 .73093 L p .46558 .73348 L F P
0 g
s
.854 .821 .815 r
.44752 .77233 m .44881 .77092 L .44647 .7684 L p F P
0 g
s
.602 .851 .991 r
.62757 .77615 m .62095 .77879 L .61853 .77618 L p F P
0 g
s
.65 .757 .928 r
.30724 .53825 m .29816 .54128 L .30109 .54408 L p F P
0 g
s
.65 .757 .928 r
.30109 .54408 m .31017 .54105 L .30724 .53825 L p F P
0 g
s
.651 .758 .928 r
.74156 .54408 m .75142 .54105 L .75361 .54384 L p F P
0 g
s
.651 .758 .928 r
.75142 .54105 m .74156 .54408 L .73935 .54129 L p F P
0 g
s
0 .07 .608 r
.64297 .71428 m .64268 .71753 L .64495 .72153 L p F P
0 g
s
0 .12 .646 r
.64268 .71753 m .64297 .71428 L .64035 .71039 L p F P
0 g
s
.076 .42 .867 r
.42066 .77369 m .41506 .77088 L .41332 .76818 L p F P
0 g
s
.054 .441 .875 r
.41506 .77088 m .42066 .77369 L .42282 .77584 L p F P
0 g
s
.65 .757 .928 r
.45457 .53829 m .44522 .54132 L .44791 .54412 L p F P
0 g
s
.65 .757 .928 r
.44791 .54412 m .45725 .54109 L .45457 .53829 L p F P
0 g
s
.651 .757 .928 r
.6019 .53828 m .59229 .54132 L .59474 .54412 L p F P
0 g
s
.651 .757 .928 r
.59474 .54412 m .60434 .54109 L .6019 .53828 L p F P
0 g
s
.699 .352 0 r
.40704 .75754 m .40582 .75466 L .40737 .75882 L p F P
0 g
s
.699 .352 0 r
.40737 .75882 m .40865 .76168 L .40704 .75754 L p F P
0 g
s
0 .111 .645 r
.57255 .70416 m .57249 .70259 L p .57514 .70966 L F P
0 g
s
0 .04 .599 r
.57255 .70416 m .57129 .70062 L .57249 .70259 L closepath p F P
0 g
s
0 0 0 r
.64622 .7539 m .64434 .75751 L .64246 .76271 L p F P
0 g
s
0 0 .18 r
.64693 .7493 m .64694 .74905 L p .64434 .75751 L F P
0 g
s
0 0 .18 r
.64434 .75751 m .64622 .7539 L .64693 .7493 L p F P
0 g
s
.561 .278 .444 r
.5081 .66145 m .50865 .65747 L .51889 .65546 L p F P
0 g
s
.854 .821 .815 r
.44647 .7684 m .44482 .77017 L .44752 .77233 L p F P
0 g
s
.777 .822 .888 r
.43628 .77589 m .44482 .77017 L .44752 .77233 L p F P
0 g
s
.65 .757 .928 r
.17194 .53787 m .1631 .5409 L .16626 .5437 L p F P
0 g
s
.65 .757 .928 r
.16626 .5437 m .17509 .54069 L .17194 .53787 L p F P
0 g
s
.94 .848 .725 r
.46347 .74192 m .46118 .74599 L .46387 .74717 L p F P
0 g
s
.9 .874 .802 r
.46387 .74717 m .46154 .75029 L .45998 .74752 L p F P
0 g
s
.9 .874 .802 r
.45998 .74752 m .46118 .74599 L .46387 .74717 L p F P
0 g
s
.032 .172 .678 r
.58043 .72058 m .57949 .72404 L .58293 .72769 L p F P
0 g
s
.217 .275 .709 r
.57745 .71681 m .58043 .72058 L .57949 .72404 L p F P
0 g
s
0 0 .08 r
.48763 .68402 m .48992 .68141 L .48892 .68503 L p F P
0 g
s
0 0 .08 r
.48892 .68503 m .48522 .68926 L .48763 .68402 L p F P
0 g
s
.967 .935 .651 r
.47389 .71735 m .47398 .71405 L .47105 .71947 L p F P
0 g
s
.967 .935 .651 r
.47105 .71947 m .47136 .72265 L .47389 .71735 L p F P
0 g
s
.651 .758 .928 r
.75361 .54384 m .7635 .54081 L .76567 .5436 L p F P
0 g
s
.651 .758 .928 r
.7635 .54081 m .75361 .54384 L .75142 .54105 L p F P
0 g
s
.65 .757 .928 r
.31928 .53802 m .31017 .54105 L .31308 .54385 L p F P
0 g
s
.65 .757 .928 r
.31308 .54385 m .32218 .54082 L .31928 .53802 L p F P
0 g
s
.719 .984 .796 r
.44771 .65859 m .44916 .65729 L p .44499 .6596 L F P
0 g
s
.719 .984 .796 r
.44499 .6596 m .44495 .65965 L .44771 .65859 L p F P
0 g
s
.794 .997 .794 r
.44495 .65965 m .44771 .65859 L .44243 .66379 L closepath p F P
0 g
s
.651 .757 .928 r
.61397 .53805 m .60434 .54109 L .60677 .54388 L p F P
0 g
s
.651 .757 .928 r
.60677 .54388 m .61639 .54085 L .61397 .53805 L p F P
0 g
s
.651 .757 .928 r
.46662 .53805 m .45725 .54109 L .45993 .54388 L p F P
0 g
s
.651 .757 .928 r
.45993 .54388 m .46929 .54086 L .46662 .53805 L p F P
0 g
s
0 0 .556 r
.57249 .70259 m .57129 .70062 L .56972 .69679 L p F P
0 g
s
.719 .984 .796 r
.44916 .65729 m .45294 .65272 L .44499 .6596 L p F P
0 g
s
.685 .972 .776 r
.45704 .65044 m .44916 .65729 L .45294 .65272 L p F P
0 g
s
0 .286 .786 r
.62073 .6769 m .61961 .67395 L .61534 .67063 L p F P
0 g
s
0 .276 .78 r
.6139 .66776 m .61534 .67063 L .61961 .67395 L p F P
0 g
s
.96 .932 .604 r
.47501 .71216 m .47651 .70875 L .47658 .71062 L closepath p F P
0 g
s
.904 .954 .613 r
.47398 .71405 m .47501 .71216 L .47658 .71062 L p F P
0 g
s
.897 .985 .726 r
.41909 .69176 m .42181 .68794 L .42118 .69057 L closepath p F P
0 g
s
.912 .98 .72 r
.41782 .69364 m .41909 .69176 L .42118 .69057 L p F P
0 g
s
.65 .757 .928 r
.18396 .53766 m .17509 .54069 L .17823 .54349 L p F P
0 g
s
.65 .757 .928 r
.17823 .54349 m .18709 .54047 L .18396 .53766 L p F P
0 g
s
.789 .998 .806 r
.44243 .66379 m .44495 .65965 L p .43858 .66603 L F P
0 g
s
.789 .998 .806 r
.43822 .66805 m .44243 .66379 L p .43858 .66603 L F P
0 g
s
.685 .972 .776 r
.45711 .65035 m .45704 .65044 L p .45294 .65272 L F P
0 g
s
.651 .758 .928 r
.76567 .5436 m .77558 .54057 L .77773 .54336 L p F P
0 g
s
.651 .758 .928 r
.77558 .54057 m .76567 .5436 L .7635 .54081 L p F P
0 g
s
.65 .757 .928 r
.33131 .53779 m .32218 .54082 L .32508 .54362 L p F P
0 g
s
.65 .757 .928 r
.32508 .54362 m .3342 .5406 L .33131 .53779 L p F P
0 g
s
.927 .971 .698 r
.41746 .69711 m .41782 .69364 L .41443 .69917 L p F P
0 g
s
.927 .971 .698 r
.41443 .69917 m .41403 .70264 L .41746 .69711 L p F P
0 g
s
0 0 .304 r
.64694 .74905 m .6468 .74576 L .64696 .74902 L closepath p F P
0 g
s
.651 .757 .928 r
.62605 .53781 m .61639 .54085 L .61881 .54365 L p F P
0 g
s
.651 .757 .928 r
.61881 .54365 m .62845 .54062 L .62605 .53781 L p F P
0 g
s
.651 .757 .928 r
.47868 .53782 m .46929 .54086 L .47194 .54365 L p F P
0 g
s
.651 .757 .928 r
.47194 .54365 m .48133 .54062 L .47868 .53782 L p F P
0 g
s
0 .111 .646 r
.64038 .70719 m .64035 .71039 L .64297 .71428 L p F P
0 g
s
0 .149 .675 r
.64035 .71039 m .64038 .70719 L .63746 .7034 L p F P
0 g
s
.622 .949 .766 r
.4544 .65151 m .4627 .64528 L .45711 .65035 L closepath p F P
0 g
s
.685 .972 .776 r
.45294 .65272 m .4544 .65151 L .45711 .65035 L p F P
0 g
s
.65 .757 .928 r
.19598 .53745 m .18709 .54047 L .19021 .54327 L p F P
0 g
s
.65 .757 .928 r
.19021 .54327 m .19909 .54026 L .19598 .53745 L p F P
0 g
s
.789 .998 .806 r
.43858 .66603 m .43705 .66846 L .43822 .66805 L p F P
0 g
s
.843 .999 .795 r
.43705 .66846 m .43822 .66805 L .43632 .67011 L closepath p F P
0 g
s
.901 .849 .782 r
.46154 .75029 m .45998 .74752 L .45553 .7534 L p F P
0 g
s
.901 .849 .782 r
.45553 .7534 m .45736 .75608 L .46154 .75029 L p F P
0 g
s
.651 .758 .928 r
.77773 .54336 m .78766 .54032 L .78979 .54312 L p F P
0 g
s
.651 .758 .928 r
.78766 .54032 m .77773 .54336 L .77558 .54057 L p F P
0 g
s
.08 .333 .809 r
.62391 .67948 m .62073 .6769 L p .62577 .68328 L F P
0 g
s
0 .258 .768 r
.62073 .6769 m .62391 .67948 L .62146 .67549 L p F P
0 g
s
0 .258 .768 r
.62146 .67549 m .61961 .67395 L .62073 .6769 L p F P
0 g
s
.65 .757 .928 r
.34335 .53756 m .3342 .5406 L .33708 .54339 L p F P
0 g
s
.65 .757 .928 r
.33708 .54339 m .34622 .54037 L .34335 .53756 L p F P
0 g
s
.771 .454 .449 r
.54092 .65687 m .53383 .65562 L .53543 .65966 L p F P
0 g
s
.771 .454 .449 r
.53543 .65966 m .54213 .66103 L .54092 .65687 L p F P
0 g
s
.651 .757 .928 r
.63813 .53758 m .62845 .54062 L .63085 .54341 L p F P
0 g
s
.651 .757 .928 r
.63085 .54341 m .64052 .54038 L .63813 .53758 L p F P
0 g
s
.651 .757 .928 r
.49074 .53759 m .48133 .54062 L .48396 .54342 L p F P
0 g
s
.651 .757 .928 r
.48396 .54342 m .49337 .54039 L .49074 .53759 L p F P
0 g
s
.839 .886 .456 r
.47878 .70354 m .48009 .69985 L .47734 .70521 L p F P
0 g
s
.839 .886 .456 r
.47734 .70521 m .47651 .70875 L .47878 .70354 L p F P
0 g
s
.874 .602 .077 r
.40526 .75023 m .40421 .74728 L .40475 .75172 L p F P
0 g
s
.874 .602 .077 r
.40475 .75172 m .40582 .75466 L .40526 .75023 L p F P
0 g
s
.584 .631 .864 r
.6064 .77311 m .6161 .77301 L p .6146 .7766 L F P
0 g
s
.514 .571 .851 r
.61364 .76935 m .6161 .77301 L .6064 .77311 L p F P
0 g
s
.514 .571 .851 r
.60438 .76853 m .61364 .76935 L p .6064 .77311 L F P
0 g
s
.514 .571 .851 r
.6064 .77311 m .6041 .76883 L .60438 .76853 L p F P
0 g
s
.813 .993 .753 r
.43632 .67011 m .43098 .6762 L .43272 .67228 L p F P
0 g
s
.813 .993 .753 r
.43705 .66846 m .43632 .67011 L p .43272 .67228 L F P
0 g
s
0 .079 .627 r
.57776 .71351 m .57745 .71681 L .58043 .72058 L p F P
0 g
s
.104 .207 .687 r
.57514 .70966 m .57776 .71351 L .57745 .71681 L p F P
0 g
s
0 0 .556 r
.56972 .69679 m .56944 .69563 L p .57249 .70259 L F P
0 g
s
0 0 .503 r
.56972 .69679 m .56875 .69439 L .56944 .69563 L closepath p F P
0 g
s
0 .309 .79 r
.60108 .6558 m .59879 .65314 L .59392 .65005 L p F P
0 g
s
0 .284 .759 r
.59392 .65005 m .59131 .64747 L .59618 .65056 L p F P
0 g
s
0 .284 .759 r
.59618 .65056 m .59879 .65314 L .59392 .65005 L p F P
0 g
s
.65 .757 .928 r
.208 .53723 m .19909 .54026 L .20219 .54306 L p F P
0 g
s
.65 .757 .928 r
.20219 .54306 m .21109 .54004 L .208 .53723 L p F P
0 g
s
0 .14 .674 r
.63723 .70026 m .63746 .7034 L .64038 .70719 L p F P
0 g
s
0 .171 .697 r
.63746 .7034 m .63723 .70026 L .63405 .69655 L p F P
0 g
s
.651 .758 .928 r
.78979 .54312 m .79974 .54008 L .80186 .54288 L p F P
0 g
s
.651 .758 .928 r
.79974 .54008 m .78979 .54312 L .78766 .54032 L p F P
0 g
s
.65 .757 .928 r
.3554 .53733 m .34622 .54037 L .34908 .54316 L p F P
0 g
s
.65 .757 .928 r
.34908 .54316 m .35825 .54014 L .3554 .53733 L p F P
0 g
s
.651 .757 .928 r
.65022 .53734 m .64052 .54038 L .64289 .54318 L p F P
0 g
s
.651 .757 .928 r
.64289 .54318 m .65258 .54015 L .65022 .53734 L p F P
0 g
s
.651 .757 .928 r
.50281 .53735 m .49337 .54039 L .49599 .54319 L p F P
0 g
s
.651 .757 .928 r
.49599 .54319 m .50541 .54016 L .50281 .53735 L p F P
0 g
s
0 .242 .754 r
.62636 .68381 m .62577 .68328 L .6255 .68221 L closepath p F P
0 g
s
.08 .333 .809 r
.62577 .68328 m .6255 .68221 L .62391 .67948 L p F P
0 g
s
.972 .905 .554 r
.40526 .72524 m .40651 .72178 L .40668 .72329 L closepath p F P
0 g
s
.981 .895 .554 r
.40472 .72686 m .40526 .72524 L .40668 .72329 L p F P
0 g
s
.984 .859 .485 r
.40544 .72994 m .40472 .72686 L .40351 .73177 L p F P
0 g
s
.984 .859 .485 r
.40351 .73177 m .40423 .73485 L .40544 .72994 L p F P
0 g
s
.962 .927 .596 r
.40873 .71659 m .40852 .71333 L .40634 .71852 L p F P
0 g
s
.962 .927 .596 r
.40634 .71852 m .40651 .72178 L .40873 .71659 L p F P
0 g
s
0 0 .39 r
.64766 .73324 m .64687 .73659 L .6477 .74102 L p F P
0 g
s
0 0 .491 r
.64687 .73659 m .64766 .73324 L .64626 .72897 L p F P
0 g
s
0 .159 .693 r
.63355 .69347 m .63405 .69655 L .63723 .70026 L p F P
0 g
s
0 .206 .722 r
.63017 .68984 m .63355 .69347 L .63405 .69655 L p F P
0 g
s
.65 .757 .928 r
.22003 .53701 m .21109 .54004 L .21417 .54284 L p F P
0 g
s
.65 .757 .928 r
.21417 .54284 m .2231 .53982 L .22003 .53701 L p F P
0 g
s
.567 .686 .92 r
.61853 .77618 m .6146 .7766 L .61645 .77347 L closepath p F P
0 g
s
.584 .631 .864 r
.6161 .77301 m .61645 .77347 L .6146 .7766 L p F P
0 g
s
0 .171 .706 r
.62941 .68682 m .63017 .68984 L .63355 .69347 L p F P
0 g
s
0 .236 .748 r
.62636 .68381 m .62941 .68682 L .63017 .68984 L p F P
0 g
s
.651 .758 .928 r
.80186 .54288 m .81183 .53984 L .81392 .54263 L p F P
0 g
s
.651 .758 .928 r
.81183 .53984 m .80186 .54288 L .79974 .54008 L p F P
0 g
s
.65 .757 .928 r
.36745 .5371 m .35825 .54014 L .36109 .54294 L p F P
0 g
s
.65 .757 .928 r
.36109 .54294 m .37028 .53991 L .36745 .5371 L p F P
0 g
s
.651 .758 .928 r
.66231 .5371 m .65258 .54015 L .65494 .54294 L p F P
0 g
s
.651 .758 .928 r
.65494 .54294 m .66465 .53991 L .66231 .5371 L p F P
0 g
s
.649 .756 .928 r
.08465 .53646 m .07596 .53946 L .07927 .54228 L p F P
0 g
s
.649 .756 .928 r
.07927 .54228 m .08795 .53928 L .08465 .53646 L p F P
0 g
s
.651 .757 .928 r
.51488 .53712 m .50541 .54016 L .50801 .54296 L p F P
0 g
s
.651 .757 .928 r
.50801 .54296 m .51746 .53993 L .51488 .53712 L p F P
0 g
s
.948 .883 .736 r
.46658 .73644 m .46558 .73348 L .46216 .73906 L p F P
0 g
s
.948 .883 .736 r
.46216 .73906 m .46347 .74192 L .46658 .73644 L p F P
0 g
s
0 0 .549 r
.57486 .7065 m .57514 .70966 L .57776 .71351 L p F P
0 g
s
0 .111 .645 r
.57249 .70259 m .57486 .7065 L .57514 .70966 L p F P
0 g
s
.65 .757 .928 r
.23206 .53679 m .2231 .53982 L .22616 .54262 L p F P
0 g
s
.65 .757 .928 r
.22616 .54262 m .23511 .5396 L .23206 .53679 L p F P
0 g
s
.651 .758 .928 r
.81392 .54263 m .82392 .53959 L .826 .54239 L p F P
0 g
s
.651 .758 .928 r
.82392 .53959 m .81392 .54263 L .81183 .53984 L p F P
0 g
s
.247 .571 .94 r
.42339 .77639 m .42329 .77637 L .42282 .77584 L closepath p F P
0 g
s
.65 .757 .928 r
.3795 .53687 m .37028 .53991 L .3731 .54271 L p F P
0 g
s
.65 .757 .928 r
.3731 .54271 m .38231 .53968 L .3795 .53687 L p F P
0 g
s
.651 .758 .928 r
.6744 .53687 m .66465 .53991 L .66699 .54271 L p F P
0 g
s
.651 .758 .928 r
.66699 .54271 m .67672 .53967 L .6744 .53687 L p F P
0 g
s
.651 .757 .928 r
.52695 .53688 m .51746 .53993 L .52004 .54272 L p F P
0 g
s
.651 .757 .928 r
.52004 .54272 m .52952 .53969 L .52695 .53688 L p F P
0 g
s
.649 .756 .928 r
.09666 .53627 m .08795 .53928 L .09123 .54209 L p F P
0 g
s
.649 .756 .928 r
.09123 .54209 m .09993 .53909 L .09666 .53627 L p F P
0 g
s
.836 .997 .77 r
.43098 .6762 m .43272 .67228 L .42751 .67835 L p F P
0 g
s
.836 .997 .77 r
.4287 .67892 m .43098 .6762 L p .42751 .67835 L F P
0 g
s
.585 .735 .946 r
.42995 .77195 m .43268 .77423 L .42339 .77639 L p F P
0 g
s
.585 .735 .946 r
.42266 .77336 m .42995 .77195 L p .42339 .77639 L F P
0 g
s
.585 .735 .946 r
.42339 .77639 m .42282 .77584 L .42266 .77336 L p F P
0 g
s
.804 .454 .394 r
.54752 .66278 m .54563 .66223 L .54442 .66549 L p F P
0 g
s
.804 .454 .394 r
.54442 .66549 m .54903 .66686 L .54752 .66278 L p F P
0 g
s
0 .196 .725 r
.62941 .68682 m .62636 .68381 L .6255 .68221 L p F P
0 g
s
.651 .758 .928 r
.826 .54239 m .83602 .53934 L .83807 .54214 L p F P
0 g
s
.651 .758 .928 r
.83602 .53934 m .826 .54239 L .82392 .53959 L p F P
0 g
s
.65 .757 .928 r
.24409 .53656 m .23511 .5396 L .23815 .5424 L p F P
0 g
s
.65 .757 .928 r
.23815 .5424 m .24712 .53938 L .24409 .53656 L p F P
0 g
s
.651 .758 .928 r
.68649 .53663 m .67672 .53967 L .67904 .54247 L p F P
0 g
s
.651 .758 .928 r
.67904 .54247 m .6888 .53944 L .68649 .53663 L p F P
0 g
s
.65 .757 .928 r
.39155 .53664 m .38231 .53968 L .38511 .54248 L p F P
0 g
s
.65 .757 .928 r
.38511 .54248 m .39434 .53945 L .39155 .53664 L p F P
0 g
s
.602 .851 .991 r
.62955 .77431 m .62757 .77615 L p .61853 .77618 L F P
0 g
s
.685 .893 .973 r
.62757 .77615 m .62955 .77431 L .63055 .77486 L closepath p F P
0 g
s
.651 .757 .928 r
.53902 .53665 m .52952 .53969 L .53207 .54249 L p F P
0 g
s
.651 .757 .928 r
.53207 .54249 m .54157 .53946 L .53902 .53665 L p F P
0 g
s
.968 .886 .695 r
.46809 .7295 m .46883 .72796 L .46941 .72939 L closepath p F P
0 g
s
.947 .929 .752 r
.46558 .73348 m .46809 .7295 L .46941 .72939 L p F P
0 g
s
.906 .848 .776 r
.45431 .76045 m .45736 .75608 L .45553 .7534 L p F P
0 g
s
.649 .756 .928 r
.10867 .53608 m .09993 .53909 L .1032 .54191 L p F P
0 g
s
.649 .756 .928 r
.1032 .54191 m .11193 .5389 L .10867 .53608 L p F P
0 g
s
0 .285 .78 r
.60789 .66165 m .60665 .66079 L .6042 .65775 L p F P
0 g
s
.924 .97 .683 r
.41403 .70264 m .41443 .69917 L .41128 .70463 L p F P
0 g
s
.924 .97 .683 r
.41227 .70572 m .41403 .70264 L p .41128 .70463 L F P
0 g
s
0 0 0 r
.64416 .75916 m .64622 .7539 L p .64257 .76244 L F P
0 g
s
0 0 0 r
.64246 .76271 m .64416 .75916 L p .64257 .76244 L F P
0 g
s
0 0 0 r
.64658 .75315 m .64622 .7539 L .64416 .75916 L p F P
0 g
s
0 0 0 r
.64416 .75916 m .64548 .75649 L .64658 .75315 L p F P
0 g
s
.839 .984 .702 r
.64416 .75916 m .64033 .76491 L p .64536 .75669 L F P
0 g
s
.839 .984 .702 r
.64548 .75649 m .64416 .75916 L p .64536 .75669 L F P
0 g
s
.906 .965 .648 r
.64246 .76271 m .64416 .75916 L p .63937 .76731 L F P
0 g
s
.906 .965 .648 r
.63937 .76731 m .64005 .76683 L .64246 .76271 L p F P
0 g
s
.974 .92 .672 r
.47136 .72265 m .47105 .71947 L .46818 .72488 L p F P
0 g
s
.974 .92 .672 r
.46818 .72488 m .46883 .72796 L .47136 .72265 L p F P
0 g
s
0 0 .135 r
.48522 .68926 m .48277 .69452 L .48607 .69022 L p F P
0 g
s
0 0 .135 r
.48892 .68503 m .48522 .68926 L p .48607 .69022 L F P
0 g
s
.836 .997 .77 r
.42751 .67835 m .42687 .67975 L .4287 .67892 L p F P
0 g
s
.881 .992 .759 r
.42687 .67975 m .4287 .67892 L .42615 .68214 L closepath p F P
0 g
s
.942 .736 .266 r
.40439 .74265 m .40349 .73964 L .40331 .74428 L p F P
0 g
s
.942 .736 .266 r
.40331 .74428 m .40421 .74728 L .40439 .74265 L p F P
0 g
s
0 0 .436 r
.57163 .69958 m .57249 .70259 L .57486 .7065 L p F P
0 g
s
0 0 .556 r
.56944 .69563 m .57163 .69958 L .57249 .70259 L p F P
0 g
s
.651 .758 .928 r
.83807 .54214 m .84811 .53909 L .85015 .54189 L p F P
0 g
s
.651 .758 .928 r
.84811 .53909 m .83807 .54214 L .83602 .53934 L p F P
0 g
s
.65 .757 .928 r
.25612 .53634 m .24712 .53938 L .25014 .54218 L p F P
0 g
s
.65 .757 .928 r
.25014 .54218 m .25914 .53915 L .25612 .53634 L p F P
0 g
s
.785 .816 .877 r
.43394 .77337 m .43268 .77423 L .4354 .77652 L p F P
0 g
s
.785 .816 .877 r
.4354 .77652 m .43628 .77589 L .43394 .77337 L p F P
0 g
s
0 .315 .794 r
.60108 .6558 m .6042 .65775 L .60175 .65499 L p F P
0 g
s
0 .315 .794 r
.60175 .65499 m .59879 .65314 L .60108 .6558 L p F P
0 g
s
.651 .758 .928 r
.69859 .53639 m .6888 .53944 L .69109 .54224 L p F P
0 g
s
.651 .758 .928 r
.69109 .54224 m .70088 .5392 L .69859 .53639 L p F P
0 g
s
.65 .757 .928 r
.40361 .5364 m .39434 .53945 L .39712 .54225 L p F P
0 g
s
.65 .757 .928 r
.39712 .54225 m .40638 .53921 L .40361 .5364 L p F P
0 g
s
.651 .757 .928 r
.5511 .53641 m .54157 .53946 L .54411 .54226 L p F P
0 g
s
.651 .757 .928 r
.54411 .54226 m .55363 .53922 L .5511 .53641 L p F P
0 g
s
.771 .834 .901 r
.44482 .77017 m .43628 .77589 L .43394 .77337 L p F P
0 g
s
.649 .756 .928 r
.12069 .53588 m .11193 .5389 L .11517 .54171 L p F P
0 g
s
.649 .756 .928 r
.11517 .54171 m .12392 .5387 L .12069 .53588 L p F P
0 g
s
.472 .469 .774 r
.59393 .75584 m .59891 .75801 L p .59822 .76244 L F P
0 g
s
.348 .401 .775 r
.59393 .75584 m .59891 .75801 L .59639 .75229 L p F P
0 g
s
.348 .401 .775 r
.59639 .75229 m .59608 .75211 L .59393 .75584 L p F P
0 g
s
.439 .438 .76 r
.59063 .74896 m .59608 .75211 L .59393 .75584 L p F P
0 g
s
.579 .73 .946 r
.42266 .77336 m .42282 .77584 L .42066 .77369 L closepath p F P
0 g
s
.651 .758 .928 r
.85015 .54189 m .86021 .53884 L .86223 .54164 L p F P
0 g
s
.651 .758 .928 r
.86021 .53884 m .85015 .54189 L .84811 .53909 L p F P
0 g
s
.722 .409 .447 r
.53383 .65562 m .53104 .65535 L .53035 .65915 L p F P
0 g
s
.722 .409 .447 r
.53035 .65915 m .53543 .65966 L .53383 .65562 L p F P
0 g
s
.432 .489 .819 r
.60142 .76343 m .59822 .76244 L .59986 .76006 L closepath p F P
0 g
s
.472 .469 .774 r
.59891 .75801 m .59986 .76006 L .59822 .76244 L p F P
0 g
s
.65 .757 .928 r
.26816 .53611 m .25914 .53915 L .26214 .54196 L p F P
0 g
s
.65 .757 .928 r
.26214 .54196 m .27116 .53893 L .26816 .53611 L p F P
0 g
s
0 0 .138 r
.64693 .7493 m .64696 .74902 L .64694 .74905 L closepath p F P
0 g
s
.651 .758 .928 r
.71069 .53615 m .70088 .5392 L .70315 .542 L p F P
0 g
s
.651 .758 .928 r
.70315 .542 m .71296 .53896 L .71069 .53615 L p F P
0 g
s
.662 .268 0 r
.56799 .69278 m .56944 .69563 L .57163 .69958 L p F P
0 g
s
0 0 .387 r
.56623 .68944 m .56799 .69278 L .56944 .69563 L p F P
0 g
s
.65 .757 .928 r
.41567 .53617 m .40638 .53921 L .40914 .54202 L p F P
0 g
s
.65 .757 .928 r
.40914 .54202 m .41842 .53898 L .41567 .53617 L p F P
0 g
s
.651 .757 .928 r
.56318 .53618 m .55363 .53922 L .55615 .54202 L p F P
0 g
s
.651 .757 .928 r
.55615 .54202 m .56569 .53899 L .56318 .53618 L p F P
0 g
s
.821 .473 .397 r
.54563 .66223 m .54213 .66103 L .54346 .66516 L p F P
0 g
s
.821 .473 .397 r
.54346 .66516 m .54442 .66549 L .54563 .66223 L p F P
0 g
s
0 0 0 r
.64696 .74902 m .6479 .74565 L p .64658 .75315 L F P
0 g
s
0 0 0 r
.64658 .75315 m .64693 .7493 L .64696 .74902 L p F P
0 g
s
0 0 .299 r
.6477 .74102 m .6479 .74565 L .64696 .74902 L p F P
0 g
s
.408 .128 .373 r
.4983 .67122 m .50382 .66684 L .49874 .66888 L closepath p F P
0 g
s
.119 0 .21 r
.49874 .66888 m .4983 .67122 L .49689 .67342 L p F P
0 g
s
.865 .499 .352 r
.5535 .66888 m .54903 .66686 L .55055 .67095 L p F P
0 g
s
.865 .499 .352 r
.55055 .67095 m .55484 .67302 L .5535 .66888 L p F P
0 g
s
0 0 .489 r
.64684 .72565 m .64626 .72897 L .64766 .73324 L p F P
0 g
s
0 .015 .558 r
.64626 .72897 m .64684 .72565 L .64495 .72153 L p F P
0 g
s
0 .196 .725 r
.6255 .68221 m .62484 .68029 L p .62941 .68682 L F P
0 g
s
0 .243 .757 r
.6255 .68221 m .62391 .67948 L .62484 .68029 L closepath p F P
0 g
s
.649 .756 .928 r
.1327 .53568 m .12392 .5387 L .12715 .54151 L p F P
0 g
s
.649 .756 .928 r
.12715 .54151 m .13592 .5385 L .1327 .53568 L p F P
0 g
s
.324 .405 .791 r
.59248 .7453 m .59063 .74896 L .59608 .75211 L p F P
0 g
s
.401 .404 .748 r
.58787 .74193 m .59248 .7453 L .59063 .74896 L p F P
0 g
s
.655 .354 .451 r
.52357 .65531 m .51889 .65546 L .51829 .65937 L p F P
0 g
s
.561 .278 .444 r
.51889 .65546 m .51829 .65937 L .5081 .66145 L p F P
0 g
s
.856 .987 .712 r
.42615 .68214 m .42181 .68794 L .42294 .68422 L p F P
0 g
s
.856 .987 .712 r
.42687 .67975 m .42615 .68214 L p .42294 .68422 L F P
0 g
s
0 0 .155 r
.64622 .7539 m .64658 .75315 L .64693 .7493 L closepath p F P
0 g
s
.897 .497 .074 r
.56623 .68944 m .566 .68879 L .56402 .68648 L closepath p F P
0 g
s
.906 .512 .097 r
.56371 .68606 m .5624 .68198 L p .566 .68879 L F P
0 g
s
.906 .512 .097 r
.566 .68879 m .56402 .68648 L .56371 .68606 L p F P
0 g
s
.65 .757 .928 r
.28021 .53589 m .27116 .53893 L .27414 .54173 L p F P
0 g
s
.65 .757 .928 r
.27414 .54173 m .28318 .5387 L .28021 .53589 L p F P
0 g
s
.651 .758 .928 r
.71522 .54176 m .72504 .53872 L .72728 .54153 L p F P
0 g
s
.651 .758 .928 r
.7228 .53591 m .71296 .53896 L .71522 .54176 L p F P
0 g
s
.651 .758 .928 r
.71522 .54176 m .72504 .53872 L .7228 .53591 L p F P
0 g
s
.671 .358 .436 r
.53104 .65535 m .52357 .65531 L .5259 .65912 L p F P
0 g
s
.671 .358 .436 r
.5259 .65912 m .53035 .65915 L .53104 .65535 L p F P
0 g
s
.65 .757 .928 r
.42774 .53594 m .41842 .53898 L .42117 .54178 L p F P
0 g
s
.65 .757 .928 r
.42117 .54178 m .43047 .53875 L .42774 .53594 L p F P
0 g
s
.651 .757 .928 r
.57527 .53594 m .56569 .53899 L .56819 .54179 L p F P
0 g
s
.651 .757 .928 r
.56819 .54179 m .57776 .53875 L .57527 .53594 L p F P
0 g
s
.825 .907 .896 r
.62955 .77431 m .63055 .77486 L .63852 .76848 L p F P
0 g
s
.907 .944 .588 r
.47651 .70875 m .47734 .70521 L .4746 .71058 L p F P
0 g
s
.907 .944 .588 r
.47501 .71216 m .47651 .70875 L p .4746 .71058 L F P
0 g
s
.515 .574 .853 r
.6041 .76883 m .60392 .7685 L .60438 .76853 L closepath p F P
0 g
s
.655 .354 .451 r
.51829 .65937 m .5259 .65912 L .52357 .65531 L p F P
0 g
s
.907 .524 .284 r
.55831 .67533 m .55484 .67302 L .55623 .67717 L p F P
0 g
s
.907 .524 .284 r
.55623 .67717 m .55962 .67949 L .55831 .67533 L p F P
0 g
s
.919 .522 .19 r
.5624 .68198 m .55962 .67949 L .56098 .68366 L p F P
0 g
s
.919 .522 .19 r
.56371 .68606 m .5624 .68198 L p .56098 .68366 L F P
0 g
s
.65 .757 .928 r
.14473 .53547 m .13592 .5385 L .13913 .54131 L p F P
0 g
s
.65 .757 .928 r
.13913 .54131 m .14792 .53829 L .14473 .53547 L p F P
0 g
s
.906 .848 .776 r
.45553 .7534 m .45161 .75878 L .45431 .76045 L p F P
0 g
s
.843 .858 .855 r
.45431 .76045 m .4527 .76202 L .45108 .75928 L p F P
0 g
s
.843 .858 .855 r
.45108 .75928 m .45161 .75878 L .45431 .76045 L p F P
0 g
s
.524 .556 .83 r
.60438 .76853 m .60392 .7685 L .60142 .76343 L p F P
0 g
s
.924 .97 .683 r
.41128 .70463 m .41102 .70662 L .41227 .70572 L p F P
0 g
s
.951 .954 .671 r
.41102 .70662 m .41227 .70572 L .41101 .70806 L closepath p F P
0 g
s
.85 .834 .83 r
.4527 .76202 m .45108 .75928 L .4444 .7658 L p F P
0 g
s
.85 .834 .83 r
.4444 .7658 m .44647 .7684 L .4527 .76202 L p F P
0 g
s
.65 .757 .928 r
.29226 .53566 m .28318 .5387 L .28615 .54151 L p F P
0 g
s
.65 .757 .928 r
.28615 .54151 m .29521 .53847 L .29226 .53566 L p F P
0 g
s
0 0 0 r
.48191 .69632 m .48277 .69452 L .4824 .69522 L closepath p F P
0 g
s
0 0 0 r
.48009 .69985 m .48191 .69632 L .4824 .69522 L p F P
0 g
s
.651 .758 .928 r
.72728 .54153 m .73713 .53848 L .73935 .54129 L p F P
0 g
s
.651 .758 .928 r
.73713 .53848 m .72728 .54153 L .72504 .53872 L p F P
0 g
s
.65 .757 .928 r
.4398 .53571 m .43047 .53875 L .43319 .54155 L p F P
0 g
s
.65 .757 .928 r
.43319 .54155 m .44252 .53852 L .4398 .53571 L p F P
0 g
s
.651 .757 .928 r
.58736 .53571 m .57776 .53875 L .58024 .54156 L p F P
0 g
s
.651 .757 .928 r
.58024 .54156 m .58983 .53852 L .58736 .53571 L p F P
0 g
s
.777 .989 .754 r
.43541 .6693 m .43858 .66603 L .43705 .66846 L closepath p F P
0 g
s
.813 .993 .753 r
.43272 .67228 m .43541 .6693 L .43705 .66846 L p F P
0 g
s
.248 .353 .774 r
.58929 .73837 m .58787 .74193 L .59248 .7453 L p F P
0 g
s
.353 .368 .736 r
.58537 .73482 m .58929 .73837 L .58787 .74193 L p F P
0 g
s
.937 .87 .746 r
.46347 .74192 m .46216 .73906 L .45882 .74462 L p F P
0 g
s
.937 .87 .746 r
.46118 .74599 m .46347 .74192 L p .45882 .74462 L F P
0 g
s
.694 .942 .653 r
.63852 .76848 m .63937 .76731 L .64005 .76683 L closepath p F P
0 g
s
.602 .851 .991 r
.61853 .77618 m .62819 .77346 L .62955 .77431 L p F P
0 g
s
.601 .7 .913 r
.62579 .77135 m .62819 .77346 L .61853 .77618 L p F P
0 g
s
.601 .7 .913 r
.61724 .77281 m .62579 .77135 L p .61853 .77618 L F P
0 g
s
.601 .7 .913 r
.61853 .77618 m .61645 .77347 L .61724 .77281 L p F P
0 g
s
.65 .757 .928 r
.15675 .53527 m .14792 .53829 L .15111 .54111 L p F P
0 g
s
.65 .757 .928 r
.15111 .54111 m .15993 .53809 L .15675 .53527 L p F P
0 g
s
.771 .332 0 r
.56799 .69278 m .56623 .68944 L .56402 .68648 L p F P
0 g
s
.955 .912 .545 r
.40651 .72178 m .40634 .71852 L .40452 .72361 L p F P
0 g
s
.955 .912 .545 r
.40526 .72524 m .40651 .72178 L p .40452 .72361 L F P
0 g
s
.468 .522 .83 r
.60438 .76853 m .61364 .76935 L .61117 .76532 L p F P
0 g
s
.468 .522 .83 r
.61117 .76532 m .60757 .76456 L .60438 .76853 L p F P
0 g
s
.524 .556 .83 r
.60142 .76343 m .60757 .76456 L .60438 .76853 L p F P
0 g
s
0 .253 .762 r
.6139 .66776 m .61218 .66496 L .60789 .66165 L p F P
0 g
s
0 .231 .74 r
.60587 .65893 m .60789 .66165 L .61218 .66496 L p F P
0 g
s
0 .285 .78 r
.6042 .65775 m .60587 .65893 L .60789 .66165 L p F P
0 g
s
.65 .757 .928 r
.30431 .53543 m .29521 .53847 L .29816 .54128 L p F P
0 g
s
.65 .757 .928 r
.29816 .54128 m .30724 .53825 L .30431 .53543 L p F P
0 g
s
.651 .758 .928 r
.73935 .54129 m .74922 .53824 L .75142 .54105 L p F P
0 g
s
.651 .758 .928 r
.74922 .53824 m .73935 .54129 L .73713 .53848 L p F P
0 g
s
.825 .907 .896 r
.63852 .76848 m .63937 .76731 L p .62955 .77431 L F P
0 g
s
.65 .757 .928 r
.45188 .53547 m .44252 .53852 L .44522 .54132 L p F P
0 g
s
.65 .757 .928 r
.44522 .54132 m .45457 .53829 L .45188 .53547 L p F P
0 g
s
.651 .757 .928 r
.59945 .53547 m .58983 .53852 L .59229 .54132 L p F P
0 g
s
.651 .757 .928 r
.59229 .54132 m .6019 .53828 L .59945 .53547 L p F P
0 g
s
.857 .835 .824 r
.44482 .77017 m .44647 .7684 L .4444 .7658 L p F P
0 g
s
0 .017 .581 r
.40865 .76168 m .40737 .75882 L .41027 .76261 L p F P
0 g
s
0 .017 .581 r
.41027 .76261 m .41172 .76542 L .40865 .76168 L p F P
0 g
s
.65 .757 .928 r
.16878 .53505 m .15993 .53809 L .1631 .5409 L p F P
0 g
s
.65 .757 .928 r
.1631 .5409 m .17194 .53787 L .16878 .53505 L p F P
0 g
s
.545 .259 .431 r
.5081 .66145 m .51829 .65937 L p .51172 .66449 L F P
0 g
s
.545 .259 .431 r
.51172 .66449 m .50778 .66355 L .5081 .66145 L p F P
0 g
s
.414 .138 .384 r
.5081 .66145 m .50778 .66355 L .50382 .66684 L p F P
0 g
s
0 .022 .57 r
.64529 .71827 m .64495 .72153 L .64684 .72565 L p F P
0 g
s
0 .07 .608 r
.64495 .72153 m .64529 .71827 L .64297 .71428 L p F P
0 g
s
.857 .835 .824 r
.4444 .7658 m .4421 .76815 L .44482 .77017 L p F P
0 g
s
.771 .834 .901 r
.43394 .77337 m .4421 .76815 L .44482 .77017 L p F P
0 g
s
.651 .758 .928 r
.75142 .54105 m .76132 .538 L .7635 .54081 L p F P
0 g
s
.651 .758 .928 r
.76132 .538 m .75142 .54105 L .74922 .53824 L p F P
0 g
s
.65 .757 .928 r
.31636 .5352 m .30724 .53825 L .31017 .54105 L p F P
0 g
s
.65 .757 .928 r
.31017 .54105 m .31928 .53802 L .31636 .5352 L p F P
0 g
s
.107 0 .195 r
.48992 .68141 m .49316 .67905 L .48938 .6847 L p F P
0 g
s
.107 0 .195 r
.48938 .6847 m .48892 .68503 L .48992 .68141 L p F P
0 g
s
.651 .757 .928 r
.61154 .53524 m .6019 .53828 L .60434 .54109 L p F P
0 g
s
.651 .757 .928 r
.60434 .54109 m .61397 .53805 L .61154 .53524 L p F P
0 g
s
.651 .757 .928 r
.46395 .53524 m .45457 .53829 L .45725 .54109 L p F P
0 g
s
.651 .757 .928 r
.45725 .54109 m .46662 .53805 L .46395 .53524 L p F P
0 g
s
.966 .811 .382 r
.40423 .73485 m .40351 .73177 L .40276 .73657 L p F P
0 g
s
.966 .811 .382 r
.40276 .73657 m .40349 .73964 L .40423 .73485 L p F P
0 g
s
.148 .287 .75 r
.5863 .73138 m .58537 .73482 L .58929 .73837 L p F P
0 g
s
.293 .325 .724 r
.58293 .72769 m .5863 .73138 L .58537 .73482 L p F P
0 g
s
.937 .946 .614 r
.41101 .70806 m .40852 .71333 L .40852 .70999 L p F P
0 g
s
.937 .946 .614 r
.41102 .70662 m .41101 .70806 L p .40852 .70999 L F P
0 g
s
.039 .379 .844 r
.41793 .77081 m .41332 .76818 L .41172 .76542 L p F P
0 g
s
.076 .42 .867 r
.41332 .76818 m .41793 .77081 L .42066 .77369 L p F P
0 g
s
.65 .757 .928 r
.18082 .53484 m .17194 .53787 L .17509 .54069 L p F P
0 g
s
.65 .757 .928 r
.17509 .54069 m .18396 .53766 L .18082 .53484 L p F P
0 g
s
.875 .989 .729 r
.42181 .68794 m .42294 .68422 L .41881 .68997 L p F P
0 g
s
.875 .989 .729 r
.41909 .69176 m .42181 .68794 L p .41881 .68997 L F P
0 g
s
.651 .758 .928 r
.7635 .54081 m .77342 .53776 L .77558 .54057 L p F P
0 g
s
.651 .758 .928 r
.77342 .53776 m .7635 .54081 L .76132 .538 L p F P
0 g
s
.65 .757 .928 r
.32842 .53497 m .31928 .53802 L .32218 .54082 L p F P
0 g
s
.65 .757 .928 r
.32218 .54082 m .33131 .53779 L .32842 .53497 L p F P
0 g
s
.651 .757 .928 r
.62364 .535 m .61397 .53805 L .61639 .54085 L p F P
0 g
s
.651 .757 .928 r
.61639 .54085 m .62605 .53781 L .62364 .535 L p F P
0 g
s
.651 .757 .928 r
.47603 .535 m .46662 .53805 L .46929 .54086 L p F P
0 g
s
.651 .757 .928 r
.46929 .54086 m .47868 .53782 L .47603 .535 L p F P
0 g
s
.974 .921 .675 r
.46809 .7295 m .46883 .72796 L .46818 .72488 L p F P
0 g
s
.675 .347 0 r
.40582 .75466 m .40475 .75172 L .40623 .7559 L p F P
0 g
s
.675 .347 0 r
.40623 .7559 m .40737 .75882 L .40582 .75466 L p F P
0 g
s
0 0 0 r
.48277 .69452 m .48607 .69022 L .48289 .69571 L p F P
0 g
s
0 0 0 r
.48191 .69632 m .48277 .69452 L p .48289 .69571 L F P
0 g
s
0 .276 .78 r
.61961 .67395 m .61821 .67107 L .6139 .66776 L p F P
0 g
s
0 .263 .769 r
.61218 .66496 m .6139 .66776 L .61821 .67107 L p F P
0 g
s
.907 .944 .588 r
.4746 .71058 m .47421 .71303 L .47501 .71216 L p F P
0 g
s
.881 .946 .586 r
.47421 .71303 m .47501 .71216 L .47398 .71405 L closepath p F P
0 g
s
.782 .453 .432 r
.54213 .66103 m .53543 .65966 L .53711 .66368 L p F P
0 g
s
.782 .453 .432 r
.53711 .66368 m .54346 .66516 L .54213 .66103 L p F P
0 g
s
.65 .757 .928 r
.19286 .53462 m .18396 .53766 L .18709 .54047 L p F P
0 g
s
.65 .757 .928 r
.18709 .54047 m .19598 .53745 L .19286 .53462 L p F P
0 g
s
0 .23 .749 r
.62484 .68029 m .62391 .67948 L .62146 .67549 L p F P
0 g
s
.651 .758 .928 r
.77558 .54057 m .78552 .53752 L .78766 .54032 L p F P
0 g
s
.651 .758 .928 r
.78552 .53752 m .77558 .54057 L .77342 .53776 L p F P
0 g
s
.65 .757 .928 r
.34048 .53474 m .33131 .53779 L .3342 .5406 L p F P
0 g
s
.65 .757 .928 r
.3342 .5406 m .34335 .53756 L .34048 .53474 L p F P
0 g
s
.651 .757 .928 r
.63574 .53476 m .62605 .53781 L .62845 .54062 L p F P
0 g
s
.651 .757 .928 r
.62845 .54062 m .63813 .53758 L .63574 .53476 L p F P
0 g
s
.651 .757 .928 r
.48811 .53477 m .47868 .53782 L .48133 .54062 L p F P
0 g
s
.651 .757 .928 r
.48133 .54062 m .49074 .53759 L .48811 .53477 L p F P
0 g
s
.014 .201 .711 r
.58336 .72438 m .58293 .72769 L .5863 .73138 L p F P
0 g
s
.032 .172 .678 r
.58293 .72769 m .58336 .72438 L .58043 .72058 L p F P
0 g
s
0 .253 .717 r
.59131 .64747 m .58838 .64498 L .59323 .64808 L p F P
0 g
s
0 .253 .717 r
.59323 .64808 m .59618 .65056 L .59131 .64747 L p F P
0 g
s
.937 .87 .746 r
.45882 .74462 m .45926 .74544 L .46118 .74599 L p F P
0 g
s
.909 .9 .805 r
.45926 .74544 m .46118 .74599 L .45998 .74752 L closepath p F P
0 g
s
0 0 .235 r
.64851 .73767 m .6477 .74102 L .6479 .74565 L p F P
0 g
s
0 0 .39 r
.6477 .74102 m .64851 .73767 L .64766 .73324 L p F P
0 g
s
0 .07 .615 r
.64306 .71106 m .64297 .71428 L .64529 .71827 L p F P
0 g
s
0 .111 .646 r
.64297 .71428 m .64306 .71106 L .64038 .70719 L p F P
0 g
s
.65 .757 .928 r
.2049 .53441 m .19598 .53745 L .19909 .54026 L p F P
0 g
s
.65 .757 .928 r
.19909 .54026 m .208 .53723 L .2049 .53441 L p F P
0 g
s
.651 .758 .928 r
.79762 .53727 m .78766 .54032 L .78552 .53752 L p F P
0 g
s
.651 .758 .928 r
.78766 .54032 m .79762 .53727 L .79974 .54008 L p F P
0 g
s
.974 .921 .675 r
.46818 .72488 m .46536 .73023 L .46809 .7295 L p F P
0 g
s
.933 .963 .759 r
.46809 .7295 m .46558 .73348 L .46531 .7303 L p F P
0 g
s
.933 .963 .759 r
.46531 .7303 m .46536 .73023 L .46809 .7295 L p F P
0 g
s
.65 .757 .928 r
.35254 .53451 m .34335 .53756 L .34622 .54037 L p F P
0 g
s
.65 .757 .928 r
.34622 .54037 m .3554 .53733 L .35254 .53451 L p F P
0 g
s
.651 .757 .928 r
.64785 .53452 m .63813 .53758 L .64052 .54038 L p F P
0 g
s
.651 .757 .928 r
.64052 .54038 m .65022 .53734 L .64785 .53452 L p F P
0 g
s
.651 .757 .928 r
.50019 .53454 m .49074 .53759 L .49337 .54039 L p F P
0 g
s
.651 .757 .928 r
.49337 .54039 m .50281 .53735 L .50019 .53454 L p F P
0 g
s
.738 .886 .948 r
.62819 .77346 m .63029 .77234 L .62955 .77431 L closepath p F P
0 g
s
.825 .907 .896 r
.63778 .7677 m .63029 .77234 L .62955 .77431 L p F P
0 g
s
.825 .907 .896 r
.63937 .76731 m .63778 .7677 L p .62955 .77431 L F P
0 g
s
.903 .903 .814 r
.45998 .74752 m .45553 .7534 L .45411 .75058 L p F P
0 g
s
.903 .903 .814 r
.45926 .74544 m .45998 .74752 L p .45411 .75058 L F P
0 g
s
0 0 0 r
.48289 .69571 m .48092 .69842 L .48191 .69632 L p F P
0 g
s
0 0 0 r
.48092 .69842 m .48191 .69632 L .48009 .69985 L closepath p F P
0 g
s
0 .23 .75 r
.61961 .67395 m .62146 .67549 L .61901 .67174 L p F P
0 g
s
0 .23 .75 r
.61901 .67174 m .61821 .67107 L .61961 .67395 L p F P
0 g
s
.827 .942 .58 r
.47398 .71405 m .47105 .71947 L .47174 .71599 L p F P
0 g
s
.827 .942 .58 r
.47421 .71303 m .47398 .71405 L p .47174 .71599 L F P
0 g
s
.875 .989 .729 r
.41881 .68997 m .41805 .69236 L .41909 .69176 L p F P
0 g
s
.911 .98 .719 r
.41805 .69236 m .41909 .69176 L .41782 .69364 L closepath p F P
0 g
s
.65 .757 .928 r
.21694 .53419 m .208 .53723 L .21109 .54004 L p F P
0 g
s
.65 .757 .928 r
.21109 .54004 m .22003 .53701 L .21694 .53419 L p F P
0 g
s
.651 .758 .928 r
.79974 .54008 m .80973 .53703 L .81183 .53984 L p F P
0 g
s
.651 .758 .928 r
.80973 .53703 m .79974 .54008 L .79762 .53727 L p F P
0 g
s
.955 .912 .545 r
.40452 .72361 m .40461 .72618 L .40526 .72524 L p F P
0 g
s
.978 .896 .547 r
.40461 .72618 m .40526 .72524 L .40472 .72686 L closepath p F P
0 g
s
.649 .756 .928 r
.08135 .53362 m .07265 .53664 L .07596 .53946 L p F P
0 g
s
.649 .756 .928 r
.07596 .53946 m .08465 .53646 L .08135 .53362 L p F P
0 g
s
.65 .757 .928 r
.36461 .53428 m .3554 .53733 L .35825 .54014 L p F P
0 g
s
.65 .757 .928 r
.35825 .54014 m .36745 .5371 L .36461 .53428 L p F P
0 g
s
.651 .757 .928 r
.65996 .53429 m .65022 .53734 L .65258 .54015 L p F P
0 g
s
.651 .757 .928 r
.65258 .54015 m .66231 .5371 L .65996 .53429 L p F P
0 g
s
.651 .757 .928 r
.51228 .5343 m .50281 .53735 L .50541 .54016 L p F P
0 g
s
.651 .757 .928 r
.50541 .54016 m .51488 .53712 L .51228 .5343 L p F P
0 g
s
.485 .52 .818 r
.60757 .76456 m .60142 .76343 L .59986 .76006 L p F P
0 g
s
.37 .076 .329 r
.49797 .67268 m .4983 .67122 L .50382 .66684 L p F P
0 g
s
.179 0 .259 r
.49797 .67268 m .4983 .67122 L .49689 .67342 L closepath p F P
0 g
s
0 .04 .606 r
.58035 .71739 m .58043 .72058 L .58336 .72438 L p F P
0 g
s
0 .079 .627 r
.58043 .72058 m .58035 .71739 L .57776 .71351 L p F P
0 g
s
0 .117 .656 r
.6402 .70404 m .64038 .70719 L .64306 .71106 L p F P
0 g
s
0 .14 .674 r
.64038 .70719 m .6402 .70404 L .63723 .70026 L p F P
0 g
s
.544 .703 .944 r
.42066 .77369 m .42266 .77336 L .42163 .77046 L p F P
0 g
s
.544 .703 .944 r
.42163 .77046 m .41793 .77081 L .42066 .77369 L p F P
0 g
s
.845 .588 .046 r
.40421 .74728 m .40331 .74428 L .40383 .74873 L p F P
0 g
s
.845 .588 .046 r
.40383 .74873 m .40475 .75172 L .40421 .74728 L p F P
0 g
s
.846 .999 .796 r
.63778 .7677 m .64033 .76491 L .63937 .76731 L closepath p F P
0 g
s
.906 .965 .648 r
.64416 .75916 m .64033 .76491 L .63937 .76731 L p F P
0 g
s
.65 .757 .928 r
.22899 .53396 m .22003 .53701 L .2231 .53982 L p F P
0 g
s
.65 .757 .928 r
.2231 .53982 m .23206 .53679 L .22899 .53396 L p F P
0 g
s
.651 .758 .928 r
.81183 .53984 m .82184 .53678 L .82392 .53959 L p F P
0 g
s
.651 .758 .928 r
.82184 .53678 m .81183 .53984 L .80973 .53703 L p F P
0 g
s
.65 .757 .928 r
.37668 .53405 m .36745 .5371 L .37028 .53991 L p F P
0 g
s
.65 .757 .928 r
.37028 .53991 m .3795 .53687 L .37668 .53405 L p F P
0 g
s
.651 .758 .928 r
.67207 .53405 m .66231 .5371 L .66465 .53991 L p F P
0 g
s
.651 .758 .928 r
.66465 .53991 m .6744 .53687 L .67207 .53405 L p F P
0 g
s
.651 .757 .928 r
.52437 .53407 m .51488 .53712 L .51746 .53993 L p F P
0 g
s
.651 .757 .928 r
.51746 .53993 m .52695 .53688 L .52437 .53407 L p F P
0 g
s
.649 .756 .928 r
.09338 .53344 m .08465 .53646 L .08795 .53928 L p F P
0 g
s
.649 .756 .928 r
.08795 .53928 m .09666 .53627 L .09338 .53344 L p F P
0 g
s
0 .196 .725 r
.62484 .68029 m .6284 .68385 L .62941 .68682 L p F P
0 g
s
0 .157 .698 r
.62356 .67739 m .62484 .68029 L .6284 .68385 L p F P
0 g
s
0 .23 .749 r
.62146 .67549 m .62356 .67739 L .62484 .68029 L p F P
0 g
s
.89 .973 .667 r
.41782 .69364 m .41443 .69917 L .41506 .69562 L p F P
0 g
s
.89 .973 .667 r
.41805 .69236 m .41782 .69364 L p .41506 .69562 L F P
0 g
s
0 .255 .749 r
.60587 .65893 m .6042 .65775 L .60175 .65499 L p F P
0 g
s
.783 .423 .373 r
.54903 .66686 m .55055 .67095 L .54516 .6692 L p F P
0 g
s
.783 .423 .373 r
.54442 .66549 m .54903 .66686 L p .54516 .6692 L F P
0 g
s
.37 .076 .329 r
.50382 .66684 m .50743 .66533 L p .49797 .67268 L F P
0 g
s
.391 .108 .359 r
.50743 .66533 m .50778 .66355 L .50382 .66684 L closepath p F P
0 g
s
0 .161 .694 r
.63676 .69717 m .63723 .70026 L .6402 .70404 L p F P
0 g
s
0 .159 .693 r
.63723 .70026 m .63676 .69717 L .63355 .69347 L p F P
0 g
s
.651 .758 .928 r
.82392 .53959 m .83396 .53654 L .83602 .53934 L p F P
0 g
s
.651 .758 .928 r
.83396 .53654 m .82392 .53959 L .82184 .53678 L p F P
0 g
s
.65 .757 .928 r
.24105 .53374 m .23206 .53679 L .23511 .5396 L p F P
0 g
s
.65 .757 .928 r
.23511 .5396 m .24409 .53656 L .24105 .53374 L p F P
0 g
s
.651 .758 .928 r
.68418 .53381 m .6744 .53687 L .67672 .53967 L p F P
0 g
s
.651 .758 .928 r
.67672 .53967 m .68649 .53663 L .68418 .53381 L p F P
0 g
s
.65 .757 .928 r
.38875 .53382 m .3795 .53687 L .38231 .53968 L p F P
0 g
s
.65 .757 .928 r
.38231 .53968 m .39155 .53664 L .38875 .53382 L p F P
0 g
s
0 .171 .706 r
.63355 .69347 m .63281 .69044 L .62941 .68682 L p F P
0 g
s
0 .154 .696 r
.6284 .68385 m .62941 .68682 L .63281 .69044 L p F P
0 g
s
.651 .757 .928 r
.53647 .53383 m .52695 .53688 L .52952 .53969 L p F P
0 g
s
.651 .757 .928 r
.52952 .53969 m .53902 .53665 L .53647 .53383 L p F P
0 g
s
.173 0 .249 r
.49689 .67342 m .49797 .67268 L .49708 .67639 L p F P
0 g
s
.173 0 .249 r
.49708 .67639 m .49316 .67905 L .49689 .67342 L p F P
0 g
s
0 .147 .689 r
.63281 .69044 m .63355 .69347 L .63676 .69717 L p F P
0 g
s
.649 .756 .928 r
.10541 .53325 m .09666 .53627 L .09993 .53909 L p F P
0 g
s
.649 .756 .928 r
.09993 .53909 m .10867 .53608 L .10541 .53325 L p F P
0 g
s
0 0 .516 r
.57719 .71044 m .57776 .71351 L .58035 .71739 L p F P
0 g
s
0 0 .549 r
.57776 .71351 m .57719 .71044 L .57486 .7065 L p F P
0 g
s
.969 .858 .456 r
.40472 .72686 m .40461 .72618 L .40315 .72963 L p F P
0 g
s
.969 .858 .456 r
.40315 .72963 m .40351 .73177 L .40472 .72686 L p F P
0 g
s
.545 .243 .405 r
.50743 .66533 m .50778 .66355 L .51172 .66449 L closepath p F P
0 g
s
.949 .923 .747 r
.46558 .73348 m .46531 .7303 L .46143 .73602 L p F P
0 g
s
.949 .923 .747 r
.46143 .73602 m .46216 .73906 L .46558 .73348 L p F P
0 g
s
.651 .758 .928 r
.83602 .53934 m .84607 .53629 L .84811 .53909 L p F P
0 g
s
.651 .758 .928 r
.84607 .53629 m .83602 .53934 L .83396 .53654 L p F P
0 g
s
.65 .757 .928 r
.2531 .53352 m .24409 .53656 L .24712 .53938 L p F P
0 g
s
.65 .757 .928 r
.24712 .53938 m .25612 .53634 L .2531 .53352 L p F P
0 g
s
.651 .758 .928 r
.6963 .53357 m .68649 .53663 L .6888 .53944 L p F P
0 g
s
.651 .758 .928 r
.6888 .53944 m .69859 .53639 L .6963 .53357 L p F P
0 g
s
.65 .757 .928 r
.40083 .53358 m .39155 .53664 L .39434 .53945 L p F P
0 g
s
.65 .757 .928 r
.39434 .53945 m .40361 .5364 L .40083 .53358 L p F P
0 g
s
.651 .757 .928 r
.54857 .53359 m .53902 .53665 L .54157 .53946 L p F P
0 g
s
.651 .757 .928 r
.54157 .53946 m .5511 .53641 L .54857 .53359 L p F P
0 g
s
.948 .925 .567 r
.40852 .71333 m .40852 .70999 L .40635 .71518 L p F P
0 g
s
.948 .925 .567 r
.40635 .71518 m .40634 .71852 L .40852 .71333 L p F P
0 g
s
.778 .82 .886 r
.43179 .77079 m .42995 .77195 L .43268 .77423 L p F P
0 g
s
.778 .82 .886 r
.43268 .77423 m .43394 .77337 L .43179 .77079 L p F P
0 g
s
0 .29 .764 r
.60175 .65499 m .59879 .65314 L .59618 .65056 L p F P
0 g
s
.92 .952 .615 r
.40934 .70834 m .41128 .70463 L .41102 .70662 L closepath p F P
0 g
s
.937 .946 .614 r
.40852 .70999 m .40934 .70834 L .41102 .70662 L p F P
0 g
s
.649 .756 .928 r
.11744 .53305 m .10867 .53608 L .11193 .5389 L p F P
0 g
s
.649 .756 .928 r
.11193 .5389 m .12069 .53588 L .11744 .53305 L p F P
0 g
s
.601 .701 .914 r
.61645 .77347 m .6161 .77301 L .61724 .77281 L closepath p F P
0 g
s
.898 .855 .791 r
.45553 .7534 m .45411 .75058 L .44953 .75651 L p F P
0 g
s
.898 .855 .791 r
.45161 .75878 m .45553 .7534 L p .44953 .75651 L F P
0 g
s
.485 .52 .818 r
.59986 .76006 m .60094 .75858 L p .60757 .76456 L F P
0 g
s
.443 .498 .82 r
.59986 .76006 m .59891 .75801 L .60094 .75858 L closepath p F P
0 g
s
.771 .332 0 r
.56402 .68648 m .56376 .68615 L p .56799 .69278 L F P
0 g
s
.783 .347 0 r
.56402 .68648 m .56371 .68606 L .56376 .68615 L closepath p F P
0 g
s
0 0 0 r
.48009 .69985 m .48092 .69842 L .47941 .7016 L p F P
0 g
s
0 0 0 r
.47941 .7016 m .47734 .70521 L .48009 .69985 L p F P
0 g
s
.651 .758 .928 r
.84811 .53909 m .85819 .53603 L .86021 .53884 L p F P
0 g
s
.651 .758 .928 r
.85819 .53603 m .84811 .53909 L .84607 .53629 L p F P
0 g
s
0 0 .397 r
.57379 .70356 m .57486 .7065 L .57719 .71044 L p F P
0 g
s
0 0 .436 r
.57486 .7065 m .57379 .70356 L .57163 .69958 L p F P
0 g
s
.827 .986 .714 r
.42585 .6804 m .42751 .67835 L .42687 .67975 L closepath p F P
0 g
s
.856 .987 .712 r
.42294 .68422 m .42585 .6804 L .42687 .67975 L p F P
0 g
s
.76 .844 .915 r
.4421 .76815 m .43394 .77337 L .43179 .77079 L p F P
0 g
s
0 0 .387 r
.64829 .72991 m .64766 .73324 L .64851 .73767 L p F P
0 g
s
0 0 .489 r
.64766 .73324 m .64829 .72991 L .64684 .72565 L p F P
0 g
s
.65 .757 .928 r
.26516 .53329 m .25612 .53634 L .25914 .53915 L p F P
0 g
s
.65 .757 .928 r
.25914 .53915 m .26816 .53611 L .26516 .53329 L p F P
0 g
s
.591 .746 .951 r
.42995 .77195 m .42266 .77336 L .42163 .77046 L p F P
0 g
s
.723 .406 .442 r
.53543 .65966 m .53035 .65915 L .52961 .66291 L p F P
0 g
s
.723 .406 .442 r
.52961 .66291 m .53711 .66368 L .53543 .65966 L p F P
0 g
s
.695 .966 .737 r
.44492 .65967 m .44499 .6596 L .44495 .65965 L closepath p F P
0 g
s
.789 .998 .806 r
.44495 .65965 m .44492 .65967 L .43858 .66603 L p F P
0 g
s
.872 .498 .332 r
.55484 .67302 m .55055 .67095 L .55211 .67505 L p F P
0 g
s
.872 .498 .332 r
.55211 .67505 m .55623 .67717 L .55484 .67302 L p F P
0 g
s
.651 .758 .928 r
.70842 .53333 m .69859 .53639 L .70088 .5392 L p F P
0 g
s
.651 .758 .928 r
.70088 .5392 m .71069 .53615 L .70842 .53333 L p F P
0 g
s
.65 .757 .928 r
.41291 .53335 m .40361 .5364 L .40638 .53921 L p F P
0 g
s
.65 .757 .928 r
.40638 .53921 m .41567 .53617 L .41291 .53335 L p F P
0 g
s
.651 .757 .928 r
.56067 .53336 m .5511 .53641 L .55363 .53922 L p F P
0 g
s
.651 .757 .928 r
.55363 .53922 m .56318 .53618 L .56067 .53336 L p F P
0 g
s
.642 .936 .685 r
.44933 .65486 m .44211 .66118 L .44492 .65967 L p F P
0 g
s
.642 .936 .685 r
.44492 .65967 m .44499 .6596 L .44933 .65486 L p F P
0 g
s
.716 .972 .738 r
.44492 .65967 m .43858 .66603 L .44156 .6617 L p F P
0 g
s
.716 .972 .738 r
.44156 .6617 m .44211 .66118 L .44492 .65967 L p F P
0 g
s
.629 .941 .718 r
.45294 .65272 m .44499 .6596 L .44933 .65486 L p F P
0 g
s
.649 .756 .928 r
.12948 .53285 m .12069 .53588 L .12392 .5387 L p F P
0 g
s
.649 .756 .928 r
.12392 .5387 m .1327 .53568 L .12948 .53285 L p F P
0 g
s
.907 .945 .591 r
.47227 .71513 m .4746 .71058 L .47421 .71303 L closepath p F P
0 g
s
.827 .942 .58 r
.47174 .71599 m .47227 .71513 L .47421 .71303 L p F P
0 g
s
0 0 0 r
.6479 .74565 m .6473 .7505 L .64658 .75315 L p F P
0 g
s
.728 .759 .254 r
.6473 .7505 m .64658 .75315 L .64548 .75649 L p F P
0 g
s
.857 .405 .033 r
.56341 .68585 m .56371 .68606 L .56376 .68615 L closepath p F P
0 g
s
.919 .522 .19 r
.56098 .68366 m .56341 .68585 L .56371 .68606 L p F P
0 g
s
.606 .669 .885 r
.61724 .77281 m .6161 .77301 L .61364 .76935 L p F P
0 g
s
.696 .291 0 r
.57005 .69677 m .57163 .69958 L .57379 .70356 L p F P
0 g
s
.662 .268 0 r
.57163 .69958 m .57005 .69677 L .56799 .69278 L p F P
0 g
s
.65 .757 .928 r
.27722 .53306 m .26816 .53611 L .27116 .53893 L p F P
0 g
s
.65 .757 .928 r
.27116 .53893 m .28021 .53589 L .27722 .53306 L p F P
0 g
s
.651 .758 .928 r
.72055 .53309 m .71069 .53615 L .71296 .53896 L p F P
0 g
s
.651 .758 .928 r
.71296 .53896 m .7228 .53591 L .72055 .53309 L p F P
0 g
s
.907 .518 .262 r
.55962 .67949 m .55623 .67717 L .55768 .68131 L p F P
0 g
s
.907 .518 .262 r
.55768 .68131 m .56098 .68366 L .55962 .67949 L p F P
0 g
s
.65 .757 .928 r
.425 .53312 m .41567 .53617 L .41842 .53898 L p F P
0 g
s
.65 .757 .928 r
.41842 .53898 m .42774 .53594 L .425 .53312 L p F P
0 g
s
.651 .757 .928 r
.57277 .53312 m .56318 .53618 L .56569 .53899 L p F P
0 g
s
.651 .757 .928 r
.56569 .53899 m .57527 .53594 L .57277 .53312 L p F P
0 g
s
.629 .941 .718 r
.45383 .65174 m .45294 .65272 L p .44933 .65486 L F P
0 g
s
.692 .975 .782 r
.45383 .65174 m .4544 .65151 L .45294 .65272 L closepath p F P
0 g
s
.771 .332 0 r
.56376 .68615 m .56582 .69013 L .56799 .69278 L p F P
0 g
s
.849 .392 .013 r
.56376 .68615 m .56582 .69013 L .56297 .68766 L p F P
0 g
s
.849 .392 .013 r
.56341 .68585 m .56376 .68615 L p .56297 .68766 L F P
0 g
s
.918 .725 .231 r
.40349 .73964 m .40276 .73657 L .40257 .74121 L p F P
0 g
s
.918 .725 .231 r
.40257 .74121 m .40331 .74428 L .40349 .73964 L p F P
0 g
s
.653 .349 .445 r
.5259 .65912 m .51829 .65937 L .51765 .66326 L p F P
0 g
s
.545 .259 .431 r
.51829 .65937 m .51765 .66326 L .51172 .66449 L p F P
0 g
s
.599 .941 .768 r
.4544 .65151 m .4627 .64528 L p .45888 .64747 L F P
0 g
s
.599 .941 .768 r
.45888 .64747 m .45383 .65174 L .4544 .65151 L p F P
0 g
s
.75 .984 .756 r
.43858 .66603 m .44156 .6617 L .43525 .66811 L p F P
0 g
s
.75 .984 .756 r
.43541 .6693 m .43858 .66603 L p .43525 .66811 L F P
0 g
s
.8 .361 0 r
.56582 .69013 m .56799 .69278 L .57005 .69677 L p F P
0 g
s
.65 .757 .928 r
.14152 .53264 m .1327 .53568 L .13592 .5385 L p F P
0 g
s
.65 .757 .928 r
.13592 .5385 m .14473 .53547 L .14152 .53264 L p F P
0 g
s
.376 .077 .325 r
.49708 .67639 m .49797 .67268 L .50666 .66912 L p F P
0 g
s
.37 .076 .329 r
.50743 .66533 m .50666 .66912 L .49797 .67268 L p F P
0 g
s
.93 .863 .431 r
.40461 .72618 m .40452 .72361 L .40312 .72858 L p F P
0 g
s
.93 .863 .431 r
.40312 .72858 m .40315 .72963 L .40461 .72618 L p F P
0 g
s
.452 .491 .808 r
.60094 .75858 m .59891 .75801 L .59639 .75229 L p F P
0 g
s
.941 .955 .649 r
.47105 .71947 m .47174 .71599 L .46836 .72156 L p F P
0 g
s
.941 .955 .649 r
.46836 .72156 m .46818 .72488 L .47105 .71947 L p F P
0 g
s
.65 .757 .928 r
.28929 .53284 m .28021 .53589 L .28318 .5387 L p F P
0 g
s
.65 .757 .928 r
.28318 .5387 m .29226 .53566 L .28929 .53284 L p F P
0 g
s
.651 .758 .928 r
.72504 .53872 m .73491 .53567 L .73713 .53848 L p F P
0 g
s
.651 .758 .928 r
.73267 .53285 m .7228 .53591 L .72504 .53872 L p F P
0 g
s
.651 .758 .928 r
.72504 .53872 m .73491 .53567 L .73267 .53285 L p F P
0 g
s
.65 .757 .928 r
.43708 .53288 m .42774 .53594 L .43047 .53875 L p F P
0 g
s
.65 .757 .928 r
.43047 .53875 m .4398 .53571 L .43708 .53288 L p F P
0 g
s
.651 .757 .928 r
.58488 .53289 m .57527 .53594 L .57776 .53875 L p F P
0 g
s
.651 .757 .928 r
.57776 .53875 m .58736 .53571 L .58488 .53289 L p F P
0 g
s
.75 .984 .756 r
.43525 .66811 m .43386 .67008 L .43541 .6693 L p F P
0 g
s
.815 .994 .755 r
.43386 .67008 m .43541 .6693 L .43272 .67228 L closepath p F P
0 g
s
.669 .352 .429 r
.53035 .65915 m .5259 .65912 L .52838 .66291 L p F P
0 g
s
.669 .352 .429 r
.52838 .66291 m .52961 .66291 L .53035 .65915 L p F P
0 g
s
.653 .349 .445 r
.51765 .66326 m .52838 .66291 L .5259 .65912 L p F P
0 g
s
.65 .757 .928 r
.15357 .53243 m .14473 .53547 L .14792 .53829 L p F P
0 g
s
.65 .757 .928 r
.14792 .53829 m .15675 .53527 L .15357 .53243 L p F P
0 g
s
.849 .392 .013 r
.56297 .68766 m .56121 .68432 L .56341 .68585 L p F P
0 g
s
.913 .51 .171 r
.56121 .68432 m .56098 .68366 L .56341 .68585 L closepath p F P
0 g
s
0 .192 .722 r
.62356 .67739 m .62146 .67549 L .61901 .67174 L p F P
0 g
s
.552 .648 .898 r
.61724 .77281 m .62579 .77135 L .62337 .76871 L p F P
0 g
s
.552 .648 .898 r
.62337 .76871 m .62036 .76888 L .61724 .77281 L p F P
0 g
s
.606 .669 .885 r
.61364 .76935 m .62036 .76888 L .61724 .77281 L p F P
0 g
s
.905 .962 .638 r
.41443 .69917 m .41506 .69562 L .41194 .70108 L p F P
0 g
s
.905 .962 .638 r
.41194 .70108 m .41128 .70463 L .41443 .69917 L p F P
0 g
s
.65 .757 .928 r
.30136 .53261 m .29226 .53566 L .29521 .53847 L p F P
0 g
s
.65 .757 .928 r
.29521 .53847 m .30431 .53543 L .30136 .53261 L p F P
0 g
s
.651 .758 .928 r
.73713 .53848 m .74702 .53543 L .74922 .53824 L p F P
0 g
s
.651 .758 .928 r
.74702 .53543 m .73713 .53848 L .73491 .53567 L p F P
0 g
s
.65 .757 .928 r
.44917 .53265 m .4398 .53571 L .44252 .53852 L p F P
0 g
s
.65 .757 .928 r
.44252 .53852 m .45188 .53547 L .44917 .53265 L p F P
0 g
s
.651 .757 .928 r
.59699 .53265 m .58736 .53571 L .58983 .53852 L p F P
0 g
s
.651 .757 .928 r
.58983 .53852 m .59945 .53547 L .59699 .53265 L p F P
0 g
s
.171 0 .245 r
.49316 .67905 m .49708 .67639 L .49619 .68011 L p F P
0 g
s
.171 0 .245 r
.49619 .68011 m .48938 .6847 L .49316 .67905 L p F P
0 g
s
.693 .841 .954 r
.63029 .77234 m .62819 .77346 L .62579 .77135 L p F P
0 g
s
0 .231 .74 r
.61218 .66496 m .61017 .66223 L .60587 .65893 L p F P
0 g
s
0 .205 .709 r
.60357 .65627 m .60587 .65893 L .61017 .66223 L p F P
0 g
s
0 .255 .749 r
.60175 .65499 m .60357 .65627 L .60587 .65893 L p F P
0 g
s
.898 .855 .791 r
.44953 .75651 m .45068 .7583 L .45161 .75878 L p F P
0 g
s
.848 .877 .861 r
.45068 .7583 m .45161 .75878 L .45108 .75928 L closepath p F P
0 g
s
.845 .876 .864 r
.45108 .75928 m .4444 .7658 L .44263 .76309 L p F P
0 g
s
.845 .876 .864 r
.45068 .7583 m .45108 .75928 L p .44263 .76309 L F P
0 g
s
.867 .975 .668 r
.41619 .69384 m .41881 .68997 L .41805 .69236 L closepath p F P
0 g
s
.89 .973 .667 r
.41506 .69562 m .41619 .69384 L .41805 .69236 L p F P
0 g
s
.769 .974 .697 r
.43272 .67228 m .42751 .67835 L .42962 .67431 L p F P
0 g
s
.769 .974 .697 r
.43386 .67008 m .43272 .67228 L p .42962 .67431 L F P
0 g
s
.65 .757 .928 r
.16562 .53222 m .15675 .53527 L .15993 .53809 L p F P
0 g
s
.65 .757 .928 r
.15993 .53809 m .16878 .53505 L .16562 .53222 L p F P
0 g
s
.783 .423 .373 r
.54516 .6692 m .54397 .66661 L .54442 .66549 L p F P
0 g
s
.819 .466 .387 r
.54397 .66661 m .54346 .66516 L .54442 .66549 L closepath p F P
0 g
s
.651 .758 .928 r
.74922 .53824 m .75913 .53519 L .76132 .538 L p F P
0 g
s
.651 .758 .928 r
.75913 .53519 m .74922 .53824 L .74702 .53543 L p F P
0 g
s
.65 .757 .928 r
.31343 .53238 m .30431 .53543 L .30724 .53825 L p F P
0 g
s
.65 .757 .928 r
.30724 .53825 m .31636 .5352 L .31343 .53238 L p F P
0 g
s
.651 .757 .928 r
.60911 .53241 m .59945 .53547 L .6019 .53828 L p F P
0 g
s
.651 .757 .928 r
.6019 .53828 m .61154 .53524 L .60911 .53241 L p F P
0 g
s
.651 .757 .928 r
.46127 .53241 m .45188 .53547 L .45457 .53829 L p F P
0 g
s
.651 .757 .928 r
.45457 .53829 m .46395 .53524 L .46127 .53241 L p F P
0 g
s
.946 .898 .747 r
.46216 .73906 m .46143 .73602 L .4577 .7417 L p F P
0 g
s
.946 .898 .747 r
.4577 .7417 m .45882 .74462 L .46216 .73906 L p F P
0 g
s
0 0 .476 r
.64715 .72308 m .64684 .72565 L .64829 .72991 L p F P
0 g
s
0 .022 .57 r
.64659 .72107 m .64529 .71827 L p .64684 .72565 L F P
0 g
s
0 .022 .57 r
.64684 .72565 m .64715 .72308 L .64659 .72107 L p F P
0 g
s
.857 .851 .836 r
.4421 .76815 m .4444 .7658 L .44263 .76309 L p F P
0 g
s
.599 .941 .768 r
.4627 .64528 m .46351 .6446 L p .45888 .64747 L F P
0 g
s
0 0 0 r
.64871 .7423 m .6479 .74565 L .6473 .7505 L p F P
0 g
s
0 0 .235 r
.6479 .74565 m .64871 .7423 L .64851 .73767 L p F P
0 g
s
.543 .236 .398 r
.50666 .66912 m .50743 .66533 L .51172 .66449 L p F P
0 g
s
.65 .757 .928 r
.17767 .53201 m .16878 .53505 L .17194 .53787 L p F P
0 g
s
.65 .757 .928 r
.17194 .53787 m .18082 .53484 L .17767 .53201 L p F P
0 g
s
.857 .851 .836 r
.44263 .76309 m .43937 .76626 L .4421 .76815 L p F P
0 g
s
.76 .844 .915 r
.43179 .77079 m .43937 .76626 L .4421 .76815 L p F P
0 g
s
.693 .841 .954 r
.62579 .77135 m .63172 .76888 L .63029 .77234 L p F P
0 g
s
.74 .964 .937 r
.63545 .76717 m .63172 .76888 L .63029 .77234 L p F P
0 g
s
.74 .964 .937 r
.63029 .77234 m .63778 .7677 L .63545 .76717 L p F P
0 g
s
.651 .758 .928 r
.76132 .538 m .77125 .53495 L .77342 .53776 L p F P
0 g
s
.651 .758 .928 r
.77125 .53495 m .76132 .538 L .75913 .53519 L p F P
0 g
s
.65 .757 .928 r
.32551 .53215 m .31636 .5352 L .31928 .53802 L p F P
0 g
s
.65 .757 .928 r
.31928 .53802 m .32842 .53497 L .32551 .53215 L p F P
0 g
s
.651 .757 .928 r
.62122 .53218 m .61154 .53524 L .61397 .53805 L p F P
0 g
s
.651 .757 .928 r
.61397 .53805 m .62364 .535 L .62122 .53218 L p F P
0 g
s
.651 .757 .928 r
.47337 .53218 m .46395 .53524 L .46662 .53805 L p F P
0 g
s
.651 .757 .928 r
.46662 .53805 m .47603 .535 L .47337 .53218 L p F P
0 g
s
.778 .424 .385 r
.54346 .66516 m .53711 .66368 L .53887 .6677 L p F P
0 g
s
.778 .424 .385 r
.54397 .66661 m .54346 .66516 L p .53887 .6677 L F P
0 g
s
.558 .909 .7 r
.45161 .65295 m .45888 .64747 L .45383 .65174 L closepath p F P
0 g
s
.629 .941 .718 r
.44933 .65486 m .45161 .65295 L .45383 .65174 L p F P
0 g
s
.936 .87 .748 r
.45847 .74521 m .45882 .74462 L .45926 .74544 L closepath p F P
0 g
s
.903 .903 .814 r
.45411 .75058 m .45847 .74521 L .45926 .74544 L p F P
0 g
s
0 0 .564 r
.40737 .75882 m .40623 .7559 L .40896 .75975 L p F P
0 g
s
0 0 .564 r
.40896 .75975 m .41027 .76261 L .40737 .75882 L p F P
0 g
s
.65 .757 .928 r
.18973 .53179 m .18082 .53484 L .18396 .53766 L p F P
0 g
s
.65 .757 .928 r
.18396 .53766 m .19286 .53462 L .18973 .53179 L p F P
0 g
s
.323 .403 .79 r
.59639 .75229 m .59608 .75211 L .5962 .75185 L closepath p F P
0 g
s
.324 .405 .791 r
.59386 .74632 m .59248 .7453 L p .59608 .75211 L F P
0 g
s
.324 .405 .791 r
.59608 .75211 m .5962 .75185 L .59386 .74632 L p F P
0 g
s
0 .216 .662 r
.58838 .64498 m .58513 .64258 L .58996 .64568 L p F P
0 g
s
0 .216 .662 r
.58996 .64568 m .59323 .64808 L .58838 .64498 L p F P
0 g
s
0 0 0 r
.47734 .70521 m .4746 .71058 L .47632 .70677 L p F P
0 g
s
0 0 0 r
.47941 .7016 m .47734 .70521 L p .47632 .70677 L F P
0 g
s
.651 .758 .928 r
.77342 .53776 m .78337 .5347 L .78552 .53752 L p F P
0 g
s
.651 .758 .928 r
.78337 .5347 m .77342 .53776 L .77125 .53495 L p F P
0 g
s
.65 .757 .928 r
.33759 .53192 m .32842 .53497 L .33131 .53779 L p F P
0 g
s
.65 .757 .928 r
.33131 .53779 m .34048 .53474 L .33759 .53192 L p F P
0 g
s
.651 .757 .928 r
.63334 .53194 m .62364 .535 L .62605 .53781 L p F P
0 g
s
.651 .757 .928 r
.62605 .53781 m .63574 .53476 L .63334 .53194 L p F P
0 g
s
.651 .757 .928 r
.48547 .53194 m .47603 .535 L .47868 .53782 L p F P
0 g
s
.651 .757 .928 r
.47868 .53782 m .48811 .53477 L .48547 .53194 L p F P
0 g
s
0 .329 .814 r
.4152 .76771 m .41172 .76542 L .41027 .76261 L p F P
0 g
s
.039 .379 .844 r
.41172 .76542 m .4152 .76771 L .41793 .77081 L p F P
0 g
s
.247 .352 .774 r
.59386 .74632 m .59248 .7453 L .59288 .74397 L closepath p F P
0 g
s
.248 .353 .774 r
.59132 .74023 m .58929 .73837 L p .59248 .7453 L F P
0 g
s
.248 .353 .774 r
.59248 .7453 m .59288 .74397 L .59132 .74023 L p F P
0 g
s
.932 .897 .494 r
.40634 .71852 m .40635 .71518 L .40457 .72027 L p F P
0 g
s
.932 .897 .494 r
.40457 .72027 m .40452 .72361 L .40634 .71852 L p F P
0 g
s
.799 .983 .714 r
.42751 .67835 m .42962 .67431 L .4246 .68033 L p F P
0 g
s
.799 .983 .714 r
.42585 .6804 m .42751 .67835 L p .4246 .68033 L F P
0 g
s
0 .263 .769 r
.61821 .67107 m .61653 .66826 L .61218 .66496 L p F P
0 g
s
0 .312 .799 r
.61017 .66223 m .61218 .66496 L .61653 .66826 L p F P
0 g
s
.098 0 .181 r
.48876 .6856 m .48938 .6847 L .48892 .68503 L closepath p F P
0 g
s
0 0 .135 r
.48607 .69022 m .48876 .6856 L .48892 .68503 L p F P
0 g
s
0 0 0 r
.48092 .69842 m .48289 .69571 L .47969 .70121 L p F P
0 g
s
0 0 0 r
.47969 .70121 m .47941 .7016 L .48092 .69842 L p F P
0 g
s
.452 .491 .808 r
.59639 .75229 m .60287 .75492 L .60094 .75858 L p F P
0 g
s
.406 .454 .797 r
.60287 .75492 m .59639 .75229 L .5962 .75185 L p F P
0 g
s
.65 .757 .928 r
.20179 .53158 m .19286 .53462 L .19598 .53745 L p F P
0 g
s
.65 .757 .928 r
.19598 .53745 m .2049 .53441 L .20179 .53158 L p F P
0 g
s
.485 .52 .818 r
.60094 .75858 m .60868 .76099 L p .60757 .76456 L F P
0 g
s
.376 .449 .809 r
.60094 .75858 m .60868 .76099 L .60619 .75639 L p F P
0 g
s
.376 .449 .809 r
.60619 .75639 m .60287 .75492 L .60094 .75858 L p F P
0 g
s
.651 .758 .928 r
.78552 .53752 m .7955 .53446 L .79762 .53727 L p F P
0 g
s
.651 .758 .928 r
.7955 .53446 m .78552 .53752 L .78337 .5347 L p F P
0 g
s
.944 .803 .349 r
.40351 .73177 m .40315 .72963 L .40225 .7336 L p F P
0 g
s
.944 .803 .349 r
.40225 .7336 m .40276 .73657 L .40351 .73177 L p F P
0 g
s
.406 .454 .797 r
.5962 .75185 m .59797 .74845 L p .60287 .75492 L F P
0 g
s
.354 .423 .794 r
.5962 .75185 m .59386 .74632 L .59797 .74845 L closepath p F P
0 g
s
.65 .757 .928 r
.34967 .53168 m .34048 .53474 L .34335 .53756 L p F P
0 g
s
.65 .757 .928 r
.34335 .53756 m .35254 .53451 L .34967 .53168 L p F P
0 g
s
.651 .757 .928 r
.64547 .5317 m .63574 .53476 L .63813 .53758 L p F P
0 g
s
.651 .757 .928 r
.63813 .53758 m .64785 .53452 L .64547 .5317 L p F P
0 g
s
.651 .757 .928 r
.49757 .53171 m .48811 .53477 L .49074 .53759 L p F P
0 g
s
.651 .757 .928 r
.49074 .53759 m .50019 .53454 L .49757 .53171 L p F P
0 g
s
.148 .287 .751 r
.59132 .74023 m .58929 .73837 L .58963 .73616 L closepath p F P
0 g
s
.148 .287 .75 r
.58878 .73412 m .5863 .73138 L p .58929 .73837 L F P
0 g
s
.148 .287 .75 r
.58929 .73837 m .58963 .73616 L .58878 .73412 L p F P
0 g
s
0 0 .531 r
.64659 .72107 m .64529 .71827 L .64536 .71675 L closepath p F P
0 g
s
0 .07 .615 r
.644 .71273 m .64306 .71106 L p .64529 .71827 L F P
0 g
s
0 .07 .615 r
.64529 .71827 m .64536 .71675 L .644 .71273 L p F P
0 g
s
.799 .983 .714 r
.4246 .68033 m .4239 .68164 L .42585 .6804 L p F P
0 g
s
.856 .987 .713 r
.4239 .68164 m .42585 .6804 L .42294 .68422 L closepath p F P
0 g
s
.501 .667 .937 r
.41793 .77081 m .42163 .77046 L .4202 .76765 L p F P
0 g
s
.501 .667 .937 r
.4202 .76765 m .4152 .76771 L .41793 .77081 L p F P
0 g
s
.434 .843 .663 r
.4611 .64589 m .46351 .6446 L .47094 .63979 L p F P
0 g
s
.599 .941 .768 r
.46351 .6446 m .4611 .64589 L .45888 .64747 L p F P
0 g
s
0 0 .246 r
.40475 .75172 m .40383 .74873 L .40523 .75293 L p F P
0 g
s
0 0 .246 r
.40523 .75293 m .40623 .7559 L .40475 .75172 L p F P
0 g
s
.65 .757 .928 r
.21385 .53135 m .2049 .53441 L .208 .53723 L p F P
0 g
s
.65 .757 .928 r
.208 .53723 m .21694 .53419 L .21385 .53135 L p F P
0 g
s
.651 .758 .928 r
.80762 .53421 m .79762 .53727 L .7955 .53446 L p F P
0 g
s
.651 .758 .928 r
.79762 .53727 m .80762 .53421 L .80973 .53703 L p F P
0 g
s
.953 .948 .72 r
.46818 .72488 m .46836 .72156 L .46505 .72711 L p F P
0 g
s
.953 .948 .72 r
.46536 .73023 m .46818 .72488 L p .46505 .72711 L F P
0 g
s
.128 0 .158 r
.48938 .6847 m .49619 .68011 L p .49393 .68456 L F P
0 g
s
.128 0 .158 r
.48876 .6856 m .48938 .6847 L p .49393 .68456 L F P
0 g
s
.649 .756 .928 r
.07804 .53078 m .06933 .53381 L .07265 .53664 L p F P
0 g
s
.649 .756 .928 r
.07265 .53664 m .08135 .53362 L .07804 .53078 L p F P
0 g
s
.65 .757 .928 r
.36176 .53145 m .35254 .53451 L .3554 .53733 L p F P
0 g
s
.65 .757 .928 r
.3554 .53733 m .36461 .53428 L .36176 .53145 L p F P
0 g
s
.651 .757 .928 r
.6576 .53146 m .64785 .53452 L .65022 .53734 L p F P
0 g
s
.651 .757 .928 r
.65022 .53734 m .65996 .53429 L .6576 .53146 L p F P
0 g
s
.651 .757 .928 r
.50968 .53147 m .50019 .53454 L .50281 .53735 L p F P
0 g
s
.651 .757 .928 r
.50281 .53735 m .51228 .5343 L .50968 .53147 L p F P
0 g
s
.896 .855 .793 r
.44889 .75735 m .44953 .75651 L .45068 .7583 L closepath p F P
0 g
s
.845 .876 .864 r
.44263 .76309 m .44889 .75735 L .45068 .7583 L p F P
0 g
s
.543 .236 .398 r
.51172 .66449 m .51724 .66559 L p .50666 .66912 L F P
0 g
s
.541 .244 .412 r
.51724 .66559 m .51172 .66449 L .51765 .66326 L closepath p F P
0 g
s
.833 .989 .866 r
.64033 .76491 m .63778 .7677 L .63545 .76717 L p F P
0 g
s
.833 .989 .866 r
.63545 .76717 m .64171 .76144 L .64033 .76491 L p F P
0 g
s
.839 .984 .702 r
.64492 .75726 m .64548 .75649 L p .64033 .76491 L F P
0 g
s
.839 .984 .702 r
.64033 .76491 m .64171 .76144 L .64492 .75726 L p F P
0 g
s
.896 .954 .61 r
.41128 .70463 m .41194 .70108 L .40912 .70646 L p F P
0 g
s
.896 .954 .61 r
.40934 .70834 m .41128 .70463 L p .40912 .70646 L F P
0 g
s
.128 0 .158 r
.49393 .68456 m .48777 .68853 L .48876 .6856 L p F P
0 g
s
0 0 .043 r
.48777 .68853 m .48876 .6856 L .48607 .69022 L closepath p F P
0 g
s
.65 .757 .928 r
.22592 .53113 m .21694 .53419 L .22003 .53701 L p F P
0 g
s
.65 .757 .928 r
.22003 .53701 m .22899 .53396 L .22592 .53113 L p F P
0 g
s
.016 .204 .713 r
.58878 .73412 m .5863 .73138 L .58629 .72825 L closepath p F P
0 g
s
.014 .201 .711 r
.58624 .72814 m .58336 .72438 L p .5863 .73138 L F P
0 g
s
.014 .201 .711 r
.5863 .73138 m .58629 .72825 L .58624 .72814 L p F P
0 g
s
.651 .758 .928 r
.80973 .53703 m .81975 .53397 L .82184 .53678 L p F P
0 g
s
.651 .758 .928 r
.81975 .53397 m .80973 .53703 L .80762 .53421 L p F P
0 g
s
.65 .757 .928 r
.37385 .53122 m .36461 .53428 L .36745 .5371 L p F P
0 g
s
.65 .757 .928 r
.36745 .5371 m .37668 .53405 L .37385 .53122 L p F P
0 g
s
.651 .758 .928 r
.66973 .53122 m .65996 .53429 L .66231 .5371 L p F P
0 g
s
.651 .758 .928 r
.66231 .5371 m .67207 .53405 L .66973 .53122 L p F P
0 g
s
0 .2 .724 r
.61821 .67107 m .61901 .67174 L .61656 .66829 L p F P
0 g
s
0 .2 .724 r
.61656 .66829 m .61653 .66826 L .61821 .67107 L p F P
0 g
s
.651 .757 .928 r
.52179 .53124 m .51228 .5343 L .51488 .53712 L p F P
0 g
s
.651 .757 .928 r
.51488 .53712 m .52437 .53407 L .52179 .53124 L p F P
0 g
s
.649 .756 .928 r
.09008 .5306 m .08135 .53362 L .08465 .53646 L p F P
0 g
s
.649 .756 .928 r
.08465 .53646 m .09338 .53344 L .09008 .5306 L p F P
0 g
s
0 .228 .714 r
.60175 .65499 m .60357 .65627 L .60098 .65369 L p F P
0 g
s
0 .228 .714 r
.60098 .65369 m .5993 .65252 L .60175 .65499 L p F P
0 g
s
0 .29 .764 r
.59618 .65056 m .5993 .65252 L .60175 .65499 L p F P
0 g
s
.946 .898 .747 r
.45847 .74521 m .45882 .74462 L .4577 .7417 L p F P
0 g
s
.826 .461 .366 r
.55055 .67095 m .54516 .6692 L .54702 .67321 L p F P
0 g
s
.826 .461 .366 r
.54702 .67321 m .55211 .67505 L .55055 .67095 L p F P
0 g
s
.774 .419 .384 r
.5432 .66875 m .54397 .66661 L .54516 .6692 L closepath p F P
0 g
s
.778 .424 .385 r
.53887 .6677 m .5432 .66875 L .54397 .66661 L p F P
0 g
s
.651 .758 .928 r
.82184 .53678 m .83189 .53372 L .83396 .53654 L p F P
0 g
s
.651 .758 .928 r
.83189 .53372 m .82184 .53678 L .81975 .53397 L p F P
0 g
s
.65 .757 .928 r
.23799 .53091 m .22899 .53396 L .23206 .53679 L p F P
0 g
s
.65 .757 .928 r
.23206 .53679 m .24105 .53374 L .23799 .53091 L p F P
0 g
s
0 .006 .574 r
.644 .71273 m .64306 .71106 L .64301 .70983 L closepath p F P
0 g
s
0 .117 .656 r
.64147 .70593 m .6402 .70404 L p .64306 .71106 L F P
0 g
s
0 .117 .656 r
.64306 .71106 m .64301 .70983 L .64147 .70593 L p F P
0 g
s
.651 .758 .928 r
.68186 .53098 m .67207 .53405 L .6744 .53687 L p F P
0 g
s
.651 .758 .928 r
.6744 .53687 m .68418 .53381 L .68186 .53098 L p F P
0 g
s
.65 .757 .928 r
.38594 .53099 m .37668 .53405 L .3795 .53687 L p F P
0 g
s
.65 .757 .928 r
.3795 .53687 m .38875 .53382 L .38594 .53099 L p F P
0 g
s
.651 .757 .928 r
.5339 .531 m .52437 .53407 L .52695 .53688 L p F P
0 g
s
.651 .757 .928 r
.52695 .53688 m .53647 .53383 L .5339 .531 L p F P
0 g
s
.946 .898 .747 r
.4577 .7417 m .45574 .74473 L .45847 .74521 L p F P
0 g
s
.896 .931 .832 r
.45847 .74521 m .45411 .75058 L .45323 .7476 L p F P
0 g
s
.896 .931 .832 r
.45323 .7476 m .45574 .74473 L .45847 .74521 L p F P
0 g
s
.814 .966 .649 r
.42294 .68422 m .41881 .68997 L .42024 .68616 L p F P
0 g
s
.814 .966 .649 r
.4239 .68164 m .42294 .68422 L p .42024 .68616 L F P
0 g
s
.649 .756 .928 r
.10213 .5304 m .09338 .53344 L .09666 .53627 L p F P
0 g
s
.649 .756 .928 r
.09666 .53627 m .10541 .53325 L .10213 .5304 L p F P
0 g
s
.565 .629 .874 r
.62036 .76888 m .61364 .76935 L .61117 .76532 L p F P
0 g
s
.439 .548 .869 r
.61117 .76532 m .60757 .76456 L .60889 .76135 L closepath p F P
0 g
s
.485 .52 .818 r
.60868 .76099 m .60889 .76135 L .60757 .76456 L p F P
0 g
s
0 .046 .61 r
.58336 .72438 m .58624 .72814 L .5837 .72242 L p F P
0 g
s
0 .046 .61 r
.5837 .72242 m .58294 .72129 L .58336 .72438 L p F P
0 g
s
0 .04 .606 r
.58336 .72438 m .58294 .72129 L .58035 .71739 L p F P
0 g
s
.651 .758 .928 r
.83396 .53654 m .84402 .53347 L .84607 .53629 L p F P
0 g
s
.651 .758 .928 r
.84402 .53347 m .83396 .53654 L .83189 .53372 L p F P
0 g
s
0 0 .227 r
.6492 .73434 m .64851 .73767 L .64871 .7423 L p F P
0 g
s
0 0 .387 r
.64851 .73767 m .6492 .73434 L .64829 .72991 L p F P
0 g
s
0 .157 .698 r
.6284 .68385 m .62713 .68095 L .62356 .67739 L p F P
0 g
s
0 .134 .677 r
.62202 .67455 m .62356 .67739 L .62713 .68095 L p F P
0 g
s
0 .192 .722 r
.61901 .67174 m .62202 .67455 L .62356 .67739 L p F P
0 g
s
.65 .757 .928 r
.25007 .53068 m .24105 .53374 L .24409 .53656 L p F P
0 g
s
.65 .757 .928 r
.24409 .53656 m .2531 .53352 L .25007 .53068 L p F P
0 g
s
0 .262 .725 r
.5993 .65252 m .59618 .65056 L .59323 .64808 L p F P
0 g
s
.651 .758 .928 r
.694 .53074 m .68418 .53381 L .68649 .53663 L p F P
0 g
s
.651 .758 .928 r
.68649 .53663 m .6963 .53357 L .694 .53074 L p F P
0 g
s
.65 .757 .928 r
.39804 .53075 m .38875 .53382 L .39155 .53664 L p F P
0 g
s
.65 .757 .928 r
.39155 .53664 m .40083 .53358 L .39804 .53075 L p F P
0 g
s
.651 .757 .928 r
.54602 .53077 m .53647 .53383 L .53902 .53665 L p F P
0 g
s
.651 .757 .928 r
.53902 .53665 m .54857 .53359 L .54602 .53077 L p F P
0 g
s
.36 .422 .79 r
.59797 .74845 m .59386 .74632 L .59288 .74397 L p F P
0 g
s
.815 .574 .017 r
.40331 .74428 m .40257 .74121 L .40305 .74568 L p F P
0 g
s
.815 .574 .017 r
.40305 .74568 m .40383 .74873 L .40331 .74428 L p F P
0 g
s
.649 .756 .928 r
.11418 .53021 m .10541 .53325 L .10867 .53608 L p F P
0 g
s
.649 .756 .928 r
.10867 .53608 m .11744 .53305 L .11418 .53021 L p F P
0 g
s
.767 .824 .897 r
.42986 .76813 m .42721 .76965 L .42995 .77195 L p F P
0 g
s
.767 .824 .897 r
.42995 .77195 m .43179 .77079 L .42986 .76813 L p F P
0 g
s
.591 .746 .951 r
.42163 .77046 m .42721 .76965 L .42995 .77195 L p F P
0 g
s
0 .049 .613 r
.64147 .70593 m .6402 .70404 L .63995 .70216 L closepath p F P
0 g
s
0 .161 .694 r
.63897 .69999 m .63676 .69717 L p .6402 .70404 L F P
0 g
s
0 .161 .694 r
.6402 .70404 m .63995 .70216 L .63897 .69999 L p F P
0 g
s
0 0 .547 r
.57953 .7144 m .58035 .71739 L .58294 .72129 L p F P
0 g
s
0 0 .516 r
.58035 .71739 m .57953 .7144 L .57719 .71044 L p F P
0 g
s
.651 .758 .928 r
.84607 .53629 m .85616 .53322 L .85819 .53603 L p F P
0 g
s
.651 .758 .928 r
.85616 .53322 m .84607 .53629 L .84402 .53347 L p F P
0 g
s
.878 .496 .311 r
.55623 .67717 m .55211 .67505 L .55372 .67915 L p F P
0 g
s
.878 .496 .311 r
.55372 .67915 m .55768 .68131 L .55623 .67717 L p F P
0 g
s
.65 .757 .928 r
.26215 .53046 m .2531 .53352 L .25612 .53634 L p F P
0 g
s
.65 .757 .928 r
.25612 .53634 m .26516 .53329 L .26215 .53046 L p F P
0 g
s
0 .154 .696 r
.63281 .69044 m .63182 .68747 L .6284 .68385 L p F P
0 g
s
0 .137 .683 r
.62713 .68095 m .6284 .68385 L .63182 .68747 L p F P
0 g
s
.651 .758 .928 r
.70614 .5305 m .6963 .53357 L .69859 .53639 L p F P
0 g
s
.651 .758 .928 r
.69859 .53639 m .70842 .53333 L .70614 .5305 L p F P
0 g
s
.65 .757 .928 r
.41014 .53052 m .40083 .53358 L .40361 .5364 L p F P
0 g
s
.65 .757 .928 r
.40361 .5364 m .41291 .53335 L .41014 .53052 L p F P
0 g
s
.651 .757 .928 r
.55814 .53053 m .54857 .53359 L .5511 .53641 L p F P
0 g
s
.651 .757 .928 r
.5511 .53641 m .56067 .53336 L .55814 .53053 L p F P
0 g
s
0 .151 .685 r
.62202 .67455 m .61901 .67174 L .61656 .66829 L p F P
0 g
s
.686 .363 .424 r
.53711 .66368 m .53887 .6677 L .53084 .66672 L p F P
0 g
s
.686 .363 .424 r
.52961 .66291 m .53711 .66368 L p .53084 .66672 L F P
0 g
s
.837 .943 .579 r
.4746 .71058 m .47632 .70677 L .47298 .71233 L p F P
0 g
s
.837 .943 .579 r
.47227 .71513 m .4746 .71058 L p .47298 .71233 L F P
0 g
s
0 .068 .63 r
.63676 .69717 m .63897 .69999 L .63648 .69468 L p F P
0 g
s
0 .068 .63 r
.63648 .69468 m .63607 .69413 L .63676 .69717 L p F P
0 g
s
0 .147 .689 r
.63676 .69717 m .63607 .69413 L .63281 .69044 L p F P
0 g
s
.649 .756 .928 r
.12624 .53001 m .11744 .53305 L .12069 .53588 L p F P
0 g
s
.649 .756 .928 r
.12069 .53588 m .12948 .53285 L .12624 .53001 L p F P
0 g
s
0 .168 .706 r
.63182 .68747 m .63281 .69044 L .63607 .69413 L p F P
0 g
s
.742 .85 .93 r
.43937 .76626 m .43179 .77079 L .42986 .76813 L p F P
0 g
s
.36 .422 .79 r
.59288 .74397 m .59377 .74178 L p .59797 .74845 L F P
0 g
s
.302 .387 .783 r
.59288 .74397 m .59132 .74023 L .59377 .74178 L closepath p F P
0 g
s
.905 .509 .249 r
.56121 .68432 m .56098 .68366 L .55768 .68131 L p F P
0 g
s
0 0 .365 r
.57594 .70755 m .57719 .71044 L .57953 .7144 L p F P
0 g
s
0 0 .365 r
.57812 .71156 m .57594 .70755 L p .57621 .70806 L F P
0 g
s
0 0 .365 r
.57953 .7144 m .57812 .71156 L p .57621 .70806 L F P
0 g
s
.701 .275 0 r
.57812 .71156 m .57658 .70933 L .5786 .71243 L p F P
0 g
s
0 0 .376 r
.57864 .7125 m .57812 .71156 L .57953 .7144 L p F P
0 g
s
.701 .275 0 r
.5786 .71243 m .57864 .7125 L .57812 .71156 L p F P
0 g
s
.713 .288 0 r
.57594 .70755 m .57812 .71156 L p .57803 .7114 L F P
0 g
s
0 0 .397 r
.57719 .71044 m .57594 .70755 L p .57387 .70372 L F P
0 g
s
.713 .288 0 r
.57415 .70481 m .57594 .70755 L p .57803 .7114 L F P
0 g
s
0 0 .397 r
.57594 .70755 m .57379 .70356 L p .57387 .70372 L F P
0 g
s
.65 .757 .928 r
.27423 .53023 m .26516 .53329 L .26816 .53611 L p F P
0 g
s
.65 .757 .928 r
.26816 .53611 m .27722 .53306 L .27423 .53023 L p F P
0 g
s
.651 .758 .928 r
.71829 .53026 m .70842 .53333 L .71069 .53615 L p F P
0 g
s
.651 .758 .928 r
.71069 .53615 m .72055 .53309 L .71829 .53026 L p F P
0 g
s
.896 .954 .61 r
.40912 .70646 m .40858 .70912 L .40934 .70834 L p F P
0 g
s
.934 .946 .61 r
.40858 .70912 m .40934 .70834 L .40852 .70999 L closepath p F P
0 g
s
.65 .757 .928 r
.42225 .53029 m .41291 .53335 L .41567 .53617 L p F P
0 g
s
.65 .757 .928 r
.41567 .53617 m .425 .53312 L .42225 .53029 L p F P
0 g
s
.651 .757 .928 r
.57027 .53029 m .56067 .53336 L .56318 .53618 L p F P
0 g
s
.651 .757 .928 r
.56318 .53618 m .57277 .53312 L .57027 .53029 L p F P
0 g
s
.903 .877 .8 r
.45411 .75058 m .45323 .7476 L .44812 .75368 L p F P
0 g
s
.903 .877 .8 r
.44812 .75368 m .44953 .75651 L .45411 .75058 L p F P
0 g
s
.65 .756 .928 r
.1383 .5298 m .12948 .53285 L .1327 .53568 L p F P
0 g
s
.65 .756 .928 r
.1327 .53568 m .14152 .53264 L .1383 .5298 L p F P
0 g
s
0 0 .042 r
.48607 .69022 m .48777 .68853 L .4866 .69202 L p F P
0 g
s
0 0 .042 r
.4866 .69202 m .48289 .69571 L .48607 .69022 L p F P
0 g
s
.728 .759 .254 r
.64548 .75649 m .6457 .75564 L .6473 .7505 L p F P
0 g
s
0 0 0 r
.6473 .7505 m .64806 .74717 L .64871 .7423 L p F P
0 g
s
.811 .825 .348 r
.64806 .74717 m .6473 .7505 L .6457 .75564 L p F P
0 g
s
.725 .962 .691 r
.43256 .67096 m .43525 .66811 L .43386 .67008 L closepath p F P
0 g
s
.769 .974 .697 r
.42962 .67431 m .43256 .67096 L .43386 .67008 L p F P
0 g
s
.718 .304 0 r
.57209 .70079 m .57379 .70356 L .57594 .70755 L p F P
0 g
s
.696 .291 0 r
.57379 .70356 m .57209 .70079 L .57005 .69677 L p F P
0 g
s
.8 .361 0 r
.57005 .69677 m .56783 .69414 L .56582 .69013 L p F P
0 g
s
.856 .405 .021 r
.56582 .69013 m .56297 .68766 L .56503 .69166 L p F P
0 g
s
.856 .405 .021 r
.56503 .69166 m .56783 .69414 L .56582 .69013 L p F P
0 g
s
.65 .757 .928 r
.28632 .53 m .27722 .53306 L .28021 .53589 L p F P
0 g
s
.65 .757 .928 r
.28021 .53589 m .28929 .53284 L .28632 .53 L p F P
0 g
s
.953 .948 .72 r
.46505 .72711 m .46531 .73024 L .46536 .73023 L p F P
0 g
s
.927 .972 .748 r
.46531 .73024 m .46536 .73023 L .46531 .7303 L closepath p F P
0 g
s
.651 .758 .928 r
.73043 .53002 m .72055 .53309 L .7228 .53591 L p F P
0 g
s
.651 .758 .928 r
.7228 .53591 m .73267 .53285 L .73043 .53002 L p F P
0 g
s
.897 .846 .391 r
.40452 .72361 m .40457 .72027 L .40322 .72524 L p F P
0 g
s
.897 .846 .391 r
.40322 .72524 m .40312 .72858 L .40452 .72361 L p F P
0 g
s
.907 .983 .764 r
.46531 .7303 m .46143 .73602 L .46147 .73275 L p F P
0 g
s
.907 .983 .764 r
.46531 .73024 m .46531 .7303 L p .46147 .73275 L F P
0 g
s
.65 .757 .928 r
.43435 .53005 m .425 .53312 L .42774 .53594 L p F P
0 g
s
.65 .757 .928 r
.42774 .53594 m .43708 .53288 L .43435 .53005 L p F P
0 g
s
.651 .757 .928 r
.58239 .53006 m .57277 .53312 L .57527 .53594 L p F P
0 g
s
.651 .757 .928 r
.57527 .53594 m .58488 .53289 L .58239 .53006 L p F P
0 g
s
.808 .368 0 r
.56783 .69414 m .57005 .69677 L .57209 .70079 L p F P
0 g
s
.616 .311 .43 r
.51765 .66326 m .52838 .66291 L p .51864 .66696 L F P
0 g
s
.616 .311 .43 r
.51864 .66696 m .51724 .66559 L .51765 .66326 L p F P
0 g
s
.563 .733 .955 r
.42721 .76965 m .42163 .77046 L .4202 .76765 L p F P
0 g
s
.953 .949 .721 r
.46262 .73121 m .46505 .72711 L .46531 .73024 L closepath p F P
0 g
s
.907 .983 .764 r
.46147 .73275 m .46262 .73121 L .46531 .73024 L p F P
0 g
s
.65 .757 .928 r
.15037 .52959 m .14152 .53264 L .14473 .53547 L p F P
0 g
s
.65 .757 .928 r
.14473 .53547 m .15357 .53243 L .15037 .52959 L p F P
0 g
s
.84 .974 .666 r
.41881 .68997 m .42024 .68616 L .41638 .69184 L p F P
0 g
s
.84 .974 .666 r
.41619 .69384 m .41881 .68997 L p .41638 .69184 L F P
0 g
s
.851 .4 .127 r
.56121 .68432 m .56297 .68766 L .5594 .68539 L p F P
0 g
s
.851 .4 .127 r
.5594 .68539 m .55871 .68415 L .56121 .68432 L p F P
0 g
s
.905 .509 .249 r
.55768 .68131 m .55871 .68415 L .56121 .68432 L p F P
0 g
s
0 0 .488 r
.64536 .71675 m .64524 .7151 L p .64716 .7224 L F P
0 g
s
0 0 .488 r
.64716 .7224 m .64659 .72107 L .64536 .71675 L p F P
0 g
s
0 0 .539 r
.64536 .71675 m .644 .71273 L .64524 .7151 L closepath p F P
0 g
s
.65 .757 .928 r
.2984 .52977 m .28929 .53284 L .29226 .53566 L p F P
0 g
s
.65 .757 .928 r
.29226 .53566 m .30136 .53261 L .2984 .52977 L p F P
0 g
s
.651 .758 .928 r
.73491 .53567 m .7448 .53261 L .74702 .53543 L p F P
0 g
s
.651 .758 .928 r
.74258 .52978 m .73267 .53285 L .73491 .53567 L p F P
0 g
s
.651 .758 .928 r
.73491 .53567 m .7448 .53261 L .74258 .52978 L p F P
0 g
s
.925 .918 .534 r
.40852 .70999 m .40858 .70912 L .40657 .71203 L p F P
0 g
s
.925 .918 .534 r
.40657 .71203 m .40635 .71518 L .40852 .70999 L p F P
0 g
s
.65 .757 .928 r
.44646 .52982 m .43708 .53288 L .4398 .53571 L p F P
0 g
s
.65 .757 .928 r
.4398 .53571 m .44917 .53265 L .44646 .52982 L p F P
0 g
s
.651 .757 .928 r
.59453 .52982 m .58488 .53289 L .58736 .53571 L p F P
0 g
s
.651 .757 .928 r
.58736 .53571 m .59699 .53265 L .59453 .52982 L p F P
0 g
s
0 0 .532 r
.64524 .7151 m .644 .71273 L .64301 .70983 L p F P
0 g
s
.303 .387 .783 r
.59377 .74178 m .59132 .74023 L .58963 .73616 L p F P
0 g
s
.392 .09 .329 r
.49708 .67639 m .50587 .67291 L p .50478 .6768 L F P
0 g
s
.392 .09 .329 r
.50478 .6768 m .49619 .68011 L .49708 .67639 L p F P
0 g
s
.376 .077 .325 r
.50666 .66912 m .50587 .67291 L .49708 .67639 L p F P
0 g
s
0 .205 .709 r
.61017 .66223 m .60787 .65957 L .60357 .65627 L p F P
0 g
s
0 .174 .667 r
.60357 .65627 m .60098 .65369 L .60528 .65699 L p F P
0 g
s
0 .174 .667 r
.60528 .65699 m .60787 .65957 L .60357 .65627 L p F P
0 g
s
.65 .757 .928 r
.16244 .52938 m .15357 .53243 L .15675 .53527 L p F P
0 g
s
.65 .757 .928 r
.15675 .53527 m .16562 .53222 L .16244 .52938 L p F P
0 g
s
.686 .363 .424 r
.53084 .66672 m .52933 .66423 L .52961 .66291 L p F P
0 g
s
.666 .345 .419 r
.52933 .66423 m .52838 .66291 L .52961 .66291 L closepath p F P
0 g
s
0 0 .532 r
.64301 .70983 m .64273 .70795 L p .64524 .7151 L F P
0 g
s
0 .01 .583 r
.64301 .70983 m .64147 .70593 L .64273 .70795 L closepath p F P
0 g
s
.616 .311 .43 r
.52838 .66291 m .52933 .66423 L p .51864 .66696 L F P
0 g
s
0 0 .361 r
.64843 .72887 m .64829 .72991 L .6492 .73434 L p F P
0 g
s
0 0 .476 r
.64829 .72991 m .64843 .72887 L .64715 .72308 L p F P
0 g
s
0 0 .494 r
.64715 .72308 m .64659 .72107 L .64716 .7224 L closepath p F P
0 g
s
.618 .855 .988 r
.63172 .76888 m .62579 .77135 L .62337 .76871 L p F P
0 g
s
.65 .757 .928 r
.3105 .52954 m .30136 .53261 L .30431 .53543 L p F P
0 g
s
.65 .757 .928 r
.30431 .53543 m .31343 .53238 L .3105 .52954 L p F P
0 g
s
.651 .758 .928 r
.74702 .53543 m .75694 .53237 L .75913 .53519 L p F P
0 g
s
.651 .758 .928 r
.75694 .53237 m .74702 .53543 L .7448 .53261 L p F P
0 g
s
.651 .757 .928 r
.45858 .52958 m .44917 .53265 L .45188 .53547 L p F P
0 g
s
.651 .757 .928 r
.45188 .53547 m .46127 .53241 L .45858 .52958 L p F P
0 g
s
.651 .757 .928 r
.60666 .52958 m .59699 .53265 L .59945 .53547 L p F P
0 g
s
.651 .757 .928 r
.59945 .53547 m .60911 .53241 L .60666 .52958 L p F P
0 g
s
.888 .71 .197 r
.40276 .73657 m .40225 .7336 L .40202 .73819 L p F P
0 g
s
.888 .71 .197 r
.40202 .73819 m .40257 .74121 L .40276 .73657 L p F P
0 g
s
0 0 .375 r
.64716 .7224 m .64715 .72308 L .64843 .72887 L p F P
0 g
s
.65 .757 .928 r
.17451 .52917 m .16562 .53222 L .16878 .53505 L p F P
0 g
s
.65 .757 .928 r
.16878 .53505 m .17767 .53201 L .17451 .52917 L p F P
0 g
s
.389 0 0 r
.58513 .64258 m .58996 .64568 L .58638 .64336 L p F P
0 g
s
.389 0 0 r
.58336 .64143 m .58513 .64258 L p .58638 .64336 L F P
0 g
s
.651 .758 .928 r
.75913 .53519 m .76908 .53212 L .77125 .53495 L p F P
0 g
s
.651 .758 .928 r
.76908 .53212 m .75913 .53519 L .75694 .53237 L p F P
0 g
s
.905 .877 .798 r
.44889 .75735 m .44953 .75651 L .44812 .75368 L p F P
0 g
s
.65 .757 .928 r
.32259 .52931 m .31343 .53238 L .31636 .5352 L p F P
0 g
s
.65 .757 .928 r
.31636 .5352 m .32551 .53215 L .32259 .52931 L p F P
0 g
s
.838 .904 .493 r
.64492 .75726 m .6457 .75564 L .64548 .75649 L closepath p F P
0 g
s
.651 .757 .928 r
.6188 .52934 m .60911 .53241 L .61154 .53524 L p F P
0 g
s
.651 .757 .928 r
.61154 .53524 m .62122 .53218 L .6188 .52934 L p F P
0 g
s
.651 .757 .928 r
.47069 .52935 m .46127 .53241 L .46395 .53524 L p F P
0 g
s
.651 .757 .928 r
.46395 .53524 m .47337 .53218 L .47069 .52935 L p F P
0 g
s
.877 .785 .29 r
.40315 .72963 m .40312 .72858 L .40224 .73342 L p F P
0 g
s
.877 .785 .29 r
.40224 .73342 m .40225 .7336 L .40315 .72963 L p F P
0 g
s
.905 .877 .798 r
.44812 .75368 m .44615 .75609 L .44889 .75735 L p F P
0 g
s
.835 .894 .882 r
.44889 .75735 m .44263 .76309 L .44126 .76027 L p F P
0 g
s
.835 .894 .882 r
.44126 .76027 m .44615 .75609 L .44889 .75735 L p F P
0 g
s
.853 .87 .852 r
.43937 .76626 m .44263 .76309 L .44126 .76027 L p F P
0 g
s
.837 .943 .579 r
.47298 .71233 m .47191 .71551 L .47227 .71513 L p F P
0 g
s
.824 .94 .577 r
.47191 .71551 m .47227 .71513 L .47174 .71599 L closepath p F P
0 g
s
.65 .757 .928 r
.18659 .52895 m .17767 .53201 L .18082 .53484 L p F P
0 g
s
.65 .757 .928 r
.18082 .53484 m .18973 .53179 L .18659 .52895 L p F P
0 g
s
.776 .419 .381 r
.54516 .6692 m .5432 .66875 L .54197 .67202 L p F P
0 g
s
.776 .419 .381 r
.54197 .67202 m .54702 .67321 L .54516 .6692 L p F P
0 g
s
.651 .758 .928 r
.77125 .53495 m .78122 .53188 L .78337 .5347 L p F P
0 g
s
.651 .758 .928 r
.78122 .53188 m .77125 .53495 L .76908 .53212 L p F P
0 g
s
.84 .974 .666 r
.41638 .69184 m .41533 .69454 L .41619 .69384 L p F P
0 g
s
.889 .973 .666 r
.41533 .69454 m .41619 .69384 L .41506 .69562 L closepath p F P
0 g
s
.853 .87 .852 r
.44126 .76027 m .43663 .76444 L .43937 .76626 L p F P
0 g
s
.742 .85 .93 r
.42986 .76813 m .43663 .76444 L .43937 .76626 L p F P
0 g
s
0 0 .574 r
.64273 .70795 m .64147 .70593 L .63995 .70216 L p F P
0 g
s
.65 .757 .928 r
.33469 .52908 m .32551 .53215 L .32842 .53497 L p F P
0 g
s
.65 .757 .928 r
.32842 .53497 m .33759 .53192 L .33469 .52908 L p F P
0 g
s
.651 .757 .928 r
.63094 .5291 m .62122 .53218 L .62364 .535 L p F P
0 g
s
.651 .757 .928 r
.62364 .535 m .63334 .53194 L .63094 .5291 L p F P
0 g
s
.651 .757 .928 r
.48281 .52911 m .47337 .53218 L .47603 .535 L p F P
0 g
s
.651 .757 .928 r
.47603 .535 m .48547 .53194 L .48281 .52911 L p F P
0 g
s
.538 .231 .394 r
.50587 .67291 m .50666 .66912 L .51691 .66706 L p F P
0 g
s
.543 .236 .398 r
.51724 .66559 m .51691 .66706 L .50666 .66912 L p F P
0 g
s
.303 .387 .783 r
.58963 .73616 m .58996 .73501 L p .59377 .74178 L F P
0 g
s
.239 .346 .772 r
.58963 .73616 m .58878 .73412 L .58996 .73501 L closepath p F P
0 g
s
.449 .62 .924 r
.4152 .76771 m .4202 .76765 L .41868 .76486 L p F P
0 g
s
.449 .62 .924 r
.41868 .76486 m .41247 .76429 L .4152 .76771 L p F P
0 g
s
0 .329 .814 r
.41027 .76261 m .41247 .76429 L .4152 .76771 L p F P
0 g
s
.828 .941 .578 r
.47174 .71599 m .47191 .71551 L .46961 .71802 L p F P
0 g
s
.828 .941 .578 r
.46961 .71802 m .46836 .72156 L .47174 .71599 L p F P
0 g
s
.65 .757 .928 r
.19867 .52873 m .18973 .53179 L .19286 .53462 L p F P
0 g
s
.65 .757 .928 r
.19286 .53462 m .20179 .53158 L .19867 .52873 L p F P
0 g
s
.942 .936 .761 r
.46143 .73602 m .46147 .73275 L .45718 .7386 L p F P
0 g
s
.942 .936 .761 r
.45718 .7386 m .4577 .7417 L .46143 .73602 L p F P
0 g
s
.565 .629 .874 r
.61117 .76532 m .6208 .76566 L .62036 .76888 L p F P
0 g
s
.524 .593 .865 r
.6208 .76566 m .61117 .76532 L .60889 .76135 L p F P
0 g
s
.651 .758 .928 r
.78337 .5347 m .79336 .53164 L .7955 .53446 L p F P
0 g
s
.651 .758 .928 r
.79336 .53164 m .78337 .5347 L .78122 .53188 L p F P
0 g
s
0 .312 .799 r
.61412 .66525 m .61017 .66223 L p .61653 .66826 L F P
0 g
s
0 .206 .71 r
.61017 .66223 m .61412 .66525 L .61167 .66249 L p F P
0 g
s
0 .206 .71 r
.61167 .66249 m .60787 .65957 L .61017 .66223 L p F P
0 g
s
.65 .757 .928 r
.3468 .52885 m .33759 .53192 L .34048 .53474 L p F P
0 g
s
.65 .757 .928 r
.34048 .53474 m .34967 .53168 L .3468 .52885 L p F P
0 g
s
.651 .757 .928 r
.64308 .52886 m .63334 .53194 L .63574 .53476 L p F P
0 g
s
.651 .757 .928 r
.63574 .53476 m .64547 .5317 L .64308 .52886 L p F P
0 g
s
.651 .757 .928 r
.49494 .52887 m .48547 .53194 L .48811 .53477 L p F P
0 g
s
.651 .757 .928 r
.48811 .53477 m .49757 .53171 L .49494 .52887 L p F P
0 g
s
.871 .917 .52 r
.40858 .70912 m .40912 .70646 L .40662 .71176 L p F P
0 g
s
.871 .917 .52 r
.40662 .71176 m .40657 .71203 L .40858 .70912 L p F P
0 g
s
.01 0 .1 r
.48289 .69571 m .47969 .70121 L .48398 .69663 L p F P
0 g
s
.01 0 .1 r
.4866 .69202 m .48289 .69571 L p .48398 .69663 L F P
0 g
s
.229 .345 .775 r
.58996 .73501 m .58878 .73412 L .58629 .72825 L p F P
0 g
s
.849 .95 .595 r
.41506 .69562 m .41194 .70108 L .41283 .69744 L p F P
0 g
s
.849 .95 .595 r
.41533 .69454 m .41506 .69562 L p .41283 .69744 L F P
0 g
s
.65 .757 .928 r
.21075 .52851 m .20179 .53158 L .2049 .53441 L p F P
0 g
s
.65 .757 .928 r
.2049 .53441 m .21385 .53135 L .21075 .52851 L p F P
0 g
s
0 0 .375 r
.64843 .72887 m .64842 .72671 L .64716 .7224 L p F P
0 g
s
0 0 .339 r
.64693 .71928 m .64716 .7224 L .64842 .72671 L p F P
0 g
s
0 0 .488 r
.64524 .7151 m .64693 .71928 L .64716 .7224 L p F P
0 g
s
.776 .418 .379 r
.5432 .66875 m .53887 .6677 L .54071 .67172 L p F P
0 g
s
.776 .418 .379 r
.54071 .67172 m .54197 .67202 L .5432 .66875 L p F P
0 g
s
.651 .758 .928 r
.7955 .53446 m .80551 .53139 L .80762 .53421 L p F P
0 g
s
.651 .758 .928 r
.80551 .53139 m .7955 .53446 L .79336 .53164 L p F P
0 g
s
.649 .756 .927 r
.07471 .52793 m .066 .53096 L .06933 .53381 L p F P
0 g
s
.649 .756 .927 r
.06933 .53381 m .07804 .53078 L .07471 .52793 L p F P
0 g
s
0 0 .553 r
.40623 .7559 m .40523 .75293 L p .40839 .75829 L F P
0 g
s
0 0 .553 r
.40839 .75829 m .40896 .75975 L .40623 .7559 L p F P
0 g
s
0 .27 .777 r
.41247 .76429 m .41027 .76261 L .40896 .75975 L p F P
0 g
s
.65 .757 .928 r
.3589 .52862 m .34967 .53168 L .35254 .53451 L p F P
0 g
s
.65 .757 .928 r
.35254 .53451 m .36176 .53145 L .3589 .52862 L p F P
0 g
s
.651 .757 .928 r
.65523 .52863 m .64547 .5317 L .64785 .53452 L p F P
0 g
s
.651 .757 .928 r
.64785 .53452 m .6576 .53146 L .65523 .52863 L p F P
0 g
s
.651 .757 .928 r
.50707 .52864 m .49757 .53171 L .50019 .53454 L p F P
0 g
s
.651 .757 .928 r
.50019 .53454 m .50968 .53147 L .50707 .52864 L p F P
0 g
s
0 0 .574 r
.63995 .70216 m .63968 .70096 L p .64273 .70795 L F P
0 g
s
0 .059 .623 r
.63995 .70216 m .63897 .69999 L .63968 .70096 L closepath p F P
0 g
s
.698 .366 .412 r
.52876 .66658 m .52933 .66423 L .53084 .66672 L closepath p F P
0 g
s
.616 .311 .43 r
.52933 .66423 m .52876 .66658 L .51864 .66696 L p F P
0 g
s
.835 .943 .58 r
.47191 .71551 m .47298 .71233 L .46965 .71789 L p F P
0 g
s
.835 .943 .58 r
.46965 .71789 m .46961 .71802 L .47191 .71551 L p F P
0 g
s
.65 .757 .928 r
.22284 .52829 m .21385 .53135 L .21694 .53419 L p F P
0 g
s
.65 .757 .928 r
.21694 .53419 m .22592 .53113 L .22284 .52829 L p F P
0 g
s
0 0 0 r
.64943 .73896 m .64871 .7423 L .64806 .74717 L p F P
0 g
s
0 0 .227 r
.64871 .7423 m .64943 .73896 L .6492 .73434 L p F P
0 g
s
.651 .758 .928 r
.81766 .53114 m .80762 .53421 L .80551 .53139 L p F P
0 g
s
.651 .758 .928 r
.80762 .53421 m .81766 .53114 L .81975 .53397 L p F P
0 g
s
0 0 .236 r
.64842 .72671 m .64843 .72887 L .64923 .73416 L p F P
0 g
s
0 0 .361 r
.6492 .73434 m .64923 .73416 L .64843 .72887 L p F P
0 g
s
.65 .757 .928 r
.37101 .52838 m .36176 .53145 L .36461 .53428 L p F P
0 g
s
.65 .757 .928 r
.36461 .53428 m .37385 .53122 L .37101 .52838 L p F P
0 g
s
.651 .758 .928 r
.66738 .52839 m .6576 .53146 L .65996 .53429 L p F P
0 g
s
.651 .758 .928 r
.65996 .53429 m .66973 .53122 L .66738 .52839 L p F P
0 g
s
.649 .756 .927 r
.08677 .52774 m .07804 .53078 L .08135 .53362 L p F P
0 g
s
.649 .756 .927 r
.08135 .53362 m .09008 .5306 L .08677 .52774 L p F P
0 g
s
.651 .757 .928 r
.5192 .5284 m .50968 .53147 L .51228 .5343 L p F P
0 g
s
.651 .757 .928 r
.51228 .5343 m .52179 .53124 L .5192 .5284 L p F P
0 g
s
.952 .944 .628 r
.6457 .75564 m .64633 .75236 L p .64308 .75851 L F P
0 g
s
.952 .944 .628 r
.64308 .75851 m .64492 .75726 L .6457 .75564 L p F P
0 g
s
.811 .825 .348 r
.6457 .75564 m .64633 .75236 L .64806 .74717 L p F P
0 g
s
.639 .947 .731 r
.44211 .66118 m .44933 .65486 L p .4463 .65683 L F P
0 g
s
.639 .947 .731 r
.4463 .65683 m .44186 .66131 L .44211 .66118 L p F P
0 g
s
.723 .976 .745 r
.44186 .66131 m .44211 .66118 L .44156 .6617 L closepath p F P
0 g
s
.658 .938 .674 r
.44156 .6617 m .43525 .66811 L .43867 .66365 L p F P
0 g
s
.658 .938 .674 r
.44186 .66131 m .44156 .6617 L p .43867 .66365 L F P
0 g
s
.127 0 .157 r
.48777 .68853 m .49393 .68456 L .4887 .69067 L p F P
0 g
s
.127 0 .157 r
.4887 .69067 m .4866 .69202 L .48777 .68853 L p F P
0 g
s
0 .206 .677 r
.5993 .65252 m .60098 .65369 L .5981 .65119 L p F P
0 g
s
0 .206 .677 r
.5981 .65119 m .59685 .65032 L .5993 .65252 L p F P
0 g
s
0 .262 .725 r
.59323 .64808 m .59685 .65032 L .5993 .65252 L p F P
0 g
s
.836 .463 .346 r
.55211 .67505 m .54702 .67321 L .54888 .67723 L p F P
0 g
s
.836 .463 .346 r
.54888 .67723 m .55372 .67915 L .55211 .67505 L p F P
0 g
s
.65 .757 .928 r
.23493 .52807 m .22592 .53113 L .22899 .53396 L p F P
0 g
s
.65 .757 .928 r
.22899 .53396 m .23799 .53091 L .23493 .52807 L p F P
0 g
s
.651 .758 .928 r
.81975 .53397 m .82981 .53089 L .83189 .53372 L p F P
0 g
s
.651 .758 .928 r
.82981 .53089 m .81975 .53397 L .81766 .53114 L p F P
0 g
s
.639 .947 .731 r
.44933 .65486 m .45078 .65339 L p .4463 .65683 L F P
0 g
s
.639 .947 .728 r
.45078 .65339 m .45161 .65295 L .44933 .65486 L closepath p F P
0 g
s
.65 .757 .928 r
.38313 .52815 m .37385 .53122 L .37668 .53405 L p F P
0 g
s
.65 .757 .928 r
.37668 .53405 m .38594 .53099 L .38313 .52815 L p F P
0 g
s
.651 .758 .928 r
.67954 .52815 m .66973 .53122 L .67207 .53405 L p F P
0 g
s
.651 .758 .928 r
.67207 .53405 m .68186 .53098 L .67954 .52815 L p F P
0 g
s
.389 0 0 r
.58638 .64336 m .58212 .64067 L .58336 .64143 L p F P
0 g
s
0 .28 .682 r
.58212 .64067 m .58141 .6403 L .58336 .64143 L closepath p F P
0 g
s
0 .172 .694 r
.61656 .66829 m .61653 .66826 L .61638 .66806 L closepath p F P
0 g
s
0 .312 .799 r
.61653 .66826 m .61638 .66806 L .61412 .66525 L p F P
0 g
s
.651 .757 .928 r
.53133 .52816 m .52179 .53124 L .52437 .53407 L p F P
0 g
s
.651 .757 .928 r
.52437 .53407 m .5339 .531 L .53133 .52816 L p F P
0 g
s
.484 .632 .919 r
.62036 .76888 m .62337 .76871 L .62093 .76567 L p F P
0 g
s
.484 .632 .919 r
.62093 .76567 m .6208 .76566 L .62036 .76888 L p F P
0 g
s
.618 .855 .988 r
.63396 .76632 m .63172 .76888 L p .62337 .76871 L F P
0 g
s
.7 .893 .967 r
.63172 .76888 m .63396 .76632 L .63545 .76717 L closepath p F P
0 g
s
.649 .756 .928 r
.09884 .52755 m .09008 .5306 L .09338 .53344 L p F P
0 g
s
.649 .756 .928 r
.09338 .53344 m .10213 .5304 L .09884 .52755 L p F P
0 g
s
.629 .308 .409 r
.51691 .66706 m .51724 .66559 L .51864 .66696 L closepath p F P
0 g
s
0 .151 .685 r
.61656 .66829 m .62023 .67177 L .62202 .67455 L p F P
0 g
s
0 .107 .639 r
.62023 .67177 m .61656 .66829 L .61638 .66806 L p F P
0 g
s
0 0 .254 r
.40383 .74873 m .40305 .74568 L .40437 .74991 L p F P
0 g
s
0 0 .254 r
.40437 .74991 m .40523 .75293 L .40383 .74873 L p F P
0 g
s
.776 .958 .643 r
.42296 .68243 m .4246 .68033 L .4239 .68164 L closepath p F P
0 g
s
.814 .966 .649 r
.42024 .68616 m .42296 .68243 L .4239 .68164 L p F P
0 g
s
.87 .867 .42 r
.40635 .71518 m .40457 .72027 L .4048 .71686 L p F P
0 g
s
.87 .867 .42 r
.40657 .71203 m .40635 .71518 L p .4048 .71686 L F P
0 g
s
.828 .756 .24 r
.40312 .72858 m .40322 .72524 L .40239 .73007 L p F P
0 g
s
.828 .756 .24 r
.40239 .73007 m .40224 .73342 L .40312 .72858 L p F P
0 g
s
0 .233 .678 r
.59685 .65032 m .59323 .64808 L .58996 .64568 L p F P
0 g
s
.536 .9 .702 r
.45161 .65295 m .45888 .64747 L p .45571 .64947 L F P
0 g
s
.536 .9 .702 r
.45571 .64947 m .45078 .65339 L .45161 .65295 L p F P
0 g
s
0 .043 .612 r
.63968 .70096 m .63897 .69999 L .63648 .69468 L p F P
0 g
s
0 0 .416 r
.64479 .71203 m .64524 .7151 L .64693 .71928 L p F P
0 g
s
0 0 .532 r
.64273 .70795 m .64479 .71203 L .64524 .7151 L p F P
0 g
s
.695 .954 .689 r
.43525 .66811 m .43867 .66365 L .43253 .67001 L p F P
0 g
s
.695 .954 .689 r
.43256 .67096 m .43525 .66811 L p .43253 .67001 L F P
0 g
s
.651 .758 .928 r
.83189 .53372 m .84197 .53064 L .84402 .53347 L p F P
0 g
s
.651 .758 .928 r
.84197 .53064 m .83189 .53372 L .82981 .53089 L p F P
0 g
s
.65 .757 .928 r
.24702 .52784 m .23799 .53091 L .24105 .53374 L p F P
0 g
s
.65 .757 .928 r
.24105 .53374 m .25007 .53068 L .24702 .52784 L p F P
0 g
s
0 0 0 r
.47915 .70213 m .47969 .70121 L .47941 .7016 L closepath p F P
0 g
s
0 0 0 r
.47632 .70677 m .47915 .70213 L .47941 .7016 L p F P
0 g
s
0 .107 .639 r
.61638 .66806 m .61448 .66554 L p .62023 .67177 L F P
0 g
s
0 .191 .707 r
.61638 .66806 m .61412 .66525 L .61448 .66554 L closepath p F P
0 g
s
.651 .758 .928 r
.69169 .52791 m .68186 .53098 L .68418 .53381 L p F P
0 g
s
.651 .758 .928 r
.68418 .53381 m .694 .53074 L .69169 .52791 L p F P
0 g
s
.65 .757 .928 r
.39524 .52791 m .38594 .53099 L .38875 .53382 L p F P
0 g
s
.65 .757 .928 r
.38875 .53382 m .39804 .53075 L .39524 .52791 L p F P
0 g
s
.651 .757 .928 r
.54347 .52793 m .5339 .531 L .53647 .53383 L p F P
0 g
s
.651 .757 .928 r
.53647 .53383 m .54602 .53077 L .54347 .52793 L p F P
0 g
s
.807 .971 .668 r
.64171 .76144 m .64308 .75851 L .64492 .75726 L closepath p F P
0 g
s
.598 .912 .658 r
.43927 .66307 m .4463 .65683 L .44186 .66131 L closepath p F P
0 g
s
.658 .938 .674 r
.43867 .66365 m .43927 .66307 L .44186 .66131 L p F P
0 g
s
.649 .756 .928 r
.11091 .52736 m .10213 .5304 L .10541 .53325 L p F P
0 g
s
.649 .756 .928 r
.10541 .53325 m .11418 .53021 L .11091 .52736 L p F P
0 g
s
.36 .422 .79 r
.59377 .74178 m .5987 .74509 L .59797 .74845 L p F P
0 g
s
.104 .301 .777 r
.59435 .73845 m .59377 .74178 L .5987 .74509 L p F P
0 g
s
.303 .387 .783 r
.58996 .73501 m .59435 .73845 L .59377 .74178 L p F P
0 g
s
.406 .454 .797 r
.59797 .74845 m .60356 .75159 L .60287 .75492 L p F P
0 g
s
.25 .41 .827 r
.5987 .74509 m .59797 .74845 L .60356 .75159 L p F P
0 g
s
.695 .954 .689 r
.43253 .67001 m .43098 .67201 L .43256 .67096 L p F P
0 g
s
.774 .976 .701 r
.43098 .67201 m .43256 .67096 L .42962 .67431 L closepath p F P
0 g
s
.039 .251 .75 r
.59027 .73173 m .58996 .73501 L .59435 .73845 L p F P
0 g
s
.229 .345 .775 r
.5863 .72819 m .59027 .73173 L .58996 .73501 L p F P
0 g
s
.229 .345 .775 r
.58629 .72825 m .5863 .72819 L p .58996 .73501 L F P
0 g
s
.875 .473 .264 r
.55768 .68131 m .55372 .67915 L .55537 .68325 L p F P
0 g
s
.875 .473 .264 r
.55871 .68415 m .55768 .68131 L p .55537 .68325 L F P
0 g
s
.929 .919 .783 r
.4577 .7417 m .45718 .7386 L .45305 .7444 L p F P
0 g
s
.929 .919 .783 r
.45574 .74473 m .4577 .7417 L p .45305 .7444 L F P
0 g
s
.75 .827 .911 r
.42829 .76536 m .42446 .76729 L .42721 .76965 L p F P
0 g
s
.75 .827 .911 r
.42721 .76965 m .42986 .76813 L .42829 .76536 L p F P
0 g
s
.563 .733 .955 r
.4202 .76765 m .42446 .76729 L .42721 .76965 L p F P
0 g
s
.651 .758 .928 r
.84402 .53347 m .85413 .53039 L .85616 .53322 L p F P
0 g
s
.651 .758 .928 r
.85413 .53039 m .84402 .53347 L .84197 .53064 L p F P
0 g
s
.754 .924 .563 r
.46836 .72156 m .46505 .72711 L .46571 .72363 L p F P
0 g
s
.754 .924 .563 r
.46961 .71802 m .46836 .72156 L p .46571 .72363 L F P
0 g
s
.65 .757 .928 r
.25912 .52762 m .25007 .53068 L .2531 .53352 L p F P
0 g
s
.65 .757 .928 r
.2531 .53352 m .26215 .53046 L .25912 .52762 L p F P
0 g
s
.161 .3 .758 r
.58629 .72825 m .58624 .72814 L .5863 .72819 L closepath p F P
0 g
s
.135 .294 .762 r
.5863 .72819 m .58624 .72814 L .5837 .72242 L p F P
0 g
s
.651 .758 .928 r
.70385 .52766 m .694 .53074 L .6963 .53357 L p F P
0 g
s
.651 .758 .928 r
.6963 .53357 m .70614 .5305 L .70385 .52766 L p F P
0 g
s
0 .134 .677 r
.62713 .68095 m .6256 .67811 L .62202 .67455 L p F P
0 g
s
0 .108 .648 r
.62023 .67177 m .62202 .67455 L .6256 .67811 L p F P
0 g
s
.65 .757 .928 r
.40736 .52768 m .39804 .53075 L .40083 .53358 L p F P
0 g
s
.65 .757 .928 r
.40083 .53358 m .41014 .53052 L .40736 .52768 L p F P
0 g
s
.651 .757 .928 r
.55561 .52769 m .54602 .53077 L .54857 .53359 L p F P
0 g
s
.651 .757 .928 r
.54857 .53359 m .55814 .53053 L .55561 .52769 L p F P
0 g
s
0 .197 .72 r
.58628 .72499 m .5863 .72819 L .59027 .73173 L p F P
0 g
s
.135 .294 .762 r
.5837 .72242 m .58628 .72499 L .5863 .72819 L p F P
0 g
s
.649 .756 .928 r
.12299 .52716 m .11418 .53021 L .11744 .53305 L p F P
0 g
s
.649 .756 .928 r
.11744 .53305 m .12624 .53001 L .12299 .52716 L p F P
0 g
s
.742 .407 .414 r
.53887 .6677 m .53084 .66672 L .53321 .67057 L p F P
0 g
s
.742 .407 .414 r
.53321 .67057 m .54071 .67172 L .53887 .6677 L p F P
0 g
s
.818 .945 .589 r
.41325 .69675 m .41638 .69184 L .41533 .69454 L closepath p F P
0 g
s
.849 .95 .595 r
.41283 .69744 m .41325 .69675 L .41533 .69454 L p F P
0 g
s
0 0 .472 r
.64206 .70493 m .64273 .70795 L .64479 .71203 L p F P
0 g
s
0 0 .574 r
.63968 .70096 m .64206 .70493 L .64273 .70795 L p F P
0 g
s
.277 .409 .816 r
.60287 .75492 m .60619 .75639 L .60368 .75166 L p F P
0 g
s
.277 .409 .816 r
.60368 .75166 m .60356 .75159 L .60287 .75492 L p F P
0 g
s
0 0 0 r
.47969 .70121 m .48398 .69663 L .47986 .70241 L p F P
0 g
s
0 0 0 r
.47915 .70213 m .47969 .70121 L p .47986 .70241 L F P
0 g
s
.65 .757 .928 r
.27122 .52739 m .26215 .53046 L .26516 .53329 L p F P
0 g
s
.65 .757 .928 r
.26516 .53329 m .27423 .53023 L .27122 .52739 L p F P
0 g
s
.651 .758 .928 r
.71602 .52742 m .70614 .5305 L .70842 .53333 L p F P
0 g
s
.651 .758 .928 r
.70842 .53333 m .71829 .53026 L .71602 .52742 L p F P
0 g
s
.65 .757 .928 r
.41949 .52745 m .41014 .53052 L .41291 .53335 L p F P
0 g
s
.65 .757 .928 r
.41291 .53335 m .42225 .53029 L .41949 .52745 L p F P
0 g
s
.651 .757 .928 r
.56775 .52745 m .55814 .53053 L .56067 .53336 L p F P
0 g
s
.651 .757 .928 r
.56067 .53336 m .57027 .53029 L .56775 .52745 L p F P
0 g
s
.536 .9 .702 r
.45888 .64747 m .46047 .64621 L p .45571 .64947 L F P
0 g
s
.54 .903 .708 r
.46047 .64621 m .4611 .64589 L .45888 .64747 L closepath p F P
0 g
s
.71 .937 .625 r
.42962 .67431 m .4246 .68033 L .42706 .67618 L p F P
0 g
s
.71 .937 .625 r
.43098 .67201 m .42962 .67431 L p .42706 .67618 L F P
0 g
s
0 0 .554 r
.5837 .72242 m .58294 .72129 L .58246 .71984 L closepath p F P
0 g
s
0 0 .547 r
.58117 .71715 m .57953 .7144 L p .58294 .72129 L F P
0 g
s
0 0 .547 r
.58294 .72129 m .58246 .71984 L .58117 .71715 L p F P
0 g
s
.65 .756 .928 r
.13507 .52695 m .12624 .53001 L .12948 .53285 L p F P
0 g
s
.65 .756 .928 r
.12948 .53285 m .1383 .5298 L .13507 .52695 L p F P
0 g
s
.863 .418 .126 r
.56297 .68766 m .5594 .68539 L .56159 .68935 L p F P
0 g
s
.863 .418 .126 r
.56159 .68935 m .56503 .69166 L .56297 .68766 L p F P
0 g
s
0 .137 .683 r
.63182 .68747 m .63059 .68456 L .62713 .68095 L p F P
0 g
s
0 .182 .714 r
.6256 .67811 m .62713 .68095 L .63059 .68456 L p F P
0 g
s
.862 .931 .549 r
.41194 .70108 m .41283 .69744 L .41004 .70282 L p F P
0 g
s
.862 .931 .549 r
.41004 .70282 m .40912 .70646 L .41194 .70108 L p F P
0 g
s
.85 .902 .872 r
.63396 .76632 m .63545 .76717 L .64171 .76144 L p F P
0 g
s
.85 .902 .872 r
.64171 .76144 m .64308 .75851 L p .63396 .76632 L F P
0 g
s
.717 .85 .945 r
.43663 .76444 m .42986 .76813 L .42829 .76536 L p F P
0 g
s
0 0 0 r
.47986 .70241 m .47777 .7047 L .47915 .70213 L p F P
0 g
s
0 0 0 r
.47777 .7047 m .47915 .70213 L .47632 .70677 L closepath p F P
0 g
s
.65 .757 .928 r
.28333 .52716 m .27423 .53023 L .27722 .53306 L p F P
0 g
s
.65 .757 .928 r
.27722 .53306 m .28632 .53 L .28333 .52716 L p F P
0 g
s
0 0 .376 r
.57953 .7144 m .58117 .71715 L .57864 .7125 L p F P
0 g
s
.651 .758 .928 r
.72819 .52718 m .71829 .53026 L .72055 .53309 L p F P
0 g
s
.651 .758 .928 r
.72055 .53309 m .73043 .53002 L .72819 .52718 L p F P
0 g
s
0 0 .512 r
.63877 .69799 m .63968 .70096 L .64206 .70493 L p F P
0 g
s
0 .043 .612 r
.63648 .69468 m .63877 .69799 L .63968 .70096 L p F P
0 g
s
.65 .757 .928 r
.43161 .52721 m .42225 .53029 L .425 .53312 L p F P
0 g
s
.65 .757 .928 r
.425 .53312 m .43435 .53005 L .43161 .52721 L p F P
0 g
s
.651 .757 .928 r
.5799 .52721 m .57027 .53029 L .57277 .53312 L p F P
0 g
s
.651 .757 .928 r
.57277 .53312 m .58239 .53006 L .5799 .52721 L p F P
0 g
s
.444 .852 .677 r
.46047 .64621 m .4611 .64589 L .47057 .64001 L p F P
0 g
s
.434 .843 .663 r
.47094 .63979 m .47057 .64001 L .4611 .64589 L p F P
0 g
s
.524 .593 .865 r
.60889 .76135 m .6091 .76103 L p .6208 .76566 L F P
0 g
s
.491 .577 .869 r
.60889 .76135 m .60868 .76099 L .6091 .76103 L closepath p F P
0 g
s
.776 .556 0 r
.40257 .74121 m .40202 .73819 L .40265 .74356 L p F P
0 g
s
.776 .556 0 r
.40265 .74356 m .40305 .74568 L .40257 .74121 L p F P
0 g
s
0 .168 .706 r
.63401 .69 m .63182 .68747 L p .63607 .69413 L F P
0 g
s
0 .067 .629 r
.63182 .68747 m .63401 .69 L .63155 .6857 L p F P
0 g
s
0 .067 .629 r
.63155 .6857 m .63059 .68456 L .63182 .68747 L p F P
0 g
s
.929 .919 .783 r
.45305 .7444 m .45308 .7445 L .45574 .74473 L p F P
0 g
s
.897 .946 .831 r
.45308 .7445 m .45574 .74473 L .45323 .7476 L closepath p F P
0 g
s
.65 .757 .928 r
.14716 .52674 m .1383 .5298 L .14152 .53264 L p F P
0 g
s
.65 .757 .928 r
.14152 .53264 m .15037 .52959 L .14716 .52674 L p F P
0 g
s
.808 .368 0 r
.57209 .70079 m .56984 .69816 L .56783 .69414 L p F P
0 g
s
.856 .406 .017 r
.56783 .69414 m .56503 .69166 L .56707 .69567 L p F P
0 g
s
.856 .406 .017 r
.56707 .69567 m .56984 .69816 L .56783 .69414 L p F P
0 g
s
.718 .304 0 r
.57594 .70755 m .57415 .70481 L .57209 .70079 L p F P
0 g
s
0 .168 .706 r
.63607 .69413 m .63581 .69332 L .63401 .69 L p F P
0 g
s
0 .038 .608 r
.63648 .69468 m .63607 .69413 L .63581 .69332 L closepath p F P
0 g
s
.498 .566 .855 r
.6091 .76103 m .60868 .76099 L .60619 .75639 L p F P
0 g
s
.811 .369 0 r
.56984 .69816 m .57209 .70079 L .57415 .70481 L p F P
0 g
s
0 0 .186 r
.64923 .73416 m .6492 .73434 L .64943 .73896 L p F P
0 g
s
.65 .757 .928 r
.29544 .52693 m .28632 .53 L .28929 .53284 L p F P
0 g
s
.65 .757 .928 r
.28929 .53284 m .2984 .52977 L .29544 .52693 L p F P
0 g
s
.651 .758 .928 r
.74036 .52694 m .73043 .53002 L .73267 .53285 L p F P
0 g
s
.651 .758 .928 r
.73267 .53285 m .74258 .52978 L .74036 .52694 L p F P
0 g
s
.65 .757 .928 r
.44374 .52697 m .43435 .53005 L .43708 .53288 L p F P
0 g
s
.65 .757 .928 r
.43708 .53288 m .44646 .52982 L .44374 .52697 L p F P
0 g
s
.651 .757 .928 r
.59205 .52698 m .58239 .53006 L .58488 .53289 L p F P
0 g
s
.651 .757 .928 r
.58488 .53289 m .59453 .52982 L .59205 .52698 L p F P
0 g
s
.333 0 0 r
.58212 .64067 m .58141 .6403 L .57718 .63817 L p F P
0 g
s
0 .141 .617 r
.60098 .65369 m .5981 .65119 L .6024 .65449 L p F P
0 g
s
0 .141 .617 r
.6024 .65449 m .60528 .65699 L .60098 .65369 L p F P
0 g
s
.618 .855 .988 r
.62337 .76871 m .63308 .76576 L .63396 .76632 L p F P
0 g
s
.575 .792 .981 r
.63308 .76576 m .62337 .76871 L .62093 .76567 L p F P
0 g
s
.65 .757 .928 r
.15924 .52653 m .15037 .52959 L .15357 .53243 L p F P
0 g
s
.65 .757 .928 r
.15357 .53243 m .16244 .52938 L .15924 .52653 L p F P
0 g
s
.627 .303 .404 r
.51864 .66696 m .51691 .66706 L .51606 .67077 L p F P
0 g
s
.538 .231 .394 r
.51691 .66706 m .51606 .67077 L .50587 .67291 L p F P
0 g
s
.524 .593 .865 r
.6091 .76103 m .61848 .76227 L p .6208 .76566 L F P
0 g
s
.433 .525 .852 r
.6091 .76103 m .61848 .76227 L .61601 .75865 L p F P
0 g
s
.433 .525 .852 r
.61601 .75865 m .61095 .7574 L .6091 .76103 L p F P
0 g
s
.498 .566 .855 r
.60619 .75639 m .61095 .7574 L .6091 .76103 L p F P
0 g
s
.885 .952 .845 r
.45323 .7476 m .44812 .75368 L .44719 .75071 L p F P
0 g
s
.885 .952 .845 r
.45308 .7445 m .45323 .7476 L p .44719 .75071 L F P
0 g
s
0 0 .049 r
.6492 .73118 m .64923 .73416 L .64945 .73885 L p F P
0 g
s
0 0 .236 r
.64923 .73416 m .6492 .73118 L .64842 .72671 L p F P
0 g
s
0 0 .186 r
.64943 .73896 m .64945 .73885 L .64923 .73416 L p F P
0 g
s
.65 .757 .928 r
.30755 .5267 m .2984 .52977 L .30136 .53261 L p F P
0 g
s
.65 .757 .928 r
.30136 .53261 m .3105 .52954 L .30755 .5267 L p F P
0 g
s
.651 .758 .928 r
.7448 .53261 m .75474 .52954 L .75694 .53237 L p F P
0 g
s
.651 .758 .928 r
.75253 .52669 m .74258 .52978 L .7448 .53261 L p F P
0 g
s
.651 .758 .928 r
.7448 .53261 m .75474 .52954 L .75253 .52669 L p F P
0 g
s
.627 .303 .404 r
.51606 .67077 m .52235 .67041 L .51864 .66696 L p F P
0 g
s
.634 .301 .39 r
.52876 .66658 m .51864 .66696 L .52235 .67041 L p F P
0 g
s
.651 .757 .928 r
.45588 .52674 m .44646 .52982 L .44917 .53265 L p F P
0 g
s
.651 .757 .928 r
.44917 .53265 m .45858 .52958 L .45588 .52674 L p F P
0 g
s
.651 .757 .928 r
.60421 .52674 m .59453 .52982 L .59699 .53265 L p F P
0 g
s
.651 .757 .928 r
.59699 .53265 m .60666 .52958 L .60421 .52674 L p F P
0 g
s
.39 .56 .901 r
.41247 .76429 m .41868 .76486 L .41717 .76205 L p F P
0 g
s
.39 .56 .901 r
.41717 .76205 m .40974 .76046 L .41247 .76429 L p F P
0 g
s
0 .27 .777 r
.40896 .75975 m .40974 .76046 L .41247 .76429 L p F P
0 g
s
.528 .714 .958 r
.42446 .76729 m .4202 .76765 L .41868 .76486 L p F P
0 g
s
.744 .95 .638 r
.4246 .68033 m .42706 .67618 L .42229 .68214 L p F P
0 g
s
.744 .95 .638 r
.42296 .68243 m .4246 .68033 L p .42229 .68214 L F P
0 g
s
0 0 .562 r
.63877 .69799 m .63648 .69468 L .63581 .69332 L p F P
0 g
s
.65 .757 .928 r
.17134 .52632 m .16244 .52938 L .16562 .53222 L p F P
0 g
s
.65 .757 .928 r
.16562 .53222 m .17451 .52917 L .17134 .52632 L p F P
0 g
s
.484 .854 .622 r
.44881 .65472 m .45571 .64947 L .45078 .65339 L closepath p F P
0 g
s
.639 .947 .731 r
.45078 .65339 m .44881 .65472 L .4463 .65683 L p F P
0 g
s
.651 .758 .928 r
.75694 .53237 m .7669 .52929 L .76908 .53212 L p F P
0 g
s
.651 .758 .928 r
.7669 .52929 m .75694 .53237 L .75474 .52954 L p F P
0 g
s
.65 .757 .928 r
.31967 .52647 m .3105 .52954 L .31343 .53238 L p F P
0 g
s
.65 .757 .928 r
.31343 .53238 m .32259 .52931 L .31967 .52647 L p F P
0 g
s
0 .22 .733 r
.58628 .72499 m .5837 .72242 L .58246 .71984 L p F P
0 g
s
.651 .757 .928 r
.61636 .5265 m .60666 .52958 L .60911 .53241 L p F P
0 g
s
.651 .757 .928 r
.60911 .53241 m .6188 .52934 L .61636 .5265 L p F P
0 g
s
.651 .757 .928 r
.46801 .5265 m .45858 .52958 L .46127 .53241 L p F P
0 g
s
.651 .757 .928 r
.46127 .53241 m .47069 .52935 L .46801 .5265 L p F P
0 g
s
.698 .364 .409 r
.53084 .66672 m .52876 .66658 L .52784 .67021 L p F P
0 g
s
.698 .364 .409 r
.52784 .67021 m .53321 .67057 L .53084 .66672 L p F P
0 g
s
.389 .084 .323 r
.49556 .68264 m .50478 .6768 L .49619 .68011 L closepath p F P
0 g
s
.128 0 .158 r
.49619 .68011 m .49556 .68264 L .49393 .68456 L p F P
0 g
s
.929 .972 .738 r
.46505 .72711 m .46571 .72363 L .46185 .72936 L p F P
0 g
s
.929 .972 .738 r
.46262 .73121 m .46505 .72711 L p .46185 .72936 L F P
0 g
s
.413 0 0 r
.58212 .64067 m .58638 .64336 L .58247 .64113 L p F P
0 g
s
.413 0 0 r
.58247 .64113 m .57965 .63943 L .58212 .64067 L p F P
0 g
s
.333 0 0 r
.57718 .63817 m .57965 .63943 L .58212 .64067 L p F P
0 g
s
0 0 0 r
.47057 .64001 m .47337 .63858 L .47094 .63979 L closepath p F P
0 g
s
.744 .95 .638 r
.42229 .68214 m .42125 .68386 L .42296 .68243 L p F P
0 g
s
.816 .967 .651 r
.42125 .68386 m .42296 .68243 L .42024 .68616 L closepath p F P
0 g
s
.65 .757 .928 r
.18343 .5261 m .17451 .52917 L .17767 .53201 L p F P
0 g
s
.65 .757 .928 r
.17767 .53201 m .18659 .52895 L .18343 .5261 L p F P
0 g
s
0 0 0 r
.64806 .74717 m .64876 .74385 L .64943 .73896 L p F P
0 g
s
.837 .851 .391 r
.64876 .74385 m .64806 .74717 L .64633 .75236 L p F P
0 g
s
.634 .301 .39 r
.52235 .67041 m .52784 .67021 L .52876 .66658 L p F P
0 g
s
.651 .758 .928 r
.76908 .53212 m .77906 .52905 L .78122 .53188 L p F P
0 g
s
.651 .758 .928 r
.77906 .52905 m .76908 .53212 L .7669 .52929 L p F P
0 g
s
.864 .825 .348 r
.40457 .72027 m .4048 .71686 L .40347 .72183 L p F P
0 g
s
.864 .825 .348 r
.40347 .72183 m .40322 .72524 L .40457 .72027 L p F P
0 g
s
.65 .757 .928 r
.33179 .52624 m .32259 .52931 L .32551 .53215 L p F P
0 g
s
.65 .757 .928 r
.32551 .53215 m .33469 .52908 L .33179 .52624 L p F P
0 g
s
.651 .757 .928 r
.62852 .52626 m .6188 .52934 L .62122 .53218 L p F P
0 g
s
.651 .757 .928 r
.62122 .53218 m .63094 .5291 L .62852 .52626 L p F P
0 g
s
.651 .757 .928 r
.48015 .52627 m .47069 .52935 L .47337 .53218 L p F P
0 g
s
.651 .757 .928 r
.47337 .53218 m .48281 .52911 L .48015 .52627 L p F P
0 g
s
.749 .384 .362 r
.54702 .67321 m .54888 .67723 L .54285 .67566 L p F P
0 g
s
.749 .384 .362 r
.54197 .67202 m .54702 .67321 L p .54285 .67566 L F P
0 g
s
0 0 0 r
.47632 .70677 m .47298 .71233 L .47574 .70821 L p F P
0 g
s
0 0 0 r
.47777 .7047 m .47632 .70677 L p .47574 .70821 L F P
0 g
s
0 0 .562 r
.63581 .69332 m .63498 .69119 L p .63877 .69799 L F P
0 g
s
0 .057 .621 r
.63581 .69332 m .63401 .69 L .63498 .69119 L closepath p F P
0 g
s
.765 .642 .082 r
.40225 .7336 m .40224 .73342 L .40202 .73808 L p F P
0 g
s
.765 .642 .082 r
.40202 .73808 m .40202 .73819 L .40225 .7336 L p F P
0 g
s
.65 .757 .928 r
.19553 .52588 m .18659 .52895 L .18973 .53179 L p F P
0 g
s
.65 .757 .928 r
.18973 .53179 m .19867 .52873 L .19553 .52588 L p F P
0 g
s
.903 .906 .815 r
.44615 .75609 m .44812 .75368 L .44719 .75071 L p F P
0 g
s
0 0 0 r
.45832 .64761 m .46047 .64621 L .46805 .64151 L p F P
0 g
s
.444 .852 .677 r
.47057 .64001 m .46805 .64151 L .46047 .64621 L p F P
0 g
s
.536 .9 .702 r
.46047 .64621 m .45832 .64761 L .45571 .64947 L p F P
0 g
s
.651 .758 .928 r
.78122 .53188 m .79122 .5288 L .79336 .53164 L p F P
0 g
s
.651 .758 .928 r
.79122 .5288 m .78122 .53188 L .77906 .52905 L p F P
0 g
s
.65 .757 .928 r
.34391 .526 m .33469 .52908 L .33759 .53192 L p F P
0 g
s
.65 .757 .928 r
.33759 .53192 m .3468 .52885 L .34391 .526 L p F P
0 g
s
.651 .757 .928 r
.64069 .52602 m .63094 .5291 L .63334 .53194 L p F P
0 g
s
.651 .757 .928 r
.63334 .53194 m .64308 .52886 L .64069 .52602 L p F P
0 g
s
.651 .757 .928 r
.4923 .52603 m .48281 .52911 L .48547 .53194 L p F P
0 g
s
.651 .757 .928 r
.48547 .53194 m .49494 .52887 L .4923 .52603 L p F P
0 g
s
0 .176 .669 r
.61167 .66249 m .60787 .65957 L .60528 .65699 L p F P
0 g
s
0 0 .194 r
.6482 .7236 m .64842 .72671 L .6492 .73118 L p F P
0 g
s
0 0 .339 r
.64842 .72671 m .6482 .7236 L .64693 .71928 L p F P
0 g
s
.846 .892 .872 r
.44045 .75727 m .43388 .76267 L .43663 .76444 L p F P
0 g
s
.846 .892 .872 r
.43663 .76444 m .44126 .76027 L .44045 .75727 L p F P
0 g
s
.717 .85 .945 r
.42829 .76536 m .43388 .76267 L .43663 .76444 L p F P
0 g
s
0 0 0 r
.40224 .73342 m .40239 .73007 L .40219 .73472 L p F P
0 g
s
0 0 0 r
.40219 .73472 m .40202 .73808 L .40224 .73342 L p F P
0 g
s
.818 .908 .902 r
.44615 .75609 m .44126 .76027 L .44045 .75727 L p F P
0 g
s
.521 .213 .385 r
.50587 .67291 m .51606 .67077 L p .50538 .67662 L F P
0 g
s
.521 .213 .385 r
.50538 .67662 m .50508 .6766 L .50587 .67291 L p F P
0 g
s
.392 .09 .329 r
.50587 .67291 m .50508 .6766 L .50478 .6768 L p F P
0 g
s
.829 .894 .474 r
.40912 .70646 m .41004 .70282 L .40761 .70811 L p F P
0 g
s
.829 .894 .474 r
.40761 .70811 m .40662 .71176 L .40912 .70646 L p F P
0 g
s
.65 .757 .928 r
.20764 .52566 m .19867 .52873 L .20179 .53158 L p F P
0 g
s
.65 .757 .928 r
.20179 .53158 m .21075 .52851 L .20764 .52566 L p F P
0 g
s
.649 .756 .927 r
.07137 .52506 m .06265 .52811 L .066 .53096 L p F P
0 g
s
.649 .756 .927 r
.066 .53096 m .07471 .52793 L .07137 .52506 L p F P
0 g
s
.651 .758 .928 r
.79336 .53164 m .80339 .52855 L .80551 .53139 L p F P
0 g
s
.651 .758 .928 r
.80339 .52855 m .79336 .53164 L .79122 .5288 L p F P
0 g
s
.837 .406 .211 r
.55776 .6846 m .55871 .68415 L .5594 .68539 L closepath p F P
0 g
s
.875 .473 .264 r
.55537 .68325 m .55776 .6846 L .55871 .68415 L p F P
0 g
s
0 .22 .733 r
.58246 .71984 m .5822 .71827 L p .58628 .72499 L F P
0 g
s
0 .173 .704 r
.58246 .71984 m .58117 .71715 L .5822 .71827 L closepath p F P
0 g
s
.65 .757 .928 r
.35604 .52577 m .3468 .52885 L .34967 .53168 L p F P
0 g
s
.65 .757 .928 r
.34967 .53168 m .3589 .52862 L .35604 .52577 L p F P
0 g
s
.651 .757 .928 r
.65286 .52578 m .64308 .52886 L .64547 .5317 L p F P
0 g
s
.651 .757 .928 r
.64547 .5317 m .65523 .52863 L .65286 .52578 L p F P
0 g
s
.651 .757 .928 r
.50445 .52579 m .49494 .52887 L .49757 .53171 L p F P
0 g
s
.651 .757 .928 r
.49757 .53171 m .50707 .52864 L .50445 .52579 L p F P
0 g
s
.903 .906 .815 r
.44719 .75071 m .4434 .75497 L .44615 .75609 L p F P
0 g
s
.818 .908 .902 r
.44045 .75727 m .4434 .75497 L .44615 .75609 L p F P
0 g
s
0 0 0 r
.47057 .64001 m .47337 .63858 L p .4697 .64072 L F P
0 g
s
0 0 0 r
.4697 .64072 m .46805 .64151 L .47057 .64001 L p F P
0 g
s
.754 .926 .568 r
.42024 .68616 m .41638 .69184 L .41811 .68793 L p F P
0 g
s
.754 .926 .568 r
.42125 .68386 m .42024 .68616 L p .41811 .68793 L F P
0 g
s
.65 .757 .928 r
.21974 .52544 m .21075 .52851 L .21385 .53135 L p F P
0 g
s
.65 .757 .928 r
.21385 .53135 m .22284 .52829 L .21974 .52544 L p F P
0 g
s
.651 .758 .928 r
.80551 .53139 m .81556 .52831 L .81766 .53114 L p F P
0 g
s
.651 .758 .928 r
.81556 .52831 m .80551 .53139 L .80339 .52855 L p F P
0 g
s
.65 .757 .928 r
.36817 .52554 m .3589 .52862 L .36176 .53145 L p F P
0 g
s
.65 .757 .928 r
.36176 .53145 m .37101 .52838 L .36817 .52554 L p F P
0 g
s
.649 .756 .927 r
.08346 .52488 m .07471 .52793 L .07804 .53078 L p F P
0 g
s
.649 .756 .927 r
.07804 .53078 m .08677 .52774 L .08346 .52488 L p F P
0 g
s
.651 .757 .928 r
.66503 .52554 m .65523 .52863 L .6576 .53146 L p F P
0 g
s
.651 .757 .928 r
.6576 .53146 m .66738 .52839 L .66503 .52554 L p F P
0 g
s
.651 .757 .928 r
.5166 .52556 m .50707 .52864 L .50968 .53147 L p F P
0 g
s
.651 .757 .928 r
.50968 .53147 m .5192 .5284 L .5166 .52556 L p F P
0 g
s
0 .164 .674 r
.61448 .66554 m .61412 .66525 L .61167 .66249 L p F P
0 g
s
0 .305 .72 r
.58996 .64568 m .58638 .64336 L .59138 .64643 L p F P
0 g
s
0 .305 .72 r
.5944 .64839 m .58996 .64568 L p .59138 .64643 L F P
0 g
s
0 .233 .678 r
.58996 .64568 m .5944 .64839 L .59685 .65032 L p F P
0 g
s
.929 .972 .738 r
.46185 .72936 m .4617 .73159 L .46262 .73121 L p F P
0 g
s
.901 .986 .757 r
.4617 .73159 m .46262 .73121 L .46147 .73275 L closepath p F P
0 g
s
.846 .463 .325 r
.55372 .67915 m .54888 .67723 L .55077 .68126 L p F P
0 g
s
.846 .463 .325 r
.55077 .68126 m .55537 .68325 L .55372 .67915 L p F P
0 g
s
.65 .757 .928 r
.23186 .52522 m .22284 .52829 L .22592 .53113 L p F P
0 g
s
.65 .757 .928 r
.22592 .53113 m .23493 .52807 L .23186 .52522 L p F P
0 g
s
.651 .758 .928 r
.81766 .53114 m .82773 .52806 L .82981 .53089 L p F P
0 g
s
.651 .758 .928 r
.82773 .52806 m .81766 .53114 L .81556 .52831 L p F P
0 g
s
0 .208 .734 r
.40974 .76046 m .40896 .75975 L .40839 .75829 L closepath p F P
0 g
s
.65 .757 .928 r
.3803 .5253 m .37101 .52838 L .37385 .53122 L p F P
0 g
s
.65 .757 .928 r
.37385 .53122 m .38313 .52815 L .3803 .5253 L p F P
0 g
s
.651 .758 .928 r
.6772 .5253 m .66738 .52839 L .66973 .53122 L p F P
0 g
s
.651 .758 .928 r
.66973 .53122 m .67954 .52815 L .6772 .5253 L p F P
0 g
s
.651 .757 .928 r
.52875 .52532 m .5192 .5284 L .52179 .53124 L p F P
0 g
s
.651 .757 .928 r
.52179 .53124 m .53133 .52816 L .52875 .52532 L p F P
0 g
s
.649 .756 .927 r
.09554 .52469 m .08677 .52774 L .09008 .5306 L p F P
0 g
s
.649 .756 .927 r
.09008 .5306 m .09884 .52755 L .09554 .52469 L p F P
0 g
s
.451 .534 .851 r
.61095 .7574 m .60619 .75639 L .60368 .75166 L p F P
0 g
s
0 .188 .641 r
.59685 .65032 m .5981 .65119 L .59494 .64876 L p F P
0 g
s
0 .188 .641 r
.59494 .64876 m .5944 .64839 L .59685 .65032 L p F P
0 g
s
0 0 .532 r
.40704 .75583 m .40523 .75293 L .40437 .74991 L p F P
0 g
s
0 0 .553 r
.40523 .75293 m .40704 .75583 L .40839 .75829 L p F P
0 g
s
.871 .994 .77 r
.46147 .73275 m .45718 .7386 L .45746 .73525 L p F P
0 g
s
.871 .994 .77 r
.4617 .73159 m .46147 .73275 L p .45746 .73525 L F P
0 g
s
0 .107 .639 r
.61448 .66554 m .61818 .66905 L .62023 .67177 L p F P
0 g
s
0 .07 .589 r
.61217 .66289 m .61448 .66554 L .61818 .66905 L p F P
0 g
s
0 .164 .674 r
.61167 .66249 m .61217 .66289 L .61448 .66554 L p F P
0 g
s
0 0 .305 r
.64649 .71621 m .64693 .71928 L .6482 .7236 L p F P
0 g
s
0 0 .416 r
.64693 .71928 m .64649 .71621 L .64479 .71203 L p F P
0 g
s
.771 .889 .929 r
.63308 .76576 m .63407 .76514 L .63396 .76632 L closepath p F P
0 g
s
.85 .902 .872 r
.64267 .7586 m .63407 .76514 L .63396 .76632 L p F P
0 g
s
.85 .902 .872 r
.64308 .75851 m .64267 .7586 L p .63396 .76632 L F P
0 g
s
.651 .758 .928 r
.82981 .53089 m .83991 .5278 L .84197 .53064 L p F P
0 g
s
.651 .758 .928 r
.83991 .5278 m .82981 .53089 L .82773 .52806 L p F P
0 g
s
.65 .757 .928 r
.24397 .52499 m .23493 .52807 L .23799 .53091 L p F P
0 g
s
.65 .757 .928 r
.23799 .53091 m .24702 .52784 L .24397 .52499 L p F P
0 g
s
0 0 0 r
.47337 .63858 m .47926 .63579 L p .4697 .64072 L F P
0 g
s
.651 .758 .928 r
.68938 .52506 m .67954 .52815 L .68186 .53098 L p F P
0 g
s
.651 .758 .928 r
.68186 .53098 m .69169 .52791 L .68938 .52506 L p F P
0 g
s
.65 .757 .928 r
.39244 .52507 m .38313 .52815 L .38594 .53099 L p F P
0 g
s
.65 .757 .928 r
.38594 .53099 m .39524 .52791 L .39244 .52507 L p F P
0 g
s
0 .133 .681 r
.5822 .71827 m .58117 .71715 L .57864 .7125 L p F P
0 g
s
.651 .757 .928 r
.54091 .52508 m .53133 .52816 L .5339 .531 L p F P
0 g
s
.651 .757 .928 r
.5339 .531 m .54347 .52793 L .54091 .52508 L p F P
0 g
s
.649 .756 .927 r
.10764 .52449 m .09884 .52755 L .10213 .5304 L p F P
0 g
s
.649 .756 .927 r
.10213 .5304 m .11091 .52736 L .10764 .52449 L p F P
0 g
s
.749 .384 .362 r
.54285 .67566 m .54147 .67328 L .54197 .67202 L p F P
0 g
s
.775 .414 .372 r
.54147 .67328 m .54071 .67172 L .54197 .67202 L closepath p F P
0 g
s
.657 .916 .61 r
.42969 .6731 m .43253 .67001 L .43098 .67201 L closepath p F P
0 g
s
.71 .937 .625 r
.42706 .67618 m .42969 .6731 L .43098 .67201 L p F P
0 g
s
.651 .758 .928 r
.84197 .53064 m .85209 .52755 L .85413 .53039 L p F P
0 g
s
.651 .758 .928 r
.85209 .52755 m .84197 .53064 L .83991 .5278 L p F P
0 g
s
.704 .862 .451 r
.47298 .71233 m .47574 .70821 L .4716 .71401 L p F P
0 g
s
.704 .862 .451 r
.4716 .71401 m .46965 .71789 L .47298 .71233 L p F P
0 g
s
.65 .757 .928 r
.25609 .52476 m .24702 .52784 L .25007 .53068 L p F P
0 g
s
.65 .757 .928 r
.25007 .53068 m .25912 .52762 L .25609 .52476 L p F P
0 g
s
.727 .833 .93 r
.42755 .76234 m .42171 .76481 L .42446 .76729 L p F P
0 g
s
.727 .833 .93 r
.42446 .76729 m .42829 .76536 L .42755 .76234 L p F P
0 g
s
.528 .714 .958 r
.41868 .76486 m .42171 .76481 L .42446 .76729 L p F P
0 g
s
0 .035 .601 r
.63498 .69119 m .63401 .69 L .63155 .6857 L p F P
0 g
s
.651 .758 .928 r
.70156 .52482 m .69169 .52791 L .694 .53074 L p F P
0 g
s
.651 .758 .928 r
.694 .53074 m .70385 .52766 L .70156 .52482 L p F P
0 g
s
.824 .382 .186 r
.5594 .68539 m .56159 .68935 L .55742 .68725 L p F P
0 g
s
.824 .382 .186 r
.55776 .6846 m .5594 .68539 L p .55742 .68725 L F P
0 g
s
.65 .757 .928 r
.40458 .52483 m .39524 .52791 L .39804 .53075 L p F P
0 g
s
.65 .757 .928 r
.39804 .53075 m .40736 .52768 L .40458 .52483 L p F P
0 g
s
.651 .757 .928 r
.55307 .52484 m .54347 .52793 L .54602 .53077 L p F P
0 g
s
.651 .757 .928 r
.54602 .53077 m .55561 .52769 L .55307 .52484 L p F P
0 g
s
.649 .756 .928 r
.11973 .5243 m .11091 .52736 L .11418 .53021 L p F P
0 g
s
.649 .756 .928 r
.11418 .53021 m .12299 .52716 L .11973 .5243 L p F P
0 g
s
.123 0 .15 r
.48599 .6938 m .4887 .69067 L .4866 .69202 L closepath p F P
0 g
s
.01 0 .1 r
.48398 .69663 m .48599 .6938 L .4866 .69202 L p F P
0 g
s
.372 0 0 r
.57965 .63943 m .57718 .63817 L .57263 .63612 L p F P
0 g
s
0 .108 .648 r
.6256 .67811 m .62383 .67533 L .62023 .67177 L p F P
0 g
s
0 .078 .612 r
.61818 .66905 m .62023 .67177 L .62383 .67533 L p F P
0 g
s
.65 .757 .928 r
.26821 .52454 m .25912 .52762 L .26215 .53046 L p F P
0 g
s
.65 .757 .928 r
.26215 .53046 m .27122 .52739 L .26821 .52454 L p F P
0 g
s
0 0 0 r
.64945 .73885 m .64943 .73896 L .64876 .74385 L p F P
0 g
s
.651 .758 .928 r
.71374 .52457 m .70385 .52766 L .70614 .5305 L p F P
0 g
s
.651 .758 .928 r
.70614 .5305 m .71602 .52742 L .71374 .52457 L p F P
0 g
s
0 0 .278 r
.40305 .74568 m .40265 .74356 L .40437 .7499 L p F P
0 g
s
0 0 .278 r
.40437 .7499 m .40437 .74991 L .40305 .74568 L p F P
0 g
s
.65 .757 .928 r
.41672 .5246 m .40736 .52768 L .41014 .53052 L p F P
0 g
s
.65 .757 .928 r
.41014 .53052 m .41949 .52745 L .41672 .5246 L p F P
0 g
s
.651 .757 .928 r
.56523 .5246 m .55561 .52769 L .55814 .53053 L p F P
0 g
s
.651 .757 .928 r
.55814 .53053 m .56775 .52745 L .56523 .5246 L p F P
0 g
s
.737 .371 .359 r
.54071 .67172 m .53321 .67057 L .53562 .67443 L p F P
0 g
s
.737 .371 .359 r
.54147 .67328 m .54071 .67172 L p .53562 .67443 L F P
0 g
s
.332 .583 .935 r
.40974 .76046 m .40839 .75829 L p .41576 .7592 L F P
0 g
s
.332 .583 .935 r
.41576 .7592 m .41717 .76205 L .40974 .76046 L p F P
0 g
s
.826 .854 .397 r
.40632 .71255 m .40662 .71176 L .40657 .71203 L closepath p F P
0 g
s
.87 .867 .42 r
.4048 .71686 m .40632 .71255 L .40657 .71203 L p F P
0 g
s
0 0 .386 r
.64412 .709 m .64479 .71203 L .64649 .71621 L p F P
0 g
s
0 0 .472 r
.64479 .71203 m .64412 .709 L .64206 .70493 L p F P
0 g
s
.952 .944 .628 r
.64633 .75236 m .64317 .75794 L .64308 .75851 L p F P
0 g
s
.931 .97 .704 r
.64691 .74907 m .64633 .75236 L .64317 .75794 L p F P
0 g
s
.837 .851 .391 r
.64633 .75236 m .64691 .74907 L .64876 .74385 L p F P
0 g
s
.785 .937 .581 r
.41638 .69184 m .41811 .68793 L .41457 .69354 L p F P
0 g
s
.785 .937 .581 r
.41325 .69675 m .41638 .69184 L p .41457 .69354 L F P
0 g
s
.65 .756 .928 r
.13183 .52409 m .12299 .52716 L .12624 .53001 L p F P
0 g
s
.65 .756 .928 r
.12624 .53001 m .13507 .52695 L .13183 .52409 L p F P
0 g
s
0 0 .049 r
.64945 .73885 m .64939 .73582 L .6492 .73118 L p F P
0 g
s
0 0 0 r
.64876 .74385 m .64894 .7428 L .64945 .73885 L p F P
0 g
s
.828 .715 .183 r
.64939 .73582 m .64945 .73885 L .64894 .7428 L p F P
0 g
s
.65 .757 .928 r
.28034 .52431 m .27122 .52739 L .27423 .53023 L p F P
0 g
s
.65 .757 .928 r
.27423 .53023 m .28333 .52716 L .28034 .52431 L p F P
0 g
s
.484 .632 .919 r
.62093 .76567 m .6208 .76566 L .62082 .76551 L closepath p F P
0 g
s
.524 .593 .865 r
.61848 .76227 m .62082 .76551 L .6208 .76566 L p F P
0 g
s
.651 .758 .928 r
.72593 .52433 m .71602 .52742 L .71829 .53026 L p F P
0 g
s
.651 .758 .928 r
.71829 .53026 m .72819 .52718 L .72593 .52433 L p F P
0 g
s
.65 .757 .928 r
.42887 .52436 m .41949 .52745 L .42225 .53029 L p F P
0 g
s
.65 .757 .928 r
.42225 .53029 m .43161 .52721 L .42887 .52436 L p F P
0 g
s
.651 .757 .928 r
.5774 .52436 m .56775 .52745 L .57027 .53029 L p F P
0 g
s
.651 .757 .928 r
.57027 .53029 m .5799 .52721 L .5774 .52436 L p F P
0 g
s
.865 .419 .112 r
.56503 .69166 m .56159 .68935 L .56374 .69334 L p F P
0 g
s
.865 .419 .112 r
.56374 .69334 m .56707 .69567 L .56503 .69166 L p F P
0 g
s
.575 .792 .981 r
.62093 .76567 m .63068 .76376 L .63308 .76576 L p F P
0 g
s
.568 .672 .909 r
.62827 .76135 m .63068 .76376 L .62093 .76567 L p F P
0 g
s
.568 .672 .909 r
.62376 .76174 m .62827 .76135 L p .62093 .76567 L F P
0 g
s
.568 .672 .909 r
.62093 .76567 m .62082 .76551 L .62376 .76174 L p F P
0 g
s
.791 .728 .199 r
.40322 .72524 m .40347 .72183 L .40265 .72666 L p F P
0 g
s
.791 .728 .199 r
.40265 .72666 m .40239 .73007 L .40322 .72524 L p F P
0 g
s
.65 .756 .928 r
.14394 .52388 m .13507 .52695 L .1383 .5298 L p F P
0 g
s
.65 .756 .928 r
.1383 .5298 m .14716 .52674 L .14394 .52388 L p F P
0 g
s
.78 .835 .371 r
.40662 .71176 m .40761 .70811 L .40558 .71328 L p F P
0 g
s
.78 .835 .371 r
.40632 .71255 m .40662 .71176 L p .40558 .71328 L F P
0 g
s
0 .182 .714 r
.62909 .6817 m .6256 .67811 L p .63059 .68456 L F P
0 g
s
0 .074 .62 r
.6256 .67811 m .62909 .6817 L .62665 .67828 L p F P
0 g
s
0 .074 .62 r
.62665 .67828 m .62383 .67533 L .6256 .67811 L p F P
0 g
s
.568 .673 .91 r
.62082 .76551 m .61848 .76227 L .62376 .76174 L closepath p F P
0 g
s
.433 0 0 r
.5981 .65119 m .59494 .64876 L .59922 .65206 L p F P
0 g
s
.433 0 0 r
.59922 .65206 m .6024 .65449 L .5981 .65119 L p F P
0 g
s
.931 .942 .78 r
.45718 .7386 m .45746 .73525 L .45263 .74126 L p F P
0 g
s
.931 .942 .78 r
.45263 .74126 m .45305 .7444 L .45718 .7386 L p F P
0 g
s
.65 .757 .928 r
.29246 .52408 m .28333 .52716 L .28632 .53 L p F P
0 g
s
.65 .757 .928 r
.28632 .53 m .29544 .52693 L .29246 .52408 L p F P
0 g
s
.346 .022 .266 r
.49521 .68376 m .49556 .68264 L .50478 .6768 L p F P
0 g
s
.162 0 .191 r
.49521 .68376 m .49556 .68264 L .49393 .68456 L closepath p F P
0 g
s
0 0 .441 r
.64115 .70196 m .64206 .70493 L .64412 .709 L p F P
0 g
s
0 0 .512 r
.64206 .70493 m .64115 .70196 L .63877 .69799 L p F P
0 g
s
.651 .758 .928 r
.73812 .52409 m .72819 .52718 L .73043 .53002 L p F P
0 g
s
.651 .758 .928 r
.73043 .53002 m .74036 .52694 L .73812 .52409 L p F P
0 g
s
.65 .757 .928 r
.44102 .52412 m .43161 .52721 L .43435 .53005 L p F P
0 g
s
.65 .757 .928 r
.43435 .53005 m .44374 .52697 L .44102 .52412 L p F P
0 g
s
.651 .757 .928 r
.58957 .52413 m .5799 .52721 L .58239 .53006 L p F P
0 g
s
.651 .757 .928 r
.58239 .53006 m .59205 .52698 L .58957 .52413 L p F P
0 g
s
.811 .369 0 r
.57415 .70481 m .57187 .7022 L .56984 .69816 L p F P
0 g
s
.853 .403 .008 r
.56984 .69816 m .56707 .69567 L .56912 .6997 L p F P
0 g
s
.853 .403 .008 r
.56912 .6997 m .57187 .7022 L .56984 .69816 L p F P
0 g
s
.685 .844 .959 r
.43388 .76267 m .42829 .76536 L .42755 .76234 L p F P
0 g
s
.713 .288 0 r
.57612 .70863 m .57415 .70481 L p .57812 .71156 L F P
0 g
s
.713 .288 0 r
.57812 .71156 m .57658 .70933 L .57612 .70863 L p F P
0 g
s
.039 .251 .75 r
.59435 .73845 m .59411 .73533 L .59027 .73173 L p F P
0 g
s
0 .152 .694 r
.5898 .72866 m .59027 .73173 L .59411 .73533 L p F P
0 g
s
0 .197 .72 r
.59027 .73173 m .5898 .72866 L .58628 .72499 L p F P
0 g
s
.104 .301 .777 r
.5987 .74509 m .59859 .74195 L .59435 .73845 L p F P
0 g
s
.046 .284 .776 r
.59411 .73533 m .59435 .73845 L .59859 .74195 L p F P
0 g
s
0 .22 .733 r
.5822 .71827 m .58551 .72199 L .58628 .72499 L p F P
0 g
s
0 .028 .593 r
.58106 .71536 m .5822 .71827 L .58551 .72199 L p F P
0 g
s
0 .133 .681 r
.57864 .7125 m .58106 .71536 L .5822 .71827 L p F P
0 g
s
0 .09 .648 r
.58551 .72199 m .58628 .72499 L .5898 .72866 L p F P
0 g
s
.806 .363 0 r
.57415 .70481 m .57612 .70863 L .57361 .70562 L p F P
0 g
s
.806 .363 0 r
.57361 .70562 m .57187 .7022 L .57415 .70481 L p F P
0 g
s
.65 .757 .928 r
.15604 .52367 m .14716 .52674 L .15037 .52959 L p F P
0 g
s
.65 .757 .928 r
.15037 .52959 m .15924 .52653 L .15604 .52367 L p F P
0 g
s
.78 .835 .371 r
.40558 .71328 m .405 .71538 L .40632 .71255 L p F P
0 g
s
.865 .864 .415 r
.405 .71538 m .40632 .71255 L .4048 .71686 L closepath p F P
0 g
s
.824 .382 .186 r
.55742 .68725 m .55622 .68528 L .55776 .6846 L p F P
0 g
s
.873 .467 .255 r
.55622 .68528 m .55537 .68325 L .55776 .6846 L closepath p F P
0 g
s
.732 .85 .936 r
.63407 .76514 m .63308 .76576 L .63068 .76376 L p F P
0 g
s
.25 .41 .827 r
.60117 .74681 m .5987 .74509 L p .60356 .75159 L F P
0 g
s
.102 .299 .776 r
.5987 .74509 m .60117 .74681 L .59865 .742 L p F P
0 g
s
.102 .299 .776 r
.59865 .742 m .59859 .74195 L .5987 .74509 L p F P
0 g
s
0 .035 .597 r
.63155 .6857 m .63059 .68456 L .62911 .68174 L closepath p F P
0 g
s
0 .182 .714 r
.63059 .68456 m .62911 .68174 L .62909 .6817 L p F P
0 g
s
.16 0 .186 r
.49393 .68456 m .49521 .68376 L .49411 .6873 L p F P
0 g
s
.16 0 .186 r
.49411 .6873 m .4887 .69067 L .49393 .68456 L p F P
0 g
s
.65 .757 .928 r
.3046 .52385 m .29544 .52693 L .2984 .52977 L p F P
0 g
s
.65 .757 .928 r
.2984 .52977 m .30755 .5267 L .3046 .52385 L p F P
0 g
s
.651 .758 .928 r
.75032 .52384 m .74036 .52694 L .74258 .52978 L p F P
0 g
s
.651 .758 .928 r
.74258 .52978 m .75253 .52669 L .75032 .52384 L p F P
0 g
s
.906 .984 .765 r
.64267 .7586 m .64317 .75794 L .64308 .75851 L closepath p F P
0 g
s
0 0 .479 r
.63763 .69507 m .63877 .69799 L .64115 .70196 L p F P
0 g
s
0 0 .562 r
.63498 .69119 m .63763 .69507 L .63877 .69799 L p F P
0 g
s
.651 .757 .928 r
.45317 .52389 m .44374 .52697 L .44646 .52982 L p F P
0 g
s
.651 .757 .928 r
.44646 .52982 m .45588 .52674 L .45317 .52389 L p F P
0 g
s
.651 .757 .928 r
.60174 .52389 m .59205 .52698 L .59453 .52982 L p F P
0 g
s
.651 .757 .928 r
.59453 .52982 m .60421 .52674 L .60174 .52389 L p F P
0 g
s
0 0 0 r
.47637 .70732 m .47986 .70241 L .47777 .7047 L closepath p F P
0 g
s
0 0 0 r
.47574 .70821 m .47637 .70732 L .47777 .7047 L p F P
0 g
s
.929 .972 .738 r
.45986 .73234 m .46185 .72936 L .4617 .73159 L closepath p F P
0 g
s
.871 .994 .77 r
.45746 .73525 m .45986 .73234 L .4617 .73159 L p F P
0 g
s
0 0 .503 r
.6336 .68832 m .63498 .69119 L .63763 .69507 L p F P
0 g
s
0 .035 .601 r
.63155 .6857 m .6336 .68832 L .63498 .69119 L p F P
0 g
s
.732 .85 .936 r
.63068 .76376 m .63401 .76205 L .63407 .76514 L p F P
0 g
s
.789 .981 .904 r
.64035 .75828 m .63401 .76205 L .63407 .76514 L p F P
0 g
s
.789 .981 .904 r
.63407 .76514 m .64267 .7586 L .64035 .75828 L p F P
0 g
s
.65 .757 .928 r
.16816 .52346 m .15924 .52653 L .16244 .52938 L p F P
0 g
s
.65 .757 .928 r
.16244 .52938 m .17134 .52632 L .16816 .52346 L p F P
0 g
s
.836 .944 .583 r
.46951 .71813 m .46965 .71789 L .46961 .71802 L closepath p F P
0 g
s
.754 .924 .563 r
.46571 .72363 m .46951 .71813 L .46961 .71802 L p F P
0 g
s
0 0 .197 r
.40202 .73819 m .40202 .73808 L .40265 .74251 L p F P
0 g
s
0 0 .197 r
.40265 .74251 m .40265 .74356 L .40202 .73819 L p F P
0 g
s
.651 .758 .928 r
.75474 .52954 m .76471 .52645 L .7669 .52929 L p F P
0 g
s
.651 .758 .928 r
.76251 .5236 m .75253 .52669 L .75474 .52954 L p F P
0 g
s
.651 .758 .928 r
.75474 .52954 m .76471 .52645 L .76251 .5236 L p F P
0 g
s
.25 .409 .827 r
.60368 .75166 m .60356 .75159 L .60358 .75146 L closepath p F P
0 g
s
.25 .41 .827 r
.60356 .75159 m .60358 .75146 L .60117 .74681 L p F P
0 g
s
.65 .757 .928 r
.31673 .52361 m .30755 .5267 L .3105 .52954 L p F P
0 g
s
.65 .757 .928 r
.3105 .52954 m .31967 .52647 L .31673 .52361 L p F P
0 g
s
.651 .757 .928 r
.61392 .52365 m .60421 .52674 L .60666 .52958 L p F P
0 g
s
.651 .757 .928 r
.60666 .52958 m .61636 .5265 L .61392 .52365 L p F P
0 g
s
.651 .757 .928 r
.46533 .52365 m .45588 .52674 L .45858 .52958 L p F P
0 g
s
.651 .757 .928 r
.45858 .52958 m .46801 .5265 L .46533 .52365 L p F P
0 g
s
.332 .583 .935 r
.40839 .75829 m .40827 .75669 L .41576 .7592 L p F P
0 g
s
.132 .34 .804 r
.40827 .75669 m .40839 .75829 L .40704 .75583 L closepath p F P
0 g
s
0 0 .227 r
.40202 .73808 m .40219 .73472 L .40281 .73916 L p F P
0 g
s
0 0 .227 r
.40281 .73916 m .40265 .74251 L .40202 .73808 L p F P
0 g
s
.765 .934 .583 r
.46965 .71789 m .4716 .71401 L .46754 .7198 L p F P
0 g
s
.765 .934 .583 r
.46951 .71813 m .46965 .71789 L p .46754 .7198 L F P
0 g
s
.451 .534 .851 r
.60368 .75166 m .61143 .75413 L .61095 .7574 L p F P
0 g
s
.4 .5 .845 r
.61143 .75413 m .60368 .75166 L .60358 .75146 L p F P
0 g
s
.626 .301 .401 r
.52235 .67041 m .51606 .67077 L .5152 .67449 L p F P
0 g
s
.521 .213 .385 r
.51606 .67077 m .5152 .67449 L .50538 .67662 L p F P
0 g
s
.765 .934 .583 r
.46754 .7198 m .46721 .72047 L .46951 .71813 L p F P
0 g
s
.778 .938 .586 r
.46721 .72047 m .46951 .71813 L .46571 .72363 L closepath p F P
0 g
s
.4 .5 .845 r
.60358 .75146 m .60458 .74816 L p .61143 .75413 L F P
0 g
s
.358 .475 .842 r
.60358 .75146 m .60117 .74681 L .60458 .74816 L closepath p F P
0 g
s
.65 .757 .928 r
.18027 .52324 m .17134 .52632 L .17451 .52917 L p F P
0 g
s
.65 .757 .928 r
.17451 .52917 m .18343 .5261 L .18027 .52324 L p F P
0 g
s
.485 .687 .957 r
.42171 .76481 m .41868 .76486 L .41717 .76205 L p F P
0 g
s
.785 .937 .581 r
.41457 .69354 m .41295 .69707 L .41325 .69675 L p F P
0 g
s
.85 .95 .596 r
.41295 .69707 m .41325 .69675 L .41283 .69744 L closepath p F P
0 g
s
.651 .758 .928 r
.7669 .52929 m .77689 .5262 L .77906 .52905 L p F P
0 g
s
.651 .758 .928 r
.77689 .5262 m .7669 .52929 L .76471 .52645 L p F P
0 g
s
.65 .757 .928 r
.32887 .52338 m .31967 .52647 L .32259 .52931 L p F P
0 g
s
.65 .757 .928 r
.32259 .52931 m .33179 .52624 L .32887 .52338 L p F P
0 g
s
.748 .383 .363 r
.54069 .67526 m .54147 .67328 L .54285 .67566 L closepath p F P
0 g
s
.737 .371 .359 r
.53562 .67443 m .54069 .67526 L .54147 .67328 L p F P
0 g
s
.651 .757 .928 r
.6261 .52341 m .61636 .5265 L .6188 .52934 L p F P
0 g
s
.651 .757 .928 r
.6188 .52934 m .62852 .52626 L .6261 .52341 L p F P
0 g
s
.651 .757 .928 r
.47749 .52341 m .46801 .5265 L .47069 .52935 L p F P
0 g
s
.651 .757 .928 r
.47069 .52935 m .48015 .52627 L .47749 .52341 L p F P
0 g
s
0 0 .194 r
.6492 .73118 m .64897 .72807 L .6482 .7236 L p F P
0 g
s
.742 .576 .001 r
.64897 .72807 m .6492 .73118 L .64939 .73582 L p F P
0 g
s
.698 .364 .407 r
.53321 .67057 m .52784 .67021 L .52691 .67383 L p F P
0 g
s
.698 .364 .407 r
.52691 .67383 m .53562 .67443 L .53321 .67057 L p F P
0 g
s
0 .018 .576 r
.58106 .71536 m .57864 .7125 L .57658 .70933 L p F P
0 g
s
.821 .908 .503 r
.41283 .69744 m .41295 .69707 L .41093 .69996 L p F P
0 g
s
.821 .908 .503 r
.41093 .69996 m .41004 .70282 L .41283 .69744 L p F P
0 g
s
.798 .426 .351 r
.54888 .67723 m .54285 .67566 L .54512 .67958 L p F P
0 g
s
.798 .426 .351 r
.54512 .67958 m .55077 .68126 L .54888 .67723 L p F P
0 g
s
.65 .757 .928 r
.19239 .52302 m .18343 .5261 L .18659 .52895 L p F P
0 g
s
.65 .757 .928 r
.18659 .52895 m .19553 .52588 L .19239 .52302 L p F P
0 g
s
.929 .919 .783 r
.45299 .74449 m .45305 .7444 L .45308 .7445 L closepath p F P
0 g
s
.885 .952 .845 r
.44719 .75071 m .45299 .74449 L .45308 .7445 L p F P
0 g
s
.018 0 .054 r
.4887 .69067 m .49411 .6873 L p .48532 .69543 L F P
0 g
s
.018 0 .054 r
.48532 .69543 m .48599 .6938 L .4887 .69067 L p F P
0 g
s
.895 .968 .825 r
.64317 .75794 m .64267 .7586 L .64035 .75828 L p F P
0 g
s
.895 .968 .825 r
.64035 .75828 m .64341 .75476 L .64317 .75794 L p F P
0 g
s
.931 .97 .704 r
.64317 .75794 m .64341 .75476 L .64691 .74907 L p F P
0 g
s
.651 .758 .928 r
.77906 .52905 m .78907 .52596 L .79122 .5288 L p F P
0 g
s
.651 .758 .928 r
.78907 .52596 m .77906 .52905 L .77689 .5262 L p F P
0 g
s
0 .238 .706 r
.60528 .65699 m .6024 .65449 L .60675 .65779 L p F P
0 g
s
0 .238 .706 r
.60923 .66001 m .60528 .65699 L p .60675 .65779 L F P
0 g
s
0 .176 .669 r
.60528 .65699 m .60923 .66001 L .61167 .66249 L p F P
0 g
s
.65 .757 .928 r
.34101 .52315 m .33179 .52624 L .33469 .52908 L p F P
0 g
s
.65 .757 .928 r
.33469 .52908 m .34391 .526 L .34101 .52315 L p F P
0 g
s
.651 .757 .928 r
.63829 .52317 m .62852 .52626 L .63094 .5291 L p F P
0 g
s
.651 .757 .928 r
.63094 .5291 m .64069 .52602 L .63829 .52317 L p F P
0 g
s
.651 .757 .928 r
.48965 .52318 m .48015 .52627 L .48281 .52911 L p F P
0 g
s
.651 .757 .928 r
.48281 .52911 m .4923 .52603 L .48965 .52318 L p F P
0 g
s
.626 .301 .401 r
.5152 .67449 m .52614 .67386 L .52235 .67041 L p F P
0 g
s
.633 .299 .387 r
.52784 .67021 m .52235 .67041 L .52614 .67386 L p F P
0 g
s
.706 .908 .553 r
.42004 .68517 m .42229 .68214 L .42125 .68386 L closepath p F P
0 g
s
.754 .926 .568 r
.41811 .68793 m .42004 .68517 L .42125 .68386 L p F P
0 g
s
.932 .942 .779 r
.45299 .74449 m .45305 .7444 L .45263 .74126 L p F P
0 g
s
.574 .903 .659 r
.43927 .66307 m .4463 .65683 L p .44392 .65861 L F P
0 g
s
.574 .903 .659 r
.44392 .65861 m .43902 .66324 L .43927 .66307 L p F P
0 g
s
.669 .945 .685 r
.43902 .66324 m .43927 .66307 L .43867 .66365 L closepath p F P
0 g
s
.932 .942 .779 r
.45263 .74126 m .45023 .74433 L .45299 .74449 L p F P
0 g
s
.861 .967 .865 r
.45299 .74449 m .44719 .75071 L .44691 .74754 L p F P
0 g
s
.861 .967 .865 r
.44691 .74754 m .45023 .74433 L .45299 .74449 L p F P
0 g
s
.589 .889 .598 r
.43867 .66365 m .43253 .67001 L .43638 .66542 L p F P
0 g
s
.589 .889 .598 r
.43902 .66324 m .43867 .66365 L p .43638 .66542 L F P
0 g
s
.352 .026 .265 r
.49411 .6873 m .49521 .68376 L .50404 .68029 L p F P
0 g
s
.346 .022 .266 r
.50506 .67669 m .50404 .68029 L .49521 .68376 L p F P
0 g
s
.346 .022 .266 r
.50478 .6768 m .50506 .67669 L p .49521 .68376 L F P
0 g
s
.574 .903 .659 r
.4463 .65683 m .44794 .65528 L p .44392 .65861 L F P
0 g
s
.576 .905 .662 r
.44794 .65528 m .44881 .65472 L .4463 .65683 L closepath p F P
0 g
s
.65 .757 .928 r
.20451 .5228 m .19553 .52588 L .19867 .52873 L p F P
0 g
s
.65 .757 .928 r
.19867 .52873 m .20764 .52566 L .20451 .5228 L p F P
0 g
s
.414 0 0 r
.58638 .64336 m .58247 .64113 L .5874 .64422 L p F P
0 g
s
.414 0 0 r
.5874 .64422 m .59138 .64643 L .58638 .64336 L p F P
0 g
s
.649 .756 .927 r
.06803 .52219 m .0593 .52524 L .06265 .52811 L p F P
0 g
s
.649 .756 .927 r
.06265 .52811 m .07137 .52506 L .06803 .52219 L p F P
0 g
s
.651 .758 .928 r
.79122 .5288 m .80126 .52571 L .80339 .52855 L p F P
0 g
s
.651 .758 .928 r
.80126 .52571 m .79122 .5288 L .78907 .52596 L p F P
0 g
s
.65 .757 .928 r
.35316 .52291 m .34391 .526 L .3468 .52885 L p F P
0 g
s
.65 .757 .928 r
.3468 .52885 m .35604 .52577 L .35316 .52291 L p F P
0 g
s
.651 .757 .928 r
.65047 .52293 m .64069 .52602 L .64308 .52886 L p F P
0 g
s
.651 .757 .928 r
.64308 .52886 m .65286 .52578 L .65047 .52293 L p F P
0 g
s
.633 .299 .387 r
.52614 .67386 m .52691 .67383 L .52784 .67021 L p F P
0 g
s
.651 .757 .928 r
.50182 .52294 m .4923 .52603 L .49494 .52887 L p F P
0 g
s
.651 .757 .928 r
.49494 .52887 m .50445 .52579 L .50182 .52294 L p F P
0 g
s
.464 .846 .624 r
.44881 .65472 m .45571 .64947 L p .4533 .65125 L F P
0 g
s
.464 .846 .624 r
.4533 .65125 m .44794 .65528 L .44881 .65472 L p F P
0 g
s
0 0 .549 r
.6336 .68832 m .63155 .6857 L .62911 .68174 L p F P
0 g
s
0 0 0 r
.48532 .69543 m .48599 .6938 L .48398 .69663 L closepath p F P
0 g
s
.735 .879 .471 r
.41295 .69707 m .41457 .69354 L .41135 .69905 L p F P
0 g
s
.735 .879 .471 r
.41135 .69905 m .41093 .69996 L .41295 .69707 L p F P
0 g
s
.056 .241 .737 r
.40704 .75583 m .40827 .75669 L .40805 .75349 L p F P
0 g
s
.056 .241 .737 r
.40805 .75349 m .40438 .74993 L .40704 .75583 L p F P
0 g
s
0 0 .532 r
.40437 .74991 m .40438 .74993 L .40704 .75583 L p F P
0 g
s
.42 0 0 r
.57965 .63943 m .58247 .64113 L .57824 .63899 L p F P
0 g
s
.42 0 0 r
.57824 .63899 m .57718 .63838 L .57965 .63943 L p F P
0 g
s
.372 0 0 r
.57263 .63612 m .57718 .63838 L .57965 .63943 L p F P
0 g
s
.366 .053 .296 r
.50506 .67669 m .50508 .6766 L .50478 .6768 L closepath p F P
0 g
s
.83 .921 .896 r
.4405 .75401 m .43112 .76088 L .43388 .76267 L p F P
0 g
s
.83 .921 .896 r
.43388 .76267 m .44045 .75727 L .4405 .75401 L p F P
0 g
s
.685 .844 .959 r
.42755 .76234 m .43112 .76088 L .43388 .76267 L p F P
0 g
s
.65 .757 .928 r
.21664 .52258 m .20764 .52566 L .21075 .52851 L p F P
0 g
s
.65 .757 .928 r
.21075 .52851 m .21974 .52544 L .21664 .52258 L p F P
0 g
s
.651 .758 .928 r
.80339 .52855 m .81345 .52546 L .81556 .52831 L p F P
0 g
s
.651 .758 .928 r
.81345 .52546 m .80339 .52855 L .80126 .52571 L p F P
0 g
s
.514 .186 .348 r
.50506 .67669 m .50508 .6766 L .50538 .67662 L closepath p F P
0 g
s
0 .135 .632 r
.61167 .66249 m .61217 .66289 L .60959 .66031 L p F P
0 g
s
0 .135 .632 r
.60959 .66031 m .60923 .66001 L .61167 .66249 L p F P
0 g
s
.625 .905 .606 r
.43253 .67001 m .43638 .66542 L .43046 .67173 L p F P
0 g
s
.625 .905 .606 r
.42969 .6731 m .43253 .67001 L p .43046 .67173 L F P
0 g
s
.649 .756 .927 r
.08013 .52201 m .07137 .52506 L .07471 .52793 L p F P
0 g
s
.649 .756 .927 r
.07471 .52793 m .08346 .52488 L .08013 .52201 L p F P
0 g
s
.65 .757 .928 r
.36531 .52268 m .35604 .52577 L .3589 .52862 L p F P
0 g
s
.65 .757 .928 r
.3589 .52862 m .36817 .52554 L .36531 .52268 L p F P
0 g
s
.651 .757 .928 r
.66266 .52269 m .65286 .52578 L .65523 .52863 L p F P
0 g
s
.651 .757 .928 r
.65523 .52863 m .66503 .52554 L .66266 .52269 L p F P
0 g
s
.651 .757 .928 r
.51399 .5227 m .50445 .52579 L .50707 .52864 L p F P
0 g
s
.651 .757 .928 r
.50707 .52864 m .5166 .52556 L .51399 .5227 L p F P
0 g
s
.522 .854 .574 r
.4364 .66539 m .44392 .65861 L .43902 .66324 L closepath p F P
0 g
s
.589 .889 .598 r
.43638 .66542 m .4364 .66539 L .43902 .66324 L p F P
0 g
s
.512 .18 .342 r
.50404 .68029 m .50506 .67669 L .50538 .67662 L p F P
0 g
s
.894 .939 .835 r
.4434 .75497 m .44719 .75071 L .44691 .74754 L p F P
0 g
s
.349 .497 .865 r
.61095 .7574 m .61601 .75865 L .61353 .75488 L p F P
0 g
s
.349 .497 .865 r
.61353 .75488 m .61143 .75413 L .61095 .7574 L p F P
0 g
s
.512 .18 .342 r
.50538 .67662 m .51459 .67703 L p .50404 .68029 L F P
0 g
s
.515 .197 .365 r
.51459 .67703 m .50538 .67662 L .5152 .67449 L closepath p F P
0 g
s
.65 .757 .928 r
.22877 .52236 m .21974 .52544 L .22284 .52829 L p F P
0 g
s
.65 .757 .928 r
.22284 .52829 m .23186 .52522 L .22877 .52236 L p F P
0 g
s
.651 .758 .928 r
.81556 .52831 m .82564 .52521 L .82773 .52806 L p F P
0 g
s
.651 .758 .928 r
.82564 .52521 m .81556 .52831 L .81345 .52546 L p F P
0 g
s
.833 .847 .385 r
.64894 .7428 m .64876 .74385 L .64691 .74907 L p F P
0 g
s
.686 .905 .559 r
.46571 .72363 m .46185 .72936 L .46298 .72574 L p F P
0 g
s
.686 .905 .559 r
.46721 .72047 m .46571 .72363 L p .46298 .72574 L F P
0 g
s
.841 .434 .271 r
.55537 .68325 m .55077 .68126 L .5527 .6853 L p F P
0 g
s
.841 .434 .271 r
.55622 .68528 m .55537 .68325 L p .5527 .6853 L F P
0 g
s
.65 .757 .928 r
.37746 .52244 m .36817 .52554 L .37101 .52838 L p F P
0 g
s
.65 .757 .928 r
.37101 .52838 m .3803 .5253 L .37746 .52244 L p F P
0 g
s
.651 .758 .928 r
.67486 .52244 m .66503 .52554 L .66738 .52839 L p F P
0 g
s
.651 .758 .928 r
.66738 .52839 m .6772 .5253 L .67486 .52244 L p F P
0 g
s
.305 0 0 r
.57263 .63612 m .56776 .63416 L .57344 .637 L p F P
0 g
s
.305 0 0 r
.57718 .63838 m .57263 .63612 L p .57344 .637 L F P
0 g
s
.625 .905 .606 r
.43046 .67173 m .42836 .67421 L .42969 .6731 L p F P
0 g
s
.718 .942 .632 r
.42836 .67421 m .42969 .6731 L .42706 .67618 L closepath p F P
0 g
s
.651 .757 .928 r
.52616 .52246 m .5166 .52556 L .5192 .5284 L p F P
0 g
s
.651 .757 .928 r
.5192 .5284 m .52875 .52532 L .52616 .52246 L p F P
0 g
s
.792 .917 .923 r
.4434 .75497 m .44045 .75727 L .4405 .75401 L p F P
0 g
s
.649 .756 .927 r
.09223 .52182 m .08346 .52488 L .08677 .52774 L p F P
0 g
s
.649 .756 .927 r
.08677 .52774 m .09554 .52469 L .09223 .52182 L p F P
0 g
s
0 0 .155 r
.64777 .72053 m .6482 .7236 L .64897 .72807 L p F P
0 g
s
0 0 .305 r
.6482 .7236 m .64777 .72053 L .64649 .71621 L p F P
0 g
s
.82 .797 .302 r
.4048 .71686 m .405 .71538 L .40382 .71909 L p F P
0 g
s
.82 .797 .302 r
.40382 .71909 m .40347 .72183 L .4048 .71686 L p F P
0 g
s
0 0 0 r
.48398 .69663 m .48532 .69543 L .48396 .69877 L p F P
0 g
s
0 0 0 r
.48396 .69877 m .47986 .70241 L .48398 .69663 L p F P
0 g
s
.464 .846 .624 r
.45571 .64947 m .45763 .64804 L p .4533 .65125 L F P
0 g
s
.473 .855 .639 r
.45763 .64804 m .45832 .64761 L .45571 .64947 L closepath p F P
0 g
s
0 .07 .589 r
.61818 .66905 m .61587 .6664 L .61217 .66289 L p F P
0 g
s
0 .037 .538 r
.61217 .66289 m .60959 .66031 L .6133 .66382 L p F P
0 g
s
0 .037 .538 r
.6133 .66382 m .61587 .6664 L .61217 .66289 L p F P
0 g
s
.651 .758 .928 r
.83784 .52496 m .82773 .52806 L .82564 .52521 L p F P
0 g
s
.651 .758 .928 r
.82773 .52806 m .83784 .52496 L .83991 .5278 L p F P
0 g
s
.65 .757 .928 r
.24091 .52213 m .23186 .52522 L .23493 .52807 L p F P
0 g
s
.65 .757 .928 r
.23493 .52807 m .24397 .52499 L .24091 .52213 L p F P
0 g
s
.894 .939 .835 r
.44691 .74754 m .44064 .75391 L .4434 .75497 L p F P
0 g
s
.792 .917 .923 r
.4405 .75401 m .44064 .75391 L .4434 .75497 L p F P
0 g
s
.651 .758 .928 r
.68706 .5222 m .6772 .5253 L .67954 .52815 L p F P
0 g
s
.651 .758 .928 r
.67954 .52815 m .68938 .52506 L .68706 .5222 L p F P
0 g
s
.65 .757 .928 r
.38962 .52221 m .3803 .5253 L .38313 .52815 L p F P
0 g
s
.65 .757 .928 r
.38313 .52815 m .39244 .52507 L .38962 .52221 L p F P
0 g
s
.651 .757 .928 r
.53834 .52222 m .52875 .52532 L .53133 .52816 L p F P
0 g
s
.651 .757 .928 r
.53133 .52816 m .54091 .52508 L .53834 .52222 L p F P
0 g
s
.649 .756 .927 r
.10435 .52162 m .09554 .52469 L .09884 .52755 L p F P
0 g
s
.649 .756 .927 r
.09884 .52755 m .10764 .52449 L .10435 .52162 L p F P
0 g
s
0 0 .487 r
.40265 .74356 m .40265 .74251 L .40442 .74662 L p F P
0 g
s
0 0 .487 r
.40442 .74662 m .40437 .7499 L .40265 .74356 L p F P
0 g
s
0 0 0 r
.40239 .73007 m .40265 .72666 L .40246 .73133 L p F P
0 g
s
0 0 0 r
.40246 .73133 m .40219 .73472 L .40239 .73007 L p F P
0 g
s
0 0 0 r
.47731 .63706 m .47926 .63579 L .48838 .63253 L p F P
0 g
s
0 0 0 r
.47926 .63579 m .47731 .63706 L .4697 .64072 L p F P
0 g
s
.636 .882 .538 r
.42706 .67618 m .42229 .68214 L .42511 .67788 L p F P
0 g
s
.636 .882 .538 r
.42836 .67421 m .42706 .67618 L p .42511 .67788 L F P
0 g
s
0 0 0 r
.46805 .64151 m .46782 .64168 L .45832 .64761 L p F P
0 g
s
.375 .796 .601 r
.45763 .64804 m .45832 .64761 L .46782 .64168 L p F P
0 g
s
.651 .758 .928 r
.83991 .5278 m .85004 .5247 L .85209 .52755 L p F P
0 g
s
.651 .758 .928 r
.85004 .5247 m .83991 .5278 L .83784 .52496 L p F P
0 g
s
.692 .845 .957 r
.42835 .75901 m .41895 .76217 L .42171 .76481 L p F P
0 g
s
.692 .845 .957 r
.42903 .75948 m .42835 .75901 L p .42171 .76481 L F P
0 g
s
.692 .845 .957 r
.42171 .76481 m .42755 .76234 L .42903 .75948 L p F P
0 g
s
.485 .687 .957 r
.41717 .76205 m .41895 .76217 L .42171 .76481 L p F P
0 g
s
.65 .757 .928 r
.25304 .5219 m .24397 .52499 L .24702 .52784 L p F P
0 g
s
.65 .757 .928 r
.24702 .52784 m .25609 .52476 L .25304 .5219 L p F P
0 g
s
0 .156 .588 r
.59309 .6475 m .5944 .64839 L .59494 .64876 L closepath p F P
0 g
s
0 .305 .72 r
.59138 .64643 m .59309 .6475 L .5944 .64839 L p F P
0 g
s
.651 .758 .928 r
.69926 .52196 m .68938 .52506 L .69169 .52791 L p F P
0 g
s
.651 .758 .928 r
.69169 .52791 m .70156 .52482 L .69926 .52196 L p F P
0 g
s
.65 .757 .928 r
.40178 .52197 m .39244 .52507 L .39524 .52791 L p F P
0 g
s
.65 .757 .928 r
.39524 .52791 m .40458 .52483 L .40178 .52197 L p F P
0 g
s
.651 .757 .928 r
.55052 .52198 m .54091 .52508 L .54347 .52793 L p F P
0 g
s
.651 .757 .928 r
.54347 .52793 m .55307 .52484 L .55052 .52198 L p F P
0 g
s
.572 .659 .897 r
.62376 .76174 m .61848 .76227 L .61601 .75865 L p F P
0 g
s
.356 .476 .844 r
.60458 .74816 m .60117 .74681 L .59865 .742 L p F P
0 g
s
.649 .756 .927 r
.11646 .52142 m .10764 .52449 L .11091 .52736 L p F P
0 g
s
.649 .756 .927 r
.11091 .52736 m .11973 .5243 L .11646 .52142 L p F P
0 g
s
.265 .517 .906 r
.40827 .75669 m .40805 .75349 L p .41548 .75843 L F P
0 g
s
.265 .517 .906 r
.41548 .75843 m .41576 .7592 L .40827 .75669 L p F P
0 g
s
.736 .835 .384 r
.41004 .70282 m .40761 .70811 L .40877 .70439 L p F P
0 g
s
.736 .835 .384 r
.41093 .69996 m .41004 .70282 L p .40877 .70439 L F P
0 g
s
.65 .757 .928 r
.26519 .52167 m .25609 .52476 L .25912 .52762 L p F P
0 g
s
.65 .757 .928 r
.25912 .52762 m .26821 .52454 L .26519 .52167 L p F P
0 g
s
.849 .411 .179 r
.56159 .68935 m .55742 .68725 L .55978 .69118 L p F P
0 g
s
.849 .411 .179 r
.55978 .69118 m .56374 .69334 L .56159 .68935 L p F P
0 g
s
.651 .758 .928 r
.71146 .52172 m .70156 .52482 L .70385 .52766 L p F P
0 g
s
.651 .758 .928 r
.70385 .52766 m .71374 .52457 L .71146 .52172 L p F P
0 g
s
.65 .757 .928 r
.41394 .52174 m .40458 .52483 L .40736 .52768 L p F P
0 g
s
.65 .757 .928 r
.40736 .52768 m .41672 .5246 L .41394 .52174 L p F P
0 g
s
.651 .757 .928 r
.5627 .52174 m .55307 .52484 L .55561 .52769 L p F P
0 g
s
.651 .757 .928 r
.55561 .52769 m .56523 .5246 L .5627 .52174 L p F P
0 g
s
0 0 .482 r
.40438 .74993 m .40437 .74991 L .40437 .7499 L closepath p F P
0 g
s
.007 .227 .736 r
.40438 .74993 m .40437 .7499 L p .40776 .75029 L F P
0 g
s
.007 .227 .736 r
.40776 .75029 m .40805 .75349 L .40438 .74993 L p F P
0 g
s
.007 .227 .736 r
.40437 .7499 m .40442 .74662 L .40776 .75029 L p F P
0 g
s
0 0 .272 r
.64584 .71319 m .64649 .71621 L .64777 .72053 L p F P
0 g
s
0 0 .386 r
.64649 .71621 m .64584 .71319 L .64412 .709 L p F P
0 g
s
0 .078 .612 r
.62383 .67533 m .62178 .67261 L .61818 .66905 L p F P
0 g
s
0 .045 .566 r
.61587 .6664 m .61818 .66905 L .62178 .67261 L p F P
0 g
s
.649 .756 .927 r
.12858 .52122 m .11973 .5243 L .12299 .52716 L p F P
0 g
s
.649 .756 .927 r
.12299 .52716 m .13183 .52409 L .12858 .52122 L p F P
0 g
s
.493 0 0 r
.59494 .64876 m .59922 .65206 L .59576 .6497 L p F P
0 g
s
.493 0 0 r
.59309 .6475 m .59494 .64876 L p .59576 .6497 L F P
0 g
s
.65 .757 .928 r
.27733 .52144 m .26821 .52454 L .27122 .52739 L p F P
0 g
s
.65 .757 .928 r
.27122 .52739 m .28034 .52431 L .27733 .52144 L p F P
0 g
s
0 .018 .576 r
.57658 .70933 m .57628 .70883 L p .58106 .71536 L F P
0 g
s
0 0 .555 r
.57658 .70933 m .57612 .70863 L .57628 .70883 L closepath p F P
0 g
s
.749 .384 .362 r
.54285 .67566 m .54069 .67526 L .53939 .6785 L p F P
0 g
s
.749 .384 .362 r
.53939 .6785 m .54512 .67958 L .54285 .67566 L p F P
0 g
s
.651 .758 .928 r
.72367 .52147 m .71374 .52457 L .71602 .52742 L p F P
0 g
s
.651 .758 .928 r
.71602 .52742 m .72593 .52433 L .72367 .52147 L p F P
0 g
s
.65 .757 .928 r
.42611 .5215 m .41672 .5246 L .41949 .52745 L p F P
0 g
s
.65 .757 .928 r
.41949 .52745 m .42887 .52436 L .42611 .5215 L p F P
0 g
s
.651 .757 .928 r
.57489 .52151 m .56523 .5246 L .56775 .52745 L p F P
0 g
s
.651 .757 .928 r
.56775 .52745 m .5774 .52436 L .57489 .52151 L p F P
0 g
s
.65 .756 .928 r
.1407 .52101 m .13183 .52409 L .13507 .52695 L p F P
0 g
s
.65 .756 .928 r
.13507 .52695 m .14394 .52388 L .1407 .52101 L p F P
0 g
s
0 0 0 r
.44597 .65686 m .4533 .65125 L .44794 .65528 L closepath p F P
0 g
s
0 0 0 r
.45174 .65278 m .44543 .6573 L p .44597 .65686 L F P
0 g
s
.506 .852 .586 r
.44531 .65738 m .44597 .65686 L .44392 .65861 L closepath p F P
0 g
s
0 0 0 r
.44543 .6573 m .44531 .65738 L .44597 .65686 L p F P
0 g
s
.574 .903 .659 r
.44597 .65686 m .44392 .65861 L p .44722 .65588 L F P
0 g
s
.574 .903 .659 r
.44794 .65528 m .44597 .65686 L p .44722 .65588 L F P
0 g
s
.898 .987 .76 r
.46185 .72936 m .46298 .72574 L .45844 .73168 L p F P
0 g
s
.898 .987 .76 r
.45986 .73234 m .46185 .72936 L p .45844 .73168 L F P
0 g
s
0 0 0 r
.47986 .70241 m .48396 .69877 L p .48078 .70341 L F P
0 g
s
0 0 0 r
.47637 .70732 m .47986 .70241 L p .48078 .70341 L F P
0 g
s
.864 .416 .094 r
.56707 .69567 m .56374 .69334 L .56589 .69734 L p F P
0 g
s
.864 .416 .094 r
.56589 .69734 m .56912 .6997 L .56707 .69567 L p F P
0 g
s
.65 .757 .928 r
.28948 .52121 m .28034 .52431 L .28333 .52716 L p F P
0 g
s
.65 .757 .928 r
.28333 .52716 m .29246 .52408 L .28948 .52121 L p F P
0 g
s
.928 .859 .424 r
.64888 .74067 m .64894 .7428 L .64749 .74579 L p F P
0 g
s
.833 .847 .385 r
.64691 .74907 m .64749 .74579 L .64894 .7428 L p F P
0 g
s
.828 .715 .183 r
.64894 .7428 m .64888 .74067 L .64939 .73582 L p F P
0 g
s
.651 .758 .928 r
.73588 .52123 m .72593 .52433 L .72819 .52718 L p F P
0 g
s
.651 .758 .928 r
.72819 .52718 m .73812 .52409 L .73588 .52123 L p F P
0 g
s
.65 .757 .928 r
.43828 .52126 m .42887 .52436 L .43161 .52721 L p F P
0 g
s
.65 .757 .928 r
.43161 .52721 m .44102 .52412 L .43828 .52126 L p F P
0 g
s
.651 .757 .928 r
.58708 .52127 m .5774 .52436 L .5799 .52721 L p F P
0 g
s
.651 .757 .928 r
.5799 .52721 m .58957 .52413 L .58708 .52127 L p F P
0 g
s
.67 .895 .544 r
.42229 .68214 m .42511 .67788 L .42066 .68376 L p F P
0 g
s
.67 .895 .544 r
.42004 .68517 m .42229 .68214 L p .42066 .68376 L F P
0 g
s
0 .036 .573 r
.62383 .67533 m .62665 .67828 L .6242 .67516 L p F P
0 g
s
0 .036 .573 r
.6242 .67516 m .62178 .67261 L .62383 .67533 L p F P
0 g
s
0 0 .353 r
.64324 .70603 m .64412 .709 L .64584 .71319 L p F P
0 g
s
0 0 .441 r
.64412 .709 m .64324 .70603 L .64115 .70196 L p F P
0 g
s
.65 .757 .928 r
.15283 .5208 m .14394 .52388 L .14716 .52674 L p F P
0 g
s
.65 .757 .928 r
.14716 .52674 m .15604 .52367 L .15283 .5208 L p F P
0 g
s
.559 .089 0 r
.57628 .70883 m .57612 .70863 L .57361 .70562 L p F P
0 g
s
.735 .367 .355 r
.54069 .67526 m .53562 .67443 L .53807 .67829 L p F P
0 g
s
.735 .367 .355 r
.53807 .67829 m .53939 .6785 L .54069 .67526 L p F P
0 g
s
.849 .397 0 r
.57361 .70562 m .57187 .7022 L .56912 .6997 L p F P
0 g
s
.65 .757 .928 r
.30163 .52098 m .29246 .52408 L .29544 .52693 L p F P
0 g
s
.65 .757 .928 r
.29544 .52693 m .3046 .52385 L .30163 .52098 L p F P
0 g
s
.651 .758 .928 r
.74809 .52098 m .73812 .52409 L .74036 .52694 L p F P
0 g
s
.651 .758 .928 r
.74036 .52694 m .75032 .52384 L .74809 .52098 L p F P
0 g
s
.125 0 .103 r
.48532 .69543 m .493 .69086 L p .48699 .69699 L F P
0 g
s
.125 0 .103 r
.48699 .69699 m .48396 .69877 L .48532 .69543 L p F P
0 g
s
.018 0 .054 r
.49411 .6873 m .493 .69086 L .48532 .69543 L p F P
0 g
s
.651 .757 .928 r
.45045 .52103 m .44102 .52412 L .44374 .52697 L p F P
0 g
s
.651 .757 .928 r
.44374 .52697 m .45317 .52389 L .45045 .52103 L p F P
0 g
s
.651 .757 .928 r
.59927 .52103 m .58957 .52413 L .59205 .52698 L p F P
0 g
s
.651 .757 .928 r
.59205 .52698 m .60174 .52389 L .59927 .52103 L p F P
0 g
s
.809 .385 .238 r
.55499 .68632 m .55622 .68528 L .55742 .68725 L closepath p F P
0 g
s
.841 .434 .271 r
.5527 .6853 m .55499 .68632 L .55622 .68528 L p F P
0 g
s
.879 .749 .241 r
.64916 .73272 m .64939 .73582 L .64888 .74067 L p F P
0 g
s
.742 .576 .001 r
.64939 .73582 m .64916 .73272 L .64897 .72807 L p F P
0 g
s
0 0 0 r
.46782 .64168 m .4697 .64072 L .46805 .64151 L closepath p F P
0 g
s
0 .018 .576 r
.57628 .70883 m .57933 .71261 L .58106 .71536 L p F P
0 g
s
.591 .117 0 r
.57407 .7062 m .57628 .70883 L .57933 .71261 L p F P
0 g
s
.559 .089 0 r
.57361 .70562 m .57407 .7062 L .57628 .70883 L p F P
0 g
s
0 0 .489 r
.40265 .74251 m .40281 .73916 L .40446 .74331 L p F P
0 g
s
0 0 .489 r
.40446 .74331 m .40442 .74662 L .40265 .74251 L p F P
0 g
s
.65 .757 .928 r
.16496 .52059 m .15604 .52367 L .15924 .52653 L p F P
0 g
s
.65 .757 .928 r
.15924 .52653 m .16816 .52346 L .16496 .52059 L p F P
0 g
s
.692 .825 .946 r
.63401 .76205 m .63068 .76376 L .62827 .76135 L p F P
0 g
s
0 0 .407 r
.64002 .69904 m .64115 .70196 L .64324 .70603 L p F P
0 g
s
0 0 .479 r
.64115 .70196 m .64002 .69904 L .63763 .69507 L p F P
0 g
s
.651 .758 .928 r
.76031 .52074 m .75032 .52384 L .75253 .52669 L p F P
0 g
s
.651 .758 .928 r
.75253 .52669 m .76251 .5236 L .76031 .52074 L p F P
0 g
s
.65 .757 .928 r
.31379 .52075 m .3046 .52385 L .30755 .5267 L p F P
0 g
s
.65 .757 .928 r
.30755 .5267 m .31673 .52361 L .31379 .52075 L p F P
0 g
s
0 0 .549 r
.62911 .68174 m .6291 .68171 L p .6336 .68832 L F P
0 g
s
0 .07 .622 r
.62911 .68174 m .62909 .6817 L .6291 .68171 L closepath p F P
0 g
s
.651 .757 .928 r
.61147 .52079 m .60174 .52389 L .60421 .52674 L p F P
0 g
s
.651 .757 .928 r
.60421 .52674 m .61392 .52365 L .61147 .52079 L p F P
0 g
s
.651 .757 .928 r
.46263 .52079 m .45317 .52389 L .45588 .52674 L p F P
0 g
s
.651 .757 .928 r
.45588 .52674 m .46533 .52365 L .46263 .52079 L p F P
0 g
s
0 0 0 r
.45551 .64966 m .45763 .64804 L .46534 .64345 L p F P
0 g
s
.375 .796 .601 r
.46782 .64168 m .46534 .64345 L .45763 .64804 L p F P
0 g
s
.464 .846 .624 r
.45763 .64804 m .45551 .64966 L .4533 .65125 L p F P
0 g
s
0 .041 .588 r
.6291 .68171 m .62909 .6817 L .62665 .67828 L p F P
0 g
s
0 0 .549 r
.6291 .68171 m .63199 .68551 L .6336 .68832 L p F P
0 g
s
0 0 .474 r
.62725 .67895 m .6291 .68171 L .63199 .68551 L p F P
0 g
s
0 .041 .588 r
.62665 .67828 m .62725 .67895 L .6291 .68171 L p F P
0 g
s
.927 .973 .738 r
.64749 .74579 m .64691 .74907 L .64341 .75476 L p F P
0 g
s
.703 .741 .232 r
.405 .71538 m .40558 .71328 L .40404 .71832 L p F P
0 g
s
.703 .741 .232 r
.40404 .71832 m .40382 .71909 L .405 .71538 L p F P
0 g
s
0 .028 .593 r
.58551 .72199 m .58414 .71914 L .58106 .71536 L p F P
0 g
s
0 0 .478 r
.57933 .71261 m .58106 .71536 L .58414 .71914 L p F P
0 g
s
.67 .895 .544 r
.42066 .68376 m .4189 .68638 L .42004 .68517 L p F P
0 g
s
.758 .928 .572 r
.4189 .68638 m .42004 .68517 L .41811 .68793 L closepath p F P
0 g
s
.898 .987 .76 r
.45844 .73168 m .45815 .73303 L .45986 .73234 L p F P
0 g
s
.872 .994 .771 r
.45815 .73303 m .45986 .73234 L .45746 .73525 L closepath p F P
0 g
s
.65 .757 .928 r
.1771 .52037 m .16816 .52346 L .17134 .52632 L p F P
0 g
s
.65 .757 .928 r
.17134 .52632 m .18027 .52324 L .1771 .52037 L p F P
0 g
s
0 0 .441 r
.63626 .6922 m .63763 .69507 L .64002 .69904 L p F P
0 g
s
0 0 .503 r
.63763 .69507 m .63626 .6922 L .6336 .68832 L p F P
0 g
s
0 0 .461 r
.63199 .68551 m .6336 .68832 L .63626 .6922 L p F P
0 g
s
0 .09 .648 r
.5898 .72866 m .58873 .72575 L .58551 .72199 L p F P
0 g
s
0 0 .548 r
.58414 .71914 m .58551 .72199 L .58873 .72575 L p F P
0 g
s
.473 0 0 r
.58247 .64113 m .57824 .63899 L .58311 .64209 L p F P
0 g
s
.473 0 0 r
.58311 .64209 m .5874 .64422 L .58247 .64113 L p F P
0 g
s
.651 .758 .928 r
.76471 .52645 m .77471 .52335 L .77689 .5262 L p F P
0 g
s
.651 .758 .928 r
.77253 .52049 m .76251 .5236 L .76471 .52645 L p F P
0 g
s
.651 .758 .928 r
.76471 .52645 m .77471 .52335 L .77253 .52049 L p F P
0 g
s
0 0 0 r
.46782 .64168 m .4697 .64072 L p .46763 .64238 L F P
0 g
s
0 0 0 r
.46763 .64238 m .46534 .64345 L .46782 .64168 L p F P
0 g
s
.65 .757 .928 r
.32595 .52052 m .31673 .52361 L .31967 .52647 L p F P
0 g
s
.65 .757 .928 r
.31967 .52647 m .32887 .52338 L .32595 .52052 L p F P
0 g
s
.651 .757 .928 r
.62367 .52054 m .61392 .52365 L .61636 .5265 L p F P
0 g
s
.651 .757 .928 r
.61636 .5265 m .6261 .52341 L .62367 .52054 L p F P
0 g
s
.651 .757 .928 r
.47481 .52055 m .46533 .52365 L .46801 .5265 L p F P
0 g
s
.651 .757 .928 r
.46801 .5265 m .47749 .52341 L .47481 .52055 L p F P
0 g
s
0 .152 .694 r
.59411 .73533 m .59325 .73237 L .5898 .72866 L p F P
0 g
s
0 .105 .658 r
.58873 .72575 m .5898 .72866 L .59325 .73237 L p F P
0 g
s
.686 .838 .956 r
.42903 .75948 m .43112 .76088 L .42755 .76234 L closepath p F P
0 g
s
.429 0 0 r
.6024 .65449 m .59922 .65206 L .60355 .65537 L p F P
0 g
s
.429 0 0 r
.60355 .65537 m .60675 .65779 L .6024 .65449 L p F P
0 g
s
.046 .284 .776 r
.59613 .73727 m .59411 .73533 L p .59859 .74195 L F P
0 g
s
0 .152 .694 r
.59411 .73533 m .59613 .73727 L .59361 .73277 L p F P
0 g
s
0 .152 .694 r
.59361 .73277 m .59325 .73237 L .59411 .73533 L p F P
0 g
s
.747 .698 .158 r
.40347 .72183 m .40382 .71909 L .40307 .72322 L p F P
0 g
s
.747 .698 .158 r
.40307 .72322 m .40265 .72666 L .40347 .72183 L p F P
0 g
s
0 0 0 r
.48078 .70341 m .47609 .70777 L .47637 .70732 L p F P
0 g
s
0 0 0 r
.47609 .70777 m .47637 .70732 L .47574 .70821 L closepath p F P
0 g
s
.65 .757 .928 r
.18924 .52015 m .18027 .52324 L .18343 .5261 L p F P
0 g
s
.65 .757 .928 r
.18343 .5261 m .19239 .52302 L .18924 .52015 L p F P
0 g
s
.831 .998 .781 r
.45746 .73525 m .45263 .74126 L .45304 .73787 L p F P
0 g
s
.831 .998 .781 r
.45815 .73303 m .45746 .73525 L p .45304 .73787 L F P
0 g
s
.459 0 0 r
.56776 .63416 m .56253 .6323 L .56809 .63518 L p F P
0 g
s
.459 0 0 r
.56809 .63518 m .57344 .637 L .56776 .63416 L p F P
0 g
s
.651 .758 .928 r
.77689 .5262 m .78692 .5231 L .78907 .52596 L p F P
0 g
s
.651 .758 .928 r
.78692 .5231 m .77689 .5262 L .77471 .52335 L p F P
0 g
s
.65 .757 .928 r
.33811 .52028 m .32887 .52338 L .33179 .52624 L p F P
0 g
s
.65 .757 .928 r
.33179 .52624 m .34101 .52315 L .33811 .52028 L p F P
0 g
s
.048 .286 .777 r
.59865 .742 m .59859 .74195 L .59857 .74186 L closepath p F P
0 g
s
.046 .284 .776 r
.59859 .74195 m .59857 .74186 L .59613 .73727 L p F P
0 g
s
.651 .757 .928 r
.63588 .5203 m .6261 .52341 L .62852 .52626 L p F P
0 g
s
.651 .757 .928 r
.62852 .52626 m .63829 .52317 L .63588 .5203 L p F P
0 g
s
.651 .757 .928 r
.48699 .52031 m .47749 .52341 L .48015 .52627 L p F P
0 g
s
.651 .757 .928 r
.48015 .52627 m .48965 .52318 L .48699 .52031 L p F P
0 g
s
.811 .427 .329 r
.55077 .68126 m .54512 .67958 L .54739 .68351 L p F P
0 g
s
.811 .427 .329 r
.54739 .68351 m .5527 .6853 L .55077 .68126 L p F P
0 g
s
0 0 0 r
.47574 .70821 m .47609 .70777 L .47427 .71072 L p F P
0 g
s
0 0 0 r
.47427 .71072 m .4716 .71401 L .47574 .70821 L p F P
0 g
s
.356 .476 .844 r
.59865 .742 m .60464 .74497 L .60458 .74816 L p F P
0 g
s
.287 .439 .84 r
.60464 .74497 m .59865 .742 L .59857 .74186 L p F P
0 g
s
.591 .267 .388 r
.5152 .67449 m .52614 .67386 L p .51621 .67799 L F P
0 g
s
.591 .267 .388 r
.51621 .67799 m .51459 .67703 L .5152 .67449 L p F P
0 g
s
.287 .439 .84 r
.59857 .74186 m .59872 .73873 L p .60464 .74497 L F P
0 g
s
.241 .411 .831 r
.59857 .74186 m .59613 .73727 L .59872 .73873 L closepath p F P
0 g
s
.493 0 0 r
.59576 .6497 m .59195 .6468 L .59309 .6475 L p F P
0 g
s
.419 0 0 r
.59195 .6468 m .59138 .64643 L .59309 .6475 L closepath p F P
0 g
s
.675 .864 .47 r
.41811 .68793 m .41457 .69354 L .41659 .68953 L p F P
0 g
s
.675 .864 .47 r
.4189 .68638 m .41811 .68793 L p .41659 .68953 L F P
0 g
s
.692 .825 .946 r
.62827 .76135 m .63442 .75882 L .63401 .76205 L p F P
0 g
s
.754 .927 .946 r
.63799 .7572 m .63442 .75882 L .63401 .76205 L p F P
0 g
s
.754 .927 .946 r
.63401 .76205 m .64035 .75828 L .63799 .7572 L p F P
0 g
s
.433 .652 .951 r
.41895 .76217 m .41717 .76205 L .41576 .7592 L p F P
0 g
s
.66 .322 .389 r
.53562 .67443 m .53807 .67829 L .52944 .67747 L p F P
0 g
s
.66 .322 .389 r
.52691 .67383 m .53562 .67443 L p .52944 .67747 L F P
0 g
s
0 0 0 r
.4697 .64072 m .47647 .63759 L p .46763 .64238 L F P
0 g
s
0 0 0 r
.47647 .63759 m .47731 .63706 L .4697 .64072 L closepath p F P
0 g
s
.65 .757 .928 r
.20138 .51993 m .19239 .52302 L .19553 .52588 L p F P
0 g
s
.65 .757 .928 r
.19553 .52588 m .20451 .5228 L .20138 .51993 L p F P
0 g
s
.731 .799 .32 r
.40761 .70811 m .40877 .70439 L .40678 .70956 L p F P
0 g
s
.731 .799 .32 r
.40678 .70956 m .40558 .71328 L .40761 .70811 L p F P
0 g
s
.649 .755 .927 r
.06467 .5193 m .05593 .52237 L .0593 .52524 L p F P
0 g
s
.649 .755 .927 r
.0593 .52524 m .06803 .52219 L .06467 .5193 L p F P
0 g
s
.651 .758 .928 r
.78907 .52596 m .79912 .52286 L .80126 .52571 L p F P
0 g
s
.651 .758 .928 r
.79912 .52286 m .78907 .52596 L .78692 .5231 L p F P
0 g
s
.65 .757 .928 r
.35027 .52005 m .34101 .52315 L .34391 .526 L p F P
0 g
s
.65 .757 .928 r
.34391 .526 m .35316 .52291 L .35027 .52005 L p F P
0 g
s
.651 .757 .928 r
.64808 .52006 m .63829 .52317 L .64069 .52602 L p F P
0 g
s
.651 .757 .928 r
.64069 .52602 m .65047 .52293 L .64808 .52006 L p F P
0 g
s
.651 .757 .928 r
.49918 .52007 m .48965 .52318 L .4923 .52603 L p F P
0 g
s
.651 .757 .928 r
.4923 .52603 m .50182 .52294 L .49918 .52007 L p F P
0 g
s
.574 .851 .515 r
.42678 .67586 m .43046 .67173 L .42836 .67421 L closepath p F P
0 g
s
.636 .882 .538 r
.42511 .67788 m .42678 .67586 L .42836 .67421 L p F P
0 g
s
.65 .757 .928 r
.21353 .51971 m .20451 .5228 L .20764 .52566 L p F P
0 g
s
.65 .757 .928 r
.20764 .52566 m .21664 .52258 L .21353 .51971 L p F P
0 g
s
.651 .758 .928 r
.80126 .52571 m .81133 .52261 L .81345 .52546 L p F P
0 g
s
.651 .758 .928 r
.81133 .52261 m .80126 .52571 L .79912 .52286 L p F P
0 g
s
0 0 .155 r
.64897 .72807 m .64856 .725 L .64777 .72053 L p F P
0 g
s
.792 .607 .044 r
.64856 .725 m .64897 .72807 L .64916 .73272 L p F P
0 g
s
.649 .756 .927 r
.07679 .51912 m .06803 .52219 L .07137 .52506 L p F P
0 g
s
.649 .756 .927 r
.07137 .52506 m .08013 .52201 L .07679 .51912 L p F P
0 g
s
.65 .757 .928 r
.36244 .51981 m .35316 .52291 L .35604 .52577 L p F P
0 g
s
.65 .757 .928 r
.35604 .52577 m .36531 .52268 L .36244 .51981 L p F P
0 g
s
.651 .757 .928 r
.66029 .51982 m .65047 .52293 L .65286 .52578 L p F P
0 g
s
.651 .757 .928 r
.65286 .52578 m .66266 .52269 L .66029 .51982 L p F P
0 g
s
.651 .757 .928 r
.51137 .51983 m .50182 .52294 L .50445 .52579 L p F P
0 g
s
.651 .757 .928 r
.50445 .52579 m .51399 .5227 L .51137 .51983 L p F P
0 g
s
.496 .656 .931 r
.62376 .76174 m .62827 .76135 L .62583 .75864 L p F P
0 g
s
.496 .656 .931 r
.62583 .75864 m .62378 .7586 L .62376 .76174 L p F P
0 g
s
.572 .659 .897 r
.61601 .75865 m .62378 .7586 L .62376 .76174 L p F P
0 g
s
0 .104 .584 r
.60697 .65798 m .60923 .66001 L .60959 .66031 L closepath p F P
0 g
s
0 .238 .706 r
.60675 .65779 m .60697 .65798 L .60923 .66001 L p F P
0 g
s
0 0 0 r
.47609 .70777 m .48078 .70341 L .47553 .70955 L p F P
0 g
s
0 0 0 r
.47553 .70955 m .47427 .71072 L .47609 .70777 L p F P
0 g
s
0 0 .233 r
.40219 .73472 m .40246 .73133 L .40302 .73578 L p F P
0 g
s
0 0 .233 r
.40302 .73578 m .40281 .73916 L .40219 .73472 L p F P
0 g
s
.4 .5 .845 r
.60458 .74816 m .61105 .75103 L p .61143 .75413 L F P
0 g
s
.241 .418 .838 r
.60458 .74816 m .61105 .75103 L .60855 .74712 L p F P
0 g
s
.241 .418 .838 r
.60855 .74712 m .60464 .74497 L .60458 .74816 L p F P
0 g
s
.529 .63 .895 r
.62378 .7586 m .61601 .75865 L .61353 .75488 L p F P
0 g
s
.65 .757 .928 r
.22568 .51949 m .21664 .52258 L .21974 .52544 L p F P
0 g
s
.65 .757 .928 r
.21974 .52544 m .22877 .52236 L .22568 .51949 L p F P
0 g
s
.651 .758 .928 r
.81345 .52546 m .82355 .52236 L .82564 .52521 L p F P
0 g
s
.651 .758 .928 r
.82355 .52236 m .81345 .52546 L .81133 .52261 L p F P
0 g
s
.65 .757 .928 r
.37462 .51958 m .36531 .52268 L .36817 .52554 L p F P
0 g
s
.65 .757 .928 r
.36817 .52554 m .37746 .52244 L .37462 .51958 L p F P
0 g
s
.651 .757 .928 r
.67251 .51958 m .66266 .52269 L .66503 .52554 L p F P
0 g
s
.651 .757 .928 r
.66503 .52554 m .67486 .52244 L .67251 .51958 L p F P
0 g
s
.649 .756 .927 r
.08892 .51894 m .08013 .52201 L .08346 .52488 L p F P
0 g
s
.649 .756 .927 r
.08346 .52488 m .09223 .52182 L .08892 .51894 L p F P
0 g
s
.651 .757 .928 r
.52356 .5196 m .51399 .5227 L .5166 .52556 L p F P
0 g
s
.651 .757 .928 r
.5166 .52556 m .52616 .52246 L .52356 .5196 L p F P
0 g
s
.786 .85 .899 r
.43112 .76088 m .4405 .75401 L p .42872 .75877 L F P
0 g
s
.786 .85 .899 r
.42872 .75877 m .42903 .75948 L .43112 .76088 L p F P
0 g
s
.591 .267 .388 r
.52614 .67386 m .52676 .6744 L p .51621 .67799 L F P
0 g
s
.631 .293 .381 r
.52676 .6744 m .52614 .67386 L .52691 .67383 L closepath p F P
0 g
s
.87 .954 .861 r
.64341 .75476 m .64035 .75828 L .63799 .7572 L p F P
0 g
s
.87 .954 .861 r
.63799 .7572 m .64363 .75156 L .64341 .75476 L p F P
0 g
s
.927 .973 .738 r
.64748 .7458 m .64749 .74579 L p .64341 .75476 L F P
0 g
s
.927 .973 .738 r
.64341 .75476 m .64363 .75156 L .64748 .7458 L p F P
0 g
s
.897 .953 .829 r
.45263 .74126 m .45304 .73787 L .44756 .74408 L p F P
0 g
s
.897 .953 .829 r
.45023 .74433 m .45263 .74126 L p .44756 .74408 L F P
0 g
s
.66 .322 .389 r
.52944 .67747 m .52676 .6744 L .52691 .67383 L p F P
0 g
s
.368 .04 .271 r
.49411 .6873 m .50303 .68391 L p .49593 .68977 L F P
0 g
s
.368 .04 .271 r
.49593 .68977 m .493 .69086 L .49411 .6873 L p F P
0 g
s
.352 .026 .265 r
.50404 .68029 m .50303 .68391 L .49411 .6873 L p F P
0 g
s
.522 0 0 r
.60959 .66031 m .6133 .66382 L .61046 .6613 L p F P
0 g
s
.522 0 0 r
.60697 .65798 m .60959 .66031 L p .61046 .6613 L F P
0 g
s
.791 .355 .215 r
.55742 .68725 m .55978 .69118 L .55501 .68924 L p F P
0 g
s
.791 .355 .215 r
.55499 .68632 m .55742 .68725 L p .55501 .68924 L F P
0 g
s
.651 .758 .928 r
.82564 .52521 m .83576 .5221 L .83784 .52496 L p F P
0 g
s
.651 .758 .928 r
.83576 .5221 m .82564 .52521 L .82355 .52236 L p F P
0 g
s
.65 .757 .928 r
.23783 .51926 m .22877 .52236 L .23186 .52522 L p F P
0 g
s
.65 .757 .928 r
.23186 .52522 m .24091 .52213 L .23783 .51926 L p F P
0 g
s
.651 .758 .928 r
.68472 .51934 m .67486 .52244 L .6772 .5253 L p F P
0 g
s
.651 .758 .928 r
.6772 .5253 m .68706 .5222 L .68472 .51934 L p F P
0 g
s
.65 .757 .928 r
.38679 .51934 m .37746 .52244 L .3803 .5253 L p F P
0 g
s
.65 .757 .928 r
.3803 .5253 m .38962 .52221 L .38679 .51934 L p F P
0 g
s
.651 .757 .928 r
.53576 .51936 m .52616 .52246 L .52875 .52532 L p F P
0 g
s
.651 .757 .928 r
.52875 .52532 m .53834 .52222 L .53576 .51936 L p F P
0 g
s
.649 .756 .927 r
.10105 .51874 m .09223 .52182 L .09554 .52469 L p F P
0 g
s
.649 .756 .927 r
.09554 .52469 m .10435 .52162 L .10105 .51874 L p F P
0 g
s
.652 .817 .963 r
.42558 .75699 m .41619 .75927 L .41895 .76217 L p F P
0 g
s
.652 .817 .963 r
.41895 .76217 m .42835 .75901 L .42558 .75699 L p F P
0 g
s
.433 .652 .951 r
.41576 .7592 m .41619 .75927 L .41895 .76217 L p F P
0 g
s
.705 .927 .601 r
.46754 .7198 m .47038 .71566 L .46539 .72174 L p F P
0 g
s
0 0 0 r
.46915 .71732 m .46916 .71732 L .47038 .71566 L F
.4716 .71402 m .46754 .7198 L .47038 .71566 L p F P
0 g
s
0 0 0 r
.4723 .71357 m .47038 .71566 L p .46916 .71732 L F P
0 g
s
0 0 0 r
.4716 .71401 m .4716 .71402 L p .47038 .71566 L F P
0 g
s
0 0 0 r
.47427 .71072 m .4716 .71401 L p .47038 .71566 L F P
0 g
s
.509 .178 .342 r
.50303 .68391 m .50404 .68029 L .51426 .67815 L p F P
0 g
s
.512 .18 .342 r
.51459 .67703 m .51426 .67815 L .50404 .68029 L p F P
0 g
s
.651 .758 .928 r
.83784 .52496 m .84798 .52185 L .85004 .5247 L p F P
0 g
s
.651 .758 .928 r
.84798 .52185 m .83784 .52496 L .83576 .5221 L p F P
0 g
s
.65 .757 .928 r
.24999 .51903 m .24091 .52213 L .24397 .52499 L p F P
0 g
s
.65 .757 .928 r
.24397 .52499 m .25304 .5219 L .24999 .51903 L p F P
0 g
s
.651 .758 .928 r
.69695 .51909 m .68706 .5222 L .68938 .52506 L p F P
0 g
s
.651 .758 .928 r
.68938 .52506 m .69926 .52196 L .69695 .51909 L p F P
0 g
s
.65 .757 .928 r
.39897 .5191 m .38962 .52221 L .39244 .52507 L p F P
0 g
s
.65 .757 .928 r
.39244 .52507 m .40178 .52197 L .39897 .5191 L p F P
0 g
s
.651 .757 .928 r
.54796 .51912 m .53834 .52222 L .54091 .52508 L p F P
0 g
s
.651 .757 .928 r
.54091 .52508 m .55052 .52198 L .54796 .51912 L p F P
0 g
s
.451 0 0 r
.57592 .63794 m .57718 .63838 L .57824 .63899 L closepath p F P
0 g
s
.305 0 0 r
.57344 .637 m .57592 .63794 L .57718 .63838 L p F P
0 g
s
.897 .953 .829 r
.44756 .74408 m .44757 .74422 L .45023 .74433 L p F P
0 g
s
.86 .969 .865 r
.44757 .74422 m .45023 .74433 L .44691 .74754 L closepath p F P
0 g
s
.649 .756 .927 r
.11318 .51854 m .10435 .52162 L .10764 .52449 L p F P
0 g
s
.649 .756 .927 r
.10764 .52449 m .11646 .52142 L .11318 .51854 L p F P
0 g
s
.471 0 0 r
.59195 .6468 m .59138 .64643 L .5874 .64422 L p F P
0 g
s
.854 .904 .869 r
.44691 .74754 m .44757 .74422 L p .4399 .75092 L F P
0 g
s
.854 .904 .869 r
.44064 .75391 m .44691 .74754 L p .4399 .75092 L F P
0 g
s
.672 .321 .371 r
.52583 .67733 m .52676 .6744 L .52944 .67747 L closepath p F P
0 g
s
.591 .267 .388 r
.52676 .6744 m .52583 .67733 L .51621 .67799 L p F P
0 g
s
0 0 .272 r
.64777 .72053 m .64715 .7175 L .64584 .71319 L p F P
0 g
s
.707 .471 0 r
.64715 .7175 m .64777 .72053 L .64856 .725 L p F P
0 g
s
.68 .84 .418 r
.41457 .69354 m .41659 .68953 L .41343 .69504 L p F P
0 g
s
.68 .84 .418 r
.41343 .69504 m .41135 .69905 L .41457 .69354 L p F P
0 g
s
.65 .757 .928 r
.26215 .5188 m .25304 .5219 L .25609 .52476 L p F P
0 g
s
.65 .757 .928 r
.25609 .52476 m .26519 .52167 L .26215 .5188 L p F P
0 g
s
.651 .758 .928 r
.70917 .51885 m .69926 .52196 L .70156 .52482 L p F P
0 g
s
.651 .758 .928 r
.70156 .52482 m .71146 .52172 L .70917 .51885 L p F P
0 g
s
.764 .933 .581 r
.46673 .72096 m .46754 .7198 L .46721 .72047 L closepath p F P
0 g
s
.686 .905 .559 r
.46298 .72574 m .46673 .72096 L .46721 .72047 L p F P
0 g
s
.65 .757 .928 r
.41115 .51887 m .40178 .52197 L .40458 .52483 L p F P
0 g
s
.65 .757 .928 r
.40458 .52483 m .41394 .52174 L .41115 .51887 L p F P
0 g
s
.651 .757 .928 r
.56016 .51888 m .55052 .52198 L .55307 .52484 L p F P
0 g
s
.651 .757 .928 r
.55307 .52484 m .5627 .52174 L .56016 .51888 L p F P
0 g
s
.928 .859 .424 r
.64749 .74579 m .64749 .74577 L .64888 .74067 L p F P
0 g
s
.964 .879 .487 r
.6486 .73759 m .64888 .74067 L .64749 .74577 L p F P
0 g
s
.879 .749 .241 r
.64888 .74067 m .6486 .73759 L .64916 .73272 L p F P
0 g
s
.311 .507 .887 r
.61353 .75488 m .61143 .75413 L .61115 .75118 L closepath p F P
0 g
s
.4 .5 .845 r
.61105 .75103 m .61115 .75118 L .61143 .75413 L p F P
0 g
s
.649 .756 .927 r
.12532 .51834 m .11646 .52142 L .11973 .5243 L p F P
0 g
s
.649 .756 .927 r
.11973 .5243 m .12858 .52122 L .12532 .51834 L p F P
0 g
s
0 .045 .566 r
.62178 .67261 m .61948 .66996 L .61587 .6664 L p F P
0 g
s
0 .011 .511 r
.61587 .6664 m .6133 .66382 L .6169 .66738 L p F P
0 g
s
0 .011 .511 r
.6169 .66738 m .61948 .66996 L .61587 .6664 L p F P
0 g
s
.853 .41 .157 r
.56374 .69334 m .55978 .69118 L .56211 .69513 L p F P
0 g
s
.853 .41 .157 r
.56211 .69513 m .56589 .69734 L .56374 .69334 L p F P
0 g
s
.65 .757 .928 r
.27432 .51857 m .26519 .52167 L .26821 .52454 L p F P
0 g
s
.65 .757 .928 r
.26821 .52454 m .27733 .52144 L .27432 .51857 L p F P
0 g
s
.786 .85 .899 r
.4405 .75401 m .44053 .75387 L p .42872 .75877 L F P
0 g
s
.792 .914 .922 r
.44053 .75387 m .44064 .75391 L .4405 .75401 L closepath p F P
0 g
s
.854 .904 .869 r
.4399 .75092 m .44053 .75387 L .44064 .75391 L p F P
0 g
s
.651 .758 .928 r
.7214 .5186 m .71146 .52172 L .71374 .52457 L p F P
0 g
s
.651 .758 .928 r
.71374 .52457 m .72367 .52147 L .7214 .5186 L p F P
0 g
s
.65 .757 .928 r
.42334 .51863 m .41394 .52174 L .41672 .5246 L p F P
0 g
s
.65 .757 .928 r
.41672 .5246 m .42611 .5215 L .42334 .51863 L p F P
0 g
s
.651 .757 .928 r
.57237 .51864 m .5627 .52174 L .56523 .5246 L p F P
0 g
s
.651 .757 .928 r
.56523 .5246 m .57489 .52151 L .57237 .51864 L p F P
0 g
s
.084 0 0 r
.48682 .63358 m .48838 .63253 L .49826 .63 L p F P
0 g
s
0 0 0 r
.48838 .63253 m .48682 .63358 L .47731 .63706 L p F P
0 g
s
.513 0 0 r
.59195 .6468 m .59576 .6497 L .59201 .64742 L p F P
0 g
s
.513 0 0 r
.59201 .64742 m .58949 .64558 L .59195 .6468 L p F P
0 g
s
.471 0 0 r
.5874 .64422 m .58949 .64558 L .59195 .6468 L p F P
0 g
s
.675 .807 .355 r
.41022 .70129 m .41135 .69905 L .41093 .69996 L closepath p F P
0 g
s
.736 .835 .384 r
.40877 .70439 m .41022 .70129 L .41093 .69996 L p F P
0 g
s
.65 .756 .927 r
.13746 .51813 m .12858 .52122 L .13183 .52409 L p F P
0 g
s
.65 .756 .927 r
.13183 .52409 m .1407 .52101 L .13746 .51813 L p F P
0 g
s
.219 .41 .838 r
.59872 .73873 m .59613 .73727 L .59361 .73277 L p F P
0 g
s
.679 .169 0 r
.57361 .70562 m .57407 .7062 L .57126 .70373 L p F P
0 g
s
.679 .169 0 r
.57126 .70373 m .5711 .70353 L .57361 .70562 L p F P
0 g
s
.849 .397 0 r
.56912 .6997 m .5711 .70353 L .57361 .70562 L p F P
0 g
s
.853 .903 .869 r
.43787 .75282 m .4399 .75092 L .44053 .75387 L closepath p F P
0 g
s
.786 .85 .899 r
.44053 .75387 m .43787 .75282 L .42872 .75877 L p F P
0 g
s
.618 .836 .447 r
.41706 .68882 m .42066 .68376 L .4189 .68638 L closepath p F P
0 g
s
.675 .864 .47 r
.41659 .68953 m .41706 .68882 L .4189 .68638 L p F P
0 g
s
.65 .757 .928 r
.28648 .51834 m .27733 .52144 L .28034 .52431 L p F P
0 g
s
.65 .757 .928 r
.28034 .52431 m .28948 .52121 L .28648 .51834 L p F P
0 g
s
.651 .758 .928 r
.73363 .51836 m .72367 .52147 L .72593 .52433 L p F P
0 g
s
.651 .758 .928 r
.72593 .52433 m .73588 .52123 L .73363 .51836 L p F P
0 g
s
.791 .355 .215 r
.55501 .68924 m .55372 .68736 L .55499 .68632 L p F P
0 g
s
.839 .43 .265 r
.55372 .68736 m .5527 .6853 L .55499 .68632 L closepath p F P
0 g
s
.718 .345 .343 r
.54512 .67958 m .54739 .68351 L .54078 .6821 L p F P
0 g
s
.718 .345 .343 r
.53939 .6785 m .54512 .67958 L p .54078 .6821 L F P
0 g
s
.65 .757 .928 r
.43553 .51839 m .42611 .5215 L .42887 .52436 L p F P
0 g
s
.65 .757 .928 r
.42887 .52436 m .43828 .52126 L .43553 .51839 L p F P
0 g
s
.651 .757 .928 r
.58458 .5184 m .57489 .52151 L .5774 .52436 L p F P
0 g
s
.651 .757 .928 r
.5774 .52436 m .58708 .52127 L .58458 .5184 L p F P
0 g
s
0 0 0 r
.47647 .63759 m .47731 .63706 L .48682 .63358 L p F P
0 g
s
0 0 0 r
.40558 .71328 m .40678 .70956 L .40529 .71459 L p F P
0 g
s
0 0 0 r
.40529 .71459 m .40404 .71832 L .40558 .71328 L p F P
0 g
s
.485 0 0 r
.56253 .6323 m .56809 .63518 L .56244 .63343 L p F P
0 g
s
.485 0 0 r
.56238 .63226 m .56253 .6323 L p .56244 .63343 L F P
0 g
s
0 0 .534 r
.62725 .67895 m .62665 .67828 L .6242 .67516 L p F P
0 g
s
.485 0 0 r
.56244 .63343 m .55994 .63224 L .56238 .63226 L p F P
0 g
s
.422 0 0 r
.55994 .63224 m .55618 .63078 L .56238 .63226 L closepath p F P
0 g
s
.65 .756 .928 r
.14961 .51792 m .1407 .52101 L .14394 .52388 L p F P
0 g
s
.65 .756 .928 r
.14394 .52388 m .15283 .5208 L .14961 .51792 L p F P
0 g
s
.525 0 0 r
.57824 .63899 m .58311 .64209 L .57852 .64004 L p F P
0 g
s
.525 0 0 r
.57592 .63794 m .57824 .63899 L p .57852 .64004 L F P
0 g
s
.853 .395 .051 r
.56912 .6997 m .56589 .69734 L .56807 .70135 L p F P
0 g
s
.853 .395 .051 r
.5711 .70353 m .56912 .6997 L p .56807 .70135 L F P
0 g
s
0 0 .237 r
.64499 .71021 m .64584 .71319 L .64715 .7175 L p F P
0 g
s
0 0 .353 r
.64584 .71319 m .64499 .71021 L .64324 .70603 L p F P
0 g
s
0 0 .07 r
.40265 .72666 m .40246 .73133 L .40285 .72788 L p F P
0 g
s
0 0 .07 r
.40307 .72322 m .40265 .72666 L p .40285 .72788 L F P
0 g
s
.65 .757 .928 r
.29866 .51811 m .28948 .52121 L .29246 .52408 L p F P
0 g
s
.65 .757 .928 r
.29246 .52408 m .30163 .52098 L .29866 .51811 L p F P
0 g
s
.651 .758 .928 r
.74586 .51811 m .73588 .52123 L .73812 .52409 L p F P
0 g
s
.651 .758 .928 r
.73812 .52409 m .74809 .52098 L .74586 .51811 L p F P
0 g
s
0 0 .52 r
.62178 .67261 m .6242 .67516 L .62176 .67238 L p F P
0 g
s
0 0 .52 r
.62176 .67238 m .61948 .66996 L .62178 .67261 L p F P
0 g
s
.651 .757 .928 r
.44772 .51815 m .43828 .52126 L .44102 .52412 L p F P
0 g
s
.651 .757 .928 r
.44102 .52412 m .45045 .52103 L .44772 .51815 L p F P
0 g
s
.651 .757 .928 r
.59679 .51816 m .58708 .52127 L .58957 .52413 L p F P
0 g
s
.651 .757 .928 r
.58957 .52413 m .59927 .52103 L .59679 .51816 L p F P
0 g
s
.705 .927 .601 r
.46673 .72096 m .46754 .7198 L p .46539 .72174 L F P
0 g
s
.248 .45 .861 r
.41344 .75596 m .40805 .75349 L .40776 .75029 L p F P
0 g
s
.265 .517 .906 r
.40805 .75349 m .41344 .75596 L .41548 .75843 L p F P
0 g
s
.65 .757 .928 r
.16176 .51771 m .15283 .5208 L .15604 .52367 L p F P
0 g
s
.65 .757 .928 r
.15604 .52367 m .16496 .52059 L .16176 .51771 L p F P
0 g
s
.591 .117 0 r
.57933 .71261 m .57707 .70999 L .57407 .7062 L p F P
0 g
s
.687 .182 0 r
.57407 .7062 m .57126 .70373 L .57431 .7075 L p F P
0 g
s
.687 .182 0 r
.57431 .7075 m .57707 .70999 L .57407 .7062 L p F P
0 g
s
.634 .842 .98 r
.63442 .75882 m .62827 .76135 L .62583 .75864 L p F P
0 g
s
.599 .256 .359 r
.51426 .67815 m .51459 .67703 L .51621 .67799 L closepath p F P
0 g
s
.651 .758 .928 r
.7581 .51787 m .74809 .52098 L .75032 .52384 L p F P
0 g
s
.651 .758 .928 r
.75032 .52384 m .76031 .52074 L .7581 .51787 L p F P
0 g
s
.65 .757 .928 r
.31083 .51788 m .30163 .52098 L .3046 .52385 L p F P
0 g
s
.65 .757 .928 r
.3046 .52385 m .31379 .52075 L .31083 .51788 L p F P
0 g
s
0 .178 .703 r
.40442 .74662 m .40446 .74331 L .40749 .74708 L p F P
0 g
s
0 .178 .703 r
.40749 .74708 m .40776 .75029 L .40442 .74662 L p F P
0 g
s
.651 .757 .928 r
.60901 .51791 m .59927 .52103 L .60174 .52389 L p F P
0 g
s
.651 .757 .928 r
.60174 .52389 m .61147 .52079 L .60901 .51791 L p F P
0 g
s
.651 .757 .928 r
.45992 .51792 m .45045 .52103 L .45317 .52389 L p F P
0 g
s
.651 .757 .928 r
.45317 .52389 m .46263 .52079 L .45992 .51792 L p F P
0 g
s
.705 .927 .601 r
.46539 .72174 m .46469 .72283 L .46673 .72096 L p F P
0 g
s
.737 .938 .609 r
.46469 .72283 m .46673 .72096 L .46298 .72574 L closepath p F P
0 g
s
.489 0 0 r
.59922 .65206 m .59576 .6497 L .60005 .65302 L p F P
0 g
s
.489 0 0 r
.60005 .65302 m .60355 .65537 L .59922 .65206 L p F P
0 g
s
.898 .987 .759 r
.45708 .73347 m .45844 .73168 L .45815 .73303 L closepath p F P
0 g
s
.831 .998 .781 r
.45304 .73787 m .45708 .73347 L .45815 .73303 L p F P
0 g
s
0 0 .317 r
.64213 .7031 m .64324 .70603 L .64499 .71021 L p F P
0 g
s
0 0 .407 r
.64324 .70603 m .64213 .7031 L .64002 .69904 L p F P
0 g
s
.65 .757 .928 r
.17392 .51749 m .16496 .52059 L .16816 .52346 L p F P
0 g
s
.65 .757 .928 r
.16816 .52346 m .1771 .52037 L .17392 .51749 L p F P
0 g
s
0 0 .474 r
.63199 .68551 m .63014 .68275 L .62725 .67895 L p F P
0 g
s
.569 .114 0 r
.62517 .67625 m .62725 .67895 L .63014 .68275 L p F P
0 g
s
0 0 .534 r
.6242 .67516 m .62517 .67625 L .62725 .67895 L p F P
0 g
s
.651 .758 .928 r
.77034 .51762 m .76031 .52074 L .76251 .5236 L p F P
0 g
s
.651 .758 .928 r
.76251 .5236 m .77253 .52049 L .77034 .51762 L p F P
0 g
s
.65 .757 .928 r
.32301 .51764 m .31379 .52075 L .31673 .52361 L p F P
0 g
s
.65 .757 .928 r
.31673 .52361 m .32595 .52052 L .32301 .51764 L p F P
0 g
s
.651 .757 .928 r
.62123 .51767 m .61147 .52079 L .61392 .52365 L p F P
0 g
s
.651 .757 .928 r
.61392 .52365 m .62367 .52054 L .62123 .51767 L p F P
0 g
s
.651 .757 .928 r
.47212 .51768 m .46263 .52079 L .46533 .52365 L p F P
0 g
s
.651 .757 .928 r
.46533 .52365 m .47481 .52055 L .47212 .51768 L p F P
0 g
s
.499 .845 .576 r
.4364 .66539 m .44392 .65861 L p .44228 .66018 L F P
0 g
s
.499 .845 .576 r
.44228 .66018 m .43639 .6654 L .4364 .66539 L p F P
0 g
s
.604 .899 .612 r
.43639 .6654 m .4364 .66539 L .43638 .66542 L closepath p F P
0 g
s
.548 .842 .515 r
.43638 .66542 m .43639 .6654 L .43401 .66781 L p F P
0 g
s
.548 .842 .515 r
.43401 .66781 m .43046 .67173 L .43638 .66542 L p F P
0 g
s
0 0 0 r
.43639 .6654 m .44228 .66018 L .43503 .6669 L p F P
0 g
s
0 0 0 r
.43503 .6669 m .43401 .66781 L .43639 .6654 L p F P
0 g
s
.499 .845 .576 r
.44392 .65861 m .44531 .65738 L p .44228 .66018 L F P
0 g
s
0 0 .478 r
.58414 .71914 m .58229 .71642 L .57933 .71261 L p F P
0 g
s
.623 .146 0 r
.57707 .70999 m .57933 .71261 L .58229 .71642 L p F P
0 g
s
.626 .782 .332 r
.41135 .69905 m .41343 .69504 L .41067 .70043 L p F P
0 g
s
.626 .782 .332 r
.41022 .70129 m .41135 .69905 L p .41067 .70043 L F P
0 g
s
0 0 0 r
.44597 .65686 m .4533 .65125 L p .45174 .65278 L F P
0 g
s
0 0 .367 r
.63867 .69617 m .64002 .69904 L .64213 .7031 L p F P
0 g
s
0 0 .441 r
.64002 .69904 m .63867 .69617 L .63626 .6922 L p F P
0 g
s
.65 .757 .928 r
.18608 .51727 m .1771 .52037 L .18027 .52324 L p F P
0 g
s
.65 .757 .928 r
.18027 .52324 m .18924 .52015 L .18608 .51727 L p F P
0 g
s
0 0 .461 r
.63626 .6922 m .63465 .68939 L .63199 .68551 L p F P
0 g
s
0 0 .412 r
.63014 .68275 m .63199 .68551 L .63465 .68939 L p F P
0 g
s
.651 .758 .928 r
.77471 .52335 m .78475 .52024 L .78692 .5231 L p F P
0 g
s
.651 .758 .928 r
.78258 .51737 m .77253 .52049 L .77471 .52335 L p F P
0 g
s
.651 .758 .928 r
.77471 .52335 m .78475 .52024 L .78258 .51737 L p F P
0 g
s
.529 .63 .895 r
.61353 .75488 m .62301 .75568 L .62378 .7586 L p F P
0 g
s
.484 .603 .895 r
.62301 .75568 m .61353 .75488 L .61115 .75118 L p F P
0 g
s
.914 .771 .286 r
.64875 .72966 m .64916 .73272 L .6486 .73759 L p F P
0 g
s
.792 .607 .044 r
.64916 .73272 m .64875 .72966 L .64856 .725 L p F P
0 g
s
.65 .757 .928 r
.33519 .51741 m .32595 .52052 L .32887 .52338 L p F P
0 g
s
.65 .757 .928 r
.32887 .52338 m .33811 .52028 L .33519 .51741 L p F P
0 g
s
0 0 .396 r
.63465 .68939 m .63626 .6922 L .63867 .69617 L p F P
0 g
s
.651 .757 .928 r
.63346 .51743 m .62367 .52054 L .6261 .52341 L p F P
0 g
s
.651 .757 .928 r
.6261 .52341 m .63588 .5203 L .63346 .51743 L p F P
0 g
s
.651 .757 .928 r
.48432 .51744 m .47481 .52055 L .47749 .52341 L p F P
0 g
s
.651 .757 .928 r
.47749 .52341 m .48699 .52031 L .48432 .51744 L p F P
0 g
s
0 0 .548 r
.58873 .72575 m .58717 .72296 L .58414 .71914 L p F P
0 g
s
0 0 .441 r
.58229 .71642 m .58414 .71914 L .58717 .72296 L p F P
0 g
s
0 0 0 r
.40382 .71909 m .40404 .71832 L .40307 .7232 L p F P
0 g
s
0 0 0 r
.40307 .7232 m .40307 .72322 L .40382 .71909 L p F P
0 g
s
.65 .757 .928 r
.19824 .51705 m .18924 .52015 L .19239 .52302 L p F P
0 g
s
.65 .757 .928 r
.19239 .52302 m .20138 .51993 L .19824 .51705 L p F P
0 g
s
.648 .755 .927 r
.0613 .51641 m .05255 .51948 L .05593 .52237 L p F P
0 g
s
.648 .755 .927 r
.05593 .52237 m .06467 .5193 L .0613 .51641 L p F P
0 g
s
.805 .392 .266 r
.5527 .6853 m .54739 .68351 L .54968 .68746 L p F P
0 g
s
.805 .392 .266 r
.55372 .68736 m .5527 .6853 L p .54968 .68746 L F P
0 g
s
.651 .758 .928 r
.78692 .5231 m .79698 .51999 L .79912 .52286 L p F P
0 g
s
.651 .758 .928 r
.79698 .51999 m .78692 .5231 L .78475 .52024 L p F P
0 g
s
.124 0 .101 r
.48321 .70057 m .48699 .69699 L .48396 .69877 L closepath p F P
0 g
s
0 0 0 r
.48396 .69877 m .48321 .70057 L .48078 .70341 L p F P
0 g
s
.718 .345 .343 r
.54078 .6821 m .53894 .6796 L .53939 .6785 L p F P
0 g
s
.734 .363 .35 r
.53894 .6796 m .53807 .67829 L .53939 .6785 L closepath p F P
0 g
s
.65 .757 .928 r
.34738 .51717 m .33811 .52028 L .34101 .52315 L p F P
0 g
s
.65 .757 .928 r
.34101 .52315 m .35027 .52005 L .34738 .51717 L p F P
0 g
s
0 .105 .658 r
.5911 .72855 m .58873 .72575 L p .59325 .73237 L F P
0 g
s
0 0 .547 r
.58873 .72575 m .5911 .72855 L .58858 .72474 L p F P
0 g
s
0 0 .547 r
.58858 .72474 m .58717 .72296 L .58873 .72575 L p F P
0 g
s
.651 .757 .928 r
.64568 .51719 m .63588 .5203 L .63829 .52317 L p F P
0 g
s
.651 .757 .928 r
.63829 .52317 m .64808 .52006 L .64568 .51719 L p F P
0 g
s
.635 .897 .576 r
.46298 .72574 m .45844 .73168 L .45998 .72794 L p F P
0 g
s
.635 .897 .576 r
.46469 .72283 m .46298 .72574 L p .45998 .72794 L F P
0 g
s
.651 .757 .928 r
.49653 .5172 m .48699 .52031 L .48965 .52318 L p F P
0 g
s
.651 .757 .928 r
.48965 .52318 m .49918 .52007 L .49653 .5172 L p F P
0 g
s
.542 .837 .509 r
.43046 .67173 m .43401 .66781 L p .42912 .67323 L F P
0 g
s
.542 .837 .509 r
.42678 .67586 m .43046 .67173 L p .42912 .67323 L F P
0 g
s
.785 .849 .9 r
.42835 .75901 m .42872 .75877 L .42903 .75948 L closepath p F P
0 g
s
.525 0 0 r
.57852 .64004 m .5747 .63767 L .57592 .63794 L p F P
0 g
s
.458 0 0 r
.5747 .63767 m .57344 .637 L .57592 .63794 L closepath p F P
0 g
s
0 0 .47 r
.40281 .73916 m .40302 .73578 L .40455 .73997 L p F P
0 g
s
0 0 .47 r
.40455 .73997 m .40446 .74331 L .40281 .73916 L p F P
0 g
s
0 .112 .663 r
.59361 .73277 m .59325 .73237 L .59288 .73153 L closepath p F P
0 g
s
0 .105 .658 r
.59325 .73237 m .59288 .73153 L .5911 .72855 L p F P
0 g
s
.65 .757 .928 r
.2104 .51683 m .20138 .51993 L .20451 .5228 L p F P
0 g
s
.65 .757 .928 r
.20451 .5228 m .21353 .51971 L .2104 .51683 L p F P
0 g
s
.651 .758 .928 r
.79912 .52286 m .80921 .51974 L .81133 .52261 L p F P
0 g
s
.651 .758 .928 r
.80921 .51974 m .79912 .52286 L .79698 .51999 L p F P
0 g
s
.649 .756 .927 r
.07344 .51623 m .06467 .5193 L .06803 .52219 L p F P
0 g
s
.649 .756 .927 r
.06803 .52219 m .07679 .51912 L .07344 .51623 L p F P
0 g
s
.697 .318 .326 r
.53807 .67829 m .52944 .67747 L .53263 .68113 L p F P
0 g
s
.697 .318 .326 r
.53894 .6796 m .53807 .67829 L p .53263 .68113 L F P
0 g
s
.65 .757 .928 r
.35957 .51694 m .35027 .52005 L .35316 .52291 L p F P
0 g
s
.65 .757 .928 r
.35316 .52291 m .36244 .51981 L .35957 .51694 L p F P
0 g
s
.651 .757 .928 r
.65791 .51695 m .64808 .52006 L .65047 .52293 L p F P
0 g
s
.651 .757 .928 r
.65047 .52293 m .66029 .51982 L .65791 .51695 L p F P
0 g
s
.956 .925 .578 r
.64748 .7458 m .64749 .74577 L .64749 .74579 L closepath p F P
0 g
s
.651 .757 .928 r
.50874 .51696 m .49918 .52007 L .50182 .52294 L p F P
0 g
s
.651 .757 .928 r
.50182 .52294 m .51137 .51983 L .50874 .51696 L p F P
0 g
s
0 0 0 r
.4533 .65125 m .45496 .65006 L p .45174 .65278 L F P
0 g
s
0 0 0 r
.45496 .65006 m .45551 .64966 L .4533 .65125 L closepath p F P
0 g
s
.969 .934 .655 r
.64749 .74577 m .64748 .7458 L .64521 .74674 L p F P
0 g
s
.969 .934 .655 r
.64521 .74674 m .64712 .74272 L .64749 .74577 L p F P
0 g
s
.964 .879 .487 r
.64749 .74577 m .64712 .74272 L .6486 .73759 L p F P
0 g
s
.909 .98 .713 r
.64363 .75156 m .64748 .7458 L .64521 .74674 L p F P
0 g
s
0 .064 .539 r
.60679 .65782 m .60675 .65779 L .60697 .65798 L closepath p F P
0 g
s
.522 0 0 r
.61046 .6613 m .60679 .65782 L .60697 .65798 L p F P
0 g
s
.626 .782 .332 r
.41067 .70043 m .40923 .70316 L .41022 .70129 L p F P
0 g
s
.736 .836 .385 r
.40923 .70316 m .41022 .70129 L .40877 .70439 L closepath p F P
0 g
s
.381 .604 .936 r
.41619 .75927 m .41576 .7592 L .41548 .75843 L closepath p F P
0 g
s
.598 .253 .356 r
.51621 .67799 m .51426 .67815 L .51319 .68169 L p F P
0 g
s
.509 .178 .342 r
.51426 .67815 m .51319 .68169 L .50303 .68391 L p F P
0 g
s
.542 .837 .509 r
.42912 .67323 m .42598 .67668 L .42678 .67586 L p F P
0 g
s
.647 .89 .548 r
.42598 .67668 m .42678 .67586 L .42511 .67788 L closepath p F P
0 g
s
0 0 0 r
.47456 .63905 m .47647 .63759 L .48564 .63435 L p F P
0 g
s
0 0 0 r
.48682 .63358 m .48564 .63435 L .47647 .63759 L p F P
0 g
s
0 0 0 r
.47647 .63759 m .47456 .63905 L .46763 .64238 L p F P
0 g
s
.65 .757 .928 r
.22257 .51661 m .21353 .51971 L .21664 .52258 L p F P
0 g
s
.65 .757 .928 r
.21664 .52258 m .22568 .51949 L .22257 .51661 L p F P
0 g
s
.651 .758 .928 r
.81133 .52261 m .82144 .51949 L .82355 .52236 L p F P
0 g
s
.651 .758 .928 r
.82144 .51949 m .81133 .52261 L .80921 .51974 L p F P
0 g
s
.65 .757 .928 r
.37176 .5167 m .36244 .51981 L .36531 .52268 L p F P
0 g
s
.65 .757 .928 r
.36531 .52268 m .37462 .51958 L .37176 .5167 L p F P
0 g
s
.649 .756 .927 r
.08558 .51604 m .07679 .51912 L .08013 .52201 L p F P
0 g
s
.649 .756 .927 r
.08013 .52201 m .08892 .51894 L .08558 .51604 L p F P
0 g
s
.651 .757 .928 r
.67015 .5167 m .66029 .51982 L .66266 .52269 L p F P
0 g
s
.651 .757 .928 r
.66266 .52269 m .67251 .51958 L .67015 .5167 L p F P
0 g
s
.651 .757 .928 r
.52095 .51672 m .51137 .51983 L .51399 .5227 L p F P
0 g
s
.651 .757 .928 r
.51399 .5227 m .52356 .5196 L .52095 .51672 L p F P
0 g
s
.516 0 0 r
.60679 .65782 m .60675 .65779 L .60355 .65537 L p F P
0 g
s
0 0 0 r
.45496 .65006 m .45551 .64966 L .46504 .64371 L p F P
0 g
s
0 0 0 r
.46534 .64345 m .46504 .64371 L .45551 .64966 L p F P
0 g
s
.373 0 0 r
.55618 .63078 m .54953 .62933 L .55619 .63186 L p F P
0 g
s
.373 0 0 r
.55994 .63224 m .55618 .63078 L p .55619 .63186 L F P
0 g
s
.219 .41 .838 r
.59361 .73277 m .59813 .7357 L .59872 .73873 L p F P
0 g
s
.117 .364 .826 r
.59813 .7357 m .59361 .73277 L .59288 .73153 L p F P
0 g
s
.56 .022 0 r
.60679 .65782 m .61046 .6613 L .60737 .65885 L p F P
0 g
s
.56 .022 0 r
.60737 .65885 m .60434 .65604 L .60679 .65782 L p F P
0 g
s
.516 0 0 r
.60355 .65537 m .60434 .65604 L .60679 .65782 L p F P
0 g
s
.598 .253 .356 r
.51319 .68169 m .52144 .68105 L .51621 .67799 L p F P
0 g
s
.6 .249 .346 r
.52583 .67733 m .51621 .67799 L .52144 .68105 L p F P
0 g
s
.498 0 0 r
.58949 .64558 m .5874 .64422 L .58311 .64209 L p F P
0 g
s
.287 .439 .84 r
.59872 .73873 m .60401 .74197 L .60464 .74497 L p F P
0 g
s
.016 .319 .806 r
.59813 .7357 m .59872 .73873 L .60401 .74197 L p F P
0 g
s
.566 .691 .924 r
.4228 .75476 m .42558 .75699 L .41619 .75927 L p F P
0 g
s
.566 .691 .924 r
.41687 .75562 m .4228 .75476 L p .41619 .75927 L F P
0 g
s
.566 .691 .924 r
.41619 .75927 m .41548 .75843 L .41687 .75562 L p F P
0 g
s
.651 .758 .928 r
.82355 .52236 m .83368 .51924 L .83576 .5221 L p F P
0 g
s
.651 .758 .928 r
.83368 .51924 m .82355 .52236 L .82144 .51949 L p F P
0 g
s
.65 .757 .928 r
.23475 .51638 m .22568 .51949 L .22877 .52236 L p F P
0 g
s
.65 .757 .928 r
.22877 .52236 m .23783 .51926 L .23475 .51638 L p F P
0 g
s
0 0 0 r
.42511 .67788 m .42066 .68376 L .42382 .67938 L p F P
0 g
s
0 0 0 r
.42598 .67668 m .42511 .67788 L p .42382 .67938 L F P
0 g
s
.651 .758 .928 r
.68239 .51646 m .67251 .51958 L .67486 .52244 L p F P
0 g
s
.651 .758 .928 r
.67486 .52244 m .68472 .51934 L .68239 .51646 L p F P
0 g
s
.65 .757 .928 r
.38396 .51646 m .37462 .51958 L .37746 .52244 L p F P
0 g
s
.65 .757 .928 r
.37746 .52244 m .38679 .51934 L .38396 .51646 L p F P
0 g
s
.651 .757 .928 r
.53317 .51648 m .52356 .5196 L .52616 .52246 L p F P
0 g
s
.651 .757 .928 r
.52616 .52246 m .53576 .51936 L .53317 .51648 L p F P
0 g
s
.649 .756 .927 r
.09773 .51585 m .08892 .51894 L .09223 .52182 L p F P
0 g
s
.649 .756 .927 r
.09223 .52182 m .10105 .51874 L .09773 .51585 L p F P
0 g
s
0 0 0 r
.40404 .71832 m .40529 .71459 L .40438 .71946 L p F P
0 g
s
0 0 0 r
.40438 .71946 m .40307 .7232 L .40404 .71832 L p F P
0 g
s
.634 .842 .98 r
.63623 .75601 m .63442 .75882 L p .62583 .75864 L F P
0 g
s
.704 .872 .961 r
.63442 .75882 m .63623 .75601 L .63799 .7572 L closepath p F P
0 g
s
.785 .854 .902 r
.42756 .75584 m .42558 .75699 L .42835 .75901 L p F P
0 g
s
.785 .854 .902 r
.42835 .75901 m .42872 .75877 L .42756 .75584 L p F P
0 g
s
.834 .631 .084 r
.64797 .72197 m .64856 .725 L .64875 .72966 L p F P
0 g
s
.707 .471 0 r
.64856 .725 m .64797 .72197 L .64715 .7175 L p F P
0 g
s
.741 .906 .951 r
.43787 .75282 m .42872 .75877 L .42756 .75584 L p F P
0 g
s
.651 .758 .928 r
.83576 .5221 m .84592 .51898 L .84798 .52185 L p F P
0 g
s
.651 .758 .928 r
.84592 .51898 m .83576 .5221 L .83368 .51924 L p F P
0 g
s
.826 .39 .203 r
.55978 .69118 m .55501 .68924 L .55763 .69311 L p F P
0 g
s
.826 .39 .203 r
.55763 .69311 m .56211 .69513 L .55978 .69118 L p F P
0 g
s
.65 .757 .928 r
.24693 .51615 m .23783 .51926 L .24091 .52213 L p F P
0 g
s
.65 .757 .928 r
.24091 .52213 m .24999 .51903 L .24693 .51615 L p F P
0 g
s
0 0 0 r
.44311 .65946 m .45174 .65278 L .44531 .65738 L closepath p F P
0 g
s
.499 .845 .576 r
.44531 .65738 m .44311 .65946 L .44228 .66018 L p F P
0 g
s
.863 .996 .786 r
.45844 .73168 m .45998 .72794 L .45459 .73414 L p F P
0 g
s
.863 .996 .786 r
.45708 .73347 m .45844 .73168 L p .45459 .73414 L F P
0 g
s
.651 .758 .928 r
.69463 .51622 m .68472 .51934 L .68706 .5222 L p F P
0 g
s
.651 .758 .928 r
.68706 .5222 m .69695 .51909 L .69463 .51622 L p F P
0 g
s
.65 .757 .928 r
.39616 .51623 m .38679 .51934 L .38962 .52221 L p F P
0 g
s
.65 .757 .928 r
.38962 .52221 m .39897 .5191 L .39616 .51623 L p F P
0 g
s
.651 .757 .928 r
.54539 .51624 m .53576 .51936 L .53834 .52222 L p F P
0 g
s
.651 .757 .928 r
.53834 .52222 m .54796 .51912 L .54539 .51624 L p F P
0 g
s
.649 .756 .927 r
.10989 .51565 m .10105 .51874 L .10435 .52162 L p F P
0 g
s
.649 .756 .927 r
.10435 .52162 m .11318 .51854 L .10989 .51565 L p F P
0 g
s
.428 .627 .936 r
.62378 .7586 m .62583 .75864 L .62338 .75572 L p F P
0 g
s
.428 .627 .936 r
.62338 .75572 m .62301 .75568 L .62378 .7586 L p F P
0 g
s
.49 0 0 r
.5747 .63767 m .57344 .637 L .56809 .63518 L p F P
0 g
s
.117 .364 .826 r
.59288 .73153 m .59234 .72942 L p .59813 .7357 L F P
0 g
s
.08 .338 .813 r
.59288 .73153 m .5911 .72855 L .59234 .72942 L closepath p F P
0 g
s
.672 .322 .371 r
.52944 .67747 m .52583 .67733 L .52473 .68082 L p F P
0 g
s
.672 .322 .371 r
.52473 .68082 m .53263 .68113 L .52944 .67747 L p F P
0 g
s
.65 .757 .928 r
.25911 .51592 m .24999 .51903 L .25304 .5219 L p F P
0 g
s
.65 .757 .928 r
.25304 .5219 m .26215 .5188 L .25911 .51592 L p F P
0 g
s
.126 .368 .827 r
.60464 .74497 m .60855 .74712 L .60606 .74328 L p F P
0 g
s
.126 .368 .827 r
.60606 .74328 m .60401 .74197 L .60464 .74497 L p F P
0 g
s
.651 .758 .928 r
.70687 .51597 m .69695 .51909 L .69926 .52196 L p F P
0 g
s
.651 .758 .928 r
.69926 .52196 m .70917 .51885 L .70687 .51597 L p F P
0 g
s
.65 .757 .928 r
.40836 .51599 m .39897 .5191 L .40178 .52197 L p F P
0 g
s
.65 .757 .928 r
.40178 .52197 m .41115 .51887 L .40836 .51599 L p F P
0 g
s
.651 .757 .928 r
.55762 .516 m .54796 .51912 L .55052 .52198 L p F P
0 g
s
.651 .757 .928 r
.55052 .52198 m .56016 .51888 L .55762 .516 L p F P
0 g
s
.863 .996 .786 r
.45459 .73414 m .4545 .7344 L .45708 .73347 L p F P
0 g
s
.842 .999 .792 r
.4545 .7344 m .45708 .73347 L .45304 .73787 L closepath p F P
0 g
s
.674 .756 .265 r
.40877 .70439 m .40923 .70316 L .40785 .70668 L p F P
0 g
s
.674 .756 .265 r
.40785 .70668 m .40678 .70956 L .40877 .70439 L p F P
0 g
s
.555 .677 .92 r
.41687 .75562 m .41548 .75843 L .41344 .75596 L closepath p F P
0 g
s
.365 .034 .265 r
.49281 .69145 m .49593 .68977 L .493 .69086 L closepath p F P
0 g
s
.125 0 .103 r
.493 .69086 m .49281 .69145 L .48699 .69699 L p F P
0 g
s
.649 .756 .927 r
.12205 .51545 m .11318 .51854 L .11646 .52142 L p F P
0 g
s
.649 .756 .927 r
.11646 .52142 m .12532 .51834 L .12205 .51545 L p F P
0 g
s
.544 .025 0 r
.6133 .66382 m .61046 .6613 L .61406 .66486 L p F P
0 g
s
.544 .025 0 r
.61406 .66486 m .6169 .66738 L .6133 .66382 L p F P
0 g
s
.6 .249 .346 r
.52144 .68105 m .52473 .68082 L .52583 .67733 L p F P
0 g
s
.722 .346 .336 r
.53802 .6817 m .53894 .6796 L .54078 .6821 L closepath p F P
0 g
s
.697 .318 .326 r
.53263 .68113 m .53802 .6817 L .53894 .6796 L p F P
0 g
s
.188 0 0 r
.49826 .63 m .50574 .62872 L p .504 .63028 L F P
0 g
s
.188 0 0 r
.504 .63028 m .49635 .63126 L .49826 .63 L p F P
0 g
s
.084 0 0 r
.49826 .63 m .49635 .63126 L .48682 .63358 L p F P
0 g
s
0 0 .245 r
.40246 .73133 m .40285 .72788 L p .40331 .73308 L F P
0 g
s
0 0 .245 r
.40331 .73308 m .40302 .73578 L .40246 .73133 L p F P
0 g
s
.861 .88 .85 r
.64363 .75156 m .64391 .74834 L p .63623 .75601 L F P
0 g
s
.861 .88 .85 r
.63623 .75601 m .63799 .7572 L .64363 .75156 L p F P
0 g
s
.909 .98 .713 r
.64521 .74674 m .64391 .74834 L .64363 .75156 L p F P
0 g
s
0 0 0 r
.46504 .64371 m .46763 .64238 L .46534 .64345 L closepath p F P
0 g
s
.65 .757 .928 r
.27129 .51569 m .26215 .5188 L .26519 .52167 L p F P
0 g
s
.65 .757 .928 r
.26519 .52167 m .27432 .51857 L .27129 .51569 L p F P
0 g
s
.651 .758 .928 r
.71912 .51573 m .70917 .51885 L .71146 .52172 L p F P
0 g
s
.651 .758 .928 r
.71146 .52172 m .7214 .5186 L .71912 .51573 L p F P
0 g
s
.65 .757 .928 r
.42056 .51575 m .41115 .51887 L .41394 .52174 L p F P
0 g
s
.65 .757 .928 r
.41394 .52174 m .42334 .51863 L .42056 .51575 L p F P
0 g
s
.651 .757 .928 r
.56984 .51576 m .56016 .51888 L .5627 .52174 L p F P
0 g
s
.651 .757 .928 r
.5627 .52174 m .57237 .51864 L .56984 .51576 L p F P
0 g
s
0 0 .476 r
.62517 .67625 m .6242 .67516 L .62176 .67238 L p F P
0 g
s
.494 .162 .333 r
.50303 .68391 m .51319 .68169 L p .5088 .68599 L F P
0 g
s
.494 .162 .333 r
.5088 .68599 m .50237 .68626 L .50303 .68391 L p F P
0 g
s
.368 .04 .271 r
.50303 .68391 m .50237 .68626 L .49593 .68977 L p F P
0 g
s
.78 .357 .246 r
.55265 .68851 m .55372 .68736 L .55501 .68924 L closepath p F P
0 g
s
.805 .392 .266 r
.54968 .68746 m .55265 .68851 L .55372 .68736 L p F P
0 g
s
.65 .756 .927 r
.13421 .51524 m .12532 .51834 L .12858 .52122 L p F P
0 g
s
.65 .756 .927 r
.12858 .52122 m .13746 .51813 L .13421 .51524 L p F P
0 g
s
0 0 0 r
.45268 .65209 m .45496 .65006 L .4628 .64558 L p F P
0 g
s
0 0 0 r
.46504 .64371 m .4628 .64558 L .45496 .65006 L p F P
0 g
s
0 0 0 r
.45496 .65006 m .45268 .65209 L .45174 .65278 L p F P
0 g
s
.854 .406 .13 r
.56589 .69734 m .56211 .69513 L .56444 .6991 L p F P
0 g
s
.854 .406 .13 r
.56444 .6991 m .56807 .70135 L .56589 .69734 L p F P
0 g
s
.794 .998 .799 r
.45304 .73787 m .44756 .74408 L .44792 .7407 L p F P
0 g
s
.794 .998 .799 r
.4545 .7344 m .45304 .73787 L p .44792 .7407 L F P
0 g
s
.07 0 0 r
.48564 .63435 m .48682 .63358 L .49635 .63126 L p F P
0 g
s
.579 .818 .435 r
.42066 .68376 m .42382 .67938 L .41975 .68516 L p F P
0 g
s
.579 .818 .435 r
.41706 .68882 m .42066 .68376 L p .41975 .68516 L F P
0 g
s
.65 .757 .928 r
.28348 .51546 m .27432 .51857 L .27733 .52144 L p F P
0 g
s
.65 .757 .928 r
.27733 .52144 m .28648 .51834 L .28348 .51546 L p F P
0 g
s
.651 .758 .928 r
.73137 .51548 m .7214 .5186 L .72367 .52147 L p F P
0 g
s
.651 .758 .928 r
.72367 .52147 m .73363 .51836 L .73137 .51548 L p F P
0 g
s
.65 .757 .928 r
.43277 .51551 m .42334 .51863 L .42611 .5215 L p F P
0 g
s
.65 .757 .928 r
.42611 .5215 m .43553 .51839 L .43277 .51551 L p F P
0 g
s
.651 .757 .928 r
.58207 .51552 m .57237 .51864 L .57489 .52151 L p F P
0 g
s
.651 .757 .928 r
.57489 .52151 m .58458 .5184 L .58207 .51552 L p F P
0 g
s
0 0 .237 r
.64715 .7175 m .64634 .71452 L .64499 .71021 L p F P
0 g
s
.754 .495 0 r
.64634 .71452 m .64715 .7175 L .64797 .72197 L p F P
0 g
s
0 0 0 r
.47359 .71182 m .47553 .70955 L .47427 .71072 L closepath p F P
0 g
s
0 0 0 r
.47038 .71566 m .47359 .71182 L .47427 .71072 L p F P
0 g
s
.65 .756 .927 r
.14638 .51503 m .13746 .51813 L .1407 .52101 L p F P
0 g
s
.65 .756 .927 r
.1407 .52101 m .14961 .51792 L .14638 .51503 L p F P
0 g
s
.745 .228 0 r
.57065 .70331 m .5711 .70353 L .57126 .70373 L closepath p F P
0 g
s
.853 .395 .051 r
.56807 .70135 m .57065 .70331 L .5711 .70353 L p F P
0 g
s
.484 .603 .895 r
.61115 .75118 m .61119 .75104 L p .62301 .75568 L F P
0 g
s
.461 .59 .896 r
.61115 .75118 m .61105 .75103 L .61119 .75104 L closepath p F P
0 g
s
.314 0 .193 r
.49169 .69425 m .49281 .69145 L .49593 .68977 L p F P
0 g
s
.136 0 .114 r
.49169 .69425 m .49281 .69145 L .48699 .69699 L closepath p F P
0 g
s
.65 .757 .928 r
.29567 .51523 m .28648 .51834 L .28948 .52121 L p F P
0 g
s
.65 .757 .928 r
.28948 .52121 m .29866 .51811 L .29567 .51523 L p F P
0 g
s
.651 .758 .928 r
.74362 .51523 m .73363 .51836 L .73588 .52123 L p F P
0 g
s
.651 .758 .928 r
.73588 .52123 m .74586 .51811 L .74362 .51523 L p F P
0 g
s
.462 .589 .894 r
.61119 .75104 m .61105 .75103 L .60855 .74712 L p F P
0 g
s
.978 .886 .525 r
.64817 .73454 m .6486 .73759 L .64712 .74272 L p F P
0 g
s
.914 .771 .286 r
.6486 .73759 m .64817 .73454 L .64875 .72966 L p F P
0 g
s
.774 .389 .326 r
.54739 .68351 m .54078 .6821 L .54355 .6859 L p F P
0 g
s
.774 .389 .326 r
.54355 .6859 m .54968 .68746 L .54739 .68351 L p F P
0 g
s
.651 .757 .928 r
.44499 .51527 m .43553 .51839 L .43828 .52126 L p F P
0 g
s
.651 .757 .928 r
.43828 .52126 m .44772 .51815 L .44499 .51527 L p F P
0 g
s
.651 .757 .928 r
.59431 .51527 m .58458 .5184 L .58708 .52127 L p F P
0 g
s
.651 .757 .928 r
.58708 .52127 m .59679 .51816 L .59431 .51527 L p F P
0 g
s
.541 0 0 r
.59576 .6497 m .59201 .64742 L .59626 .65075 L p F P
0 g
s
.541 0 0 r
.59626 .65075 m .60005 .65302 L .59576 .6497 L p F P
0 g
s
.537 .037 0 r
.62176 .67238 m .61948 .66996 L .6169 .66738 L p F P
0 g
s
.009 0 0 r
.48699 .69699 m .49169 .69425 L p .48248 .70202 L F P
0 g
s
.009 0 0 r
.48248 .70202 m .48321 .70057 L .48699 .69699 L p F P
0 g
s
.484 .603 .895 r
.61119 .75104 m .62093 .75264 L p .62301 .75568 L F P
0 g
s
.393 .543 .887 r
.61119 .75104 m .62093 .75264 L .61846 .74948 L p F P
0 g
s
.393 .543 .887 r
.61846 .74948 m .61162 .74776 L .61119 .75104 L p F P
0 g
s
.462 .589 .894 r
.60855 .74712 m .61162 .74776 L .61119 .75104 L p F P
0 g
s
0 0 0 r
.46504 .64371 m .46763 .64238 L p .46738 .64349 L F P
0 g
s
0 0 0 r
.46738 .64349 m .4628 .64558 L .46504 .64371 L p F P
0 g
s
.731 .208 0 r
.57126 .70373 m .57431 .7075 L .57101 .70516 L p F P
0 g
s
.731 .208 0 r
.57065 .70331 m .57126 .70373 L p .57101 .70516 L F P
0 g
s
.634 .842 .98 r
.62583 .75864 m .6356 .75556 L .63623 .75601 L p F P
0 g
s
.593 .798 .978 r
.6356 .75556 m .62583 .75864 L .62338 .75572 L p F P
0 g
s
0 0 0 r
.42383 .67937 m .42912 .67323 L .42598 .67668 L closepath p F P
0 g
s
0 0 0 r
.42382 .67938 m .42383 .67937 L .42598 .67668 L p F P
0 g
s
.514 0 0 r
.5747 .63767 m .57852 .64004 L .57362 .63808 L p F P
0 g
s
.514 0 0 r
.57362 .63808 m .57221 .63726 L .5747 .63767 L p F P
0 g
s
.49 0 0 r
.56809 .63518 m .57221 .63726 L .5747 .63767 L p F P
0 g
s
0 0 0 r
.48248 .70202 m .48321 .70057 L .48078 .70341 L closepath p F P
0 g
s
.65 .757 .927 r
.15855 .51482 m .14961 .51792 L .15283 .5208 L p F P
0 g
s
.65 .757 .927 r
.15283 .5208 m .16176 .51771 L .15855 .51482 L p F P
0 g
s
.467 0 0 r
.54953 .62933 m .55619 .63186 L .54899 .63057 L p F P
0 g
s
.467 0 0 r
.5467 .6288 m .54953 .62933 L p .54899 .63057 L F P
0 g
s
.898 .953 .829 r
.44745 .74421 m .44756 .74408 L .44757 .74422 L closepath p F P
0 g
s
.854 .904 .869 r
.44757 .74422 m .44745 .74421 L .4399 .75092 L p F P
0 g
s
.856 .94 .875 r
.43787 .75282 m .4399 .75092 L .44001 .74762 L p F P
0 g
s
.804 .974 .905 r
.44745 .74421 m .4399 .75092 L .44001 .74762 L p F P
0 g
s
.856 .94 .875 r
.44001 .74762 m .43508 .75164 L .43787 .75282 L p F P
0 g
s
.741 .906 .951 r
.42756 .75584 m .43508 .75164 L .43787 .75282 L p F P
0 g
s
.65 .757 .928 r
.30787 .51499 m .29866 .51811 L .30163 .52098 L p F P
0 g
s
.65 .757 .928 r
.30163 .52098 m .31083 .51788 L .30787 .51499 L p F P
0 g
s
.651 .758 .928 r
.75588 .51499 m .74586 .51811 L .74809 .52098 L p F P
0 g
s
.651 .758 .928 r
.74809 .52098 m .7581 .51787 L .75588 .51499 L p F P
0 g
s
.651 .757 .928 r
.4572 .51503 m .44772 .51815 L .45045 .52103 L p F P
0 g
s
.651 .757 .928 r
.45045 .52103 m .45992 .51792 L .4572 .51503 L p F P
0 g
s
.651 .757 .928 r
.60655 .51503 m .59679 .51816 L .59927 .52103 L p F P
0 g
s
.651 .757 .928 r
.59927 .52103 m .60901 .51791 L .60655 .51503 L p F P
0 g
s
.894 .972 .823 r
.44745 .74421 m .44756 .74408 L .44792 .7407 L p F P
0 g
s
.894 .972 .823 r
.44792 .7407 m .44466 .74399 L .44745 .74421 L p F P
0 g
s
.804 .974 .905 r
.44001 .74762 m .44466 .74399 L .44745 .74421 L p F P
0 g
s
.518 0 0 r
.58949 .64558 m .59201 .64742 L .58797 .64522 L p F P
0 g
s
.518 0 0 r
.58797 .64522 m .58702 .64456 L .58949 .64558 L p F P
0 g
s
.498 0 0 r
.58311 .64209 m .58702 .64456 L .58949 .64558 L p F P
0 g
s
.65 .757 .928 r
.17072 .5146 m .16176 .51771 L .16496 .52059 L p F P
0 g
s
.65 .757 .928 r
.16496 .52059 m .17392 .51749 L .17072 .5146 L p F P
0 g
s
0 0 .317 r
.64499 .71021 m .64392 .70728 L .64213 .7031 L p F P
0 g
s
.688 .375 0 r
.64392 .70728 m .64499 .71021 L .64634 .71452 L p F P
0 g
s
0 0 0 r
.48078 .70341 m .48248 .70202 L .48089 .7052 L p F P
0 g
s
0 0 0 r
.48089 .7052 m .47553 .70955 L .48078 .70341 L p F P
0 g
s
.651 .758 .928 r
.76814 .51474 m .7581 .51787 L .76031 .52074 L p F P
0 g
s
.651 .758 .928 r
.76031 .52074 m .77034 .51762 L .76814 .51474 L p F P
0 g
s
.65 .757 .928 r
.32007 .51476 m .31083 .51788 L .31379 .52075 L p F P
0 g
s
.65 .757 .928 r
.31379 .52075 m .32301 .51764 L .32007 .51476 L p F P
0 g
s
.651 .757 .928 r
.61879 .51479 m .60901 .51791 L .61147 .52079 L p F P
0 g
s
.651 .757 .928 r
.61147 .52079 m .62123 .51767 L .61879 .51479 L p F P
0 g
s
.651 .757 .928 r
.46942 .51479 m .45992 .51792 L .46263 .52079 L p F P
0 g
s
.651 .757 .928 r
.46263 .52079 m .47212 .51768 L .46942 .51479 L p F P
0 g
s
.731 .208 0 r
.57101 .70516 m .56859 .7023 L .57065 .70331 L p F P
0 g
s
.847 .385 .038 r
.56859 .7023 m .56807 .70135 L .57065 .70331 L closepath p F P
0 g
s
.569 .114 0 r
.63014 .68275 m .62806 .68005 L .62517 .67625 L p F P
0 g
s
0 0 .476 r
.62176 .67238 m .62285 .67361 L .62517 .67625 L p F P
0 g
s
.622 .146 0 r
.62285 .67361 m .62517 .67625 L .62806 .68005 L p F P
0 g
s
.314 0 .193 r
.49593 .68977 m .50193 .68747 L p .49169 .69425 L F P
0 g
s
.333 0 .223 r
.50193 .68747 m .50237 .68626 L .49593 .68977 L closepath p F P
0 g
s
.017 .324 .81 r
.59234 .72942 m .5911 .72855 L .58858 .72474 L p F P
0 g
s
.65 .757 .928 r
.1829 .51438 m .17392 .51749 L .1771 .52037 L p F P
0 g
s
.65 .757 .928 r
.1771 .52037 m .18608 .51727 L .1829 .51438 L p F P
0 g
s
0 0 0 r
.46763 .64238 m .47384 .63958 L p .46738 .64349 L F P
0 g
s
0 0 0 r
.47384 .63958 m .47456 .63905 L .46763 .64238 L closepath p F P
0 g
s
.623 .146 0 r
.58229 .71642 m .57999 .71382 L .57707 .70999 L p F P
0 g
s
.7 .2 0 r
.57707 .70999 m .57431 .7075 L .57726 .71133 L p F P
0 g
s
.7 .2 0 r
.57726 .71133 m .57999 .71382 L .57707 .70999 L p F P
0 g
s
.579 .818 .435 r
.41975 .68516 m .4168 .68917 L .41706 .68882 L p F P
0 g
s
.683 .869 .478 r
.4168 .68917 m .41706 .68882 L .41659 .68953 L closepath p F P
0 g
s
.467 0 0 r
.54899 .63057 m .54517 .62918 L .5467 .6288 L p F P
0 g
s
.405 0 0 r
.54517 .62918 m .54173 .62823 L .5467 .6288 L closepath p F P
0 g
s
.651 .758 .928 r
.78041 .51449 m .77034 .51762 L .77253 .52049 L p F P
0 g
s
.651 .758 .928 r
.77253 .52049 m .78258 .51737 L .78041 .51449 L p F P
0 g
s
0 0 0 r
.40923 .70316 m .41067 .70043 L .40837 .7057 L p F P
0 g
s
0 0 0 r
.40837 .7057 m .40785 .70668 L .40923 .70316 L p F P
0 g
s
.65 .757 .928 r
.33227 .51452 m .32301 .51764 L .32595 .52052 L p F P
0 g
s
.65 .757 .928 r
.32595 .52052 m .33519 .51741 L .33227 .51452 L p F P
0 g
s
.651 .757 .928 r
.63103 .51455 m .62123 .51767 L .62367 .52054 L p F P
0 g
s
.651 .757 .928 r
.62367 .52054 m .63346 .51743 L .63103 .51455 L p F P
0 g
s
.651 .757 .928 r
.48165 .51456 m .47212 .51768 L .47481 .52055 L p F P
0 g
s
.651 .757 .928 r
.47481 .52055 m .48432 .51744 L .48165 .51456 L p F P
0 g
s
0 0 .305 r
.64081 .70023 m .64213 .7031 L .64392 .70728 L p F P
0 g
s
0 0 .367 r
.64213 .7031 m .64081 .70023 L .63867 .69617 L p F P
0 g
s
.188 0 0 r
.50574 .62872 m .50856 .62844 L p .504 .63028 L F P
0 g
s
.196 0 0 r
.50856 .62844 m .50574 .62872 L .50892 .62822 L closepath p F P
0 g
s
.618 .792 .357 r
.41659 .68953 m .4168 .68917 L .41501 .69226 L p F P
0 g
s
.618 .792 .357 r
.41501 .69226 m .41343 .69504 L .41659 .68953 L p F P
0 g
s
0 0 .412 r
.63465 .68939 m .63282 .68663 L .63014 .68275 L p F P
0 g
s
.626 .174 0 r
.62806 .68005 m .63014 .68275 L .63282 .68663 L p F P
0 g
s
.65 .757 .928 r
.19508 .51416 m .18608 .51727 L .18924 .52015 L p F P
0 g
s
.65 .757 .928 r
.18924 .52015 m .19824 .51705 L .19508 .51416 L p F P
0 g
s
.651 .758 .928 r
.78475 .52024 m .79483 .51712 L .79698 .51999 L p F P
0 g
s
.651 .758 .928 r
.79267 .51424 m .78258 .51737 L .78475 .52024 L p F P
0 g
s
.651 .758 .928 r
.78475 .52024 m .79483 .51712 L .79267 .51424 L p F P
0 g
s
.171 .378 .825 r
.41069 .75209 m .40776 .75029 L .40749 .74708 L p F P
0 g
s
.248 .45 .861 r
.40776 .75029 m .41069 .75209 L .41344 .75596 L p F P
0 g
s
.434 0 0 r
.58311 .64209 m .57852 .64004 L .58345 .64315 L p F P
0 g
s
.434 0 0 r
.58702 .64456 m .58311 .64209 L p .58345 .64315 L F P
0 g
s
.65 .757 .928 r
.34447 .51429 m .33519 .51741 L .33811 .52028 L p F P
0 g
s
.65 .757 .928 r
.33811 .52028 m .34738 .51717 L .34447 .51429 L p F P
0 g
s
.651 .757 .928 r
.64328 .51431 m .63346 .51743 L .63588 .5203 L p F P
0 g
s
.651 .757 .928 r
.63588 .5203 m .64568 .51719 L .64328 .51431 L p F P
0 g
s
.637 .245 0 r
.63708 .69336 m .63867 .69617 L .64081 .70023 L p F P
0 g
s
0 0 .396 r
.63867 .69617 m .63708 .69336 L .63465 .68939 L p F P
0 g
s
0 0 .149 r
.40301 .72457 m .40307 .7232 L .40307 .72322 L closepath p F P
0 g
s
0 0 .07 r
.40285 .72788 m .40301 .72457 L .40307 .72322 L p F P
0 g
s
.651 .757 .928 r
.49387 .51432 m .48432 .51744 L .48699 .52031 L p F P
0 g
s
.651 .757 .928 r
.48699 .52031 m .49653 .5172 L .49387 .51432 L p F P
0 g
s
.629 .205 0 r
.63282 .68663 m .63465 .68939 L .63708 .69336 L p F P
0 g
s
0 0 .19 r
.40307 .7232 m .40438 .71946 L .40418 .72414 L p F P
0 g
s
0 0 .19 r
.40301 .72457 m .40307 .7232 L p .40418 .72414 L F P
0 g
s
0 0 .441 r
.58717 .72296 m .58521 .72027 L .58229 .71642 L p F P
0 g
s
.641 .163 0 r
.57999 .71382 m .58229 .71642 L .58521 .72027 L p F P
0 g
s
.421 0 0 r
.56809 .63518 m .56244 .63343 L .56811 .63629 L p F P
0 g
s
.421 0 0 r
.57221 .63726 m .56809 .63518 L p .56811 .63629 L F P
0 g
s
0 0 0 r
.40678 .70956 m .40529 .71459 L .40669 .7108 L p F P
0 g
s
0 0 0 r
.40785 .70668 m .40678 .70956 L p .40669 .7108 L F P
0 g
s
0 0 0 r
.47553 .70955 m .48089 .7052 L p .47568 .71079 L F P
0 g
s
0 0 0 r
.47359 .71182 m .47553 .70955 L p .47568 .71079 L F P
0 g
s
.65 .757 .928 r
.20727 .51394 m .19824 .51705 L .20138 .51993 L p F P
0 g
s
.65 .757 .928 r
.20138 .51993 m .2104 .51683 L .20727 .51394 L p F P
0 g
s
.492 .613 .9 r
.41344 .75596 m .41687 .75562 L .4168 .75236 L p F P
0 g
s
.492 .613 .9 r
.4168 .75236 m .41069 .75209 L .41344 .75596 L p F P
0 g
s
.756 .323 .222 r
.55501 .68924 m .55763 .69311 L .55225 .69134 L p F P
0 g
s
.756 .323 .222 r
.55265 .68851 m .55501 .68924 L p .55225 .69134 L F P
0 g
s
.489 0 0 r
.55814 .63226 m .55994 .63224 L .56244 .63343 L closepath p F P
0 g
s
.373 0 0 r
.55619 .63186 m .55814 .63226 L .55994 .63224 L p F P
0 g
s
.649 .756 .927 r
.07008 .51332 m .0613 .51641 L .06467 .5193 L p F P
0 g
s
.649 .756 .927 r
.06467 .5193 m .07344 .51623 L .07008 .51332 L p F P
0 g
s
.651 .758 .928 r
.79698 .51999 m .80708 .51687 L .80921 .51974 L p F P
0 g
s
.651 .758 .928 r
.80708 .51687 m .79698 .51999 L .79483 .51712 L p F P
0 g
s
0 .146 .675 r
.40446 .74331 m .40455 .73997 L p .40749 .74649 L F P
0 g
s
0 .146 .675 r
.40749 .74649 m .40749 .74708 L .40446 .74331 L p F P
0 g
s
.65 .757 .928 r
.35668 .51405 m .34738 .51717 L .35027 .52005 L p F P
0 g
s
.65 .757 .928 r
.35027 .52005 m .35957 .51694 L .35668 .51405 L p F P
0 g
s
.651 .757 .928 r
.65553 .51406 m .64568 .51719 L .64808 .52006 L p F P
0 g
s
.651 .757 .928 r
.64808 .52006 m .65791 .51695 L .65553 .51406 L p F P
0 g
s
.651 .757 .928 r
.50611 .51407 m .49653 .5172 L .49918 .52007 L p F P
0 g
s
.651 .757 .928 r
.49918 .52007 m .50874 .51696 L .50611 .51407 L p F P
0 g
s
.555 0 0 r
.60434 .65604 m .60355 .65537 L .60005 .65302 L p F P
0 g
s
0 0 0 r
.4168 .68917 m .41975 .68516 L .41606 .69084 L p F P
0 g
s
0 0 0 r
.41606 .69084 m .41501 .69226 L .4168 .68917 L p F P
0 g
s
0 0 .443 r
.58717 .72296 m .58858 .72474 L .58606 .7214 L p F P
0 g
s
0 0 .443 r
.58606 .7214 m .58521 .72027 L .58717 .72296 L p F P
0 g
s
.365 0 0 r
.54173 .62823 m .53309 .62737 L .54113 .62947 L p F P
0 g
s
.365 0 0 r
.54517 .62918 m .54173 .62823 L p .54113 .62947 L F P
0 g
s
.31 0 0 r
.50856 .62844 m .50892 .62822 L .52043 .6273 L p F P
0 g
s
.941 .786 .324 r
.64817 .72663 m .64875 .72966 L .64817 .73454 L p F P
0 g
s
.834 .631 .084 r
.64875 .72966 m .64817 .72663 L .64797 .72197 L p F P
0 g
s
.65 .757 .928 r
.21946 .51372 m .2104 .51683 L .21353 .51971 L p F P
0 g
s
.65 .757 .928 r
.21353 .51971 m .22257 .51661 L .21946 .51372 L p F P
0 g
s
0 0 0 r
.47568 .71079 m .4723 .71357 L .47359 .71182 L p F P
0 g
s
0 0 0 r
.4723 .71357 m .47359 .71182 L .47038 .71566 L closepath p F P
0 g
s
.651 .758 .928 r
.80921 .51974 m .81934 .51662 L .82144 .51949 L p F P
0 g
s
.651 .758 .928 r
.81934 .51662 m .80921 .51974 L .80708 .51687 L p F P
0 g
s
.703 .925 .596 r
.46394 .72351 m .46539 .72174 L .46469 .72283 L closepath p F P
0 g
s
.635 .897 .576 r
.45998 .72794 m .46394 .72351 L .46469 .72283 L p F P
0 g
s
.649 .756 .927 r
.08224 .51314 m .07344 .51623 L .07679 .51912 L p F P
0 g
s
.649 .756 .927 r
.07679 .51912 m .08558 .51604 L .08224 .51314 L p F P
0 g
s
.65 .757 .928 r
.36889 .51381 m .35957 .51694 L .36244 .51981 L p F P
0 g
s
.65 .757 .928 r
.36244 .51981 m .37176 .5167 L .36889 .51381 L p F P
0 g
s
.651 .757 .928 r
.66778 .51382 m .65791 .51695 L .66029 .51982 L p F P
0 g
s
.651 .757 .928 r
.66029 .51982 m .67015 .5167 L .66778 .51382 L p F P
0 g
s
.651 .757 .928 r
.51834 .51383 m .50874 .51696 L .51137 .51983 L p F P
0 g
s
.651 .757 .928 r
.51137 .51983 m .52095 .51672 L .51834 .51383 L p F P
0 g
s
.723 .347 .337 r
.54078 .6821 m .53802 .6817 L .53663 .68488 L p F P
0 g
s
.723 .347 .337 r
.53663 .68488 m .54355 .6859 L .54078 .6821 L p F P
0 g
s
.117 .364 .826 r
.59234 .72942 m .59697 .73282 L .59813 .7357 L p F P
0 g
s
0 .237 .751 r
.59101 .72656 m .59234 .72942 L .59697 .73282 L p F P
0 g
s
.017 .324 .81 r
.58858 .72474 m .59101 .72656 L .59234 .72942 L p F P
0 g
s
.65 .757 .928 r
.23165 .51349 m .22257 .51661 L .22568 .51949 L p F P
0 g
s
.65 .757 .928 r
.22568 .51949 m .23475 .51638 L .23165 .51349 L p F P
0 g
s
.651 .758 .928 r
.82144 .51949 m .83159 .51636 L .83368 .51924 L p F P
0 g
s
.651 .758 .928 r
.83159 .51636 m .82144 .51949 L .81934 .51662 L p F P
0 g
s
.65 .757 .928 r
.38111 .51358 m .37176 .5167 L .37462 .51958 L p F P
0 g
s
.65 .757 .928 r
.37462 .51958 m .38396 .51646 L .38111 .51358 L p F P
0 g
s
.651 .757 .928 r
.68004 .51357 m .67015 .5167 L .67251 .51958 L p F P
0 g
s
.651 .757 .928 r
.67251 .51958 m .68239 .51646 L .68004 .51357 L p F P
0 g
s
0 0 .19 r
.40418 .72414 m .40286 .72784 L .40301 .72457 L p F P
0 g
s
0 0 .077 r
.40286 .72784 m .40301 .72457 L .40285 .72788 L closepath p F P
0 g
s
.651 .757 .928 r
.53058 .51359 m .52095 .51672 L .52356 .5196 L p F P
0 g
s
.651 .757 .928 r
.52356 .5196 m .53317 .51648 L .53058 .51359 L p F P
0 g
s
.649 .756 .927 r
.09441 .51295 m .08558 .51604 L .08892 .51894 L p F P
0 g
s
.649 .756 .927 r
.08892 .51894 m .09773 .51585 L .09441 .51295 L p F P
0 g
s
.479 .123 .283 r
.50193 .68747 m .50237 .68626 L .5088 .68599 L closepath p F P
0 g
s
0 0 0 r
.47038 .71566 m .46539 .72174 L .46915 .71732 L p F P
0 g
s
.651 .758 .928 r
.83368 .51924 m .84385 .51611 L .84592 .51898 L p F P
0 g
s
.651 .758 .928 r
.84385 .51611 m .83368 .51924 L .83159 .51636 L p F P
0 g
s
.973 .903 .687 r
.64712 .74272 m .64659 .7397 L p .64404 .74672 L F P
0 g
s
.973 .903 .687 r
.64404 .74672 m .64521 .74674 L .64712 .74272 L p F P
0 g
s
.978 .886 .525 r
.64712 .74272 m .64659 .7397 L .64817 .73454 L p F P
0 g
s
.65 .757 .928 r
.24385 .51326 m .23475 .51638 L .23783 .51926 L p F P
0 g
s
.65 .757 .928 r
.23783 .51926 m .24693 .51615 L .24385 .51326 L p F P
0 g
s
.651 .758 .928 r
.6923 .51333 m .68239 .51646 L .68472 .51934 L p F P
0 g
s
.651 .758 .928 r
.68472 .51934 m .69463 .51622 L .6923 .51333 L p F P
0 g
s
.65 .757 .928 r
.39333 .51334 m .38396 .51646 L .38679 .51934 L p F P
0 g
s
.65 .757 .928 r
.38679 .51934 m .39616 .51623 L .39333 .51334 L p F P
0 g
s
.651 .757 .928 r
.54282 .51335 m .53317 .51648 L .53576 .51936 L p F P
0 g
s
.651 .757 .928 r
.53576 .51936 m .54539 .51624 L .54282 .51335 L p F P
0 g
s
.584 .035 0 r
.60434 .65604 m .60737 .65885 L .60401 .65646 L p F P
0 g
s
.584 .035 0 r
.60401 .65646 m .6019 .65456 L .60434 .65604 L p F P
0 g
s
.555 0 0 r
.60005 .65302 m .6019 .65456 L .60434 .65604 L p F P
0 g
s
.649 .756 .927 r
.10659 .51275 m .09773 .51585 L .10105 .51874 L p F P
0 g
s
.649 .756 .927 r
.10105 .51874 m .10989 .51565 L .10659 .51275 L p F P
0 g
s
.756 .323 .222 r
.55225 .69134 m .5512 .69002 L .55265 .68851 L p F P
0 g
s
.804 .389 .262 r
.5512 .69002 m .54968 .68746 L .55265 .68851 L closepath p F P
0 g
s
.107 0 .034 r
.48248 .70202 m .49036 .69764 L p .48308 .70401 L F P
0 g
s
.107 0 .034 r
.48308 .70401 m .48089 .7052 L .48248 .70202 L p F P
0 g
s
.009 0 0 r
.49169 .69425 m .49036 .69764 L .48248 .70202 L p F P
0 g
s
.131 0 0 r
.48409 .63556 m .48564 .63435 L .49552 .63179 L p F P
0 g
s
.07 0 0 r
.49635 .63126 m .49552 .63179 L .48564 .63435 L p F P
0 g
s
0 0 0 r
.48564 .63435 m .48409 .63556 L .47456 .63905 L p F P
0 g
s
.755 .858 .926 r
.42716 .75268 m .4228 .75476 L .42558 .75699 L p F P
0 g
s
.755 .858 .926 r
.42558 .75699 m .42756 .75584 L .42716 .75268 L p F P
0 g
s
.293 0 0 r
.50613 .62993 m .50856 .62844 L .51814 .62855 L p F P
0 g
s
.31 0 0 r
.52043 .6273 m .51814 .62855 L .50856 .62844 L p F P
0 g
s
.188 0 0 r
.50856 .62844 m .50613 .62993 L .504 .63028 L p F P
0 g
s
.696 .316 .324 r
.53802 .6817 m .53263 .68113 L .53584 .6848 L p F P
0 g
s
.696 .316 .324 r
.53584 .6848 m .53663 .68488 L .53802 .6817 L p F P
0 g
s
.598 .253 .356 r
.51211 .68525 m .51319 .68169 L .52144 .68105 L p F P
0 g
s
.494 .162 .333 r
.51319 .68169 m .51211 .68525 L .5088 .68599 L p F P
0 g
s
0 0 .466 r
.40302 .73578 m .40331 .73308 L .40464 .7391 L p F P
0 g
s
0 0 .466 r
.40464 .7391 m .40455 .73997 L .40302 .73578 L p F P
0 g
s
.594 .06 0 r
.61046 .6613 m .60737 .65885 L .61095 .66241 L p F P
0 g
s
.594 .06 0 r
.61095 .66241 m .61406 .66486 L .61046 .6613 L p F P
0 g
s
.65 .757 .928 r
.25605 .51303 m .24693 .51615 L .24999 .51903 L p F P
0 g
s
.65 .757 .928 r
.24999 .51903 m .25911 .51592 L .25605 .51303 L p F P
0 g
s
.833 .389 .174 r
.56211 .69513 m .55763 .69311 L .56022 .697 L p F P
0 g
s
.833 .389 .174 r
.56022 .697 m .56444 .6991 L .56211 .69513 L p F P
0 g
s
.409 .565 .898 r
.61162 .74776 m .60855 .74712 L .60606 .74328 L p F P
0 g
s
.797 .874 .904 r
.6356 .75556 m .63605 .75524 L .63623 .75601 L closepath p F P
0 g
s
.861 .88 .85 r
.64391 .74834 m .63605 .75524 L .63623 .75601 L p F P
0 g
s
.651 .758 .928 r
.70457 .51308 m .69463 .51622 L .69695 .51909 L p F P
0 g
s
.651 .758 .928 r
.69695 .51909 m .70687 .51597 L .70457 .51308 L p F P
0 g
s
.016 .319 .806 r
.60401 .74197 m .60289 .73908 L .59813 .7357 L p F P
0 g
s
0 .281 .783 r
.59697 .73282 m .59813 .7357 L .60289 .73908 L p F P
0 g
s
.65 .757 .928 r
.40555 .5131 m .39616 .51623 L .39897 .5191 L p F P
0 g
s
.65 .757 .928 r
.39897 .5191 m .40836 .51599 L .40555 .5131 L p F P
0 g
s
.651 .757 .928 r
.55506 .51311 m .54539 .51624 L .54796 .51912 L p F P
0 g
s
.651 .757 .928 r
.54796 .51912 m .55762 .516 L .55506 .51311 L p F P
0 g
s
.41 0 0 r
.53309 .62737 m .54113 .62947 L .53186 .6288 L p F P
0 g
s
.41 0 0 r
.53291 .62736 m .53309 .62737 L p .53186 .6288 L F P
0 g
s
.649 .756 .927 r
.11876 .51255 m .10989 .51565 L .11318 .51854 L p F P
0 g
s
.649 .756 .927 r
.11318 .51854 m .12205 .51545 L .11876 .51255 L p F P
0 g
s
0 0 0 r
.41343 .69504 m .41067 .70043 L .41301 .69633 L p F P
0 g
s
0 0 0 r
.41501 .69226 m .41343 .69504 L p .41301 .69633 L F P
0 g
s
.41 0 0 r
.53186 .6288 m .53037 .62847 L .53291 .62736 L p F P
0 g
s
.348 0 0 r
.53037 .62847 m .52193 .62728 L .53291 .62736 L closepath p F P
0 g
s
0 0 0 r
.47384 .63958 m .47456 .63905 L .48409 .63556 L p F P
0 g
s
.35 0 0 r
.52043 .6273 m .52193 .62728 L p .52039 .62879 L F P
0 g
s
.35 0 0 r
.52039 .62879 m .51814 .62855 L .52043 .6273 L p F P
0 g
s
.35 0 0 r
.52193 .62728 m .53037 .62847 L p .52039 .62879 L F P
0 g
s
.575 .077 0 r
.62176 .67238 m .62285 .67361 L .62029 .67102 L p F P
0 g
s
.575 .077 0 r
.62029 .67102 m .61932 .66993 L .62176 .67238 L p F P
0 g
s
.537 .037 0 r
.6169 .66738 m .61932 .66993 L .62176 .67238 L p F P
0 g
s
.698 .889 .968 r
.43508 .75164 m .42756 .75584 L .42716 .75268 L p F P
0 g
s
.65 .757 .928 r
.26826 .5128 m .25911 .51592 L .26215 .5188 L p F P
0 g
s
.65 .757 .928 r
.26215 .5188 m .27129 .51569 L .26826 .5128 L p F P
0 g
s
.871 .649 .12 r
.64719 .71898 m .64797 .72197 L .64817 .72663 L p F P
0 g
s
.754 .495 0 r
.64797 .72197 m .64719 .71898 L .64634 .71452 L p F P
0 g
s
.651 .758 .928 r
.71683 .51284 m .70687 .51597 L .70917 .51885 L p F P
0 g
s
.651 .758 .928 r
.70917 .51885 m .71912 .51573 L .71683 .51284 L p F P
0 g
s
0 0 0 r
.4335 .66844 m .43503 .6669 L .43401 .66781 L closepath p F P
0 g
s
.542 .837 .509 r
.43401 .66781 m .4335 .66844 L .42912 .67323 L p F P
0 g
s
.65 .757 .928 r
.41778 .51286 m .40836 .51599 L .41115 .51887 L p F P
0 g
s
.65 .757 .928 r
.41115 .51887 m .42056 .51575 L .41778 .51286 L p F P
0 g
s
.651 .757 .928 r
.56731 .51287 m .55762 .516 L .56016 .51888 L p F P
0 g
s
.651 .757 .928 r
.56016 .51888 m .56984 .51576 L .56731 .51287 L p F P
0 g
s
.65 .756 .927 r
.13095 .51234 m .12205 .51545 L .12532 .51834 L p F P
0 g
s
.65 .756 .927 r
.12532 .51834 m .13421 .51524 L .13095 .51234 L p F P
0 g
s
.582 .013 0 r
.59201 .64742 m .58797 .64522 L .59219 .64856 L p F P
0 g
s
.582 .013 0 r
.59219 .64856 m .59626 .65075 L .59201 .64742 L p F P
0 g
s
.424 .629 .939 r
.62338 .75572 m .62301 .75568 L .62278 .75496 L closepath p F P
0 g
s
.484 .603 .895 r
.62093 .75264 m .62278 .75496 L .62301 .75568 L p F P
0 g
s
.567 .719 .944 r
.4228 .75476 m .41687 .75562 L .4168 .75236 L p F P
0 g
s
.65 .757 .928 r
.28046 .51257 m .27129 .51569 L .27432 .51857 L p F P
0 g
s
.65 .757 .928 r
.27432 .51857 m .28348 .51546 L .28046 .51257 L p F P
0 g
s
.651 .758 .928 r
.7291 .51259 m .71912 .51573 L .7214 .5186 L p F P
0 g
s
.651 .758 .928 r
.7214 .5186 m .73137 .51548 L .7291 .51259 L p F P
0 g
s
.65 .757 .928 r
.43001 .51262 m .42056 .51575 L .42334 .51863 L p F P
0 g
s
.65 .757 .928 r
.42334 .51863 m .43277 .51551 L .43001 .51262 L p F P
0 g
s
.635 .281 .355 r
.53263 .68113 m .53584 .6848 L .52617 .68426 L p F P
0 g
s
.635 .281 .355 r
.52473 .68082 m .53263 .68113 L p .52617 .68426 L F P
0 g
s
.651 .757 .928 r
.57956 .51263 m .56984 .51576 L .57237 .51864 L p F P
0 g
s
.651 .757 .928 r
.57237 .51864 m .58207 .51552 L .57956 .51263 L p F P
0 g
s
.665 .929 .638 r
.46539 .72174 m .46915 .71732 L .46298 .72376 L p F P
0 g
s
.665 .929 .638 r
.46394 .72351 m .46539 .72174 L p .46298 .72376 L F P
0 g
s
.593 .798 .978 r
.62338 .75572 m .6332 .75352 L .6356 .75556 L p F P
0 g
s
.585 .706 .926 r
.63077 .75122 m .6332 .75352 L .62338 .75572 L p F P
0 g
s
.585 .706 .926 r
.62466 .75207 m .63077 .75122 L p .62338 .75572 L F P
0 g
s
.585 .706 .926 r
.62338 .75572 m .62278 .75496 L .62466 .75207 L p F P
0 g
s
.851 .4 .121 r
.56859 .7023 m .56807 .70135 L .56444 .6991 L p F P
0 g
s
.598 .253 .356 r
.52144 .68105 m .52416 .6826 L p .51211 .68525 L F P
0 g
s
.599 .246 .342 r
.52416 .6826 m .52144 .68105 L .52473 .68082 L closepath p F P
0 g
s
.004 .308 .8 r
.60401 .74197 m .60606 .74328 L .60355 .73957 L p F P
0 g
s
.004 .308 .8 r
.60355 .73957 m .60289 .73908 L .60401 .74197 L p F P
0 g
s
.65 .756 .927 r
.14313 .51213 m .13421 .51524 L .13746 .51813 L p F P
0 g
s
.65 .756 .927 r
.13746 .51813 m .14638 .51503 L .14313 .51213 L p F P
0 g
s
0 .259 .765 r
.59101 .72656 m .58858 .72474 L .58606 .7214 L p F P
0 g
s
.65 .757 .928 r
.29268 .51233 m .28348 .51546 L .28648 .51834 L p F P
0 g
s
.65 .757 .928 r
.28648 .51834 m .29567 .51523 L .29268 .51233 L p F P
0 g
s
.651 .758 .928 r
.74138 .51234 m .73137 .51548 L .73363 .51836 L p F P
0 g
s
.651 .758 .928 r
.73363 .51836 m .74362 .51523 L .74138 .51234 L p F P
0 g
s
.588 .07 0 r
.61932 .66993 m .6169 .66738 L .61406 .66486 L p F P
0 g
s
.665 .929 .638 r
.46298 .72376 m .46197 .72503 L .46394 .72351 L p F P
0 g
s
.711 .946 .65 r
.46197 .72503 m .46394 .72351 L .45998 .72794 L closepath p F P
0 g
s
.651 .757 .928 r
.44224 .51238 m .43277 .51551 L .43553 .51839 L p F P
0 g
s
.651 .757 .928 r
.43553 .51839 m .44499 .51527 L .44224 .51238 L p F P
0 g
s
.651 .757 .928 r
.59181 .51238 m .58207 .51552 L .58458 .5184 L p F P
0 g
s
.651 .757 .928 r
.58458 .5184 m .59431 .51527 L .59181 .51238 L p F P
0 g
s
.536 0 0 r
.56244 .63343 m .56811 .63629 L .562 .63467 L p F P
0 g
s
.536 0 0 r
.55814 .63226 m .56244 .63343 L p .562 .63467 L F P
0 g
s
.635 .281 .355 r
.52617 .68426 m .52416 .6826 L .52473 .68082 L p F P
0 g
s
.905 .973 .804 r
.64391 .74834 m .64404 .74672 L .64521 .74674 L closepath p F P
0 g
s
.768 .849 .912 r
.63605 .75524 m .6356 .75556 L .6332 .75352 L p F P
0 g
s
.65 .757 .927 r
.15532 .51192 m .14638 .51503 L .14961 .51792 L p F P
0 g
s
.65 .757 .927 r
.14961 .51792 m .15855 .51482 L .15532 .51192 L p F P
0 g
s
.768 .849 .912 r
.6332 .75352 m .63506 .75237 L .63605 .75524 L p F P
0 g
s
.809 .869 .891 r
.64404 .74672 m .64391 .74834 L .63605 .75524 L p F P
0 g
s
.809 .869 .891 r
.64288 .74643 m .64404 .74672 L p .63605 .75524 L F P
0 g
s
.809 .869 .891 r
.63605 .75524 m .63506 .75237 L .64288 .74643 L p F P
0 g
s
0 0 .024 r
.40529 .71459 m .40669 .7108 L .40579 .71568 L p F P
0 g
s
0 0 .024 r
.40579 .71568 m .40438 .71946 L .40529 .71459 L p F P
0 g
s
.65 .757 .928 r
.30489 .5121 m .29567 .51523 L .29866 .51811 L p F P
0 g
s
.65 .757 .928 r
.29866 .51811 m .30787 .51499 L .30489 .5121 L p F P
0 g
s
.651 .758 .928 r
.75366 .5121 m .74362 .51523 L .74586 .51811 L p F P
0 g
s
.651 .758 .928 r
.74586 .51811 m .75588 .51499 L .75366 .5121 L p F P
0 g
s
.338 0 .207 r
.49169 .69425 m .50069 .69091 L p .49591 .69563 L F P
0 g
s
.338 0 .207 r
.49591 .69563 m .49036 .69764 L .49169 .69425 L p F P
0 g
s
.314 0 .193 r
.50193 .68747 m .50069 .69091 L .49169 .69425 L p F P
0 g
s
.479 .122 .282 r
.50069 .69091 m .50193 .68747 L .5088 .68599 L p F P
0 g
s
.651 .757 .928 r
.45448 .51214 m .44499 .51527 L .44772 .51815 L p F P
0 g
s
.651 .757 .928 r
.44772 .51815 m .4572 .51503 L .45448 .51214 L p F P
0 g
s
.651 .757 .928 r
.60407 .51214 m .59431 .51527 L .59679 .51816 L p F P
0 g
s
.651 .757 .928 r
.59679 .51816 m .60655 .51503 L .60407 .51214 L p F P
0 g
s
.768 .346 .249 r
.54968 .68746 m .54355 .6859 L .54631 .68972 L p F P
0 g
s
.768 .346 .249 r
.5512 .69002 m .54968 .68746 L p .54631 .68972 L F P
0 g
s
.178 0 0 r
.49552 .63179 m .49635 .63126 L .504 .63028 L closepath p F P
0 g
s
.551 0 0 r
.57852 .64004 m .57362 .63808 L .57847 .64121 L p F P
0 g
s
.551 0 0 r
.57847 .64121 m .58345 .64315 L .57852 .64004 L p F P
0 g
s
.813 .529 0 r
.6458 .71301 m .64634 .71452 L .64719 .71898 L p F P
0 g
s
.688 .375 0 r
.64455 .70933 m .64392 .70728 L p .64634 .71452 L F P
0 g
s
.688 .375 0 r
.64634 .71452 m .6458 .71301 L .64455 .70933 L p F P
0 g
s
.65 .757 .927 r
.16752 .5117 m .15855 .51482 L .16176 .51771 L p F P
0 g
s
.65 .757 .927 r
.16176 .51771 m .17072 .5146 L .16752 .5117 L p F P
0 g
s
.606 .901 .616 r
.45998 .72794 m .45459 .73414 L .45642 .7303 L p F P
0 g
s
.606 .901 .616 r
.46197 .72503 m .45998 .72794 L p .45642 .7303 L F P
0 g
s
.427 .534 .863 r
.41069 .75209 m .4168 .75236 L .41628 .74922 L p F P
0 g
s
.427 .534 .863 r
.41628 .74922 m .40797 .74746 L .41069 .75209 L p F P
0 g
s
.171 .378 .825 r
.40749 .74708 m .40797 .74746 L .41069 .75209 L p F P
0 g
s
.651 .758 .928 r
.76594 .51185 m .75588 .51499 L .7581 .51787 L p F P
0 g
s
.651 .758 .928 r
.7581 .51787 m .76814 .51474 L .76594 .51185 L p F P
0 g
s
.65 .757 .928 r
.31711 .51186 m .30787 .51499 L .31083 .51788 L p F P
0 g
s
.65 .757 .928 r
.31083 .51788 m .32007 .51476 L .31711 .51186 L p F P
0 g
s
0 0 0 r
.44228 .66018 m .44285 .65969 L .44061 .66223 L p F P
0 g
s
0 0 0 r
.44061 .66223 m .43503 .6669 L .44228 .66018 L p F P
0 g
s
0 0 0 r
.44285 .65969 m .44311 .65946 L .44228 .66018 L closepath p F P
0 g
s
.651 .757 .928 r
.61633 .5119 m .60655 .51503 L .60901 .51791 L p F P
0 g
s
.651 .757 .928 r
.60901 .51791 m .61879 .51479 L .61633 .5119 L p F P
0 g
s
.651 .757 .928 r
.46672 .5119 m .4572 .51503 L .45992 .51792 L p F P
0 g
s
.651 .757 .928 r
.45992 .51792 m .46942 .51479 L .46672 .5119 L p F P
0 g
s
.585 .705 .926 r
.62278 .75496 m .62093 .75264 L .62466 .75207 L closepath p F P
0 g
s
0 0 .261 r
.40287 .72814 m .40285 .72788 L .40286 .72784 L closepath p F P
0 g
s
0 0 .245 r
.40285 .72788 m .40287 .72814 L .40331 .73308 L p F P
0 g
s
0 0 0 r
.44285 .65969 m .44311 .65946 L .45174 .65278 L p F P
0 g
s
0 0 0 r
.43503 .6669 m .44061 .66223 L p .43459 .66813 L F P
0 g
s
0 0 0 r
.4335 .66844 m .43503 .6669 L p .43459 .66813 L F P
0 g
s
0 0 .392 r
.40286 .72784 m .40418 .72414 L .40487 .72857 L p F P
0 g
s
0 0 .392 r
.40287 .72814 m .40286 .72784 L p .40487 .72857 L F P
0 g
s
.746 .235 0 r
.57431 .7075 m .57101 .70516 L .57409 .70895 L p F P
0 g
s
.746 .235 0 r
.57409 .70895 m .57726 .71133 L .57431 .7075 L p F P
0 g
s
0 0 0 r
.43459 .66813 m .43182 .67045 L .4335 .66844 L p F P
0 g
s
0 0 0 r
.43182 .67045 m .4335 .66844 L .42912 .67323 L closepath p F P
0 g
s
.74 .216 0 r
.56859 .7023 m .57101 .70516 L .56711 .70298 L p F P
0 g
s
.74 .216 0 r
.56711 .70298 m .56608 .70185 L .56859 .7023 L p F P
0 g
s
.851 .4 .121 r
.56444 .6991 m .56608 .70185 L .56859 .7023 L p F P
0 g
s
.622 .146 0 r
.62806 .68005 m .62574 .67741 L .62285 .67361 L p F P
0 g
s
.668 .177 0 r
.62285 .67361 m .62029 .67102 L .62318 .67483 L p F P
0 g
s
.668 .177 0 r
.62318 .67483 m .62574 .67741 L .62285 .67361 L p F P
0 g
s
.467 0 0 r
.54322 .62966 m .54517 .62918 L .54899 .63057 L closepath p F P
0 g
s
.365 0 0 r
.54113 .62947 m .54322 .62966 L .54517 .62918 L p F P
0 g
s
.986 .888 .555 r
.64757 .73152 m .64817 .73454 L .64659 .7397 L p F P
0 g
s
.941 .786 .324 r
.64817 .73454 m .64757 .73152 L .64817 .72663 L p F P
0 g
s
.65 .757 .928 r
.17972 .51149 m .17072 .5146 L .17392 .51749 L p F P
0 g
s
.65 .757 .928 r
.17392 .51749 m .1829 .51438 L .17972 .51149 L p F P
0 g
s
0 0 .392 r
.40487 .72857 m .40356 .7323 L .40287 .72814 L p F P
0 g
s
0 0 .379 r
.40356 .7323 m .40331 .73308 L .40287 .72814 L closepath p F P
0 g
s
.651 .758 .928 r
.77822 .5116 m .76814 .51474 L .77034 .51762 L p F P
0 g
s
.651 .758 .928 r
.77034 .51762 m .78041 .51449 L .77822 .5116 L p F P
0 g
s
.65 .757 .928 r
.32933 .51163 m .32007 .51476 L .32301 .51764 L p F P
0 g
s
.65 .757 .928 r
.32301 .51764 m .33227 .51452 L .32933 .51163 L p F P
0 g
s
.651 .757 .928 r
.6286 .51166 m .61879 .51479 L .62123 .51767 L p F P
0 g
s
.651 .757 .928 r
.62123 .51767 m .63103 .51455 L .6286 .51166 L p F P
0 g
s
.651 .757 .928 r
.47896 .51166 m .46942 .51479 L .47212 .51768 L p F P
0 g
s
.651 .757 .928 r
.47212 .51768 m .48165 .51456 L .47896 .51166 L p F P
0 g
s
.863 .996 .783 r
.45429 .73448 m .45459 .73414 L .4545 .7344 L closepath p F P
0 g
s
.794 .998 .799 r
.44792 .7407 m .45429 .73448 L .4545 .7344 L p F P
0 g
s
.049 0 0 r
.47179 .64137 m .47384 .63958 L .48305 .63635 L p F P
0 g
s
0 0 0 r
.48409 .63556 m .48305 .63635 L .47384 .63958 L p F P
0 g
s
0 0 0 r
.47384 .63958 m .47179 .64137 L .46738 .64349 L p F P
0 g
s
.782 .447 0 r
.64455 .70933 m .64392 .70728 L .64328 .70586 L closepath p F P
0 g
s
0 0 .305 r
.64201 .70308 m .64081 .70023 L p .64392 .70728 L F P
0 g
s
0 0 .305 r
.64392 .70728 m .64328 .70586 L .64201 .70308 L p F P
0 g
s
.65 .757 .928 r
.19192 .51126 m .1829 .51438 L .18608 .51727 L p F P
0 g
s
.65 .757 .928 r
.18608 .51727 m .19508 .51416 L .19192 .51126 L p F P
0 g
s
.582 .02 0 r
.6019 .65456 m .60005 .65302 L .59626 .65075 L p F P
0 g
s
.817 .971 .898 r
.44145 .74393 m .43229 .75032 L .43508 .75164 L p F P
0 g
s
.817 .971 .898 r
.43508 .75164 m .44001 .74762 L .44145 .74393 L p F P
0 g
s
.698 .889 .968 r
.42716 .75268 m .43229 .75032 L .43508 .75164 L p F P
0 g
s
0 0 0 r
.41067 .70043 m .41301 .69633 L .41077 .70159 L p F P
0 g
s
0 0 0 r
.41077 .70159 m .40837 .7057 L .41067 .70043 L p F P
0 g
s
.651 .758 .928 r
.79051 .51134 m .78041 .51449 L .78258 .51737 L p F P
0 g
s
.651 .758 .928 r
.78258 .51737 m .79267 .51424 L .79051 .51134 L p F P
0 g
s
.65 .757 .928 r
.34156 .51139 m .33227 .51452 L .33519 .51741 L p F P
0 g
s
.65 .757 .928 r
.33519 .51741 m .34447 .51429 L .34156 .51139 L p F P
0 g
s
.626 .174 0 r
.63282 .68663 m .63074 .68393 L .62806 .68005 L p F P
0 g
s
.677 .206 0 r
.62574 .67741 m .62806 .68005 L .63074 .68393 L p F P
0 g
s
.651 .757 .928 r
.64086 .51141 m .63103 .51455 L .63346 .51743 L p F P
0 g
s
.651 .757 .928 r
.63346 .51743 m .64328 .51431 L .64086 .51141 L p F P
0 g
s
.651 .757 .928 r
.49121 .51142 m .48165 .51456 L .48432 .51744 L p F P
0 g
s
.651 .757 .928 r
.48432 .51744 m .49387 .51432 L .49121 .51142 L p F P
0 g
s
.315 .521 .896 r
.61162 .74776 m .61846 .74948 L .61598 .7463 L p F P
0 g
s
.315 .521 .896 r
.61598 .7463 m .61115 .74471 L .61162 .74776 L p F P
0 g
s
.409 .565 .898 r
.60606 .74328 m .61115 .74471 L .61162 .74776 L p F P
0 g
s
0 0 0 r
.44285 .65969 m .45015 .65471 L p .44183 .66139 L F P
0 g
s
0 0 0 r
.44183 .66139 m .44061 .66223 L .44285 .65969 L p F P
0 g
s
0 0 0 r
.45246 .65228 m .45015 .65471 L .44285 .65969 L p F P
0 g
s
0 0 0 r
.45174 .65278 m .45246 .65228 L p .44285 .65969 L F P
0 g
s
0 0 0 r
.42912 .67323 m .43182 .67045 L p .42858 .6745 L F P
0 g
s
0 0 0 r
.42383 .67937 m .42912 .67323 L p .42858 .6745 L F P
0 g
s
.641 .163 0 r
.58521 .72027 m .58287 .71768 L .57999 .71382 L p F P
0 g
s
.704 .207 0 r
.57999 .71382 m .57726 .71133 L .58018 .71518 L p F P
0 g
s
.704 .207 0 r
.58018 .71518 m .58287 .71768 L .57999 .71382 L p F P
0 g
s
.819 .991 .738 r
.45429 .73448 m .45459 .73414 L .45642 .7303 L p F P
0 g
s
.819 .991 .738 r
.45642 .7303 m .45149 .73526 L .45429 .73448 L p F P
0 g
s
.756 .995 .833 r
.45429 .73448 m .44792 .7407 L .44948 .73696 L p F P
0 g
s
.756 .995 .833 r
.44948 .73696 m .45149 .73526 L .45429 .73448 L p F P
0 g
s
.754 .377 0 r
.64081 .70023 m .64201 .70308 L .63951 .69806 L p F P
0 g
s
.754 .377 0 r
.63951 .69806 m .63925 .69741 L .64081 .70023 L p F P
0 g
s
.637 .245 0 r
.64081 .70023 m .63925 .69741 L .63708 .69336 L p F P
0 g
s
.65 .757 .928 r
.20413 .51104 m .19508 .51416 L .19824 .51705 L p F P
0 g
s
.65 .757 .928 r
.19824 .51705 m .20727 .51394 L .20413 .51104 L p F P
0 g
s
.761 .967 .929 r
.44466 .74399 m .44001 .74762 L .44145 .74393 L p F P
0 g
s
0 0 0 r
.45246 .65228 m .45268 .65209 L .45174 .65278 L closepath p F P
0 g
s
.651 .758 .928 r
.79483 .51712 m .80495 .51399 L .80708 .51687 L p F P
0 g
s
.651 .758 .928 r
.8028 .51109 m .79267 .51424 L .79483 .51712 L p F P
0 g
s
.651 .758 .928 r
.79483 .51712 m .80495 .51399 L .8028 .51109 L p F P
0 g
s
.629 .205 0 r
.63708 .69336 m .63526 .6906 L .63282 .68663 L p F P
0 g
s
.683 .236 0 r
.63074 .68393 m .63282 .68663 L .63526 .6906 L p F P
0 g
s
.65 .757 .928 r
.35379 .51116 m .34447 .51429 L .34738 .51717 L p F P
0 g
s
.65 .757 .928 r
.34738 .51717 m .35668 .51405 L .35379 .51116 L p F P
0 g
s
.651 .757 .928 r
.65313 .51117 m .64328 .51431 L .64568 .51719 L p F P
0 g
s
.651 .757 .928 r
.64568 .51719 m .65553 .51406 L .65313 .51117 L p F P
0 g
s
.651 .757 .928 r
.50346 .51118 m .49387 .51432 L .49653 .5172 L p F P
0 g
s
.651 .757 .928 r
.49653 .5172 m .50611 .51407 L .50346 .51118 L p F P
0 g
s
.544 0 0 r
.58578 .64415 m .58702 .64456 L .58797 .64522 L closepath p F P
0 g
s
.434 0 0 r
.58345 .64315 m .58578 .64415 L .58702 .64456 L p F P
0 g
s
.65 .23 0 r
.63526 .6906 m .63708 .69336 L .63925 .69741 L p F P
0 g
s
0 0 0 r
.45246 .65228 m .45268 .65209 L .46224 .64613 L p F P
0 g
s
0 0 0 r
.4628 .64558 m .46224 .64613 L .45268 .65209 L p F P
0 g
s
.528 0 0 r
.57093 .63712 m .57221 .63726 L .57362 .63808 L closepath p F P
0 g
s
.421 0 0 r
.56811 .63629 m .57093 .63712 L .57221 .63726 L p F P
0 g
s
.84 .998 .825 r
.44466 .74399 m .44792 .7407 L .44948 .73696 L p F P
0 g
s
0 0 0 r
.47079 .71564 m .47568 .71079 L .4723 .71357 L closepath p F P
0 g
s
0 0 0 r
.46915 .71732 m .47079 .71564 L .4723 .71357 L p F P
0 g
s
.536 0 0 r
.562 .63467 m .55742 .63237 L .55814 .63226 L p F P
0 g
s
.48 0 0 r
.55742 .63237 m .55619 .63186 L .55814 .63226 L closepath p F P
0 g
s
.65 .757 .928 r
.21634 .51081 m .20727 .51394 L .2104 .51683 L p F P
0 g
s
.65 .757 .928 r
.2104 .51683 m .21946 .51372 L .21634 .51081 L p F P
0 g
s
.651 .758 .928 r
.80708 .51687 m .81722 .51373 L .81934 .51662 L p F P
0 g
s
.651 .758 .928 r
.81722 .51373 m .80708 .51687 L .80495 .51399 L p F P
0 g
s
.649 .756 .927 r
.07889 .51023 m .07008 .51332 L .07344 .51623 L p F P
0 g
s
.649 .756 .927 r
.07344 .51623 m .08224 .51314 L .07889 .51023 L p F P
0 g
s
.639 .16 0 r
.58521 .72027 m .58606 .7214 L .58355 .71858 L p F P
0 g
s
.639 .16 0 r
.58355 .71858 m .58287 .71768 L .58521 .72027 L p F P
0 g
s
.65 .757 .928 r
.36602 .51092 m .35668 .51405 L .35957 .51694 L p F P
0 g
s
.65 .757 .928 r
.35957 .51694 m .36889 .51381 L .36602 .51092 L p F P
0 g
s
.651 .757 .928 r
.66541 .51092 m .65553 .51406 L .65791 .51695 L p F P
0 g
s
.651 .757 .928 r
.65791 .51695 m .66778 .51382 L .66541 .51092 L p F P
0 g
s
.651 .757 .928 r
.51571 .51094 m .50611 .51407 L .50874 .51696 L p F P
0 g
s
.651 .757 .928 r
.50874 .51696 m .51834 .51383 L .51571 .51094 L p F P
0 g
s
.35 .541 .901 r
.61115 .74471 m .60606 .74328 L .60355 .73957 L p F P
0 g
s
.84 .998 .825 r
.44948 .73696 m .44187 .74365 L .44466 .74399 L p F P
0 g
s
.761 .967 .929 r
.44145 .74393 m .44187 .74365 L .44466 .74399 L p F P
0 g
s
0 0 0 r
.40704 .70966 m .40837 .7057 L .40785 .70668 L closepath p F P
0 g
s
0 0 0 r
.40669 .7108 m .40704 .70966 L .40785 .70668 L p F P
0 g
s
.8 .362 .208 r
.55763 .69311 m .55225 .69134 L .55523 .69512 L p F P
0 g
s
.8 .362 .208 r
.55523 .69512 m .56022 .697 L .55763 .69311 L p F P
0 g
s
0 0 0 r
.46224 .64613 m .46738 .64349 L .4628 .64558 L closepath p F P
0 g
s
.65 .757 .928 r
.22855 .51059 m .21946 .51372 L .22257 .51661 L p F P
0 g
s
.65 .757 .928 r
.22257 .51661 m .23165 .51349 L .22855 .51059 L p F P
0 g
s
.651 .758 .928 r
.81934 .51662 m .8295 .51348 L .83159 .51636 L p F P
0 g
s
.651 .758 .928 r
.8295 .51348 m .81934 .51662 L .81722 .51373 L p F P
0 g
s
.65 .757 .928 r
.37826 .51068 m .36889 .51381 L .37176 .5167 L p F P
0 g
s
.65 .757 .928 r
.37176 .5167 m .38111 .51358 L .37826 .51068 L p F P
0 g
s
.651 .757 .928 r
.67769 .51068 m .66778 .51382 L .67015 .5167 L p F P
0 g
s
.651 .757 .928 r
.67015 .5167 m .68004 .51357 L .67769 .51068 L p F P
0 g
s
0 0 0 r
.45246 .65228 m .46041 .64789 L p .45169 .65385 L F P
0 g
s
0 0 0 r
.45169 .65385 m .45015 .65471 L .45246 .65228 L p F P
0 g
s
0 0 0 r
.46224 .64613 m .46041 .64789 L .45246 .65228 L p F P
0 g
s
.651 .757 .928 r
.52797 .5107 m .51834 .51383 L .52095 .51672 L p F P
0 g
s
.651 .757 .928 r
.52095 .51672 m .53058 .51359 L .52797 .5107 L p F P
0 g
s
.649 .756 .927 r
.09108 .51003 m .08224 .51314 L .08558 .51604 L p F P
0 g
s
.649 .756 .927 r
.08558 .51604 m .09441 .51295 L .09108 .51003 L p F P
0 g
s
0 0 0 r
.42858 .6745 m .42382 .67938 L .42383 .67937 L p F P
0 g
s
.564 .821 .454 r
.42382 .67938 m .42383 .67937 L .42382 .67938 L closepath p F P
0 g
s
0 0 0 r
.42382 .67938 m .42382 .67938 L .42195 .68236 L p F P
0 g
s
0 0 0 r
.42195 .68236 m .41975 .68516 L .42382 .67938 L p F P
0 g
s
0 0 0 r
.42382 .67938 m .42858 .6745 L .42375 .68053 L p F P
0 g
s
0 0 0 r
.42375 .68053 m .42195 .68236 L .42382 .67938 L p F P
0 g
s
.114 .302 .776 r
.40797 .74746 m .40749 .74708 L .40749 .74649 L closepath p F P
0 g
s
.499 0 0 r
.55742 .63237 m .55619 .63186 L .54899 .63057 L p F P
0 g
s
.651 .758 .928 r
.83159 .51636 m .84178 .51322 L .84385 .51611 L p F P
0 g
s
.651 .758 .928 r
.84178 .51322 m .83159 .51636 L .8295 .51348 L p F P
0 g
s
.226 0 0 r
.49552 .63179 m .504 .63028 L p .50061 .63235 L F P
0 g
s
.226 0 0 r
.50061 .63235 m .49365 .63324 L .49552 .63179 L p F P
0 g
s
.131 0 0 r
.49552 .63179 m .49365 .63324 L .48409 .63556 L p F P
0 g
s
.65 .757 .928 r
.24077 .51036 m .23165 .51349 L .23475 .51638 L p F P
0 g
s
.65 .757 .928 r
.23475 .51638 m .24385 .51326 L .24077 .51036 L p F P
0 g
s
.479 .122 .282 r
.5088 .68599 m .51193 .68584 L p .50069 .69091 L F P
0 g
s
.486 .145 .312 r
.51193 .68584 m .5088 .68599 L .51211 .68525 L closepath p F P
0 g
s
.963 .796 .358 r
.64743 .7237 m .64817 .72663 L .64757 .73152 L p F P
0 g
s
.871 .649 .12 r
.64725 .72035 m .64719 .71898 L p .64817 .72663 L F P
0 g
s
.871 .649 .12 r
.64817 .72663 m .64743 .7237 L .64725 .72035 L p F P
0 g
s
.651 .758 .928 r
.68997 .51043 m .68004 .51357 L .68239 .51646 L p F P
0 g
s
.651 .758 .928 r
.68239 .51646 m .6923 .51333 L .68997 .51043 L p F P
0 g
s
.634 .093 0 r
.60737 .65885 m .60401 .65646 L .60758 .66003 L p F P
0 g
s
.634 .093 0 r
.60758 .66003 m .61095 .66241 L .60737 .65885 L p F P
0 g
s
.65 .757 .928 r
.3905 .51044 m .38111 .51358 L .38396 .51646 L p F P
0 g
s
.65 .757 .928 r
.38396 .51646 m .39333 .51334 L .3905 .51044 L p F P
0 g
s
.651 .757 .928 r
.54023 .51046 m .53058 .51359 L .53317 .51648 L p F P
0 g
s
.651 .757 .928 r
.53317 .51648 m .54282 .51335 L .54023 .51046 L p F P
0 g
s
.649 .756 .927 r
.10327 .50984 m .09441 .51295 L .09773 .51585 L p F P
0 g
s
.649 .756 .927 r
.09773 .51585 m .10659 .51275 L .10327 .50984 L p F P
0 g
s
.645 .275 .328 r
.52353 .68423 m .52416 .6826 L .52617 .68426 L closepath p F P
0 g
s
.598 .253 .356 r
.52416 .6826 m .52353 .68423 L .51211 .68525 L p F P
0 g
s
.891 .593 .086 r
.64519 .71162 m .6458 .71301 L .64718 .71895 L p F P
0 g
s
.798 .47 0 r
.6458 .71301 m .64455 .70933 L .64519 .71162 L closepath p F P
0 g
s
.813 .529 0 r
.64719 .71898 m .64718 .71895 L .6458 .71301 L p F P
0 g
s
.688 .305 .317 r
.54355 .6859 m .54631 .68972 L .53924 .68843 L p F P
0 g
s
.688 .305 .317 r
.53663 .68488 m .54355 .6859 L p .53924 .68843 L F P
0 g
s
0 .237 .751 r
.59697 .73282 m .59536 .73004 L .59101 .72656 L p F P
0 g
s
0 .176 .695 r
.58917 .72384 m .59101 .72656 L .59536 .73004 L p F P
0 g
s
0 .259 .765 r
.58606 .7214 m .58917 .72384 L .59101 .72656 L p F P
0 g
s
.614 .046 0 r
.58797 .64522 m .59219 .64856 L .58785 .64644 L p F P
0 g
s
.614 .046 0 r
.58578 .64415 m .58797 .64522 L p .58785 .64644 L F P
0 g
s
.65 .757 .928 r
.25299 .51013 m .24385 .51326 L .24693 .51615 L p F P
0 g
s
.65 .757 .928 r
.24693 .51615 m .25605 .51303 L .25299 .51013 L p F P
0 g
s
.825 .487 0 r
.64519 .71162 m .64455 .70933 L .64328 .70586 L p F P
0 g
s
.709 .88 .96 r
.4295 .74877 m .42002 .75222 L .4228 .75476 L p F P
0 g
s
.709 .88 .96 r
.42963 .74884 m .4295 .74877 L p .4228 .75476 L F P
0 g
s
.709 .88 .96 r
.4228 .75476 m .42716 .75268 L .42963 .74884 L p F P
0 g
s
.567 .719 .944 r
.4168 .75236 m .42002 .75222 L .4228 .75476 L p F P
0 g
s
.651 .758 .928 r
.70225 .51019 m .6923 .51333 L .69463 .51622 L p F P
0 g
s
.651 .758 .928 r
.69463 .51622 m .70457 .51308 L .70225 .51019 L p F P
0 g
s
0 .084 .621 r
.4053 .74114 m .40455 .73997 L .40464 .7391 L closepath p F P
0 g
s
0 .146 .675 r
.40455 .73997 m .4053 .74114 L .40749 .74649 L p F P
0 g
s
.65 .757 .928 r
.40274 .5102 m .39333 .51334 L .39616 .51623 L p F P
0 g
s
.65 .757 .928 r
.39616 .51623 m .40555 .5131 L .40274 .5102 L p F P
0 g
s
.651 .757 .928 r
.5525 .51021 m .54282 .51335 L .54539 .51624 L p F P
0 g
s
.651 .757 .928 r
.54539 .51624 m .55506 .51311 L .5525 .51021 L p F P
0 g
s
.116 0 0 r
.48305 .63635 m .48409 .63556 L .49365 .63324 L p F P
0 g
s
.931 .927 .781 r
.64288 .74643 m .64371 .74524 L .64404 .74672 L closepath p F P
0 g
s
.973 .903 .687 r
.64659 .7397 m .64371 .74524 L .64404 .74672 L p F P
0 g
s
.382 .563 .906 r
.40797 .74746 m .40749 .74649 L p .41622 .74801 L F P
0 g
s
.382 .563 .906 r
.41622 .74801 m .41628 .74922 L .40797 .74746 L p F P
0 g
s
.649 .756 .927 r
.11547 .50964 m .10659 .51275 L .10989 .51565 L p F P
0 g
s
.649 .756 .927 r
.10989 .51565 m .11876 .51255 L .11547 .50964 L p F P
0 g
s
0 .063 .575 r
.40331 .73308 m .40356 .7323 L .40554 .73636 L p F P
0 g
s
0 .063 .575 r
.40554 .73636 m .40464 .7391 L .40331 .73308 L p F P
0 g
s
.752 .325 .237 r
.55047 .69088 m .5512 .69002 L .55225 .69134 L closepath p F P
0 g
s
.768 .346 .249 r
.54631 .68972 m .55047 .69088 L .5512 .69002 L p F P
0 g
s
0 0 .203 r
.40438 .71946 m .40579 .71568 L .40557 .72036 L p F P
0 g
s
0 0 .203 r
.40557 .72036 m .40418 .72414 L .40438 .71946 L p F P
0 g
s
.65 .757 .928 r
.26521 .5099 m .25605 .51303 L .25911 .51592 L p F P
0 g
s
.65 .757 .928 r
.25911 .51592 m .26826 .5128 L .26521 .5099 L p F P
0 g
s
.819 .35 .1 r
.56444 .6991 m .56022 .697 L .56281 .70091 L p F P
0 g
s
.819 .35 .1 r
.56608 .70185 m .56444 .6991 L p .56281 .70091 L F P
0 g
s
.582 .01 0 r
.57362 .63808 m .57847 .64121 L .57321 .63934 L p F P
0 g
s
.582 .01 0 r
.57093 .63712 m .57362 .63808 L p .57321 .63934 L F P
0 g
s
.651 .758 .928 r
.71454 .50994 m .70457 .51308 L .70687 .51597 L p F P
0 g
s
.651 .758 .928 r
.70687 .51597 m .71683 .51284 L .71454 .50994 L p F P
0 g
s
.65 .757 .928 r
.41499 .50996 m .40555 .5131 L .40836 .51599 L p F P
0 g
s
.65 .757 .928 r
.40836 .51599 m .41778 .51286 L .41499 .50996 L p F P
0 g
s
0 .189 .695 r
.58917 .72384 m .58606 .7214 L .58355 .71858 L p F P
0 g
s
.825 .487 0 r
.64328 .70586 m .64253 .70443 L p .64519 .71162 L F P
0 g
s
.749 .382 0 r
.64328 .70586 m .64201 .70308 L .64253 .70443 L closepath p F P
0 g
s
.651 .757 .928 r
.56476 .50997 m .55506 .51311 L .55762 .516 L p F P
0 g
s
.651 .757 .928 r
.55762 .516 m .56731 .51287 L .56476 .50997 L p F P
0 g
s
.586 .701 .922 r
.62466 .75207 m .62093 .75264 L .61846 .74948 L p F P
0 g
s
.614 .1 0 r
.61932 .66993 m .62029 .67102 L .61749 .66849 L p F P
0 g
s
.614 .1 0 r
.61749 .66849 m .61689 .66782 L .61932 .66993 L p F P
0 g
s
.588 .07 0 r
.61406 .66486 m .61689 .66782 L .61932 .66993 L p F P
0 g
s
0 0 0 r
.414 .69445 m .41606 .69084 L .41501 .69226 L closepath p F P
0 g
s
0 0 0 r
.41301 .69633 m .414 .69445 L .41501 .69226 L p F P
0 g
s
.382 .563 .906 r
.40749 .74649 m .4084 .74351 L p .41622 .74801 L F P
0 g
s
.226 .33 .762 r
.4084 .74351 m .40749 .74649 L .4053 .74114 L closepath p F P
0 g
s
.96 .914 .723 r
.64592 .73671 m .64659 .7397 L .64371 .74524 L p F P
0 g
s
.986 .888 .555 r
.64659 .7397 m .64592 .73671 L .64757 .73152 L p F P
0 g
s
.649 .756 .927 r
.12767 .50943 m .11876 .51255 L .12205 .51545 L p F P
0 g
s
.649 .756 .927 r
.12205 .51545 m .13095 .51234 L .12767 .50943 L p F P
0 g
s
.597 .039 0 r
.6019 .65456 m .60401 .65646 L .60038 .65414 L p F P
0 g
s
.597 .039 0 r
.60038 .65414 m .59945 .65333 L .6019 .65456 L p F P
0 g
s
.582 .02 0 r
.59626 .65075 m .59945 .65333 L .6019 .65456 L p F P
0 g
s
0 0 0 r
.40837 .7057 m .41077 .70159 L .40909 .70669 L p F P
0 g
s
0 0 0 r
.40704 .70966 m .40837 .7057 L p .40909 .70669 L F P
0 g
s
0 .281 .783 r
.60105 .73604 m .59697 .73282 L p .60289 .73908 L F P
0 g
s
0 .21 .732 r
.59697 .73282 m .60105 .73604 L .59855 .73273 L p F P
0 g
s
0 .21 .732 r
.59855 .73273 m .59536 .73004 L .59697 .73282 L p F P
0 g
s
.65 .757 .928 r
.27744 .50966 m .26826 .5128 L .27129 .51569 L p F P
0 g
s
.65 .757 .928 r
.27129 .51569 m .28046 .51257 L .27744 .50966 L p F P
0 g
s
.651 .758 .928 r
.72683 .50969 m .71683 .51284 L .71912 .51573 L p F P
0 g
s
.651 .758 .928 r
.71912 .51573 m .7291 .51259 L .72683 .50969 L p F P
0 g
s
.65 .757 .928 r
.42723 .50972 m .41778 .51286 L .42056 .51575 L p F P
0 g
s
.65 .757 .928 r
.42056 .51575 m .43001 .51262 L .42723 .50972 L p F P
0 g
s
.51 0 0 r
.55742 .63237 m .562 .63467 L .55558 .63314 L p F P
0 g
s
.51 0 0 r
.55558 .63314 m .55489 .63283 L .55742 .63237 L p F P
0 g
s
.499 0 0 r
.54899 .63057 m .55489 .63283 L .55742 .63237 L p F P
0 g
s
.651 .757 .928 r
.57703 .50973 m .56731 .51287 L .56984 .51576 L p F P
0 g
s
.651 .757 .928 r
.56984 .51576 m .57956 .51263 L .57703 .50973 L p F P
0 g
s
.564 .218 .34 r
.51211 .68525 m .52353 .68423 L p .51775 .68798 L F P
0 g
s
.564 .218 .34 r
.51775 .68798 m .51193 .68584 L .51211 .68525 L p F P
0 g
s
.65 .756 .927 r
.13988 .50922 m .13095 .51234 L .13421 .51524 L p F P
0 g
s
.65 .756 .927 r
.13421 .51524 m .14313 .51213 L .13988 .50922 L p F P
0 g
s
0 0 0 r
.46041 .64789 m .46224 .64613 L .46738 .64349 L p F P
0 g
s
.627 .096 0 r
.61689 .66782 m .61406 .66486 L .61095 .66241 L p F P
0 g
s
0 0 0 r
.41975 .68516 m .41606 .69084 L .41961 .68635 L p F P
0 g
s
0 0 0 r
.42195 .68236 m .41975 .68516 L p .41961 .68635 L F P
0 g
s
.65 .757 .928 r
.28967 .50943 m .28046 .51257 L .28348 .51546 L p F P
0 g
s
.65 .757 .928 r
.28348 .51546 m .29268 .51233 L .28967 .50943 L p F P
0 g
s
.651 .758 .928 r
.73913 .50944 m .7291 .51259 L .73137 .51548 L p F P
0 g
s
.651 .758 .928 r
.73137 .51548 m .74138 .51234 L .73913 .50944 L p F P
0 g
s
.651 .757 .928 r
.43949 .50948 m .43001 .51262 L .43277 .51551 L p F P
0 g
s
.651 .757 .928 r
.43277 .51551 m .44224 .51238 L .43949 .50948 L p F P
0 g
s
.651 .757 .928 r
.58931 .50949 m .57956 .51263 L .58207 .51552 L p F P
0 g
s
.651 .757 .928 r
.58207 .51552 m .59181 .51238 L .58931 .50949 L p F P
0 g
s
.92 .677 .183 r
.64725 .72035 m .64719 .71898 L .64718 .71895 L closepath p F P
0 g
s
.943 .689 .222 r
.64718 .71895 m .64591 .71612 L p .64741 .72364 L F P
0 g
s
.943 .689 .222 r
.64741 .72364 m .64725 .72035 L .64718 .71895 L p F P
0 g
s
.891 .593 .086 r
.64718 .71895 m .64591 .71612 L .64519 .71162 L p F P
0 g
s
.65 .756 .927 r
.15209 .50901 m .14313 .51213 L .14638 .51503 L p F P
0 g
s
.65 .756 .927 r
.14638 .51503 m .15532 .51192 L .15209 .50901 L p F P
0 g
s
.783 .403 0 r
.64253 .70443 m .64201 .70308 L .63951 .69806 L p F P
0 g
s
.65 .757 .928 r
.30191 .5092 m .29268 .51233 L .29567 .51523 L p F P
0 g
s
.65 .757 .928 r
.29567 .51523 m .30489 .5121 L .30191 .5092 L p F P
0 g
s
.651 .758 .928 r
.75142 .5092 m .74138 .51234 L .74362 .51523 L p F P
0 g
s
.651 .758 .928 r
.74362 .51523 m .75366 .5121 L .75142 .5092 L p F P
0 g
s
.688 .305 .317 r
.53924 .68843 m .53639 .68541 L .53663 .68488 L p F P
0 g
s
.695 .313 .32 r
.53639 .68541 m .53584 .6848 L .53663 .68488 L closepath p F P
0 g
s
.651 .757 .928 r
.45175 .50924 m .44224 .51238 L .44499 .51527 L p F P
0 g
s
.651 .757 .928 r
.44499 .51527 m .45448 .51214 L .45175 .50924 L p F P
0 g
s
.651 .757 .928 r
.60159 .50924 m .59181 .51238 L .59431 .51527 L p F P
0 g
s
.651 .757 .928 r
.59431 .51527 m .60407 .51214 L .60159 .50924 L p F P
0 g
s
.704 .871 .961 r
.42963 .74884 m .43229 .75032 L .42716 .75268 L closepath p F P
0 g
s
.207 .328 .768 r
.4053 .74114 m .40464 .7391 L p .40925 .73994 L F P
0 g
s
.207 .328 .768 r
.40925 .73994 m .4084 .74351 L .4053 .74114 L p F P
0 g
s
.106 0 .034 r
.48043 .70612 m .48308 .70401 L .48089 .7052 L closepath p F P
0 g
s
0 0 0 r
.48089 .7052 m .48043 .70612 L .47568 .71079 L p F P
0 g
s
.614 .046 0 r
.58785 .64644 m .58456 .64391 L .58578 .64415 L p F P
0 g
s
.571 0 0 r
.58456 .64391 m .58345 .64315 L .58578 .64415 L closepath p F P
0 g
s
.207 .328 .768 r
.40464 .7391 m .40554 .73636 L .40925 .73994 L p F P
0 g
s
.502 0 0 r
.54899 .63057 m .55489 .63283 L p .54802 .63195 L F P
0 g
s
.502 0 0 r
.54322 .62966 m .54899 .63057 L p .54802 .63195 L F P
0 g
s
0 .29 .789 r
.60355 .73957 m .60289 .73908 L .60191 .73725 L closepath p F P
0 g
s
0 .281 .783 r
.60289 .73908 m .60191 .73725 L .60105 .73604 L p F P
0 g
s
0 .06 .575 r
.40356 .7323 m .40487 .72857 L .40669 .73268 L p F P
0 g
s
0 .06 .575 r
.40669 .73268 m .40554 .73636 L .40356 .7323 L p F P
0 g
s
.761 .247 0 r
.57101 .70516 m .56711 .70298 L .57042 .70671 L p F P
0 g
s
.761 .247 0 r
.57042 .70671 m .57409 .70895 L .57101 .70516 L p F P
0 g
s
.659 .263 .284 r
.53584 .6848 m .52617 .68426 L .53031 .68768 L p F P
0 g
s
.659 .263 .284 r
.53639 .68541 m .53584 .6848 L p .53031 .68768 L F P
0 g
s
.741 .833 .921 r
.63506 .75237 m .6332 .75352 L .63077 .75122 L p F P
0 g
s
.65 .757 .927 r
.1643 .50879 m .15532 .51192 L .15855 .51482 L p F P
0 g
s
.65 .757 .927 r
.15855 .51482 m .16752 .5117 L .1643 .50879 L p F P
0 g
s
.566 .197 .3 r
.51085 .68864 m .51193 .68584 L .51775 .68798 L closepath p F P
0 g
s
.479 .122 .282 r
.51193 .68584 m .51085 .68864 L .50069 .69091 L p F P
0 g
s
.651 .758 .928 r
.76373 .50895 m .75366 .5121 L .75588 .51499 L p F P
0 g
s
.651 .758 .928 r
.75588 .51499 m .76594 .51185 L .76373 .50895 L p F P
0 g
s
.65 .757 .928 r
.31415 .50896 m .30489 .5121 L .30787 .51499 L p F P
0 g
s
.65 .757 .928 r
.30787 .51499 m .31711 .51186 L .31415 .50896 L p F P
0 g
s
.53 0 0 r
.59626 .65075 m .59219 .64856 L .59641 .65192 L p F P
0 g
s
.53 0 0 r
.59945 .65333 m .59626 .65075 L p .59641 .65192 L F P
0 g
s
.651 .757 .928 r
.61387 .509 m .60407 .51214 L .60655 .51503 L p F P
0 g
s
.651 .757 .928 r
.60655 .51503 m .61633 .5119 L .61387 .509 L p F P
0 g
s
.651 .757 .928 r
.46401 .509 m .45448 .51214 L .4572 .51503 L p F P
0 g
s
.651 .757 .928 r
.4572 .51503 m .46672 .5119 L .46401 .509 L p F P
0 g
s
.582 .01 0 r
.57321 .63934 m .56972 .63716 L .57093 .63712 L p F P
0 g
s
.536 0 0 r
.56972 .63716 m .56811 .63629 L .57093 .63712 L closepath p F P
0 g
s
.706 .205 0 r
.62029 .67102 m .61749 .66849 L .62038 .6723 L p F P
0 g
s
.706 .205 0 r
.62038 .6723 m .62318 .67483 L .62029 .67102 L p F P
0 g
s
.722 .286 .213 r
.55225 .69134 m .55523 .69512 L .54921 .69353 L p F P
0 g
s
.722 .286 .213 r
.55047 .69088 m .55225 .69134 L p .54921 .69353 L F P
0 g
s
.226 0 0 r
.504 .63028 m .5059 .63009 L p .50061 .63235 L F P
0 g
s
.24 0 0 r
.5059 .63009 m .504 .63028 L .50613 .62993 L closepath p F P
0 g
s
.741 .833 .921 r
.63077 .75122 m .63396 .74951 L .63506 .75237 L p F P
0 g
s
.813 .93 .91 r
.64051 .74532 m .63396 .74951 L .63506 .75237 L p F P
0 g
s
.813 .93 .91 r
.63506 .75237 m .64288 .74643 L .64051 .74532 L p F P
0 g
s
.65 .757 .927 r
.17652 .50858 m .16752 .5117 L .17072 .5146 L p F P
0 g
s
.65 .757 .927 r
.17072 .5146 m .17972 .51149 L .17652 .50858 L p F P
0 g
s
.512 .682 .943 r
.42002 .75222 m .4168 .75236 L .41628 .74922 L p F P
0 g
s
.921 .61 .135 r
.64371 .70879 m .64519 .71162 L .64591 .71612 L p F P
0 g
s
.825 .487 0 r
.64253 .70443 m .64371 .70879 L .64519 .71162 L p F P
0 g
s
.651 .758 .928 r
.77603 .50869 m .76594 .51185 L .76814 .51474 L p F P
0 g
s
.651 .758 .928 r
.76814 .51474 m .77822 .5116 L .77603 .50869 L p F P
0 g
s
.65 .757 .928 r
.32639 .50872 m .31711 .51186 L .32007 .51476 L p F P
0 g
s
.65 .757 .928 r
.32007 .51476 m .32933 .51163 L .32639 .50872 L p F P
0 g
s
.651 .757 .928 r
.62615 .50875 m .61633 .5119 L .61879 .51479 L p F P
0 g
s
.651 .757 .928 r
.61879 .51479 m .6286 .51166 L .62615 .50875 L p F P
0 g
s
.93 .682 .199 r
.64743 .7237 m .64725 .72035 L .64741 .72364 L closepath p F P
0 g
s
.651 .757 .928 r
.47627 .50876 m .46672 .5119 L .46942 .51479 L p F P
0 g
s
.651 .757 .928 r
.46942 .51479 m .47896 .51166 L .47627 .50876 L p F P
0 g
s
.35 .541 .901 r
.60355 .73957 m .61009 .74181 L .61115 .74471 L p F P
0 g
s
.285 .517 .902 r
.61009 .74181 m .60355 .73957 L .60191 .73725 L p F P
0 g
s
.661 .925 .632 r
.46114 .72569 m .46298 .72376 L .46197 .72503 L closepath p F P
0 g
s
.606 .901 .616 r
.45642 .7303 m .46114 .72569 L .46197 .72503 L p F P
0 g
s
.65 .757 .928 r
.18874 .50835 m .17972 .51149 L .1829 .51438 L p F P
0 g
s
.65 .757 .928 r
.1829 .51438 m .19192 .51126 L .18874 .50835 L p F P
0 g
s
.695 .303 .301 r
.53511 .68797 m .53639 .68541 L .53924 .68843 L closepath p F P
0 g
s
.659 .263 .284 r
.53031 .68768 m .53511 .68797 L .53639 .68541 L p F P
0 g
s
.645 .275 .328 r
.52617 .68426 m .52353 .68423 L .52224 .68757 L p F P
0 g
s
.645 .275 .328 r
.52224 .68757 m .53031 .68768 L .52617 .68426 L p F P
0 g
s
.651 .758 .928 r
.78834 .50844 m .77822 .5116 L .78041 .51449 L p F P
0 g
s
.651 .758 .928 r
.78041 .51449 m .79051 .51134 L .78834 .50844 L p F P
0 g
s
.65 .757 .928 r
.33863 .50849 m .32933 .51163 L .33227 .51452 L p F P
0 g
s
.65 .757 .928 r
.33227 .51452 m .34156 .51139 L .33863 .50849 L p F P
0 g
s
.564 .218 .34 r
.52353 .68423 m .52224 .68757 L .51775 .68798 L p F P
0 g
s
.651 .757 .928 r
.63844 .50851 m .6286 .51166 L .63103 .51455 L p F P
0 g
s
.651 .757 .928 r
.63103 .51455 m .64086 .51141 L .63844 .50851 L p F P
0 g
s
.53 .693 .943 r
.62466 .75207 m .63077 .75122 L .62834 .74875 L p F P
0 g
s
.53 .693 .943 r
.62834 .74875 m .62431 .74899 L .62466 .75207 L p F P
0 g
s
.586 .701 .922 r
.61846 .74948 m .62431 .74899 L .62466 .75207 L p F P
0 g
s
.651 .757 .928 r
.48854 .50852 m .47896 .51166 L .48165 .51456 L p F P
0 g
s
.651 .757 .928 r
.48165 .51456 m .49121 .51142 L .48854 .50852 L p F P
0 g
s
.345 0 0 r
.51755 .62887 m .51814 .62855 L .52039 .62879 L closepath p F P
0 g
s
.293 0 0 r
.51814 .62855 m .51755 .62887 L .50613 .62993 L p F P
0 g
s
.343 0 0 r
.5059 .63009 m .50613 .62993 L .51755 .62887 L p F P
0 g
s
0 0 0 r
.46738 .64349 m .47135 .64174 L p .46041 .64789 L F P
0 g
s
0 0 0 r
.47135 .64174 m .47179 .64137 L .46738 .64349 L closepath p F P
0 g
s
.677 .206 0 r
.63074 .68393 m .62842 .68129 L .62574 .67741 L p F P
0 g
s
.719 .235 0 r
.62574 .67741 m .62318 .67483 L .62586 .67871 L p F P
0 g
s
.719 .235 0 r
.62586 .67871 m .62842 .68129 L .62574 .67741 L p F P
0 g
s
.744 .236 0 r
.57726 .71133 m .57409 .70895 L .57712 .71277 L p F P
0 g
s
.744 .236 0 r
.57712 .71277 m .58018 .71518 L .57726 .71133 L p F P
0 g
s
.913 .911 .804 r
.64371 .74524 m .64288 .74643 L .64051 .74532 L p F P
0 g
s
.913 .911 .804 r
.64051 .74532 m .64283 .74231 L .64371 .74524 L p F P
0 g
s
.96 .914 .723 r
.64371 .74524 m .64283 .74231 L .64592 .73671 L p F P
0 g
s
.464 .108 .277 r
.50069 .69091 m .51085 .68864 L p .50338 .69345 L F P
0 g
s
.464 .108 .277 r
.50338 .69345 m .49964 .69383 L .50069 .69091 L p F P
0 g
s
.338 0 .207 r
.50069 .69091 m .49964 .69383 L .49591 .69563 L p F P
0 g
s
.722 .286 .213 r
.54921 .69353 m .54868 .69297 L .55047 .69088 L p F P
0 g
s
.767 .344 .247 r
.54868 .69297 m .54631 .68972 L .55047 .69088 L closepath p F P
0 g
s
.65 .757 .928 r
.20097 .50813 m .19192 .51126 L .19508 .51416 L p F P
0 g
s
.65 .757 .928 r
.19508 .51416 m .20413 .51104 L .20097 .50813 L p F P
0 g
s
.883 .528 .04 r
.64084 .70165 m .64253 .70443 L .64371 .70879 L p F P
0 g
s
.783 .403 0 r
.63951 .69806 m .64084 .70165 L .64253 .70443 L p F P
0 g
s
.336 0 .203 r
.49005 .69844 m .49591 .69563 L .49036 .69764 L closepath p F P
0 g
s
.107 0 .034 r
.49036 .69764 m .49005 .69844 L .48308 .70401 L p F P
0 g
s
0 0 0 r
.41606 .69084 m .41961 .68635 L .41646 .69188 L p F P
0 g
s
0 0 0 r
.414 .69445 m .41606 .69084 L p .41646 .69188 L F P
0 g
s
0 0 0 r
.40909 .70669 m .40681 .71052 L .40704 .70966 L p F P
0 g
s
0 0 0 r
.40681 .71052 m .40704 .70966 L .40669 .7108 L closepath p F P
0 g
s
.651 .758 .928 r
.80065 .50819 m .79051 .51134 L .79267 .51424 L p F P
0 g
s
.651 .758 .928 r
.79267 .51424 m .8028 .51109 L .80065 .50819 L p F P
0 g
s
0 0 0 r
.43055 .67228 m .43459 .66813 L .43182 .67045 L closepath p F P
0 g
s
0 0 0 r
.43182 .67045 m .43055 .67228 L .42858 .6745 L p F P
0 g
s
.991 .887 .58 r
.64681 .72853 m .64757 .73152 L .64592 .73671 L p F P
0 g
s
.963 .796 .358 r
.64738 .72392 m .64743 .7237 L p .64757 .73152 L F P
0 g
s
.963 .796 .358 r
.64757 .73152 m .64681 .72853 L .64738 .72392 L p F P
0 g
s
.65 .757 .928 r
.35088 .50825 m .34156 .51139 L .34447 .51429 L p F P
0 g
s
.65 .757 .928 r
.34447 .51429 m .35379 .51116 L .35088 .50825 L p F P
0 g
s
.651 .757 .928 r
.65073 .50826 m .64086 .51141 L .64328 .51431 L p F P
0 g
s
.651 .757 .928 r
.64328 .51431 m .65313 .51117 L .65073 .50826 L p F P
0 g
s
.651 .757 .928 r
.50081 .50828 m .49121 .51142 L .49387 .51432 L p F P
0 g
s
.651 .757 .928 r
.49387 .51432 m .50346 .51118 L .50081 .50828 L p F P
0 g
s
.502 0 0 r
.54802 .63195 m .54262 .62991 L .54322 .62966 L p F P
0 g
s
.448 0 0 r
.54262 .62991 m .54113 .62947 L .54322 .62966 L closepath p F P
0 g
s
.683 .236 0 r
.63526 .6906 m .63319 .6879 L .63074 .68393 L p F P
0 g
s
.729 .267 0 r
.62842 .68129 m .63074 .68393 L .63319 .6879 L p F P
0 g
s
.406 0 0 r
.52984 .6287 m .53037 .62847 L .53186 .6288 L closepath p F P
0 g
s
.35 0 0 r
.53037 .62847 m .52984 .6287 L .52039 .62879 L p F P
0 g
s
.594 .021 0 r
.58456 .64391 m .58345 .64315 L .57847 .64121 L p F P
0 g
s
.174 0 0 r
.48135 .63788 m .48305 .63635 L .49293 .63377 L p F P
0 g
s
.116 0 0 r
.49365 .63324 m .49293 .63377 L .48305 .63635 L p F P
0 g
s
.049 0 0 r
.48305 .63635 m .48135 .63788 L .47179 .64137 L p F P
0 g
s
.65 .757 .928 r
.2132 .5079 m .20413 .51104 L .20727 .51394 L p F P
0 g
s
.65 .757 .928 r
.20727 .51394 m .21634 .51081 L .2132 .5079 L p F P
0 g
s
.804 .408 0 r
.63951 .69806 m .63925 .69741 L .63855 .69635 L closepath p F P
0 g
s
.65 .23 0 r
.63704 .69396 m .63526 .6906 L p .63925 .69741 L F P
0 g
s
.65 .23 0 r
.63925 .69741 m .63855 .69635 L .63704 .69396 L p F P
0 g
s
.651 .758 .928 r
.80495 .51399 m .8151 .51084 L .81722 .51373 L p F P
0 g
s
.651 .758 .928 r
.81296 .50793 m .8028 .51109 L .80495 .51399 L p F P
0 g
s
.651 .758 .928 r
.80495 .51399 m .8151 .51084 L .81296 .50793 L p F P
0 g
s
.76 .327 0 r
.63526 .6906 m .63704 .69396 L .63458 .69056 L p F P
0 g
s
.76 .327 0 r
.63458 .69056 m .63319 .6879 L .63526 .6906 L p F P
0 g
s
.327 0 0 r
.50351 .63184 m .5059 .63009 L .5155 .63024 L p F P
0 g
s
.343 0 0 r
.51755 .62887 m .5155 .63024 L .5059 .63009 L p F P
0 g
s
.226 0 0 r
.5059 .63009 m .50351 .63184 L .50061 .63235 L p F P
0 g
s
.554 0 0 r
.56972 .63716 m .56811 .63629 L .562 .63467 L p F P
0 g
s
.65 .757 .928 r
.36314 .50801 m .35379 .51116 L .35668 .51405 L p F P
0 g
s
.65 .757 .928 r
.35668 .51405 m .36602 .51092 L .36314 .50801 L p F P
0 g
s
.066 0 0 r
.48043 .70612 m .48308 .70401 L p .48712 .70411 L F P
0 g
s
.066 0 0 r
.48712 .70411 m .47912 .70821 L .48043 .70612 L p F P
0 g
s
0 0 0 r
.47912 .70821 m .48043 .70612 L .47568 .71079 L closepath p F P
0 g
s
.651 .757 .928 r
.66303 .50802 m .65313 .51117 L .65553 .51406 L p F P
0 g
s
.651 .757 .928 r
.65553 .51406 m .66541 .51092 L .66303 .50802 L p F P
0 g
s
.651 .757 .928 r
.51308 .50803 m .50346 .51118 L .50611 .51407 L p F P
0 g
s
.651 .757 .928 r
.50611 .51407 m .51571 .51094 L .51308 .50803 L p F P
0 g
s
.414 0 0 r
.54113 .62947 m .53186 .6288 L .53998 .6309 L p F P
0 g
s
.414 0 0 r
.54262 .62991 m .54113 .62947 L p .53998 .6309 L F P
0 g
s
.768 .878 .926 r
.43229 .75032 m .44145 .74393 L p .42963 .74869 L F P
0 g
s
.768 .878 .926 r
.42963 .74869 m .42963 .74884 L .43229 .75032 L p F P
0 g
s
.702 .204 0 r
.58355 .71858 m .58287 .71768 L .58018 .71518 L p F P
0 g
s
0 0 .073 r
.40669 .7108 m .40681 .71052 L .40618 .71477 L p F P
0 g
s
0 0 .073 r
.40618 .71477 m .40579 .71568 L .40669 .7108 L p F P
0 g
s
.066 0 0 r
.48308 .70401 m .48883 .70085 L p .48712 .70411 L F P
0 g
s
.098 0 .025 r
.48883 .70085 m .49005 .69844 L .48308 .70401 L closepath p F P
0 g
s
0 0 0 r
.47568 .71079 m .47912 .70821 L p .47598 .712 L F P
0 g
s
0 0 0 r
.47079 .71564 m .47568 .71079 L p .47598 .712 L F P
0 g
s
.65 .757 .928 r
.22543 .50768 m .21634 .51081 L .21946 .51372 L p F P
0 g
s
.65 .757 .928 r
.21946 .51372 m .22855 .51059 L .22543 .50768 L p F P
0 g
s
.235 .492 .895 r
.61115 .74471 m .61598 .7463 L .6135 .74316 L p F P
0 g
s
.235 .492 .895 r
.6135 .74316 m .61009 .74181 L .61115 .74471 L p F P
0 g
s
.651 .758 .928 r
.81722 .51373 m .82739 .51058 L .8295 .51348 L p F P
0 g
s
.651 .758 .928 r
.82739 .51058 m .81722 .51373 L .8151 .51084 L p F P
0 g
s
.667 .122 0 r
.60401 .65646 m .60038 .65414 L .60395 .65772 L p F P
0 g
s
.667 .122 0 r
.60395 .65772 m .60758 .66003 L .60401 .65646 L p F P
0 g
s
.65 .757 .928 r
.37539 .50777 m .36602 .51092 L .36889 .51381 L p F P
0 g
s
.65 .757 .928 r
.36889 .51381 m .37826 .51068 L .37539 .50777 L p F P
0 g
s
.649 .756 .927 r
.08773 .50711 m .07889 .51023 L .08224 .51314 L p F P
0 g
s
.649 .756 .927 r
.08224 .51314 m .09108 .51003 L .08773 .50711 L p F P
0 g
s
.651 .757 .928 r
.67532 .50777 m .66541 .51092 L .66778 .51382 L p F P
0 g
s
.651 .757 .928 r
.66778 .51382 m .67769 .51068 L .67532 .50777 L p F P
0 g
s
.751 .243 .001 r
.5648 .70196 m .56608 .70185 L .56711 .70298 L closepath p F P
0 g
s
.819 .35 .1 r
.56281 .70091 m .5648 .70196 L .56608 .70185 L p F P
0 g
s
.651 .757 .928 r
.52536 .50779 m .51571 .51094 L .51834 .51383 L p F P
0 g
s
.651 .757 .928 r
.51834 .51383 m .52797 .5107 L .52536 .50779 L p F P
0 g
s
0 0 0 r
.47598 .712 m .47019 .7163 L .47079 .71564 L p F P
0 g
s
0 0 0 r
.47019 .7163 m .47079 .71564 L .46915 .71732 L closepath p F P
0 g
s
.836 .445 0 r
.64084 .70165 m .63951 .69806 L .63855 .69635 L p F P
0 g
s
.809 .36 .173 r
.56022 .697 m .55523 .69512 L .55816 .69893 L p F P
0 g
s
.809 .36 .173 r
.55816 .69893 m .56281 .70091 L .56022 .697 L p F P
0 g
s
.651 .758 .928 r
.8295 .51348 m .83969 .51033 L .84178 .51322 L p F P
0 g
s
.651 .758 .928 r
.83969 .51033 m .8295 .51348 L .82739 .51058 L p F P
0 g
s
0 0 .385 r
.40418 .72414 m .40557 .72036 L .40619 .72482 L p F P
0 g
s
0 0 .385 r
.40619 .72482 m .40487 .72857 L .40418 .72414 L p F P
0 g
s
.65 .757 .928 r
.23767 .50745 m .22855 .51059 L .23165 .51349 L p F P
0 g
s
.65 .757 .928 r
.23165 .51349 m .24077 .51036 L .23767 .50745 L p F P
0 g
s
0 0 0 r
.46763 .71908 m .46799 .71876 L .47019 .7163 L p F P
0 g
s
.492 .832 .547 r
.46763 .71908 m .46787 .71886 L .46777 .71895 L p F P
0 g
s
0 0 0 r
.46915 .71732 m .46588 .72073 L p .46763 .71908 L F P
0 g
s
.492 .832 .547 r
.46777 .71895 m .46522 .72115 L p .46763 .71908 L F P
0 g
s
0 0 0 r
.46588 .72073 m .46298 .72376 L .46763 .71908 L p F P
0 g
s
0 0 0 r
.47019 .7163 m .46915 .71732 L p .46763 .71908 L F P
0 g
s
0 0 .158 r
.40681 .71052 m .40909 .70669 L .40808 .71161 L p F P
0 g
s
0 0 .158 r
.40808 .71161 m .40618 .71477 L .40681 .71052 L p F P
0 g
s
.651 .757 .928 r
.68763 .50753 m .67769 .51068 L .68004 .51357 L p F P
0 g
s
.651 .757 .928 r
.68004 .51357 m .68997 .51043 L .68763 .50753 L p F P
0 g
s
.65 .757 .928 r
.38765 .50753 m .37826 .51068 L .38111 .51358 L p F P
0 g
s
.65 .757 .928 r
.38111 .51358 m .3905 .51044 L .38765 .50753 L p F P
0 g
s
.651 .757 .928 r
.53764 .50755 m .52797 .5107 L .53058 .51359 L p F P
0 g
s
.651 .757 .928 r
.53058 .51359 m .54023 .51046 L .53764 .50755 L p F P
0 g
s
.649 .756 .927 r
.09995 .50692 m .09108 .51003 L .09441 .51295 L p F P
0 g
s
.649 .756 .927 r
.09441 .51295 m .10327 .50984 L .09995 .50692 L p F P
0 g
s
.036 0 0 r
.47135 .64174 m .47179 .64137 L .48135 .63788 L p F P
0 g
s
.272 0 .109 r
.48883 .70085 m .49005 .69844 L .49591 .69563 L p F P
0 g
s
0 0 0 r
.41646 .69188 m .41347 .69561 L .414 .69445 L p F P
0 g
s
0 0 0 r
.41347 .69561 m .414 .69445 L .41301 .69633 L closepath p F P
0 g
s
.55 .684 .928 r
.62431 .74899 m .61846 .74948 L .61598 .7463 L p F P
0 g
s
.663 .833 .965 r
.4267 .74688 m .41724 .74928 L .42002 .75222 L p F P
0 g
s
.663 .833 .965 r
.42002 .75222 m .4295 .74877 L .4267 .74688 L p F P
0 g
s
.512 .682 .943 r
.41628 .74922 m .41724 .74928 L .42002 .75222 L p F P
0 g
s
.379 0 0 r
.51755 .62887 m .52039 .62879 L p .51814 .63052 L F P
0 g
s
.379 0 0 r
.51814 .63052 m .5155 .63024 L .51755 .62887 L p F P
0 g
s
.65 .757 .928 r
.24991 .50722 m .24077 .51036 L .24385 .51326 L p F P
0 g
s
.65 .757 .928 r
.24385 .51326 m .25299 .51013 L .24991 .50722 L p F P
0 g
s
.651 .758 .928 r
.69993 .50728 m .68997 .51043 L .6923 .51333 L p F P
0 g
s
.651 .758 .928 r
.6923 .51333 m .70225 .51019 L .69993 .50728 L p F P
0 g
s
.65 .757 .928 r
.39991 .50729 m .3905 .51044 L .39333 .51334 L p F P
0 g
s
.65 .757 .928 r
.39333 .51334 m .40274 .5102 L .39991 .50729 L p F P
0 g
s
.651 .757 .928 r
.54992 .50731 m .54023 .51046 L .54282 .51335 L p F P
0 g
s
.651 .757 .928 r
.54282 .51335 m .5525 .51021 L .54992 .50731 L p F P
0 g
s
.438 0 0 r
.53186 .6288 m .53998 .6309 L .53009 .6304 L p F P
0 g
s
.438 0 0 r
.52984 .6287 m .53186 .6288 L p .53009 .6304 L F P
0 g
s
.379 0 0 r
.52039 .62879 m .52777 .62987 L p .51814 .63052 L F P
0 g
s
.382 0 0 r
.52777 .62987 m .52039 .62879 L .52984 .6287 L closepath p F P
0 g
s
0 .176 .695 r
.59536 .73004 m .59337 .72737 L .58917 .72384 L p F P
0 g
s
0 .129 .638 r
.58688 .72124 m .58917 .72384 L .59337 .72737 L p F P
0 g
s
0 .189 .695 r
.58355 .71858 m .58688 .72124 L .58917 .72384 L p F P
0 g
s
.649 .756 .927 r
.11217 .50672 m .10327 .50984 L .10659 .51275 L p F P
0 g
s
.649 .756 .927 r
.10659 .51275 m .11547 .50964 L .11217 .50672 L p F P
0 g
s
0 .132 .613 r
.58355 .71858 m .58688 .72124 L .58415 .71875 L p F P
0 g
s
0 .132 .613 r
.58415 .71875 m .58104 .71631 L .58355 .71858 L p F P
0 g
s
.702 .204 0 r
.58018 .71518 m .58104 .71631 L .58355 .71858 L p F P
0 g
s
.603 .032 0 r
.58456 .64391 m .58785 .64644 L .58321 .64439 L p F P
0 g
s
.603 .032 0 r
.58321 .64439 m .58208 .64358 L .58456 .64391 L p F P
0 g
s
.594 .021 0 r
.57847 .64121 m .58208 .64358 L .58456 .64391 L p F P
0 g
s
.643 .939 .694 r
.46298 .72376 m .46763 .71908 L .45994 .72597 L p F P
0 g
s
.643 .939 .694 r
.46114 .72569 m .46298 .72376 L p .45994 .72597 L F P
0 g
s
.438 0 0 r
.53009 .6304 m .52777 .62987 L .52984 .6287 L p F P
0 g
s
.978 .772 .354 r
.64738 .72392 m .64741 .72364 L .64743 .7237 L closepath p F P
0 g
s
.65 .757 .928 r
.26216 .50699 m .25299 .51013 L .25605 .51303 L p F P
0 g
s
.65 .757 .928 r
.25605 .51303 m .26521 .5099 L .26216 .50699 L p F P
0 g
s
.729 .295 .22 r
.54631 .68972 m .53924 .68843 L .54261 .69209 L p F P
0 g
s
.729 .295 .22 r
.54868 .69297 m .54631 .68972 L p .54261 .69209 L F P
0 g
s
.651 .758 .928 r
.71224 .50703 m .70225 .51019 L .70457 .51308 L p F P
0 g
s
.651 .758 .928 r
.70457 .51308 m .71454 .50994 L .71224 .50703 L p F P
0 g
s
.285 .517 .902 r
.60191 .73725 m .60161 .73624 L p .61009 .74181 L F P
0 g
s
.274 .51 .899 r
.60191 .73725 m .60105 .73604 L .60161 .73624 L closepath p F P
0 g
s
.65 .757 .928 r
.41218 .50705 m .40274 .5102 L .40555 .5131 L p F P
0 g
s
.65 .757 .928 r
.40555 .5131 m .41499 .50996 L .41218 .50705 L p F P
0 g
s
.502 0 0 r
.54008 .6309 m .54262 .62991 L .54802 .63195 L closepath p F P
0 g
s
.414 0 0 r
.53998 .6309 m .54008 .6309 L .54262 .62991 L p F P
0 g
s
.651 .757 .928 r
.56221 .50706 m .5525 .51021 L .55506 .51311 L p F P
0 g
s
.651 .757 .928 r
.55506 .51311 m .56476 .50997 L .56221 .50706 L p F P
0 g
s
.643 .939 .694 r
.45994 .72597 m .45899 .72701 L .46114 .72569 L p F P
0 g
s
.697 .959 .705 r
.45899 .72701 m .46114 .72569 L .45642 .7303 L closepath p F P
0 g
s
.994 .771 .407 r
.64741 .72364 m .64611 .72078 L p .64631 .72703 L F P
0 g
s
.994 .771 .407 r
.64631 .72703 m .64738 .72392 L .64741 .72364 L p F P
0 g
s
.943 .689 .222 r
.64591 .71612 m .64611 .72078 L .64741 .72364 L p F P
0 g
s
.649 .756 .927 r
.12439 .50651 m .11547 .50964 L .11876 .51255 L p F P
0 g
s
.649 .756 .927 r
.11876 .51255 m .12767 .50943 L .12439 .50651 L p F P
0 g
s
.768 .878 .926 r
.44145 .74393 m .44163 .7436 L p .42963 .74869 L F P
0 g
s
.774 .951 .933 r
.44163 .7436 m .44187 .74365 L .44145 .74393 L closepath p F P
0 g
s
.59 .042 0 r
.61095 .66241 m .60758 .66003 L .61105 .66365 L p F P
0 g
s
.59 .042 0 r
.61445 .66602 m .61095 .66241 L p .61105 .66365 L F P
0 g
s
.627 .096 0 r
.61095 .66241 m .61445 .66602 L .61689 .66782 L p F P
0 g
s
.982 .8 .394 r
.64681 .72853 m .64631 .72703 L .64738 .72392 L closepath p F P
0 g
s
.836 .445 0 r
.63855 .69635 m .63738 .69467 L p .64084 .70165 L F P
0 g
s
.752 .334 0 r
.63855 .69635 m .63704 .69396 L .63738 .69467 L closepath p F P
0 g
s
.798 .997 .858 r
.45642 .7303 m .45899 .72701 L p .45185 .73296 L F P
0 g
s
.798 .997 .858 r
.45149 .73526 m .45642 .7303 L p .45185 .73296 L F P
0 g
s
.812 .949 .911 r
.44187 .74365 m .44948 .73696 L p .44261 .7403 L F P
0 g
s
.812 .949 .911 r
.44261 .7403 m .44163 .7436 L .44187 .74365 L p F P
0 g
s
0 0 0 r
.41301 .69633 m .41347 .69561 L .41224 .69926 L p F P
0 g
s
0 0 0 r
.41224 .69926 m .41077 .70159 L .41301 .69633 L p F P
0 g
s
.65 .757 .928 r
.2744 .50675 m .26521 .5099 L .26826 .5128 L p F P
0 g
s
.65 .757 .928 r
.26826 .5128 m .27744 .50966 L .2744 .50675 L p F P
0 g
s
.651 .758 .928 r
.72455 .50678 m .71454 .50994 L .71683 .51284 L p F P
0 g
s
.651 .758 .928 r
.71683 .51284 m .72683 .50969 L .72455 .50678 L p F P
0 g
s
.65 .757 .928 r
.42445 .50681 m .41499 .50996 L .41778 .51286 L p F P
0 g
s
.65 .757 .928 r
.41778 .51286 m .42723 .50972 L .42445 .50681 L p F P
0 g
s
.651 .757 .928 r
.5745 .50682 m .56476 .50997 L .56731 .51287 L p F P
0 g
s
.651 .757 .928 r
.56731 .51287 m .57703 .50973 L .5745 .50682 L p F P
0 g
s
.559 0 0 r
.56972 .63716 m .57321 .63934 L .56763 .63756 L p F P
0 g
s
.559 0 0 r
.56763 .63756 m .56721 .63733 L .56972 .63716 L p F P
0 g
s
.554 0 0 r
.562 .63467 m .56721 .63733 L .56972 .63716 L p F P
0 g
s
.642 .116 0 r
.61689 .66782 m .61749 .66849 L .61445 .66602 L p F P
0 g
s
.642 .116 0 r
.61445 .66602 m .61445 .66602 L .61689 .66782 L p F P
0 g
s
.812 .949 .911 r
.44948 .73696 m .45043 .73543 L p .44261 .7403 L F P
0 g
s
.788 .997 .861 r
.45043 .73543 m .45149 .73526 L .44948 .73696 L closepath p F P
0 g
s
.65 .756 .927 r
.13661 .5063 m .12767 .50943 L .13095 .51234 L p F P
0 g
s
.65 .756 .927 r
.13095 .51234 m .13988 .50922 L .13661 .5063 L p F P
0 g
s
.216 0 0 r
.49293 .63377 m .49365 .63324 L .50061 .63235 L closepath p F P
0 g
s
.728 .208 0 r
.56711 .70298 m .57042 .70671 L .56615 .70462 L p F P
0 g
s
.728 .208 0 r
.5648 .70196 m .56711 .70298 L p .56615 .70462 L F P
0 g
s
0 0 0 r
.44021 .66276 m .44183 .66139 L .44061 .66223 L closepath p F P
0 g
s
0 0 0 r
.44061 .66223 m .44021 .66276 L .43459 .66813 L p F P
0 g
s
.798 .997 .858 r
.45185 .73296 m .45043 .73543 L .45149 .73526 L p F P
0 g
s
.624 .059 0 r
.59219 .64856 m .58785 .64644 L .592 .64981 L p F P
0 g
s
.624 .059 0 r
.592 .64981 m .59641 .65192 L .59219 .64856 L p F P
0 g
s
.65 .757 .928 r
.28666 .50652 m .27744 .50966 L .28046 .51257 L p F P
0 g
s
.65 .757 .928 r
.28046 .51257 m .28967 .50943 L .28666 .50652 L p F P
0 g
s
.651 .758 .928 r
.73687 .50654 m .72683 .50969 L .7291 .51259 L p F P
0 g
s
.651 .758 .928 r
.7291 .51259 m .73913 .50944 L .73687 .50654 L p F P
0 g
s
0 .151 .675 r
.59536 .73004 m .59855 .73273 L .59604 .72971 L p F P
0 g
s
0 .151 .675 r
.59604 .72971 m .59337 .72737 L .59536 .73004 L p F P
0 g
s
.097 0 0 r
.47135 .64174 m .4806 .63853 L p .46953 .64389 L F P
0 g
s
.097 0 0 r
.46953 .64389 m .46901 .64407 L .47135 .64174 L p F P
0 g
s
.036 0 0 r
.48135 .63788 m .4806 .63853 L .47135 .64174 L p F P
0 g
s
0 0 0 r
.47135 .64174 m .46901 .64407 L .46041 .64789 L p F P
0 g
s
.651 .757 .928 r
.43672 .50657 m .42723 .50972 L .43001 .51262 L p F P
0 g
s
.651 .757 .928 r
.43001 .51262 m .43949 .50948 L .43672 .50657 L p F P
0 g
s
.651 .757 .928 r
.5868 .50658 m .57703 .50973 L .57956 .51263 L p F P
0 g
s
.651 .757 .928 r
.57956 .51263 m .58931 .50949 L .5868 .50658 L p F P
0 g
s
.813 .95 .91 r
.43906 .74304 m .44261 .7403 L .44163 .7436 L closepath p F P
0 g
s
.768 .878 .926 r
.44163 .7436 m .43906 .74304 L .42963 .74869 L p F P
0 g
s
.65 .756 .927 r
.14884 .50609 m .13988 .50922 L .14313 .51213 L p F P
0 g
s
.65 .756 .927 r
.14313 .51213 m .15209 .50901 L .14884 .50609 L p F P
0 g
s
.347 .478 .849 r
.41448 .74573 m .4084 .74351 L .40925 .73994 L p F P
0 g
s
.382 .563 .906 r
.4084 .74351 m .41448 .74573 L .41622 .74801 L p F P
0 g
s
.952 .904 .738 r
.64508 .73375 m .64592 .73671 L .64283 .74231 L p F P
0 g
s
.991 .887 .58 r
.64592 .73671 m .64508 .73375 L .64681 .72853 L p F P
0 g
s
0 0 0 r
.4208 .68457 m .42375 .68053 L .42195 .68236 L closepath p F P
0 g
s
0 0 0 r
.41961 .68635 m .4208 .68457 L .42195 .68236 L p F P
0 g
s
0 0 0 r
.46799 .71876 m .47598 .712 L .47019 .7163 L closepath p F P
0 g
s
.65 .757 .928 r
.29891 .50628 m .28967 .50943 L .29268 .51233 L p F P
0 g
s
.65 .757 .928 r
.29268 .51233 m .30191 .5092 L .29891 .50628 L p F P
0 g
s
.651 .758 .928 r
.74918 .50629 m .73913 .50944 L .74138 .51234 L p F P
0 g
s
.651 .758 .928 r
.74138 .51234 m .75142 .5092 L .74918 .50629 L p F P
0 g
s
.651 .757 .928 r
.449 .50633 m .43949 .50948 L .44224 .51238 L p F P
0 g
s
.651 .757 .928 r
.44224 .51238 m .45175 .50924 L .449 .50633 L p F P
0 g
s
.651 .757 .928 r
.59909 .50633 m .58931 .50949 L .59181 .51238 L p F P
0 g
s
.651 .757 .928 r
.59181 .51238 m .60159 .50924 L .59909 .50633 L p F P
0 g
s
.49 0 0 r
.562 .63467 m .55558 .63314 L .56115 .63605 L p F P
0 g
s
.49 0 0 r
.56721 .63733 m .562 .63467 L p .56115 .63605 L F P
0 g
s
.246 .512 .907 r
.60161 .73624 m .60105 .73604 L .59855 .73273 L p F P
0 g
s
.65 .757 .927 r
.16108 .50587 m .15209 .50901 L .15532 .51192 L p F P
0 g
s
.65 .757 .927 r
.15532 .51192 m .1643 .50879 L .16108 .50587 L p F P
0 g
s
.972 .703 .288 r
.64443 .7133 m .64591 .71612 L .64611 .72078 L p F P
0 g
s
.921 .61 .135 r
.64591 .71612 m .64443 .7133 L .64371 .70879 L p F P
0 g
s
.621 .062 0 r
.59786 .65269 m .59945 .65333 L .60038 .65414 L closepath p F P
0 g
s
.53 0 0 r
.59641 .65192 m .59786 .65269 L .59945 .65333 L p F P
0 g
s
.715 .819 .929 r
.63396 .74951 m .63077 .75122 L .62834 .74875 L p F P
0 g
s
.736 .229 0 r
.61749 .66849 m .61445 .66602 L .61735 .66983 L p F P
0 g
s
.736 .229 0 r
.61735 .66983 m .62038 .6723 L .61749 .66849 L p F P
0 g
s
.651 .758 .928 r
.76151 .50603 m .75142 .5092 L .75366 .5121 L p F P
0 g
s
.651 .758 .928 r
.75366 .5121 m .76373 .50895 L .76151 .50603 L p F P
0 g
s
.65 .757 .928 r
.31117 .50605 m .30191 .5092 L .30489 .5121 L p F P
0 g
s
.65 .757 .928 r
.30489 .5121 m .31415 .50896 L .31117 .50605 L p F P
0 g
s
.651 .757 .928 r
.6114 .50609 m .60159 .50924 L .60407 .51214 L p F P
0 g
s
.651 .757 .928 r
.60407 .51214 m .61387 .509 L .6114 .50609 L p F P
0 g
s
.651 .757 .928 r
.46128 .50609 m .45175 .50924 L .45448 .51214 L p F P
0 g
s
.651 .757 .928 r
.45448 .51214 m .46401 .509 L .46128 .50609 L p F P
0 g
s
.272 0 .109 r
.49591 .69563 m .49942 .69432 L p .48883 .70085 L F P
0 g
s
.292 0 .14 r
.49942 .69432 m .49964 .69383 L .49591 .69563 L closepath p F P
0 g
s
0 0 0 r
.41347 .69561 m .41646 .69188 L .41385 .69726 L p F P
0 g
s
0 0 0 r
.41385 .69726 m .41224 .69926 L .41347 .69561 L p F P
0 g
s
.149 .265 .728 r
.40554 .73636 m .40669 .73268 L p .40985 .73745 L F P
0 g
s
.149 .265 .728 r
.40985 .73745 m .40925 .73994 L .40554 .73636 L p F P
0 g
s
.534 0 0 r
.57847 .64121 m .57321 .63934 L .57803 .6425 L p F P
0 g
s
.534 0 0 r
.58208 .64358 m .57847 .64121 L p .57803 .6425 L F P
0 g
s
.65 .757 .927 r
.17332 .50565 m .1643 .50879 L .16752 .5117 L p F P
0 g
s
.65 .757 .927 r
.16752 .5117 m .17652 .50858 L .17332 .50565 L p F P
0 g
s
0 0 0 r
.44982 .65511 m .45169 .65385 L .45015 .65471 L closepath p F P
0 g
s
0 0 0 r
.45015 .65471 m .44982 .65511 L .44183 .66139 L p F P
0 g
s
.285 .517 .902 r
.60161 .73624 m .6086 .73902 L .61009 .74181 L p F P
0 g
s
.121 .458 .887 r
.60023 .7334 m .60161 .73624 L .6086 .73902 L p F P
0 g
s
.246 .512 .907 r
.59855 .73273 m .60023 .7334 L .60161 .73624 L p F P
0 g
s
.026 0 0 r
.45941 .64902 m .46041 .64789 L .46901 .64407 L p F P
0 g
s
0 0 0 r
.46041 .64789 m .45941 .64902 L .45169 .65385 L p F P
0 g
s
.651 .758 .928 r
.77383 .50578 m .76373 .50895 L .76594 .51185 L p F P
0 g
s
.651 .758 .928 r
.76594 .51185 m .77603 .50869 L .77383 .50578 L p F P
0 g
s
.65 .757 .928 r
.32343 .50581 m .31415 .50896 L .31711 .51186 L p F P
0 g
s
.65 .757 .928 r
.31711 .51186 m .32639 .50872 L .32343 .50581 L p F P
0 g
s
.567 .199 .303 r
.50956 .69203 m .51085 .68864 L .51775 .68798 L p F P
0 g
s
.464 .108 .277 r
.51085 .68864 m .50956 .69203 L .50338 .69345 L p F P
0 g
s
.651 .757 .928 r
.6237 .50584 m .61387 .509 L .61633 .5119 L p F P
0 g
s
.651 .757 .928 r
.61633 .5119 m .62615 .50875 L .6237 .50584 L p F P
0 g
s
.651 .757 .928 r
.47357 .50585 m .46401 .509 L .46672 .5119 L p F P
0 g
s
.651 .757 .928 r
.46672 .5119 m .47627 .50876 L .47357 .50585 L p F P
0 g
s
0 0 0 r
.44021 .66276 m .44183 .66139 L p .44279 .66218 L F P
0 g
s
0 0 0 r
.44279 .66218 m .43855 .66497 L .44021 .66276 L p F P
0 g
s
0 0 0 r
.43855 .66497 m .44021 .66276 L .43459 .66813 L closepath p F P
0 g
s
0 0 0 r
.44183 .66139 m .44801 .65733 L p .44279 .66218 L F P
0 g
s
0 0 0 r
.44801 .65733 m .44982 .65511 L .44183 .66139 L closepath p F P
0 g
s
.759 .246 0 r
.57409 .70895 m .57042 .70671 L .57364 .71047 L p F P
0 g
s
.759 .246 0 r
.57364 .71047 m .57712 .71277 L .57409 .70895 L p F P
0 g
s
0 0 0 r
.43459 .66813 m .43855 .66497 L p .43512 .66907 L F P
0 g
s
0 0 0 r
.43055 .67228 m .43459 .66813 L p .43512 .66907 L F P
0 g
s
.65 .757 .927 r
.18556 .50543 m .17652 .50858 L .17972 .51149 L p F P
0 g
s
.65 .757 .927 r
.17972 .51149 m .18874 .50835 L .18556 .50543 L p F P
0 g
s
0 0 .233 r
.40579 .71568 m .40618 .71477 L .40598 .71941 L p F P
0 g
s
0 0 .233 r
.40598 .71941 m .40557 .72036 L .40579 .71568 L p F P
0 g
s
.651 .758 .928 r
.78616 .50553 m .77603 .50869 L .77822 .5116 L p F P
0 g
s
.651 .758 .928 r
.77822 .5116 m .78834 .50844 L .78616 .50553 L p F P
0 g
s
.657 .262 .284 r
.53924 .68843 m .54261 .69209 L .53446 .69111 L p F P
0 g
s
.657 .262 .284 r
.53511 .68797 m .53924 .68843 L p .53446 .69111 L F P
0 g
s
.65 .757 .928 r
.3357 .50557 m .32639 .50872 L .32933 .51163 L p F P
0 g
s
.65 .757 .928 r
.32933 .51163 m .33863 .50849 L .3357 .50557 L p F P
0 g
s
.752 .26 0 r
.62318 .67483 m .62038 .6723 L .62305 .67619 L p F P
0 g
s
.752 .26 0 r
.62305 .67619 m .62586 .67871 L .62318 .67483 L p F P
0 g
s
.651 .757 .928 r
.63601 .5056 m .62615 .50875 L .6286 .51166 L p F P
0 g
s
.651 .757 .928 r
.6286 .51166 m .63844 .50851 L .63601 .5056 L p F P
0 g
s
.651 .757 .928 r
.48585 .50561 m .47627 .50876 L .47896 .51166 L p F P
0 g
s
.651 .757 .928 r
.47896 .51166 m .48854 .50852 L .48585 .50561 L p F P
0 g
s
.941 .621 .179 r
.64202 .70602 m .64371 .70879 L .64443 .7133 L p F P
0 g
s
.883 .528 .04 r
.64371 .70879 m .64202 .70602 L .64084 .70165 L p F P
0 g
s
.728 .208 0 r
.56615 .70462 m .56357 .70205 L .5648 .70196 L p F P
0 g
s
.816 .345 .093 r
.56357 .70205 m .56281 .70091 L .5648 .70196 L closepath p F P
0 g
s
.715 .819 .929 r
.62834 .74875 m .63282 .74665 L .63396 .74951 L p F P
0 g
s
.776 .893 .927 r
.63812 .7438 m .63282 .74665 L .63396 .74951 L p F P
0 g
s
.776 .893 .927 r
.63396 .74951 m .64051 .74532 L .63812 .7438 L p F P
0 g
s
.789 .358 0 r
.63738 .69467 m .63704 .69396 L .63458 .69056 L p F P
0 g
s
.771 .328 .199 r
.55523 .69512 m .54921 .69353 L .55266 .69719 L p F P
0 g
s
.771 .328 .199 r
.55266 .69719 m .55816 .69893 L .55523 .69512 L p F P
0 g
s
0 0 0 r
.43512 .66907 m .42983 .67329 L .43055 .67228 L p F P
0 g
s
0 0 0 r
.42983 .67329 m .43055 .67228 L .42858 .6745 L closepath p F P
0 g
s
.65 .757 .928 r
.19781 .50521 m .18874 .50835 L .19192 .51126 L p F P
0 g
s
.65 .757 .928 r
.19192 .51126 m .20097 .50813 L .19781 .50521 L p F P
0 g
s
.651 .758 .928 r
.79849 .50528 m .78834 .50844 L .79051 .51134 L p F P
0 g
s
.651 .758 .928 r
.79051 .51134 m .80065 .50819 L .79849 .50528 L p F P
0 g
s
.65 .757 .928 r
.34797 .50533 m .33863 .50849 L .34156 .51139 L p F P
0 g
s
.65 .757 .928 r
.34156 .51139 m .35088 .50825 L .34797 .50533 L p F P
0 g
s
.651 .757 .928 r
.64832 .50535 m .63844 .50851 L .64086 .51141 L p F P
0 g
s
.651 .757 .928 r
.64086 .51141 m .65073 .50826 L .64832 .50535 L p F P
0 g
s
.651 .757 .928 r
.49814 .50536 m .48854 .50852 L .49121 .51142 L p F P
0 g
s
.651 .757 .928 r
.49121 .51142 m .50081 .50828 L .49814 .50536 L p F P
0 g
s
.26 0 0 r
.49293 .63377 m .50061 .63235 L p .49535 .63499 L F P
0 g
s
.26 0 0 r
.49535 .63499 m .49092 .63555 L .49293 .63377 L p F P
0 g
s
.174 0 0 r
.49293 .63377 m .49092 .63555 L .48135 .63788 L p F P
0 g
s
.692 .149 0 r
.60038 .65414 m .60395 .65772 L .60006 .65547 L p F P
0 g
s
.692 .149 0 r
.59786 .65269 m .60038 .65414 L p .60006 .65547 L F P
0 g
s
0 0 0 r
.42858 .6745 m .42983 .67329 L .42805 .67636 L p F P
0 g
s
0 0 0 r
.42805 .67636 m .42375 .68053 L .42858 .6745 L p F P
0 g
s
.729 .267 0 r
.63319 .6879 m .63087 .68526 L .62842 .68129 L p F P
0 g
s
.767 .293 0 r
.62842 .68129 m .62586 .67871 L .62831 .68268 L p F P
0 g
s
.767 .293 0 r
.62831 .68268 m .63087 .68526 L .62842 .68129 L p F P
0 g
s
.438 .052 .208 r
.49942 .69432 m .49964 .69383 L .50338 .69345 L closepath p F P
0 g
s
0 0 0 r
.44982 .65511 m .45169 .65385 L p .45352 .65437 L F P
0 g
s
0 0 0 r
.45352 .65437 m .44801 .65733 L .44982 .65511 L p F P
0 g
s
.907 .542 .088 r
.63894 .69891 m .64084 .70165 L .64202 .70602 L p F P
0 g
s
.836 .445 0 r
.63738 .69467 m .63894 .69891 L .64084 .70165 L p F P
0 g
s
.65 .757 .928 r
.21005 .50498 m .20097 .50813 L .20413 .51104 L p F P
0 g
s
.65 .757 .928 r
.20413 .51104 m .2132 .5079 L .21005 .50498 L p F P
0 g
s
.456 .627 .926 r
.41724 .74928 m .41628 .74922 L .41622 .74801 L closepath p F P
0 g
s
.651 .758 .928 r
.81083 .50502 m .80065 .50819 L .8028 .51109 L p F P
0 g
s
.651 .758 .928 r
.8028 .51109 m .81296 .50793 L .81083 .50502 L p F P
0 g
s
0 0 .038 r
.41077 .70159 m .41224 .69926 L .41129 .7032 L p F P
0 g
s
0 0 .038 r
.41129 .7032 m .40909 .70669 L .41077 .70159 L p F P
0 g
s
.515 0 0 r
.55448 .63291 m .55489 .63283 L .55558 .63314 L closepath p F P
0 g
s
.502 0 0 r
.55489 .63283 m .55448 .63291 L .54802 .63195 L p F P
0 g
s
.65 .757 .928 r
.36024 .5051 m .35088 .50825 L .35379 .51116 L p F P
0 g
s
.65 .757 .928 r
.35379 .51116 m .36314 .50801 L .36024 .5051 L p F P
0 g
s
.742 .234 0 r
.58104 .71631 m .58018 .71518 L .57712 .71277 L p F P
0 g
s
.567 .199 .303 r
.51775 .68798 m .52154 .68937 L p .50956 .69203 L F P
0 g
s
.565 .193 .295 r
.52154 .68937 m .51775 .68798 L .52224 .68757 L closepath p F P
0 g
s
.651 .757 .928 r
.66064 .5051 m .65073 .50826 L .65313 .51117 L p F P
0 g
s
.651 .757 .928 r
.65313 .51117 m .66303 .50802 L .66064 .5051 L p F P
0 g
s
.651 .757 .928 r
.51044 .50512 m .50081 .50828 L .50346 .51118 L p F P
0 g
s
.651 .757 .928 r
.50346 .51118 m .51308 .50803 L .51044 .50512 L p F P
0 g
s
.657 .262 .284 r
.53446 .69111 m .53381 .69058 L .53511 .68797 L p F P
0 g
s
.659 .263 .285 r
.53381 .69058 m .53031 .68768 L .53511 .68797 L closepath p F P
0 g
s
.896 .898 .821 r
.64283 .74231 m .64051 .74532 L .63812 .7438 L p F P
0 g
s
.896 .898 .821 r
.63812 .7438 m .64181 .73941 L .64283 .74231 L p F P
0 g
s
.952 .904 .738 r
.64283 .74231 m .64181 .73941 L .64508 .73375 L p F P
0 g
s
.8 .355 0 r
.63319 .6879 m .63458 .69056 L .63214 .68769 L p F P
0 g
s
.8 .355 0 r
.63214 .68769 m .63087 .68526 L .63319 .6879 L p F P
0 g
s
.873 .471 .015 r
.63527 .69198 m .63738 .69467 L .63894 .69891 L p F P
0 g
s
.789 .358 0 r
.63458 .69056 m .63527 .69198 L .63738 .69467 L p F P
0 g
s
0 0 0 r
.45169 .65385 m .45818 .65037 L p .45352 .65437 L F P
0 g
s
0 0 0 r
.45818 .65037 m .45941 .64902 L .45169 .65385 L closepath p F P
0 g
s
.798 .998 .855 r
.44868 .73574 m .45185 .73296 L .45043 .73543 L closepath p F P
0 g
s
.812 .949 .911 r
.45043 .73543 m .44868 .73574 L .44261 .7403 L p F P
0 g
s
.65 .757 .928 r
.22231 .50476 m .2132 .5079 L .21634 .51081 L p F P
0 g
s
.65 .757 .928 r
.21634 .51081 m .22543 .50768 L .22231 .50476 L p F P
0 g
s
.073 0 0 r
.47764 .71061 m .48712 .70411 L .47912 .70821 L closepath p F P
0 g
s
0 0 0 r
.47912 .70821 m .47764 .71061 L .47598 .712 L p F P
0 g
s
.651 .758 .928 r
.8151 .51084 m .82528 .50768 L .82739 .51058 L p F P
0 g
s
.651 .758 .928 r
.82316 .50476 m .81296 .50793 L .8151 .51084 L p F P
0 g
s
.651 .758 .928 r
.8151 .51084 m .82528 .50768 L .82316 .50476 L p F P
0 g
s
.482 .679 .952 r
.62431 .74899 m .62834 .74875 L .62589 .74617 L p F P
0 g
s
.482 .679 .952 r
.62589 .74617 m .6231 .74615 L .62431 .74899 L p F P
0 g
s
.55 .684 .928 r
.61598 .7463 m .6231 .74615 L .62431 .74899 L p F P
0 g
s
0 .042 .557 r
.40487 .72857 m .40619 .72482 L p .40746 .73043 L F P
0 g
s
0 .042 .557 r
.40746 .73043 m .40669 .73268 L .40487 .72857 L p F P
0 g
s
.65 .757 .928 r
.37252 .50486 m .36314 .50801 L .36602 .51092 L p F P
0 g
s
.65 .757 .928 r
.36602 .51092 m .37539 .50777 L .37252 .50486 L p F P
0 g
s
.651 .757 .928 r
.67296 .50486 m .66303 .50802 L .66541 .51092 L p F P
0 g
s
.651 .757 .928 r
.66541 .51092 m .67532 .50777 L .67296 .50486 L p F P
0 g
s
.651 .757 .928 r
.52274 .50488 m .51308 .50803 L .51571 .51094 L p F P
0 g
s
.651 .757 .928 r
.51571 .51094 m .52536 .50779 L .52274 .50488 L p F P
0 g
s
.99 .885 .616 r
.64631 .72703 m .64681 .72853 L .64508 .73375 L p F P
0 g
s
.513 .671 .935 r
.6231 .74615 m .61598 .7463 L .6135 .74316 L p F P
0 g
s
.606 .234 .311 r
.53031 .68768 m .53381 .69058 L p .52398 .6908 L F P
0 g
s
.606 .234 .311 r
.52224 .68757 m .53031 .68768 L p .52398 .6908 L F P
0 g
s
.769 .878 .926 r
.4295 .74877 m .42963 .74869 L .42963 .74884 L closepath p F P
0 g
s
.651 .758 .928 r
.82739 .51058 m .8376 .50742 L .83969 .51033 L p F P
0 g
s
.651 .758 .928 r
.8376 .50742 m .82739 .51058 L .82528 .50768 L p F P
0 g
s
.65 .757 .928 r
.23457 .50453 m .22543 .50768 L .22855 .51059 L p F P
0 g
s
.65 .757 .928 r
.22855 .51059 m .23767 .50745 L .23457 .50453 L p F P
0 g
s
.568 .678 .914 r
.42391 .74457 m .4267 .74688 L .41724 .74928 L p F P
0 g
s
.568 .678 .914 r
.41811 .74538 m .42391 .74457 L p .41724 .74928 L F P
0 g
s
.568 .678 .914 r
.41724 .74928 m .41622 .74801 L .41811 .74538 L p F P
0 g
s
.606 .234 .311 r
.52398 .6908 m .52154 .68937 L .52224 .68757 L p F P
0 g
s
0 0 .313 r
.40618 .71477 m .40808 .71161 L .40787 .71631 L p F P
0 g
s
0 0 .313 r
.40787 .71631 m .40598 .71941 L .40618 .71477 L p F P
0 g
s
.651 .757 .928 r
.68528 .50461 m .67532 .50777 L .67769 .51068 L p F P
0 g
s
.651 .757 .928 r
.67769 .51068 m .68763 .50753 L .68528 .50461 L p F P
0 g
s
.65 .757 .928 r
.3848 .50462 m .37539 .50777 L .37826 .51068 L p F P
0 g
s
.65 .757 .928 r
.37826 .51068 m .38765 .50753 L .3848 .50462 L p F P
0 g
s
.55 0 0 r
.55558 .63314 m .56115 .63605 L .55432 .63463 L p F P
0 g
s
.55 0 0 r
.55448 .63291 m .55558 .63314 L p .55432 .63463 L F P
0 g
s
.651 .757 .928 r
.53504 .50463 m .52536 .50779 L .52797 .5107 L p F P
0 g
s
.651 .757 .928 r
.52797 .5107 m .53764 .50755 L .53504 .50463 L p F P
0 g
s
.649 .756 .927 r
.09661 .50398 m .08773 .50711 L .09108 .51003 L p F P
0 g
s
.649 .756 .927 r
.09108 .51003 m .09995 .50692 L .09661 .50398 L p F P
0 g
s
.158 0 0 r
.4806 .63853 m .48135 .63788 L .49092 .63555 L p F P
0 g
s
.438 .052 .208 r
.49793 .69756 m .49942 .69432 L .50338 .69345 L p F P
0 g
s
.272 0 .109 r
.49942 .69432 m .49793 .69756 L .48883 .70085 L p F P
0 g
s
.769 .878 .926 r
.42966 .74538 m .4267 .74688 L .4295 .74877 L p F P
0 g
s
.769 .878 .926 r
.4295 .74877 m .42963 .74869 L .42966 .74538 L p F P
0 g
s
.696 .923 .968 r
.43906 .74304 m .42963 .74869 L .42966 .74538 L p F P
0 g
s
.156 .46 .887 r
.61009 .74181 m .6135 .74316 L .61101 .7401 L p F P
0 g
s
.156 .46 .887 r
.61101 .7401 m .6086 .73902 L .61009 .74181 L p F P
0 g
s
.65 .757 .928 r
.24683 .5043 m .23767 .50745 L .24077 .51036 L p F P
0 g
s
.65 .757 .928 r
.24077 .51036 m .24991 .50722 L .24683 .5043 L p F P
0 g
s
.651 .758 .928 r
.6976 .50436 m .68763 .50753 L .68997 .51043 L p F P
0 g
s
.651 .758 .928 r
.68997 .51043 m .69993 .50728 L .6976 .50436 L p F P
0 g
s
0 0 0 r
.42375 .68053 m .42805 .67636 L p .42459 .68141 L F P
0 g
s
0 0 0 r
.4208 .68457 m .42375 .68053 L p .42459 .68141 L F P
0 g
s
.65 .757 .928 r
.39708 .50438 m .38765 .50753 L .3905 .51044 L p F P
0 g
s
.65 .757 .928 r
.3905 .51044 m .39991 .50729 L .39708 .50438 L p F P
0 g
s
.55 0 0 r
.55432 .63463 m .55235 .63369 L .55448 .63291 L p F P
0 g
s
.511 0 0 r
.55235 .63369 m .54802 .63195 L .55448 .63291 L closepath p F P
0 g
s
.651 .757 .928 r
.54734 .50439 m .53764 .50755 L .54023 .51046 L p F P
0 g
s
.651 .757 .928 r
.54023 .51046 m .54992 .50731 L .54734 .50439 L p F P
0 g
s
.807 .357 .168 r
.56357 .70205 m .56281 .70091 L .55816 .69893 L p F P
0 g
s
.649 .756 .927 r
.10885 .50378 m .09995 .50692 L .10327 .50984 L p F P
0 g
s
.649 .756 .927 r
.10327 .50984 m .11217 .50672 L .10885 .50378 L p F P
0 g
s
.29 0 .124 r
.48728 .704 m .48883 .70085 L .49793 .69756 L p F P
0 g
s
.066 0 0 r
.48883 .70085 m .48728 .704 L .48712 .70411 L p F P
0 g
s
.65 .093 0 r
.58785 .64644 m .58321 .64439 L .58733 .64778 L p F P
0 g
s
.65 .093 0 r
.58733 .64778 m .592 .64981 L .58785 .64644 L p F P
0 g
s
.691 .152 0 r
.60758 .66003 m .60395 .65772 L .60739 .66135 L p F P
0 g
s
.691 .152 0 r
.60739 .66135 m .61105 .66365 L .60758 .66003 L p F P
0 g
s
0 .129 .638 r
.59337 .72737 m .59103 .72478 L .58688 .72124 L p F P
0 g
s
0 .089 .578 r
.58688 .72124 m .58415 .71875 L .58835 .72228 L p F P
0 g
s
0 .089 .578 r
.58835 .72228 m .59103 .72478 L .58688 .72124 L p F P
0 g
s
.722 .286 .215 r
.54835 .69335 m .54868 .69297 L .54921 .69353 L closepath p F P
0 g
s
.729 .295 .22 r
.54261 .69209 m .54835 .69335 L .54868 .69297 L p F P
0 g
s
.65 .757 .928 r
.25909 .50406 m .24991 .50722 L .25299 .51013 L p F P
0 g
s
.65 .757 .928 r
.25299 .51013 m .26216 .50699 L .25909 .50406 L p F P
0 g
s
.651 .758 .928 r
.70993 .50411 m .69993 .50728 L .70225 .51019 L p F P
0 g
s
.651 .758 .928 r
.70225 .51019 m .71224 .50703 L .70993 .50411 L p F P
0 g
s
.65 .757 .928 r
.40937 .50414 m .39991 .50729 L .40274 .5102 L p F P
0 g
s
.65 .757 .928 r
.40274 .5102 m .41218 .50705 L .40937 .50414 L p F P
0 g
s
.449 0 0 r
.58104 .71631 m .58415 .71875 L .58096 .71638 L p F P
0 g
s
.449 0 0 r
.58096 .71638 m .57853 .71455 L .58104 .71631 L p F P
0 g
s
.742 .234 0 r
.57712 .71277 m .57853 .71455 L .58104 .71631 L p F P
0 g
s
.651 .757 .928 r
.55965 .50415 m .54992 .50731 L .5525 .51021 L p F P
0 g
s
.651 .757 .928 r
.5525 .51021 m .56221 .50706 L .55965 .50415 L p F P
0 g
s
.649 .756 .927 r
.12109 .50358 m .11217 .50672 L .11547 .50964 L p F P
0 g
s
.649 .756 .927 r
.11547 .50964 m .12439 .50651 L .12109 .50358 L p F P
0 g
s
.608 .046 0 r
.57321 .63934 m .56763 .63756 L .57239 .64073 L p F P
0 g
s
.608 .046 0 r
.57239 .64073 m .57803 .6425 L .57321 .63934 L p F P
0 g
s
.65 .757 .928 r
.27136 .50383 m .26216 .50699 L .26521 .5099 L p F P
0 g
s
.65 .757 .928 r
.26521 .5099 m .2744 .50675 L .27136 .50383 L p F P
0 g
s
.651 .758 .928 r
.72226 .50387 m .71224 .50703 L .71454 .50994 L p F P
0 g
s
.651 .758 .928 r
.71454 .50994 m .72455 .50678 L .72226 .50387 L p F P
0 g
s
0 0 0 r
.42983 .67329 m .43512 .66907 L .42921 .67543 L p F P
0 g
s
0 0 0 r
.42921 .67543 m .42805 .67636 L .42983 .67329 L p F P
0 g
s
.65 .757 .928 r
.42166 .50389 m .41218 .50705 L .41499 .50996 L p F P
0 g
s
.65 .757 .928 r
.41499 .50996 m .42445 .50681 L .42166 .50389 L p F P
0 g
s
.651 .757 .928 r
.57196 .5039 m .56221 .50706 L .56476 .50997 L p F P
0 g
s
.651 .757 .928 r
.56476 .50997 m .5745 .50682 L .57196 .5039 L p F P
0 g
s
.65 .756 .927 r
.13334 .50337 m .12439 .50651 L .12767 .50943 L p F P
0 g
s
.65 .756 .927 r
.12767 .50943 m .13661 .5063 L .13334 .50337 L p F P
0 g
s
.557 .661 .906 r
.41811 .74538 m .41622 .74801 L .41448 .74573 L closepath p F P
0 g
s
.26 0 0 r
.50061 .63235 m .50323 .63209 L p .49535 .63499 L F P
0 g
s
.279 0 0 r
.50323 .63209 m .50061 .63235 L .50351 .63184 L closepath p F P
0 g
s
.994 .771 .407 r
.64611 .72078 m .64567 .72564 L .64631 .72703 L p F P
0 g
s
.997 .778 .437 r
.64461 .71797 m .64611 .72078 L .64567 .72564 L p F P
0 g
s
.972 .703 .288 r
.64611 .72078 m .64461 .71797 L .64443 .7133 L p F P
0 g
s
.011 0 0 r
.45818 .65037 m .45941 .64902 L .46899 .64409 L p F P
0 g
s
.026 0 0 r
.46901 .64407 m .46899 .64409 L .45941 .64902 L p F P
0 g
s
.169 .489 .902 r
.60023 .7334 m .59855 .73273 L .59604 .72971 L p F P
0 g
s
.724 .288 .216 r
.54921 .69353 m .54835 .69335 L .54622 .69583 L p F P
0 g
s
.724 .288 .216 r
.54622 .69583 m .55266 .69719 L .54921 .69353 L p F P
0 g
s
.692 .149 0 r
.60006 .65547 m .597 .65245 L .59786 .65269 L p F P
0 g
s
.66 .106 0 r
.597 .65245 m .59641 .65192 L .59786 .65269 L closepath p F P
0 g
s
.65 .757 .928 r
.28363 .5036 m .2744 .50675 L .27744 .50966 L p F P
0 g
s
.65 .757 .928 r
.27744 .50966 m .28666 .50652 L .28363 .5036 L p F P
0 g
s
.651 .758 .928 r
.7346 .50362 m .72455 .50678 L .72683 .50969 L p F P
0 g
s
.651 .758 .928 r
.72683 .50969 m .73687 .50654 L .7346 .50362 L p F P
0 g
s
0 0 0 r
.42459 .68141 m .42028 .68556 L .4208 .68457 L p F P
0 g
s
0 0 0 r
.42028 .68556 m .4208 .68457 L .41961 .68635 L closepath p F P
0 g
s
.651 .757 .928 r
.43395 .50365 m .42445 .50681 L .42723 .50972 L p F P
0 g
s
.651 .757 .928 r
.42723 .50972 m .43672 .50657 L .43395 .50365 L p F P
0 g
s
.651 .757 .928 r
.58428 .50366 m .5745 .50682 L .57703 .50973 L p F P
0 g
s
.651 .757 .928 r
.57703 .50973 m .5868 .50658 L .58428 .50366 L p F P
0 g
s
.438 .052 .208 r
.50338 .69345 m .50925 .69283 L p .49793 .69756 L F P
0 g
s
.454 .089 .254 r
.50925 .69283 m .50338 .69345 L .50956 .69203 L closepath p F P
0 g
s
.65 .756 .927 r
.14559 .50316 m .13661 .5063 L .13988 .50922 L p F P
0 g
s
.65 .756 .927 r
.13988 .50922 m .14884 .50609 L .14559 .50316 L p F P
0 g
s
0 .104 .615 r
.59337 .72737 m .59604 .72971 L .59353 .72701 L p F P
0 g
s
0 .104 .615 r
.59353 .72701 m .59103 .72478 L .59337 .72737 L p F P
0 g
s
.727 .292 .217 r
.54835 .69335 m .54261 .69209 L .54598 .69577 L p F P
0 g
s
.727 .292 .217 r
.54598 .69577 m .54622 .69583 L .54835 .69335 L p F P
0 g
s
.65 .757 .928 r
.29591 .50336 m .28666 .50652 L .28967 .50943 L p F P
0 g
s
.65 .757 .928 r
.28967 .50943 m .29891 .50628 L .29591 .50336 L p F P
0 g
s
.651 .758 .928 r
.74694 .50337 m .73687 .50654 L .73913 .50944 L p F P
0 g
s
.651 .758 .928 r
.73913 .50944 m .74918 .50629 L .74694 .50337 L p F P
0 g
s
.699 .179 0 r
.56357 .70205 m .56615 .70462 L .5611 .70276 L p F P
0 g
s
.699 .179 0 r
.5611 .70276 m .56105 .70271 L .56357 .70205 L p F P
0 g
s
.807 .357 .168 r
.55816 .69893 m .56105 .70271 L .56357 .70205 L p F P
0 g
s
.651 .757 .928 r
.44625 .50341 m .43672 .50657 L .43949 .50948 L p F P
0 g
s
.651 .757 .928 r
.43949 .50948 m .449 .50633 L .44625 .50341 L p F P
0 g
s
.651 .757 .928 r
.59659 .50341 m .5868 .50658 L .58931 .50949 L p F P
0 g
s
.651 .757 .928 r
.58931 .50949 m .59909 .50633 L .59659 .50341 L p F P
0 g
s
.673 .142 0 r
.61443 .666 m .61445 .66602 L .61445 .66602 L closepath p F P
0 g
s
.59 .042 0 r
.61105 .66365 m .61443 .666 L .61445 .66602 L p F P
0 g
s
.752 .239 0 r
.61445 .66602 m .61735 .66983 L .61407 .66742 L p F P
0 g
s
.752 .239 0 r
.61443 .666 m .61445 .66602 L p .61407 .66742 L F P
0 g
s
.752 .239 0 r
.61407 .66742 m .61201 .6648 L .61443 .666 L p F P
0 g
s
.726 .204 0 r
.61201 .6648 m .61105 .66365 L .61443 .666 L closepath p F P
0 g
s
.53 0 0 r
.54802 .63195 m .55235 .63369 L p .54655 .63349 L F P
0 g
s
.53 0 0 r
.54008 .6309 m .54802 .63195 L p .54655 .63349 L F P
0 g
s
.65 .756 .927 r
.15784 .50294 m .14884 .50609 L .15209 .50901 L p F P
0 g
s
.65 .756 .927 r
.15209 .50901 m .16108 .50587 L .15784 .50294 L p F P
0 g
s
0 0 0 r
.41961 .68635 m .42028 .68556 L .41887 .68903 L p F P
0 g
s
0 0 0 r
.41887 .68903 m .41646 .69188 L .41961 .68635 L p F P
0 g
s
0 0 .395 r
.40557 .72036 m .40598 .71941 L .40631 .72455 L p F P
0 g
s
0 0 .395 r
.40631 .72455 m .40619 .72482 L .40557 .72036 L p F P
0 g
s
.373 0 0 r
.51485 .63066 m .5155 .63024 L .51814 .63052 L closepath p F P
0 g
s
.327 0 0 r
.5155 .63024 m .51485 .63066 L .50351 .63184 L p F P
0 g
s
.756 .241 0 r
.57042 .70671 m .56615 .70462 L .56968 .7083 L p F P
0 g
s
.756 .241 0 r
.56968 .7083 m .57364 .71047 L .57042 .70671 L p F P
0 g
s
.371 0 0 r
.50323 .63209 m .50351 .63184 L .51485 .63066 L p F P
0 g
s
0 0 .175 r
.40909 .70669 m .41129 .7032 L .41067 .70745 L p F P
0 g
s
0 0 .175 r
.41067 .70745 m .40808 .71161 L .40909 .70669 L p F P
0 g
s
.692 .808 .937 r
.63282 .74665 m .62834 .74875 L .62589 .74617 L p F P
0 g
s
.651 .758 .928 r
.75928 .50311 m .74918 .50629 L .75142 .5092 L p F P
0 g
s
.651 .758 .928 r
.75142 .5092 m .76151 .50603 L .75928 .50311 L p F P
0 g
s
.65 .757 .928 r
.30819 .50312 m .29891 .50628 L .30191 .5092 L p F P
0 g
s
.65 .757 .928 r
.30191 .5092 m .31117 .50605 L .30819 .50312 L p F P
0 g
s
.651 .757 .928 r
.60892 .50317 m .59909 .50633 L .60159 .50924 L p F P
0 g
s
.651 .757 .928 r
.60159 .50924 m .6114 .50609 L .60892 .50317 L p F P
0 g
s
.651 .757 .928 r
.45855 .50317 m .449 .50633 L .45175 .50924 L p F P
0 g
s
.651 .757 .928 r
.45175 .50924 m .46128 .50609 L .45855 .50317 L p F P
0 g
s
.999 .835 .534 r
.6452 .72772 m .64567 .72564 L .64631 .72703 L closepath p F P
0 g
s
.99 .885 .616 r
.6452 .72772 m .64631 .72703 L p .64508 .73375 L F P
0 g
s
.639 .935 .685 r
.45833 .72743 m .45994 .72597 L .45899 .72701 L closepath p F P
0 g
s
.798 .997 .858 r
.45899 .72701 m .45833 .72743 L .45185 .73296 L p F P
0 g
s
.208 0 0 r
.4806 .63853 m .4905 .63592 L p .48765 .63838 L F P
0 g
s
.208 0 0 r
.48765 .63838 m .47858 .64059 L .4806 .63853 L p F P
0 g
s
.158 0 0 r
.49092 .63555 m .4905 .63592 L .4806 .63853 L p F P
0 g
s
.097 0 0 r
.4806 .63853 m .47858 .64059 L .46953 .64389 L p F P
0 g
s
.435 0 0 r
.52699 .63029 m .52777 .62987 L .53009 .6304 L closepath p F P
0 g
s
.379 0 0 r
.52777 .62987 m .52699 .63029 L .51814 .63052 L p F P
0 g
s
.65 .757 .927 r
.1701 .50272 m .16108 .50587 L .1643 .50879 L p F P
0 g
s
.65 .757 .927 r
.1643 .50879 m .17332 .50565 L .1701 .50272 L p F P
0 g
s
.613 .045 0 r
.58095 .6435 m .58208 .64358 L .58321 .64439 L closepath p F P
0 g
s
.534 0 0 r
.57803 .6425 m .58095 .6435 L .58208 .64358 L p F P
0 g
s
.943 .894 .75 r
.64408 .73083 m .64508 .73375 L .64181 .73941 L p F P
0 g
s
.99 .885 .616 r
.64508 .73375 m .64408 .73083 L .6452 .72772 L p F P
0 g
s
.824 .386 0 r
.63527 .69198 m .63458 .69056 L .63214 .68769 L p F P
0 g
s
.981 .704 .323 r
.64273 .71053 m .64443 .7133 L .64461 .71797 L p F P
0 g
s
.941 .621 .179 r
.64443 .7133 m .64273 .71053 L .64202 .70602 L p F P
0 g
s
.772 .991 .886 r
.44541 .73618 m .43626 .74214 L .43906 .74304 L p F P
0 g
s
.772 .991 .886 r
.43906 .74304 m .44261 .7403 L .44541 .73618 L p F P
0 g
s
.696 .923 .968 r
.42966 .74538 m .43626 .74214 L .43906 .74304 L p F P
0 g
s
.651 .758 .928 r
.77163 .50286 m .76151 .50603 L .76373 .50895 L p F P
0 g
s
.651 .758 .928 r
.76373 .50895 m .77383 .50578 L .77163 .50286 L p F P
0 g
s
.65 .757 .928 r
.32047 .50289 m .31117 .50605 L .31415 .50896 L p F P
0 g
s
.65 .757 .928 r
.31415 .50896 m .32343 .50581 L .32047 .50289 L p F P
0 g
s
.651 .757 .928 r
.62124 .50292 m .6114 .50609 L .61387 .509 L p F P
0 g
s
.651 .757 .928 r
.61387 .509 m .6237 .50584 L .62124 .50292 L p F P
0 g
s
.651 .757 .928 r
.47085 .50293 m .46128 .50609 L .46401 .509 L p F P
0 g
s
.651 .757 .928 r
.46401 .509 m .47357 .50585 L .47085 .50293 L p F P
0 g
s
.679 .13 0 r
.597 .65245 m .59641 .65192 L .592 .64981 L p F P
0 g
s
.777 .282 0 r
.62038 .6723 m .61735 .66983 L .62001 .67372 L p F P
0 g
s
.777 .282 0 r
.62001 .67372 m .62305 .67619 L .62038 .6723 L p F P
0 g
s
.65 .757 .927 r
.18236 .5025 m .17332 .50565 L .17652 .50858 L p F P
0 g
s
.65 .757 .927 r
.17652 .50858 m .18556 .50543 L .18236 .5025 L p F P
0 g
s
.651 .758 .928 r
.78397 .50261 m .77383 .50578 L .77603 .50869 L p F P
0 g
s
.651 .758 .928 r
.77603 .50869 m .78616 .50553 L .78397 .50261 L p F P
0 g
s
.697 .978 .907 r
.44868 .73574 m .44261 .7403 L .44541 .73618 L p F P
0 g
s
.65 .757 .928 r
.33275 .50265 m .32343 .50581 L .32639 .50872 L p F P
0 g
s
.65 .757 .928 r
.32639 .50872 m .3357 .50557 L .33275 .50265 L p F P
0 g
s
.651 .757 .928 r
.63357 .50267 m .6237 .50584 L .62615 .50875 L p F P
0 g
s
.651 .757 .928 r
.62615 .50875 m .63601 .5056 L .63357 .50267 L p F P
0 g
s
.651 .757 .928 r
.48316 .50268 m .47357 .50585 L .47627 .50876 L p F P
0 g
s
.651 .757 .928 r
.47627 .50876 m .48585 .50561 L .48316 .50268 L p F P
0 g
s
.354 0 0 r
.50107 .63395 m .50323 .63209 L .51285 .63225 L p F P
0 g
s
.26 0 0 r
.50323 .63209 m .50107 .63395 L .49535 .63499 L p F P
0 g
s
.371 0 0 r
.51485 .63066 m .51285 .63225 L .50323 .63209 L p F P
0 g
s
.121 .458 .887 r
.6086 .73902 m .60678 .73631 L .60023 .7334 L p F P
0 g
s
.057 .432 .872 r
.59837 .73069 m .60023 .7334 L .60678 .73631 L p F P
0 g
s
.169 .489 .902 r
.59604 .72971 m .59837 .73069 L .60023 .7334 L p F P
0 g
s
.612 .219 .273 r
.52084 .69082 m .52154 .68937 L .52398 .6908 L closepath p F P
0 g
s
.567 .199 .303 r
.52154 .68937 m .52084 .69082 L .50956 .69203 L p F P
0 g
s
.65 .757 .927 r
.19463 .50228 m .18556 .50543 L .18874 .50835 L p F P
0 g
s
.65 .757 .927 r
.18874 .50835 m .19781 .50521 L .19463 .50228 L p F P
0 g
s
0 0 .109 r
.41224 .69926 m .41385 .69726 L .41189 .70246 L p F P
0 g
s
0 0 .109 r
.41189 .70246 m .41129 .7032 L .41224 .69926 L p F P
0 g
s
.651 .758 .928 r
.79633 .50235 m .78616 .50553 L .78834 .50844 L p F P
0 g
s
.651 .758 .928 r
.78834 .50844 m .79849 .50528 L .79633 .50235 L p F P
0 g
s
.65 .757 .928 r
.34504 .50241 m .3357 .50557 L .33863 .50849 L p F P
0 g
s
.65 .757 .928 r
.33863 .50849 m .34797 .50533 L .34504 .50241 L p F P
0 g
s
.954 .626 .219 r
.64011 .70329 m .64202 .70602 L .64273 .71053 L p F P
0 g
s
.907 .542 .088 r
.64202 .70602 m .64011 .70329 L .63894 .69891 L p F P
0 g
s
.651 .757 .928 r
.6459 .50243 m .63601 .5056 L .63844 .50851 L p F P
0 g
s
.651 .757 .928 r
.63844 .50851 m .64832 .50535 L .6459 .50243 L p F P
0 g
s
.651 .757 .928 r
.49547 .50244 m .48585 .50561 L .48854 .50852 L p F P
0 g
s
.651 .757 .928 r
.48854 .50852 m .49814 .50536 L .49547 .50244 L p F P
0 g
s
0 0 0 r
.42028 .68556 m .42459 .68141 L .42085 .68713 L p F P
0 g
s
0 0 0 r
.42085 .68713 m .41887 .68903 L .42028 .68556 L p F P
0 g
s
.76 .248 0 r
.57853 .71455 m .57712 .71277 L .57364 .71047 L p F P
0 g
s
.567 0 0 r
.56691 .63736 m .56721 .63733 L .56763 .63756 L closepath p F P
0 g
s
.49 0 0 r
.56115 .63605 m .56691 .63736 L .56721 .63733 L p F P
0 g
s
.795 .316 0 r
.62586 .67871 m .62305 .67619 L .6255 .68016 L p F P
0 g
s
.795 .316 0 r
.6255 .68016 m .62831 .68268 L .62586 .67871 L p F P
0 g
s
.28 .405 .811 r
.41174 .7413 m .40925 .73994 L .40985 .73745 L closepath p F P
0 g
s
.347 .478 .849 r
.40925 .73994 m .41174 .7413 L .41448 .74573 L p F P
0 g
s
.493 .582 .872 r
.41448 .74573 m .41811 .74538 L .41906 .74179 L p F P
0 g
s
.493 .582 .872 r
.41906 .74179 m .41174 .7413 L .41448 .74573 L p F P
0 g
s
.686 .14 0 r
.597 .65245 m .60006 .65547 L .5959 .65329 L p F P
0 g
s
.686 .14 0 r
.5959 .65329 m .59454 .65202 L .597 .65245 L p F P
0 g
s
.679 .13 0 r
.592 .64981 m .59454 .65202 L .597 .65245 L p F P
0 g
s
.65 .757 .927 r
.2069 .50205 m .19781 .50521 L .20097 .50813 L p F P
0 g
s
.65 .757 .927 r
.20097 .50813 m .21005 .50498 L .2069 .50205 L p F P
0 g
s
.651 .758 .928 r
.80868 .5021 m .79849 .50528 L .80065 .50819 L p F P
0 g
s
.651 .758 .928 r
.80065 .50819 m .81083 .50502 L .80868 .5021 L p F P
0 g
s
0 0 0 r
.43727 .66697 m .44279 .66218 L .43855 .66497 L closepath p F P
0 g
s
0 0 0 r
.43855 .66497 m .43727 .66697 L .43512 .66907 L p F P
0 g
s
.513 .671 .935 r
.6135 .74316 m .62149 .7434 L .6231 .74615 L p F P
0 g
s
.476 .66 .942 r
.62149 .7434 m .6135 .74316 L .61101 .7401 L p F P
0 g
s
.53 0 0 r
.54655 .63349 m .54005 .63092 L .54008 .6309 L p F P
0 g
s
.483 0 0 r
.54005 .63092 m .53998 .6309 L .54008 .6309 L closepath p F P
0 g
s
.65 .757 .928 r
.35734 .50217 m .34797 .50533 L .35088 .50825 L p F P
0 g
s
.65 .757 .928 r
.35088 .50825 m .36024 .5051 L .35734 .50217 L p F P
0 g
s
.497 0 0 r
.54005 .63092 m .53998 .6309 L .53009 .6304 L p F P
0 g
s
.651 .757 .928 r
.65824 .50218 m .64832 .50535 L .65073 .50826 L p F P
0 g
s
.651 .757 .928 r
.65073 .50826 m .66064 .5051 L .65824 .50218 L p F P
0 g
s
.651 .757 .928 r
.50779 .5022 m .49814 .50536 L .50081 .50828 L p F P
0 g
s
.651 .757 .928 r
.50081 .50828 m .51044 .50512 L .50779 .5022 L p F P
0 g
s
.027 0 .462 r
.40598 .71941 m .40787 .71631 L .40868 .72072 L p F P
0 g
s
.027 0 .462 r
.40868 .72072 m .40631 .72455 L .40598 .71941 L p F P
0 g
s
.692 .808 .937 r
.62589 .74617 m .63179 .74375 L .63282 .74665 L p F P
0 g
s
.741 .862 .936 r
.63571 .74196 m .63179 .74375 L .63282 .74665 L p F P
0 g
s
.741 .862 .936 r
.63282 .74665 m .63812 .7438 L .63571 .74196 L p F P
0 g
s
.685 .966 .748 r
.45552 .72868 m .44587 .73588 L .44868 .73574 L p F P
0 g
s
.685 .966 .748 r
.45559 .72865 m .45552 .72868 L p .44868 .73574 L F P
0 g
s
.685 .966 .748 r
.44868 .73574 m .45185 .73296 L .45559 .72865 L p F P
0 g
s
.697 .978 .907 r
.44541 .73618 m .44587 .73588 L .44868 .73574 L p F P
0 g
s
.503 0 0 r
.54005 .63092 m .54655 .63349 L .53803 .63257 L p F P
0 g
s
.503 0 0 r
.53803 .63257 m .53747 .63238 L .54005 .63092 L p F P
0 g
s
.497 0 0 r
.53009 .6304 m .53747 .63238 L .54005 .63092 L p F P
0 g
s
.755 .268 .081 r
.55816 .69893 m .55266 .69719 L .55603 .70089 L p F P
0 g
s
.755 .268 .081 r
.56105 .70271 m .55816 .69893 L p .55603 .70089 L F P
0 g
s
.693 .973 .77 r
.45559 .72865 m .45833 .72743 L .45185 .73296 L closepath p F P
0 g
s
.923 .552 .133 r
.63683 .69623 m .63894 .69891 L .64011 .70329 L p F P
0 g
s
.873 .471 .015 r
.63894 .69891 m .63683 .69623 L .63527 .69198 L p F P
0 g
s
.714 .302 .264 r
.54261 .69209 m .53446 .69111 L .53863 .69455 L p F P
0 g
s
.714 .302 .264 r
.53863 .69455 m .54598 .69577 L .54261 .69209 L p F P
0 g
s
.828 .376 0 r
.63214 .68769 m .63087 .68526 L .62831 .68268 L p F P
0 g
s
.661 .114 0 r
.58321 .64439 m .58733 .64778 L .58238 .64581 L p F P
0 g
s
.661 .114 0 r
.58095 .6435 m .58321 .64439 L p .58238 .64581 L F P
0 g
s
.606 .055 0 r
.56763 .63756 m .57239 .64073 L .56646 .63905 L p F P
0 g
s
.606 .055 0 r
.56691 .63736 m .56763 .63756 L p .56646 .63905 L F P
0 g
s
.534 .165 .287 r
.50956 .69203 m .52084 .69082 L p .51623 .69434 L F P
0 g
s
.534 .165 .287 r
.51623 .69434 m .50925 .69283 L .50956 .69203 L p F P
0 g
s
.65 .757 .928 r
.21917 .50183 m .21005 .50498 L .2132 .5079 L p F P
0 g
s
.65 .757 .928 r
.2132 .5079 m .22231 .50476 L .21917 .50183 L p F P
0 g
s
.651 .758 .928 r
.82104 .50184 m .81083 .50502 L .81296 .50793 L p F P
0 g
s
.651 .758 .928 r
.81296 .50793 m .82316 .50476 L .82104 .50184 L p F P
0 g
s
.891 .484 .062 r
.63294 .68935 m .63527 .69198 L .63683 .69623 L p F P
0 g
s
.824 .386 0 r
.63214 .68769 m .63294 .68935 L .63527 .69198 L p F P
0 g
s
.65 .757 .928 r
.36963 .50193 m .36024 .5051 L .36314 .50801 L p F P
0 g
s
.65 .757 .928 r
.36314 .50801 m .37252 .50486 L .36963 .50193 L p F P
0 g
s
.651 .757 .928 r
.67058 .50193 m .66064 .5051 L .66303 .50802 L p F P
0 g
s
.651 .757 .928 r
.66303 .50802 m .67296 .50486 L .67058 .50193 L p F P
0 g
s
.651 .757 .928 r
.52011 .50195 m .51044 .50512 L .51308 .50803 L p F P
0 g
s
.651 .757 .928 r
.51308 .50803 m .52274 .50488 L .52011 .50195 L p F P
0 g
s
.404 0 0 r
.51485 .63066 m .51814 .63052 L p .51509 .63251 L F P
0 g
s
.404 0 0 r
.51509 .63251 m .51285 .63225 L .51485 .63066 L p F P
0 g
s
.637 .954 .761 r
.45833 .72743 m .45994 .72597 L p .45572 .72852 L F P
0 g
s
.637 .954 .761 r
.45572 .72852 m .45559 .72865 L .45833 .72743 L p F P
0 g
s
.637 .954 .761 r
.45994 .72597 m .46522 .72115 L p .45572 .72852 L F P
0 g
s
.492 .832 .547 r
.46522 .72115 m .45994 .72597 L .46763 .71908 L p F P
0 g
s
0 0 .02 r
.41646 .69188 m .41887 .68903 L .41769 .69273 L p F P
0 g
s
0 0 .02 r
.41769 .69273 m .41385 .69726 L .41646 .69188 L p F P
0 g
s
.606 .055 0 r
.56646 .63905 m .5647 .63797 L .56691 .63736 L p F P
0 g
s
.574 .015 0 r
.5647 .63797 m .56115 .63605 L .56691 .63736 L closepath p F P
0 g
s
.5 .84 .561 r
.46787 .71886 m .46799 .71876 L .46763 .71908 L closepath p F P
0 g
s
.465 .82 .548 r
.46787 .71886 m .46799 .71876 L .47598 .712 L p F P
0 g
s
.404 0 0 r
.51814 .63052 m .52516 .63159 L p .51509 .63251 L F P
0 g
s
.412 0 0 r
.52516 .63159 m .51814 .63052 L .52699 .63029 L closepath p F P
0 g
s
.139 .22 .686 r
.40904 .73544 m .40669 .73268 L .40746 .73043 L closepath p F P
0 g
s
.149 .265 .728 r
.40669 .73268 m .40904 .73544 L .40985 .73745 L p F P
0 g
s
.65 .757 .928 r
.23145 .5016 m .22231 .50476 L .22543 .50768 L p F P
0 g
s
.65 .757 .928 r
.22543 .50768 m .23457 .50453 L .23145 .5016 L p F P
0 g
s
.651 .758 .928 r
.82528 .50768 m .83551 .50451 L .8376 .50742 L p F P
0 g
s
.651 .758 .928 r
.8334 .50158 m .82316 .50476 L .82528 .50768 L p F P
0 g
s
.651 .758 .928 r
.82528 .50768 m .83551 .50451 L .8334 .50158 L p F P
0 g
s
.715 .181 0 r
.60395 .65772 m .60006 .65547 L .60346 .6591 L p F P
0 g
s
.715 .181 0 r
.60346 .6591 m .60739 .66135 L .60395 .65772 L p F P
0 g
s
.65 .757 .928 r
.38193 .50169 m .37252 .50486 L .37539 .50777 L p F P
0 g
s
.65 .757 .928 r
.37539 .50777 m .3848 .50462 L .38193 .50169 L p F P
0 g
s
.651 .757 .928 r
.68292 .50169 m .67296 .50486 L .67532 .50777 L p F P
0 g
s
.651 .757 .928 r
.67532 .50777 m .68528 .50461 L .68292 .50169 L p F P
0 g
s
.163 0 0 r
.46899 .64409 m .46953 .64389 L .46901 .64407 L closepath p F P
0 g
s
.651 .757 .928 r
.53243 .50171 m .52274 .50488 L .52536 .50779 L p F P
0 g
s
.651 .757 .928 r
.52536 .50779 m .53504 .50463 L .53243 .50171 L p F P
0 g
s
.88 .886 .834 r
.64181 .73941 m .63812 .7438 L .63571 .74196 L p F P
0 g
s
.88 .886 .834 r
.63571 .74196 m .64062 .73654 L .64181 .73941 L p F P
0 g
s
.943 .894 .75 r
.64181 .73941 m .64062 .73654 L .64408 .73083 L p F P
0 g
s
.154 0 0 r
.46685 .6466 m .46899 .64409 L .46953 .64389 L p F P
0 g
s
.011 0 0 r
.46899 .64409 m .46685 .6466 L .45818 .65037 L p F P
0 g
s
.463 0 0 r
.53009 .6304 m .53747 .63238 L p .5277 .63219 L F P
0 g
s
.463 0 0 r
.52699 .63029 m .53009 .6304 L p .5277 .63219 L F P
0 g
s
.437 .662 .956 r
.6231 .74615 m .62589 .74617 L .62343 .74352 L p F P
0 g
s
.437 .662 .956 r
.62343 .74352 m .62149 .7434 L .6231 .74615 L p F P
0 g
s
.664 .254 .258 r
.53355 .69103 m .53381 .69058 L .53446 .69111 L closepath p F P
0 g
s
.606 .234 .311 r
.53381 .69058 m .53355 .69103 L .52398 .6908 L p F P
0 g
s
0 0 0 r
.46787 .71886 m .47507 .71384 L p .46534 .72107 L F P
0 g
s
0 0 0 r
.46534 .72107 m .46522 .72115 L .46787 .71886 L p F P
0 g
s
.465 .82 .548 r
.47722 .71113 m .47507 .71384 L .46787 .71886 L p F P
0 g
s
.465 .82 .548 r
.47598 .712 m .47722 .71113 L p .46787 .71886 L F P
0 g
s
.463 0 0 r
.5277 .63219 m .52516 .63159 L .52699 .63029 L p F P
0 g
s
.994 .816 .558 r
.64567 .72564 m .64415 .72284 L p .6429 .72797 L F P
0 g
s
.994 .816 .558 r
.6429 .72797 m .6452 .72772 L .64567 .72564 L p F P
0 g
s
.997 .778 .437 r
.64567 .72564 m .64415 .72284 L .64461 .71797 L p F P
0 g
s
.65 .757 .928 r
.24373 .50137 m .23457 .50453 L .23767 .50745 L p F P
0 g
s
.65 .757 .928 r
.23767 .50745 m .24683 .5043 L .24373 .50137 L p F P
0 g
s
.154 0 0 r
.46953 .64389 m .4783 .64087 L p .46685 .6466 L F P
0 g
s
.093 0 0 r
.4783 .64087 m .47858 .64059 L .46953 .64389 L closepath p F P
0 g
s
0 0 0 r
.47722 .71113 m .47764 .71061 L .47598 .712 L closepath p F P
0 g
s
.651 .757 .928 r
.69527 .50144 m .68528 .50461 L .68763 .50753 L p F P
0 g
s
.651 .757 .928 r
.68763 .50753 m .6976 .50436 L .69527 .50144 L p F P
0 g
s
.65 .757 .928 r
.39424 .50145 m .3848 .50462 L .38765 .50753 L p F P
0 g
s
.65 .757 .928 r
.38765 .50753 m .39708 .50438 L .39424 .50145 L p F P
0 g
s
.651 .757 .928 r
.54475 .50146 m .53504 .50463 L .53764 .50755 L p F P
0 g
s
.651 .757 .928 r
.53764 .50755 m .54734 .50439 L .54475 .50146 L p F P
0 g
s
0 0 0 r
.47722 .71113 m .47764 .71061 L .48712 .70411 L p F P
0 g
s
.649 .756 .927 r
.10552 .50084 m .09661 .50398 L .09995 .50692 L p F P
0 g
s
.649 .756 .927 r
.09995 .50692 m .10885 .50378 L .10552 .50084 L p F P
0 g
s
.478 0 0 r
.58415 .71875 m .58096 .71638 L .58532 .71986 L p F P
0 g
s
.478 0 0 r
.58532 .71986 m .58835 .72228 L .58415 .71875 L p F P
0 g
s
.719 .895 .959 r
.43231 .7413 m .42391 .74457 L .4267 .74688 L p F P
0 g
s
.719 .895 .959 r
.4267 .74688 m .42966 .74538 L .43231 .7413 L p F P
0 g
s
.007 0 0 r
.44693 .65888 m .45352 .65437 L .44801 .65733 L closepath p F P
0 g
s
0 0 0 r
.44801 .65733 m .44693 .65888 L .44279 .66218 L p F P
0 g
s
.65 .757 .928 r
.25602 .50113 m .24683 .5043 L .24991 .50722 L p F P
0 g
s
.65 .757 .928 r
.24991 .50722 m .25909 .50406 L .25602 .50113 L p F P
0 g
s
.082 .429 .872 r
.6086 .73902 m .61101 .7401 L .60852 .73716 L p F P
0 g
s
.082 .429 .872 r
.60852 .73716 m .60678 .73631 L .6086 .73902 L p F P
0 g
s
.651 .758 .928 r
.70761 .50119 m .6976 .50436 L .69993 .50728 L p F P
0 g
s
.651 .758 .928 r
.69993 .50728 m .70993 .50411 L .70761 .50119 L p F P
0 g
s
.65 .757 .928 r
.40654 .50121 m .39708 .50438 L .39991 .50729 L p F P
0 g
s
.65 .757 .928 r
.39991 .50729 m .40937 .50414 L .40654 .50121 L p F P
0 g
s
.651 .757 .928 r
.55708 .50122 m .54734 .50439 L .54992 .50731 L p F P
0 g
s
.651 .757 .928 r
.54992 .50731 m .55965 .50415 L .55708 .50122 L p F P
0 g
s
.649 .756 .927 r
.11778 .50064 m .10885 .50378 L .11217 .50672 L p F P
0 g
s
.649 .756 .927 r
.11217 .50672 m .12109 .50358 L .11778 .50064 L p F P
0 g
s
.082 0 0 r
.45655 .65245 m .45818 .65037 L .46685 .6466 L p F P
0 g
s
0 0 0 r
.45818 .65037 m .45655 .65245 L .45352 .65437 L p F P
0 g
s
.25 0 0 r
.4905 .63592 m .49092 .63555 L .49535 .63499 L closepath p F P
0 g
s
.527 .13 .231 r
.50806 .69524 m .50925 .69283 L .51623 .69434 L closepath p F P
0 g
s
.438 .052 .208 r
.50925 .69283 m .50806 .69524 L .49793 .69756 L p F P
0 g
s
.661 .114 0 r
.58238 .64581 m .5796 .64362 L .58095 .6435 L p F P
0 g
s
.631 .074 0 r
.5796 .64362 m .57803 .6425 L .58095 .6435 L closepath p F P
0 g
s
.091 .465 .889 r
.59837 .73069 m .59604 .72971 L .59353 .72701 L p F P
0 g
s
0 0 .338 r
.40808 .71161 m .40787 .71631 L .41046 .71215 L p F P
0 g
s
0 0 .338 r
.41067 .70745 m .40808 .71161 L p .41046 .71215 L F P
0 g
s
.65 .757 .928 r
.2683 .5009 m .25909 .50406 L .26216 .50699 L p F P
0 g
s
.65 .757 .928 r
.26216 .50699 m .27136 .50383 L .2683 .5009 L p F P
0 g
s
.665 .255 .258 r
.53446 .69111 m .53355 .69103 L .53185 .69398 L p F P
0 g
s
.665 .255 .258 r
.53185 .69398 m .53863 .69455 L .53446 .69111 L p F P
0 g
s
.651 .758 .928 r
.71997 .50094 m .70993 .50411 L .71224 .50703 L p F P
0 g
s
.651 .758 .928 r
.71224 .50703 m .72226 .50387 L .71997 .50094 L p F P
0 g
s
.65 .757 .928 r
.41886 .50096 m .40937 .50414 L .41218 .50705 L p F P
0 g
s
.65 .757 .928 r
.41218 .50705 m .42166 .50389 L .41886 .50096 L p F P
0 g
s
.651 .757 .928 r
.56941 .50097 m .55965 .50415 L .56221 .50706 L p F P
0 g
s
.651 .757 .928 r
.56221 .50706 m .57196 .5039 L .56941 .50097 L p F P
0 g
s
.618 .203 .232 r
.53355 .69103 m .52398 .6908 L .52926 .69392 L p F P
0 g
s
.618 .203 .232 r
.52926 .69392 m .53185 .69398 L .53355 .69103 L p F P
0 g
s
.65 .756 .927 r
.13005 .50043 m .12109 .50358 L .12439 .50651 L p F P
0 g
s
.65 .756 .927 r
.12439 .50651 m .13334 .50337 L .13005 .50043 L p F P
0 g
s
.738 .221 0 r
.56615 .70462 m .5611 .70276 L .56509 .7063 L p F P
0 g
s
.738 .221 0 r
.56509 .7063 m .56968 .7083 L .56615 .70462 L p F P
0 g
s
.486 0 0 r
.57853 .71455 m .58096 .71638 L .57726 .71414 L p F P
0 g
s
.486 0 0 r
.57726 .71414 m .57601 .71328 L .57853 .71455 L p F P
0 g
s
.76 .248 0 r
.57364 .71047 m .57601 .71328 L .57853 .71455 L p F P
0 g
s
.745 .225 0 r
.61201 .6648 m .61105 .66365 L .60739 .66135 L p F P
0 g
s
.65 .757 .928 r
.2806 .50066 m .27136 .50383 L .2744 .50675 L p F P
0 g
s
.65 .757 .928 r
.2744 .50675 m .28363 .5036 L .2806 .50066 L p F P
0 g
s
.651 .758 .928 r
.73232 .50069 m .72226 .50387 L .72455 .50678 L p F P
0 g
s
.651 .758 .928 r
.72455 .50678 m .7346 .50362 L .73232 .50069 L p F P
0 g
s
.651 .757 .928 r
.43117 .50072 m .42166 .50389 L .42445 .50681 L p F P
0 g
s
.651 .757 .928 r
.42445 .50681 m .43395 .50365 L .43117 .50072 L p F P
0 g
s
.651 .757 .928 r
.58175 .50073 m .57196 .5039 L .5745 .50682 L p F P
0 g
s
.651 .757 .928 r
.5745 .50682 m .58428 .50366 L .58175 .50073 L p F P
0 g
s
.568 .706 .935 r
.42391 .74457 m .41811 .74538 L .41906 .74179 L p F P
0 g
s
.648 .885 .983 r
.43626 .74214 m .42966 .74538 L .43231 .7413 L p F P
0 g
s
.988 .874 .627 r
.64408 .73083 m .6429 .72797 L .6452 .72772 L closepath p F P
0 g
s
.613 .221 .276 r
.52398 .6908 m .52084 .69082 L .51933 .69399 L p F P
0 g
s
.534 .165 .287 r
.52084 .69082 m .51933 .69399 L .51623 .69434 L p F P
0 g
s
.613 .221 .276 r
.51933 .69399 m .52926 .69392 L .52398 .6908 L p F P
0 g
s
.65 .756 .927 r
.14232 .50022 m .13334 .50337 L .13661 .5063 L p F P
0 g
s
.65 .756 .927 r
.13661 .5063 m .14559 .50316 L .14232 .50022 L p F P
0 g
s
.433 .049 .209 r
.49691 .69979 m .49793 .69756 L .50806 .69524 L p F P
0 g
s
.29 0 .124 r
.49793 .69756 m .49691 .69979 L .48728 .704 L p F P
0 g
s
0 .018 .525 r
.40648 .72562 m .40619 .72482 L .40631 .72455 L closepath p F P
0 g
s
0 .042 .557 r
.40619 .72482 m .40648 .72562 L .40746 .73043 L p F P
0 g
s
.63 .066 0 r
.592 .64981 m .58733 .64778 L .59137 .65121 L p F P
0 g
s
.63 .066 0 r
.59454 .65202 m .592 .64981 L p .59137 .65121 L F P
0 g
s
.997 .771 .46 r
.64291 .71521 m .64461 .71797 L .64415 .72284 L p F P
0 g
s
.981 .704 .323 r
.64461 .71797 m .64291 .71521 L .64273 .71053 L p F P
0 g
s
0 .062 .552 r
.59353 .72701 m .59103 .72478 L .58835 .72228 L p F P
0 g
s
.65 .757 .928 r
.29289 .50043 m .28363 .5036 L .28666 .50652 L p F P
0 g
s
.65 .757 .928 r
.28666 .50652 m .29591 .50336 L .29289 .50043 L p F P
0 g
s
.011 0 0 r
.47722 .71113 m .48537 .70696 L p .47645 .71317 L F P
0 g
s
.011 0 0 r
.47645 .71317 m .47507 .71384 L .47722 .71113 L p F P
0 g
s
0 0 0 r
.48725 .70404 m .48537 .70696 L .47722 .71113 L p F P
0 g
s
0 0 0 r
.48712 .70411 m .48725 .70404 L p .47722 .71113 L F P
0 g
s
.651 .758 .928 r
.74468 .50044 m .7346 .50362 L .73687 .50654 L p F P
0 g
s
.651 .758 .928 r
.73687 .50654 m .74694 .50337 L .74468 .50044 L p F P
0 g
s
.651 .757 .928 r
.44349 .50048 m .43395 .50365 L .43672 .50657 L p F P
0 g
s
.651 .757 .928 r
.43672 .50657 m .44625 .50341 L .44349 .50048 L p F P
0 g
s
.651 .757 .928 r
.59409 .50048 m .58428 .50366 L .5868 .50658 L p F P
0 g
s
.651 .757 .928 r
.5868 .50658 m .59659 .50341 L .59409 .50048 L p F P
0 g
s
.54 0 0 r
.56115 .63605 m .55432 .63463 L .55982 .63757 L p F P
0 g
s
.54 0 0 r
.5647 .63797 m .56115 .63605 L p .55982 .63757 L F P
0 g
s
.65 .756 .927 r
.1546 .5 m .14559 .50316 L .14884 .50609 L p F P
0 g
s
.65 .756 .927 r
.14884 .50609 m .15784 .50294 L .1546 .5 L p F P
0 g
s
.472 .611 .907 r
.41174 .7413 m .40985 .73745 L p .41952 .73973 L F P
0 g
s
.472 .611 .907 r
.41952 .73973 m .41906 .74179 L .41174 .7413 L p F P
0 g
s
.672 .799 .943 r
.63179 .74375 m .62589 .74617 L .62343 .74352 L p F P
0 g
s
.55 0 0 r
.55128 .63408 m .55235 .63369 L .55432 .63463 L closepath p F P
0 g
s
.53 0 0 r
.55235 .63369 m .55128 .63408 L .54655 .63349 L p F P
0 g
s
.039 0 0 r
.48725 .70404 m .48728 .704 L .48712 .70411 L closepath p F P
0 g
s
.65 .757 .928 r
.30519 .50019 m .29591 .50336 L .29891 .50628 L p F P
0 g
s
.65 .757 .928 r
.29891 .50628 m .30819 .50312 L .30519 .50019 L p F P
0 g
s
.651 .758 .928 r
.75705 .50018 m .74694 .50337 L .74918 .50629 L p F P
0 g
s
.651 .758 .928 r
.74918 .50629 m .75928 .50311 L .75705 .50018 L p F P
0 g
s
.165 .168 .616 r
.40631 .72455 m .40868 .72072 L .41077 .72477 L p F P
0 g
s
.165 .168 .616 r
.40648 .72562 m .40631 .72455 L p .41077 .72477 L F P
0 g
s
.211 0 0 r
.48725 .70404 m .48728 .704 L .49691 .69979 L p F P
0 g
s
.301 0 0 r
.4882 .63824 m .4905 .63592 L .49535 .63499 L p F P
0 g
s
.208 0 0 r
.4905 .63592 m .4882 .63824 L .48765 .63838 L p F P
0 g
s
.651 .757 .928 r
.45581 .50024 m .44625 .50341 L .449 .50633 L p F P
0 g
s
.651 .757 .928 r
.449 .50633 m .45855 .50317 L .45581 .50024 L p F P
0 g
s
.651 .757 .928 r
.60643 .50024 m .59659 .50341 L .59909 .50633 L p F P
0 g
s
.651 .757 .928 r
.59909 .50633 m .60892 .50317 L .60643 .50024 L p F P
0 g
s
0 0 .179 r
.41385 .69726 m .41189 .70246 L .41583 .69786 L p F P
0 g
s
0 0 .179 r
.41769 .69273 m .41385 .69726 L p .41583 .69786 L F P
0 g
s
.846 .402 0 r
.63214 .68769 m .63294 .68935 L .63039 .68677 L p F P
0 g
s
.846 .402 0 r
.63039 .68677 m .6297 .68535 L .63214 .68769 L p F P
0 g
s
.828 .376 0 r
.62831 .68268 m .6297 .68535 L .63214 .68769 L p F P
0 g
s
.218 0 .004 r
.48537 .70696 m .48725 .70404 L .49635 .70073 L p F P
0 g
s
.211 0 0 r
.49691 .69979 m .49635 .70073 L .48725 .70404 L p F P
0 g
s
.689 .244 .188 r
.55266 .69719 m .55603 .70089 L .55 .69929 L p F P
0 g
s
.689 .244 .188 r
.54622 .69583 m .55266 .69719 L p .55 .69929 L F P
0 g
s
.65 .757 .927 r
.16687 .49978 m .15784 .50294 L .16108 .50587 L p F P
0 g
s
.65 .757 .927 r
.16108 .50587 m .1701 .50272 L .16687 .49978 L p F P
0 g
s
.794 .301 0 r
.61735 .66983 m .61407 .66742 L .61672 .67131 L p F P
0 g
s
.794 .301 0 r
.61672 .67131 m .62001 .67372 L .61735 .66983 L p F P
0 g
s
.651 .758 .928 r
.76941 .49993 m .75928 .50311 L .76151 .50603 L p F P
0 g
s
.651 .758 .928 r
.76151 .50603 m .77163 .50286 L .76941 .49993 L p F P
0 g
s
.65 .757 .928 r
.31749 .49995 m .30819 .50312 L .31117 .50605 L p F P
0 g
s
.65 .757 .928 r
.31117 .50605 m .32047 .50289 L .31749 .49995 L p F P
0 g
s
.165 .168 .616 r
.41077 .72477 m .40839 .72883 L .40648 .72562 L p F P
0 g
s
.162 .167 .616 r
.40839 .72883 m .40746 .73043 L .40648 .72562 L closepath p F P
0 g
s
.651 .757 .928 r
.61877 .49999 m .60892 .50317 L .6114 .50609 L p F P
0 g
s
.651 .757 .928 r
.6114 .50609 m .62124 .50292 L .61877 .49999 L p F P
0 g
s
.651 .757 .928 r
.46813 .49999 m .45855 .50317 L .46128 .50609 L p F P
0 g
s
.651 .757 .928 r
.46128 .50609 m .47085 .50293 L .46813 .49999 L p F P
0 g
s
.641 .094 0 r
.5796 .64362 m .57803 .6425 L .57239 .64073 L p F P
0 g
s
.65 .757 .927 r
.17916 .49956 m .1701 .50272 L .17332 .50565 L p F P
0 g
s
.65 .757 .927 r
.17332 .50565 m .18236 .5025 L .17916 .49956 L p F P
0 g
s
.984 .701 .352 r
.64083 .7078 m .64273 .71053 L .64291 .71521 L p F P
0 g
s
.954 .626 .219 r
.64273 .71053 m .64083 .7078 L .64011 .70329 L p F P
0 g
s
.651 .758 .928 r
.78178 .49968 m .77163 .50286 L .77383 .50578 L p F P
0 g
s
.651 .758 .928 r
.77383 .50578 m .78397 .50261 L .78178 .49968 L p F P
0 g
s
.65 .757 .928 r
.3298 .49971 m .32047 .50289 L .32343 .50581 L p F P
0 g
s
.65 .757 .928 r
.32343 .50581 m .33275 .50265 L .3298 .49971 L p F P
0 g
s
.722 .191 0 r
.57364 .71047 m .56968 .7083 L .57313 .71202 L p F P
0 g
s
.722 .191 0 r
.57601 .71328 m .57364 .71047 L p .57313 .71202 L F P
0 g
s
.651 .757 .928 r
.63112 .49974 m .62124 .50292 L .6237 .50584 L p F P
0 g
s
.651 .757 .928 r
.6237 .50584 m .63357 .50267 L .63112 .49974 L p F P
0 g
s
.651 .757 .928 r
.48046 .49975 m .47085 .50293 L .47357 .50585 L p F P
0 g
s
.651 .757 .928 r
.47357 .50585 m .48316 .50268 L .48046 .49975 L p F P
0 g
s
0 0 0 r
.42754 .67745 m .42921 .67543 L .42805 .67636 L closepath p F P
0 g
s
0 0 0 r
.42805 .67636 m .42754 .67745 L .42459 .68141 L p F P
0 g
s
.754 .238 0 r
.61201 .6648 m .61407 .66742 L .61055 .66507 L p F P
0 g
s
.754 .238 0 r
.61055 .66507 m .60958 .66388 L .61201 .6648 L p F P
0 g
s
.745 .225 0 r
.60739 .66135 m .60958 .66388 L .61201 .6648 L p F P
0 g
s
.934 .882 .759 r
.6429 .72797 m .64408 .73083 L .64062 .73654 L p F P
0 g
s
.65 .757 .927 r
.19144 .49934 m .18236 .5025 L .18556 .50543 L p F P
0 g
s
.65 .757 .927 r
.18556 .50543 m .19463 .50228 L .19144 .49934 L p F P
0 g
s
.476 .66 .942 r
.61101 .7401 m .61962 .74071 L .62149 .7434 L p F P
0 g
s
.44 .652 .949 r
.61962 .74071 m .61101 .7401 L .60852 .73716 L p F P
0 g
s
.651 .758 .928 r
.79415 .49942 m .78397 .50261 L .78616 .50553 L p F P
0 g
s
.651 .758 .928 r
.78616 .50553 m .79633 .50235 L .79415 .49942 L p F P
0 g
s
.815 .336 0 r
.62305 .67619 m .62001 .67372 L .62243 .6777 L p F P
0 g
s
.815 .336 0 r
.62243 .6777 m .6255 .68016 L .62305 .67619 L p F P
0 g
s
.65 .757 .928 r
.34211 .49947 m .33275 .50265 L .3357 .50557 L p F P
0 g
s
.65 .757 .928 r
.3357 .50557 m .34504 .50241 L .34211 .49947 L p F P
0 g
s
.651 .757 .928 r
.64348 .49949 m .63357 .50267 L .63601 .5056 L p F P
0 g
s
.651 .757 .928 r
.63601 .5056 m .6459 .50243 L .64348 .49949 L p F P
0 g
s
.651 .757 .928 r
.49279 .49951 m .48316 .50268 L .48585 .50561 L p F P
0 g
s
.651 .757 .928 r
.48585 .50561 m .49547 .50244 L .49279 .49951 L p F P
0 g
s
.057 .432 .872 r
.60678 .73631 m .60467 .73367 L .59837 .73069 L p F P
0 g
s
.01 .415 .858 r
.59607 .72809 m .59837 .73069 L .60467 .73367 L p F P
0 g
s
.091 .465 .889 r
.59353 .72701 m .59607 .72809 L .59837 .73069 L p F P
0 g
s
.472 .611 .907 r
.40985 .73745 m .41053 .73623 L p .41952 .73973 L F P
0 g
s
.344 .403 .779 r
.41053 .73623 m .40985 .73745 L .40904 .73544 L closepath p F P
0 g
s
.65 .757 .927 r
.20373 .49911 m .19463 .50228 L .19781 .50521 L p F P
0 g
s
.65 .757 .927 r
.19781 .50521 m .2069 .50205 L .20373 .49911 L p F P
0 g
s
.96 .628 .255 r
.63799 .70061 m .64011 .70329 L .64083 .7078 L p F P
0 g
s
.923 .552 .133 r
.64011 .70329 m .63799 .70061 L .63683 .69623 L p F P
0 g
s
.651 .758 .928 r
.80653 .49916 m .79633 .50235 L .79849 .50528 L p F P
0 g
s
.651 .758 .928 r
.79849 .50528 m .80868 .5021 L .80653 .49916 L p F P
0 g
s
0 0 0 r
.43666 .6679 m .43727 .66697 L .44279 .66218 L p F P
0 g
s
0 0 0 r
.43666 .6679 m .43727 .66697 L .43512 .66907 L closepath p F P
0 g
s
.65 .757 .928 r
.35442 .49923 m .34504 .50241 L .34797 .50533 L p F P
0 g
s
.65 .757 .928 r
.34797 .50533 m .35734 .50217 L .35442 .49923 L p F P
0 g
s
.651 .757 .928 r
.65583 .49925 m .6459 .50243 L .64832 .50535 L p F P
0 g
s
.651 .757 .928 r
.64832 .50535 m .65824 .50218 L .65583 .49925 L p F P
0 g
s
.651 .757 .928 r
.50513 .49926 m .49547 .50244 L .49814 .50536 L p F P
0 g
s
.651 .757 .928 r
.49814 .50536 m .50779 .5022 L .50513 .49926 L p F P
0 g
s
.731 .204 0 r
.60006 .65547 m .5959 .65329 L .59929 .65693 L p F P
0 g
s
.731 .204 0 r
.59929 .65693 m .60346 .6591 L .60006 .65547 L p F P
0 g
s
.301 0 0 r
.49535 .63499 m .50053 .6345 L p .4882 .63824 L F P
0 g
s
.312 0 0 r
.50053 .6345 m .49535 .63499 L .50107 .63395 L closepath p F P
0 g
s
0 0 .241 r
.41129 .7032 m .41189 .70246 L .41069 .70744 L p F P
0 g
s
0 0 .241 r
.41069 .70744 m .41067 .70745 L .41129 .7032 L p F P
0 g
s
.743 .972 .928 r
.44305 .73557 m .43345 .74087 L .43626 .74214 L p F P
0 g
s
.743 .972 .928 r
.44566 .73586 m .44305 .73557 L p .43626 .74214 L F P
0 g
s
.743 .972 .928 r
.43626 .74214 m .44541 .73618 L .44566 .73586 L p F P
0 g
s
.648 .885 .983 r
.43231 .7413 m .43345 .74087 L .43626 .74214 L p F P
0 g
s
0 0 0 r
.43512 .66907 m .43666 .6679 L .43498 .67104 L p F P
0 g
s
0 0 0 r
.43498 .67104 m .42921 .67543 L .43512 .66907 L p F P
0 g
s
.341 .403 .781 r
.40746 .73043 m .40839 .72883 L .4127 .73225 L p F P
0 g
s
.341 .403 .781 r
.40904 .73544 m .40746 .73043 L p .4127 .73225 L F P
0 g
s
.845 .39 0 r
.6297 .68535 m .62831 .68268 L .6255 .68016 L p F P
0 g
s
.341 .403 .781 r
.4127 .73225 m .41053 .73623 L .40904 .73544 L p F P
0 g
s
0 0 0 r
.44279 .66218 m .44603 .66013 L p .43666 .6679 L F P
0 g
s
0 0 0 r
.44603 .66013 m .44693 .65888 L .44279 .66218 L closepath p F P
0 g
s
.65 .757 .927 r
.21603 .49888 m .2069 .50205 L .21005 .50498 L p F P
0 g
s
.65 .757 .927 r
.21005 .50498 m .21917 .50183 L .21603 .49888 L p F P
0 g
s
.932 .557 .173 r
.63449 .6936 m .63683 .69623 L .63799 .70061 L p F P
0 g
s
.891 .484 .062 r
.63683 .69623 m .63449 .6936 L .63294 .68935 L p F P
0 g
s
.651 .758 .928 r
.81891 .49891 m .80868 .5021 L .81083 .50502 L p F P
0 g
s
.651 .758 .928 r
.81083 .50502 m .82104 .50184 L .81891 .49891 L p F P
0 g
s
.65 .757 .928 r
.36674 .49899 m .35734 .50217 L .36024 .5051 L p F P
0 g
s
.65 .757 .928 r
.36024 .5051 m .36963 .50193 L .36674 .49899 L p F P
0 g
s
.651 .757 .928 r
.66819 .499 m .65824 .50218 L .66064 .5051 L p F P
0 g
s
.651 .757 .928 r
.66064 .5051 m .67058 .50193 L .66819 .499 L p F P
0 g
s
.651 .757 .928 r
.51747 .49902 m .50779 .5022 L .51044 .50512 L p F P
0 g
s
.651 .757 .928 r
.51044 .50512 m .52011 .50195 L .51747 .49902 L p F P
0 g
s
.901 .492 .105 r
.63294 .68935 m .63039 .68677 L .63194 .69102 L p F P
0 g
s
.901 .492 .105 r
.63194 .69102 m .63449 .6936 L .63294 .68935 L p F P
0 g
s
0 0 0 r
.44603 .66013 m .44693 .65888 L .45352 .65437 L p F P
0 g
s
.578 .046 0 r
.55432 .63463 m .55982 .63757 L .55256 .63627 L p F P
0 g
s
.578 .046 0 r
.55128 .63408 m .55432 .63463 L p .55256 .63627 L F P
0 g
s
.65 .757 .928 r
.22832 .49866 m .21917 .50183 L .22231 .50476 L p F P
0 g
s
.65 .757 .928 r
.22231 .50476 m .23145 .5016 L .22832 .49866 L p F P
0 g
s
.651 .758 .928 r
.83129 .49865 m .82104 .50184 L .82316 .50476 L p F P
0 g
s
.651 .758 .928 r
.82316 .50476 m .8334 .50158 L .83129 .49865 L p F P
0 g
s
.196 0 0 r
.4783 .64087 m .47858 .64059 L .48765 .63838 L closepath p F P
0 g
s
.672 .799 .943 r
.62343 .74352 m .63115 .74073 L .63179 .74375 L p F P
0 g
s
.71 .836 .942 r
.63328 .73989 m .63115 .74073 L .63179 .74375 L p F P
0 g
s
.71 .836 .942 r
.63179 .74375 m .63571 .74196 L .63328 .73989 L p F P
0 g
s
.701 .192 .019 r
.561 .70272 m .56105 .70271 L .5611 .70276 L closepath p F P
0 g
s
.755 .268 .081 r
.55603 .70089 m .561 .70272 L .56105 .70271 L p F P
0 g
s
.65 .757 .928 r
.37906 .49875 m .36963 .50193 L .37252 .50486 L p F P
0 g
s
.65 .757 .928 r
.37252 .50486 m .38193 .50169 L .37906 .49875 L p F P
0 g
s
.651 .757 .928 r
.68055 .49875 m .67058 .50193 L .67296 .50486 L p F P
0 g
s
.651 .757 .928 r
.67296 .50486 m .68292 .50169 L .68055 .49875 L p F P
0 g
s
.651 .757 .928 r
.52981 .49877 m .52011 .50195 L .52274 .50488 L p F P
0 g
s
.651 .757 .928 r
.52274 .50488 m .53243 .50171 L .52981 .49877 L p F P
0 g
s
.665 .142 0 r
.5611 .70276 m .56509 .7063 L .55969 .70452 L p F P
0 g
s
.665 .142 0 r
.561 .70272 m .5611 .70276 L p .55969 .70452 L F P
0 g
s
.512 0 0 r
.58096 .71638 m .57726 .71414 L .5819 .71754 L p F P
0 g
s
.512 0 0 r
.5819 .71754 m .58532 .71986 L .58096 .71638 L p F P
0 g
s
.665 .142 0 r
.55969 .70452 m .55852 .70364 L .561 .70272 L p F P
0 g
s
.753 .266 .078 r
.55852 .70364 m .55603 .70089 L .561 .70272 L closepath p F P
0 g
s
0 0 0 r
.42921 .67543 m .43498 .67104 L p .43146 .67588 L F P
0 g
s
0 0 0 r
.42754 .67745 m .42921 .67543 L p .43146 .67588 L F P
0 g
s
0 0 .082 r
.41887 .68903 m .42085 .68713 L .41775 .69267 L p F P
0 g
s
0 0 .082 r
.41775 .69267 m .41769 .69273 L .41887 .68903 L p F P
0 g
s
.641 .089 0 r
.5796 .64362 m .58238 .64581 L .57713 .64393 L p F P
0 g
s
.641 .089 0 r
.57713 .64393 m .57711 .64392 L .5796 .64362 L p F P
0 g
s
.641 .094 0 r
.57239 .64073 m .57711 .64392 L .5796 .64362 L p F P
0 g
s
.029 0 .464 r
.40787 .71631 m .41046 .71215 L p .41081 .71726 L F P
0 g
s
.029 0 .464 r
.41081 .71726 m .40868 .72072 L .40787 .71631 L p F P
0 g
s
.689 .244 .188 r
.55 .69929 m .54613 .69593 L .54622 .69583 L p F P
0 g
s
.726 .291 .215 r
.54613 .69593 m .54598 .69577 L .54622 .69583 L closepath p F P
0 g
s
.65 .757 .928 r
.24062 .49842 m .23145 .5016 L .23457 .50453 L p F P
0 g
s
.65 .757 .928 r
.23457 .50453 m .24373 .50137 L .24062 .49842 L p F P
0 g
s
.685 .233 .174 r
.54598 .69577 m .53863 .69455 L .54274 .69804 L p F P
0 g
s
.685 .233 .174 r
.54613 .69593 m .54598 .69577 L p .54274 .69804 L F P
0 g
s
.651 .757 .928 r
.69292 .4985 m .68292 .50169 L .68528 .50461 L p F P
0 g
s
.651 .757 .928 r
.68528 .50461 m .69527 .50144 L .69292 .4985 L p F P
0 g
s
.65 .757 .928 r
.39138 .49851 m .38193 .50169 L .3848 .50462 L p F P
0 g
s
.65 .757 .928 r
.3848 .50462 m .39424 .50145 L .39138 .49851 L p F P
0 g
s
.651 .757 .928 r
.54215 .49853 m .53243 .50171 L .53504 .50463 L p F P
0 g
s
.651 .757 .928 r
.53504 .50463 m .54475 .50146 L .54215 .49853 L p F P
0 g
s
0 0 0 r
.43146 .67588 m .4265 .67966 L .42754 .67745 L p F P
0 g
s
0 0 0 r
.4265 .67966 m .42754 .67745 L .42459 .68141 L closepath p F P
0 g
s
.691 .241 .178 r
.54401 .69825 m .54613 .69593 L .55 .69929 L closepath p F P
0 g
s
.685 .233 .174 r
.54274 .69804 m .54401 .69825 L .54613 .69593 L p F P
0 g
s
0 0 .265 r
.41189 .70246 m .41583 .69786 L .41469 .70283 L p F P
0 g
s
0 0 .265 r
.41469 .70283 m .41069 .70744 L .41189 .70246 L p F P
0 g
s
.397 .646 .957 r
.62149 .7434 m .62343 .74352 L .62096 .74086 L p F P
0 g
s
.397 .646 .957 r
.62096 .74086 m .61962 .74071 L .62149 .7434 L p F P
0 g
s
.865 .873 .842 r
.64062 .73654 m .63571 .74196 L .63328 .73989 L p F P
0 g
s
.865 .873 .842 r
.63328 .73989 m .63926 .73371 L .64062 .73654 L p F P
0 g
s
.934 .882 .759 r
.64288 .72796 m .6429 .72797 L p .64062 .73654 L F P
0 g
s
.934 .882 .759 r
.64062 .73654 m .63926 .73371 L .64288 .72796 L p F P
0 g
s
.65 .757 .928 r
.25293 .49819 m .24373 .50137 L .24683 .5043 L p F P
0 g
s
.65 .757 .928 r
.24683 .5043 m .25602 .50113 L .25293 .49819 L p F P
0 g
s
.67 .852 .969 r
.43064 .7391 m .42112 .74174 L .42391 .74457 L p F P
0 g
s
.67 .852 .969 r
.43304 .74061 m .43064 .7391 L p .42391 .74457 L F P
0 g
s
.67 .852 .969 r
.42391 .74457 m .43231 .7413 L .43304 .74061 L p F P
0 g
s
.568 .706 .935 r
.41906 .74179 m .42112 .74174 L .42391 .74457 L p F P
0 g
s
.68 .139 0 r
.58733 .64778 m .58238 .64581 L .58636 .64926 L p F P
0 g
s
.68 .139 0 r
.58636 .64926 m .59137 .65121 L .58733 .64778 L p F P
0 g
s
.651 .758 .928 r
.70529 .49825 m .69527 .50144 L .6976 .50436 L p F P
0 g
s
.651 .758 .928 r
.6976 .50436 m .70761 .50119 L .70529 .49825 L p F P
0 g
s
.994 .816 .558 r
.64415 .72284 m .64288 .72794 L .6429 .72797 L p F P
0 g
s
.988 .817 .583 r
.64243 .72008 m .64415 .72284 L .64288 .72794 L p F P
0 g
s
.997 .771 .46 r
.64415 .72284 m .64243 .72008 L .64291 .71521 L p F P
0 g
s
.65 .757 .928 r
.40371 .49827 m .39424 .50145 L .39708 .50438 L p F P
0 g
s
.65 .757 .928 r
.39708 .50438 m .40654 .50121 L .40371 .49827 L p F P
0 g
s
.651 .757 .928 r
.5545 .49828 m .54475 .50146 L .54734 .50439 L p F P
0 g
s
.651 .757 .928 r
.54734 .50439 m .55708 .50122 L .5545 .49828 L p F P
0 g
s
.578 .046 0 r
.55256 .63627 m .5498 .63488 L .55128 .63408 L p F P
0 g
s
.543 .004 0 r
.5498 .63488 m .54655 .63349 L .55128 .63408 L closepath p F P
0 g
s
.649 .756 .927 r
.11447 .49768 m .10552 .50084 L .10885 .50378 L p F P
0 g
s
.649 .756 .927 r
.10885 .50378 m .11778 .50064 L .11447 .49768 L p F P
0 g
s
.028 .451 .873 r
.59353 .72701 m .59607 .72809 L .59335 .7256 L p F P
0 g
s
.028 .451 .873 r
.59335 .7256 m .59102 .72462 L .59353 .72701 L p F P
0 g
s
0 .452 .86 r
.5902 .72321 m .58917 .72281 L p .59102 .72462 L F P
0 g
s
0 .452 .86 r
.58917 .72281 m .58851 .72255 L .59102 .72462 L p F P
0 g
s
0 .062 .552 r
.59102 .72462 m .59353 .72701 L p .59251 .72607 L F P
0 g
s
0 .062 .552 r
.58835 .72228 m .59102 .72462 L p .59251 .72607 L F P
0 g
s
.709 .172 0 r
.60739 .66135 m .60346 .6591 L .60673 .6628 L p F P
0 g
s
.709 .172 0 r
.60958 .66388 m .60739 .66135 L p .60673 .6628 L F P
0 g
s
.255 0 0 r
.47616 .6434 m .4783 .64087 L .48765 .63838 L p F P
0 g
s
.154 0 0 r
.4783 .64087 m .47616 .6434 L .46685 .6466 L p F P
0 g
s
.694 .151 0 r
.59285 .65184 m .59454 .65202 L .5959 .65329 L closepath p F P
0 g
s
.63 .066 0 r
.59137 .65121 m .59285 .65184 L .59454 .65202 L p F P
0 g
s
.395 0 0 r
.50053 .6345 m .50107 .63395 L .51232 .63266 L p F P
0 g
s
.354 0 0 r
.51285 .63225 m .51232 .63266 L .50107 .63395 L p F P
0 g
s
.019 .404 .855 r
.60678 .73631 m .60852 .73716 L .60603 .73437 L p F P
0 g
s
.019 .404 .855 r
.60603 .73437 m .60467 .73367 L .60678 .73631 L p F P
0 g
s
.65 .757 .928 r
.26524 .49796 m .25602 .50113 L .25909 .50406 L p F P
0 g
s
.65 .757 .928 r
.25909 .50406 m .2683 .5009 L .26524 .49796 L p F P
0 g
s
.588 .025 0 r
.57239 .64073 m .56646 .63905 L .57111 .64227 L p F P
0 g
s
.588 .025 0 r
.57711 .64392 m .57239 .64073 L p .57111 .64227 L F P
0 g
s
.651 .758 .928 r
.71766 .498 m .70761 .50119 L .70993 .50411 L p F P
0 g
s
.651 .758 .928 r
.70993 .50411 m .71997 .50094 L .71766 .498 L p F P
0 g
s
0 0 0 r
.45352 .65437 m .45609 .65302 L p .44603 .66013 L F P
0 g
s
0 0 0 r
.45609 .65302 m .45655 .65245 L .45352 .65437 L closepath p F P
0 g
s
.65 .757 .928 r
.41604 .49803 m .40654 .50121 L .40937 .50414 L p F P
0 g
s
.65 .757 .928 r
.40937 .50414 m .41886 .50096 L .41604 .49803 L p F P
0 g
s
.651 .757 .928 r
.56685 .49803 m .55708 .50122 L .55965 .50415 L p F P
0 g
s
.651 .757 .928 r
.55965 .50415 m .56941 .50097 L .56685 .49803 L p F P
0 g
s
.424 .507 .84 r
.41834 .73817 m .41053 .73623 L .4127 .73225 L p F P
0 g
s
.472 .611 .907 r
.41053 .73623 m .41834 .73817 L .41952 .73973 L p F P
0 g
s
.649 .756 .927 r
.12675 .49748 m .11778 .50064 L .12109 .50358 L p F P
0 g
s
.649 .756 .927 r
.12109 .50358 m .13005 .50043 L .12675 .49748 L p F P
0 g
s
.497 .102 .222 r
.50806 .69524 m .51623 .69434 L p .50671 .6984 L F P
0 g
s
.497 .102 .222 r
.50671 .6984 m .50655 .69838 L .50806 .69524 L p F P
0 g
s
.433 .049 .209 r
.50806 .69524 m .50655 .69838 L .49691 .69979 L p F P
0 g
s
.741 .966 .935 r
.44566 .73586 m .44587 .73588 L .44541 .73618 L closepath p F P
0 g
s
.006 0 0 r
.43666 .6679 m .44421 .66311 L p .43744 .66948 L F P
0 g
s
.006 0 0 r
.43744 .66948 m .43498 .67104 L .43666 .6679 L p F P
0 g
s
0 0 0 r
.44603 .66013 m .44421 .66311 L .43666 .6679 L p F P
0 g
s
.745 .967 .934 r
.44587 .73588 m .45552 .72868 L p .44876 .73188 L F P
0 g
s
.745 .967 .934 r
.44876 .73188 m .44566 .73586 L .44587 .73588 L p F P
0 g
s
.65 .757 .928 r
.27755 .49772 m .2683 .5009 L .27136 .50383 L p F P
0 g
s
.65 .757 .928 r
.27136 .50383 m .2806 .50066 L .27755 .49772 L p F P
0 g
s
.384 0 .111 r
.49635 .70073 m .49691 .69979 L .50655 .69838 L p F P
0 g
s
.651 .758 .928 r
.73004 .49775 m .71997 .50094 L .72226 .50387 L p F P
0 g
s
.651 .758 .928 r
.72226 .50387 m .73232 .50069 L .73004 .49775 L p F P
0 g
s
.651 .757 .928 r
.42838 .49778 m .41886 .50096 L .42166 .50389 L p F P
0 g
s
.651 .757 .928 r
.42166 .50389 m .43117 .50072 L .42838 .49778 L p F P
0 g
s
.651 .757 .928 r
.57921 .49779 m .56941 .50097 L .57196 .5039 L p F P
0 g
s
.651 .757 .928 r
.57196 .5039 m .58175 .50073 L .57921 .49779 L p F P
0 g
s
.399 0 0 r
.51232 .63266 m .51285 .63225 L .51509 .63251 L closepath p F P
0 g
s
.459 0 0 r
.52435 .63214 m .52516 .63159 L .5277 .63219 L closepath p F P
0 g
s
.404 0 0 r
.52516 .63159 m .52435 .63214 L .51509 .63251 L p F P
0 g
s
0 0 .024 r
.42459 .68141 m .4265 .67966 L .42517 .68319 L p F P
0 g
s
0 0 .024 r
.42517 .68319 m .42085 .68713 L .42459 .68141 L p F P
0 g
s
.65 .756 .927 r
.13904 .49727 m .13005 .50043 L .13334 .50337 L p F P
0 g
s
.65 .756 .927 r
.13334 .50337 m .14232 .50022 L .13904 .49727 L p F P
0 g
s
.606 .057 0 r
.56353 .63831 m .5647 .63797 L .56646 .63905 L closepath p F P
0 g
s
.54 0 0 r
.55982 .63757 m .56353 .63831 L .5647 .63797 L p F P
0 g
s
.507 0 0 r
.59102 .72462 m .58835 .72228 L .58532 .71986 L p F P
0 g
s
.514 0 0 r
.54655 .63349 m .53803 .63257 L .54448 .63521 L p F P
0 g
s
.514 0 0 r
.5498 .63488 m .54655 .63349 L p .54448 .63521 L F P
0 g
s
.65 .757 .928 r
.28987 .49748 m .2806 .50066 L .28363 .5036 L p F P
0 g
s
.65 .757 .928 r
.28363 .5036 m .29289 .50043 L .28987 .49748 L p F P
0 g
s
.071 0 0 r
.45609 .65302 m .45655 .65245 L .46616 .64754 L p F P
0 g
s
.082 0 0 r
.46685 .6466 m .46616 .64754 L .45655 .65245 L p F P
0 g
s
.651 .758 .928 r
.74242 .4975 m .73232 .50069 L .7346 .50362 L p F P
0 g
s
.651 .758 .928 r
.7346 .50362 m .74468 .50044 L .74242 .4975 L p F P
0 g
s
.746 .968 .932 r
.44305 .73557 m .44876 .73188 L .44566 .73586 L closepath p F P
0 g
s
.651 .757 .928 r
.44072 .49754 m .43117 .50072 L .43395 .50365 L p F P
0 g
s
.651 .757 .928 r
.43395 .50365 m .44349 .50048 L .44072 .49754 L p F P
0 g
s
.651 .757 .928 r
.59157 .49754 m .58175 .50073 L .58428 .50366 L p F P
0 g
s
.651 .757 .928 r
.58428 .50366 m .59409 .50048 L .59157 .49754 L p F P
0 g
s
.65 .756 .927 r
.15134 .49705 m .14232 .50022 L .14559 .50316 L p F P
0 g
s
.65 .756 .927 r
.14559 .50316 m .1546 .5 L .15134 .49705 L p F P
0 g
s
.652 .803 .955 r
.63115 .74073 m .62343 .74352 L .62096 .74086 L p F P
0 g
s
.806 .316 0 r
.61407 .66742 m .61055 .66507 L .6132 .66897 L p F P
0 g
s
.806 .316 0 r
.6132 .66897 m .61672 .67131 L .61407 .66742 L p F P
0 g
s
.993 .762 .48 r
.641 .71249 m .64291 .71521 L .64243 .72008 L p F P
0 g
s
.984 .701 .352 r
.64291 .71521 m .641 .71249 L .64083 .7078 L p F P
0 g
s
.274 .325 .734 r
.40839 .72883 m .41077 .72477 L p .41396 .72984 L F P
0 g
s
.274 .325 .734 r
.41396 .72984 m .4127 .73225 L .40839 .72883 L p F P
0 g
s
.65 .757 .928 r
.30219 .49725 m .29289 .50043 L .29591 .50336 L p F P
0 g
s
.65 .757 .928 r
.29591 .50336 m .30519 .50019 L .30219 .49725 L p F P
0 g
s
.651 .758 .928 r
.7548 .49724 m .74468 .50044 L .74694 .50337 L p F P
0 g
s
.651 .758 .928 r
.74694 .50337 m .75705 .50018 L .7548 .49724 L p F P
0 g
s
.651 .757 .928 r
.45306 .4973 m .44349 .50048 L .44625 .50341 L p F P
0 g
s
.651 .757 .928 r
.44625 .50341 m .45581 .50024 L .45306 .4973 L p F P
0 g
s
.651 .757 .928 r
.60393 .49729 m .59409 .50048 L .59659 .50341 L p F P
0 g
s
.651 .757 .928 r
.59659 .50341 m .60643 .50024 L .60393 .49729 L p F P
0 g
s
.737 .214 0 r
.56968 .7083 m .56509 .7063 L .56894 .70991 L p F P
0 g
s
.737 .214 0 r
.56894 .70991 m .57313 .71202 L .56968 .7083 L p F P
0 g
s
.543 0 0 r
.57424 .71268 m .57601 .71328 L .57726 .71414 L closepath p F P
0 g
s
.722 .191 0 r
.57313 .71202 m .57424 .71268 L .57601 .71328 L p F P
0 g
s
.65 .756 .927 r
.16364 .49683 m .1546 .5 L .15784 .50294 L p F P
0 g
s
.65 .756 .927 r
.15784 .50294 m .16687 .49978 L .16364 .49683 L p F P
0 g
s
.625 .21 .237 r
.53863 .69455 m .54274 .69804 L .53446 .69708 L p F P
0 g
s
.625 .21 .237 r
.53185 .69398 m .53863 .69455 L p .53446 .69708 L F P
0 g
s
.857 .409 .016 r
.6297 .68535 m .63039 .68677 L .62762 .68423 L p F P
0 g
s
.857 .409 .016 r
.62762 .68423 m .62727 .68353 L .6297 .68535 L p F P
0 g
s
.845 .39 0 r
.6255 .68016 m .62727 .68353 L .6297 .68535 L p F P
0 g
s
.632 .95 .752 r
.45552 .72868 m .45572 .72852 L .45559 .72865 L closepath p F P
0 g
s
.651 .758 .928 r
.76719 .49699 m .75705 .50018 L .75928 .50311 L p F P
0 g
s
.651 .758 .928 r
.75928 .50311 m .76941 .49993 L .76719 .49699 L p F P
0 g
s
.65 .757 .928 r
.31451 .49701 m .30519 .50019 L .30819 .50312 L p F P
0 g
s
.65 .757 .928 r
.30819 .50312 m .31749 .49995 L .31451 .49701 L p F P
0 g
s
.651 .757 .928 r
.6163 .49705 m .60643 .50024 L .60892 .50317 L p F P
0 g
s
.651 .757 .928 r
.60892 .50317 m .61877 .49999 L .6163 .49705 L p F P
0 g
s
.651 .757 .928 r
.4654 .49705 m .45581 .50024 L .45855 .50317 L p F P
0 g
s
.651 .757 .928 r
.45855 .50317 m .46813 .49999 L .4654 .49705 L p F P
0 g
s
.206 0 0 r
.46616 .64754 m .46685 .6466 L .47616 .6434 L p F P
0 g
s
.549 .897 .67 r
.46143 .72353 m .4527 .72938 L .45552 .72868 L p F P
0 g
s
.549 .897 .67 r
.45552 .72868 m .45572 .72852 L .46143 .72353 L p F P
0 g
s
.745 .967 .934 r
.45552 .72868 m .4527 .72938 L .44876 .73188 L p F P
0 g
s
.501 0 0 r
.53724 .6325 m .53747 .63238 L .53803 .63257 L closepath p F P
0 g
s
.463 0 0 r
.53747 .63238 m .53724 .6325 L .5277 .63219 L p F P
0 g
s
.637 .954 .761 r
.46522 .72115 m .46518 .72118 L .45572 .72852 L p F P
0 g
s
.423 .827 .624 r
.46518 .72118 m .45572 .72852 L .46143 .72353 L p F P
0 g
s
.377 0 0 r
.49877 .63624 m .50053 .6345 L .51018 .63466 L p F P
0 g
s
.395 0 0 r
.51232 .63266 m .51018 .63466 L .50053 .6345 L p F P
0 g
s
.301 0 0 r
.50053 .6345 m .49877 .63624 L .4882 .63824 L p F P
0 g
s
.497 .102 .222 r
.51623 .69434 m .51889 .69492 L p .50671 .6984 L F P
0 g
s
.528 .132 .235 r
.51889 .69492 m .51623 .69434 L .51933 .69399 L closepath p F P
0 g
s
.65 .757 .927 r
.17594 .49661 m .16687 .49978 L .1701 .50272 L p F P
0 g
s
.65 .757 .927 r
.1701 .50272 m .17916 .49956 L .17594 .49661 L p F P
0 g
s
.071 0 0 r
.44603 .66013 m .45418 .65587 L p .44543 .66248 L F P
0 g
s
.071 0 0 r
.44543 .66248 m .44421 .66311 L .44603 .66013 L p F P
0 g
s
0 0 0 r
.45609 .65302 m .45418 .65587 L .44603 .66013 L p F P
0 g
s
.738 .221 0 r
.5959 .65329 m .59929 .65693 L .59485 .65482 L p F P
0 g
s
.738 .221 0 r
.59285 .65184 m .5959 .65329 L p .59485 .65482 L F P
0 g
s
.651 .758 .928 r
.77958 .49673 m .76941 .49993 L .77163 .50286 L p F P
0 g
s
.651 .758 .928 r
.77163 .50286 m .78178 .49968 L .77958 .49673 L p F P
0 g
s
.44 .652 .949 r
.60852 .73716 m .61755 .73807 L .61962 .74071 L p F P
0 g
s
.405 .647 .956 r
.61755 .73807 m .60852 .73716 L .60603 .73437 L p F P
0 g
s
.65 .757 .928 r
.32684 .49677 m .31749 .49995 L .32047 .50289 L p F P
0 g
s
.65 .757 .928 r
.32047 .50289 m .3298 .49971 L .32684 .49677 L p F P
0 g
s
.651 .757 .928 r
.62867 .4968 m .61877 .49999 L .62124 .50292 L p F P
0 g
s
.651 .757 .928 r
.62124 .50292 m .63112 .49974 L .62867 .4968 L p F P
0 g
s
.651 .757 .928 r
.47775 .49681 m .46813 .49999 L .47085 .50293 L p F P
0 g
s
.651 .757 .928 r
.47085 .50293 m .48046 .49975 L .47775 .49681 L p F P
0 g
s
.827 .352 .004 r
.62001 .67372 m .61672 .67131 L .61913 .6753 L p F P
0 g
s
.827 .352 .004 r
.61913 .6753 m .62243 .6777 L .62001 .67372 L p F P
0 g
s
.982 .696 .378 r
.63871 .70513 m .64083 .7078 L .641 .71249 L p F P
0 g
s
.96 .628 .255 r
.64083 .7078 m .63871 .70513 L .63799 .70061 L p F P
0 g
s
.426 0 0 r
.51232 .63266 m .51509 .63251 L p .51113 .63477 L F P
0 g
s
.426 0 0 r
.51113 .63477 m .51018 .63466 L .51232 .63266 L p F P
0 g
s
.65 .757 .927 r
.18824 .49639 m .17916 .49956 L .18236 .5025 L p F P
0 g
s
.65 .757 .927 r
.18236 .5025 m .19144 .49934 L .18824 .49639 L p F P
0 g
s
.712 .21 .044 r
.55603 .70089 m .55 .69929 L .55393 .70284 L p F P
0 g
s
.712 .21 .044 r
.55852 .70364 m .55603 .70089 L p .55393 .70284 L F P
0 g
s
.525 .005 0 r
.53803 .63257 m .54448 .63521 L .53548 .63443 L p F P
0 g
s
.525 .005 0 r
.53724 .6325 m .53803 .63257 L p .53548 .63443 L F P
0 g
s
.651 .758 .928 r
.79197 .49648 m .78178 .49968 L .78397 .50261 L p F P
0 g
s
.651 .758 .928 r
.78397 .50261 m .79415 .49942 L .79197 .49648 L p F P
0 g
s
.65 .757 .928 r
.33917 .49653 m .3298 .49971 L .33275 .50265 L p F P
0 g
s
.65 .757 .928 r
.33275 .50265 m .34211 .49947 L .33917 .49653 L p F P
0 g
s
.651 .757 .928 r
.64104 .49655 m .63112 .49974 L .63357 .50267 L p F P
0 g
s
.651 .757 .928 r
.63357 .50267 m .64348 .49949 L .64104 .49655 L p F P
0 g
s
.142 0 0 r
.45609 .65302 m .46483 .6493 L p .45924 .65371 L F P
0 g
s
.142 0 0 r
.45924 .65371 m .45418 .65587 L .45609 .65302 L p F P
0 g
s
.071 0 0 r
.46616 .64754 m .46483 .6493 L .45609 .65302 L p F P
0 g
s
.651 .757 .928 r
.4901 .49656 m .48046 .49975 L .48316 .50268 L p F P
0 g
s
.651 .757 .928 r
.48316 .50268 m .49279 .49951 L .4901 .49656 L p F P
0 g
s
.574 .179 .256 r
.51933 .69399 m .52926 .69392 L p .52367 .69684 L F P
0 g
s
.574 .179 .256 r
.52367 .69684 m .51889 .69492 L .51933 .69399 L p F P
0 g
s
.426 0 0 r
.51509 .63251 m .52252 .63369 L p .51113 .63477 L F P
0 g
s
.437 0 0 r
.52252 .63369 m .51509 .63251 L .52435 .63214 L closepath p F P
0 g
s
.525 .005 0 r
.53548 .63443 m .53487 .63421 L .53724 .6325 L p F P
0 g
s
.487 0 0 r
.53487 .63421 m .5277 .63219 L .53724 .6325 L closepath p F P
0 g
s
.625 .21 .237 r
.53446 .69708 m .53122 .69507 L .53185 .69398 L p F P
0 g
s
.619 .204 .233 r
.53122 .69507 m .52926 .69392 L .53185 .69398 L closepath p F P
0 g
s
.513 .652 .921 r
.42112 .74174 m .41906 .74179 L .41952 .73973 L closepath p F P
0 g
s
0 0 .142 r
.42085 .68713 m .41775 .69267 L .4234 .68753 L p F P
0 g
s
0 0 .142 r
.42517 .68319 m .42085 .68713 L p .4234 .68753 L F P
0 g
s
.01 .415 .858 r
.60467 .73367 m .60229 .73109 L .59607 .72809 L p F P
0 g
s
0 .404 .845 r
.59607 .72809 m .59335 .7256 L .59966 .72857 L p F P
0 g
s
0 .404 .845 r
.59966 .72857 m .60229 .73109 L .59607 .72809 L p F P
0 g
s
.574 .179 .256 r
.52926 .69392 m .53122 .69507 L p .52367 .69684 L F P
0 g
s
.388 0 .118 r
.49458 .70374 m .49635 .70073 L .50653 .69842 L p F P
0 g
s
.384 0 .111 r
.50655 .69838 m .50653 .69842 L .49635 .70073 L p F P
0 g
s
.218 0 .004 r
.49635 .70073 m .49458 .70374 L .48537 .70696 L p F P
0 g
s
.65 .757 .927 r
.20055 .49616 m .19144 .49934 L .19463 .50228 L p F P
0 g
s
.65 .757 .927 r
.19463 .50228 m .20373 .49911 L .20055 .49616 L p F P
0 g
s
.651 .758 .928 r
.80437 .49622 m .79415 .49942 L .79633 .50235 L p F P
0 g
s
.651 .758 .928 r
.79633 .50235 m .80653 .49916 L .80437 .49622 L p F P
0 g
s
.829 .357 0 r
.6255 .68016 m .62243 .6777 L .6246 .68177 L p F P
0 g
s
.829 .357 0 r
.62727 .68353 m .6255 .68016 L p .6246 .68177 L F P
0 g
s
0 0 0 r
.46518 .72118 m .46534 .72107 L .46522 .72115 L closepath p F P
0 g
s
.65 .757 .928 r
.3515 .49629 m .34211 .49947 L .34504 .50241 L p F P
0 g
s
.65 .757 .928 r
.34504 .50241 m .35442 .49923 L .3515 .49629 L p F P
0 g
s
.977 .853 .65 r
.64288 .72796 m .64288 .72794 L .6429 .72797 L closepath p F P
0 g
s
.651 .757 .928 r
.65342 .4963 m .64348 .49949 L .6459 .50243 L p F P
0 g
s
.651 .757 .928 r
.6459 .50243 m .65583 .49925 L .65342 .4963 L p F P
0 g
s
.651 .757 .928 r
.50246 .49632 m .49279 .49951 L .49547 .50244 L p F P
0 g
s
.651 .757 .928 r
.49547 .50244 m .50513 .49926 L .50246 .49632 L p F P
0 g
s
.043 0 .376 r
.41062 .70882 m .41069 .70744 L .41067 .70745 L closepath p F P
0 g
s
0 0 .338 r
.41046 .71215 m .41062 .70882 L .41067 .70745 L p F P
0 g
s
.967 .841 .666 r
.64288 .72794 m .64288 .72796 L .64049 .7268 L p F P
0 g
s
.967 .841 .666 r
.64049 .7268 m .64113 .7252 L .64288 .72794 L p F P
0 g
s
.988 .817 .583 r
.64288 .72794 m .64113 .7252 L .64243 .72008 L p F P
0 g
s
.961 .626 .287 r
.63566 .69798 m .63799 .70061 L .63871 .70513 L p F P
0 g
s
.932 .557 .173 r
.63799 .70061 m .63566 .69798 L .63449 .6936 L p F P
0 g
s
.077 0 .389 r
.41069 .70744 m .41469 .70283 L .41448 .70755 L p F P
0 g
s
.077 0 .389 r
.41062 .70882 m .41069 .70744 L p .41448 .70755 L F P
0 g
s
.935 .886 .759 r
.63926 .73371 m .64288 .72796 L .64049 .7268 L p F P
0 g
s
0 0 0 r
.47258 .71625 m .47205 .71677 L p .46518 .72118 L F P
0 g
s
0 0 0 r
.47258 .71625 m .47485 .71413 L .46534 .72107 L closepath p F P
0 g
s
0 0 0 r
.47507 .71384 m .47485 .71413 L .46534 .72107 L p F P
0 g
s
0 0 0 r
.47205 .71677 m .46237 .72291 L .46518 .72118 L p F P
0 g
s
0 0 0 r
.46518 .72118 m .46534 .72107 L .47258 .71625 L p F P
0 g
s
.423 .827 .624 r
.46143 .72353 m .46237 .72291 L .46518 .72118 L p F P
0 g
s
.635 .11 0 r
.56646 .63905 m .57111 .64227 L .56482 .64068 L p F P
0 g
s
.635 .11 0 r
.56353 .63831 m .56646 .63905 L p .56482 .64068 L F P
0 g
s
.483 0 0 r
.5277 .63219 m .53487 .63421 L p .5246 .63421 L F P
0 g
s
.483 0 0 r
.52435 .63214 m .5277 .63219 L p .5246 .63421 L F P
0 g
s
.65 .757 .927 r
.21287 .49593 m .20373 .49911 L .2069 .50205 L p F P
0 g
s
.65 .757 .927 r
.2069 .50205 m .21603 .49888 L .21287 .49593 L p F P
0 g
s
.692 .164 0 r
.58238 .64581 m .57713 .64393 L .58109 .64738 L p F P
0 g
s
.692 .164 0 r
.58109 .64738 m .58636 .64926 L .58238 .64581 L p F P
0 g
s
.508 0 0 r
.57726 .71414 m .5819 .71754 L .57802 .71535 L p F P
0 g
s
.508 0 0 r
.57424 .71268 m .57726 .71414 L p .57802 .71535 L F P
0 g
s
.483 0 0 r
.5246 .63421 m .52252 .63369 L .52435 .63214 L p F P
0 g
s
.651 .758 .928 r
.81677 .49596 m .80653 .49916 L .80868 .5021 L p F P
0 g
s
.651 .758 .928 r
.80868 .5021 m .81891 .49891 L .81677 .49596 L p F P
0 g
s
.935 .559 .209 r
.63449 .6936 m .63194 .69102 L .63311 .69541 L p F P
0 g
s
.935 .559 .209 r
.63311 .69541 m .63566 .69798 L .63449 .6936 L p F P
0 g
s
.907 .497 .144 r
.63039 .68677 m .62762 .68423 L .62917 .68849 L p F P
0 g
s
.907 .497 .144 r
.62917 .68849 m .63194 .69102 L .63039 .68677 L p F P
0 g
s
.65 .757 .928 r
.36384 .49605 m .35442 .49923 L .35734 .50217 L p F P
0 g
s
.65 .757 .928 r
.35734 .50217 m .36674 .49899 L .36384 .49605 L p F P
0 g
s
.651 .757 .928 r
.6658 .49605 m .65583 .49925 L .65824 .50218 L p F P
0 g
s
.651 .757 .928 r
.65824 .50218 m .66819 .499 L .6658 .49605 L p F P
0 g
s
.651 .757 .928 r
.51482 .49607 m .50513 .49926 L .50779 .5022 L p F P
0 g
s
.651 .757 .928 r
.50779 .5022 m .51747 .49902 L .51482 .49607 L p F P
0 g
s
.668 .847 .968 r
.43304 .74061 m .43345 .74087 L .43231 .7413 L closepath p F P
0 g
s
.65 .757 .927 r
.22519 .4957 m .21603 .49888 L .21917 .50183 L p F P
0 g
s
.65 .757 .927 r
.21917 .50183 m .22832 .49866 L .22519 .4957 L p F P
0 g
s
.651 .758 .927 r
.82917 .4957 m .81891 .49891 L .82104 .50184 L p F P
0 g
s
.651 .758 .927 r
.82104 .50184 m .83129 .49865 L .82917 .4957 L p F P
0 g
s
.763 .25 0 r
.6078 .66341 m .60958 .66388 L .61055 .66507 L closepath p F P
0 g
s
.709 .172 0 r
.60673 .6628 m .6078 .66341 L .60958 .66388 L p F P
0 g
s
.153 .144 .594 r
.40868 .72072 m .41081 .71726 L .41183 .72304 L p F P
0 g
s
.153 .144 .594 r
.41183 .72304 m .41077 .72477 L .40868 .72072 L p F P
0 g
s
.65 .757 .928 r
.37618 .4958 m .36674 .49899 L .36963 .50193 L p F P
0 g
s
.65 .757 .928 r
.36963 .50193 m .37906 .49875 L .37618 .4958 L p F P
0 g
s
.651 .757 .928 r
.67818 .4958 m .66819 .499 L .67058 .50193 L p F P
0 g
s
.651 .757 .928 r
.67058 .50193 m .68055 .49875 L .67818 .4958 L p F P
0 g
s
.651 .757 .928 r
.52718 .49583 m .51747 .49902 L .52011 .50195 L p F P
0 g
s
.651 .757 .928 r
.52011 .50195 m .52981 .49877 L .52718 .49583 L p F P
0 g
s
.017 0 0 r
.47485 .71413 m .47645 .71317 L .47507 .71384 L closepath p F P
0 g
s
.006 0 .078 r
.4265 .67966 m .43146 .67588 L .42691 .68186 L p F P
0 g
s
.006 0 .078 r
.42691 .68186 m .42517 .68319 L .4265 .67966 L p F P
0 g
s
.24 0 .024 r
.48451 .70833 m .48537 .70696 L .49458 .70374 L p F P
0 g
s
.011 0 0 r
.48537 .70696 m .48451 .70833 L .47645 .71317 L p F P
0 g
s
.752 .236 0 r
.60346 .6591 m .59929 .65693 L .6025 .66064 L p F P
0 g
s
.752 .236 0 r
.6025 .66064 m .60673 .6628 L .60346 .6591 L p F P
0 g
s
.65 .757 .928 r
.23751 .49547 m .22832 .49866 L .23145 .5016 L p F P
0 g
s
.65 .757 .928 r
.23145 .5016 m .24062 .49842 L .23751 .49547 L p F P
0 g
s
.703 .854 .955 r
.43345 .74087 m .44305 .73557 L p .43454 .73733 L F P
0 g
s
.703 .854 .955 r
.43454 .73733 m .43304 .74061 L .43345 .74087 L p F P
0 g
s
.651 .757 .928 r
.69057 .49555 m .68055 .49875 L .68292 .50169 L p F P
0 g
s
.651 .757 .928 r
.68292 .50169 m .69292 .4985 L .69057 .49555 L p F P
0 g
s
.65 .757 .928 r
.38852 .49556 m .37906 .49875 L .38193 .50169 L p F P
0 g
s
.65 .757 .928 r
.38193 .50169 m .39138 .49851 L .38852 .49556 L p F P
0 g
s
.651 .757 .928 r
.53955 .49558 m .52981 .49877 L .53243 .50171 L p F P
0 g
s
.651 .757 .928 r
.53243 .50171 m .54215 .49853 L .53955 .49558 L p F P
0 g
s
.077 0 .389 r
.41448 .70755 m .41048 .71211 L .41062 .70882 L p F P
0 g
s
0 0 .341 r
.41048 .71211 m .41062 .70882 L .41046 .71215 L closepath p F P
0 g
s
.58 .682 .91 r
.42784 .73676 m .43064 .7391 L .42112 .74174 L p F P
0 g
s
.58 .682 .91 r
.42129 .7378 m .42784 .73676 L p .42112 .74174 L F P
0 g
s
.58 .682 .91 r
.42112 .74174 m .41952 .73973 L .42129 .7378 L p F P
0 g
s
.255 0 0 r
.48765 .63838 m .48818 .63826 L p .47616 .6434 L F P
0 g
s
.267 0 0 r
.48818 .63826 m .48765 .63838 L .4882 .63824 L closepath p F P
0 g
s
.196 0 0 r
.46483 .6493 m .46616 .64754 L .47578 .64392 L p F P
0 g
s
.206 0 0 r
.47616 .6434 m .47578 .64392 L .46616 .64754 L p F P
0 g
s
.635 .11 0 r
.56482 .64068 m .56218 .63895 L .56353 .63831 L p F P
0 g
s
.607 .074 0 r
.56218 .63895 m .55982 .63757 L .56353 .63831 L closepath p F P
0 g
s
.65 .757 .928 r
.24983 .49524 m .24062 .49842 L .24373 .50137 L p F P
0 g
s
.65 .757 .928 r
.24373 .50137 m .25293 .49819 L .24983 .49524 L p F P
0 g
s
.651 .757 .928 r
.70296 .4953 m .69292 .4985 L .69527 .50144 L p F P
0 g
s
.651 .757 .928 r
.69527 .50144 m .70529 .49825 L .70296 .4953 L p F P
0 g
s
.573 .151 .203 r
.51764 .697 m .51889 .69492 L .52367 .69684 L closepath p F P
0 g
s
.497 .102 .222 r
.51889 .69492 m .51764 .697 L .50671 .6984 L p F P
0 g
s
.65 .757 .928 r
.40087 .49532 m .39138 .49851 L .39424 .50145 L p F P
0 g
s
.65 .757 .928 r
.39424 .50145 m .40371 .49827 L .40087 .49532 L p F P
0 g
s
.355 0 0 r
.48818 .63826 m .4882 .63824 L .49877 .63624 L p F P
0 g
s
.651 .757 .928 r
.55191 .49533 m .54215 .49853 L .54475 .50146 L p F P
0 g
s
.651 .757 .928 r
.54475 .50146 m .5545 .49828 L .55191 .49533 L p F P
0 g
s
0 0 0 r
.47485 .71413 m .47645 .71317 L p .4762 .71456 L F P
0 g
s
0 0 0 r
.4762 .71456 m .47258 .71625 L .47485 .71413 L p F P
0 g
s
.346 0 0 r
.48609 .64077 m .48818 .63826 L .49781 .63737 L p F P
0 g
s
.355 0 0 r
.49877 .63624 m .49781 .63737 L .48818 .63826 L p F P
0 g
s
.255 0 0 r
.48818 .63826 m .48609 .64077 L .47616 .6434 L p F P
0 g
s
.577 .044 0 r
.54841 .63562 m .5498 .63488 L .55256 .63627 L closepath p F P
0 g
s
.514 0 0 r
.54448 .63521 m .54841 .63562 L .5498 .63488 L p F P
0 g
s
.652 .803 .955 r
.63135 .73813 m .63115 .74073 L p .62096 .74086 L F P
0 g
s
.683 .815 .946 r
.63115 .74073 m .63135 .73813 L .63328 .73989 L closepath p F P
0 g
s
.738 .221 0 r
.59485 .65482 m .59208 .6519 L .59285 .65184 L p F P
0 g
s
.716 .189 0 r
.59208 .6519 m .59137 .65121 L .59285 .65184 L closepath p F P
0 g
s
.364 .633 .957 r
.61962 .74071 m .62096 .74086 L .61849 .7382 L p F P
0 g
s
.364 .633 .957 r
.61849 .7382 m .61755 .73807 L .61962 .74071 L p F P
0 g
s
0 .452 .86 r
.59102 .72462 m .59335 .7256 L .5902 .72321 L p F P
0 g
s
.507 0 0 r
.58532 .71986 m .58851 .72255 L p .59011 .72386 L F P
0 g
s
0 .464 .849 r
.58851 .72255 m .5902 .72321 L .58665 .72102 L p F P
0 g
s
.546 0 0 r
.58851 .72255 m .58532 .71986 L .5819 .71754 L p F P
0 g
s
0 .464 .849 r
.58665 .72102 m .58655 .72096 L p .58851 .72255 L F P
0 g
s
.507 0 0 r
.58851 .72255 m .59102 .72462 L p .59011 .72386 L F P
0 g
s
.703 .855 .955 r
.43064 .7391 m .43454 .73733 L .43304 .74061 L closepath p F P
0 g
s
.65 .757 .928 r
.26216 .495 m .25293 .49819 L .25602 .50113 L p F P
0 g
s
.65 .757 .928 r
.25602 .50113 m .26524 .49796 L .26216 .495 L p F P
0 g
s
.98 .804 .593 r
.64051 .71737 m .64243 .72008 L .64113 .7252 L p F P
0 g
s
.993 .762 .48 r
.64243 .72008 m .64051 .71737 L .641 .71249 L p F P
0 g
s
.01 0 .215 r
.41765 .69292 m .41775 .69267 L .41769 .69273 L closepath p F P
0 g
s
0 0 .179 r
.41583 .69786 m .41765 .69292 L .41769 .69273 L p F P
0 g
s
.651 .758 .928 r
.71535 .49505 m .70529 .49825 L .70761 .50119 L p F P
0 g
s
.651 .758 .928 r
.70761 .50119 m .71766 .498 L .71535 .49505 L p F P
0 g
s
.65 .757 .928 r
.41322 .49508 m .40371 .49827 L .40654 .50121 L p F P
0 g
s
.65 .757 .928 r
.40654 .50121 m .41604 .49803 L .41322 .49508 L p F P
0 g
s
.651 .757 .928 r
.56429 .49509 m .5545 .49828 L .55708 .50122 L p F P
0 g
s
.651 .757 .928 r
.55708 .50122 m .56685 .49803 L .56429 .49509 L p F P
0 g
s
.853 .838 .83 r
.63926 .73371 m .6377 .73092 L p .63135 .73813 L F P
0 g
s
.853 .838 .83 r
.63135 .73813 m .63328 .73989 L .63926 .73371 L p F P
0 g
s
.935 .886 .759 r
.64049 .7268 m .6377 .73092 L .63926 .73371 L p F P
0 g
s
.04 0 .228 r
.41775 .69267 m .4234 .68753 L .42116 .69283 L p F P
0 g
s
.04 0 .228 r
.41765 .69292 m .41775 .69267 L p .42116 .69283 L F P
0 g
s
0 0 0 r
.47645 .71317 m .48331 .70972 L p .4762 .71456 L F P
0 g
s
0 0 0 r
.48331 .70972 m .48451 .70833 L .47645 .71317 L closepath p F P
0 g
s
.649 .756 .927 r
.12344 .49451 m .11447 .49768 L .11778 .50064 L p F P
0 g
s
.649 .756 .927 r
.11778 .50064 m .12675 .49748 L .12344 .49451 L p F P
0 g
s
0 .386 .839 r
.60467 .73367 m .60603 .73437 L .60353 .73173 L p F P
0 g
s
0 .386 .839 r
.60353 .73173 m .60229 .73109 L .60467 .73367 L p F P
0 g
s
.711 .184 0 r
.56509 .7063 m .55969 .70452 L .56411 .70796 L p F P
0 g
s
.711 .184 0 r
.56411 .70796 m .56894 .70991 L .56509 .7063 L p F P
0 g
s
.04 0 .228 r
.42116 .69283 m .41684 .69675 L .41765 .69292 L p F P
0 g
s
0 0 .178 r
.41684 .69675 m .41765 .69292 L .41583 .69786 L closepath p F P
0 g
s
.628 .194 .198 r
.53001 .69681 m .53122 .69507 L .53446 .69708 L closepath p F P
0 g
s
.574 .179 .256 r
.53122 .69507 m .53001 .69681 L .52367 .69684 L p F P
0 g
s
.65 .757 .928 r
.27449 .49477 m .26524 .49796 L .2683 .5009 L p F P
0 g
s
.65 .757 .928 r
.2683 .5009 m .27755 .49772 L .27449 .49477 L p F P
0 g
s
.651 .758 .928 r
.72775 .4948 m .71766 .498 L .71997 .50094 L p F P
0 g
s
.651 .758 .928 r
.71997 .50094 m .73004 .49775 L .72775 .4948 L p F P
0 g
s
.651 .757 .928 r
.42558 .49483 m .41604 .49803 L .41886 .50096 L p F P
0 g
s
.651 .757 .928 r
.41886 .50096 m .42838 .49778 L .42558 .49483 L p F P
0 g
s
.651 .757 .928 r
.57666 .49484 m .56685 .49803 L .56941 .50097 L p F P
0 g
s
.651 .757 .928 r
.56941 .50097 m .57921 .49779 L .57666 .49484 L p F P
0 g
s
.652 .193 .15 r
.55 .69929 m .55393 .70284 L .54739 .70138 L p F P
0 g
s
.652 .193 .15 r
.54401 .69825 m .55 .69929 L p .54739 .70138 L F P
0 g
s
.81 .326 .037 r
.61055 .66507 m .6132 .66897 L .60943 .66668 L p F P
0 g
s
.81 .326 .037 r
.6078 .66341 m .61055 .66507 L p .60943 .66668 L F P
0 g
s
.65 .756 .927 r
.13575 .4943 m .12675 .49748 L .13005 .50043 L p F P
0 g
s
.65 .756 .927 r
.13005 .50043 m .13904 .49727 L .13575 .4943 L p F P
0 g
s
.65 .757 .928 r
.28683 .49453 m .27755 .49772 L .2806 .50066 L p F P
0 g
s
.65 .757 .928 r
.2806 .50066 m .28987 .49748 L .28683 .49453 L p F P
0 g
s
.651 .758 .928 r
.74015 .49455 m .73004 .49775 L .73232 .50069 L p F P
0 g
s
.651 .758 .928 r
.73232 .50069 m .74242 .4975 L .74015 .49455 L p F P
0 g
s
.579 .04 0 r
.55982 .63757 m .55256 .63627 L .55793 .63927 L p F P
0 g
s
.579 .04 0 r
.56218 .63895 m .55982 .63757 L p .55793 .63927 L F P
0 g
s
.651 .757 .928 r
.43794 .49459 m .42838 .49778 L .43117 .50072 L p F P
0 g
s
.651 .757 .928 r
.43117 .50072 m .44072 .49754 L .43794 .49459 L p F P
0 g
s
.651 .757 .928 r
.58904 .49459 m .57921 .49779 L .58175 .50073 L p F P
0 g
s
.651 .757 .928 r
.58175 .50073 m .59157 .49754 L .58904 .49459 L p F P
0 g
s
.721 .204 0 r
.59208 .6519 m .59137 .65121 L .58636 .64926 L p F P
0 g
s
.652 .803 .955 r
.62096 .74086 m .63084 .73766 L .63135 .73813 L p F P
0 g
s
.639 .79 .955 r
.63084 .73766 m .62096 .74086 L .61849 .7382 L p F P
0 g
s
.65 .756 .927 r
.14807 .49409 m .13904 .49727 L .14232 .50022 L p F P
0 g
s
.65 .756 .927 r
.14232 .50022 m .15134 .49705 L .14807 .49409 L p F P
0 g
s
.508 0 0 r
.57802 .71535 m .5735 .71242 L .57424 .71268 L p F P
0 g
s
.716 .183 0 r
.5735 .71242 m .57313 .71202 L .57424 .71268 L closepath p F P
0 g
s
.65 .757 .928 r
.29917 .49429 m .28987 .49748 L .29289 .50043 L p F P
0 g
s
.65 .757 .928 r
.29289 .50043 m .30219 .49725 L .29917 .49429 L p F P
0 g
s
.651 .758 .928 r
.75255 .49429 m .74242 .4975 L .74468 .50044 L p F P
0 g
s
.651 .758 .928 r
.74468 .50044 m .7548 .49724 L .75255 .49429 L p F P
0 g
s
.651 .757 .928 r
.4503 .49434 m .44072 .49754 L .44349 .50048 L p F P
0 g
s
.651 .757 .928 r
.44349 .50048 m .45306 .4973 L .4503 .49434 L p F P
0 g
s
.651 .757 .928 r
.60143 .49434 m .59157 .49754 L .59409 .50048 L p F P
0 g
s
.651 .757 .928 r
.59409 .50048 m .60393 .49729 L .60143 .49434 L p F P
0 g
s
.986 .751 .496 r
.63888 .70982 m .641 .71249 L .64051 .71737 L p F P
0 g
s
.982 .696 .378 r
.641 .71249 m .63888 .70982 L .63871 .70513 L p F P
0 g
s
.65 .756 .927 r
.16039 .49387 m .15134 .49705 L .1546 .5 L p F P
0 g
s
.65 .756 .927 r
.1546 .5 m .16364 .49683 L .16039 .49387 L p F P
0 g
s
.651 .758 .928 r
.76496 .49404 m .7548 .49724 L .75705 .50018 L p F P
0 g
s
.651 .758 .928 r
.75705 .50018 m .76719 .49699 L .76496 .49404 L p F P
0 g
s
.65 .757 .928 r
.31151 .49405 m .30219 .49725 L .30519 .50019 L p F P
0 g
s
.65 .757 .928 r
.30519 .50019 m .31451 .49701 L .31151 .49405 L p F P
0 g
s
.57 .665 .902 r
.42129 .7378 m .41952 .73973 L .41834 .73817 L closepath p F P
0 g
s
.651 .757 .928 r
.61381 .4941 m .60393 .49729 L .60643 .50024 L p F P
0 g
s
.651 .757 .928 r
.60643 .50024 m .6163 .49705 L .61381 .4941 L p F P
0 g
s
.651 .757 .928 r
.46266 .4941 m .45306 .4973 L .45581 .50024 L p F P
0 g
s
.651 .757 .928 r
.45581 .50024 m .4654 .49705 L .46266 .4941 L p F P
0 g
s
.834 .364 .052 r
.61672 .67131 m .6132 .66897 L .61559 .67296 L p F P
0 g
s
.834 .364 .052 r
.61559 .67296 m .61913 .6753 L .61672 .67131 L p F P
0 g
s
.646 .099 0 r
.5771 .64392 m .57711 .64392 L .57713 .64393 L closepath p F P
0 g
s
.588 .025 0 r
.57111 .64227 m .5771 .64392 L .57711 .64392 L p F P
0 g
s
.677 .156 0 r
.57713 .64393 m .58109 .64738 L .57554 .64558 L p F P
0 g
s
.677 .156 0 r
.5771 .64392 m .57713 .64393 L p .57554 .64558 L F P
0 g
s
.677 .156 0 r
.57554 .64558 m .57462 .64484 L .5771 .64392 L p F P
0 g
s
.656 .127 0 r
.57462 .64484 m .57111 .64227 L .5771 .64392 L closepath p F P
0 g
s
.405 .647 .956 r
.60603 .73437 m .61531 .73546 L .61755 .73807 L p F P
0 g
s
.374 .646 .962 r
.61531 .73546 m .60603 .73437 L .60353 .73173 L p F P
0 g
s
.667 .149 0 r
.55767 .704 m .55852 .70364 L .55969 .70452 L closepath p F P
0 g
s
.712 .21 .044 r
.55393 .70284 m .55767 .704 L .55852 .70364 L p F P
0 g
s
.65 .757 .927 r
.17271 .49365 m .16364 .49683 L .16687 .49978 L p F P
0 g
s
.65 .757 .927 r
.16687 .49978 m .17594 .49661 L .17271 .49365 L p F P
0 g
s
.651 .758 .928 r
.77737 .49378 m .76719 .49699 L .76941 .49993 L p F P
0 g
s
.651 .758 .928 r
.76941 .49993 m .77958 .49673 L .77737 .49378 L p F P
0 g
s
.65 .757 .928 r
.32386 .49381 m .31451 .49701 L .31749 .49995 L p F P
0 g
s
.65 .757 .928 r
.31749 .49995 m .32684 .49677 L .32386 .49381 L p F P
0 g
s
.477 .046 .14 r
.50653 .69842 m .50655 .69838 L .50671 .6984 L closepath p F P
0 g
s
.651 .757 .928 r
.6262 .49385 m .6163 .49705 L .61877 .49999 L p F P
0 g
s
.651 .757 .928 r
.61877 .49999 m .62867 .4968 L .6262 .49385 L p F P
0 g
s
.651 .757 .928 r
.47503 .49385 m .4654 .49705 L .46813 .49999 L p F P
0 g
s
.651 .757 .928 r
.46813 .49999 m .47775 .49681 L .47503 .49385 L p F P
0 g
s
.055 0 .455 r
.41049 .7124 m .41046 .71215 L .41048 .71211 L closepath p F P
0 g
s
.029 0 .464 r
.41046 .71215 m .41049 .7124 L .41081 .71726 L p F P
0 g
s
.723 .203 0 r
.59208 .6519 m .59485 .65482 L .59016 .65278 L p F P
0 g
s
.723 .203 0 r
.59016 .65278 m .58962 .65225 L .59208 .6519 L p F P
0 g
s
.721 .204 0 r
.58636 .64926 m .58962 .65225 L .59208 .6519 L p F P
0 g
s
.174 .086 .509 r
.41048 .71211 m .41448 .70755 L .41539 .71194 L p F P
0 g
s
.174 .086 .509 r
.41049 .7124 m .41048 .71211 L p .41539 .71194 L F P
0 g
s
.479 .048 .143 r
.50469 .70134 m .50653 .69842 L .50671 .6984 L p F P
0 g
s
.388 0 .118 r
.50653 .69842 m .50469 .70134 L .49458 .70374 L p F P
0 g
s
.069 0 .062 r
.43426 .67268 m .43744 .66948 L .43498 .67104 L closepath p F P
0 g
s
0 0 0 r
.43498 .67104 m .43426 .67268 L .43146 .67588 L p F P
0 g
s
.479 .048 .143 r
.50671 .6984 m .51623 .69939 L p .50469 .70134 L F P
0 g
s
.482 .059 .16 r
.51623 .69939 m .50671 .6984 L .51764 .697 L closepath p F P
0 g
s
.865 .418 .057 r
.62579 .68271 m .62727 .68353 L .62762 .68423 L closepath p F P
0 g
s
.829 .357 0 r
.6246 .68177 m .62579 .68271 L .62727 .68353 L p F P
0 g
s
.696 .979 .898 r
.44988 .72953 m .44024 .73479 L .44305 .73557 L p F P
0 g
s
.696 .979 .898 r
.45126 .72944 m .44988 .72953 L p .44305 .73557 L F P
0 g
s
.696 .979 .898 r
.44305 .73557 m .44876 .73188 L .45126 .72944 L p F P
0 g
s
.703 .854 .955 r
.44305 .73557 m .44024 .73479 L .43454 .73733 L p F P
0 g
s
.65 .757 .927 r
.18504 .49343 m .17594 .49661 L .17916 .49956 L p F P
0 g
s
.65 .757 .927 r
.17916 .49956 m .18824 .49639 L .18504 .49343 L p F P
0 g
s
.737 .214 0 r
.5735 .71242 m .57313 .71202 L .56894 .70991 L p F P
0 g
s
.174 .086 .509 r
.41539 .71194 m .41143 .71652 L .41049 .7124 L p F P
0 g
s
.158 .076 .506 r
.41143 .71652 m .41081 .71726 L .41049 .7124 L closepath p F P
0 g
s
.13 0 0 r
.48331 .70972 m .48451 .70833 L .49417 .70444 L p F P
0 g
s
.24 0 .024 r
.49458 .70374 m .49417 .70444 L .48451 .70833 L p F P
0 g
s
.977 .688 .4 r
.63637 .70251 m .63871 .70513 L .63888 .70982 L p F P
0 g
s
.961 .626 .287 r
.63871 .70513 m .63637 .70251 L .63566 .69798 L p F P
0 g
s
.651 .758 .928 r
.78979 .49352 m .77958 .49673 L .78178 .49968 L p F P
0 g
s
.651 .758 .928 r
.78178 .49968 m .79197 .49648 L .78979 .49352 L p F P
0 g
s
.65 .757 .928 r
.33621 .49357 m .32684 .49677 L .3298 .49971 L p F P
0 g
s
.65 .757 .928 r
.3298 .49971 m .33917 .49653 L .33621 .49357 L p F P
0 g
s
.651 .757 .928 r
.6386 .4936 m .62867 .4968 L .63112 .49974 L p F P
0 g
s
.651 .757 .928 r
.63112 .49974 m .64104 .49655 L .6386 .4936 L p F P
0 g
s
.652 .193 .15 r
.54739 .70138 m .54357 .69873 L .54401 .69825 L p F P
0 g
s
.685 .234 .175 r
.54357 .69873 m .54274 .69804 L .54401 .69825 L closepath p F P
0 g
s
.651 .757 .928 r
.4874 .49361 m .47775 .49681 L .48046 .49975 L p F P
0 g
s
.651 .757 .928 r
.48046 .49975 m .4901 .49656 L .4874 .49361 L p F P
0 g
s
.857 .403 .081 r
.62243 .6777 m .61913 .6753 L .62126 .67938 L p F P
0 g
s
.857 .403 .081 r
.62126 .67938 m .6246 .68177 L .62243 .6777 L p F P
0 g
s
0 .399 .833 r
.59335 .7256 m .5902 .72321 L .59677 .72612 L p F P
0 g
s
0 .399 .833 r
.59677 .72612 m .59966 .72857 L .59335 .7256 L p F P
0 g
s
.303 0 .014 r
.47578 .64392 m .47616 .6434 L .48609 .64077 L p F P
0 g
s
.65 .757 .927 r
.19737 .4932 m .18824 .49639 L .19144 .49934 L p F P
0 g
s
.65 .757 .927 r
.19144 .49934 m .20055 .49616 L .19737 .4932 L p F P
0 g
s
.651 .758 .928 r
.8022 .49327 m .79197 .49648 L .79415 .49942 L p F P
0 g
s
.651 .758 .928 r
.79415 .49942 m .80437 .49622 L .8022 .49327 L p F P
0 g
s
.65 .757 .928 r
.34857 .49333 m .33917 .49653 L .34211 .49947 L p F P
0 g
s
.65 .757 .928 r
.34211 .49947 m .3515 .49629 L .34857 .49333 L p F P
0 g
s
.637 .165 .114 r
.54274 .69804 m .53446 .69708 L .53951 .7003 L p F P
0 g
s
.637 .165 .114 r
.54357 .69873 m .54274 .69804 L p .53951 .7003 L F P
0 g
s
.651 .757 .928 r
.651 .49335 m .64104 .49655 L .64348 .49949 L p F P
0 g
s
.651 .757 .928 r
.64348 .49949 m .65342 .4963 L .651 .49335 L p F P
0 g
s
.651 .757 .928 r
.49978 .49336 m .4901 .49656 L .49279 .49951 L p F P
0 g
s
.651 .757 .928 r
.49279 .49951 m .50246 .49632 L .49978 .49336 L p F P
0 g
s
.365 .438 .803 r
.4156 .73349 m .4127 .73225 L .41396 .72984 L closepath p F P
0 g
s
.424 .507 .84 r
.4127 .73225 m .4156 .73349 L .41834 .73817 L p F P
0 g
s
.485 0 0 r
.5735 .71242 m .57802 .71535 L .57357 .71331 L p F P
0 g
s
.485 0 0 r
.57357 .71331 m .57097 .71185 L .5735 .71242 L p F P
0 g
s
.737 .214 0 r
.56894 .70991 m .57097 .71185 L .5735 .71242 L p F P
0 g
s
.761 .256 .003 r
.59929 .65693 m .59485 .65482 L .59803 .65854 L p F P
0 g
s
.761 .256 .003 r
.59803 .65854 m .6025 .66064 L .59929 .65693 L p F P
0 g
s
.958 .622 .314 r
.63566 .69798 m .63311 .69541 L .63381 .69993 L p F P
0 g
s
.958 .622 .314 r
.63381 .69993 m .63637 .70251 L .63566 .69798 L p F P
0 g
s
.906 .497 .181 r
.62762 .68423 m .62917 .68849 L .62618 .68602 L p F P
0 g
s
.906 .497 .181 r
.62579 .68271 m .62762 .68423 L p .62618 .68602 L F P
0 g
s
.65 .757 .927 r
.2097 .49297 m .20055 .49616 L .20373 .49911 L p F P
0 g
s
.65 .757 .927 r
.20373 .49911 m .21287 .49593 L .2097 .49297 L p F P
0 g
s
.598 .09 .014 r
.55256 .63627 m .55793 .63927 L .55027 .63808 L p F P
0 g
s
.598 .09 .014 r
.54841 .63562 m .55256 .63627 L p .55027 .63808 L F P
0 g
s
.934 .558 .241 r
.63194 .69102 m .62917 .68849 L .63033 .69288 L p F P
0 g
s
.934 .558 .241 r
.63033 .69288 m .63311 .69541 L .63194 .69102 L p F P
0 g
s
.011 0 .289 r
.41583 .69786 m .41684 .69675 L .41629 .70107 L p F P
0 g
s
.011 0 .289 r
.41629 .70107 m .41469 .70283 L .41583 .69786 L p F P
0 g
s
.651 .758 .928 r
.81462 .49301 m .80437 .49622 L .80653 .49916 L p F P
0 g
s
.651 .758 .928 r
.80653 .49916 m .81677 .49596 L .81462 .49301 L p F P
0 g
s
.403 0 .01 r
.49877 .63624 m .50996 .63485 L p .5056 .63752 L F P
0 g
s
.403 0 .01 r
.5056 .63752 m .49781 .63737 L .49877 .63624 L p F P
0 g
s
.377 0 0 r
.51018 .63466 m .50996 .63485 L .49877 .63624 L p F P
0 g
s
.65 .757 .928 r
.36092 .49309 m .3515 .49629 L .35442 .49923 L p F P
0 g
s
.65 .757 .928 r
.35442 .49923 m .36384 .49605 L .36092 .49309 L p F P
0 g
s
.957 .828 .676 r
.64113 .7252 m .64049 .7268 L .63808 .72515 L p F P
0 g
s
.957 .828 .676 r
.63808 .72515 m .63918 .7225 L .64113 .7252 L p F P
0 g
s
.98 .804 .593 r
.64113 .7252 m .63918 .7225 L .64051 .71737 L p F P
0 g
s
.651 .757 .928 r
.6634 .4931 m .65342 .4963 L .65583 .49925 L p F P
0 g
s
.651 .757 .928 r
.65583 .49925 m .6658 .49605 L .6634 .4931 L p F P
0 g
s
.651 .757 .928 r
.51216 .49312 m .50246 .49632 L .50513 .49926 L p F P
0 g
s
.651 .757 .928 r
.50513 .49926 m .51482 .49607 L .51216 .49312 L p F P
0 g
s
.512 .58 .86 r
.41834 .73817 m .42129 .7378 L .42365 .73377 L p F P
0 g
s
.512 .58 .86 r
.42365 .73377 m .4156 .73349 L .41834 .73817 L p F P
0 g
s
.625 .094 0 r
.55969 .70452 m .56411 .70796 L .55844 .70626 L p F P
0 g
s
.625 .094 0 r
.55767 .704 m .55969 .70452 L p .55844 .70626 L F P
0 g
s
.65 .757 .927 r
.22204 .49274 m .21287 .49593 L .21603 .49888 L p F P
0 g
s
.65 .757 .927 r
.21603 .49888 m .22519 .4957 L .22204 .49274 L p F P
0 g
s
.651 .758 .927 r
.82705 .49274 m .81677 .49596 L .81891 .49891 L p F P
0 g
s
.651 .758 .927 r
.81891 .49891 m .82917 .4957 L .82705 .49274 L p F P
0 g
s
.699 .978 .908 r
.45126 .72944 m .4527 .72938 L .44876 .73188 L closepath p F P
0 g
s
.81 .326 .037 r
.60943 .66668 m .60714 .66336 L .6078 .66341 L p F P
0 g
s
.792 .298 .009 r
.60714 .66336 m .60673 .6628 L .6078 .66341 L closepath p F P
0 g
s
.65 .757 .928 r
.37329 .49285 m .36384 .49605 L .36674 .49899 L p F P
0 g
s
.65 .757 .928 r
.36674 .49899 m .37618 .4958 L .37329 .49285 L p F P
0 g
s
.651 .757 .928 r
.6758 .49285 m .6658 .49605 L .66819 .499 L p F P
0 g
s
.651 .757 .928 r
.66819 .499 m .67818 .4958 L .6758 .49285 L p F P
0 g
s
.651 .757 .928 r
.52454 .49287 m .51482 .49607 L .51747 .49902 L p F P
0 g
s
.651 .757 .928 r
.51747 .49902 m .52718 .49583 L .52454 .49287 L p F P
0 g
s
.635 .11 0 r
.56055 .63972 m .56218 .63895 L .56482 .64068 L closepath p F P
0 g
s
.579 .04 0 r
.55793 .63927 m .56055 .63972 L .56218 .63895 L p F P
0 g
s
.65 .757 .927 r
.23438 .49251 m .22519 .4957 L .22832 .49866 L p F P
0 g
s
.65 .757 .927 r
.22832 .49866 m .23751 .49547 L .23438 .49251 L p F P
0 g
s
.651 .757 .928 r
.68821 .4926 m .67818 .4958 L .68055 .49875 L p F P
0 g
s
.651 .757 .928 r
.68055 .49875 m .69057 .49555 L .68821 .4926 L p F P
0 g
s
.65 .757 .928 r
.38565 .4926 m .37618 .4958 L .37906 .49875 L p F P
0 g
s
.65 .757 .928 r
.37906 .49875 m .38852 .49556 L .38565 .4926 L p F P
0 g
s
.295 0 .001 r
.47417 .64611 m .47578 .64392 L .48541 .6417 L p F P
0 g
s
.303 0 .014 r
.48609 .64077 m .48541 .6417 L .47578 .64392 L p F P
0 g
s
.196 0 0 r
.47578 .64392 m .47417 .64611 L .46483 .6493 L p F P
0 g
s
.651 .757 .928 r
.53693 .49262 m .52718 .49583 L .52981 .49877 L p F P
0 g
s
.651 .757 .928 r
.52981 .49877 m .53955 .49558 L .53693 .49262 L p F P
0 g
s
.256 .276 .69 r
.41291 .72695 m .41077 .72477 L .41183 .72304 L closepath p F P
0 g
s
.274 .325 .734 r
.41077 .72477 m .41291 .72695 L .41396 .72984 L p F P
0 g
s
.916 .864 .773 r
.6377 .73092 m .64049 .7268 L .63808 .72515 L p F P
0 g
s
.653 .184 .126 r
.54168 .70057 m .54357 .69873 L .54739 .70138 L closepath p F P
0 g
s
.637 .165 .114 r
.53951 .7003 m .54168 .70057 L .54357 .69873 L p F P
0 g
s
.138 0 .058 r
.44398 .66358 m .44543 .66248 L .44421 .66311 L closepath p F P
0 g
s
.006 0 0 r
.44421 .66311 m .44398 .66358 L .43744 .66948 L p F P
0 g
s
.598 .09 .014 r
.55027 .63808 m .54724 .63647 L .54841 .63562 L p F P
0 g
s
.567 .053 0 r
.54724 .63647 m .54448 .63521 L .54841 .63562 L closepath p F P
0 g
s
.242 0 .012 r
.4633 .65163 m .46483 .6493 L .47417 .64611 L p F P
0 g
s
.142 0 0 r
.46483 .6493 m .4633 .65163 L .45924 .65371 L p F P
0 g
s
.65 .757 .928 r
.24673 .49228 m .23751 .49547 L .24062 .49842 L p F P
0 g
s
.65 .757 .928 r
.24062 .49842 m .24983 .49524 L .24673 .49228 L p F P
0 g
s
.679 .145 0 r
.58636 .64926 m .58109 .64738 L .58489 .6509 L p F P
0 g
s
.679 .145 0 r
.58962 .65225 m .58636 .64926 L p .58489 .6509 L F P
0 g
s
.651 .757 .928 r
.70062 .49235 m .69057 .49555 L .69292 .4985 L p F P
0 g
s
.651 .757 .928 r
.69292 .4985 m .70296 .4953 L .70062 .49235 L p F P
0 g
s
.65 .757 .928 r
.39802 .49236 m .38852 .49556 L .39138 .49851 L p F P
0 g
s
.65 .757 .928 r
.39138 .49851 m .40087 .49532 L .39802 .49236 L p F P
0 g
s
.651 .757 .928 r
.54932 .49237 m .53955 .49558 L .54215 .49853 L p F P
0 g
s
.651 .757 .928 r
.54215 .49853 m .55191 .49533 L .54932 .49237 L p F P
0 g
s
.625 .094 0 r
.55844 .70626 m .55597 .70471 L .55767 .704 L p F P
0 g
s
.712 .21 .043 r
.55597 .70471 m .55393 .70284 L .55767 .704 L closepath p F P
0 g
s
.658 .967 .91 r
.4527 .72938 m .46143 .72353 L p .4544 .7269 L F P
0 g
s
.658 .967 .91 r
.4544 .7269 m .45126 .72944 L .4527 .72938 L p F P
0 g
s
.584 .147 .175 r
.53446 .69708 m .53951 .7003 L .53026 .69961 L p F P
0 g
s
.584 .147 .175 r
.53001 .69681 m .53446 .69708 L p .53026 .69961 L F P
0 g
s
.691 .895 .971 r
.43742 .73345 m .42784 .73676 L .43064 .7391 L p F P
0 g
s
.691 .895 .971 r
.43812 .73377 m .43742 .73345 L p .43064 .7391 L F P
0 g
s
.691 .895 .971 r
.43064 .7391 m .43454 .73733 L .43812 .73377 L p F P
0 g
s
.629 .093 0 r
.57111 .64227 m .56482 .64068 L .5693 .64397 L p F P
0 g
s
.629 .093 0 r
.57462 .64484 m .57111 .64227 L p .5693 .64397 L F P
0 g
s
.795 .308 .051 r
.60714 .66336 m .60673 .6628 L .6025 .66064 L p F P
0 g
s
.81 .836 .87 r
.63084 .73766 m .63095 .73757 L .63135 .73813 L closepath p F P
0 g
s
.853 .838 .83 r
.6377 .73092 m .63095 .73757 L .63135 .73813 L p F P
0 g
s
.48 0 0 r
.5219 .6342 m .52252 .63369 L .5246 .63421 L closepath p F P
0 g
s
.426 0 0 r
.52252 .63369 m .5219 .6342 L .51113 .63477 L p F P
0 g
s
.532 .111 .186 r
.51764 .697 m .52367 .69684 L p .5179 .69983 L F P
0 g
s
.532 .111 .186 r
.5179 .69983 m .51623 .69939 L .51764 .697 L p F P
0 g
s
.478 0 0 r
.5819 .71754 m .57802 .71535 L .58281 .71873 L p F P
0 g
s
.478 0 0 r
.586 .72077 m .5819 .71754 L p .58281 .71873 L F P
0 g
s
.546 0 0 r
.5819 .71754 m .586 .72077 L p .5877 .72194 L F P
0 g
s
0 .44 .811 r
.586 .72077 m .58655 .72096 L .5855 .72043 L p F P
0 g
s
0 .44 .811 r
.5855 .72043 m .58514 .72024 L .586 .72077 L p F P
0 g
s
.546 0 0 r
.586 .72077 m .58851 .72255 L p .5877 .72194 L F P
0 g
s
.65 .757 .928 r
.25908 .49204 m .24983 .49524 L .25293 .49819 L p F P
0 g
s
.65 .757 .928 r
.25293 .49819 m .26216 .495 L .25908 .49204 L p F P
0 g
s
.339 .626 .957 r
.61755 .73807 m .61849 .7382 L .616 .73557 L p F P
0 g
s
.339 .626 .957 r
.616 .73557 m .61531 .73546 L .61755 .73807 L p F P
0 g
s
.195 0 .041 r
.45365 .65681 m .45924 .65371 L .45418 .65587 L closepath p F P
0 g
s
.071 0 0 r
.45418 .65587 m .45365 .65681 L .44543 .66248 L p F P
0 g
s
.651 .758 .928 r
.71303 .49209 m .70296 .4953 L .70529 .49825 L p F P
0 g
s
.651 .758 .928 r
.70529 .49825 m .71535 .49505 L .71303 .49209 L p F P
0 g
s
.65 .757 .928 r
.41039 .49212 m .40087 .49532 L .40371 .49827 L p F P
0 g
s
.65 .757 .928 r
.40371 .49827 m .41322 .49508 L .41039 .49212 L p F P
0 g
s
.651 .757 .928 r
.56171 .49213 m .55191 .49533 L .5545 .49828 L p F P
0 g
s
.651 .757 .928 r
.5545 .49828 m .56429 .49509 L .56171 .49213 L p F P
0 g
s
.421 0 0 r
.50996 .63485 m .51018 .63466 L .51113 .63477 L closepath p F P
0 g
s
.378 0 .116 r
.49417 .70444 m .49458 .70374 L .50469 .70134 L p F P
0 g
s
.074 0 .175 r
.42442 .68575 m .42691 .68186 L .42517 .68319 L closepath p F P
0 g
s
0 0 .142 r
.4234 .68753 m .42442 .68575 L .42517 .68319 L p F P
0 g
s
.06 0 .053 r
.43744 .66948 m .44261 .66632 L p .4335 .6744 L F P
0 g
s
.06 0 .053 r
.4335 .6744 m .43426 .67268 L .43744 .66948 L p F P
0 g
s
.049 0 .009 r
.44261 .66632 m .44398 .66358 L .43744 .66948 L closepath p F P
0 g
s
.543 .023 0 r
.54448 .63521 m .53548 .63443 L .54176 .63714 L p F P
0 g
s
.543 .023 0 r
.54724 .63647 m .54448 .63521 L p .54176 .63714 L F P
0 g
s
0 .373 .823 r
.60353 .73173 m .60229 .73109 L .59966 .72857 L p F P
0 g
s
.532 .111 .186 r
.52367 .69684 m .5286 .69887 L p .5179 .69983 L F P
0 g
s
.574 .135 .169 r
.5286 .69887 m .52367 .69684 L .53001 .69681 L closepath p F P
0 g
s
.13 0 .048 r
.44261 .66632 m .44398 .66358 L .44543 .66248 L p F P
0 g
s
.972 .791 .601 r
.63837 .71471 m .64051 .71737 L .63918 .7225 L p F P
0 g
s
.986 .751 .496 r
.64051 .71737 m .63837 .71471 L .63888 .70982 L p F P
0 g
s
.584 .147 .175 r
.53026 .69961 m .5286 .69887 L .53001 .69681 L p F P
0 g
s
0 .464 .849 r
.58655 .72096 m .586 .72077 L .58851 .72255 L p F P
0 g
s
.65 .757 .928 r
.27143 .4918 m .26216 .495 L .26524 .49796 L p F P
0 g
s
.65 .757 .928 r
.26524 .49796 m .27449 .49477 L .27143 .4918 L p F P
0 g
s
.117 0 .33 r
.41684 .69675 m .42116 .69283 L .41984 .69787 L p F P
0 g
s
.117 0 .33 r
.41984 .69787 m .41629 .70107 L .41684 .69675 L p F P
0 g
s
.651 .758 .928 r
.72545 .49184 m .71535 .49505 L .71766 .498 L p F P
0 g
s
.651 .758 .928 r
.71766 .498 m .72775 .4948 L .72545 .49184 L p F P
0 g
s
0 0 .015 r
.4335 .6744 m .43426 .67268 L .43146 .67588 L closepath p F P
0 g
s
.651 .757 .928 r
.42277 .49187 m .41322 .49508 L .41604 .49803 L p F P
0 g
s
.651 .757 .928 r
.41604 .49803 m .42558 .49483 L .42277 .49187 L p F P
0 g
s
.651 .757 .928 r
.57411 .49188 m .56429 .49509 L .56685 .49803 L p F P
0 g
s
.651 .757 .928 r
.56685 .49803 m .57666 .49484 L .57411 .49188 L p F P
0 g
s
.104 0 0 r
.45244 .65891 m .45365 .65681 L .44543 .66248 L closepath p F P
0 g
s
.13 0 .048 r
.44543 .66248 m .45244 .65891 L p .44261 .66632 L F P
0 g
s
.263 .22 .62 r
.41081 .71726 m .41143 .71652 L .41402 .72042 L p F P
0 g
s
.263 .22 .62 r
.41402 .72042 m .41183 .72304 L .41081 .71726 L p F P
0 g
s
.579 .702 .926 r
.42784 .73676 m .42129 .7378 L .42365 .73377 L p F P
0 g
s
.839 .834 .842 r
.63592 .72818 m .6377 .73092 L .63095 .73757 L p F P
0 g
s
.916 .864 .773 r
.63808 .72515 m .63592 .72818 L .6377 .73092 L p F P
0 g
s
.65 .756 .927 r
.13245 .49133 m .12344 .49451 L .12675 .49748 L p F P
0 g
s
.65 .756 .927 r
.12675 .49748 m .13575 .4943 L .13245 .49133 L p F P
0 g
s
.799 .313 .045 r
.60714 .66336 m .60943 .66668 L .60543 .66446 L p F P
0 g
s
.799 .313 .045 r
.60543 .66446 m .60471 .66347 L .60714 .66336 L p F P
0 g
s
.795 .308 .051 r
.6025 .66064 m .60471 .66347 L .60714 .66336 L p F P
0 g
s
.65 .757 .928 r
.28379 .49157 m .27449 .49477 L .27755 .49772 L p F P
0 g
s
.65 .757 .928 r
.27755 .49772 m .28683 .49453 L .28379 .49157 L p F P
0 g
s
.639 .79 .955 r
.61849 .7382 m .62839 .73529 L .63084 .73766 L p F P
0 g
s
.631 .78 .953 r
.62839 .73529 m .61849 .7382 L .616 .73557 L p F P
0 g
s
.651 .758 .928 r
.73787 .49159 m .72775 .4948 L .73004 .49775 L p F P
0 g
s
.651 .758 .928 r
.73004 .49775 m .74015 .49455 L .73787 .49159 L p F P
0 g
s
.651 .757 .928 r
.43515 .49163 m .42558 .49483 L .42838 .49778 L p F P
0 g
s
.651 .757 .928 r
.42838 .49778 m .43794 .49459 L .43515 .49163 L p F P
0 g
s
.651 .757 .928 r
.58651 .49163 m .57666 .49484 L .57921 .49779 L p F P
0 g
s
.651 .757 .928 r
.57921 .49779 m .58904 .49459 L .58651 .49163 L p F P
0 g
s
.466 0 .029 r
.50778 .63725 m .50996 .63485 L .51113 .63477 L p F P
0 g
s
.403 0 .01 r
.50996 .63485 m .50778 .63725 L .5056 .63752 L p F P
0 g
s
.801 .828 .872 r
.63095 .73757 m .63084 .73766 L .62839 .73529 L p F P
0 g
s
.524 0 0 r
.53464 .63437 m .53487 .63421 L .53548 .63443 L closepath p F P
0 g
s
.483 0 0 r
.53487 .63421 m .53464 .63437 L .5246 .63421 L p F P
0 g
s
.801 .828 .872 r
.62839 .73529 m .62886 .73493 L .63095 .73757 L p F P
0 g
s
.839 .834 .842 r
.63095 .73757 m .62886 .73493 L .63592 .72818 L p F P
0 g
s
.049 0 .115 r
.43146 .67588 m .4335 .6744 L .43223 .67798 L p F P
0 g
s
.049 0 .115 r
.43223 .67798 m .42691 .68186 L .43146 .67588 L p F P
0 g
s
.466 0 .029 r
.51113 .63477 m .51987 .63625 L p .50778 .63725 L F P
0 g
s
.459 0 0 r
.51987 .63625 m .51113 .63477 L .5219 .6342 L closepath p F P
0 g
s
.65 .756 .927 r
.14479 .49112 m .13575 .4943 L .13904 .49727 L p F P
0 g
s
.65 .756 .927 r
.13904 .49727 m .14807 .49409 L .14479 .49112 L p F P
0 g
s
.906 .497 .181 r
.62618 .68602 m .62486 .68241 L .62579 .68271 L p F P
0 g
s
.896 .477 .158 r
.62486 .68241 m .6246 .68177 L .62579 .68271 L closepath p F P
0 g
s
.837 .374 .093 r
.6132 .66897 m .60943 .66668 L .61181 .67068 L p F P
0 g
s
.837 .374 .093 r
.61181 .67068 m .61559 .67296 L .6132 .66897 L p F P
0 g
s
.65 .757 .928 r
.29615 .49133 m .28683 .49453 L .28987 .49748 L p F P
0 g
s
.65 .757 .928 r
.28987 .49748 m .29917 .49429 L .29615 .49133 L p F P
0 g
s
.651 .758 .928 r
.7503 .49133 m .74015 .49455 L .74242 .4975 L p F P
0 g
s
.651 .758 .928 r
.74242 .4975 m .75255 .49429 L .7503 .49133 L p F P
0 g
s
.651 .757 .928 r
.44753 .49138 m .43794 .49459 L .44072 .49754 L p F P
0 g
s
.651 .757 .928 r
.44072 .49754 m .4503 .49434 L .44753 .49138 L p F P
0 g
s
.651 .757 .928 r
.59891 .49138 m .58904 .49459 L .59157 .49754 L p F P
0 g
s
.651 .757 .928 r
.59157 .49754 m .60143 .49434 L .59891 .49138 L p F P
0 g
s
.689 .89 .971 r
.43812 .73377 m .44024 .73479 L .43454 .73733 L closepath p F P
0 g
s
.656 .101 0 r
.56894 .70991 m .56411 .70796 L .56837 .71147 L p F P
0 g
s
.656 .101 0 r
.57097 .71185 m .56894 .70991 L p .56837 .71147 L F P
0 g
s
.65 .756 .927 r
.15713 .4909 m .14807 .49409 L .15134 .49705 L p F P
0 g
s
.65 .756 .927 r
.15134 .49705 m .16039 .49387 L .15713 .4909 L p F P
0 g
s
.503 .598 .882 r
.4156 .73349 m .41396 .72984 L p .42431 .73269 L F P
0 g
s
.503 .598 .882 r
.42431 .73269 m .42365 .73377 L .4156 .73349 L p F P
0 g
s
.658 .967 .91 r
.46143 .72353 m .46209 .723 L p .4544 .7269 L F P
0 g
s
.591 .943 .795 r
.46209 .723 m .46237 .72291 L .46143 .72353 L closepath p F P
0 g
s
.977 .739 .508 r
.63653 .7072 m .63888 .70982 L .63837 .71471 L p F P
0 g
s
.977 .688 .4 r
.63888 .70982 m .63653 .7072 L .63637 .70251 L p F P
0 g
s
.651 .758 .928 r
.76272 .49108 m .75255 .49429 L .7548 .49724 L p F P
0 g
s
.651 .758 .928 r
.7548 .49724 m .76496 .49404 L .76272 .49108 L p F P
0 g
s
.65 .757 .928 r
.30851 .49109 m .29917 .49429 L .30219 .49725 L p F P
0 g
s
.65 .757 .928 r
.30219 .49725 m .31151 .49405 L .30851 .49109 L p F P
0 g
s
.543 .043 .019 r
.53548 .63443 m .54176 .63714 L .53229 .63649 L p F P
0 g
s
.543 .043 .019 r
.53464 .63437 m .53548 .63443 L p .53229 .63649 L F P
0 g
s
.651 .757 .928 r
.61132 .49113 m .60143 .49434 L .60393 .49729 L p F P
0 g
s
.651 .757 .928 r
.60393 .49729 m .61381 .4941 L .61132 .49113 L p F P
0 g
s
.651 .757 .928 r
.45991 .49114 m .4503 .49434 L .45306 .4973 L p F P
0 g
s
.651 .757 .928 r
.45306 .4973 m .46266 .4941 L .45991 .49114 L p F P
0 g
s
.543 .043 .019 r
.53229 .63649 m .53226 .63648 L .53464 .63437 L p F P
0 g
s
.509 .004 0 r
.53226 .63648 m .5246 .63421 L .53464 .63437 L closepath p F P
0 g
s
.374 .646 .962 r
.60353 .73173 m .6129 .73289 L .61531 .73546 L p F P
0 g
s
.355 .652 .968 r
.60353 .73173 m .6129 .73289 L .61032 .73035 L p F P
0 g
s
.355 .652 .968 r
.61032 .73035 m .60103 .72927 L .60353 .73173 L p F P
0 g
s
0 .373 .823 r
.59966 .72857 m .60103 .72927 L .60353 .73173 L p F P
0 g
s
.155 0 0 r
.48173 .71162 m .48331 .70972 L .49253 .7065 L p F P
0 g
s
.13 0 0 r
.49417 .70444 m .49253 .7065 L .48331 .70972 L p F P
0 g
s
0 0 0 r
.48331 .70972 m .48173 .71162 L .4762 .71456 L p F P
0 g
s
.566 .932 .79 r
.46209 .723 m .46237 .72291 L .47205 .71677 L p F P
0 g
s
.661 .141 0 r
.55393 .70284 m .54739 .70138 L .55203 .70476 L p F P
0 g
s
.661 .141 0 r
.55597 .70471 m .55393 .70284 L p .55203 .70476 L F P
0 g
s
.311 0 0 r
.49253 .7065 m .49417 .70444 L .50384 .70271 L p F P
0 g
s
.378 0 .116 r
.50469 .70134 m .50384 .70271 L .49417 .70444 L p F P
0 g
s
.098 0 .398 r
.41469 .70283 m .41629 .70107 L .41611 .70575 L p F P
0 g
s
.098 0 .398 r
.41611 .70575 m .41448 .70755 L .41469 .70283 L p F P
0 g
s
.65 .757 .927 r
.16947 .49068 m .16039 .49387 L .16364 .49683 L p F P
0 g
s
.65 .757 .927 r
.16364 .49683 m .17271 .49365 L .16947 .49068 L p F P
0 g
s
.264 .22 .62 r
.41143 .71652 m .41539 .71194 L p .41729 .71654 L F P
0 g
s
.264 .22 .62 r
.41729 .71654 m .41402 .72042 L .41143 .71652 L p F P
0 g
s
.398 0 0 r
.49663 .63871 m .49781 .63737 L .5056 .63752 L closepath p F P
0 g
s
.346 0 0 r
.49781 .63737 m .49663 .63871 L .48609 .64077 L p F P
0 g
s
.765 .271 .047 r
.59485 .65482 m .59016 .65278 L .59332 .6565 L p F P
0 g
s
.765 .271 .047 r
.59332 .6565 m .59803 .65854 L .59485 .65482 L p F P
0 g
s
.651 .758 .928 r
.77516 .49082 m .76496 .49404 L .76719 .49699 L p F P
0 g
s
.651 .758 .928 r
.76719 .49699 m .77737 .49378 L .77516 .49082 L p F P
0 g
s
.5 .01 .024 r
.5246 .63421 m .53226 .63648 L p .52071 .63647 L F P
0 g
s
.5 .01 .024 r
.5219 .6342 m .5246 .63421 L p .52071 .63647 L F P
0 g
s
.5 .01 .024 r
.52071 .63647 m .51987 .63625 L .5219 .6342 L p F P
0 g
s
.65 .757 .928 r
.32088 .49085 m .31151 .49405 L .31451 .49701 L p F P
0 g
s
.65 .757 .928 r
.31451 .49701 m .32386 .49381 L .32088 .49085 L p F P
0 g
s
.651 .757 .928 r
.62373 .49088 m .61381 .4941 L .6163 .49705 L p F P
0 g
s
.651 .757 .928 r
.6163 .49705 m .6262 .49385 L .62373 .49088 L p F P
0 g
s
.651 .757 .928 r
.4723 .49089 m .46266 .4941 L .4654 .49705 L p F P
0 g
s
.651 .757 .928 r
.4654 .49705 m .47503 .49385 L .4723 .49089 L p F P
0 g
s
.86 .413 .125 r
.61913 .6753 m .61559 .67296 L .61769 .67705 L p F P
0 g
s
.86 .413 .125 r
.61769 .67705 m .62126 .67938 L .61913 .6753 L p F P
0 g
s
.187 0 .029 r
.45244 .65891 m .45365 .65681 L .45924 .65371 L p F P
0 g
s
0 .409 .83 r
.5902 .72321 m .58655 .72096 L .59358 .72373 L p F P
0 g
s
0 .409 .83 r
.59358 .72373 m .59677 .72612 L .5902 .72321 L p F P
0 g
s
.65 .757 .927 r
.18182 .49045 m .17271 .49365 L .17594 .49661 L p F P
0 g
s
.65 .757 .927 r
.17594 .49661 m .18504 .49343 L .18182 .49045 L p F P
0 g
s
0 0 0 r
.47205 .71677 m .4762 .71456 L .47258 .71625 L closepath p F P
0 g
s
.651 .758 .928 r
.78759 .49056 m .77737 .49378 L .77958 .49673 L p F P
0 g
s
.651 .758 .928 r
.77958 .49673 m .78979 .49352 L .78759 .49056 L p F P
0 g
s
.65 .757 .928 r
.33325 .49061 m .32386 .49381 L .32684 .49677 L p F P
0 g
s
.65 .757 .928 r
.32684 .49677 m .33621 .49357 L .33325 .49061 L p F P
0 g
s
.969 .678 .419 r
.63637 .70251 m .63381 .69993 L .63398 .70463 L p F P
0 g
s
.969 .678 .419 r
.63398 .70463 m .63653 .7072 L .63637 .70251 L p F P
0 g
s
.651 .757 .928 r
.63615 .49063 m .6262 .49385 L .62867 .4968 L p F P
0 g
s
.651 .757 .928 r
.62867 .4968 m .6386 .4936 L .63615 .49063 L p F P
0 g
s
.651 .757 .928 r
.4847 .49064 m .47503 .49385 L .47775 .49681 L p F P
0 g
s
.651 .757 .928 r
.47775 .49681 m .4874 .49361 L .4847 .49064 L p F P
0 g
s
.388 .412 .764 r
.41183 .72304 m .41402 .72042 L .4188 .72372 L p F P
0 g
s
.388 .412 .764 r
.41291 .72695 m .41183 .72304 L p .4188 .72372 L F P
0 g
s
.377 0 .049 r
.48541 .6417 m .48609 .64077 L .49663 .63871 L p F P
0 g
s
.566 .932 .79 r
.47205 .71677 m .46967 .71829 L .46209 .723 L p F P
0 g
s
.481 .888 .756 r
.45955 .72393 m .46209 .723 L .46967 .71829 L p F P
0 g
s
.658 .967 .91 r
.46209 .723 m .45955 .72393 L .4544 .7269 L p F P
0 g
s
.503 .598 .882 r
.41396 .72984 m .41537 .7281 L p .42431 .73269 L F P
0 g
s
.392 .41 .76 r
.41537 .7281 m .41396 .72984 L .41291 .72695 L closepath p F P
0 g
s
.068 0 .171 r
.42691 .68186 m .43223 .67798 L p .42407 .68695 L F P
0 g
s
.068 0 .171 r
.42407 .68695 m .42442 .68575 L .42691 .68186 L p F P
0 g
s
.656 .156 .051 r
.56482 .64068 m .5693 .64397 L .56265 .64248 L p F P
0 g
s
.656 .156 .051 r
.56055 .63972 m .56482 .64068 L p .56265 .64248 L F P
0 g
s
.65 .757 .927 r
.19417 .49023 m .18504 .49343 L .18824 .49639 L p F P
0 g
s
.65 .757 .927 r
.18824 .49639 m .19737 .4932 L .19417 .49023 L p F P
0 g
s
.894 .479 .194 r
.62486 .68241 m .6246 .68177 L .62126 .67938 L p F P
0 g
s
.651 .758 .928 r
.80003 .4903 m .78979 .49352 L .79197 .49648 L p F P
0 g
s
.651 .758 .928 r
.79197 .49648 m .8022 .49327 L .80003 .4903 L p F P
0 g
s
.65 .757 .928 r
.34562 .49037 m .33621 .49357 L .33917 .49653 L p F P
0 g
s
.65 .757 .928 r
.33917 .49653 m .34857 .49333 L .34562 .49037 L p F P
0 g
s
.651 .757 .928 r
.64856 .49038 m .6386 .4936 L .64104 .49655 L p F P
0 g
s
.651 .757 .928 r
.64104 .49655 m .651 .49335 L .64856 .49038 L p F P
0 g
s
.651 .757 .928 r
.49709 .4904 m .4874 .49361 L .4901 .49656 L p F P
0 g
s
.651 .757 .928 r
.4901 .49656 m .49978 .49336 L .49709 .4904 L p F P
0 g
s
.388 .412 .764 r
.4188 .72372 m .41537 .7281 L .41291 .72695 L p F P
0 g
s
.952 .616 .338 r
.63311 .69541 m .63033 .69288 L .63104 .69741 L p F P
0 g
s
.952 .616 .338 r
.63104 .69741 m .63381 .69993 L .63311 .69541 L p F P
0 g
s
.713 .209 .035 r
.58109 .64738 m .57554 .64558 L .5793 .6491 L p F P
0 g
s
.713 .209 .035 r
.5793 .6491 m .58489 .6509 L .58109 .64738 L p F P
0 g
s
.93 .556 .268 r
.62917 .68849 m .62618 .68602 L .62734 .69041 L p F P
0 g
s
.93 .556 .268 r
.62734 .69041 m .63033 .69288 L .62917 .68849 L p F P
0 g
s
.65 .757 .927 r
.20652 .49 m .19737 .4932 L .20055 .49616 L p F P
0 g
s
.65 .757 .927 r
.20055 .49616 m .2097 .49297 L .20652 .49 L p F P
0 g
s
.651 .758 .927 r
.81247 .49004 m .8022 .49327 L .80437 .49622 L p F P
0 g
s
.651 .758 .927 r
.80437 .49622 m .81462 .49301 L .81247 .49004 L p F P
0 g
s
.65 .757 .928 r
.358 .49012 m .34857 .49333 L .3515 .49629 L p F P
0 g
s
.65 .757 .928 r
.3515 .49629 m .36092 .49309 L .358 .49012 L p F P
0 g
s
.651 .757 .928 r
.66099 .49013 m .651 .49335 L .65342 .4963 L p F P
0 g
s
.651 .757 .928 r
.65342 .4963 m .6634 .4931 L .66099 .49013 L p F P
0 g
s
.651 .757 .928 r
.50949 .49015 m .49978 .49336 L .50246 .49632 L p F P
0 g
s
.651 .757 .928 r
.50246 .49632 m .51216 .49312 L .50949 .49015 L p F P
0 g
s
.655 .968 .905 r
.44988 .72953 m .4544 .7269 L .45126 .72944 L closepath p F P
0 g
s
.598 .088 .011 r
.54582 .63748 m .54724 .63647 L .55027 .63808 L closepath p F P
0 g
s
.543 .023 0 r
.54176 .63714 m .54582 .63748 L .54724 .63647 L p F P
0 g
s
.947 .815 .681 r
.63918 .7225 m .63808 .72515 L .63565 .7231 L p F P
0 g
s
.947 .815 .681 r
.63565 .7231 m .63703 .71985 L .63918 .7225 L p F P
0 g
s
.972 .791 .601 r
.63918 .7225 m .63703 .71985 L .63837 .71471 L p F P
0 g
s
.899 .487 .197 r
.62486 .68241 m .62618 .68602 L .62298 .68359 L p F P
0 g
s
.899 .487 .197 r
.62298 .68359 m .62246 .68224 L .62486 .68241 L p F P
0 g
s
.894 .479 .194 r
.62126 .67938 m .62246 .68224 L .62486 .68241 L p F P
0 g
s
.65 .757 .927 r
.21888 .48977 m .2097 .49297 L .21287 .49593 L p F P
0 g
s
.65 .757 .927 r
.21287 .49593 m .22204 .49274 L .21888 .48977 L p F P
0 g
s
.651 .758 .927 r
.82491 .48978 m .81462 .49301 L .81677 .49596 L p F P
0 g
s
.651 .758 .927 r
.81677 .49596 m .82705 .49274 L .82491 .48978 L p F P
0 g
s
.65 .757 .928 r
.37038 .48988 m .36092 .49309 L .36384 .49605 L p F P
0 g
s
.65 .757 .928 r
.36384 .49605 m .37329 .49285 L .37038 .48988 L p F P
0 g
s
.651 .757 .928 r
.67341 .48988 m .6634 .4931 L .6658 .49605 L p F P
0 g
s
.651 .757 .928 r
.6658 .49605 m .6758 .49285 L .67341 .48988 L p F P
0 g
s
.651 .757 .928 r
.5219 .4899 m .51216 .49312 L .51482 .49607 L p F P
0 g
s
.651 .757 .928 r
.51482 .49607 m .52454 .49287 L .5219 .4899 L p F P
0 g
s
.145 0 .158 r
.4335 .6744 m .44117 .6697 L p .43607 .67564 L F P
0 g
s
.145 0 .158 r
.43607 .67564 m .43223 .67798 L .4335 .6744 L p F P
0 g
s
.06 0 .053 r
.44261 .66632 m .44117 .6697 L .4335 .6744 L p F P
0 g
s
.694 .89 .969 r
.44024 .73479 m .44988 .72953 L p .43918 .73264 L F P
0 g
s
.694 .89 .969 r
.43918 .73264 m .43812 .73377 L .44024 .73479 L p F P
0 g
s
.763 .26 .014 r
.6025 .66064 m .59803 .65854 L .60101 .66234 L p F P
0 g
s
.763 .26 .014 r
.60471 .66347 m .6025 .66064 L p .60101 .66234 L F P
0 g
s
.187 0 .029 r
.45924 .65371 m .46295 .65216 L p .45244 .65891 L F P
0 g
s
.146 0 0 r
.46295 .65216 m .4633 .65163 L .45924 .65371 L closepath p F P
0 g
s
.65 .757 .927 r
.23124 .48954 m .22204 .49274 L .22519 .4957 L p F P
0 g
s
.65 .757 .927 r
.22519 .4957 m .23438 .49251 L .23124 .48954 L p F P
0 g
s
0 0 .138 r
.42407 .68695 m .42442 .68575 L .4234 .68753 L closepath p F P
0 g
s
.651 .757 .928 r
.68584 .48963 m .6758 .49285 L .67818 .4958 L p F P
0 g
s
.651 .757 .928 r
.67818 .4958 m .68821 .4926 L .68584 .48963 L p F P
0 g
s
.65 .757 .928 r
.38277 .48964 m .37329 .49285 L .37618 .4958 L p F P
0 g
s
.65 .757 .928 r
.37618 .4958 m .38565 .4926 L .38277 .48964 L p F P
0 g
s
.504 0 0 r
.57802 .71535 m .57357 .71331 L .57889 .71654 L p F P
0 g
s
.504 0 0 r
.57889 .71654 m .58281 .71873 L .57802 .71535 L p F P
0 g
s
.651 .757 .928 r
.5343 .48966 m .52454 .49287 L .52718 .49583 L p F P
0 g
s
.651 .757 .928 r
.52718 .49583 m .53693 .49262 L .5343 .48966 L p F P
0 g
s
0 0 0 r
.47205 .71677 m .4762 .71456 L p .47285 .71686 L F P
0 g
s
0 0 0 r
.47285 .71686 m .46967 .71829 L .47205 .71677 L p F P
0 g
s
.65 .757 .927 r
.24361 .4893 m .23438 .49251 L .23751 .49547 L p F P
0 g
s
.65 .757 .927 r
.23751 .49547 m .24673 .49228 L .24361 .4893 L p F P
0 g
s
.656 .156 .051 r
.56265 .64248 m .55965 .64035 L .56055 .63972 L p F P
0 g
s
.63 .125 .029 r
.55965 .64035 m .55793 .63927 L .56055 .63972 L closepath p F P
0 g
s
.651 .757 .928 r
.69827 .48938 m .68821 .4926 L .69057 .49555 L p F P
0 g
s
.651 .757 .928 r
.69057 .49555 m .70062 .49235 L .69827 .48938 L p F P
0 g
s
.65 .757 .928 r
.39516 .48939 m .38565 .4926 L .38852 .49556 L p F P
0 g
s
.65 .757 .928 r
.38852 .49556 m .39802 .49236 L .39516 .48939 L p F P
0 g
s
.651 .757 .928 r
.54671 .48941 m .53693 .49262 L .53955 .49558 L p F P
0 g
s
.651 .757 .928 r
.53955 .49558 m .54932 .49237 L .54671 .48941 L p F P
0 g
s
.608 .13 .095 r
.54739 .70138 m .55203 .70476 L .54502 .70342 L p F P
0 g
s
.608 .13 .095 r
.54168 .70057 m .54739 .70138 L p .54502 .70342 L F P
0 g
s
.447 .02 .133 r
.50469 .70134 m .51582 .69991 L p .51193 .70287 L F P
0 g
s
.447 .02 .133 r
.51193 .70287 m .50384 .70271 L .50469 .70134 L p F P
0 g
s
.479 .048 .143 r
.51623 .69939 m .51582 .69991 L .50469 .70134 L p F P
0 g
s
.513 0 0 r
.56851 .71154 m .57097 .71185 L .57357 .71331 L closepath p F P
0 g
s
.656 .101 0 r
.56837 .71147 m .56851 .71154 L .57097 .71185 L p F P
0 g
s
.725 .209 0 r
.5891 .65236 m .58962 .65225 L .59016 .65278 L closepath p F P
0 g
s
.679 .145 0 r
.58489 .6509 m .5891 .65236 L .58962 .65225 L p F P
0 g
s
.075 0 .251 r
.4234 .68753 m .42407 .68695 L .42326 .69101 L p F P
0 g
s
.075 0 .251 r
.42326 .69101 m .42116 .69283 L .4234 .68753 L p F P
0 g
s
.65 .757 .928 r
.25598 .48907 m .24673 .49228 L .24983 .49524 L p F P
0 g
s
.65 .757 .928 r
.24983 .49524 m .25908 .49204 L .25598 .48907 L p F P
0 g
s
.653 .825 .966 r
.43461 .73144 m .42505 .73371 L .42784 .73676 L p F P
0 g
s
.653 .825 .966 r
.42784 .73676 m .43742 .73345 L .43461 .73144 L p F P
0 g
s
.579 .702 .926 r
.42365 .73377 m .42505 .73371 L .42784 .73676 L p F P
0 g
s
.678 .158 0 r
.57394 .64511 m .57462 .64484 L .57554 .64558 L closepath p F P
0 g
s
.629 .093 0 r
.5693 .64397 m .57394 .64511 L .57462 .64484 L p F P
0 g
s
.651 .758 .928 r
.71071 .48913 m .70062 .49235 L .70296 .4953 L p F P
0 g
s
.651 .758 .928 r
.70296 .4953 m .71303 .49209 L .71071 .48913 L p F P
0 g
s
.65 .757 .928 r
.40755 .48915 m .39802 .49236 L .40087 .49532 L p F P
0 g
s
.65 .757 .928 r
.40087 .49532 m .41039 .49212 L .40755 .48915 L p F P
0 g
s
.9 .843 .78 r
.63592 .72818 m .63808 .72515 L .63565 .7231 L p F P
0 g
s
.651 .757 .928 r
.55913 .48916 m .54932 .49237 L .55191 .49533 L p F P
0 g
s
.651 .757 .928 r
.55191 .49533 m .56171 .49213 L .55913 .48916 L p F P
0 g
s
.325 .624 .958 r
.61531 .73546 m .616 .73557 L .61352 .73299 L p F P
0 g
s
.325 .624 .958 r
.61352 .73299 m .6129 .73289 L .61531 .73546 L p F P
0 g
s
.624 .093 0 r
.5544 .70536 m .55597 .70471 L .55844 .70626 L closepath p F P
0 g
s
.661 .141 0 r
.55203 .70476 m .5544 .70536 L .55597 .70471 L p F P
0 g
s
0 .364 .807 r
.60103 .72927 m .59966 .72857 L .59677 .72612 L p F P
0 g
s
.671 .125 0 r
.56411 .70796 m .55844 .70626 L .5634 .70956 L p F P
0 g
s
.671 .125 0 r
.5634 .70956 m .56837 .71147 L .56411 .70796 L p F P
0 g
s
.366 0 .034 r
.48411 .64346 m .48541 .6417 L .49507 .64078 L p F P
0 g
s
.377 0 .049 r
.49663 .63871 m .49507 .64078 L .48541 .6417 L p F P
0 g
s
.295 0 .001 r
.48541 .6417 m .48411 .64346 L .47417 .64611 L p F P
0 g
s
.194 .039 .431 r
.41629 .70107 m .41984 .69787 L .41961 .7026 L p F P
0 g
s
.194 .039 .431 r
.41961 .7026 m .41611 .70575 L .41629 .70107 L p F P
0 g
s
.65 .757 .928 r
.26835 .48883 m .25908 .49204 L .26216 .495 L p F P
0 g
s
.65 .757 .928 r
.26216 .495 m .27143 .4918 L .26835 .48883 L p F P
0 g
s
.607 .096 .008 r
.55793 .63927 m .55027 .63808 L .55543 .64116 L p F P
0 g
s
.607 .096 .008 r
.55965 .64035 m .55793 .63927 L p .55543 .64116 L F P
0 g
s
.33 0 .064 r
.47295 .64803 m .47417 .64611 L .48411 .64346 L p F P
0 g
s
.242 0 .012 r
.47417 .64611 m .47295 .64803 L .4633 .65163 L p F P
0 g
s
.651 .758 .928 r
.72314 .48887 m .71303 .49209 L .71535 .49505 L p F P
0 g
s
.651 .758 .928 r
.71535 .49505 m .72545 .49184 L .72314 .48887 L p F P
0 g
s
.836 .38 .129 r
.60943 .66668 m .60543 .66446 L .60779 .66845 L p F P
0 g
s
.836 .38 .129 r
.60779 .66845 m .61181 .67068 L .60943 .66668 L p F P
0 g
s
.962 .777 .607 r
.63603 .7121 m .63837 .71471 L .63703 .71985 L p F P
0 g
s
.977 .739 .508 r
.63837 .71471 m .63603 .7121 L .63653 .7072 L p F P
0 g
s
.651 .757 .928 r
.41995 .4889 m .41039 .49212 L .41322 .49508 L p F P
0 g
s
.651 .757 .928 r
.41322 .49508 m .42277 .49187 L .41995 .4889 L p F P
0 g
s
.651 .757 .928 r
.57155 .48891 m .56171 .49213 L .56429 .49509 L p F P
0 g
s
.651 .757 .928 r
.56429 .49509 m .57411 .49188 L .57155 .48891 L p F P
0 g
s
.235 0 0 r
.46295 .65216 m .4633 .65163 L .47295 .64803 L p F P
0 g
s
0 0 0 r
.4762 .71456 m .48096 .71225 L p .47285 .71686 L F P
0 g
s
0 0 0 r
.48096 .71225 m .48173 .71162 L .4762 .71456 L closepath p F P
0 g
s
.631 .78 .953 r
.616 .73557 m .62592 .73283 L .62839 .73529 L p F P
0 g
s
.63 .774 .95 r
.62592 .73283 m .616 .73557 L .61352 .73299 L p F P
0 g
s
.751 .263 .077 r
.59016 .65278 m .59332 .6565 L .58835 .65454 L p F P
0 g
s
.751 .263 .077 r
.5891 .65236 m .59016 .65278 L p .58835 .65454 L F P
0 g
s
.65 .757 .928 r
.28073 .48859 m .27143 .4918 L .27449 .49477 L p F P
0 g
s
.65 .757 .928 r
.27449 .49477 m .28379 .49157 L .28073 .48859 L p F P
0 g
s
.651 .758 .928 r
.73559 .48862 m .72545 .49184 L .72775 .4948 L p F P
0 g
s
.651 .758 .928 r
.72775 .4948 m .73787 .49159 L .73559 .48862 L p F P
0 g
s
.651 .757 .928 r
.43235 .48866 m .42277 .49187 L .42558 .49483 L p F P
0 g
s
.651 .757 .928 r
.42558 .49483 m .43515 .49163 L .43235 .48866 L p F P
0 g
s
.651 .757 .928 r
.58397 .48866 m .57411 .49188 L .57666 .49484 L p F P
0 g
s
.651 .757 .928 r
.57666 .49484 m .58651 .49163 L .58397 .48866 L p F P
0 g
s
.52 .063 .107 r
.51582 .69991 m .51623 .69939 L .5179 .69983 L closepath p F P
0 g
s
.833 .827 .842 r
.63387 .72551 m .63592 .72818 L .62886 .73493 L p F P
0 g
s
.9 .843 .78 r
.63565 .7231 m .63387 .72551 L .63592 .72818 L p F P
0 g
s
.478 0 0 r
.58281 .71873 m .58514 .72024 L .586 .72077 L p F P
0 g
s
.65 .756 .927 r
.1415 .48813 m .13245 .49133 L .13575 .4943 L p F P
0 g
s
.65 .756 .927 r
.13575 .4943 m .14479 .49112 L .1415 .48813 L p F P
0 g
s
.185 .089 .504 r
.41448 .70755 m .41611 .70575 L .41639 .71085 L p F P
0 g
s
.185 .089 .504 r
.41639 .71085 m .41539 .71194 L .41448 .70755 L p F P
0 g
s
.167 0 .288 r
.42407 .68695 m .43117 .68178 L p .42854 .68717 L F P
0 g
s
.167 0 .288 r
.42854 .68717 m .42326 .69101 L .42407 .68695 L p F P
0 g
s
.068 0 .171 r
.43223 .67798 m .43117 .68178 L .42407 .68695 L p F P
0 g
s
.582 .117 .117 r
.52803 .69953 m .5286 .69887 L .53026 .69961 L closepath p F P
0 g
s
.532 .111 .186 r
.5286 .69887 m .52803 .69953 L .5179 .69983 L p F P
0 g
s
.451 .5 .819 r
.42228 .72961 m .41537 .7281 L .4188 .72372 L p F P
0 g
s
.503 .598 .882 r
.41537 .7281 m .42228 .72961 L .42431 .73269 L p F P
0 g
s
.796 .822 .872 r
.62886 .73493 m .62839 .73529 L .62592 .73283 L p F P
0 g
s
.187 0 .122 r
.44261 .66632 m .45086 .66212 L p .44225 .66915 L F P
0 g
s
.187 0 .122 r
.44225 .66915 m .44117 .6697 L .44261 .66632 L p F P
0 g
s
.13 0 .048 r
.45244 .65891 m .45086 .66212 L .44261 .66632 L p F P
0 g
s
.796 .822 .872 r
.62592 .73283 m .62661 .73231 L .62886 .73493 L p F P
0 g
s
.833 .827 .842 r
.62886 .73493 m .62661 .73231 L .63387 .72551 L p F P
0 g
s
.65 .757 .928 r
.29311 .48835 m .28379 .49157 L .28683 .49453 L p F P
0 g
s
.65 .757 .928 r
.28683 .49453 m .29615 .49133 L .29311 .48835 L p F P
0 g
s
.608 .13 .095 r
.54502 .70342 m .54099 .70125 L .54168 .70057 L p F P
0 g
s
.639 .168 .118 r
.54099 .70125 m .53951 .7003 L .54168 .70057 L closepath p F P
0 g
s
.651 .758 .928 r
.74803 .48836 m .73787 .49159 L .74015 .49455 L p F P
0 g
s
.651 .758 .928 r
.74015 .49455 m .7503 .49133 L .74803 .48836 L p F P
0 g
s
.651 .757 .928 r
.44475 .48841 m .43515 .49163 L .43794 .49459 L p F P
0 g
s
.651 .757 .928 r
.43794 .49459 m .44753 .49138 L .44475 .48841 L p F P
0 g
s
.651 .757 .928 r
.59639 .48841 m .58651 .49163 L .58904 .49459 L p F P
0 g
s
.651 .757 .928 r
.58904 .49459 m .59891 .49138 L .59639 .48841 L p F P
0 g
s
.7 .206 .068 r
.57554 .64558 m .5793 .6491 L .57344 .64738 L p F P
0 g
s
.7 .206 .068 r
.57394 .64511 m .57554 .64558 L p .57344 .64738 L F P
0 g
s
.422 0 .059 r
.49663 .63871 m .5056 .63752 L p .49812 .64086 L F P
0 g
s
.422 0 .059 r
.49812 .64086 m .49507 .64078 L .49663 .63871 L p F P
0 g
s
.65 .756 .927 r
.15386 .48792 m .14479 .49112 L .14807 .49409 L p F P
0 g
s
.65 .756 .927 r
.14807 .49409 m .15713 .4909 L .15386 .48792 L p F P
0 g
s
.859 .42 .163 r
.61559 .67296 m .61181 .67068 L .61388 .67477 L p F P
0 g
s
.859 .42 .163 r
.61388 .67477 m .61769 .67705 L .61559 .67296 L p F P
0 g
s
.751 .263 .077 r
.58835 .65454 m .58716 .65322 L .5891 .65236 L p F P
0 g
s
.735 .24 .059 r
.58716 .65322 m .58489 .6509 L .5891 .65236 L closepath p F P
0 g
s
0 .456 .824 r
.58655 .72096 m .59358 .72373 L .59005 .72144 L p F P
0 g
s
0 .456 .824 r
.58514 .72024 m .58655 .72096 L p .59005 .72144 L F P
0 g
s
.651 .758 .928 r
.76048 .4881 m .7503 .49133 L .75255 .49429 L p F P
0 g
s
.651 .758 .928 r
.75255 .49429 m .76272 .49108 L .76048 .4881 L p F P
0 g
s
.65 .757 .928 r
.30549 .48811 m .29615 .49133 L .29917 .49429 L p F P
0 g
s
.65 .757 .928 r
.29917 .49429 m .30851 .49109 L .30549 .48811 L p F P
0 g
s
.968 .726 .519 r
.63653 .7072 m .63398 .70463 L .63346 .70953 L p F P
0 g
s
.968 .726 .519 r
.63346 .70953 m .63603 .7121 L .63653 .7072 L p F P
0 g
s
.651 .757 .928 r
.60882 .48816 m .59891 .49138 L .60143 .49434 L p F P
0 g
s
.651 .757 .928 r
.60143 .49434 m .61132 .49113 L .60882 .48816 L p F P
0 g
s
.651 .757 .928 r
.45716 .48816 m .44753 .49138 L .4503 .49434 L p F P
0 g
s
.651 .757 .928 r
.4503 .49434 m .45991 .49114 L .45716 .48816 L p F P
0 g
s
.579 .08 .032 r
.53951 .7003 m .53026 .69961 L .53652 .70251 L p F P
0 g
s
.579 .08 .032 r
.54099 .70125 m .53951 .7003 L p .53652 .70251 L F P
0 g
s
.352 .666 .974 r
.60103 .72927 m .61032 .73035 L .60758 .72785 L p F P
0 g
s
.352 .666 .974 r
.60758 .72785 m .59852 .72697 L .60103 .72927 L p F P
0 g
s
0 .364 .807 r
.59677 .72612 m .59852 .72697 L .60103 .72927 L p F P
0 g
s
.65 .756 .927 r
.16622 .4877 m .15713 .4909 L .16039 .49387 L p F P
0 g
s
.65 .756 .927 r
.16039 .49387 m .16947 .49068 L .16622 .4877 L p F P
0 g
s
.29 0 .091 r
.46126 .65522 m .46295 .65216 L .47233 .64898 L p F P
0 g
s
.235 0 0 r
.47295 .64803 m .47233 .64898 L .46295 .65216 L p F P
0 g
s
.187 0 .029 r
.46295 .65216 m .46126 .65522 L .45244 .65891 L p F P
0 g
s
.651 .758 .928 r
.77293 .48785 m .76272 .49108 L .76496 .49404 L p F P
0 g
s
.651 .758 .928 r
.76496 .49404 m .77516 .49082 L .77293 .48785 L p F P
0 g
s
.65 .757 .928 r
.31788 .48787 m .30851 .49109 L .31151 .49405 L p F P
0 g
s
.65 .757 .928 r
.31151 .49405 m .32088 .49085 L .31788 .48787 L p F P
0 g
s
.625 .961 .88 r
.45674 .72427 m .44706 .72907 L .44988 .72953 L p F P
0 g
s
.625 .961 .88 r
.4581 .72409 m .45674 .72427 L p .44988 .72953 L F P
0 g
s
.625 .961 .88 r
.44988 .72953 m .4544 .7269 L .4581 .72409 L p F P
0 g
s
.694 .89 .969 r
.44988 .72953 m .44706 .72907 L .43918 .73264 L p F P
0 g
s
.651 .757 .928 r
.62125 .48791 m .61132 .49113 L .61381 .4941 L p F P
0 g
s
.651 .757 .928 r
.61381 .4941 m .62373 .49088 L .62125 .48791 L p F P
0 g
s
.651 .757 .928 r
.46957 .48792 m .45991 .49114 L .46266 .4941 L p F P
0 g
s
.651 .757 .928 r
.46266 .4941 m .4723 .49089 L .46957 .48792 L p F P
0 g
s
.236 0 .1 r
.45244 .65891 m .46126 .65522 L p .45239 .66148 L F P
0 g
s
.236 0 .1 r
.45239 .66148 m .45086 .66212 L .45244 .65891 L p F P
0 g
s
.7 .206 .068 r
.57344 .64738 m .57212 .64623 L .57394 .64511 L p F P
0 g
s
.68 .18 .05 r
.57212 .64623 m .5693 .64397 L .57394 .64511 L closepath p F P
0 g
s
.65 .757 .927 r
.17859 .48747 m .16947 .49068 L .17271 .49365 L p F P
0 g
s
.65 .757 .927 r
.17271 .49365 m .18182 .49045 L .17859 .48747 L p F P
0 g
s
.875 .448 .181 r
.62126 .67938 m .61769 .67705 L .61946 .68125 L p F P
0 g
s
.875 .448 .181 r
.62246 .68224 m .62126 .67938 L p .61946 .68125 L F P
0 g
s
.96 .668 .435 r
.63381 .69993 m .63104 .69741 L .6312 .70211 L p F P
0 g
s
.96 .668 .435 r
.6312 .70211 m .63398 .70463 L .63381 .69993 L p F P
0 g
s
.651 .758 .928 r
.78539 .48759 m .77516 .49082 L .77737 .49378 L p F P
0 g
s
.651 .758 .928 r
.77737 .49378 m .78759 .49056 L .78539 .48759 L p F P
0 g
s
.524 .071 .117 r
.51377 .70262 m .51582 .69991 L .5179 .69983 L p F P
0 g
s
.447 .02 .133 r
.51582 .69991 m .51377 .70262 L .51193 .70287 L p F P
0 g
s
.65 .757 .928 r
.33027 .48763 m .32088 .49085 L .32386 .49381 L p F P
0 g
s
.65 .757 .928 r
.32386 .49381 m .33325 .49061 L .33027 .48763 L p F P
0 g
s
.651 .757 .928 r
.63369 .48766 m .62373 .49088 L .6262 .49385 L p F P
0 g
s
.651 .757 .928 r
.6262 .49385 m .63615 .49063 L .63369 .48766 L p F P
0 g
s
.651 .757 .928 r
.48198 .48767 m .4723 .49089 L .47503 .49385 L p F P
0 g
s
.651 .757 .928 r
.47503 .49385 m .4847 .49064 L .48198 .48767 L p F P
0 g
s
.614 .129 .078 r
.55027 .63808 m .55543 .64116 L .54736 .64008 L p F P
0 g
s
.614 .129 .078 r
.54582 .63748 m .55027 .63808 L p .54736 .64008 L F P
0 g
s
.009 0 0 r
.48096 .71225 m .48173 .71162 L .49141 .70797 L p F P
0 g
s
.155 0 0 r
.49253 .7065 m .49141 .70797 L .48173 .71162 L p F P
0 g
s
.524 .071 .117 r
.5179 .69983 m .52596 .70197 L p .51377 .70262 L F P
0 g
s
.518 .049 .081 r
.52596 .70197 m .5179 .69983 L .52803 .69953 L closepath p F P
0 g
s
.354 .35 .716 r
.41402 .72042 m .41729 .71654 L .41924 .72319 L p F P
0 g
s
.354 .35 .716 r
.41924 .72319 m .4188 .72372 L .41402 .72042 L p F P
0 g
s
.656 .156 .05 r
.55793 .64154 m .55965 .64035 L .56265 .64248 L closepath p F P
0 g
s
.607 .096 .008 r
.55543 .64116 m .55793 .64154 L .55965 .64035 L p F P
0 g
s
.65 .757 .927 r
.19096 .48725 m .18182 .49045 L .18504 .49343 L p F P
0 g
s
.65 .757 .927 r
.18504 .49343 m .19417 .49023 L .19096 .48725 L p F P
0 g
s
.923 .552 .292 r
.62618 .68602 m .62298 .68359 L .62414 .68798 L p F P
0 g
s
.923 .552 .292 r
.62414 .68798 m .62734 .69041 L .62618 .68602 L p F P
0 g
s
.944 .608 .359 r
.63033 .69288 m .62734 .69041 L .62805 .69494 L p F P
0 g
s
.944 .608 .359 r
.62805 .69494 m .63104 .69741 L .63033 .69288 L p F P
0 g
s
.782 .305 .098 r
.59803 .65854 m .59332 .6565 L .59625 .66032 L p F P
0 g
s
.782 .305 .098 r
.59625 .66032 m .60101 .66234 L .59803 .65854 L p F P
0 g
s
.651 .758 .927 r
.79785 .48733 m .78759 .49056 L .78979 .49352 L p F P
0 g
s
.651 .758 .927 r
.78979 .49352 m .80003 .4903 L .79785 .48733 L p F P
0 g
s
.143 0 .344 r
.42116 .69283 m .42326 .69101 L .42274 .69536 L p F P
0 g
s
.143 0 .344 r
.42274 .69536 m .41984 .69787 L .42116 .69283 L p F P
0 g
s
.65 .757 .928 r
.34267 .48739 m .33325 .49061 L .33621 .49357 L p F P
0 g
s
.65 .757 .928 r
.33621 .49357 m .34562 .49037 L .34267 .48739 L p F P
0 g
s
.651 .757 .928 r
.64613 .48741 m .63615 .49063 L .6386 .4936 L p F P
0 g
s
.651 .757 .928 r
.6386 .4936 m .64856 .49038 L .64613 .48741 L p F P
0 g
s
.651 .757 .928 r
.4944 .48742 m .4847 .49064 L .4874 .49361 L p F P
0 g
s
.651 .757 .928 r
.4874 .49361 m .49709 .4904 L .4944 .48742 L p F P
0 g
s
.465 0 0 r
.58347 .71922 m .58281 .71873 L .58514 .72024 L closepath p F P
0 g
s
0 .456 .824 r
.59005 .72144 m .58347 .71922 L .58514 .72024 L p F P
0 g
s
.313 0 0 r
.49141 .70797 m .49253 .7065 L .50266 .7041 L p F P
0 g
s
.311 0 0 r
.50384 .70271 m .50266 .7041 L .49253 .7065 L p F P
0 g
s
.532 .065 .09 r
.53026 .69961 m .53652 .70251 L .52633 .70208 L p F P
0 g
s
.532 .065 .09 r
.52803 .69953 m .53026 .69961 L p .52633 .70208 L F P
0 g
s
.461 0 0 r
.57357 .71331 m .57889 .71654 L .57446 .71448 L p F P
0 g
s
.461 0 0 r
.56851 .71154 m .57357 .71331 L p .57446 .71448 L F P
0 g
s
.799 .317 .065 r
.60375 .66361 m .60471 .66347 L .60543 .66446 L closepath p F P
0 g
s
.763 .26 .014 r
.60101 .66234 m .60375 .66361 L .60471 .66347 L p F P
0 g
s
.65 .757 .927 r
.20333 .48702 m .19417 .49023 L .19737 .4932 L p F P
0 g
s
.65 .757 .927 r
.19737 .4932 m .20652 .49 L .20333 .48702 L p F P
0 g
s
.532 .065 .09 r
.52633 .70208 m .52596 .70197 L .52803 .69953 L p F P
0 g
s
.408 0 .02 r
.50266 .7041 m .50384 .70271 L .51193 .70287 L closepath p F P
0 g
s
.651 .758 .927 r
.81031 .48707 m .80003 .4903 L .8022 .49327 L p F P
0 g
s
.651 .758 .927 r
.8022 .49327 m .81247 .49004 L .81031 .48707 L p F P
0 g
s
.65 .757 .928 r
.35507 .48715 m .34562 .49037 L .34857 .49333 L p F P
0 g
s
.65 .757 .928 r
.34857 .49333 m .358 .49012 L .35507 .48715 L p F P
0 g
s
.651 .757 .928 r
.65857 .48716 m .64856 .49038 L .651 .49335 L p F P
0 g
s
.651 .757 .928 r
.651 .49335 m .66099 .49013 L .65857 .48716 L p F P
0 g
s
.651 .757 .928 r
.50682 .48717 m .49709 .4904 L .49978 .49336 L p F P
0 g
s
.651 .757 .928 r
.49978 .49336 m .50949 .49015 L .50682 .48717 L p F P
0 g
s
.695 .893 .969 r
.43742 .73345 m .43918 .73264 L .43812 .73377 L closepath p F P
0 g
s
.63 .962 .889 r
.4581 .72409 m .45955 .72393 L .4544 .7269 L closepath p F P
0 g
s
.532 .637 .899 r
.42505 .73371 m .42365 .73377 L .42431 .73269 L closepath p F P
0 g
s
.574 .031 0 r
.55844 .70626 m .5634 .70956 L .55756 .70789 L p F P
0 g
s
.574 .031 0 r
.5544 .70536 m .55844 .70626 L p .55756 .70789 L F P
0 g
s
.422 0 .059 r
.5056 .63752 m .50748 .63766 L p .49812 .64086 L F P
0 g
s
.441 0 .066 r
.50748 .63766 m .5056 .63752 L .50778 .63725 L closepath p F P
0 g
s
.65 .757 .927 r
.21571 .48679 m .20652 .49 L .2097 .49297 L p F P
0 g
s
.65 .757 .927 r
.2097 .49297 m .21888 .48977 L .21571 .48679 L p F P
0 g
s
.614 .129 .078 r
.54736 .64008 m .54467 .63855 L .54582 .63748 L p F P
0 g
s
.586 .096 .058 r
.54467 .63855 m .54176 .63714 L .54582 .63748 L closepath p F P
0 g
s
.651 .758 .927 r
.82277 .4868 m .81247 .49004 L .81462 .49301 L p F P
0 g
s
.651 .758 .927 r
.81462 .49301 m .82491 .48978 L .82277 .4868 L p F P
0 g
s
.65 .757 .928 r
.36747 .4869 m .358 .49012 L .36092 .49309 L p F P
0 g
s
.65 .757 .928 r
.36092 .49309 m .37038 .48988 L .36747 .4869 L p F P
0 g
s
.651 .757 .928 r
.67101 .48691 m .66099 .49013 L .6634 .4931 L p F P
0 g
s
.651 .757 .928 r
.6634 .4931 m .67341 .48988 L .67101 .48691 L p F P
0 g
s
.938 .801 .683 r
.63703 .71985 m .63565 .7231 L .6332 .72069 L p F P
0 g
s
.938 .801 .683 r
.6332 .72069 m .63467 .71724 L .63703 .71985 L p F P
0 g
s
.962 .777 .607 r
.63703 .71985 m .63467 .71724 L .63603 .7121 L p F P
0 g
s
.605 .111 .053 r
.53916 .70274 m .54099 .70125 L .54502 .70342 L closepath p F P
0 g
s
.579 .08 .032 r
.53652 .70251 m .53916 .70274 L .54099 .70125 L p F P
0 g
s
.651 .757 .928 r
.51924 .48693 m .50949 .49015 L .51216 .49312 L p F P
0 g
s
.651 .757 .928 r
.51216 .49312 m .5219 .4899 L .51924 .48693 L p F P
0 g
s
.65 .757 .927 r
.22809 .48655 m .21888 .48977 L .22204 .49274 L p F P
0 g
s
.65 .757 .927 r
.22204 .49274 m .23124 .48954 L .22809 .48655 L p F P
0 g
s
.488 .031 .093 r
.50778 .63725 m .51964 .63648 L p .51556 .63912 L F P
0 g
s
.488 .031 .093 r
.51556 .63912 m .50748 .63766 L .50778 .63725 L p F P
0 g
s
.466 0 .029 r
.51987 .63625 m .51964 .63648 L .50778 .63725 L p F P
0 g
s
.65 .757 .928 r
.37988 .48666 m .37038 .48988 L .37329 .49285 L p F P
0 g
s
.65 .757 .928 r
.37329 .49285 m .38277 .48964 L .37988 .48666 L p F P
0 g
s
.651 .757 .928 r
.68346 .48665 m .67341 .48988 L .6758 .49285 L p F P
0 g
s
.651 .757 .928 r
.6758 .49285 m .68584 .48963 L .68346 .48665 L p F P
0 g
s
.651 .757 .928 r
.53167 .48668 m .5219 .4899 L .52454 .49287 L p F P
0 g
s
.651 .757 .928 r
.52454 .49287 m .5343 .48966 L .53167 .48668 L p F P
0 g
s
.713 .211 .043 r
.58489 .6509 m .5793 .6491 L .58286 .65271 L p F P
0 g
s
.713 .211 .043 r
.58716 .65322 m .58489 .6509 L p .58286 .65271 L F P
0 g
s
.565 .07 .038 r
.54176 .63714 m .53229 .63649 L .53832 .63929 L p F P
0 g
s
.565 .07 .038 r
.54467 .63855 m .54176 .63714 L p .53832 .63929 L F P
0 g
s
.658 .152 .032 r
.5693 .64397 m .56265 .64248 L .56691 .64585 L p F P
0 g
s
.658 .152 .032 r
.57212 .64623 m .5693 .64397 L p .56691 .64585 L F P
0 g
s
.268 .15 .527 r
.41611 .70575 m .41961 .7026 L .42076 .70693 L p F P
0 g
s
.268 .15 .527 r
.42076 .70693 m .41639 .71085 L .41611 .70575 L p F P
0 g
s
.65 .757 .927 r
.24048 .48632 m .23124 .48954 L .23438 .49251 L p F P
0 g
s
.65 .757 .927 r
.23438 .49251 m .24361 .4893 L .24048 .48632 L p F P
0 g
s
.57 .654 .893 r
.43181 .72864 m .43461 .73144 L .42505 .73371 L p F P
0 g
s
.57 .654 .893 r
.42805 .72912 m .43181 .72864 L p .42505 .73371 L F P
0 g
s
.57 .654 .893 r
.42505 .73371 m .42431 .73269 L .42805 .72912 L p F P
0 g
s
.651 .757 .928 r
.69591 .4864 m .68584 .48963 L .68821 .4926 L p F P
0 g
s
.651 .757 .928 r
.68821 .4926 m .69827 .48938 L .69591 .4864 L p F P
0 g
s
.65 .757 .928 r
.39229 .48641 m .38277 .48964 L .38565 .4926 L p F P
0 g
s
.65 .757 .928 r
.38565 .4926 m .39516 .48939 L .39229 .48641 L p F P
0 g
s
.824 .373 .159 r
.60543 .66446 m .60779 .66845 L .60354 .66629 L p F P
0 g
s
.824 .373 .159 r
.60375 .66361 m .60543 .66446 L p .60354 .66629 L F P
0 g
s
.651 .757 .928 r
.5441 .48643 m .5343 .48966 L .53693 .49262 L p F P
0 g
s
.651 .757 .928 r
.53693 .49262 m .54671 .48941 L .5441 .48643 L p F P
0 g
s
.498 .004 .013 r
.51964 .63648 m .51987 .63625 L .52071 .63647 L closepath p F P
0 g
s
.683 .912 .974 r
.44424 .72796 m .43461 .73144 L .43742 .73345 L p F P
0 g
s
.683 .912 .974 r
.44452 .72806 m .44424 .72796 L p .43742 .73345 L F P
0 g
s
.683 .912 .974 r
.43742 .73345 m .43918 .73264 L .44452 .72806 L p F P
0 g
s
.65 .757 .927 r
.25287 .48608 m .24361 .4893 L .24673 .49228 L p F P
0 g
s
.65 .757 .927 r
.24673 .49228 m .25598 .48907 L .25287 .48608 L p F P
0 g
s
0 .367 .797 r
.59852 .72697 m .59677 .72612 L .59358 .72373 L p F P
0 g
s
.481 .888 .756 r
.46924 .71857 m .45955 .72393 L p .46865 .71886 L F P
0 g
s
.481 .888 .756 r
.46967 .71829 m .46924 .71857 L p .46865 .71886 L F P
0 g
s
0 0 0 r
.46924 .71857 m .47279 .71689 L .47615 .7154 L F
.47814 .71435 m .47615 .7154 L p .47279 .71689 L F P
0 g
s
0 0 0 r
.47615 .7154 m .47814 .71435 L .48745 .71115 L p F P
0 g
s
0 0 0 r
.48588 .71209 m .47615 .7154 L p .48345 .71266 L F P
0 g
s
0 0 0 r
.48745 .71115 m .48588 .71209 L p .48345 .71266 L F P
0 g
s
0 0 0 r
.48588 .71209 m .49564 .70975 L p .48869 .71142 L F P
0 g
s
0 0 0 r
.48392 .71258 m .48588 .71209 L p .48869 .71142 L F P
0 g
s
.324 .808 .778 r
.47615 .7154 m .48588 .71209 L p .47775 .71468 L F P
0 g
s
0 0 0 r
.48096 .71225 m .47894 .71396 L .47285 .71686 L p F P
0 g
s
0 0 0 r
.46924 .71857 m .47285 .71686 L .47814 .71435 L p F P
0 g
s
0 0 0 r
.47814 .71435 m .47894 .71396 L .47285 .71686 L closepath p F P
0 g
s
.324 .808 .778 r
.47451 .71572 m .47615 .7154 L p .47775 .71468 L F P
0 g
s
0 0 0 r
.47615 .7154 m .47366 .71647 L p .46924 .71857 L F P
0 g
s
0 0 0 r
.46924 .71857 m .47285 .71686 L .46967 .71829 L closepath p F P
0 g
s
0 0 0 r
.47366 .71647 m .46644 .71957 L .46924 .71857 L p F P
0 g
s
.542 .927 .879 r
.45955 .72393 m .46924 .71857 L p .46398 .72076 L F P
0 g
s
.542 .927 .879 r
.46398 .72076 m .4581 .72409 L .45955 .72393 L p F P
0 g
s
.651 .757 .928 r
.70837 .48615 m .69827 .48938 L .70062 .49235 L p F P
0 g
s
.651 .757 .928 r
.70062 .49235 m .71071 .48913 L .70837 .48615 L p F P
0 g
s
.193 0 .231 r
.43223 .67798 m .43607 .67564 L .43129 .6817 L p F P
0 g
s
.193 0 .231 r
.43129 .6817 m .43117 .68178 L .43223 .67798 L p F P
0 g
s
.65 .757 .928 r
.4047 .48617 m .39516 .48939 L .39802 .49236 L p F P
0 g
s
.65 .757 .928 r
.39802 .49236 m .40755 .48915 L .4047 .48617 L p F P
0 g
s
.651 .757 .928 r
.55654 .48618 m .54671 .48941 L .54932 .49237 L p F P
0 g
s
.651 .757 .928 r
.54932 .49237 m .55913 .48916 L .55654 .48618 L p F P
0 g
s
.317 .625 .96 r
.61352 .73299 m .6129 .73289 L .61032 .73035 L p F P
0 g
s
.036 0 0 r
.47894 .71396 m .48096 .71225 L .49022 .70903 L p F P
0 g
s
.009 0 0 r
.49141 .70797 m .49022 .70903 L .48096 .71225 L p F P
0 g
s
.574 .031 0 r
.55756 .70789 m .55341 .70578 L .5544 .70536 L p F P
0 g
s
.662 .143 0 r
.55341 .70578 m .55203 .70476 L .5544 .70536 L closepath p F P
0 g
s
.486 .026 .085 r
.50578 .63986 m .50748 .63766 L .51556 .63912 L closepath p F P
0 g
s
.422 0 .059 r
.50748 .63766 m .50578 .63986 L .49812 .64086 L p F P
0 g
s
.39 0 .091 r
.48411 .64346 m .49463 .64135 L p .48669 .64541 L F P
0 g
s
.39 0 .091 r
.48669 .64541 m .48261 .64579 L .48411 .64346 L p F P
0 g
s
.366 0 .034 r
.49507 .64078 m .49463 .64135 L .48411 .64346 L p F P
0 g
s
.33 0 .064 r
.48411 .64346 m .48261 .64579 L .47295 .64803 L p F P
0 g
s
.321 0 .05 r
.47233 .64898 m .47295 .64803 L .48261 .64579 L p F P
0 g
s
.65 .757 .928 r
.26527 .48585 m .25598 .48907 L .25908 .49204 L p F P
0 g
s
.65 .757 .928 r
.25908 .49204 m .26835 .48883 L .26527 .48585 L p F P
0 g
s
.651 .758 .928 r
.72083 .48589 m .71071 .48913 L .71303 .49209 L p F P
0 g
s
.651 .758 .928 r
.71303 .49209 m .72314 .48887 L .72083 .48589 L p F P
0 g
s
.651 .757 .928 r
.41712 .48592 m .40755 .48915 L .41039 .49212 L p F P
0 g
s
.651 .757 .928 r
.41039 .49212 m .41995 .4889 L .41712 .48592 L p F P
0 g
s
.651 .757 .928 r
.56897 .48593 m .55913 .48916 L .56171 .49213 L p F P
0 g
s
.651 .757 .928 r
.56171 .49213 m .57155 .48891 L .56897 .48593 L p F P
0 g
s
.542 .038 .01 r
.53225 .63649 m .53226 .63648 L .53229 .63649 L closepath p F P
0 g
s
.5 .01 .024 r
.53226 .63648 m .53225 .63649 L .52071 .63647 L p F P
0 g
s
.886 .824 .781 r
.63387 .72551 m .63565 .7231 L .6332 .72069 L p F P
0 g
s
.953 .763 .61 r
.63603 .7121 m .63346 .70953 L .63211 .71468 L p F P
0 g
s
.953 .763 .61 r
.63211 .71468 m .63467 .71724 L .63603 .7121 L p F P
0 g
s
.583 .11 .098 r
.53229 .63649 m .53225 .63649 L .53009 .63887 L p F P
0 g
s
.583 .11 .098 r
.53009 .63887 m .53832 .63929 L .53229 .63649 L p F P
0 g
s
.532 .053 .064 r
.53225 .63649 m .52071 .63647 L .52807 .63886 L p F P
0 g
s
.532 .053 .064 r
.52807 .63886 m .53009 .63887 L .53225 .63649 L p F P
0 g
s
.537 .071 .095 r
.52071 .63647 m .51964 .63648 L .51756 .63899 L p F P
0 g
s
.488 .031 .093 r
.51964 .63648 m .51756 .63899 L .51556 .63912 L p F P
0 g
s
.537 .071 .095 r
.51756 .63899 m .52807 .63886 L .52071 .63647 L p F P
0 g
s
.557 .631 .88 r
.42805 .72912 m .42431 .73269 L .42228 .72961 L closepath p F P
0 g
s
.682 .908 .974 r
.44452 .72806 m .44706 .72907 L .43918 .73264 L closepath p F P
0 g
s
.63 .774 .95 r
.61352 .73299 m .62345 .7303 L .62592 .73283 L p F P
0 g
s
.631 .77 .947 r
.62096 .7277 m .61102 .73047 L .61352 .73299 L p F P
0 g
s
.631 .77 .947 r
.61352 .73299 m .62345 .7303 L .62096 .7277 L p F P
0 g
s
.317 .625 .96 r
.61032 .73035 m .61102 .73047 L .61352 .73299 L p F P
0 g
s
.265 .201 .596 r
.41694 .71471 m .41539 .71194 L .41639 .71085 L closepath p F P
0 g
s
.264 .22 .62 r
.41539 .71194 m .41694 .71471 L .41729 .71654 L p F P
0 g
s
.65 .757 .928 r
.27766 .48561 m .26835 .48883 L .27143 .4918 L p F P
0 g
s
.65 .757 .928 r
.27143 .4918 m .28073 .48859 L .27766 .48561 L p F P
0 g
s
.895 .487 .218 r
.62125 .68239 m .62246 .68224 L .62298 .68359 L closepath p F P
0 g
s
.875 .448 .181 r
.61946 .68125 m .62125 .68239 L .62246 .68224 L p F P
0 g
s
.651 .758 .928 r
.73329 .48564 m .72314 .48887 L .72545 .49184 L p F P
0 g
s
.651 .758 .928 r
.72545 .49184 m .73559 .48862 L .73329 .48564 L p F P
0 g
s
.855 .424 .196 r
.61181 .67068 m .60779 .66845 L .60985 .67256 L p F P
0 g
s
.855 .424 .196 r
.60985 .67256 m .61388 .67477 L .61181 .67068 L p F P
0 g
s
.651 .757 .928 r
.42954 .48568 m .41995 .4889 L .42277 .49187 L p F P
0 g
s
.651 .757 .928 r
.42277 .49187 m .43235 .48866 L .42954 .48568 L p F P
0 g
s
.651 .757 .928 r
.58142 .48568 m .57155 .48891 L .57411 .49188 L p F P
0 g
s
.651 .757 .928 r
.57411 .49188 m .58397 .48866 L .58142 .48568 L p F P
0 g
s
.521 0 0 r
.58347 .71922 m .58281 .71873 L .57889 .71654 L p F P
0 g
s
.83 .821 .84 r
.63155 .72289 m .63387 .72551 L .62661 .73231 L p F P
0 g
s
.886 .824 .781 r
.6332 .72069 m .63155 .72289 L .63387 .72551 L p F P
0 g
s
.793 .817 .871 r
.62661 .73231 m .62592 .73283 L .62345 .7303 L p F P
0 g
s
.824 .373 .159 r
.60354 .66629 m .60228 .66425 L .60375 .66361 L p F P
0 g
s
.811 .352 .143 r
.60228 .66425 m .60101 .66234 L .60375 .66361 L closepath p F P
0 g
s
.65 .757 .928 r
.29006 .48537 m .28073 .48859 L .28379 .49157 L p F P
0 g
s
.65 .757 .928 r
.28379 .49157 m .29311 .48835 L .29006 .48537 L p F P
0 g
s
.651 .758 .928 r
.74576 .48538 m .73559 .48862 L .73787 .49159 L p F P
0 g
s
.651 .758 .928 r
.73787 .49159 m .74803 .48836 L .74576 .48538 L p F P
0 g
s
.651 .757 .928 r
.44196 .48543 m .43235 .48866 L .43515 .49163 L p F P
0 g
s
.651 .757 .928 r
.43515 .49163 m .44475 .48841 L .44196 .48543 L p F P
0 g
s
.793 .817 .871 r
.62345 .7303 m .62421 .72973 L .62661 .73231 L p F P
0 g
s
.83 .821 .84 r
.62661 .73231 m .62421 .72973 L .63155 .72289 L p F P
0 g
s
.651 .757 .928 r
.59386 .48543 m .58397 .48866 L .58651 .49163 L p F P
0 g
s
.651 .757 .928 r
.58651 .49163 m .59639 .48841 L .59386 .48543 L p F P
0 g
s
.227 .018 .374 r
.42326 .69101 m .42854 .68717 L .42695 .6923 L p F P
0 g
s
.227 .018 .374 r
.42695 .6923 m .42274 .69536 L .42326 .69101 L p F P
0 g
s
.598 .055 0 r
.55203 .70476 m .54502 .70342 L .55053 .70656 L p F P
0 g
s
.598 .055 0 r
.55341 .70578 m .55203 .70476 L p .55053 .70656 L F P
0 g
s
.213 .054 .438 r
.41984 .69787 m .42274 .69536 L .42257 .70004 L p F P
0 g
s
.213 .054 .438 r
.42257 .70004 m .41961 .7026 L .41984 .69787 L p F P
0 g
s
.65 .756 .927 r
.15057 .48492 m .1415 .48813 L .14479 .49112 L p F P
0 g
s
.65 .756 .927 r
.14479 .49112 m .15386 .48792 L .15057 .48492 L p F P
0 g
s
.461 0 0 r
.57446 .71448 m .56843 .71152 L .56851 .71154 L p F P
0 g
s
.654 .098 0 r
.56843 .71152 m .56837 .71147 L .56851 .71154 L closepath p F P
0 g
s
.782 .316 .134 r
.59332 .6565 m .58835 .65454 L .59125 .65836 L p F P
0 g
s
.782 .316 .134 r
.59125 .65836 m .59625 .66032 L .59332 .6565 L p F P
0 g
s
.957 .713 .527 r
.63398 .70463 m .6312 .70211 L .63069 .70702 L p F P
0 g
s
.957 .713 .527 r
.63069 .70702 m .63346 .70953 L .63398 .70463 L p F P
0 g
s
.65 .757 .928 r
.30247 .48513 m .29311 .48835 L .29615 .49133 L p F P
0 g
s
.65 .757 .928 r
.29615 .49133 m .30549 .48811 L .30247 .48513 L p F P
0 g
s
.651 .758 .928 r
.75823 .48512 m .74803 .48836 L .7503 .49133 L p F P
0 g
s
.651 .758 .928 r
.7503 .49133 m .76048 .4881 L .75823 .48512 L p F P
0 g
s
.651 .757 .928 r
.45439 .48518 m .44475 .48841 L .44753 .49138 L p F P
0 g
s
.651 .757 .928 r
.44753 .49138 m .45716 .48816 L .45439 .48518 L p F P
0 g
s
.651 .757 .928 r
.60631 .48518 m .59639 .48841 L .59891 .49138 L p F P
0 g
s
.651 .757 .928 r
.59891 .49138 m .60882 .48816 L .60631 .48518 L p F P
0 g
s
.673 .129 0 r
.56843 .71152 m .56837 .71147 L .5634 .70956 L p F P
0 g
s
.876 .465 .237 r
.61769 .67705 m .61388 .67477 L .61562 .67899 L p F P
0 g
s
.876 .465 .237 r
.61562 .67899 m .61946 .68125 L .61769 .67705 L p F P
0 g
s
.388 0 0 r
.56843 .71152 m .57446 .71448 L .56933 .71261 L p F P
0 g
s
.388 0 0 r
.56933 .71261 m .56589 .71128 L .56843 .71152 L p F P
0 g
s
.673 .129 0 r
.5634 .70956 m .56589 .71128 L .56843 .71152 L p F P
0 g
s
.65 .756 .927 r
.16296 .4847 m .15386 .48792 L .15713 .4909 L p F P
0 g
s
.65 .756 .927 r
.15713 .4909 m .16622 .4877 L .16296 .4847 L p F P
0 g
s
0 .498 .837 r
.58347 .71922 m .59005 .72144 L .58608 .71926 L p F P
0 g
s
.521 0 0 r
.58095 .71785 m .58347 .71922 L p .58287 .71886 L F P
0 g
s
.521 0 0 r
.57889 .71654 m .58095 .71785 L p .58287 .71886 L F P
0 g
s
.033 .556 .863 r
.58151 .71724 m .57872 .71668 L p .58095 .71785 L F P
0 g
s
.507 0 0 r
.57841 .71662 m .58095 .71785 L p .58065 .7177 L F P
0 g
s
.507 0 0 r
.57446 .71448 m .57841 .71662 L p .58065 .7177 L F P
0 g
s
.507 0 0 r
.58095 .71785 m .57889 .71654 L .57446 .71448 L p F P
0 g
s
.485 0 0 r
.57841 .71662 m .57446 .71448 L .56933 .71261 L p F P
0 g
s
.123 .627 .902 r
.57841 .71662 m .58151 .71724 L .57608 .7155 L p F P
0 g
s
.123 .627 .902 r
.57608 .7155 m .57601 .71547 L p .57841 .71662 L F P
0 g
s
.033 .556 .863 r
.57872 .71668 m .57841 .71662 L .58095 .71785 L p F P
0 g
s
0 .498 .837 r
.58608 .71926 m .58095 .71785 L .58347 .71922 L p F P
0 g
s
.651 .758 .928 r
.7707 .48486 m .76048 .4881 L .76272 .49108 L p F P
0 g
s
.651 .758 .928 r
.76272 .49108 m .77293 .48785 L .7707 .48486 L p F P
0 g
s
.65 .757 .928 r
.31488 .48489 m .30549 .48811 L .30851 .49109 L p F P
0 g
s
.65 .757 .928 r
.30851 .49109 m .31788 .48787 L .31488 .48489 L p F P
0 g
s
.361 .686 .98 r
.59852 .72697 m .60758 .72785 L .60466 .72539 L p F P
0 g
s
.361 .686 .98 r
.60466 .72539 m .596 .72481 L .59852 .72697 L p F P
0 g
s
0 .367 .797 r
.59358 .72373 m .596 .72481 L .59852 .72697 L p F P
0 g
s
.651 .757 .928 r
.61876 .48493 m .60882 .48816 L .61132 .49113 L p F P
0 g
s
.651 .757 .928 r
.61132 .49113 m .62125 .48791 L .61876 .48493 L p F P
0 g
s
.651 .757 .928 r
.46682 .48493 m .45716 .48816 L .45991 .49114 L p F P
0 g
s
.651 .757 .928 r
.45991 .49114 m .46957 .48792 L .46682 .48493 L p F P
0 g
s
.67 .196 .119 r
.56265 .64248 m .56691 .64585 L .55991 .64446 L p F P
0 g
s
.67 .196 .119 r
.55793 .64154 m .56265 .64248 L p .55991 .64446 L F P
0 g
s
.95 .657 .448 r
.63104 .69741 m .62805 .69494 L .6282 .69964 L p F P
0 g
s
.95 .657 .448 r
.6282 .69964 m .6312 .70211 L .63104 .69741 L p F P
0 g
s
.203 0 0 r
.49022 .70903 m .49141 .70797 L .50112 .70599 L p F P
0 g
s
.313 0 0 r
.50266 .7041 m .50112 .70599 L .49141 .70797 L p F P
0 g
s
.65 .757 .927 r
.17535 .48448 m .16622 .4877 L .16947 .49068 L p F P
0 g
s
.65 .757 .927 r
.16947 .49068 m .17859 .48747 L .17535 .48448 L p F P
0 g
s
.91 .539 .312 r
.62298 .68359 m .62414 .68798 L .62071 .68561 L p F P
0 g
s
.91 .539 .312 r
.62125 .68239 m .62298 .68359 L p .62071 .68561 L F P
0 g
s
.651 .758 .928 r
.78318 .48461 m .77293 .48785 L .77516 .49082 L p F P
0 g
s
.651 .758 .928 r
.77516 .49082 m .78539 .48759 L .78318 .48461 L p F P
0 g
s
.418 0 .046 r
.49463 .64135 m .49507 .64078 L .49812 .64086 L closepath p F P
0 g
s
.65 .757 .928 r
.32729 .48465 m .31788 .48787 L .32088 .49085 L p F P
0 g
s
.65 .757 .928 r
.32088 .49085 m .33027 .48763 L .32729 .48465 L p F P
0 g
s
.651 .757 .928 r
.63122 .48468 m .62125 .48791 L .62373 .49088 L p F P
0 g
s
.651 .757 .928 r
.62373 .49088 m .63369 .48766 L .63122 .48468 L p F P
0 g
s
.935 .601 .376 r
.62734 .69041 m .62414 .68798 L .62484 .69252 L p F P
0 g
s
.935 .601 .376 r
.62484 .69252 m .62805 .69494 L .62734 .69041 L p F P
0 g
s
.651 .757 .928 r
.47925 .48469 m .46957 .48792 L .4723 .49089 L p F P
0 g
s
.651 .757 .928 r
.4723 .49089 m .48198 .48767 L .47925 .48469 L p F P
0 g
s
.729 .252 .114 r
.5793 .6491 m .57344 .64738 L .57695 .651 L p F P
0 g
s
.729 .252 .114 r
.57695 .651 m .58286 .65271 L .5793 .6491 L p F P
0 g
s
.377 0 .012 r
.50266 .7041 m .51193 .70287 L p .50667 .70573 L F P
0 g
s
.377 0 .012 r
.50667 .70573 m .50112 .70599 L .50266 .7041 L p F P
0 g
s
.246 0 .216 r
.44097 .67032 m .44225 .66915 L .44117 .6697 L closepath p F P
0 g
s
.145 0 .158 r
.44117 .6697 m .44097 .67032 L .43607 .67564 L p F P
0 g
s
.65 .757 .927 r
.18774 .48425 m .17859 .48747 L .18182 .49045 L p F P
0 g
s
.65 .757 .927 r
.18182 .49045 m .19096 .48725 L .18774 .48425 L p F P
0 g
s
.362 0 .126 r
.47065 .65204 m .47233 .64898 L .48227 .64631 L p F P
0 g
s
.321 0 .05 r
.48261 .64579 m .48227 .64631 L .47233 .64898 L p F P
0 g
s
.29 0 .091 r
.47233 .64898 m .47065 .65204 L .46126 .65522 L p F P
0 g
s
.651 .758 .927 r
.79566 .48434 m .78539 .48759 L .78759 .49056 L p F P
0 g
s
.651 .758 .927 r
.78759 .49056 m .79785 .48733 L .79566 .48434 L p F P
0 g
s
.358 .291 .644 r
.41639 .71085 m .42076 .70693 L .42363 .71077 L p F P
0 g
s
.358 .291 .644 r
.41694 .71471 m .41639 .71085 L p .42363 .71077 L F P
0 g
s
.65 .757 .928 r
.33971 .4844 m .33027 .48763 L .33325 .49061 L p F P
0 g
s
.65 .757 .928 r
.33325 .49061 m .34267 .48739 L .33971 .4844 L p F P
0 g
s
.651 .757 .928 r
.64368 .48443 m .63369 .48766 L .63615 .49063 L p F P
0 g
s
.651 .757 .928 r
.63615 .49063 m .64613 .48741 L .64368 .48443 L p F P
0 g
s
.651 .757 .928 r
.49169 .48444 m .48198 .48767 L .4847 .49064 L p F P
0 g
s
.651 .757 .928 r
.4847 .49064 m .4944 .48742 L .49169 .48444 L p F P
0 g
s
.613 .127 .074 r
.54348 .63964 m .54467 .63855 L .54736 .64008 L closepath p F P
0 g
s
.565 .07 .038 r
.53832 .63929 m .54348 .63964 L .54467 .63855 L p F P
0 g
s
.542 .927 .879 r
.46924 .71857 m .46644 .71957 L .46398 .72076 L p F P
0 g
s
.751 .265 .084 r
.5861 .65372 m .58716 .65322 L .58835 .65454 L closepath p F P
0 g
s
.713 .211 .043 r
.58286 .65271 m .5861 .65372 L .58716 .65322 L p F P
0 g
s
.555 .64 .89 r
.42228 .72961 m .41955 .72402 L p .43032 .72664 L F P
0 g
s
.555 .64 .89 r
.43032 .72664 m .42805 .72912 L .42228 .72961 L p F P
0 g
s
.451 .5 .819 r
.4188 .72372 m .41955 .72402 L .42228 .72961 L p F P
0 g
s
.65 .757 .927 r
.20013 .48402 m .19096 .48725 L .19417 .49023 L p F P
0 g
s
.65 .757 .927 r
.19417 .49023 m .20333 .48702 L .20013 .48402 L p F P
0 g
s
.651 .758 .927 r
.80814 .48408 m .79785 .48733 L .80003 .4903 L p F P
0 g
s
.651 .758 .927 r
.80003 .4903 m .81031 .48707 L .80814 .48408 L p F P
0 g
s
.65 .757 .928 r
.35213 .48416 m .34267 .48739 L .34562 .49037 L p F P
0 g
s
.65 .757 .928 r
.34562 .49037 m .35507 .48715 L .35213 .48416 L p F P
0 g
s
.651 .757 .928 r
.65614 .48417 m .64613 .48741 L .64856 .49038 L p F P
0 g
s
.651 .757 .928 r
.64856 .49038 m .65857 .48716 L .65614 .48417 L p F P
0 g
s
.651 .757 .928 r
.50413 .48419 m .4944 .48742 L .49709 .4904 L p F P
0 g
s
.651 .757 .928 r
.49709 .4904 m .50682 .48717 L .50413 .48419 L p F P
0 g
s
.57 .02 0 r
.55103 .70666 m .55341 .70578 L .55756 .70789 L closepath p F P
0 g
s
.598 .055 0 r
.55053 .70656 m .55103 .70666 L .55341 .70578 L p F P
0 g
s
.792 .328 .135 r
.60101 .66234 m .59625 .66032 L .59892 .66422 L p F P
0 g
s
.792 .328 .135 r
.60228 .66425 m .60101 .66234 L p .59892 .66422 L F P
0 g
s
.65 .757 .927 r
.21253 .48379 m .20333 .48702 L .20652 .49 L p F P
0 g
s
.65 .757 .927 r
.20652 .49 m .21571 .48679 L .21253 .48379 L p F P
0 g
s
.7 .207 .071 r
.57122 .64679 m .57212 .64623 L .57344 .64738 L closepath p F P
0 g
s
.658 .152 .032 r
.56691 .64585 m .57122 .64679 L .57212 .64623 L p F P
0 g
s
.651 .758 .927 r
.82063 .48382 m .81031 .48707 L .81247 .49004 L p F P
0 g
s
.651 .758 .927 r
.81247 .49004 m .82277 .4868 L .82063 .48382 L p F P
0 g
s
.242 0 .212 r
.43996 .67334 m .44097 .67032 L .44225 .66915 L p F P
0 g
s
.175 0 .183 r
.43996 .67334 m .44097 .67032 L .43607 .67564 L closepath p F P
0 g
s
.242 0 .212 r
.44225 .66915 m .4495 .66557 L p .43996 .67334 L F P
0 g
s
.217 0 .154 r
.4495 .66557 m .4507 .66252 L .44225 .66915 L closepath p F P
0 g
s
.187 0 .122 r
.45086 .66212 m .4507 .66252 L .44225 .66915 L p F P
0 g
s
.65 .757 .928 r
.36455 .48391 m .35507 .48715 L .358 .49012 L p F P
0 g
s
.65 .757 .928 r
.358 .49012 m .36747 .4869 L .36455 .48391 L p F P
0 g
s
.651 .757 .928 r
.66861 .48392 m .65857 .48716 L .66099 .49013 L p F P
0 g
s
.651 .757 .928 r
.66099 .49013 m .67101 .48691 L .66861 .48392 L p F P
0 g
s
.651 .757 .928 r
.51658 .48394 m .50682 .48717 L .50949 .49015 L p F P
0 g
s
.651 .757 .928 r
.50949 .49015 m .51924 .48693 L .51658 .48394 L p F P
0 g
s
.929 .788 .683 r
.6332 .72069 m .63467 .71724 L .63211 .71468 L p F P
0 g
s
.67 .196 .119 r
.55991 .64446 m .55711 .64231 L .55793 .64154 L p F P
0 g
s
.647 .168 .101 r
.55711 .64231 m .55543 .64116 L .55793 .64154 L closepath p F P
0 g
s
.533 .924 .868 r
.45674 .72427 m .46398 .72076 L .4581 .72409 L closepath p F P
0 g
s
.661 .903 .98 r
.44706 .72907 m .45674 .72427 L p .44534 .72749 L F P
0 g
s
.661 .903 .98 r
.44534 .72749 m .44452 .72806 L .44706 .72907 L p F P
0 g
s
.553 .051 .017 r
.54502 .70342 m .55053 .70656 L .5432 .7053 L p F P
0 g
s
.553 .051 .017 r
.53916 .70274 m .54502 .70342 L p .5432 .7053 L F P
0 g
s
.29 0 .19 r
.4507 .66252 m .45239 .66148 L .45086 .66212 L closepath p F P
0 g
s
.326 0 .155 r
.4604 .65706 m .46126 .65522 L .47065 .65204 L p F P
0 g
s
.236 0 .1 r
.46126 .65522 m .4604 .65706 L .45239 .66148 L p F P
0 g
s
.65 .757 .927 r
.22494 .48356 m .21571 .48679 L .21888 .48977 L p F P
0 g
s
.65 .757 .927 r
.21888 .48977 m .22809 .48655 L .22494 .48356 L p F P
0 g
s
.65 .757 .928 r
.37698 .48367 m .36747 .4869 L .37038 .48988 L p F P
0 g
s
.65 .757 .928 r
.37038 .48988 m .37988 .48666 L .37698 .48367 L p F P
0 g
s
.651 .757 .928 r
.68108 .48367 m .67101 .48691 L .67341 .48988 L p F P
0 g
s
.651 .757 .928 r
.67341 .48988 m .68346 .48665 L .68108 .48367 L p F P
0 g
s
.651 .757 .928 r
.52903 .48369 m .51924 .48693 L .5219 .4899 L p F P
0 g
s
.651 .757 .928 r
.5219 .4899 m .53167 .48668 L .52903 .48369 L p F P
0 g
s
.456 .021 .122 r
.4928 .64419 m .49463 .64135 L .49812 .64086 L p F P
0 g
s
.39 0 .091 r
.49463 .64135 m .4928 .64419 L .48669 .64541 L p F P
0 g
s
.224 0 .258 r
.43607 .67564 m .43996 .67334 L .43897 .67719 L p F P
0 g
s
.224 0 .258 r
.43897 .67719 m .43129 .6817 L .43607 .67564 L p F P
0 g
s
.65 .757 .927 r
.23734 .48333 m .22809 .48655 L .23124 .48954 L p F P
0 g
s
.65 .757 .927 r
.23124 .48954 m .24048 .48632 L .23734 .48333 L p F P
0 g
s
.628 .144 .085 r
.55543 .64116 m .54736 .64008 L .55225 .64326 L p F P
0 g
s
.628 .144 .085 r
.55711 .64231 m .55543 .64116 L p .55225 .64326 L F P
0 g
s
0 .383 .794 r
.596 .72481 m .59358 .72373 L .59005 .72144 L p F P
0 g
s
.651 .757 .928 r
.69355 .48341 m .68346 .48665 L .68584 .48963 L p F P
0 g
s
.651 .757 .928 r
.68584 .48963 m .69591 .4864 L .69355 .48341 L p F P
0 g
s
.65 .757 .928 r
.38941 .48342 m .37988 .48666 L .38277 .48964 L p F P
0 g
s
.65 .757 .928 r
.38277 .48964 m .39229 .48641 L .38941 .48342 L p F P
0 g
s
.358 .291 .644 r
.42363 .71077 m .41804 .71584 L .41694 .71471 L p F P
0 g
s
.352 .29 .647 r
.41804 .71584 m .41729 .71654 L .41694 .71471 L closepath p F P
0 g
s
.651 .757 .928 r
.54148 .48344 m .53167 .48668 L .5343 .48966 L p F P
0 g
s
.651 .757 .928 r
.5343 .48966 m .5441 .48643 L .54148 .48344 L p F P
0 g
s
.409 .428 .769 r
.41955 .72402 m .4188 .72372 L .41924 .72319 L closepath p F P
0 g
s
.91 .539 .312 r
.62071 .68561 m .62008 .68331 L .62125 .68239 L p F P
0 g
s
.903 .526 .303 r
.62008 .68331 m .61946 .68125 L .62125 .68239 L closepath p F P
0 g
s
.286 0 .185 r
.4495 .66557 m .4507 .66252 L .45239 .66148 L p F P
0 g
s
.65 .757 .927 r
.24975 .48309 m .24048 .48632 L .24361 .4893 L p F P
0 g
s
.65 .757 .927 r
.24361 .4893 m .25287 .48608 L .24975 .48309 L p F P
0 g
s
.377 0 .012 r
.51193 .70287 m .51355 .70291 L p .50667 .70573 L F P
0 g
s
.423 0 .061 r
.51355 .70291 m .51193 .70287 L .51377 .70262 L closepath p F P
0 g
s
.651 .757 .928 r
.70603 .48316 m .69591 .4864 L .69827 .48938 L p F P
0 g
s
.651 .757 .928 r
.69827 .48938 m .70837 .48615 L .70603 .48316 L p F P
0 g
s
.85 .426 .224 r
.60779 .66845 m .60354 .66629 L .60558 .6704 L p F P
0 g
s
.85 .426 .224 r
.60558 .6704 m .60985 .67256 L .60779 .66845 L p F P
0 g
s
.65 .757 .928 r
.40184 .48318 m .39229 .48641 L .39516 .48939 L p F P
0 g
s
.65 .757 .928 r
.39516 .48939 m .4047 .48617 L .40184 .48318 L p F P
0 g
s
.651 .757 .928 r
.55393 .48319 m .5441 .48643 L .54671 .48941 L p F P
0 g
s
.651 .757 .928 r
.54671 .48941 m .55654 .48618 L .55393 .48319 L p F P
0 g
s
.315 .631 .962 r
.61102 .73047 m .61032 .73035 L .60758 .72785 L p F P
0 g
s
.456 .021 .122 r
.49812 .64086 m .50476 .6414 L p .4928 .64419 L F P
0 g
s
.459 .019 .113 r
.50476 .6414 m .49812 .64086 L .50578 .63986 L closepath p F P
0 g
s
.286 0 .185 r
.45239 .66148 m .45973 .65846 L p .4495 .66557 L F P
0 g
s
.25 0 .112 r
.45973 .65846 m .4604 .65706 L .45239 .66148 L closepath p F P
0 g
s
.416 .389 .721 r
.41729 .71654 m .41804 .71584 L .42399 .7188 L p F P
0 g
s
.416 .389 .721 r
.42399 .7188 m .41924 .72319 L .41729 .71654 L p F P
0 g
s
.553 .051 .017 r
.5432 .7053 m .53839 .70339 L .53916 .70274 L p F P
0 g
s
.583 .086 .039 r
.53839 .70339 m .53652 .70251 L .53916 .70274 L closepath p F P
0 g
s
.767 .31 .163 r
.58835 .65454 m .59125 .65836 L .586 .65646 L p F P
0 g
s
.767 .31 .163 r
.5861 .65372 m .58835 .65454 L p .586 .65646 L F P
0 g
s
.65 .757 .927 r
.26217 .48285 m .25287 .48608 L .25598 .48907 L p F P
0 g
s
.65 .757 .927 r
.25598 .48907 m .26527 .48585 L .26217 .48285 L p F P
0 g
s
.528 0 0 r
.5634 .70956 m .55756 .70789 L .56321 .71102 L p F P
0 g
s
.528 0 0 r
.56589 .71128 m .5634 .70956 L p .56321 .71102 L F P
0 g
s
.658 .838 .969 r
.44144 .72606 m .43181 .72864 L .43461 .73144 L p F P
0 g
s
.658 .838 .969 r
.43461 .73144 m .44424 .72796 L .44144 .72606 L p F P
0 g
s
.651 .758 .928 r
.71851 .4829 m .70837 .48615 L .71071 .48913 L p F P
0 g
s
.651 .758 .928 r
.71071 .48913 m .72083 .48589 L .71851 .4829 L p F P
0 g
s
.943 .75 .613 r
.63346 .70953 m .63069 .70702 L .62934 .71217 L p F P
0 g
s
.943 .75 .613 r
.62934 .71217 m .63211 .71468 L .63346 .70953 L p F P
0 g
s
.651 .757 .928 r
.41428 .48293 m .4047 .48617 L .40755 .48915 L p F P
0 g
s
.651 .757 .928 r
.40755 .48915 m .41712 .48592 L .41428 .48293 L p F P
0 g
s
.651 .757 .928 r
.56639 .48294 m .55654 .48618 L .55913 .48916 L p F P
0 g
s
.651 .757 .928 r
.55913 .48916 m .56897 .48593 L .56639 .48294 L p F P
0 g
s
.48 .025 .094 r
.51377 .70262 m .52585 .70207 L p .52315 .70434 L F P
0 g
s
.48 .025 .094 r
.52315 .70434 m .51355 .70291 L .51377 .70262 L p F P
0 g
s
.524 .071 .117 r
.52596 .70197 m .52585 .70207 L .51377 .70262 L p F P
0 g
s
.459 .459 .771 r
.4263 .71937 m .42904 .7248 L .41955 .72402 L p F P
0 g
s
.459 .459 .771 r
.42399 .7188 m .4263 .71937 L p .41955 .72402 L F P
0 g
s
.459 .459 .771 r
.41955 .72402 m .41924 .72319 L .42399 .7188 L p F P
0 g
s
.555 .64 .89 r
.41955 .72402 m .42904 .7248 L .43032 .72664 L p F P
0 g
s
.282 .158 .528 r
.41961 .7026 m .42257 .70004 L .42283 .70514 L p F P
0 g
s
.282 .158 .528 r
.42283 .70514 m .42076 .70693 L .41961 .7026 L p F P
0 g
s
.929 .788 .683 r
.63211 .71468 m .63072 .71794 L .6332 .72069 L p F P
0 g
s
.877 .805 .775 r
.6332 .72069 m .63155 .72289 L .62894 .72035 L p F P
0 g
s
.877 .805 .775 r
.62894 .72035 m .63072 .71794 L .6332 .72069 L p F P
0 g
s
.503 0 0 r
.53652 .70251 m .52633 .70208 L .53413 .70455 L p F P
0 g
s
.503 0 0 r
.53839 .70339 m .53652 .70251 L p .53413 .70455 L F P
0 g
s
.634 .766 .942 r
.61847 .72503 m .60852 .72798 L .61102 .73047 L p F P
0 g
s
.634 .766 .942 r
.61102 .73047 m .62096 .7277 L .61847 .72503 L p F P
0 g
s
.315 .631 .962 r
.60758 .72785 m .60852 .72798 L .61102 .73047 L p F P
0 g
s
.714 .248 .142 r
.57344 .64738 m .57695 .651 L .57079 .64936 L p F P
0 g
s
.714 .248 .142 r
.57122 .64679 m .57344 .64738 L p .57079 .64936 L F P
0 g
s
.65 .757 .928 r
.27459 .48261 m .26527 .48585 L .26835 .48883 L p F P
0 g
s
.65 .757 .928 r
.26835 .48883 m .27766 .48561 L .27459 .48261 L p F P
0 g
s
.651 .758 .928 r
.73099 .48265 m .72083 .48589 L .72314 .48887 L p F P
0 g
s
.651 .758 .928 r
.72314 .48887 m .73329 .48564 L .73099 .48265 L p F P
0 g
s
.256 .005 .328 r
.43113 .68198 m .43129 .6817 L .43117 .68178 L closepath p F P
0 g
s
.167 0 .288 r
.43117 .68178 m .43113 .68198 L .42854 .68717 L p F P
0 g
s
.651 .757 .928 r
.42672 .48268 m .41712 .48592 L .41995 .4889 L p F P
0 g
s
.651 .757 .928 r
.41995 .4889 m .42954 .48568 L .42672 .48268 L p F P
0 g
s
.651 .757 .928 r
.57886 .48269 m .56897 .48593 L .57155 .48891 L p F P
0 g
s
.651 .757 .928 r
.57155 .48891 m .58142 .48568 L .57886 .48269 L p F P
0 g
s
.255 .004 .328 r
.43129 .6817 m .43897 .67719 L p .4304 .68587 L F P
0 g
s
.255 .004 .328 r
.4304 .68587 m .43113 .68198 L .43129 .6817 L p F P
0 g
s
.87 .468 .265 r
.61388 .67477 m .60985 .67256 L .61155 .67678 L p F P
0 g
s
.87 .468 .265 r
.61155 .67678 m .61562 .67899 L .61388 .67477 L p F P
0 g
s
.194 0 .305 r
.4304 .68587 m .43113 .68198 L .42854 .68717 L closepath p F P
0 g
s
.516 .014 .003 r
.52585 .70207 m .52596 .70197 L .52633 .70208 L closepath p F P
0 g
s
.286 .111 .459 r
.42274 .69536 m .42695 .6923 L .42671 .69704 L p F P
0 g
s
.286 .111 .459 r
.42671 .69704 m .42257 .70004 L .42274 .69536 L p F P
0 g
s
.792 .812 .868 r
.62165 .72718 m .62096 .7277 L .62345 .7303 L p F P
0 g
s
.792 .812 .868 r
.62345 .7303 m .62421 .72973 L .62165 .72718 L p F P
0 g
s
.65 .757 .928 r
.28701 .48237 m .27766 .48561 L .28073 .48859 L p F P
0 g
s
.65 .757 .928 r
.28073 .48859 m .29006 .48537 L .28701 .48237 L p F P
0 g
s
.828 .814 .837 r
.63155 .72289 m .62894 .72035 L .62165 .72718 L p F P
0 g
s
.828 .814 .837 r
.62165 .72718 m .62421 .72973 L .63155 .72289 L p F P
0 g
s
.651 .758 .928 r
.74348 .48239 m .73329 .48564 L .73559 .48862 L p F P
0 g
s
.651 .758 .928 r
.73559 .48862 m .74576 .48538 L .74348 .48239 L p F P
0 g
s
.822 .374 .17 r
.6008 .66501 m .60228 .66425 L .60354 .66629 L closepath p F P
0 g
s
.792 .328 .135 r
.59892 .66422 m .6008 .66501 L .60228 .66425 L p F P
0 g
s
.651 .757 .928 r
.43916 .48244 m .42954 .48568 L .43235 .48866 L p F P
0 g
s
.651 .757 .928 r
.43235 .48866 m .44196 .48543 L .43916 .48244 L p F P
0 g
s
.651 .757 .928 r
.59132 .48244 m .58142 .48568 L .58397 .48866 L p F P
0 g
s
.651 .757 .928 r
.58397 .48866 m .59386 .48543 L .59132 .48244 L p F P
0 g
s
.45 0 0 r
.51137 .70501 m .51355 .70291 L .52315 .70434 L closepath p F P
0 g
s
.377 0 .012 r
.51355 .70291 m .51137 .70501 L .50667 .70573 L p F P
0 g
s
.385 0 .079 r
.48227 .64631 m .48261 .64579 L .48669 .64541 L closepath p F P
0 g
s
.213 0 0 r
.48865 .71049 m .49022 .70903 L .50036 .70662 L p F P
0 g
s
.203 0 0 r
.50112 .70599 m .50036 .70662 L .49022 .70903 L p F P
0 g
s
.036 0 0 r
.49022 .70903 m .48865 .71049 L .47894 .71396 L p F P
0 g
s
.946 .7 .533 r
.6312 .70211 m .6282 .69964 L .6277 .70455 L p F P
0 g
s
.946 .7 .533 r
.6277 .70455 m .63069 .70702 L .6312 .70211 L p F P
0 g
s
.523 .026 .017 r
.52633 .70208 m .52585 .70207 L .52335 .70433 L p F P
0 g
s
.523 .026 .017 r
.52335 .70433 m .53413 .70455 L .52633 .70208 L p F P
0 g
s
.48 .025 .094 r
.52585 .70207 m .52335 .70433 L .52315 .70434 L p F P
0 g
s
.625 .162 .134 r
.54736 .64008 m .55225 .64326 L .54378 .64229 L p F P
0 g
s
.625 .162 .134 r
.54348 .63964 m .54736 .64008 L p .54378 .64229 L F P
0 g
s
.419 .388 .718 r
.41804 .71584 m .42363 .71077 L p .42555 .71739 L F P
0 g
s
.419 .388 .718 r
.42555 .71739 m .42399 .7188 L .41804 .71584 L p F P
0 g
s
.65 .757 .928 r
.29943 .48213 m .29006 .48537 L .29311 .48835 L p F P
0 g
s
.65 .757 .928 r
.29311 .48835 m .30247 .48513 L .29943 .48213 L p F P
0 g
s
.651 .758 .928 r
.75597 .48213 m .74576 .48538 L .74803 .48836 L p F P
0 g
s
.651 .758 .928 r
.74803 .48836 m .75823 .48512 L .75597 .48213 L p F P
0 g
s
.651 .757 .928 r
.45161 .48219 m .44196 .48543 L .44475 .48841 L p F P
0 g
s
.651 .757 .928 r
.44475 .48841 m .45439 .48518 L .45161 .48219 L p F P
0 g
s
.651 .757 .928 r
.60379 .48219 m .59386 .48543 L .59639 .48841 L p F P
0 g
s
.651 .757 .928 r
.59639 .48841 m .60631 .48518 L .60379 .48219 L p F P
0 g
s
.767 .31 .163 r
.586 .65646 m .58469 .65482 L .5861 .65372 L p F P
0 g
s
.753 .289 .149 r
.58469 .65482 m .58286 .65271 L .5861 .65372 L closepath p F P
0 g
s
.889 .508 .307 r
.61946 .68125 m .61562 .67899 L .61695 .68333 L p F P
0 g
s
.889 .508 .307 r
.62008 .68331 m .61946 .68125 L p .61695 .68333 L F P
0 g
s
.714 .248 .142 r
.57079 .64936 m .56962 .64823 L .57122 .64679 L p F P
0 g
s
.696 .225 .128 r
.56962 .64823 m .56691 .64585 L .57122 .64679 L closepath p F P
0 g
s
.65 .756 .927 r
.15969 .4817 m .15057 .48492 L .15386 .48792 L p F P
0 g
s
.65 .756 .927 r
.15386 .48792 m .16296 .4847 L .15969 .4817 L p F P
0 g
s
.501 .062 .137 r
.50578 .63986 m .51556 .63912 L p .50894 .64222 L F P
0 g
s
.501 .062 .137 r
.50894 .64222 m .50476 .6414 L .50578 .63986 L p F P
0 g
s
.67 .195 .117 r
.55562 .6437 m .55711 .64231 L .55991 .64446 L closepath p F P
0 g
s
.628 .144 .085 r
.55225 .64326 m .55562 .6437 L .55711 .64231 L p F P
0 g
s
0 0 0 r
.47814 .71435 m .47894 .71396 L .48865 .71049 L p F P
0 g
s
.939 .646 .458 r
.62805 .69494 m .62484 .69252 L .625 .69723 L p F P
0 g
s
.939 .646 .458 r
.625 .69723 m .6282 .69964 L .62805 .69494 L p F P
0 g
s
.651 .758 .928 r
.76846 .48187 m .75823 .48512 L .76048 .4881 L p F P
0 g
s
.651 .758 .928 r
.76048 .4881 m .7707 .48486 L .76846 .48187 L p F P
0 g
s
.65 .757 .928 r
.31186 .48189 m .30247 .48513 L .30549 .48811 L p F P
0 g
s
.65 .757 .928 r
.30549 .48811 m .31488 .48489 L .31186 .48189 L p F P
0 g
s
.651 .757 .928 r
.61627 .48194 m .60631 .48518 L .60882 .48816 L p F P
0 g
s
.651 .757 .928 r
.60882 .48816 m .61876 .48493 L .61627 .48194 L p F P
0 g
s
.651 .757 .928 r
.46406 .48194 m .45439 .48518 L .45716 .48816 L p F P
0 g
s
.651 .757 .928 r
.45716 .48816 m .46682 .48493 L .46406 .48194 L p F P
0 g
s
.925 .592 .39 r
.62414 .68798 m .62071 .68561 L .62141 .69015 L p F P
0 g
s
.925 .592 .39 r
.62141 .69015 m .62484 .69252 L .62414 .68798 L p F P
0 g
s
.65 .756 .927 r
.17209 .48148 m .16296 .4847 L .16622 .4877 L p F P
0 g
s
.65 .756 .927 r
.16622 .4877 m .17535 .48448 L .17209 .48148 L p F P
0 g
s
.796 .35 .187 r
.59625 .66032 m .59125 .65836 L .59387 .66228 L p F P
0 g
s
.796 .35 .187 r
.59387 .66228 m .59892 .66422 L .59625 .66032 L p F P
0 g
s
.625 .162 .134 r
.54378 .64229 m .54208 .64125 L .54348 .63964 L p F P
0 g
s
.6 .133 .117 r
.54208 .64125 m .53832 .63929 L .54348 .63964 L closepath p F P
0 g
s
.385 .711 .986 r
.596 .72481 m .60466 .72539 L .60153 .72298 L p F P
0 g
s
.385 .711 .986 r
.60153 .72298 m .59348 .72278 L .596 .72481 L p F P
0 g
s
0 .383 .794 r
.59005 .72144 m .59348 .72278 L .596 .72481 L p F P
0 g
s
.651 .758 .927 r
.78096 .48161 m .7707 .48486 L .77293 .48785 L p F P
0 g
s
.651 .758 .927 r
.77293 .48785 m .78318 .48461 L .78096 .48161 L p F P
0 g
s
.65 .757 .928 r
.3243 .48165 m .31488 .48489 L .31788 .48787 L p F P
0 g
s
.65 .757 .928 r
.31788 .48787 m .32729 .48465 L .3243 .48165 L p F P
0 g
s
.57 .665 .902 r
.43181 .72864 m .42805 .72912 L .43032 .72664 L closepath p F P
0 g
s
.651 .757 .928 r
.62874 .48168 m .61876 .48493 L .62125 .48791 L p F P
0 g
s
.651 .757 .928 r
.62125 .48791 m .63122 .48468 L .62874 .48168 L p F P
0 g
s
.651 .757 .928 r
.47652 .48169 m .46682 .48493 L .46957 .48792 L p F P
0 g
s
.651 .757 .928 r
.46957 .48792 m .47925 .48469 L .47652 .48169 L p F P
0 g
s
.573 .939 .902 r
.46363 .71976 m .45392 .72388 L .45674 .72427 L p F P
0 g
s
.573 .939 .902 r
.46594 .71959 m .46363 .71976 L p .45674 .72427 L F P
0 g
s
.573 .939 .902 r
.45674 .72427 m .46398 .72076 L .46594 .71959 L p F P
0 g
s
.661 .903 .98 r
.45674 .72427 m .45392 .72388 L .44534 .72749 L p F P
0 g
s
.65 .757 .927 r
.18451 .48125 m .17535 .48448 L .17859 .48747 L p F P
0 g
s
.65 .757 .927 r
.17859 .48747 m .18774 .48425 L .18451 .48125 L p F P
0 g
s
.426 .018 .158 r
.48062 .64937 m .48227 .64631 L .48669 .64541 L p F P
0 g
s
.362 0 .126 r
.48227 .64631 m .48062 .64937 L .47065 .65204 L p F P
0 g
s
.322 0 .147 r
.45973 .65846 m .4604 .65706 L .47008 .65329 L p F P
0 g
s
.326 0 .155 r
.47065 .65204 m .47008 .65329 L .4604 .65706 L p F P
0 g
s
.651 .758 .927 r
.79346 .48135 m .78318 .48461 L .78539 .48759 L p F P
0 g
s
.651 .758 .927 r
.78539 .48759 m .79566 .48434 L .79346 .48135 L p F P
0 g
s
.65 .757 .928 r
.33673 .48141 m .32729 .48465 L .33027 .48763 L p F P
0 g
s
.65 .757 .928 r
.33027 .48763 m .33971 .4844 L .33673 .48141 L p F P
0 g
s
.651 .757 .928 r
.64122 .48143 m .63122 .48468 L .63369 .48766 L p F P
0 g
s
.651 .757 .928 r
.63369 .48766 m .64368 .48443 L .64122 .48143 L p F P
0 g
s
.651 .757 .928 r
.48898 .48144 m .47925 .48469 L .48198 .48767 L p F P
0 g
s
.651 .757 .928 r
.48198 .48767 m .49169 .48444 L .48898 .48144 L p F P
0 g
s
.033 .556 .863 r
.58095 .71785 m .58608 .71926 L .58151 .71724 L p F P
0 g
s
.541 .016 0 r
.53638 .70468 m .53839 .70339 L .5432 .7053 L closepath p F P
0 g
s
.503 0 0 r
.53413 .70455 m .53638 .70468 L .53839 .70339 L p F P
0 g
s
.593 .144 .153 r
.53832 .63929 m .54208 .64125 L p .53408 .64169 L F P
0 g
s
.593 .144 .153 r
.53009 .63887 m .53832 .63929 L p .53408 .64169 L F P
0 g
s
.65 .757 .927 r
.19692 .48102 m .18774 .48425 L .19096 .48725 L p F P
0 g
s
.65 .757 .927 r
.19096 .48725 m .20013 .48402 L .19692 .48102 L p F P
0 g
s
.651 .758 .927 r
.80596 .48109 m .79566 .48434 L .79785 .48733 L p F P
0 g
s
.651 .758 .927 r
.79785 .48733 m .80814 .48408 L .80596 .48109 L p F P
0 g
s
.501 .062 .137 r
.51556 .63912 m .5172 .63952 L p .50894 .64222 L F P
0 g
s
.517 .073 .134 r
.5172 .63952 m .51556 .63912 L .51756 .63899 L closepath p F P
0 g
s
.65 .757 .928 r
.34917 .48116 m .33971 .4844 L .34267 .48739 L p F P
0 g
s
.65 .757 .928 r
.34267 .48739 m .35213 .48416 L .34917 .48116 L p F P
0 g
s
.651 .757 .928 r
.65371 .48118 m .64368 .48443 L .64613 .48741 L p F P
0 g
s
.651 .757 .928 r
.64613 .48741 m .65614 .48417 L .65371 .48118 L p F P
0 g
s
.651 .757 .928 r
.50144 .48119 m .49169 .48444 L .4944 .48742 L p F P
0 g
s
.651 .757 .928 r
.4944 .48742 m .50413 .48419 L .50144 .48119 L p F P
0 g
s
.303 0 0 r
.50036 .70662 m .50112 .70599 L .50667 .70573 L closepath p F P
0 g
s
.552 .11 .154 r
.51756 .63899 m .52807 .63886 L p .52289 .64154 L F P
0 g
s
.552 .11 .154 r
.52289 .64154 m .5172 .63952 L .51756 .63899 L p F P
0 g
s
.511 0 0 r
.55756 .70789 m .56321 .71102 L .5574 .70933 L p F P
0 g
s
.511 0 0 r
.55103 .70666 m .55756 .70789 L p .5574 .70933 L F P
0 g
s
.678 .201 .113 r
.56691 .64585 m .55991 .64446 L .56388 .64794 L p F P
0 g
s
.678 .201 .113 r
.56962 .64823 m .56691 .64585 L p .56388 .64794 L F P
0 g
s
.65 .757 .927 r
.20934 .48079 m .20013 .48402 L .20333 .48702 L p F P
0 g
s
.65 .757 .927 r
.20333 .48702 m .21253 .48379 L .20934 .48079 L p F P
0 g
s
.734 .266 .138 r
.58286 .65271 m .57695 .651 L .58022 .65471 L p F P
0 g
s
.734 .266 .138 r
.58469 .65482 m .58286 .65271 L p .58022 .65471 L F P
0 g
s
.249 .039 .385 r
.42854 .68717 m .4304 .68587 L .42991 .69024 L p F P
0 g
s
.249 .039 .385 r
.42991 .69024 m .42695 .6923 L .42854 .68717 L p F P
0 g
s
.651 .758 .927 r
.81847 .48082 m .80814 .48408 L .81031 .48707 L p F P
0 g
s
.651 .758 .927 r
.81031 .48707 m .82063 .48382 L .81847 .48082 L p F P
0 g
s
.65 .757 .928 r
.36162 .48092 m .35213 .48416 L .35507 .48715 L p F P
0 g
s
.65 .757 .928 r
.35507 .48715 m .36455 .48391 L .36162 .48092 L p F P
0 g
s
.651 .757 .928 r
.66619 .48092 m .65614 .48417 L .65857 .48716 L p F P
0 g
s
.651 .757 .928 r
.65857 .48716 m .66861 .48392 L .66619 .48092 L p F P
0 g
s
.295 .003 .286 r
.43996 .67334 m .44831 .6692 L p .44542 .67398 L F P
0 g
s
.295 .003 .286 r
.44542 .67398 m .43897 .67719 L .43996 .67334 L p F P
0 g
s
.242 0 .212 r
.4495 .66557 m .44831 .6692 L .43996 .67334 L p F P
0 g
s
.593 .144 .153 r
.53408 .64169 m .52963 .63948 L .53009 .63887 L p F P
0 g
s
.564 .111 .135 r
.52963 .63948 m .52807 .63886 L .53009 .63887 L closepath p F P
0 g
s
.651 .757 .928 r
.5139 .48094 m .50413 .48419 L .50682 .48717 L p F P
0 g
s
.651 .757 .928 r
.50682 .48717 m .51658 .48394 L .5139 .48094 L p F P
0 g
s
.921 .774 .681 r
.63072 .71794 m .63211 .71468 L .62934 .71217 L p F P
0 g
s
.552 .11 .154 r
.52807 .63886 m .52963 .63948 L p .52289 .64154 L F P
0 g
s
.394 0 0 r
.56344 .71109 m .56589 .71128 L .56933 .71261 L closepath p F P
0 g
s
.528 0 0 r
.56321 .71102 m .56344 .71109 L .56589 .71128 L p F P
0 g
s
0 .411 .796 r
.59348 .72278 m .59005 .72144 L .58608 .71926 L p F P
0 g
s
.835 .418 .25 r
.60354 .66629 m .60558 .6704 L .60109 .6683 L p F P
0 g
s
.835 .418 .25 r
.6008 .66501 m .60354 .66629 L p .60109 .6683 L F P
0 g
s
.65 .757 .927 r
.22177 .48056 m .21253 .48379 L .21571 .48679 L p F P
0 g
s
.65 .757 .927 r
.21571 .48679 m .22494 .48356 L .22177 .48056 L p F P
0 g
s
.905 .536 .324 r
.61894 .68449 m .62008 .68331 L .62071 .68561 L closepath p F P
0 g
s
.889 .508 .307 r
.61695 .68333 m .61894 .68449 L .62008 .68331 L p F P
0 g
s
.65 .757 .928 r
.37406 .48067 m .36455 .48391 L .36747 .4869 L p F P
0 g
s
.65 .757 .928 r
.36747 .4869 m .37698 .48367 L .37406 .48067 L p F P
0 g
s
.651 .757 .928 r
.67868 .48067 m .66861 .48392 L .67101 .48691 L p F P
0 g
s
.651 .757 .928 r
.67101 .48691 m .68108 .48367 L .67868 .48067 L p F P
0 g
s
.651 .757 .928 r
.52637 .48069 m .51658 .48394 L .51924 .48693 L p F P
0 g
s
.651 .757 .928 r
.51924 .48693 m .52903 .48369 L .52637 .48069 L p F P
0 g
s
0 0 0 r
.48865 .71049 m .48745 .71115 L .47814 .71435 L p F P
0 g
s
.426 .018 .158 r
.48669 .64541 m .4923 .64513 L p .48062 .64937 L F P
0 g
s
.431 .021 .158 r
.4923 .64513 m .48669 .64541 L .4928 .64419 L closepath p F P
0 g
s
.65 .757 .927 r
.23419 .48032 m .22494 .48356 L .22809 .48655 L p F P
0 g
s
.65 .757 .927 r
.22809 .48655 m .23734 .48333 L .23419 .48032 L p F P
0 g
s
.661 .906 .979 r
.44424 .72796 m .44534 .72749 L .44452 .72806 L closepath p F P
0 g
s
.651 .757 .928 r
.69118 .48041 m .68108 .48367 L .68346 .48665 L p F P
0 g
s
.651 .757 .928 r
.68346 .48665 m .69355 .48341 L .69118 .48041 L p F P
0 g
s
.65 .757 .928 r
.38652 .48042 m .37698 .48367 L .37988 .48666 L p F P
0 g
s
.65 .757 .928 r
.37988 .48666 m .38941 .48342 L .38652 .48042 L p F P
0 g
s
.651 .757 .928 r
.53885 .48044 m .52903 .48369 L .53167 .48668 L p F P
0 g
s
.651 .757 .928 r
.53167 .48668 m .54148 .48344 L .53885 .48044 L p F P
0 g
s
.398 .016 .193 r
.47008 .65329 m .47065 .65204 L .48062 .64937 L p F P
0 g
s
.65 .757 .927 r
.24662 .48009 m .23734 .48333 L .24048 .48632 L p F P
0 g
s
.65 .757 .927 r
.24048 .48632 m .24975 .48309 L .24662 .48009 L p F P
0 g
s
.325 .643 .966 r
.60852 .72798 m .60758 .72785 L .60466 .72539 L p F P
0 g
s
.651 .757 .928 r
.70368 .48016 m .69355 .48341 L .69591 .4864 L p F P
0 g
s
.651 .757 .928 r
.69591 .4864 m .70603 .48316 L .70368 .48016 L p F P
0 g
s
.65 .757 .928 r
.39897 .48018 m .38941 .48342 L .39229 .48641 L p F P
0 g
s
.65 .757 .928 r
.39229 .48641 m .40184 .48318 L .39897 .48018 L p F P
0 g
s
.651 .757 .928 r
.55132 .48019 m .54148 .48344 L .5441 .48643 L p F P
0 g
s
.651 .757 .928 r
.5441 .48643 m .55393 .48319 L .55132 .48019 L p F P
0 g
s
.552 .107 .148 r
.51568 .64171 m .5172 .63952 L .52289 .64154 L closepath p F P
0 g
s
.501 .062 .137 r
.5172 .63952 m .51568 .64171 L .50894 .64222 L p F P
0 g
s
.589 .673 .898 r
.43864 .72329 m .44144 .72606 L .43181 .72864 L p F P
0 g
s
.589 .673 .898 r
.4334 .72417 m .43864 .72329 L p .43181 .72864 L F P
0 g
s
.589 .673 .898 r
.43181 .72864 m .43032 .72664 L .4334 .72417 L p F P
0 g
s
.663 .904 .979 r
.45111 .72274 m .44144 .72606 L .44424 .72796 L p F P
0 g
s
.663 .904 .979 r
.45169 .72297 m .45111 .72274 L p .44424 .72796 L F P
0 g
s
.663 .904 .979 r
.44424 .72796 m .44534 .72749 L .45169 .72297 L p F P
0 g
s
.863 .468 .289 r
.60985 .67256 m .60558 .6704 L .60726 .67463 L p F P
0 g
s
.863 .468 .289 r
.60726 .67463 m .61155 .67678 L .60985 .67256 L p F P
0 g
s
.933 .736 .613 r
.63069 .70702 m .6277 .70455 L .62637 .7097 L p F P
0 g
s
.933 .736 .613 r
.62637 .7097 m .62934 .71217 L .63069 .70702 L p F P
0 g
s
.65 .757 .927 r
.25906 .47985 m .24975 .48309 L .25287 .48608 L p F P
0 g
s
.65 .757 .927 r
.25287 .48608 m .26217 .48285 L .25906 .47985 L p F P
0 g
s
.574 .939 .904 r
.46594 .71959 m .46644 .71957 L .46398 .72076 L closepath p F P
0 g
s
.327 0 .248 r
.4495 .66557 m .45838 .66191 L p .45492 .66647 L F P
0 g
s
.327 0 .248 r
.45492 .66647 m .44831 .6692 L .4495 .66557 L p F P
0 g
s
.286 0 .185 r
.45973 .65846 m .45838 .66191 L .4495 .66557 L p F P
0 g
s
.344 .204 .543 r
.42257 .70004 m .42671 .69704 L .42815 .7013 L p F P
0 g
s
.344 .204 .543 r
.42815 .7013 m .42283 .70514 L .42257 .70004 L p F P
0 g
s
.651 .757 .928 r
.71618 .4799 m .70603 .48316 L .70837 .48615 L p F P
0 g
s
.651 .757 .928 r
.70837 .48615 m .71851 .4829 L .71618 .4799 L p F P
0 g
s
.347 .26 .613 r
.42076 .70693 m .42283 .70514 L .42365 .71076 L p F P
0 g
s
.347 .26 .613 r
.42365 .71076 m .42363 .71077 L .42076 .70693 L p F P
0 g
s
.651 .757 .928 r
.41143 .47993 m .40184 .48318 L .4047 .48617 L p F P
0 g
s
.651 .757 .928 r
.4047 .48617 m .41428 .48293 L .41143 .47993 L p F P
0 g
s
.651 .757 .928 r
.5638 .47994 m .55393 .48319 L .55654 .48618 L p F P
0 g
s
.651 .757 .928 r
.55654 .48618 m .56639 .48294 L .5638 .47994 L p F P
0 g
s
.921 .774 .681 r
.62934 .71217 m .62823 .71483 L .63072 .71794 L p F P
0 g
s
.871 .786 .764 r
.63072 .71794 m .62894 .72035 L .62605 .71788 L p F P
0 g
s
.871 .786 .764 r
.62605 .71788 m .62823 .71483 L .63072 .71794 L p F P
0 g
s
.593 .141 .148 r
.52813 .64147 m .52963 .63948 L .53408 .64169 L closepath p F P
0 g
s
.552 .11 .154 r
.52963 .63948 m .52813 .64147 L .52289 .64154 L p F P
0 g
s
.663 .902 .979 r
.45169 .72297 m .45392 .72388 L .44534 .72749 L closepath p F P
0 g
s
.65 .757 .927 r
.2715 .47961 m .26217 .48285 L .26527 .48585 L p F P
0 g
s
.65 .757 .927 r
.26527 .48585 m .27459 .48261 L .2715 .47961 L p F P
0 g
s
.364 .008 .22 r
.45838 .66191 m .45973 .65846 L .46915 .65529 L p F P
0 g
s
.322 0 .147 r
.47008 .65329 m .46915 .65529 L .45973 .65846 L p F P
0 g
s
.644 .763 .935 r
.61596 .72227 m .60601 .72553 L .60852 .72798 L p F P
0 g
s
.644 .763 .935 r
.60852 .72798 m .61847 .72503 L .61596 .72227 L p F P
0 g
s
.325 .643 .966 r
.60466 .72539 m .60601 .72553 L .60852 .72798 L p F P
0 g
s
.651 .758 .928 r
.72868 .47965 m .71851 .4829 L .72083 .48589 L p F P
0 g
s
.651 .758 .928 r
.72083 .48589 m .73099 .48265 L .72868 .47965 L p F P
0 g
s
.651 .757 .928 r
.42389 .47968 m .41428 .48293 L .41712 .48592 L p F P
0 g
s
.651 .757 .928 r
.41712 .48592 m .42672 .48268 L .42389 .47968 L p F P
0 g
s
.651 .757 .928 r
.57629 .47969 m .56639 .48294 L .56897 .48593 L p F P
0 g
s
.651 .757 .928 r
.56897 .48593 m .57886 .48269 L .57629 .47969 L p F P
0 g
s
.511 0 0 r
.5574 .70933 m .55084 .70673 L .55103 .70666 L p F P
0 g
s
.601 .06 0 r
.55084 .70673 m .55053 .70656 L .55103 .70666 L closepath p F P
0 g
s
.793 .358 .215 r
.59125 .65836 m .586 .65646 L .58859 .66039 L p F P
0 g
s
.793 .358 .215 r
.58859 .66039 m .59387 .66228 L .59125 .65836 L p F P
0 g
s
.272 0 0 r
.50036 .70662 m .50667 .70573 L p .50451 .70769 L F P
0 g
s
.272 0 0 r
.50451 .70769 m .49838 .70832 L .50036 .70662 L p F P
0 g
s
.213 0 0 r
.50036 .70662 m .49838 .70832 L .48865 .71049 L p F P
0 g
s
.881 .511 .337 r
.61562 .67899 m .61155 .67678 L .61284 .68114 L p F P
0 g
s
.881 .511 .337 r
.61284 .68114 m .61695 .68333 L .61562 .67899 L p F P
0 g
s
.499 .057 .129 r
.50392 .64264 m .50476 .6414 L .50894 .64222 L closepath p F P
0 g
s
.456 .021 .122 r
.50476 .6414 m .50392 .64264 L .4928 .64419 L p F P
0 g
s
.317 .093 .407 r
.42991 .69024 m .4304 .68587 L .4382 .68127 L p F P
0 g
s
.255 .004 .328 r
.43897 .67719 m .4382 .68127 L .4304 .68587 L p F P
0 g
s
.826 .808 .833 r
.62894 .72035 m .62605 .71788 L .61894 .72467 L p F P
0 g
s
.826 .808 .833 r
.61894 .72467 m .62165 .72718 L .62894 .72035 L p F P
0 g
s
.612 .093 0 r
.55084 .70673 m .55053 .70656 L .5432 .7053 L p F P
0 g
s
.679 .23 .177 r
.55991 .64446 m .56388 .64794 L .55654 .64663 L p F P
0 g
s
.679 .23 .177 r
.55562 .6437 m .55991 .64446 L p .55654 .64663 L F P
0 g
s
.935 .687 .538 r
.6282 .69964 m .625 .69723 L .6245 .70213 L p F P
0 g
s
.935 .687 .538 r
.6245 .70213 m .6277 .70455 L .6282 .69964 L p F P
0 g
s
.791 .807 .865 r
.61894 .72467 m .61847 .72503 L .62096 .7277 L p F P
0 g
s
.791 .807 .865 r
.62096 .7277 m .62165 .72718 L .61894 .72467 L p F P
0 g
s
.65 .757 .927 r
.28394 .47937 m .27459 .48261 L .27766 .48561 L p F P
0 g
s
.65 .757 .927 r
.27766 .48561 m .28701 .48237 L .28394 .47937 L p F P
0 g
s
.651 .758 .928 r
.74119 .47939 m .73099 .48265 L .73329 .48564 L p F P
0 g
s
.651 .758 .928 r
.73329 .48564 m .74348 .48239 L .74119 .47939 L p F P
0 g
s
.651 .757 .928 r
.43636 .47943 m .42672 .48268 L .42954 .48568 L p F P
0 g
s
.651 .757 .928 r
.42954 .48568 m .43916 .48244 L .43636 .47943 L p F P
0 g
s
.651 .757 .928 r
.58877 .47944 m .57886 .48269 L .58142 .48568 L p F P
0 g
s
.651 .757 .928 r
.58142 .48568 m .59132 .48244 L .58877 .47944 L p F P
0 g
s
.522 .917 .897 r
.46594 .71959 m .46644 .71957 L .47615 .7154 L p F P
0 g
s
.835 .418 .25 r
.60109 .6683 m .59986 .66591 L .6008 .66501 L p F P
0 g
s
.823 .4 .238 r
.59986 .66591 m .59892 .66422 L .6008 .66501 L closepath p F P
0 g
s
.405 0 0 r
.55084 .70673 m .5574 .70933 L .55032 .708 L p F P
0 g
s
.405 0 0 r
.55032 .708 m .54825 .70745 L .55084 .70673 L p F P
0 g
s
.612 .093 0 r
.5432 .7053 m .54825 .70745 L .55084 .70673 L p F P
0 g
s
.928 .635 .467 r
.62484 .69252 m .62141 .69015 L .62158 .69486 L p F P
0 g
s
.928 .635 .467 r
.62158 .69486 m .625 .69723 L .62484 .69252 L p F P
0 g
s
.915 .584 .403 r
.62071 .68561 m .61894 .68449 L .61781 .68786 L p F P
0 g
s
.915 .584 .403 r
.61781 .68786 m .62141 .69015 L .62071 .68561 L p F P
0 g
s
.65 .757 .928 r
.29639 .47913 m .28701 .48237 L .29006 .48537 L p F P
0 g
s
.65 .757 .928 r
.29006 .48537 m .29943 .48213 L .29639 .47913 L p F P
0 g
s
.651 .758 .928 r
.7537 .47913 m .74348 .48239 L .74576 .48538 L p F P
0 g
s
.651 .758 .928 r
.74576 .48538 m .75597 .48213 L .7537 .47913 L p F P
0 g
s
.478 .067 .182 r
.4928 .64419 m .50392 .64264 L p .50057 .64585 L F P
0 g
s
.478 .067 .182 r
.50057 .64585 m .4923 .64513 L .4928 .64419 L p F P
0 g
s
.651 .757 .928 r
.44882 .47918 m .43916 .48244 L .44196 .48543 L p F P
0 g
s
.651 .757 .928 r
.44196 .48543 m .45161 .48219 L .44882 .47918 L p F P
0 g
s
.651 .757 .928 r
.60126 .47919 m .59132 .48244 L .59386 .48543 L p F P
0 g
s
.651 .757 .928 r
.59386 .48543 m .60379 .48219 L .60126 .47919 L p F P
0 g
s
.045 0 0 r
.48745 .71115 m .48865 .71049 L .49838 .70832 L p F P
0 g
s
.741 .293 .189 r
.57695 .651 m .57079 .64936 L .574 .65309 L p F P
0 g
s
.741 .293 .189 r
.574 .65309 m .58022 .65471 L .57695 .651 L p F P
0 g
s
.767 .311 .168 r
.58363 .65568 m .58469 .65482 L .586 .65646 L closepath p F P
0 g
s
.734 .266 .138 r
.58022 .65471 m .58363 .65568 L .58469 .65482 L p F P
0 g
s
.304 .124 .464 r
.42695 .6923 m .42991 .69024 L .42975 .69493 L p F P
0 g
s
.304 .124 .464 r
.42975 .69493 m .42671 .69704 L .42695 .6923 L p F P
0 g
s
.651 .758 .928 r
.76622 .47887 m .75597 .48213 L .75823 .48512 L p F P
0 g
s
.651 .758 .928 r
.75823 .48512 m .76846 .48187 L .76622 .47887 L p F P
0 g
s
.65 .757 .928 r
.30884 .47889 m .29943 .48213 L .30247 .48513 L p F P
0 g
s
.65 .757 .928 r
.30247 .48513 m .31186 .48189 L .30884 .47889 L p F P
0 g
s
.651 .757 .928 r
.61376 .47893 m .60379 .48219 L .60631 .48518 L p F P
0 g
s
.651 .757 .928 r
.60631 .48518 m .61627 .48194 L .61376 .47893 L p F P
0 g
s
.651 .757 .928 r
.4613 .47894 m .45161 .48219 L .45439 .48518 L p F P
0 g
s
.651 .757 .928 r
.45439 .48518 m .46406 .48194 L .4613 .47894 L p F P
0 g
s
.65 .756 .927 r
.16883 .47846 m .15969 .4817 L .16296 .4847 L p F P
0 g
s
.65 .756 .927 r
.16296 .4847 m .17209 .48148 L .16883 .47846 L p F P
0 g
s
.58 .654 .887 r
.4334 .72417 m .43032 .72664 L .42904 .7248 L closepath p F P
0 g
s
.651 .758 .927 r
.77873 .47861 m .76846 .48187 L .7707 .48486 L p F P
0 g
s
.651 .758 .927 r
.7707 .48486 m .78096 .48161 L .77873 .47861 L p F P
0 g
s
.65 .757 .928 r
.32129 .47864 m .31186 .48189 L .31488 .48489 L p F P
0 g
s
.65 .757 .928 r
.31488 .48489 m .3243 .48165 L .32129 .47864 L p F P
0 g
s
.394 .009 .186 r
.46915 .65529 m .47008 .65329 L .47978 .65122 L p F P
0 g
s
.398 .016 .193 r
.48062 .64937 m .47978 .65122 L .47008 .65329 L p F P
0 g
s
.651 .757 .928 r
.62626 .47868 m .61627 .48194 L .61876 .48493 L p F P
0 g
s
.651 .757 .928 r
.61876 .48493 m .62874 .48168 L .62626 .47868 L p F P
0 g
s
.651 .757 .928 r
.47377 .47869 m .46406 .48194 L .46682 .48493 L p F P
0 g
s
.651 .757 .928 r
.46682 .48493 m .47652 .48169 L .47377 .47869 L p F P
0 g
s
.679 .23 .177 r
.55654 .64663 m .55456 .64498 L .55562 .6437 L p F P
0 g
s
.659 .205 .164 r
.55456 .64498 m .55225 .64326 L .55562 .6437 L closepath p F P
0 g
s
.483 .899 .88 r
.46363 .71976 m .46594 .71959 L .47451 .71572 L p F P
0 g
s
.522 .917 .897 r
.47615 .7154 m .47451 .71572 L .46594 .71959 L p F P
0 g
s
.272 0 0 r
.50667 .70573 m .51085 .70552 L p .50451 .70769 L F P
0 g
s
.339 0 0 r
.51085 .70552 m .50667 .70573 L .51137 .70501 L closepath p F P
0 g
s
.65 .757 .927 r
.18126 .47823 m .17209 .48148 L .17535 .48448 L p F P
0 g
s
.65 .757 .927 r
.17535 .48448 m .18451 .48125 L .18126 .47823 L p F P
0 g
s
.485 0 0 r
.56933 .71261 m .57586 .71546 L .57841 .71662 L p F P
0 g
s
.271 0 0 r
.57118 .71351 m .5656 .71175 L p .57146 .71365 L F P
0 g
s
.322 0 0 r
.57004 .71292 m .57586 .71546 L p .57118 .71351 L F P
0 g
s
0 .4 .744 r
.57331 .71425 m .57118 .71351 L .57576 .71541 L closepath p F P
0 g
s
.271 0 0 r
.57331 .71425 m .57118 .71351 L p .57146 .71365 L F P
0 g
s
.322 0 0 r
.56933 .71261 m .57004 .71292 L p .57118 .71351 L F P
0 g
s
.322 0 0 r
.56344 .71109 m .56933 .71261 L p .57118 .71351 L F P
0 g
s
.625 .16 .129 r
.54137 .64206 m .54208 .64125 L .54378 .64229 L closepath p F P
0 g
s
.593 .144 .153 r
.54208 .64125 m .54137 .64206 L .53408 .64169 L p F P
0 g
s
.651 .758 .927 r
.79126 .47835 m .78096 .48161 L .78318 .48461 L p F P
0 g
s
.651 .758 .927 r
.78318 .48461 m .79346 .48135 L .79126 .47835 L p F P
0 g
s
.65 .757 .928 r
.33375 .4784 m .3243 .48165 L .32729 .48465 L p F P
0 g
s
.65 .757 .928 r
.32729 .48465 m .33673 .48141 L .33375 .4784 L p F P
0 g
s
.807 .381 .233 r
.59892 .66422 m .59387 .66228 L .59617 .66631 L p F P
0 g
s
.807 .381 .233 r
.59986 .66591 m .59892 .66422 L p .59617 .66631 L F P
0 g
s
.714 .248 .143 r
.56887 .6489 m .56962 .64823 L .57079 .64936 L closepath p F P
0 g
s
.678 .201 .113 r
.56388 .64794 m .56887 .6489 L .56962 .64823 L p F P
0 g
s
.424 .74 .992 r
.59348 .72278 m .60153 .72298 L .59814 .72063 L p F P
0 g
s
.424 .74 .992 r
.59814 .72063 m .59095 .72083 L .59348 .72278 L p F P
0 g
s
0 .411 .796 r
.58608 .71926 m .59095 .72083 L .59348 .72278 L p F P
0 g
s
.651 .757 .928 r
.63876 .47843 m .62874 .48168 L .63122 .48468 L p F P
0 g
s
.651 .757 .928 r
.63122 .48468 m .64122 .48143 L .63876 .47843 L p F P
0 g
s
.651 .757 .928 r
.48625 .47844 m .47652 .48169 L .47925 .48469 L p F P
0 g
s
.651 .757 .928 r
.47925 .48469 m .48898 .48144 L .48625 .47844 L p F P
0 g
s
.65 .757 .927 r
.1937 .47801 m .18451 .48125 L .18774 .48425 L p F P
0 g
s
.65 .757 .927 r
.18774 .48425 m .19692 .48102 L .1937 .47801 L p F P
0 g
s
0 .448 .799 r
.59095 .72083 m .58608 .71926 L .58151 .71724 L p F P
0 g
s
.651 .758 .927 r
.80378 .47808 m .79346 .48135 L .79566 .48434 L p F P
0 g
s
.651 .758 .927 r
.79566 .48434 m .80596 .48109 L .80378 .47808 L p F P
0 g
s
.65 .757 .928 r
.34621 .47815 m .33673 .48141 L .33971 .4844 L p F P
0 g
s
.65 .757 .928 r
.33971 .4844 m .34917 .48116 L .34621 .47815 L p F P
0 g
s
.651 .757 .928 r
.65126 .47817 m .64122 .48143 L .64368 .48443 L p F P
0 g
s
.651 .757 .928 r
.64368 .48443 m .65371 .48118 L .65126 .47817 L p F P
0 g
s
.651 .757 .928 r
.49874 .47819 m .48898 .48144 L .49169 .48444 L p F P
0 g
s
.651 .757 .928 r
.49169 .48444 m .50144 .48119 L .49874 .47819 L p F P
0 g
s
.642 .184 .15 r
.55225 .64326 m .54378 .64229 L .54833 .64559 L p F P
0 g
s
.642 .184 .15 r
.55456 .64498 m .55225 .64326 L p .54833 .64559 L F P
0 g
s
.481 0 0 r
.5432 .7053 m .54825 .70745 L p .54239 .70691 L F P
0 g
s
.481 0 0 r
.53638 .70468 m .5432 .7053 L p .54239 .70691 L F P
0 g
s
.914 .76 .677 r
.62823 .71483 m .62934 .71217 L .62637 .7097 L p F P
0 g
s
.65 .757 .927 r
.20614 .47778 m .19692 .48102 L .20013 .48402 L p F P
0 g
s
.65 .757 .927 r
.20013 .48402 m .20934 .48079 L .20614 .47778 L p F P
0 g
s
.651 .758 .927 r
.81631 .47782 m .80596 .48109 L .80814 .48408 L p F P
0 g
s
.651 .758 .927 r
.80814 .48408 m .81847 .48082 L .81631 .47782 L p F P
0 g
s
.9 .562 .398 r
.61894 .68449 m .61695 .68333 L .61777 .68784 L p F P
0 g
s
.9 .562 .398 r
.61777 .68784 m .61781 .68786 L .61894 .68449 L p F P
0 g
s
.65 .757 .928 r
.35867 .47791 m .34917 .48116 L .35213 .48416 L p F P
0 g
s
.65 .757 .928 r
.35213 .48416 m .36162 .48092 L .35867 .47791 L p F P
0 g
s
.651 .757 .928 r
.66377 .47792 m .65371 .48118 L .65614 .48417 L p F P
0 g
s
.651 .757 .928 r
.65614 .48417 m .66619 .48092 L .66377 .47792 L p F P
0 g
s
.651 .757 .928 r
.51122 .47794 m .50144 .48119 L .50413 .48419 L p F P
0 g
s
.651 .757 .928 r
.50413 .48419 m .5139 .48094 L .51122 .47794 L p F P
0 g
s
.476 .062 .175 r
.49115 .64723 m .4923 .64513 L .50057 .64585 L closepath p F P
0 g
s
.426 .018 .158 r
.4923 .64513 m .49115 .64723 L .48062 .64937 L p F P
0 g
s
.399 .296 .621 r
.42365 .71076 m .42283 .70514 L .42815 .7013 L p F P
0 g
s
.65 .757 .927 r
.21858 .47754 m .20934 .48079 L .21253 .48379 L p F P
0 g
s
.65 .757 .927 r
.21253 .48379 m .22177 .48056 L .21858 .47754 L p F P
0 g
s
.58 .649 .883 r
.42904 .7248 m .4263 .71937 L p .43718 .72129 L F P
0 g
s
.58 .649 .883 r
.43718 .72129 m .4334 .72417 L .42904 .7248 L p F P
0 g
s
.458 0 .001 r
.51085 .70552 m .51137 .70501 L .52315 .70434 L p F P
0 g
s
.464 .462 .771 r
.4263 .71937 m .42399 .7188 L .42555 .71739 L closepath p F P
0 g
s
.65 .757 .928 r
.37114 .47766 m .36162 .48092 L .36455 .48391 L p F P
0 g
s
.65 .757 .928 r
.36455 .48391 m .37406 .48067 L .37114 .47766 L p F P
0 g
s
.123 .627 .902 r
.57601 .71547 m .57586 .71546 L .57841 .71662 L p F P
0 g
s
.651 .757 .928 r
.67628 .47766 m .66619 .48092 L .66861 .48392 L p F P
0 g
s
.651 .757 .928 r
.66861 .48392 m .67868 .48067 L .67628 .47766 L p F P
0 g
s
.651 .757 .928 r
.52371 .47769 m .5139 .48094 L .51658 .48394 L p F P
0 g
s
.651 .757 .928 r
.51658 .48394 m .52637 .48069 L .52371 .47769 L p F P
0 g
s
.855 .467 .308 r
.60558 .6704 m .60109 .6683 L .60275 .67253 L p F P
0 g
s
.855 .467 .308 r
.60275 .67253 m .60726 .67463 L .60558 .6704 L p F P
0 g
s
.626 .892 .987 r
.45392 .72388 m .46363 .71976 L p .45498 .72131 L F P
0 g
s
.626 .892 .987 r
.45498 .72131 m .45169 .72297 L .45392 .72388 L p F P
0 g
s
.65 .757 .927 r
.23103 .47731 m .22177 .48056 L .22494 .48356 L p F P
0 g
s
.65 .757 .927 r
.22494 .48356 m .23419 .48032 L .23103 .47731 L p F P
0 g
s
.334 .068 .352 r
.43897 .67719 m .44542 .67398 L .44057 .68009 L p F P
0 g
s
.334 .068 .352 r
.44057 .68009 m .4382 .68127 L .43897 .67719 L p F P
0 g
s
.775 .348 .235 r
.586 .65646 m .58859 .66039 L .58307 .65856 L p F P
0 g
s
.775 .348 .235 r
.58363 .65568 m .586 .65646 L p .58307 .65856 L F P
0 g
s
.526 .106 .187 r
.50223 .64562 m .50392 .64264 L .50894 .64222 L p F P
0 g
s
.478 .067 .182 r
.50392 .64264 m .50223 .64562 L .50057 .64585 L p F P
0 g
s
.651 .757 .928 r
.6888 .47741 m .67868 .48067 L .68108 .48367 L p F P
0 g
s
.651 .757 .928 r
.68108 .48367 m .69118 .48041 L .6888 .47741 L p F P
0 g
s
.65 .757 .928 r
.38361 .47741 m .37406 .48067 L .37698 .48367 L p F P
0 g
s
.65 .757 .928 r
.37698 .48367 m .38652 .48042 L .38361 .47741 L p F P
0 g
s
.651 .757 .928 r
.53621 .47743 m .52637 .48069 L .52903 .48369 L p F P
0 g
s
.651 .757 .928 r
.52903 .48369 m .53885 .48044 L .53621 .47743 L p F P
0 g
s
.481 0 0 r
.54239 .70691 m .53577 .70509 L .53638 .70468 L p F P
0 g
s
.509 0 0 r
.53577 .70509 m .53413 .70455 L .53638 .70468 L closepath p F P
0 g
s
.349 .662 .972 r
.60601 .72553 m .60466 .72539 L .60153 .72298 L p F P
0 g
s
.448 .061 .211 r
.48062 .64937 m .49115 .64723 L p .4878 .65081 L F P
0 g
s
.448 .061 .211 r
.4878 .65081 m .47978 .65122 L .48062 .64937 L p F P
0 g
s
.722 .282 .205 r
.57079 .64936 m .574 .65309 L .56753 .65153 L p F P
0 g
s
.722 .282 .205 r
.56887 .6489 m .57079 .64936 L p .56753 .65153 L F P
0 g
s
.65 .757 .927 r
.24349 .47707 m .23419 .48032 L .23734 .48333 L p F P
0 g
s
.65 .757 .927 r
.23734 .48333 m .24662 .48009 L .24349 .47707 L p F P
0 g
s
.924 .723 .613 r
.6277 .70455 m .6245 .70213 L .6232 .70728 L p F P
0 g
s
.924 .723 .613 r
.6232 .70728 m .62637 .7097 L .6277 .70455 L p F P
0 g
s
.469 0 0 r
.53413 .70455 m .53577 .70509 L p .53293 .70625 L F P
0 g
s
.469 0 0 r
.52335 .70433 m .53413 .70455 L p .53293 .70625 L F P
0 g
s
.651 .757 .928 r
.70132 .47715 m .69118 .48041 L .69355 .48341 L p F P
0 g
s
.651 .757 .928 r
.69355 .48341 m .70368 .48016 L .70132 .47715 L p F P
0 g
s
.65 .757 .928 r
.39609 .47717 m .38652 .48042 L .38941 .48342 L p F P
0 g
s
.65 .757 .928 r
.38941 .48342 m .39897 .48018 L .39609 .47717 L p F P
0 g
s
.651 .757 .928 r
.5487 .47718 m .53885 .48044 L .54148 .48344 L p F P
0 g
s
.651 .757 .928 r
.54148 .48344 m .55132 .48019 L .5487 .47718 L p F P
0 g
s
.914 .76 .677 r
.62637 .7097 m .62572 .71132 L .62823 .71483 L p F P
0 g
s
.866 .766 .75 r
.62823 .71483 m .62605 .71788 L .6229 .71547 L p F P
0 g
s
.866 .766 .75 r
.6229 .71547 m .62572 .71132 L .62823 .71483 L p F P
0 g
s
.832 .418 .256 r
.59859 .66722 m .59986 .66591 L .60109 .6683 L closepath p F P
0 g
s
.807 .381 .233 r
.59617 .66631 m .59859 .66722 L .59986 .66591 L p F P
0 g
s
.633 .191 .183 r
.54378 .64229 m .54833 .64559 L .53948 .64472 L p F P
0 g
s
.633 .191 .183 r
.54137 .64206 m .54378 .64229 L p .53948 .64472 L F P
0 g
s
.873 .509 .356 r
.61155 .67678 m .60726 .67463 L .60852 .679 L p F P
0 g
s
.873 .509 .356 r
.60852 .679 m .61284 .68114 L .61155 .67678 L p F P
0 g
s
.526 .106 .187 r
.50894 .64222 m .51451 .6437 L p .50223 .64562 L F P
0 g
s
.529 .104 .177 r
.51451 .6437 m .50894 .64222 L .51568 .64171 L closepath p F P
0 g
s
.65 .757 .927 r
.25594 .47683 m .24662 .48009 L .24975 .48309 L p F P
0 g
s
.65 .757 .927 r
.24975 .48309 m .25906 .47985 L .25594 .47683 L p F P
0 g
s
.458 0 .001 r
.52315 .70434 m .52331 .70436 L p .51085 .70552 L F P
0 g
s
.447 0 0 r
.52331 .70436 m .52315 .70434 L .52335 .70433 L closepath p F P
0 g
s
.469 0 0 r
.53293 .70625 m .52331 .70436 L .52335 .70433 L p F P
0 g
s
.651 .757 .928 r
.71384 .47689 m .70368 .48016 L .70603 .48316 L p F P
0 g
s
.651 .757 .928 r
.70603 .48316 m .71618 .4799 L .71384 .47689 L p F P
0 g
s
.651 .757 .928 r
.40857 .47692 m .39897 .48018 L .40184 .48318 L p F P
0 g
s
.651 .757 .928 r
.40184 .48318 m .41143 .47993 L .40857 .47692 L p F P
0 g
s
.651 .757 .928 r
.56121 .47693 m .55132 .48019 L .55393 .48319 L p F P
0 g
s
.651 .757 .928 r
.55393 .48319 m .5638 .47994 L .56121 .47693 L p F P
0 g
s
.353 0 0 r
.52331 .70436 m .53293 .70625 L .5216 .70613 L p F P
0 g
s
.353 0 0 r
.5216 .70613 m .52064 .70606 L .52331 .70436 L p F P
0 g
s
.458 0 .001 r
.52331 .70436 m .52064 .70606 L .51085 .70552 L p F P
0 g
s
.061 0 0 r
.48588 .71209 m .48745 .71115 L .49759 .70871 L p F P
0 g
s
.045 0 0 r
.49838 .70832 m .49759 .70871 L .48745 .71115 L p F P
0 g
s
.633 .191 .183 r
.53948 .64472 m .53948 .64472 L .54137 .64206 L p F P
0 g
s
.611 .166 .169 r
.53948 .64472 m .53408 .64169 L .54137 .64206 L closepath p F P
0 g
s
.322 0 0 r
.57118 .71351 m .56333 .71108 L .56344 .71109 L p F P
0 g
s
.529 0 0 r
.56333 .71108 m .56321 .71102 L .56344 .71109 L closepath p F P
0 g
s
.722 .282 .205 r
.56753 .65153 m .5671 .65107 L .56887 .6489 L p F P
0 g
s
.706 .262 .194 r
.5671 .65107 m .56388 .64794 L .56887 .6489 L closepath p F P
0 g
s
.65 .757 .927 r
.2684 .47659 m .25906 .47985 L .26217 .48285 L p F P
0 g
s
.65 .757 .927 r
.26217 .48285 m .2715 .47961 L .2684 .47659 L p F P
0 g
s
.925 .675 .541 r
.625 .69723 m .62158 .69486 L .6211 .69977 L p F P
0 g
s
.925 .675 .541 r
.6211 .69977 m .6245 .70213 L .625 .69723 L p F P
0 g
s
.651 .826 .967 r
.44831 .72071 m .43864 .72329 L .44144 .72606 L p F P
0 g
s
.651 .826 .967 r
.44144 .72606 m .45111 .72274 L .44831 .72071 L p F P
0 g
s
.651 .758 .928 r
.72636 .47663 m .71618 .4799 L .71851 .4829 L p F P
0 g
s
.651 .758 .928 r
.71851 .4829 m .72868 .47965 L .72636 .47663 L p F P
0 g
s
.557 0 0 r
.56333 .71108 m .56321 .71102 L .5574 .70933 L p F P
0 g
s
.651 .757 .928 r
.42105 .47667 m .41143 .47993 L .41428 .48293 L p F P
0 g
s
.651 .757 .928 r
.41428 .48293 m .42389 .47968 L .42105 .47667 L p F P
0 g
s
.651 .757 .928 r
.57371 .47668 m .5638 .47994 L .56639 .48294 L p F P
0 g
s
.651 .757 .928 r
.56639 .48294 m .57629 .47969 L .57371 .47668 L p F P
0 g
s
.826 .801 .828 r
.62605 .71788 m .6229 .71547 L .61607 .72219 L p F P
0 g
s
.826 .801 .828 r
.61607 .72219 m .61894 .72467 L .62605 .71788 L p F P
0 g
s
.888 .554 .412 r
.61695 .68333 m .61284 .68114 L .61362 .68566 L p F P
0 g
s
.888 .554 .412 r
.61362 .68566 m .61777 .68784 L .61695 .68333 L p F P
0 g
s
.361 .169 .479 r
.42991 .69024 m .43771 .68563 L p .43747 .69038 L F P
0 g
s
.361 .169 .479 r
.43747 .69038 m .42975 .69493 L .42991 .69024 L p F P
0 g
s
.317 .093 .407 r
.4382 .68127 m .43771 .68563 L .42991 .69024 L p F P
0 g
s
.658 .76 .925 r
.61129 .72023 m .60349 .72309 L .60601 .72553 L p F P
0 g
s
.658 .76 .925 r
.61544 .72168 m .61129 .72023 L p .60601 .72553 L F P
0 g
s
.658 .76 .925 r
.60601 .72553 m .61596 .72227 L .61544 .72168 L p F P
0 g
s
.349 .662 .972 r
.60153 .72298 m .60349 .72309 L .60601 .72553 L p F P
0 g
s
.339 0 0 r
.50856 .70702 m .51085 .70552 L .52064 .70606 L p F P
0 g
s
.272 0 0 r
.51085 .70552 m .50856 .70702 L .50451 .70769 L p F P
0 g
s
.775 .348 .235 r
.58307 .65856 m .58223 .65735 L .58363 .65568 L p F P
0 g
s
.762 .329 .224 r
.58223 .65735 m .58022 .65471 L .58363 .65568 L closepath p F P
0 g
s
.185 0 0 r
.56333 .71108 m .57118 .71351 L .5656 .71175 L p F P
0 g
s
.185 0 0 r
.5656 .71175 m .56076 .71078 L .56333 .71108 L p F P
0 g
s
.557 0 0 r
.5574 .70933 m .56076 .71078 L .56333 .71108 L p F P
0 g
s
.911 .618 .476 r
.62141 .69015 m .62158 .69486 L .61795 .69254 L p F P
0 g
s
.911 .618 .476 r
.61781 .68786 m .62141 .69015 L p .61795 .69254 L F P
0 g
s
.794 .802 .859 r
.61607 .72219 m .61596 .72227 L .61847 .72503 L p F P
0 g
s
.794 .802 .859 r
.61847 .72503 m .61894 .72467 L .61607 .72219 L p F P
0 g
s
.357 .211 .542 r
.42671 .69704 m .42975 .69493 L .43 .70002 L p F P
0 g
s
.357 .211 .542 r
.43 .70002 m .42815 .7013 L .42671 .69704 L p F P
0 g
s
.65 .757 .927 r
.28086 .47635 m .2715 .47961 L .27459 .48261 L p F P
0 g
s
.65 .757 .927 r
.27459 .48261 m .28394 .47937 L .28086 .47635 L p F P
0 g
s
.561 .137 .194 r
.51568 .64171 m .52289 .64154 L p .51668 .64452 L F P
0 g
s
.561 .137 .194 r
.51668 .64452 m .51451 .6437 L .51568 .64171 L p F P
0 g
s
.651 .758 .928 r
.73889 .47638 m .72868 .47965 L .73099 .48265 L p F P
0 g
s
.651 .758 .928 r
.73099 .48265 m .74119 .47939 L .73889 .47638 L p F P
0 g
s
.601 .171 .197 r
.53408 .64169 m .53948 .64472 L p .52899 .64435 L F P
0 g
s
.601 .171 .197 r
.52813 .64147 m .53408 .64169 L p .52899 .64435 L F P
0 g
s
.651 .757 .928 r
.43354 .47642 m .42389 .47968 L .42672 .48268 L p F P
0 g
s
.651 .757 .928 r
.42672 .48268 m .43636 .47943 L .43354 .47642 L p F P
0 g
s
.651 .757 .928 r
.58622 .47643 m .57629 .47969 L .57886 .48269 L p F P
0 g
s
.651 .757 .928 r
.57886 .48269 m .58877 .47944 L .58622 .47643 L p F P
0 g
s
.393 .332 .67 r
.42365 .71079 m .42363 .71077 L .42365 .71076 L closepath p F P
0 g
s
.419 .388 .718 r
.42363 .71077 m .42365 .71079 L .42555 .71739 L p F P
0 g
s
.465 .409 .711 r
.42365 .71076 m .43082 .70565 L .4326 .71218 L p F P
0 g
s
.465 .409 .711 r
.42365 .71079 m .42365 .71076 L p .4326 .71218 L F P
0 g
s
.399 .296 .621 r
.4305 .70385 m .43082 .70565 L .42365 .71076 L p F P
0 g
s
.399 .296 .621 r
.42815 .7013 m .4305 .70385 L p .42365 .71076 L F P
0 g
s
.465 .409 .711 r
.4326 .71218 m .43098 .71332 L .42365 .71079 L p F P
0 g
s
.461 .414 .72 r
.43098 .71332 m .42555 .71739 L .42365 .71079 L closepath p F P
0 g
s
.364 .063 .313 r
.44764 .67183 m .45492 .66647 L .44831 .6692 L closepath p F P
0 g
s
.295 .003 .286 r
.44831 .6692 m .44764 .67183 L .44542 .67398 L p F P
0 g
s
.804 .393 .268 r
.59387 .66228 m .58859 .66039 L .59084 .66444 L p F P
0 g
s
.804 .393 .268 r
.59084 .66444 m .59617 .66631 L .59387 .66228 L p F P
0 g
s
.561 .137 .194 r
.52289 .64154 m .52699 .64329 L p .51668 .64452 L F P
0 g
s
.574 .142 .182 r
.52699 .64329 m .52289 .64154 L .52813 .64147 L closepath p F P
0 g
s
.498 .482 .77 r
.43313 .71365 m .43586 .71935 L .4263 .71937 L p F P
0 g
s
.498 .482 .77 r
.43098 .71332 m .43313 .71365 L p .4263 .71937 L F P
0 g
s
.498 .482 .77 r
.4263 .71937 m .42555 .71739 L .43098 .71332 L p F P
0 g
s
.58 .649 .883 r
.4263 .71937 m .43586 .71935 L .43718 .72129 L p F P
0 g
s
.65 .757 .927 r
.29333 .47611 m .28394 .47937 L .28701 .48237 L p F P
0 g
s
.65 .757 .927 r
.28701 .48237 m .29639 .47913 L .29333 .47611 L p F P
0 g
s
.651 .758 .928 r
.75143 .47612 m .74119 .47939 L .74348 .48239 L p F P
0 g
s
.651 .758 .928 r
.74348 .48239 m .7537 .47913 L .75143 .47612 L p F P
0 g
s
.601 .171 .197 r
.52899 .64435 m .52699 .64329 L .52813 .64147 L p F P
0 g
s
.423 .062 .245 r
.46782 .65874 m .46915 .65529 L .47912 .65261 L p F P
0 g
s
.394 .009 .186 r
.47978 .65122 m .47912 .65261 L .46915 .65529 L p F P
0 g
s
.364 .008 .22 r
.46915 .65529 m .46782 .65874 L .45838 .66191 L p F P
0 g
s
.651 .757 .928 r
.44603 .47617 m .43636 .47943 L .43916 .48244 L p F P
0 g
s
.651 .757 .928 r
.43916 .48244 m .44882 .47918 L .44603 .47617 L p F P
0 g
s
.651 .757 .928 r
.59873 .47617 m .58877 .47944 L .59132 .48244 L p F P
0 g
s
.651 .757 .928 r
.59132 .48244 m .60126 .47919 L .59873 .47617 L p F P
0 g
s
.451 0 0 r
.5332 .70626 m .53577 .70509 L .54239 .70691 L closepath p F P
0 g
s
.469 0 0 r
.53577 .70509 m .5332 .70626 L .53293 .70625 L p F P
0 g
s
.679 .229 .175 r
.55357 .64617 m .55456 .64498 L .55654 .64663 L closepath p F P
0 g
s
.642 .184 .15 r
.54833 .64559 m .55357 .64617 L .55456 .64498 L p F P
0 g
s
.651 .758 .927 r
.76396 .47586 m .7537 .47913 L .75597 .48213 L p F P
0 g
s
.651 .758 .927 r
.75597 .48213 m .76622 .47887 L .76396 .47586 L p F P
0 g
s
.65 .757 .928 r
.3058 .47587 m .29639 .47913 L .29943 .48213 L p F P
0 g
s
.65 .757 .928 r
.29943 .48213 m .30884 .47889 L .3058 .47587 L p F P
0 g
s
.651 .757 .928 r
.61124 .47592 m .60126 .47919 L .60379 .48219 L p F P
0 g
s
.651 .757 .928 r
.60379 .48219 m .61376 .47893 L .61124 .47592 L p F P
0 g
s
.651 .757 .928 r
.45852 .47592 m .44882 .47918 L .45161 .48219 L p F P
0 g
s
.651 .757 .928 r
.45161 .48219 m .4613 .47894 L .45852 .47592 L p F P
0 g
s
.59 .669 .895 r
.43864 .72329 m .4334 .72417 L .43718 .72129 L closepath p F P
0 g
s
0 .488 .793 r
.58842 .71892 m .58151 .71724 L .57601 .71547 L p F P
0 g
s
0 .448 .799 r
.58151 .71724 m .58842 .71892 L .59095 .72083 L p F P
0 g
s
.393 .059 .275 r
.45741 .66492 m .45838 .66191 L .46782 .65874 L p F P
0 g
s
.327 0 .248 r
.45838 .66191 m .45741 .66492 L .45492 .66647 L p F P
0 g
s
.651 .758 .927 r
.7765 .47559 m .76622 .47887 L .76846 .48187 L p F P
0 g
s
.651 .758 .927 r
.76846 .48187 m .77873 .47861 L .7765 .47559 L p F P
0 g
s
.65 .757 .928 r
.31828 .47562 m .30884 .47889 L .31186 .48189 L p F P
0 g
s
.65 .757 .928 r
.31186 .48189 m .32129 .47864 L .31828 .47562 L p F P
0 g
s
.69 .242 .182 r
.56388 .64794 m .55654 .64663 L .56016 .65023 L p F P
0 g
s
.69 .242 .182 r
.5671 .65107 m .56388 .64794 L p .56016 .65023 L F P
0 g
s
.651 .757 .928 r
.62376 .47566 m .61376 .47893 L .61627 .48194 L p F P
0 g
s
.651 .757 .928 r
.61627 .48194 m .62626 .47868 L .62376 .47566 L p F P
0 g
s
.651 .757 .928 r
.47102 .47567 m .4613 .47894 L .46406 .48194 L p F P
0 g
s
.651 .757 .928 r
.46406 .48194 m .47377 .47869 L .47102 .47567 L p F P
0 g
s
.65 .756 .927 r
.17801 .47521 m .16883 .47846 L .17209 .48148 L p F P
0 g
s
.65 .756 .927 r
.17209 .48148 m .18126 .47823 L .17801 .47521 L p F P
0 g
s
.746 .31 .216 r
.58022 .65471 m .574 .65309 L .5769 .65692 L p F P
0 g
s
.746 .31 .216 r
.58223 .65735 m .58022 .65471 L p .5769 .65692 L F P
0 g
s
.144 0 0 r
.49759 .70871 m .49838 .70832 L .50451 .70769 L closepath p F P
0 g
s
.651 .758 .927 r
.78904 .47533 m .77873 .47861 L .78096 .48161 L p F P
0 g
s
.651 .758 .927 r
.78096 .48161 m .79126 .47835 L .78904 .47533 L p F P
0 g
s
.65 .757 .928 r
.33076 .47538 m .32129 .47864 L .3243 .48165 L p F P
0 g
s
.65 .757 .928 r
.3243 .48165 m .33375 .4784 L .33076 .47538 L p F P
0 g
s
.651 .757 .928 r
.63629 .47541 m .62626 .47868 L .62874 .48168 L p F P
0 g
s
.651 .757 .928 r
.62874 .48168 m .63876 .47843 L .63629 .47541 L p F P
0 g
s
.651 .757 .928 r
.48352 .47542 m .47377 .47869 L .47652 .48169 L p F P
0 g
s
.651 .757 .928 r
.47652 .48169 m .48625 .47844 L .48352 .47542 L p F P
0 g
s
.65 .757 .927 r
.19047 .47498 m .18126 .47823 L .18451 .48125 L p F P
0 g
s
.65 .757 .927 r
.18451 .48125 m .1937 .47801 L .19047 .47498 L p F P
0 g
s
.837 .452 .322 r
.60109 .6683 m .60275 .67253 L .59802 .67049 L p F P
0 g
s
.837 .452 .322 r
.59859 .66722 m .60109 .6683 L p .59802 .67049 L F P
0 g
s
.651 .758 .927 r
.80159 .47507 m .79126 .47835 L .79346 .48135 L p F P
0 g
s
.651 .758 .927 r
.79346 .48135 m .80378 .47808 L .80159 .47507 L p F P
0 g
s
.65 .757 .928 r
.34324 .47513 m .33375 .4784 L .33673 .48141 L p F P
0 g
s
.65 .757 .928 r
.33673 .48141 m .34621 .47815 L .34324 .47513 L p F P
0 g
s
.651 .757 .928 r
.64881 .47516 m .63876 .47843 L .64122 .48143 L p F P
0 g
s
.651 .757 .928 r
.64122 .48143 m .65126 .47817 L .64881 .47516 L p F P
0 g
s
.907 .746 .67 r
.62572 .71132 m .62637 .7097 L .6232 .70728 L p F P
0 g
s
.651 .757 .928 r
.49602 .47517 m .48625 .47844 L .48898 .48144 L p F P
0 g
s
.651 .757 .928 r
.48898 .48144 m .49874 .47819 L .49602 .47517 L p F P
0 g
s
.474 .768 .995 r
.59095 .72083 m .59814 .72063 L .59435 .71838 L p F P
0 g
s
.474 .768 .995 r
.59435 .71838 m .58842 .71892 L .59095 .72083 L p F P
0 g
s
.65 .757 .927 r
.20293 .47475 m .1937 .47801 L .19692 .48102 L p F P
0 g
s
.65 .757 .927 r
.19692 .48102 m .20614 .47778 L .20293 .47475 L p F P
0 g
s
.651 .758 .927 r
.81414 .4748 m .80378 .47808 L .80596 .48109 L p F P
0 g
s
.651 .758 .927 r
.80596 .48109 m .81631 .47782 L .81414 .4748 L p F P
0 g
s
.446 .056 .205 r
.47912 .65261 m .47978 .65122 L .4878 .65081 L closepath p F P
0 g
s
.65 .757 .928 r
.35572 .47489 m .34621 .47815 L .34917 .48116 L p F P
0 g
s
.65 .757 .928 r
.34917 .48116 m .35867 .47791 L .35572 .47489 L p F P
0 g
s
.545 .917 .943 r
.47056 .71572 m .46082 .71916 L .46363 .71976 L p F P
0 g
s
.545 .917 .943 r
.46363 .71976 m .47336 .71599 L .47056 .71572 L p F P
0 g
s
.626 .892 .987 r
.46363 .71976 m .46082 .71916 L .45498 .72131 L p F P
0 g
s
.483 .899 .88 r
.47451 .71572 m .47336 .71599 L .46363 .71976 L p F P
0 g
s
.651 .757 .928 r
.66134 .4749 m .65126 .47817 L .65371 .48118 L p F P
0 g
s
.651 .757 .928 r
.65371 .48118 m .66377 .47792 L .66134 .4749 L p F P
0 g
s
.651 .757 .928 r
.50853 .47492 m .49874 .47819 L .50144 .48119 L p F P
0 g
s
.651 .757 .928 r
.50144 .48119 m .51122 .47794 L .50853 .47492 L p F P
0 g
s
.499 .105 .224 r
.48964 .65043 m .49115 .64723 L .50057 .64585 L p F P
0 g
s
.448 .061 .211 r
.49115 .64723 m .48964 .65043 L .4878 .65081 L p F P
0 g
s
.65 .757 .927 r
.21539 .47452 m .20614 .47778 L .20934 .48079 L p F P
0 g
s
.65 .757 .927 r
.20934 .48079 m .21858 .47754 L .21539 .47452 L p F P
0 g
s
.51 0 0 r
.56076 .71078 m .5574 .70933 L .55032 .708 L p F P
0 g
s
.65 .757 .928 r
.36821 .47464 m .35867 .47791 L .36162 .48092 L p F P
0 g
s
.65 .757 .928 r
.36162 .48092 m .37114 .47766 L .36821 .47464 L p F P
0 g
s
.651 .757 .928 r
.67387 .47464 m .66377 .47792 L .66619 .48092 L p F P
0 g
s
.651 .757 .928 r
.66619 .48092 m .67628 .47766 L .67387 .47464 L p F P
0 g
s
.651 .757 .928 r
.52104 .47467 m .51122 .47794 L .5139 .48094 L p F P
0 g
s
.651 .757 .928 r
.5139 .48094 m .52371 .47769 L .52104 .47467 L p F P
0 g
s
.907 .746 .67 r
.6232 .70728 m .62319 .7073 L .62572 .71132 L p F P
0 g
s
.862 .745 .733 r
.62572 .71132 m .6229 .71547 L .61951 .71311 L p F P
0 g
s
.862 .745 .733 r
.61951 .71311 m .62319 .7073 L .62572 .71132 L p F P
0 g
s
.864 .506 .371 r
.60726 .67463 m .60275 .67253 L .60399 .67691 L p F P
0 g
s
.864 .506 .371 r
.60399 .67691 m .60852 .679 L .60726 .67463 L p F P
0 g
s
.384 .687 .979 r
.60349 .72309 m .60153 .72298 L .59814 .72063 L p F P
0 g
s
.625 .895 .987 r
.45111 .72274 m .45498 .72131 L .45169 .72297 L closepath p F P
0 g
s
.369 0 0 r
.54726 .7076 m .54825 .70745 L .55032 .708 L closepath p F P
0 g
s
.481 0 0 r
.54825 .70745 m .54726 .7076 L .54239 .70691 L p F P
0 g
s
.65 .757 .927 r
.22786 .47428 m .21858 .47754 L .22177 .48056 L p F P
0 g
s
.65 .757 .927 r
.22177 .48056 m .23103 .47731 L .22786 .47428 L p F P
0 g
s
.651 .757 .928 r
.68641 .47439 m .67628 .47766 L .67868 .48067 L p F P
0 g
s
.651 .757 .928 r
.67868 .48067 m .6888 .47741 L .68641 .47439 L p F P
0 g
s
.65 .757 .928 r
.3807 .47439 m .37114 .47766 L .37406 .48067 L p F P
0 g
s
.65 .757 .928 r
.37406 .48067 m .38361 .47741 L .3807 .47439 L p F P
0 g
s
.922 .711 .601 r
.6245 .70213 m .6232 .70728 L .62316 .70726 L p F P
0 g
s
.922 .711 .601 r
.6211 .69977 m .6245 .70213 L p .62316 .70726 L F P
0 g
s
.651 .757 .928 r
.53356 .47441 m .52371 .47769 L .52637 .48069 L p F P
0 g
s
.651 .757 .928 r
.52637 .48069 m .53621 .47743 L .53356 .47441 L p F P
0 g
s
.374 .137 .421 r
.4382 .68127 m .44057 .68009 L .43775 .68561 L p F P
0 g
s
.374 .137 .421 r
.43775 .68561 m .43771 .68563 L .4382 .68127 L p F P
0 g
s
.685 .258 .228 r
.55654 .64663 m .56016 .65023 L .55248 .64902 L p F P
0 g
s
.685 .258 .228 r
.55357 .64617 m .55654 .64663 L p .55248 .64902 L F P
0 g
s
.65 .757 .927 r
.24034 .47405 m .23103 .47731 L .23419 .48032 L p F P
0 g
s
.65 .757 .927 r
.23419 .48032 m .24349 .47707 L .24034 .47405 L p F P
0 g
s
.651 .757 .928 r
.69895 .47413 m .6888 .47741 L .69118 .48041 L p F P
0 g
s
.651 .757 .928 r
.69118 .48041 m .70132 .47715 L .69895 .47413 L p F P
0 g
s
.65 .757 .928 r
.3932 .47414 m .38361 .47741 L .38652 .48042 L p F P
0 g
s
.65 .757 .928 r
.38652 .48042 m .39609 .47717 L .3932 .47414 L p F P
0 g
s
.651 .757 .928 r
.54608 .47416 m .53621 .47743 L .53885 .48044 L p F P
0 g
s
.651 .757 .928 r
.53885 .48044 m .5487 .47718 L .54608 .47416 L p F P
0 g
s
.799 .397 .289 r
.58859 .66039 m .58307 .65856 L .58529 .66262 L p F P
0 g
s
.799 .397 .289 r
.58529 .66262 m .59084 .66444 L .58859 .66039 L p F P
0 g
s
.878 .55 .425 r
.61284 .68114 m .60852 .679 L .60927 .68353 L p F P
0 g
s
.878 .55 .425 r
.60927 .68353 m .61362 .68566 L .61284 .68114 L p F P
0 g
s
.29 .784 .749 r
.47336 .71599 m .47451 .71572 L .48392 .71258 L p F P
0 g
s
.324 .808 .778 r
.48588 .71209 m .48392 .71258 L .47451 .71572 L p F P
0 g
s
.406 .248 .552 r
.43 .70002 m .42975 .69493 L .43747 .69038 L p F P
0 g
s
.837 .452 .322 r
.59802 .67049 m .59746 .66915 L .59859 .66722 L p F P
0 g
s
.825 .437 .315 r
.59746 .66915 m .59617 .66631 L .59859 .66722 L closepath p F P
0 g
s
.166 0 0 r
.49564 .70975 m .49759 .70871 L .50451 .70769 L p F P
0 g
s
0 0 0 r
.49564 .70975 m .50543 .70828 L p .49838 .70938 L F P
0 g
s
0 0 0 r
.49402 .71006 m .49564 .70975 L p .49838 .70938 L F P
0 g
s
.061 0 0 r
.49564 .70975 m .48588 .71209 L p .49258 .71015 L F P
0 g
s
.061 0 0 r
.49759 .70871 m .49564 .70975 L p .49258 .71015 L F P
0 g
s
.921 .665 .533 r
.62158 .69486 m .6211 .69977 L .61933 .69863 L p F P
0 g
s
.921 .665 .533 r
.61795 .69254 m .62158 .69486 L p .61933 .69863 L F P
0 g
s
.65 .757 .927 r
.25281 .47381 m .24349 .47707 L .24662 .48009 L p F P
0 g
s
.65 .757 .927 r
.24662 .48009 m .25594 .47683 L .25281 .47381 L p F P
0 g
s
.362 .06 .311 r
.44733 .67306 m .44764 .67183 L .45492 .66647 L p F P
0 g
s
.307 .013 .291 r
.44733 .67306 m .44764 .67183 L .44542 .67398 L closepath p F P
0 g
s
.651 .757 .928 r
.71149 .47387 m .70132 .47715 L .70368 .48016 L p F P
0 g
s
.651 .757 .928 r
.70368 .48016 m .71384 .47689 L .71149 .47387 L p F P
0 g
s
.911 .618 .476 r
.61795 .69254 m .61783 .68922 L .61781 .68786 L p F P
0 g
s
.902 .61 .481 r
.61783 .68922 m .61777 .68784 L .61781 .68786 L closepath p F P
0 g
s
.651 .757 .928 r
.4057 .4739 m .39609 .47717 L .39897 .48018 L p F P
0 g
s
.651 .757 .928 r
.39897 .48018 m .40857 .47692 L .4057 .4739 L p F P
0 g
s
.131 .63 .907 r
.57576 .71541 m .57586 .71546 L .57601 .71547 L closepath p F P
0 g
s
.322 0 0 r
.57586 .71546 m .57576 .71541 L .57118 .71351 L p F P
0 g
s
.651 .757 .928 r
.5586 .47391 m .5487 .47718 L .55132 .48019 L p F P
0 g
s
.651 .757 .928 r
.55132 .48019 m .56121 .47693 L .5586 .47391 L p F P
0 g
s
.889 .597 .488 r
.61777 .68784 m .61362 .68566 L .61378 .69037 L p F P
0 g
s
.889 .597 .488 r
.61783 .68922 m .61777 .68784 L p .61378 .69037 L F P
0 g
s
.353 .089 .368 r
.44542 .67398 m .44733 .67306 L .44662 .67719 L p F P
0 g
s
.353 .089 .368 r
.44662 .67719 m .44057 .68009 L .44542 .67398 L p F P
0 g
s
.187 .668 .93 r
.57601 .71547 m .58587 .71699 L p .58293 .71495 L F P
0 g
s
.187 .668 .93 r
.57576 .71541 m .57601 .71547 L p .58293 .71495 L F P
0 g
s
0 .488 .793 r
.57601 .71547 m .58587 .71699 L .58842 .71892 L p F P
0 g
s
.836 .798 .814 r
.6229 .71547 m .61607 .72219 L .61544 .72168 L p F P
0 g
s
.836 .798 .814 r
.61951 .71311 m .6229 .71547 L p .61544 .72168 L F P
0 g
s
.597 .673 .893 r
.44552 .71767 m .44831 .72071 L .43864 .72329 L p F P
0 g
s
.597 .673 .893 r
.44143 .71843 m .44552 .71767 L p .43864 .72329 L F P
0 g
s
.597 .673 .893 r
.43864 .72329 m .43718 .72129 L .44143 .71843 L p F P
0 g
s
.187 .668 .93 r
.58293 .71495 m .57331 .71425 L .57576 .71541 L p F P
0 g
s
.685 .258 .228 r
.55248 .64902 m .552 .64858 L .55357 .64617 L p F P
0 g
s
.667 .237 .217 r
.552 .64858 m .54833 .64559 L .55357 .64617 L closepath p F P
0 g
s
.647 .87 .982 r
.45802 .71768 m .44831 .72071 L .45111 .72274 L p F P
0 g
s
.647 .87 .982 r
.45965 .71854 m .45802 .71768 L p .45111 .72274 L F P
0 g
s
.647 .87 .982 r
.45111 .72274 m .45498 .72131 L .45965 .71854 L p F P
0 g
s
.749 .332 .258 r
.574 .65309 m .56753 .65153 L .57039 .65537 L p F P
0 g
s
.749 .332 .258 r
.57039 .65537 m .5769 .65692 L .574 .65309 L p F P
0 g
s
.65 .757 .927 r
.26529 .47357 m .25594 .47683 L .25906 .47985 L p F P
0 g
s
.65 .757 .927 r
.25906 .47985 m .2684 .47659 L .26529 .47357 L p F P
0 g
s
.651 .757 .928 r
.72404 .47361 m .71384 .47689 L .71618 .4799 L p F P
0 g
s
.651 .757 .928 r
.71618 .4799 m .72636 .47663 L .72404 .47361 L p F P
0 g
s
.651 .757 .928 r
.4182 .47365 m .40857 .47692 L .41143 .47993 L p F P
0 g
s
.651 .757 .928 r
.41143 .47993 m .42105 .47667 L .4182 .47365 L p F P
0 g
s
.651 .757 .928 r
.57112 .47366 m .56121 .47693 L .5638 .47994 L p F P
0 g
s
.651 .757 .928 r
.5638 .47994 m .57371 .47668 L .57112 .47366 L p F P
0 g
s
.797 .796 .851 r
.61596 .72227 m .61607 .72219 L .61544 .72168 L closepath p F P
0 g
s
.673 .774 .926 r
.60694 .71815 m .60096 .72063 L .60349 .72309 L p F P
0 g
s
.673 .774 .926 r
.60349 .72309 m .61129 .72023 L .60694 .71815 L p F P
0 g
s
.384 .687 .979 r
.59814 .72063 m .60096 .72063 L .60349 .72309 L p F P
0 g
s
.405 .292 .611 r
.4305 .70385 m .42815 .7013 L .43 .70002 L closepath p F P
0 g
s
.65 .757 .927 r
.27778 .47333 m .2684 .47659 L .2715 .47961 L p F P
0 g
s
.65 .757 .927 r
.2715 .47961 m .28086 .47635 L .27778 .47333 L p F P
0 g
s
.651 .758 .928 r
.73659 .47335 m .72636 .47663 L .72868 .47965 L p F P
0 g
s
.651 .758 .928 r
.72868 .47965 m .73889 .47638 L .73659 .47335 L p F P
0 g
s
.561 .134 .188 r
.51396 .64462 m .51451 .6437 L .51668 .64452 L closepath p F P
0 g
s
.526 .106 .187 r
.51451 .6437 m .51396 .64462 L .50223 .64562 L p F P
0 g
s
.651 .757 .928 r
.43071 .4734 m .42105 .47667 L .42389 .47968 L p F P
0 g
s
.651 .757 .928 r
.42389 .47968 m .43354 .47642 L .43071 .4734 L p F P
0 g
s
.651 .757 .928 r
.58365 .4734 m .57371 .47668 L .57629 .47969 L p F P
0 g
s
.651 .757 .928 r
.57629 .47969 m .58622 .47643 L .58365 .4734 L p F P
0 g
s
.499 .105 .224 r
.50057 .64585 m .50202 .64608 L p .48964 .65043 L F P
0 g
s
.509 .117 .233 r
.50202 .64608 m .50057 .64585 L .50223 .64562 L closepath p F P
0 g
s
.601 .169 .191 r
.52634 .64429 m .52699 .64329 L .52899 .64435 L closepath p F P
0 g
s
.561 .137 .194 r
.52699 .64329 m .52634 .64429 L .51668 .64452 L p F P
0 g
s
.362 .06 .311 r
.45492 .66647 m .45721 .66555 L p .44733 .67306 L F P
0 g
s
.333 .003 .248 r
.45721 .66555 m .45741 .66492 L .45492 .66647 L closepath p F P
0 g
s
.284 0 0 r
.55032 .708 m .55818 .71035 L p .55191 .70894 L F P
0 g
s
.284 0 0 r
.54726 .7076 m .55032 .708 L p .55191 .70894 L F P
0 g
s
.51 0 0 r
.55032 .708 m .55818 .71035 L .56076 .71078 L p F P
0 g
s
.476 .112 .267 r
.47782 .65606 m .47912 .65261 L .4878 .65081 L p F P
0 g
s
.423 .062 .245 r
.47912 .65261 m .47782 .65606 L .46782 .65874 L p F P
0 g
s
.65 .757 .927 r
.29026 .47308 m .28086 .47635 L .28394 .47937 L p F P
0 g
s
.65 .757 .927 r
.28394 .47937 m .29333 .47611 L .29026 .47308 L p F P
0 g
s
.651 .758 .927 r
.74914 .47309 m .73889 .47638 L .74119 .47939 L p F P
0 g
s
.651 .758 .927 r
.74119 .47939 m .75143 .47612 L .74914 .47309 L p F P
0 g
s
.651 .757 .928 r
.44322 .47315 m .43354 .47642 L .43636 .47943 L p F P
0 g
s
.651 .757 .928 r
.43636 .47943 m .44603 .47617 L .44322 .47315 L p F P
0 g
s
.775 .348 .237 r
.5816 .65812 m .58223 .65735 L .58307 .65856 L closepath p F P
0 g
s
.746 .31 .216 r
.5769 .65692 m .5816 .65812 L .58223 .65735 L p F P
0 g
s
.651 .757 .928 r
.59619 .47315 m .58622 .47643 L .58877 .47944 L p F P
0 g
s
.651 .757 .928 r
.58877 .47944 m .59873 .47617 L .59619 .47315 L p F P
0 g
s
.906 .613 .479 r
.61786 .69249 m .61783 .68922 L .61795 .69254 L closepath p F P
0 g
s
.889 .597 .488 r
.61378 .69037 m .61786 .69249 L .61783 .68922 L p F P
0 g
s
.544 .152 .249 r
.50223 .64562 m .51396 .64462 L p .50859 .64808 L F P
0 g
s
.544 .152 .249 r
.50859 .64808 m .50202 .64608 L .50223 .64562 L p F P
0 g
s
.652 .219 .206 r
.54833 .64559 m .53948 .64472 L .54362 .64816 L p F P
0 g
s
.652 .219 .206 r
.552 .64858 m .54833 .64559 L p .54362 .64816 L F P
0 g
s
.812 .421 .313 r
.59617 .66631 m .59084 .66444 L .59271 .66861 L p F P
0 g
s
.812 .421 .313 r
.59746 .66915 m .59617 .66631 L p .59271 .66861 L F P
0 g
s
.836 .798 .814 r
.61544 .72168 m .61344 .71938 L .61951 .71311 L p F P
0 g
s
.684 .766 .914 r
.61129 .72023 m .61544 .72168 L .61344 .71938 L closepath p F P
0 g
s
.39 .153 .43 r
.44057 .68009 m .44662 .67719 L .44617 .68158 L p F P
0 g
s
.39 .153 .43 r
.44617 .68158 m .43775 .68561 L .44057 .68009 L p F P
0 g
s
.65 .757 .927 r
.30276 .47284 m .29333 .47611 L .29639 .47913 L p F P
0 g
s
.65 .757 .927 r
.29639 .47913 m .3058 .47587 L .30276 .47284 L p F P
0 g
s
.651 .758 .927 r
.7617 .47283 m .75143 .47612 L .7537 .47913 L p F P
0 g
s
.651 .758 .927 r
.7537 .47913 m .76396 .47586 L .7617 .47283 L p F P
0 g
s
.651 .757 .928 r
.45574 .4729 m .44603 .47617 L .44882 .47918 L p F P
0 g
s
.651 .757 .928 r
.44882 .47918 m .45852 .47592 L .45574 .4729 L p F P
0 g
s
.651 .757 .928 r
.60872 .47289 m .59873 .47617 L .60126 .47919 L p F P
0 g
s
.651 .757 .928 r
.60126 .47919 m .61124 .47592 L .60872 .47289 L p F P
0 g
s
.166 0 0 r
.50451 .70769 m .50815 .70731 L p .49564 .70975 L F P
0 g
s
.218 0 0 r
.50815 .70731 m .50451 .70769 L .50856 .70702 L closepath p F P
0 g
s
.409 .136 .385 r
.44662 .67719 m .44733 .67306 L .45629 .66945 L p F P
0 g
s
.362 .06 .311 r
.45721 .66555 m .45629 .66945 L .44733 .67306 L p F P
0 g
s
.392 .056 .272 r
.45721 .66555 m .45741 .66492 L .46715 .66092 L p F P
0 g
s
.393 .059 .275 r
.46782 .65874 m .46715 .66092 L .45741 .66492 L p F P
0 g
s
.284 0 0 r
.55191 .70894 m .54564 .70787 L .54726 .7076 L p F P
0 g
s
.398 0 0 r
.54564 .70787 m .54239 .70691 L .54726 .7076 L closepath p F P
0 g
s
.651 .758 .927 r
.77426 .47257 m .76396 .47586 L .76622 .47887 L p F P
0 g
s
.651 .758 .927 r
.76622 .47887 m .7765 .47559 L .77426 .47257 L p F P
0 g
s
.65 .757 .928 r
.31525 .4726 m .3058 .47587 L .30884 .47889 L p F P
0 g
s
.65 .757 .928 r
.30884 .47889 m .31828 .47562 L .31525 .4726 L p F P
0 g
s
.651 .757 .928 r
.62126 .47264 m .61124 .47592 L .61376 .47893 L p F P
0 g
s
.651 .757 .928 r
.61376 .47893 m .62376 .47566 L .62126 .47264 L p F P
0 g
s
.651 .757 .928 r
.46826 .47265 m .45852 .47592 L .4613 .47894 L p F P
0 g
s
.651 .757 .928 r
.4613 .47894 m .47102 .47567 L .46826 .47265 L p F P
0 g
s
.647 .87 .982 r
.45965 .71854 m .46082 .71916 L .45498 .72131 L closepath p F P
0 g
s
.589 .653 .881 r
.44143 .71843 m .43718 .72129 L .43586 .71935 L closepath p F P
0 g
s
.544 .15 .245 r
.50075 .64882 m .50202 .64608 L .50859 .64808 L closepath p F P
0 g
s
.499 .105 .224 r
.50202 .64608 m .50075 .64882 L .48964 .65043 L p F P
0 g
s
.651 .758 .927 r
.78683 .4723 m .7765 .47559 L .77873 .47861 L p F P
0 g
s
.651 .758 .927 r
.77873 .47861 m .78904 .47533 L .78683 .4723 L p F P
0 g
s
.722 .282 .205 r
.56685 .65138 m .5671 .65107 L .56753 .65153 L closepath p F P
0 g
s
.69 .242 .182 r
.56016 .65023 m .56685 .65138 L .5671 .65107 L p F P
0 g
s
.65 .757 .928 r
.32775 .47235 m .31828 .47562 L .32129 .47864 L p F P
0 g
s
.65 .757 .928 r
.32129 .47864 m .33076 .47538 L .32775 .47235 L p F P
0 g
s
.651 .757 .928 r
.6338 .47238 m .62376 .47566 L .62626 .47868 L p F P
0 g
s
.651 .757 .928 r
.62626 .47868 m .63629 .47541 L .6338 .47238 L p F P
0 g
s
.651 .757 .928 r
.48078 .47239 m .47102 .47567 L .47377 .47869 L p F P
0 g
s
.651 .757 .928 r
.47377 .47869 m .48352 .47542 L .48078 .47239 L p F P
0 g
s
.901 .73 .662 r
.62319 .7073 m .6232 .70728 L .62316 .70726 L closepath p F P
0 g
s
.863 .747 .734 r
.62319 .7073 m .62316 .70726 L p .61592 .71081 L F P
0 g
s
.863 .747 .734 r
.61592 .71081 m .61951 .71311 L .62319 .7073 L p F P
0 g
s
0 .557 .759 r
.56076 .71078 m .5656 .71175 L .55861 .71039 L p F P
0 g
s
0 .557 .759 r
.55861 .71039 m .55818 .71035 L .56076 .71078 L p F P
0 g
s
.922 .711 .601 r
.62316 .70726 m .62061 .70188 L .6211 .69977 L p F P
0 g
s
.863 .747 .734 r
.62316 .70726 m .61946 .70501 L .61592 .71081 L p F P
0 g
s
.887 .707 .654 r
.61946 .70501 m .62316 .70726 L .62061 .70188 L closepath p F P
0 g
s
.452 .115 .302 r
.46715 .66092 m .46782 .65874 L .47782 .65606 L p F P
0 g
s
.65 .757 .927 r
.18722 .47195 m .17801 .47521 L .18126 .47823 L p F P
0 g
s
.65 .757 .927 r
.18126 .47823 m .19047 .47498 L .18722 .47195 L p F P
0 g
s
.855 .502 .383 r
.60275 .67253 m .59802 .67049 L .59925 .67487 L p F P
0 g
s
.855 .502 .383 r
.59925 .67487 m .60399 .67691 L .60275 .67253 L p F P
0 g
s
.651 .758 .927 r
.79939 .47204 m .78904 .47533 L .79126 .47835 L p F P
0 g
s
.651 .758 .927 r
.79126 .47835 m .80159 .47507 L .79939 .47204 L p F P
0 g
s
.431 .126 .345 r
.45629 .66945 m .45721 .66555 L .46669 .66239 L p F P
0 g
s
.392 .056 .272 r
.46715 .66092 m .46669 .66239 L .45721 .66555 L p F P
0 g
s
.65 .757 .928 r
.34025 .4721 m .33076 .47538 L .33375 .4784 L p F P
0 g
s
.65 .757 .928 r
.33375 .4784 m .34324 .47513 L .34025 .4721 L p F P
0 g
s
.459 .882 .918 r
.48033 .71265 m .47056 .71572 L .47336 .71599 L p F P
0 g
s
.459 .882 .918 r
.47336 .71599 m .48311 .71281 L .48033 .71265 L p F P
0 g
s
.4 .847 .918 r
.48311 .71281 m .49289 .71032 L .49107 .71014 L p F P
0 g
s
.4 .847 .918 r
.49107 .71014 m .49013 .71004 L p .48311 .71281 L F P
0 g
s
.29 .784 .749 r
.48311 .71281 m .47336 .71599 L p .48068 .71362 L F P
0 g
s
.29 .784 .749 r
.48392 .71258 m .48311 .71281 L p .48068 .71362 L F P
0 g
s
.651 .757 .928 r
.64635 .47213 m .63629 .47541 L .63876 .47843 L p F P
0 g
s
.651 .757 .928 r
.63876 .47843 m .64881 .47516 L .64635 .47213 L p F P
0 g
s
.651 .757 .928 r
.4933 .47214 m .48352 .47542 L .48625 .47844 L p F P
0 g
s
.651 .757 .928 r
.48625 .47844 m .49602 .47517 L .4933 .47214 L p F P
0 g
s
.634 .19 .178 r
.53947 .64472 m .53948 .64472 L .53948 .64472 L closepath p F P
0 g
s
.601 .171 .197 r
.53948 .64472 m .53947 .64472 L .52899 .64435 L p F P
0 g
s
.661 .249 .253 r
.53948 .64472 m .53947 .64472 L .53785 .64769 L p F P
0 g
s
.661 .249 .253 r
.53785 .64769 m .54362 .64816 L .53948 .64472 L p F P
0 g
s
.626 .211 .235 r
.53947 .64472 m .52899 .64435 L .53388 .64755 L p F P
0 g
s
.626 .211 .235 r
.53388 .64755 m .53785 .64769 L .53947 .64472 L p F P
0 g
s
.793 .397 .305 r
.58307 .65856 m .5816 .65812 L .57996 .661 L p F P
0 g
s
.793 .397 .305 r
.57996 .661 m .58529 .66262 L .58307 .65856 L p F P
0 g
s
.346 0 0 r
.50815 .70731 m .50856 .70702 L .52037 .70615 L p F P
0 g
s
.339 0 0 r
.52064 .70606 m .52037 .70615 L .50856 .70702 L p F P
0 g
s
.586 .185 .25 r
.51668 .64452 m .51396 .64462 L .51243 .64776 L p F P
0 g
s
.544 .152 .249 r
.51396 .64462 m .51243 .64776 L .50859 .64808 L p F P
0 g
s
.65 .757 .927 r
.19971 .47171 m .19047 .47498 L .1937 .47801 L p F P
0 g
s
.65 .757 .927 r
.1937 .47801 m .20293 .47475 L .19971 .47171 L p F P
0 g
s
.464 .35 .638 r
.43 .70002 m .43783 .69544 L .43868 .7011 L p F P
0 g
s
.464 .35 .638 r
.4305 .70385 m .43 .70002 L p .43868 .7011 L F P
0 g
s
.406 .248 .552 r
.43757 .69062 m .43783 .69544 L .43 .70002 L p F P
0 g
s
.406 .248 .552 r
.43747 .69038 m .43757 .69062 L p .43 .70002 L F P
0 g
s
.745 .336 .277 r
.56753 .65153 m .56685 .65138 L .56517 .65424 L p F P
0 g
s
.745 .336 .277 r
.56517 .65424 m .57039 .65537 L .56753 .65153 L p F P
0 g
s
.651 .758 .927 r
.81196 .47177 m .80159 .47507 L .80378 .47808 L p F P
0 g
s
.651 .758 .927 r
.80378 .47808 m .81414 .4748 L .81196 .47177 L p F P
0 g
s
.46 0 0 r
.54239 .70691 m .54564 .70787 L p .53313 .70629 L F P
0 g
s
.46 0 0 r
.53313 .70629 m .5332 .70626 L .54239 .70691 L p F P
0 g
s
.65 .757 .928 r
.35276 .47186 m .34324 .47513 L .34621 .47815 L p F P
0 g
s
.65 .757 .928 r
.34621 .47815 m .35572 .47489 L .35276 .47186 L p F P
0 g
s
.651 .757 .928 r
.6589 .47187 m .64881 .47516 L .65126 .47817 L p F P
0 g
s
.651 .757 .928 r
.65126 .47817 m .66134 .4749 L .6589 .47187 L p F P
0 g
s
.586 .185 .25 r
.51243 .64776 m .52264 .64739 L .51668 .64452 L p F P
0 g
s
.587 .177 .233 r
.52634 .64429 m .51668 .64452 L .52264 .64739 L p F P
0 g
s
.651 .757 .928 r
.50583 .47189 m .49602 .47517 L .49874 .47819 L p F P
0 g
s
.651 .757 .928 r
.49874 .47819 m .50853 .47492 L .50583 .47189 L p F P
0 g
s
.714 .3 .259 r
.56685 .65138 m .56016 .65023 L .56345 .65394 L p F P
0 g
s
.714 .3 .259 r
.56345 .65394 m .56517 .65424 L .56685 .65138 L p F P
0 g
s
.428 .715 .984 r
.60096 .72063 m .59814 .72063 L .59435 .71838 L p F P
0 g
s
.65 .757 .927 r
.21219 .47148 m .20293 .47475 L .20614 .47778 L p F P
0 g
s
.65 .757 .927 r
.20614 .47778 m .21539 .47452 L .21219 .47148 L p F P
0 g
s
.531 .794 .993 r
.58842 .71892 m .59435 .71838 L .58966 .71638 L p F P
0 g
s
.531 .794 .993 r
.58966 .71638 m .58587 .71699 L .58842 .71892 L p F P
0 g
s
.87 .545 .435 r
.60852 .679 m .60399 .67691 L .60472 .68144 L p F P
0 g
s
.87 .545 .435 r
.60472 .68144 m .60927 .68353 L .60852 .679 L p F P
0 g
s
.624 .217 .251 r
.52899 .64435 m .52634 .64429 L .52477 .64734 L p F P
0 g
s
.624 .217 .251 r
.52477 .64734 m .53388 .64755 L .52899 .64435 L p F P
0 g
s
.905 .691 .603 r
.62061 .70188 m .6211 .69977 L .61933 .69863 L closepath p F P
0 g
s
.65 .757 .928 r
.36527 .47161 m .35572 .47489 L .35867 .47791 L p F P
0 g
s
.65 .757 .928 r
.35867 .47791 m .36821 .47464 L .36527 .47161 L p F P
0 g
s
.651 .757 .928 r
.67146 .47162 m .66134 .4749 L .66377 .47792 L p F P
0 g
s
.651 .757 .928 r
.66377 .47792 m .67387 .47464 L .67146 .47162 L p F P
0 g
s
.651 .757 .928 r
.51836 .47164 m .50853 .47492 L .51122 .47794 L p F P
0 g
s
.651 .757 .928 r
.51122 .47794 m .52104 .47467 L .51836 .47164 L p F P
0 g
s
.587 .177 .233 r
.52264 .64739 m .52477 .64734 L .52634 .64429 L p F P
0 g
s
.765 .362 .289 r
.5816 .65812 m .5769 .65692 L .57947 .66087 L p F P
0 g
s
.765 .362 .289 r
.57947 .66087 m .57996 .661 L .5816 .65812 L p F P
0 g
s
.267 0 0 r
.52037 .70615 m .52064 .70606 L .5216 .70613 L closepath p F P
0 g
s
.591 .633 .862 r
.43586 .71935 m .43313 .71365 L p .44474 .71651 L F P
0 g
s
.591 .633 .862 r
.44474 .71651 m .44143 .71843 L .43586 .71935 L p F P
0 g
s
.65 .757 .927 r
.22468 .47125 m .21539 .47452 L .21858 .47754 L p F P
0 g
s
.65 .757 .927 r
.21858 .47754 m .22786 .47428 L .22468 .47125 L p F P
0 g
s
.88 .591 .495 r
.61362 .68566 m .60927 .68353 L .6094 .68825 L p F P
0 g
s
.88 .591 .495 r
.6094 .68825 m .61378 .69037 L .61362 .68566 L p F P
0 g
s
.65 .757 .928 r
.37778 .47136 m .36821 .47464 L .37114 .47766 L p F P
0 g
s
.65 .757 .928 r
.37114 .47766 m .3807 .47439 L .37778 .47136 L p F P
0 g
s
.651 .757 .928 r
.68401 .47136 m .67387 .47464 L .67628 .47766 L p F P
0 g
s
.651 .757 .928 r
.67628 .47766 m .68641 .47439 L .68401 .47136 L p F P
0 g
s
.651 .757 .928 r
.5309 .47139 m .52104 .47467 L .52371 .47769 L p F P
0 g
s
.651 .757 .928 r
.52371 .47769 m .53356 .47441 L .5309 .47139 L p F P
0 g
s
.415 .211 .492 r
.43766 .68701 m .43775 .68561 L .43771 .68563 L closepath p F P
0 g
s
.361 .169 .479 r
.43771 .68563 m .43766 .68701 L .43747 .69038 L p F P
0 g
s
.903 .646 .54 r
.61793 .69283 m .61795 .69254 L .61786 .69249 L closepath p F P
0 g
s
.921 .665 .533 r
.61933 .69863 m .61793 .69283 L .61795 .69254 L p F P
0 g
s
.416 .212 .492 r
.43775 .68561 m .44617 .68158 L p .43755 .69033 L F P
0 g
s
.416 .212 .492 r
.43755 .69033 m .43766 .68701 L .43775 .68561 L p F P
0 g
s
.5 .473 .759 r
.43313 .71365 m .43098 .71332 L .4326 .71218 L closepath p F P
0 g
s
.706 .762 .895 r
.61344 .71938 m .61129 .72023 L .60694 .71815 L p F P
0 g
s
.884 .641 .565 r
.61786 .69249 m .61378 .69037 L .61312 .69533 L p F P
0 g
s
.884 .641 .565 r
.61793 .69283 m .61786 .69249 L p .61312 .69533 L F P
0 g
s
.086 0 0 r
.50815 .70731 m .51796 .70705 L p .50792 .70804 L F P
0 g
s
.086 0 0 r
.51796 .70705 m .51656 .70718 L .50792 .70804 L p F P
0 g
s
0 0 0 r
.51526 .70734 m .50792 .70804 L .50884 .70795 L p F P
0 g
s
0 0 0 r
.50884 .70795 m .51656 .70718 L .51526 .70734 L p F P
0 g
s
.192 0 0 r
.52037 .70615 m .5216 .70613 L p .52321 .70703 L F P
0 g
s
.192 0 0 r
.52321 .70703 m .51796 .70705 L .52037 .70615 L p F P
0 g
s
.192 0 0 r
.5216 .70613 m .53048 .70695 L p .52321 .70703 L F P
0 g
s
.054 0 0 r
.51656 .70718 m .51796 .70705 L .52321 .70703 L closepath p F P
0 g
s
.077 0 0 r
.51526 .70734 m .51656 .70718 L .52321 .70703 L p F P
0 g
s
.312 .792 .909 r
.51526 .70734 m .52514 .70652 L p .52485 .70644 L F P
0 g
s
.346 0 0 r
.52037 .70615 m .51796 .70705 L .50815 .70731 L p F P
0 g
s
.438 0 0 r
.53313 .70629 m .53293 .70625 L .5216 .70613 L p F P
0 g
s
.438 0 0 r
.5216 .70613 m .53048 .70695 L .53313 .70629 L p F P
0 g
s
.312 .792 .909 r
.52133 .70552 m .51526 .70734 L .52485 .70644 L F
.081 .641 .725 r
.50792 .70804 m .51526 .70734 L p .51513 .70736 L F P
0 g
s
.086 0 0 r
.50544 .70828 m .50815 .70731 L p .50792 .70804 L F P
0 g
s
.166 0 0 r
.50815 .70731 m .50543 .70828 L .49564 .70975 L p F P
0 g
s
.081 .641 .725 r
.5027 .70844 m .50792 .70804 L .51513 .70736 L F
.086 0 0 r
.50792 .70804 m .50543 .70828 L .50544 .70828 L p F P
0 g
s
.884 .641 .565 r
.61312 .69533 m .6173 .6975 L .61793 .69283 L p F P
0 g
s
.894 .651 .564 r
.6173 .6975 m .61933 .69863 L .61793 .69283 L closepath p F P
0 g
s
.65 .757 .927 r
.23717 .47101 m .22786 .47428 L .23103 .47731 L p F P
0 g
s
.65 .757 .927 r
.23103 .47731 m .24034 .47405 L .23717 .47101 L p F P
0 g
s
.409 0 0 r
.53313 .70629 m .53293 .70625 L .5332 .70626 L closepath p F P
0 g
s
.476 .112 .267 r
.4878 .65081 m .48949 .65083 L p .47782 .65606 L F P
0 g
s
.483 .119 .272 r
.48949 .65083 m .4878 .65081 L .48964 .65043 L closepath p F P
0 g
s
.651 .757 .928 r
.69657 .4711 m .68641 .47439 L .6888 .47741 L p F P
0 g
s
.651 .757 .928 r
.6888 .47741 m .69895 .47413 L .69657 .4711 L p F P
0 g
s
.65 .757 .928 r
.3903 .47111 m .3807 .47439 L .38361 .47741 L p F P
0 g
s
.65 .757 .928 r
.38361 .47741 m .3932 .47414 L .3903 .47111 L p F P
0 g
s
.651 .757 .928 r
.54344 .47113 m .53356 .47441 L .53621 .47743 L p F P
0 g
s
.651 .757 .928 r
.53621 .47743 m .54608 .47416 L .54344 .47113 L p F P
0 g
s
.823 .768 .801 r
.61344 .71938 m .61951 .71311 L .61592 .71081 L p F P
0 g
s
.197 0 0 r
.53765 .70705 m .54302 .70794 L p .53452 .70716 L F P
0 g
s
.197 0 0 r
.54302 .70794 m .54283 .70791 L .53452 .70716 L p F P
0 g
s
.001 .574 .763 r
.54039 .70756 m .53452 .70716 L .54283 .70791 L closepath p F P
0 g
s
.105 0 0 r
.53452 .70716 m .54039 .70756 L p .53256 .70723 L F P
0 g
s
.105 0 0 r
.52782 .70704 m .53452 .70716 L .53256 .70723 L F
.197 0 0 r
.53313 .70629 m .53765 .70705 L p .53452 .70716 L F P
0 g
s
.197 0 0 r
.53452 .70716 m .53048 .70695 L .53313 .70629 L p F P
0 g
s
.46 0 0 r
.54564 .70787 m .54302 .70794 L .53313 .70629 L p F P
0 g
s
.65 .757 .927 r
.24967 .47077 m .24034 .47405 L .24349 .47707 L p F P
0 g
s
.65 .757 .927 r
.24349 .47707 m .25281 .47381 L .24967 .47077 L p F P
0 g
s
.808 .431 .342 r
.59084 .66444 m .58529 .66262 L .58712 .6668 L p F P
0 g
s
.808 .431 .342 r
.58712 .6668 m .59271 .66861 L .59084 .66444 L p F P
0 g
s
.834 .451 .326 r
.59694 .67007 m .59746 .66915 L .59802 .67049 L closepath p F P
0 g
s
.812 .421 .313 r
.59271 .66861 m .59694 .67007 L .59746 .66915 L p F P
0 g
s
.651 .757 .928 r
.70914 .47084 m .69895 .47413 L .70132 .47715 L p F P
0 g
s
.651 .757 .928 r
.70132 .47715 m .71149 .47387 L .70914 .47084 L p F P
0 g
s
.651 .757 .928 r
.40282 .47086 m .3932 .47414 L .39609 .47717 L p F P
0 g
s
.651 .757 .928 r
.39609 .47717 m .4057 .4739 L .40282 .47086 L p F P
0 g
s
.464 .35 .638 r
.43868 .7011 m .43222 .7048 L .4305 .70385 L p F P
0 g
s
.457 .353 .648 r
.43222 .7048 m .43082 .70565 L .4305 .70385 L closepath p F P
0 g
s
.651 .757 .928 r
.55598 .47088 m .54608 .47416 L .5487 .47718 L p F P
0 g
s
.651 .757 .928 r
.5487 .47718 m .5586 .47391 L .55598 .47088 L p F P
0 g
s
.638 .868 .985 r
.45965 .71854 m .46082 .71916 L .47056 .71572 L p F P
0 g
s
.878 .697 .652 r
.62061 .70188 m .61933 .69863 L p .61551 .70279 L F P
0 g
s
.878 .697 .652 r
.61551 .70279 m .61946 .70501 L .62061 .70188 L p F P
0 g
s
.522 .156 .288 r
.48964 .65043 m .50075 .64882 L p .49795 .65241 L F P
0 g
s
.522 .156 .288 r
.49795 .65241 m .48949 .65083 L .48964 .65043 L p F P
0 g
s
.823 .768 .801 r
.61592 .71081 m .61091 .71631 L .61344 .71938 L p F P
0 g
s
.706 .762 .895 r
.60694 .71815 m .61091 .71631 L .61344 .71938 L p F P
0 g
s
.65 .757 .927 r
.26217 .47053 m .25281 .47381 L .25594 .47683 L p F P
0 g
s
.65 .757 .927 r
.25594 .47683 m .26529 .47357 L .26217 .47053 L p F P
0 g
s
.651 .757 .928 r
.72171 .47058 m .71149 .47387 L .71384 .47689 L p F P
0 g
s
.651 .757 .928 r
.71384 .47689 m .72404 .47361 L .72171 .47058 L p F P
0 g
s
.651 .757 .928 r
.41535 .47061 m .4057 .4739 L .40857 .47692 L p F P
0 g
s
.651 .757 .928 r
.40857 .47692 m .4182 .47365 L .41535 .47061 L p F P
0 g
s
.651 .757 .928 r
.56853 .47062 m .5586 .47391 L .56121 .47693 L p F P
0 g
s
.651 .757 .928 r
.56121 .47693 m .57112 .47366 L .56853 .47062 L p F P
0 g
s
.374 .179 .482 r
.43755 .69033 m .43766 .68701 L .43747 .69038 L closepath p F P
0 g
s
.71 .304 .275 r
.56016 .65023 m .55248 .64902 L .55569 .65275 L p F P
0 g
s
.71 .304 .275 r
.55569 .65275 m .56345 .65394 L .56016 .65023 L p F P
0 g
s
.496 .43 .711 r
.4326 .71218 m .43082 .70565 L .43222 .7048 L p F P
0 g
s
0 0 0 r
.49564 .70975 m .49402 .71006 L .48392 .71258 L p F P
0 g
s
0 0 0 r
.48311 .71281 m .48392 .71258 L .49402 .71006 L p F P
0 g
s
.692 .778 .917 r
.60298 .71594 m .59842 .7181 L .60096 .72063 L p F P
0 g
s
.692 .778 .917 r
.60096 .72063 m .60694 .71815 L .60298 .71594 L p F P
0 g
s
.428 .715 .984 r
.59435 .71838 m .59842 .7181 L .60096 .72063 L p F P
0 g
s
.65 .757 .927 r
.27468 .47029 m .26529 .47357 L .2684 .47659 L p F P
0 g
s
.65 .757 .927 r
.2684 .47659 m .27778 .47333 L .27468 .47029 L p F P
0 g
s
.651 .758 .928 r
.73428 .47032 m .72404 .47361 L .72636 .47663 L p F P
0 g
s
.651 .758 .928 r
.72636 .47663 m .73659 .47335 L .73428 .47032 L p F P
0 g
s
.642 .788 .952 r
.45523 .71521 m .44552 .71767 L .44831 .72071 L p F P
0 g
s
.642 .788 .952 r
.44831 .72071 m .45802 .71768 L .45523 .71521 L p F P
0 g
s
.878 .697 .652 r
.61933 .69863 m .6173 .6975 L .61551 .70279 L p F P
0 g
s
.651 .757 .928 r
.42788 .47036 m .4182 .47365 L .42105 .47667 L p F P
0 g
s
.651 .757 .928 r
.42105 .47667 m .43071 .4734 L .42788 .47036 L p F P
0 g
s
.651 .757 .928 r
.58108 .47037 m .57112 .47366 L .57371 .47668 L p F P
0 g
s
.651 .757 .928 r
.57371 .47668 m .58365 .4734 L .58108 .47037 L p F P
0 g
s
.521 .154 .285 r
.48835 .65388 m .48949 .65083 L .49795 .65241 L closepath p F P
0 g
s
.476 .112 .267 r
.48949 .65083 m .48835 .65388 L .47782 .65606 L p F P
0 g
s
.759 .363 .305 r
.5769 .65692 m .57039 .65537 L .57287 .65935 L p F P
0 g
s
.759 .363 .305 r
.57287 .65935 m .57947 .66087 L .5769 .65692 L p F P
0 g
s
.65 .757 .927 r
.28719 .47005 m .27778 .47333 L .28086 .47635 L p F P
0 g
s
.65 .757 .927 r
.28086 .47635 m .29026 .47308 L .28719 .47005 L p F P
0 g
s
.651 .758 .927 r
.74685 .47006 m .73659 .47335 L .73889 .47638 L p F P
0 g
s
.651 .758 .927 r
.73889 .47638 m .74914 .47309 L .74685 .47006 L p F P
0 g
s
.313 .741 .972 r
.57331 .71425 m .58293 .71495 L .57865 .71282 L p F P
0 g
s
.313 .741 .972 r
.57865 .71282 m .57074 .71296 L .57331 .71425 L p F P
0 g
s
.271 0 0 r
.5656 .71175 m .57074 .71296 L .57331 .71425 L p F P
0 g
s
.651 .757 .928 r
.44041 .47011 m .43071 .4734 L .43354 .47642 L p F P
0 g
s
.651 .757 .928 r
.43354 .47642 m .44322 .47315 L .44041 .47011 L p F P
0 g
s
.651 .757 .928 r
.59363 .47012 m .58365 .4734 L .58622 .47643 L p F P
0 g
s
.651 .757 .928 r
.58622 .47643 m .59619 .47315 L .59363 .47012 L p F P
0 g
s
.449 .111 .298 r
.46669 .66239 m .46715 .66092 L .47688 .65908 L p F P
0 g
s
.452 .115 .302 r
.47782 .65606 m .47688 .65908 L .46715 .66092 L p F P
0 g
s
.527 .49 .758 r
.44035 .70754 m .44275 .71323 L .43313 .71365 L p F P
0 g
s
.527 .49 .758 r
.43313 .71365 m .4326 .71218 L .44035 .70754 L p F P
0 g
s
.591 .633 .862 r
.43313 .71365 m .44275 .71323 L .44474 .71651 L p F P
0 g
s
.496 .43 .711 r
.44004 .7066 m .44035 .70754 L .4326 .71218 L p F P
0 g
s
.496 .43 .711 r
.43222 .7048 m .44004 .7066 L p .4326 .71218 L F P
0 g
s
.845 .496 .393 r
.59802 .67049 m .59694 .67007 L .59586 .67352 L p F P
0 g
s
.845 .496 .393 r
.59586 .67352 m .59925 .67487 L .59802 .67049 L p F P
0 g
s
.65 .757 .927 r
.2997 .4698 m .29026 .47308 L .29333 .47611 L p F P
0 g
s
.65 .757 .927 r
.29333 .47611 m .30276 .47284 L .2997 .4698 L p F P
0 g
s
.651 .758 .927 r
.75943 .4698 m .74914 .47309 L .75143 .47612 L p F P
0 g
s
.651 .758 .927 r
.75143 .47612 m .7617 .47283 L .75943 .4698 L p F P
0 g
s
.651 .757 .928 r
.45294 .46986 m .44322 .47315 L .44603 .47617 L p F P
0 g
s
.651 .757 .928 r
.44603 .47617 m .45574 .4729 L .45294 .46986 L p F P
0 g
s
.651 .757 .928 r
.60619 .46986 m .59619 .47315 L .59873 .47617 L p F P
0 g
s
.651 .757 .928 r
.59873 .47617 m .60872 .47289 L .60619 .46986 L p F P
0 g
s
.084 0 0 r
.54564 .70787 m .55191 .70894 L .5435 .70797 L p F P
0 g
s
.013 .583 .77 r
.5435 .70797 m .55296 .70865 L p .5494 .70834 L F P
0 g
s
.084 0 0 r
.54308 .70794 m .54564 .70787 L p .5435 .70797 L F P
0 g
s
.013 .583 .77 r
.54039 .70756 m .5435 .70797 L .5494 .70834 L F
.084 0 0 r
.5435 .70797 m .54302 .70794 L .54308 .70794 L p F P
0 g
s
.86 .736 .725 r
.61946 .70501 m .61551 .70279 L .61214 .70854 L p F P
0 g
s
.86 .736 .725 r
.61214 .70854 m .61592 .71081 L .61946 .70501 L p F P
0 g
s
.651 .758 .927 r
.77201 .46953 m .7617 .47283 L .76396 .47586 L p F P
0 g
s
.651 .758 .927 r
.76396 .47586 m .77426 .47257 L .77201 .46953 L p F P
0 g
s
.686 .257 .225 r
.55177 .64892 m .552 .64858 L .55248 .64902 L closepath p F P
0 g
s
.652 .219 .206 r
.54362 .64816 m .55177 .64892 L .552 .64858 L p F P
0 g
s
.439 .194 .444 r
.44617 .68158 m .44662 .67719 L .45559 .67357 L p F P
0 g
s
.409 .136 .385 r
.45629 .66945 m .45559 .67357 L .44662 .67719 L p F P
0 g
s
.65 .757 .927 r
.31222 .46956 m .30276 .47284 L .3058 .47587 L p F P
0 g
s
.65 .757 .927 r
.3058 .47587 m .31525 .4726 L .31222 .46956 L p F P
0 g
s
.651 .757 .928 r
.61875 .4696 m .60872 .47289 L .61124 .47592 L p F P
0 g
s
.651 .757 .928 r
.61124 .47592 m .62126 .47264 L .61875 .4696 L p F P
0 g
s
.651 .757 .928 r
.46548 .46961 m .45574 .4729 L .45852 .47592 L p F P
0 g
s
.651 .757 .928 r
.45852 .47592 m .46826 .47265 L .46548 .46961 L p F P
0 g
s
.221 0 0 r
.57074 .71296 m .5656 .71175 L .55861 .71039 L p F P
0 g
s
.498 .417 .695 r
.44004 .7066 m .43222 .7048 L .43868 .7011 L closepath p F P
0 g
s
.823 .469 .386 r
.59694 .67007 m .59271 .66861 L .59412 .67293 L p F P
0 g
s
.823 .469 .386 r
.59412 .67293 m .59586 .67352 L .59694 .67007 L p F P
0 g
s
.651 .758 .927 r
.7846 .46927 m .77426 .47257 L .7765 .47559 L p F P
0 g
s
.651 .758 .927 r
.7765 .47559 m .78683 .4723 L .7846 .46927 L p F P
0 g
s
.65 .757 .928 r
.32474 .46931 m .31525 .4726 L .31828 .47562 L p F P
0 g
s
.65 .757 .928 r
.31828 .47562 m .32775 .47235 L .32474 .46931 L p F P
0 g
s
.651 .757 .928 r
.63132 .46935 m .62126 .47264 L .62376 .47566 L p F P
0 g
s
.651 .757 .928 r
.62376 .47566 m .6338 .47238 L .63132 .46935 L p F P
0 g
s
.651 .757 .928 r
.47802 .46936 m .46826 .47265 L .47102 .47567 L p F P
0 g
s
.651 .757 .928 r
.47102 .47567 m .48078 .47239 L .47802 .46936 L p F P
0 g
s
.619 .865 .989 r
.45802 .71768 m .45965 .71854 L .46849 .71486 L p F P
0 g
s
.638 .868 .985 r
.47056 .71572 m .46849 .71486 L .45965 .71854 L p F P
0 g
s
.861 .54 .443 r
.60399 .67691 m .59925 .67487 L .59997 .67941 L p F P
0 g
s
.861 .54 .443 r
.59997 .67941 m .60472 .68144 L .60399 .67691 L p F P
0 g
s
.494 .151 .314 r
.47782 .65606 m .48835 .65388 L p .47936 .65913 L F P
0 g
s
.494 .151 .314 r
.47936 .65913 m .47688 .65908 L .47782 .65606 L p F P
0 g
s
.598 .653 .875 r
.44552 .71767 m .44143 .71843 L .44474 .71651 L closepath p F P
0 g
s
.707 .31 .293 r
.55248 .64902 m .55177 .64892 L .55027 .652 L p F P
0 g
s
.707 .31 .293 r
.55027 .652 m .55569 .65275 L .55248 .64902 L p F P
0 g
s
.651 .758 .927 r
.79719 .469 m .78683 .4723 L .78904 .47533 L p F P
0 g
s
.651 .758 .927 r
.78904 .47533 m .79939 .47204 L .79719 .469 L p F P
0 g
s
.476 .748 .989 r
.59842 .7181 m .59435 .71838 L .58966 .71638 L p F P
0 g
s
.65 .757 .928 r
.33726 .46907 m .32775 .47235 L .33076 .47538 L p F P
0 g
s
.65 .757 .928 r
.33076 .47538 m .34025 .4721 L .33726 .46907 L p F P
0 g
s
.651 .757 .928 r
.64388 .46909 m .6338 .47238 L .63629 .47541 L p F P
0 g
s
.651 .757 .928 r
.63629 .47541 m .64635 .47213 L .64388 .46909 L p F P
0 g
s
.651 .757 .928 r
.49057 .4691 m .48078 .47239 L .48352 .47542 L p F P
0 g
s
.651 .757 .928 r
.48352 .47542 m .4933 .47214 L .49057 .4691 L p F P
0 g
s
.874 .683 .641 r
.6173 .6975 m .61312 .69533 L .61139 .70061 L p F P
0 g
s
.874 .683 .641 r
.61139 .70061 m .61551 .70279 L .6173 .6975 L p F P
0 g
s
.676 .275 .279 r
.55177 .64892 m .54362 .64816 L .54735 .65173 L p F P
0 g
s
.676 .275 .279 r
.54735 .65173 m .55027 .652 L .55177 .64892 L p F P
0 g
s
.4 .847 .918 r
.49013 .71004 m .48033 .71265 L .48311 .71281 L p F P
0 g
s
0 0 0 r
.50543 .70828 m .50495 .7083 L .49402 .71006 L p F P
0 g
s
.392 .829 .95 r
.49289 .71032 m .5027 .70844 L .50136 .70814 L p F P
0 g
s
.392 .829 .95 r
.50136 .70814 m .49996 .70781 L p .49289 .71032 L F P
0 g
s
0 0 0 r
.49289 .71032 m .48311 .71281 L p .48902 .71132 L F P
0 g
s
0 0 0 r
.49402 .71006 m .49289 .71032 L p .48902 .71132 L F P
0 g
s
.871 .584 .5 r
.60927 .68353 m .60472 .68144 L .60485 .68617 L p F P
0 g
s
.871 .584 .5 r
.60485 .68617 m .6094 .68825 L .60927 .68353 L p F P
0 g
s
.65 .757 .927 r
.19647 .46867 m .18722 .47195 L .19047 .47498 L p F P
0 g
s
.65 .757 .927 r
.19047 .47498 m .19971 .47171 L .19647 .46867 L p F P
0 g
s
.562 .186 .287 r
.49942 .6522 m .50075 .64882 L .50859 .64808 L p F P
0 g
s
.522 .156 .288 r
.50075 .64882 m .49942 .6522 L .49795 .65241 L p F P
0 g
s
.651 .758 .927 r
.80978 .46873 m .79939 .47204 L .80159 .47507 L p F P
0 g
s
.651 .758 .927 r
.80159 .47507 m .81196 .47177 L .80978 .46873 L p F P
0 g
s
.728 .753 .873 r
.61091 .71631 m .60694 .71815 L .60298 .71594 L p F P
0 g
s
.65 .757 .928 r
.34979 .46882 m .34025 .4721 L .34324 .47513 L p F P
0 g
s
.65 .757 .928 r
.34324 .47513 m .35276 .47186 L .34979 .46882 L p F P
0 g
s
.412 .245 .543 r
.43757 .69062 m .43747 .69038 L .43755 .69033 L closepath p F P
0 g
s
.651 .757 .928 r
.65645 .46883 m .64635 .47213 L .64881 .47516 L p F P
0 g
s
.651 .757 .928 r
.64881 .47516 m .6589 .47187 L .65645 .46883 L p F P
0 g
s
.794 .428 .364 r
.58529 .66262 m .58712 .6668 L .58132 .66505 L p F P
0 g
s
.794 .428 .364 r
.57996 .661 m .58529 .66262 L p .58132 .66505 L F P
0 g
s
.876 .632 .566 r
.61378 .69037 m .6094 .68825 L .60876 .69321 L p F P
0 g
s
.876 .632 .566 r
.60876 .69321 m .61312 .69533 L .61378 .69037 L p F P
0 g
s
.651 .757 .928 r
.50312 .46885 m .4933 .47214 L .49602 .47517 L p F P
0 g
s
.651 .757 .928 r
.49602 .47517 m .50583 .47189 L .50312 .46885 L p F P
0 g
s
.462 .288 .558 r
.43755 .69033 m .44603 .68629 L .44629 .69139 L p F P
0 g
s
.462 .288 .558 r
.43757 .69062 m .43755 .69033 L p .44629 .69139 L F P
0 g
s
.416 .212 .492 r
.44617 .68158 m .44603 .68629 L .43755 .69033 L p F P
0 g
s
.458 .177 .399 r
.45559 .67357 m .45629 .66945 L .46578 .66629 L p F P
0 g
s
.431 .126 .345 r
.46669 .66239 m .46578 .66629 L .45629 .66945 L p F P
0 g
s
.65 .757 .927 r
.20898 .46843 m .19971 .47171 L .20293 .47475 L p F P
0 g
s
.65 .757 .927 r
.20293 .47475 m .21219 .47148 L .20898 .46843 L p F P
0 g
s
.462 .288 .558 r
.44629 .69139 m .44021 .69427 L .43757 .69062 L p F P
0 g
s
.454 .286 .563 r
.44021 .69427 m .43783 .69544 L .43757 .69062 L closepath p F P
0 g
s
.65 .757 .928 r
.36232 .46857 m .35276 .47186 L .35572 .47489 L p F P
0 g
s
.65 .757 .928 r
.35572 .47489 m .36527 .47161 L .36232 .46857 L p F P
0 g
s
.651 .757 .928 r
.66903 .46858 m .6589 .47187 L .66134 .4749 L p F P
0 g
s
.651 .757 .928 r
.66134 .4749 m .67146 .47162 L .66903 .46858 L p F P
0 g
s
.479 .168 .361 r
.46578 .66629 m .46669 .66239 L .47668 .6597 L p F P
0 g
s
.449 .111 .298 r
.47688 .65908 m .47668 .6597 L .46669 .66239 L p F P
0 g
s
.651 .757 .928 r
.51567 .4686 m .50583 .47189 L .50853 .47492 L p F P
0 g
s
.651 .757 .928 r
.50853 .47492 m .51836 .47164 L .51567 .4686 L p F P
0 g
s
.746 .363 .327 r
.57039 .65537 m .57287 .65935 L .56607 .65787 L p F P
0 g
s
.746 .363 .327 r
.56517 .65424 m .57039 .65537 L p .56607 .65787 L F P
0 g
s
.65 .757 .927 r
.22149 .4682 m .21219 .47148 L .21539 .47452 L p F P
0 g
s
.65 .757 .927 r
.21539 .47452 m .22468 .47125 L .22149 .4682 L p F P
0 g
s
.826 .758 .788 r
.61091 .71631 m .61592 .71081 L .61214 .70854 L p F P
0 g
s
.65 .757 .928 r
.37485 .46832 m .36527 .47161 L .36821 .47464 L p F P
0 g
s
.65 .757 .928 r
.36821 .47464 m .37778 .47136 L .37485 .46832 L p F P
0 g
s
.651 .757 .928 r
.68161 .46832 m .67146 .47162 L .67387 .47464 L p F P
0 g
s
.651 .757 .928 r
.67387 .47464 m .68401 .47136 L .68161 .46832 L p F P
0 g
s
.651 .757 .928 r
.52823 .46834 m .51836 .47164 L .52104 .47467 L p F P
0 g
s
.651 .757 .928 r
.52104 .47467 m .5309 .47139 L .52823 .46834 L p F P
0 g
s
.536 .789 .991 r
.58394 .71548 m .58587 .71699 L .58966 .71638 L closepath p F P
0 g
s
.187 .668 .93 r
.58587 .71699 m .58394 .71548 L .58293 .71495 L p F P
0 g
s
.663 .272 .293 r
.54362 .64816 m .54735 .65173 L .53807 .65098 L p F P
0 g
s
.663 .272 .293 r
.53785 .64769 m .54362 .64816 L p .53807 .65098 L F P
0 g
s
.65 .757 .927 r
.234 .46796 m .22468 .47125 L .22786 .47428 L p F P
0 g
s
.65 .757 .927 r
.22786 .47428 m .23717 .47101 L .234 .46796 L p F P
0 g
s
.048 .599 .828 r
.55796 .71029 m .55818 .71035 L .55861 .71039 L closepath p F P
0 g
s
.284 0 0 r
.55818 .71035 m .55796 .71029 L .55191 .70894 L p F P
0 g
s
.562 .186 .287 r
.50859 .64808 m .51179 .6494 L p .49942 .6522 L F P
0 g
s
.568 .191 .286 r
.51179 .6494 m .50859 .64808 L .51243 .64776 L closepath p F P
0 g
s
.651 .757 .928 r
.69419 .46806 m .68401 .47136 L .68641 .47439 L p F P
0 g
s
.651 .757 .928 r
.68641 .47439 m .69657 .4711 L .69419 .46806 L p F P
0 g
s
.65 .757 .928 r
.38739 .46807 m .37778 .47136 L .3807 .47439 L p F P
0 g
s
.65 .757 .928 r
.3807 .47439 m .3903 .47111 L .38739 .46807 L p F P
0 g
s
.651 .757 .928 r
.54079 .46809 m .5309 .47139 L .53356 .47441 L p F P
0 g
s
.651 .757 .928 r
.53356 .47441 m .54344 .47113 L .54079 .46809 L p F P
0 g
s
.826 .758 .788 r
.61214 .70854 m .60837 .71301 L .61091 .71631 L p F P
0 g
s
.728 .753 .873 r
.60298 .71594 m .60837 .71301 L .61091 .71631 L p F P
0 g
s
.138 .667 .871 r
.55861 .71039 m .56815 .71152 L p .56542 .70985 L F P
0 g
s
.138 .667 .871 r
.55796 .71029 m .55861 .71039 L p .56542 .70985 L F P
0 g
s
.221 0 0 r
.55861 .71039 m .56815 .71152 L .57074 .71296 L p F P
0 g
s
.65 .757 .927 r
.24652 .46772 m .23717 .47101 L .24034 .47405 L p F P
0 g
s
.65 .757 .927 r
.24034 .47405 m .24967 .47077 L .24652 .46772 L p F P
0 g
s
.585 .881 .993 r
.46849 .71486 m .47056 .71572 L .48033 .71265 L p F P
0 g
s
.651 .757 .928 r
.70678 .4678 m .69657 .4711 L .69895 .47413 L p F P
0 g
s
.651 .757 .928 r
.69895 .47413 m .70914 .47084 L .70678 .4678 L p F P
0 g
s
.651 .757 .928 r
.39993 .46782 m .3903 .47111 L .3932 .47414 L p F P
0 g
s
.651 .757 .928 r
.3932 .47414 m .40282 .47086 L .39993 .46782 L p F P
0 g
s
.651 .757 .928 r
.55336 .46784 m .54344 .47113 L .54608 .47416 L p F P
0 g
s
.651 .757 .928 r
.54608 .47416 m .55598 .47088 L .55336 .46784 L p F P
0 g
s
.138 .667 .871 r
.56542 .70985 m .55558 .70965 L .55796 .71029 L p F P
0 g
s
0 .488 .745 r
.55558 .70965 m .55191 .70894 L .55796 .71029 L closepath p F P
0 g
s
.815 .466 .397 r
.59271 .66861 m .58712 .6668 L .58847 .67115 L p F P
0 g
s
.815 .466 .397 r
.58847 .67115 m .59412 .67293 L .59271 .66861 L p F P
0 g
s
.595 .218 .297 r
.51243 .64776 m .52264 .64739 L p .5146 .65095 L F P
0 g
s
.595 .218 .297 r
.5146 .65095 m .51179 .6494 L .51243 .64776 L p F P
0 g
s
.663 .272 .293 r
.53807 .65098 m .53686 .64989 L .53785 .64769 L p F P
0 g
s
.643 .25 .284 r
.53686 .64989 m .53388 .64755 L .53785 .64769 L closepath p F P
0 g
s
.65 .757 .927 r
.25904 .46748 m .24967 .47077 L .25281 .47381 L p F P
0 g
s
.65 .757 .927 r
.25281 .47381 m .26217 .47053 L .25904 .46748 L p F P
0 g
s
.651 .757 .928 r
.71937 .46754 m .70914 .47084 L .71149 .47387 L p F P
0 g
s
.651 .757 .928 r
.71149 .47387 m .72171 .47058 L .71937 .46754 L p F P
0 g
s
.651 .757 .928 r
.41248 .46757 m .40282 .47086 L .4057 .4739 L p F P
0 g
s
.651 .757 .928 r
.4057 .4739 m .41535 .47061 L .41248 .46757 L p F P
0 g
s
.651 .757 .928 r
.56592 .46758 m .55598 .47088 L .5586 .47391 L p F P
0 g
s
.651 .757 .928 r
.5586 .47391 m .56853 .47062 L .56592 .46758 L p F P
0 g
s
.606 .657 .873 r
.453 .71231 m .45523 .71521 L .44552 .71767 L p F P
0 g
s
.606 .657 .873 r
.44552 .71767 m .44474 .71651 L .453 .71231 L p F P
0 g
s
0 0 0 r
.49289 .71032 m .49402 .71006 L .50495 .7083 L p F P
0 g
s
.632 .25 .302 r
.53388 .64755 m .53686 .64989 L p .52729 .65068 L F P
0 g
s
.632 .25 .302 r
.52477 .64734 m .53388 .64755 L p .52729 .65068 L F P
0 g
s
.65 .757 .927 r
.27157 .46724 m .26217 .47053 L .26529 .47357 L p F P
0 g
s
.65 .757 .927 r
.26529 .47357 m .27468 .47029 L .27157 .46724 L p F P
0 g
s
.595 .218 .297 r
.52264 .64739 m .52432 .64844 L p .5146 .65095 L F P
0 g
s
.609 .226 .292 r
.52432 .64844 m .52264 .64739 L .52477 .64734 L closepath p F P
0 g
s
.651 .757 .927 r
.73196 .46728 m .72171 .47058 L .72404 .47361 L p F P
0 g
s
.651 .757 .927 r
.72404 .47361 m .73428 .47032 L .73196 .46728 L p F P
0 g
s
.713 .779 .904 r
.59912 .7137 m .59587 .71546 L .59842 .7181 L p F P
0 g
s
.713 .779 .904 r
.59842 .7181 m .60298 .71594 L .59912 .7137 L p F P
0 g
s
.476 .748 .989 r
.58966 .71638 m .59587 .71546 L .59842 .7181 L p F P
0 g
s
.651 .757 .928 r
.42503 .46732 m .41535 .47061 L .4182 .47365 L p F P
0 g
s
.651 .757 .928 r
.4182 .47365 m .42788 .47036 L .42503 .46732 L p F P
0 g
s
.651 .757 .928 r
.5785 .46733 m .56853 .47062 L .57112 .47366 L p F P
0 g
s
.651 .757 .928 r
.57112 .47366 m .58108 .47037 L .5785 .46733 L p F P
0 g
s
.632 .25 .302 r
.52729 .65068 m .52432 .64844 L .52477 .64734 L p F P
0 g
s
.746 .363 .327 r
.56607 .65787 m .5646 .65556 L .56517 .65424 L p F P
0 g
s
.731 .346 .32 r
.5646 .65556 m .56345 .65394 L .56517 .65424 L closepath p F P
0 g
s
.639 .815 .968 r
.46498 .71244 m .45523 .71521 L .45802 .71768 L p F P
0 g
s
.639 .815 .968 r
.45802 .71768 m .46777 .71458 L .46498 .71244 L p F P
0 g
s
.619 .865 .989 r
.46849 .71486 m .46777 .71458 L .45802 .71768 L p F P
0 g
s
.858 .726 .716 r
.61551 .70279 m .61139 .70061 L .6082 .70632 L p F P
0 g
s
.858 .726 .716 r
.6082 .70632 m .61214 .70854 L .61551 .70279 L p F P
0 g
s
.65 .757 .927 r
.2841 .467 m .27468 .47029 L .27778 .47333 L p F P
0 g
s
.65 .757 .927 r
.27778 .47333 m .28719 .47005 L .2841 .467 L p F P
0 g
s
.651 .758 .927 r
.74455 .46702 m .73428 .47032 L .73659 .47335 L p F P
0 g
s
.651 .758 .927 r
.73659 .47335 m .74685 .47006 L .74455 .46702 L p F P
0 g
s
.651 .757 .928 r
.43758 .46707 m .42788 .47036 L .43071 .4734 L p F P
0 g
s
.651 .757 .928 r
.43071 .4734 m .44041 .47011 L .43758 .46707 L p F P
0 g
s
.651 .757 .928 r
.59107 .46707 m .58108 .47037 L .58365 .4734 L p F P
0 g
s
.651 .757 .928 r
.58365 .4734 m .59363 .47012 L .59107 .46707 L p F P
0 g
s
.794 .428 .364 r
.58132 .66505 m .57977 .66151 L .57996 .661 L p F P
0 g
s
.78 .412 .359 r
.57977 .66151 m .57947 .66087 L .57996 .661 L closepath p F P
0 g
s
.852 .533 .449 r
.59925 .67487 m .59586 .67352 L .59528 .67753 L p F P
0 g
s
.852 .533 .449 r
.59528 .67753 m .59997 .67941 L .59925 .67487 L p F P
0 g
s
.593 .631 .858 r
.45245 .71154 m .453 .71231 L .44474 .71651 L p F P
0 g
s
.593 .631 .858 r
.44474 .71651 m .44275 .71323 L .45245 .71154 L p F P
0 g
s
.719 .332 .315 r
.56345 .65394 m .55569 .65275 L .55848 .65663 L p F P
0 g
s
.719 .332 .315 r
.5646 .65556 m .56345 .65394 L p .55848 .65663 L F P
0 g
s
.769 .399 .356 r
.57947 .66087 m .57287 .65935 L .57492 .66347 L p F P
0 g
s
.769 .399 .356 r
.57977 .66151 m .57947 .66087 L p .57492 .66347 L F P
0 g
s
.65 .757 .927 r
.29663 .46675 m .28719 .47005 L .29026 .47308 L p F P
0 g
s
.65 .757 .927 r
.29026 .47308 m .2997 .4698 L .29663 .46675 L p F P
0 g
s
.651 .758 .927 r
.75715 .46675 m .74685 .47006 L .74914 .47309 L p F P
0 g
s
.651 .758 .927 r
.74914 .47309 m .75943 .4698 L .75715 .46675 L p F P
0 g
s
.54 .194 .329 r
.48723 .65752 m .48835 .65388 L .49795 .65241 L p F P
0 g
s
.494 .151 .314 r
.48835 .65388 m .48723 .65752 L .47936 .65913 L p F P
0 g
s
.651 .757 .928 r
.45014 .46682 m .44041 .47011 L .44322 .47315 L p F P
0 g
s
.651 .757 .928 r
.44322 .47315 m .45294 .46986 L .45014 .46682 L p F P
0 g
s
.651 .757 .928 r
.60365 .46681 m .59363 .47012 L .59619 .47315 L p F P
0 g
s
.651 .757 .928 r
.59619 .47315 m .60619 .46986 L .60365 .46681 L p F P
0 g
s
.538 .789 .991 r
.58966 .71638 m .59587 .71546 L p .58331 .71499 L F P
0 g
s
.538 .789 .991 r
.58331 .71499 m .58394 .71548 L .58966 .71638 L p F P
0 g
s
.469 .254 .504 r
.44603 .68629 m .44617 .68158 L .45515 .67797 L p F P
0 g
s
.439 .194 .444 r
.45559 .67357 m .45515 .67797 L .44617 .68158 L p F P
0 g
s
.491 .362 .632 r
.43783 .69544 m .44021 .69427 L .447 .69698 L p F P
0 g
s
.491 .362 .632 r
.447 .69698 m .43868 .7011 L .43783 .69544 L p F P
0 g
s
.651 .758 .927 r
.76976 .46649 m .75943 .4698 L .7617 .47283 L p F P
0 g
s
.651 .758 .927 r
.7617 .47283 m .77201 .46953 L .76976 .46649 L p F P
0 g
s
.65 .757 .927 r
.30917 .46651 m .2997 .4698 L .30276 .47284 L p F P
0 g
s
.65 .757 .927 r
.30276 .47284 m .31222 .46956 L .30917 .46651 L p F P
0 g
s
.863 .577 .503 r
.60472 .68144 m .59997 .67941 L .6001 .68414 L p F P
0 g
s
.863 .577 .503 r
.6001 .68414 m .60485 .68617 L .60472 .68144 L p F P
0 g
s
.868 .673 .637 r
.61312 .69533 m .60876 .69321 L .6071 .69847 L p F P
0 g
s
.868 .673 .637 r
.6071 .69847 m .61139 .70061 L .61312 .69533 L p F P
0 g
s
.651 .757 .928 r
.61623 .46656 m .60619 .46986 L .60872 .47289 L p F P
0 g
s
.651 .757 .928 r
.60872 .47289 m .61875 .4696 L .61623 .46656 L p F P
0 g
s
.651 .757 .928 r
.4627 .46656 m .45294 .46986 L .45574 .4729 L p F P
0 g
s
.651 .757 .928 r
.45574 .4729 m .46548 .46961 L .4627 .46656 L p F P
0 g
s
.869 .624 .565 r
.6094 .68825 m .60485 .68617 L .60422 .69113 L p F P
0 g
s
.869 .624 .565 r
.60422 .69113 m .60876 .69321 L .6094 .68825 L p F P
0 g
s
.793 .427 .365 r
.57874 .66434 m .57977 .66151 L .58132 .66505 L closepath p F P
0 g
s
.769 .399 .356 r
.57492 .66347 m .57874 .66434 L .57977 .66151 L p F P
0 g
s
.439 .797 .997 r
.57074 .71296 m .57865 .71282 L .57355 .7109 L p F P
0 g
s
.439 .797 .997 r
.57355 .7109 m .56815 .71152 L .57074 .71296 L p F P
0 g
s
.651 .758 .927 r
.78236 .46622 m .77201 .46953 L .77426 .47257 L p F P
0 g
s
.651 .758 .927 r
.77426 .47257 m .7846 .46927 L .78236 .46622 L p F P
0 g
s
.65 .757 .927 r
.32171 .46626 m .31222 .46956 L .31525 .4726 L p F P
0 g
s
.65 .757 .927 r
.31525 .4726 m .32474 .46931 L .32171 .46626 L p F P
0 g
s
.651 .757 .928 r
.62882 .4663 m .61875 .4696 L .62126 .47264 L p F P
0 g
s
.651 .757 .928 r
.62126 .47264 m .63132 .46935 L .62882 .4663 L p F P
0 g
s
.651 .757 .928 r
.47526 .46631 m .46548 .46961 L .46826 .47265 L p F P
0 g
s
.651 .757 .928 r
.46826 .47265 m .47802 .46936 L .47526 .46631 L p F P
0 g
s
.747 .74 .846 r
.60837 .71301 m .60298 .71594 L .59912 .7137 L p F P
0 g
s
.106 .661 .751 r
.50495 .7083 m .50543 .70828 L .50792 .70804 L closepath p F P
0 g
s
.084 0 0 r
.52912 .70698 m .53048 .70695 L .53452 .70716 L closepath p F P
0 g
s
.192 0 0 r
.53048 .70695 m .52912 .70698 L .52321 .70703 L p F P
0 g
s
.265 0 0 r
.55558 .70965 m .55191 .70894 L .5435 .70797 L p F P
0 g
s
.493 .149 .31 r
.47668 .6597 m .47688 .65908 L .47936 .65913 L closepath p F P
0 g
s
.651 .758 .927 r
.79497 .46595 m .7846 .46927 L .78683 .4723 L p F P
0 g
s
.651 .758 .927 r
.78683 .4723 m .79719 .469 L .79497 .46595 L p F P
0 g
s
.65 .757 .927 r
.33426 .46601 m .32474 .46931 L .32775 .47235 L p F P
0 g
s
.65 .757 .927 r
.32775 .47235 m .33726 .46907 L .33426 .46601 L p F P
0 g
s
.651 .757 .928 r
.64141 .46604 m .63132 .46935 L .6338 .47238 L p F P
0 g
s
.651 .757 .928 r
.6338 .47238 m .64388 .46909 L .64141 .46604 L p F P
0 g
s
.651 .757 .928 r
.48783 .46606 m .47802 .46936 L .48078 .47239 L p F P
0 g
s
.651 .757 .928 r
.48078 .47239 m .49057 .4691 L .48783 .46606 L p F P
0 g
s
.633 .249 .299 r
.52341 .65064 m .52432 .64844 L .52729 .65068 L closepath p F P
0 g
s
.595 .218 .297 r
.52432 .64844 m .52341 .65064 L .5146 .65095 L p F P
0 g
s
.651 .758 .927 r
.80759 .46569 m .79719 .469 L .79939 .47204 L p F P
0 g
s
.651 .758 .927 r
.79939 .47204 m .80978 .46873 L .80759 .46569 L p F P
0 g
s
.65 .757 .928 r
.34681 .46577 m .33726 .46907 L .34025 .4721 L p F P
0 g
s
.65 .757 .928 r
.34025 .4721 m .34979 .46882 L .34681 .46577 L p F P
0 g
s
.651 .757 .928 r
.654 .46579 m .64388 .46909 L .64635 .47213 L p F P
0 g
s
.651 .757 .928 r
.64635 .47213 m .65645 .46883 L .654 .46579 L p F P
0 g
s
.596 .217 .294 r
.5111 .65111 m .51179 .6494 L .5146 .65095 L closepath p F P
0 g
s
.562 .186 .287 r
.51179 .6494 m .5111 .65111 L .49942 .6522 L p F P
0 g
s
.651 .757 .928 r
.5004 .4658 m .49057 .4691 L .4933 .47214 L p F P
0 g
s
.651 .757 .928 r
.4933 .47214 m .50312 .46885 L .5004 .4658 L p F P
0 g
s
.83 .748 .773 r
.60837 .71301 m .61214 .70854 L .6082 .70632 L p F P
0 g
s
.296 .667 .973 r
.58331 .71499 m .58293 .71495 L .58394 .71548 L closepath p F P
0 g
s
.81 .467 .407 r
.58712 .6668 m .58132 .66505 L .58264 .6694 L p F P
0 g
s
.81 .467 .407 r
.58264 .6694 m .58847 .67115 L .58712 .6668 L p F P
0 g
s
.65 .757 .927 r
.20575 .46538 m .19647 .46867 L .19971 .47171 L p F P
0 g
s
.65 .757 .927 r
.19971 .47171 m .20898 .46843 L .20575 .46538 L p F P
0 g
s
.708 .333 .336 r
.55569 .65275 m .55848 .65663 L .55043 .65552 L p F P
0 g
s
.708 .333 .336 r
.55027 .652 m .55569 .65275 L p .55043 .65552 L F P
0 g
s
.521 .206 .374 r
.47579 .6636 m .47668 .6597 L .47936 .65913 L p F P
0 g
s
.479 .168 .361 r
.47668 .6597 m .47579 .6636 L .46578 .66629 L p F P
0 g
s
.392 .829 .95 r
.49996 .70781 m .49013 .71004 L .49289 .71032 L p F P
0 g
s
0 0 0 r
.50495 .7083 m .5027 .70844 L .49289 .71032 L p F P
0 g
s
.65 .757 .928 r
.35936 .46552 m .34979 .46882 L .35276 .47186 L p F P
0 g
s
.65 .757 .928 r
.35276 .47186 m .36232 .46857 L .35936 .46552 L p F P
0 g
s
.651 .757 .928 r
.6666 .46553 m .65645 .46883 L .6589 .47187 L p F P
0 g
s
.651 .757 .928 r
.6589 .47187 m .66903 .46858 L .6666 .46553 L p F P
0 g
s
.651 .757 .928 r
.51298 .46555 m .50312 .46885 L .50583 .47189 L p F P
0 g
s
.651 .757 .928 r
.50583 .47189 m .51567 .4686 L .51298 .46555 L p F P
0 g
s
.484 .23 .454 r
.45515 .67797 m .45559 .67357 L .46509 .67042 L p F P
0 g
s
.458 .177 .399 r
.46578 .66629 m .46509 .67042 L .45559 .67357 L p F P
0 g
s
.566 .542 .787 r
.44971 .70604 m .45245 .71154 L .44275 .71323 L p F P
0 g
s
.566 .542 .787 r
.44222 .70658 m .44971 .70604 L p .44275 .71323 L F P
0 g
s
.566 .542 .787 r
.44275 .71323 m .44035 .70754 L .44222 .70658 L p F P
0 g
s
.081 .641 .725 r
.5027 .70844 m .50495 .7083 L .50792 .70804 L p F P
0 g
s
.746 .363 .327 r
.56379 .65743 m .5646 .65556 L .56607 .65787 L closepath p F P
0 g
s
.719 .332 .315 r
.55848 .65663 m .56379 .65743 L .5646 .65556 L p F P
0 g
s
.828 .508 .447 r
.59586 .67352 m .59412 .67293 L .59499 .67743 L p F P
0 g
s
.828 .508 .447 r
.59499 .67743 m .59528 .67753 L .59586 .67352 L p F P
0 g
s
.65 .757 .927 r
.21829 .46514 m .20898 .46843 L .21219 .47148 L p F P
0 g
s
.65 .757 .927 r
.21219 .47148 m .22149 .4682 L .21829 .46514 L p F P
0 g
s
.028 .594 .783 r
.54283 .70791 m .54302 .70794 L .5435 .70797 L closepath p F P
0 g
s
.496 .357 .621 r
.44021 .69427 m .44629 .69139 L .44704 .69696 L p F P
0 g
s
.496 .357 .621 r
.44704 .69696 m .447 .69698 L .44021 .69427 L p F P
0 g
s
.65 .757 .928 r
.37191 .46527 m .36232 .46857 L .36527 .47161 L p F P
0 g
s
.65 .757 .928 r
.36527 .47161 m .37485 .46832 L .37191 .46527 L p F P
0 g
s
.651 .757 .928 r
.6792 .46527 m .66903 .46858 L .67146 .47162 L p F P
0 g
s
.651 .757 .928 r
.67146 .47162 m .68161 .46832 L .6792 .46527 L p F P
0 g
s
.651 .757 .928 r
.52555 .46529 m .51567 .4686 L .51836 .47164 L p F P
0 g
s
.651 .757 .928 r
.51836 .47164 m .52823 .46834 L .52555 .46529 L p F P
0 g
s
.83 .748 .773 r
.6082 .70632 m .60581 .70939 L .60837 .71301 L p F P
0 g
s
.747 .74 .846 r
.59912 .7137 m .60581 .70939 L .60837 .71301 L p F P
0 g
s
.546 .472 .724 r
.43868 .7011 m .447 .69698 L p .44879 .70348 L F P
0 g
s
.546 .472 .724 r
.44004 .7066 m .43868 .7011 L p .44879 .70348 L F P
0 g
s
.54 .194 .329 r
.49795 .65241 m .49924 .65281 L p .48723 .65752 L F P
0 g
s
.547 .202 .334 r
.49924 .65281 m .49795 .65241 L .49942 .6522 L closepath p F P
0 g
s
.764 .401 .368 r
.57287 .65935 m .56607 .65787 L .56807 .66201 L p F P
0 g
s
.764 .401 .368 r
.56807 .66201 m .57492 .66347 L .57287 .65935 L p F P
0 g
s
.502 .215 .411 r
.46509 .67042 m .46578 .66629 L .47579 .6636 L p F P
0 g
s
.287 .667 .972 r
.58331 .71499 m .58293 .71495 L .57865 .71282 L p F P
0 g
s
.65 .757 .927 r
.23082 .4649 m .22149 .4682 L .22468 .47125 L p F P
0 g
s
.65 .757 .927 r
.22468 .47125 m .234 .46796 L .23082 .4649 L p F P
0 g
s
.013 .583 .77 r
.54039 .70756 m .54283 .70791 L .5435 .70797 L p F P
0 g
s
.265 0 0 r
.5435 .70797 m .55296 .70865 L .55558 .70965 L p F P
0 g
s
.651 .757 .928 r
.6918 .46501 m .68161 .46832 L .68401 .47136 L p F P
0 g
s
.651 .757 .928 r
.68401 .47136 m .69419 .46806 L .6918 .46501 L p F P
0 g
s
.65 .757 .928 r
.38447 .46502 m .37485 .46832 L .37778 .47136 L p F P
0 g
s
.65 .757 .928 r
.37778 .47136 m .38739 .46807 L .38447 .46502 L p F P
0 g
s
.573 .88 .993 r
.46777 .71458 m .46849 .71486 L .47802 .71179 L p F P
0 g
s
.585 .881 .993 r
.48033 .71265 m .47802 .71179 L .46849 .71486 L p F P
0 g
s
.651 .757 .928 r
.53814 .46504 m .52823 .46834 L .5309 .47139 L p F P
0 g
s
.651 .757 .928 r
.5309 .47139 m .54079 .46809 L .53814 .46504 L p F P
0 g
s
.577 .23 .344 r
.49942 .6522 m .5111 .65111 L p .50412 .65524 L F P
0 g
s
.577 .23 .344 r
.50412 .65524 m .49924 .65281 L .49942 .6522 L p F P
0 g
s
.616 .732 .929 r
.59074 .70957 m .58074 .71283 L .58331 .71499 L p F P
0 g
s
.616 .732 .929 r
.58331 .71499 m .59331 .71264 L .59074 .70957 L p F P
0 g
s
.538 .789 .991 r
.59587 .71546 m .59331 .71264 L .58331 .71499 L p F P
0 g
s
.287 .667 .972 r
.57865 .71282 m .58074 .71283 L .58331 .71499 L p F P
0 g
s
.521 .206 .374 r
.47936 .65913 m .48662 .66015 L p .47579 .6636 L F P
0 g
s
.522 .202 .367 r
.48662 .66015 m .47936 .65913 L .48723 .65752 L closepath p F P
0 g
s
.65 .757 .927 r
.24336 .46467 m .234 .46796 L .23717 .47101 L p F P
0 g
s
.65 .757 .927 r
.23717 .47101 m .24652 .46772 L .24336 .46467 L p F P
0 g
s
.819 .502 .453 r
.59412 .67293 m .58847 .67115 L .58927 .67566 L p F P
0 g
s
.819 .502 .453 r
.58927 .67566 m .59499 .67743 L .59412 .67293 L p F P
0 g
s
.651 .757 .928 r
.70441 .46475 m .69419 .46806 L .69657 .4711 L p F P
0 g
s
.651 .757 .928 r
.69657 .4711 m .70678 .4678 L .70441 .46475 L p F P
0 g
s
.651 .757 .928 r
.39704 .46477 m .38739 .46807 L .3903 .47111 L p F P
0 g
s
.651 .757 .928 r
.3903 .47111 m .39993 .46782 L .39704 .46477 L p F P
0 g
s
.651 .757 .928 r
.55072 .46478 m .54079 .46809 L .54344 .47113 L p F P
0 g
s
.651 .757 .928 r
.54344 .47113 m .55336 .46784 L .55072 .46478 L p F P
0 g
s
.664 .271 .291 r
.53641 .65088 m .53686 .64989 L .53807 .65098 L closepath p F P
0 g
s
.632 .25 .302 r
.53686 .64989 m .53641 .65088 L .52729 .65068 L p F P
0 g
s
.708 .333 .336 r
.55043 .65552 m .54944 .65419 L .55027 .652 L p F P
0 g
s
.692 .315 .33 r
.54944 .65419 m .54735 .65173 L .55027 .652 L closepath p F P
0 g
s
.532 .87 .992 r
.47802 .71179 m .48033 .71265 L .49013 .71004 L p F P
0 g
s
.855 .715 .707 r
.61139 .70061 m .6071 .69847 L .6041 .70413 L p F P
0 g
s
.855 .715 .707 r
.6041 .70413 m .6082 .70632 L .61139 .70061 L p F P
0 g
s
.545 .491 .746 r
.44222 .70658 m .44035 .70754 L .44004 .7066 L closepath p F P
0 g
s
.65 .757 .927 r
.2559 .46442 m .24652 .46772 L .24967 .47077 L p F P
0 g
s
.65 .757 .927 r
.24967 .47077 m .25904 .46748 L .2559 .46442 L p F P
0 g
s
.546 .472 .724 r
.44879 .70348 m .44222 .70658 L .44004 .7066 L p F P
0 g
s
.651 .757 .927 r
.71702 .46449 m .70678 .4678 L .70914 .47084 L p F P
0 g
s
.651 .757 .927 r
.70914 .47084 m .71937 .46754 L .71702 .46449 L p F P
0 g
s
.651 .757 .928 r
.4096 .46452 m .39993 .46782 L .40282 .47086 L p F P
0 g
s
.651 .757 .928 r
.40282 .47086 m .41248 .46757 L .4096 .46452 L p F P
0 g
s
.651 .757 .928 r
.56331 .46453 m .55336 .46784 L .55598 .47088 L p F P
0 g
s
.651 .757 .928 r
.55598 .47088 m .56592 .46758 L .56331 .46453 L p F P
0 g
s
.681 .303 .324 r
.54735 .65173 m .53807 .65098 L .54123 .65474 L p F P
0 g
s
.681 .303 .324 r
.54944 .65419 m .54735 .65173 L p .54123 .65474 L F P
0 g
s
.65 .757 .927 r
.26845 .46418 m .25904 .46748 L .26217 .47053 L p F P
0 g
s
.65 .757 .927 r
.26217 .47053 m .27157 .46724 L .26845 .46418 L p F P
0 g
s
.577 .229 .342 r
.49832 .65584 m .49924 .65281 L .50412 .65524 L closepath p F P
0 g
s
.54 .194 .329 r
.49924 .65281 m .49832 .65584 L .48723 .65752 L p F P
0 g
s
.733 .778 .889 r
.59522 .71146 m .59331 .71264 L .59587 .71546 L p F P
0 g
s
.733 .778 .889 r
.59587 .71546 m .59912 .7137 L .59522 .71146 L p F P
0 g
s
.651 .757 .927 r
.72963 .46422 m .71937 .46754 L .72171 .47058 L p F P
0 g
s
.651 .757 .927 r
.72171 .47058 m .73196 .46728 L .72963 .46422 L p F P
0 g
s
.651 .757 .928 r
.42217 .46426 m .41248 .46757 L .41535 .47061 L p F P
0 g
s
.651 .757 .928 r
.41535 .47061 m .42503 .46732 L .42217 .46426 L p F P
0 g
s
.651 .757 .928 r
.5759 .46427 m .56592 .46758 L .56853 .47062 L p F P
0 g
s
.651 .757 .928 r
.56853 .47062 m .5785 .46733 L .5759 .46427 L p F P
0 g
s
.854 .569 .505 r
.59997 .67941 m .59528 .67753 L .59533 .68222 L p F P
0 g
s
.854 .569 .505 r
.59533 .68222 m .6001 .68414 L .59997 .67941 L p F P
0 g
s
.499 .316 .564 r
.44629 .69139 m .44603 .68629 L .45502 .68268 L p F P
0 g
s
.469 .254 .504 r
.45515 .67797 m .45502 .68268 L .44603 .68629 L p F P
0 g
s
.105 0 0 r
.52782 .70704 m .52912 .70698 L .53452 .70716 L p F P
0 g
s
.863 .663 .631 r
.60876 .69321 m .60422 .69113 L .60264 .69637 L p F P
0 g
s
.863 .663 .631 r
.60264 .69637 m .6071 .69847 L .60876 .69321 L p F P
0 g
s
.622 .696 .898 r
.46221 .70916 m .46498 .71244 L .45523 .71521 L p F P
0 g
s
.622 .696 .898 r
.45715 .71041 m .46221 .70916 L p .45523 .71521 L F P
0 g
s
.622 .696 .898 r
.45523 .71521 m .453 .71231 L .45715 .71041 L p F P
0 g
s
.336 .777 .964 r
.55558 .70965 m .56542 .70985 L .55986 .70806 L p F P
0 g
s
.336 .777 .964 r
.55986 .70806 m .55296 .70865 L .55558 .70965 L p F P
0 g
s
.65 .757 .927 r
.281 .46394 m .27157 .46724 L .27468 .47029 L p F P
0 g
s
.65 .757 .927 r
.27468 .47029 m .2841 .467 L .281 .46394 L p F P
0 g
s
.651 .758 .927 r
.74225 .46396 m .73196 .46728 L .73428 .47032 L p F P
0 g
s
.651 .758 .927 r
.73428 .47032 m .74455 .46702 L .74225 .46396 L p F P
0 g
s
.627 .821 .975 r
.47478 .70959 m .46498 .71244 L .46777 .71458 L p F P
0 g
s
.627 .821 .975 r
.46777 .71458 m .47755 .71162 L .47478 .70959 L p F P
0 g
s
.573 .88 .993 r
.47802 .71179 m .47755 .71162 L .46777 .71458 L p F P
0 g
s
.862 .615 .564 r
.60485 .68617 m .6001 .68414 L .59951 .68908 L p F P
0 g
s
.862 .615 .564 r
.59951 .68908 m .60422 .69113 L .60485 .68617 L p F P
0 g
s
.651 .757 .928 r
.43475 .46401 m .42503 .46732 L .42788 .47036 L p F P
0 g
s
.651 .757 .928 r
.42788 .47036 m .43758 .46707 L .43475 .46401 L p F P
0 g
s
.651 .757 .928 r
.5885 .46402 m .5785 .46733 L .58108 .47037 L p F P
0 g
s
.651 .757 .928 r
.58108 .47037 m .59107 .46707 L .5885 .46402 L p F P
0 g
s
.077 0 0 r
.52321 .70703 m .52782 .70704 L p .51526 .70734 L F P
0 g
s
.031 0 0 r
.52782 .70704 m .52321 .70703 L .52912 .70698 L closepath p F P
0 g
s
.65 .757 .927 r
.29356 .46369 m .2841 .467 L .28719 .47005 L p F P
0 g
s
.65 .757 .927 r
.28719 .47005 m .29663 .46675 L .29356 .46369 L p F P
0 g
s
.651 .758 .927 r
.75487 .4637 m .74455 .46702 L .74685 .47006 L p F P
0 g
s
.651 .758 .927 r
.74685 .47006 m .75715 .46675 L .75487 .4637 L p F P
0 g
s
.651 .757 .928 r
.44733 .46376 m .43758 .46707 L .44041 .47011 L p F P
0 g
s
.651 .757 .928 r
.44041 .47011 m .45014 .46682 L .44733 .46376 L p F P
0 g
s
.651 .757 .928 r
.6011 .46376 m .59107 .46707 L .59363 .47012 L p F P
0 g
s
.651 .757 .928 r
.59363 .47012 m .60365 .46681 L .6011 .46376 L p F P
0 g
s
.802 .464 .415 r
.58132 .66505 m .57874 .66434 L .57787 .66807 L p F P
0 g
s
.802 .464 .415 r
.57787 .66807 m .58264 .6694 L .58132 .66505 L p F P
0 g
s
.614 .26 .346 r
.5146 .65095 m .5111 .65111 L .50999 .6547 L p F P
0 g
s
.577 .23 .344 r
.5111 .65111 m .50999 .6547 L .50412 .65524 L p F P
0 g
s
.763 .723 .815 r
.60581 .70939 m .59912 .7137 L .59522 .71146 L p F P
0 g
s
.681 .316 .348 r
.53807 .65098 m .53641 .65088 L .53523 .65435 L p F P
0 g
s
.681 .316 .348 r
.53523 .65435 m .54123 .65474 L .53807 .65098 L p F P
0 g
s
.614 .26 .346 r
.50999 .6547 m .51915 .65428 L .5146 .65095 L p F P
0 g
s
.617 .257 .335 r
.52341 .65064 m .5146 .65095 L .51915 .65428 L p F P
0 g
s
.651 .758 .927 r
.76749 .46343 m .75715 .46675 L .75943 .4698 L p F P
0 g
s
.651 .758 .927 r
.75943 .4698 m .76976 .46649 L .76749 .46343 L p F P
0 g
s
.65 .757 .927 r
.30611 .46345 m .29663 .46675 L .2997 .4698 L p F P
0 g
s
.65 .757 .927 r
.2997 .4698 m .30917 .46651 L .30611 .46345 L p F P
0 g
s
.651 .757 .928 r
.6137 .4635 m .60365 .46681 L .60619 .46986 L p F P
0 g
s
.651 .757 .928 r
.60619 .46986 m .61623 .46656 L .6137 .4635 L p F P
0 g
s
.651 .757 .928 r
.45991 .46351 m .45014 .46682 L .45294 .46986 L p F P
0 g
s
.651 .757 .928 r
.45294 .46986 m .4627 .46656 L .45991 .46351 L p F P
0 g
s
.759 .402 .379 r
.56607 .65787 m .56379 .65743 L .5627 .66095 L p F P
0 g
s
.759 .402 .379 r
.5627 .66095 m .56807 .66201 L .56607 .65787 L p F P
0 g
s
.561 .511 .756 r
.44971 .70604 m .44222 .70658 L .44879 .70348 L closepath p F P
0 g
s
.652 .286 .337 r
.53641 .65088 m .52729 .65068 L .53104 .65426 L p F P
0 g
s
.652 .286 .337 r
.53104 .65426 m .53523 .65435 L .53641 .65088 L p F P
0 g
s
.651 .758 .927 r
.78012 .46316 m .76976 .46649 L .77201 .46953 L p F P
0 g
s
.651 .758 .927 r
.77201 .46953 m .78236 .46622 L .78012 .46316 L p F P
0 g
s
.65 .757 .927 r
.31868 .4632 m .30917 .46651 L .31222 .46956 L p F P
0 g
s
.65 .757 .927 r
.31222 .46956 m .32171 .46626 L .31868 .4632 L p F P
0 g
s
.651 .757 .928 r
.62631 .46324 m .61623 .46656 L .61875 .4696 L p F P
0 g
s
.651 .757 .928 r
.61875 .4696 m .62882 .4663 L .62631 .46324 L p F P
0 g
s
.651 .757 .928 r
.47249 .46325 m .4627 .46656 L .46548 .46961 L p F P
0 g
s
.651 .757 .928 r
.46548 .46961 m .47526 .46631 L .47249 .46325 L p F P
0 g
s
.648 .288 .347 r
.52729 .65068 m .52341 .65064 L .52226 .65417 L p F P
0 g
s
.648 .288 .347 r
.52226 .65417 m .53104 .65426 L .52729 .65068 L p F P
0 g
s
.617 .257 .335 r
.51915 .65428 m .52226 .65417 L .52341 .65064 L p F P
0 g
s
.833 .736 .757 r
.60581 .70939 m .6082 .70632 L .6041 .70413 L p F P
0 g
s
.555 .232 .377 r
.48723 .65752 m .49832 .65584 L p .48882 .66098 L F P
0 g
s
.555 .232 .377 r
.48882 .66098 m .48662 .66015 L .48723 .65752 L p F P
0 g
s
.651 .758 .927 r
.79275 .4629 m .78236 .46622 L .7846 .46927 L p F P
0 g
s
.651 .758 .927 r
.7846 .46927 m .79497 .46595 L .79275 .4629 L p F P
0 g
s
.65 .757 .927 r
.33124 .46295 m .32171 .46626 L .32474 .46931 L p F P
0 g
s
.65 .757 .927 r
.32474 .46931 m .33426 .46601 L .33124 .46295 L p F P
0 g
s
.732 .373 .371 r
.56379 .65743 m .55848 .65663 L .56079 .66067 L p F P
0 g
s
.732 .373 .371 r
.56079 .66067 m .5627 .66095 L .56379 .65743 L p F P
0 g
s
.651 .757 .928 r
.63892 .46299 m .62882 .4663 L .63132 .46935 L p F P
0 g
s
.651 .757 .928 r
.63132 .46935 m .64141 .46604 L .63892 .46299 L p F P
0 g
s
.651 .757 .928 r
.48508 .463 m .47526 .46631 L .47802 .46936 L p F P
0 g
s
.651 .757 .928 r
.47802 .46936 m .48783 .46606 L .48508 .463 L p F P
0 g
s
.777 .437 .41 r
.57874 .66434 m .57492 .66347 L .57646 .66775 L p F P
0 g
s
.777 .437 .41 r
.57646 .66775 m .57787 .66807 L .57874 .66434 L p F P
0 g
s
.651 .758 .927 r
.80539 .46263 m .79497 .46595 L .79719 .469 L p F P
0 g
s
.651 .758 .927 r
.79719 .469 m .80759 .46569 L .80539 .46263 L p F P
0 g
s
.815 .502 .461 r
.58847 .67115 m .58264 .6694 L .58342 .67393 L p F P
0 g
s
.815 .502 .461 r
.58342 .67393 m .58927 .67566 L .58847 .67115 L p F P
0 g
s
.65 .757 .927 r
.34381 .4627 m .33426 .46601 L .33726 .46907 L p F P
0 g
s
.65 .757 .927 r
.33726 .46907 m .34681 .46577 L .34381 .4627 L p F P
0 g
s
.651 .757 .928 r
.65154 .46273 m .64141 .46604 L .64388 .46909 L p F P
0 g
s
.651 .757 .928 r
.64388 .46909 m .654 .46579 L .65154 .46273 L p F P
0 g
s
.651 .757 .928 r
.49767 .46274 m .48783 .46606 L .49057 .4691 L p F P
0 g
s
.651 .757 .928 r
.49057 .4691 m .5004 .4658 L .49767 .46274 L p F P
0 g
s
.833 .736 .757 r
.6041 .70413 m .60324 .70534 L .60581 .70939 L p F P
0 g
s
.763 .723 .815 r
.59522 .71146 m .60324 .70534 L .60581 .70939 L p F P
0 g
s
.466 .79 .999 r
.56568 .70993 m .56815 .71152 L .57355 .7109 L closepath p F P
0 g
s
.138 .667 .871 r
.56815 .71152 m .56568 .70993 L .56542 .70985 L p F P
0 g
s
.38 .725 .989 r
.58074 .71283 m .57865 .71282 L .57355 .7109 L p F P
0 g
s
.51 .286 .511 r
.45502 .68268 m .45515 .67797 L .46466 .67481 L p F P
0 g
s
.484 .23 .454 r
.46509 .67042 m .46466 .67481 L .45515 .67797 L p F P
0 g
s
.65 .757 .928 r
.35639 .46246 m .34681 .46577 L .34979 .46882 L p F P
0 g
s
.65 .757 .928 r
.34979 .46882 m .35936 .46552 L .35639 .46246 L p F P
0 g
s
.651 .757 .928 r
.66415 .46247 m .654 .46579 L .65645 .46883 L p F P
0 g
s
.651 .757 .928 r
.65645 .46883 m .6666 .46553 L .66415 .46247 L p F P
0 g
s
.651 .757 .928 r
.51027 .46249 m .5004 .4658 L .50312 .46885 L p F P
0 g
s
.651 .757 .928 r
.50312 .46885 m .51298 .46555 L .51027 .46249 L p F P
0 g
s
.65 .757 .927 r
.21507 .46207 m .20575 .46538 L .20898 .46843 L p F P
0 g
s
.65 .757 .927 r
.20898 .46843 m .21829 .46514 L .21507 .46207 L p F P
0 g
s
.65 .757 .928 r
.36896 .4622 m .35936 .46552 L .36232 .46857 L p F P
0 g
s
.65 .757 .928 r
.36232 .46857 m .37191 .46527 L .36896 .4622 L p F P
0 g
s
.651 .757 .928 r
.67677 .46221 m .6666 .46553 L .66903 .46858 L p F P
0 g
s
.651 .757 .928 r
.66903 .46858 m .6792 .46527 L .67677 .46221 L p F P
0 g
s
.651 .757 .928 r
.52287 .46223 m .51298 .46555 L .51567 .4686 L p F P
0 g
s
.651 .757 .928 r
.51567 .4686 m .52555 .46529 L .52287 .46223 L p F P
0 g
s
.866 .711 .688 r
.6071 .69847 m .6041 .70413 L .60195 .70306 L p F P
0 g
s
.866 .711 .688 r
.60264 .69637 m .6071 .69847 L p .60195 .70306 L F P
0 g
s
.83 .547 .51 r
.59528 .67753 m .59499 .67743 L .59514 .68215 L p F P
0 g
s
.83 .547 .51 r
.59514 .68215 m .59533 .68222 L .59528 .67753 L p F P
0 g
s
.54 .249 .421 r
.47512 .66773 m .47579 .6636 L .48632 .66138 L p F P
0 g
s
.502 .215 .411 r
.47579 .6636 m .47512 .66773 L .46509 .67042 L p F P
0 g
s
.521 .206 .374 r
.48662 .66015 m .48632 .66138 L .47579 .6636 L p F P
0 g
s
.727 .373 .379 r
.55848 .65663 m .55043 .65552 L .55267 .65957 L p F P
0 g
s
.727 .373 .379 r
.55267 .65957 m .56079 .66067 L .55848 .65663 L p F P
0 g
s
.709 .333 .335 r
.54899 .65534 m .54944 .65419 L .55043 .65552 L closepath p F P
0 g
s
.681 .303 .324 r
.54123 .65474 m .54899 .65534 L .54944 .65419 L p F P
0 g
s
.65 .757 .927 r
.22763 .46184 m .21829 .46514 L .22149 .4682 L p F P
0 g
s
.65 .757 .927 r
.22149 .4682 m .23082 .4649 L .22763 .46184 L p F P
0 g
s
.618 .681 .887 r
.45715 .71041 m .453 .71231 L .45245 .71154 L closepath p F P
0 g
s
.528 .38 .624 r
.44704 .69696 m .44629 .69139 L .4553 .68779 L p F P
0 g
s
.499 .316 .564 r
.45502 .68268 m .4553 .68779 L .44629 .69139 L p F P
0 g
s
.821 .54 .512 r
.59499 .67743 m .58927 .67566 L .58939 .6804 L p F P
0 g
s
.821 .54 .512 r
.58939 .6804 m .59514 .68215 L .59499 .67743 L p F P
0 g
s
.651 .757 .928 r
.6894 .46195 m .6792 .46527 L .68161 .46832 L p F P
0 g
s
.651 .757 .928 r
.68161 .46832 m .6918 .46501 L .6894 .46195 L p F P
0 g
s
.65 .757 .928 r
.38154 .46195 m .37191 .46527 L .37485 .46832 L p F P
0 g
s
.65 .757 .928 r
.37485 .46832 m .38447 .46502 L .38154 .46195 L p F P
0 g
s
.651 .757 .928 r
.53547 .46198 m .52555 .46529 L .52823 .46834 L p F P
0 g
s
.651 .757 .928 r
.52823 .46834 m .53814 .46504 L .53547 .46198 L p F P
0 g
s
.771 .434 .417 r
.57492 .66347 m .56807 .66201 L .56954 .66631 L p F P
0 g
s
.771 .434 .417 r
.56954 .66631 m .57646 .66775 L .57492 .66347 L p F P
0 g
s
.312 .792 .909 r
.52133 .70552 m .51255 .70691 L .51526 .70734 L p F P
0 g
s
.077 0 0 r
.52782 .70704 m .52514 .70652 L .51526 .70734 L p F P
0 g
s
.081 .641 .725 r
.51526 .70734 m .51255 .70691 L .5027 .70844 L p F P
0 g
s
.524 .264 .462 r
.46466 .67481 m .46509 .67042 L .47512 .66773 L p F P
0 g
s
.65 .757 .927 r
.24019 .4616 m .23082 .4649 L .234 .46796 L p F P
0 g
s
.65 .757 .927 r
.234 .46796 m .24336 .46467 L .24019 .4616 L p F P
0 g
s
.289 .775 .911 r
.52782 .70704 m .53773 .7067 L p .53325 .7055 L F P
0 g
s
.289 .775 .911 r
.53325 .7055 m .52514 .70652 L .52782 .70704 L p F P
0 g
s
.105 0 0 r
.54039 .70756 m .53773 .7067 L .52782 .70704 L p F P
0 g
s
.651 .757 .927 r
.70203 .46168 m .6918 .46501 L .69419 .46806 L p F P
0 g
s
.651 .757 .927 r
.69419 .46806 m .70441 .46475 L .70203 .46168 L p F P
0 g
s
.415 .842 .955 r
.5027 .70844 m .51255 .70691 L p .50589 .70656 L F P
0 g
s
.415 .842 .955 r
.50589 .70656 m .49996 .70781 L .5027 .70844 L p F P
0 g
s
.651 .757 .928 r
.39413 .4617 m .38447 .46502 L .38739 .46807 L p F P
0 g
s
.651 .757 .928 r
.38739 .46807 m .39704 .46477 L .39413 .4617 L p F P
0 g
s
.858 .653 .625 r
.60422 .69113 m .59951 .68908 L .59801 .6943 L p F P
0 g
s
.858 .653 .625 r
.59801 .6943 m .60264 .69637 L .60422 .69113 L p F P
0 g
s
.651 .757 .928 r
.54808 .46172 m .53814 .46504 L .54079 .46809 L p F P
0 g
s
.651 .757 .928 r
.54079 .46809 m .55072 .46478 L .54808 .46172 L p F P
0 g
s
.853 .605 .562 r
.6001 .68414 m .59533 .68222 L .59616 .68773 L p F P
0 g
s
.853 .605 .562 r
.59616 .68773 m .59951 .68908 L .6001 .68414 L p F P
0 g
s
.656 .725 .9 r
.58447 .70779 m .57816 .71045 L .58074 .71283 L p F P
0 g
s
.656 .725 .9 r
.59007 .70869 m .58447 .70779 L p .58074 .71283 L F P
0 g
s
.656 .725 .9 r
.58074 .71283 m .59074 .70957 L .59007 .70869 L p F P
0 g
s
.38 .725 .989 r
.57355 .7109 m .57816 .71045 L .58074 .71283 L p F P
0 g
s
.617 .633 .844 r
.45245 .71154 m .44971 .70604 L p .46187 .70861 L F P
0 g
s
.617 .633 .844 r
.46187 .70861 m .45715 .71041 L .45245 .71154 L p F P
0 g
s
.65 .757 .927 r
.25275 .46135 m .24336 .46467 L .24652 .46772 L p F P
0 g
s
.65 .757 .927 r
.24652 .46772 m .2559 .46442 L .25275 .46135 L p F P
0 g
s
.651 .757 .927 r
.71466 .46142 m .70441 .46475 L .70678 .4678 L p F P
0 g
s
.651 .757 .927 r
.70678 .4678 m .71702 .46449 L .71466 .46142 L p F P
0 g
s
.651 .757 .928 r
.40672 .46145 m .39704 .46477 L .39993 .46782 L p F P
0 g
s
.651 .757 .928 r
.39993 .46782 m .4096 .46452 L .40672 .46145 L p F P
0 g
s
.651 .757 .928 r
.56069 .46146 m .55072 .46478 L .55336 .46784 L p F P
0 g
s
.651 .757 .928 r
.55336 .46784 m .56331 .46453 L .56069 .46146 L p F P
0 g
s
.535 .874 .99 r
.47755 .71162 m .47802 .71179 L .48808 .70918 L p F P
0 g
s
.532 .87 .992 r
.49013 .71004 m .48808 .70918 L .47802 .71179 L p F P
0 g
s
.752 .773 .87 r
.5912 .70924 m .59074 .70957 L .59331 .71264 L p F P
0 g
s
.752 .773 .87 r
.59331 .71264 m .59522 .71146 L .5912 .70924 L p F P
0 g
s
.65 .757 .927 r
.26532 .46111 m .2559 .46442 L .25904 .46748 L p F P
0 g
s
.65 .757 .927 r
.25904 .46748 m .26845 .46418 L .26532 .46111 L p F P
0 g
s
.51 .852 .995 r
.48808 .70918 m .49013 .71004 L .49996 .70781 L p F P
0 g
s
.651 .757 .927 r
.72729 .46116 m .71702 .46449 L .71937 .46754 L p F P
0 g
s
.651 .757 .927 r
.71937 .46754 m .72963 .46422 L .72729 .46116 L p F P
0 g
s
.651 .757 .928 r
.41931 .4612 m .4096 .46452 L .41248 .46757 L p F P
0 g
s
.651 .757 .928 r
.41248 .46757 m .42217 .46426 L .41931 .4612 L p F P
0 g
s
.593 .267 .387 r
.50412 .65524 m .49832 .65584 L .49743 .65969 L p F P
0 g
s
.555 .232 .377 r
.49832 .65584 m .49743 .65969 L .48882 .66098 L p F P
0 g
s
.651 .757 .928 r
.5733 .46121 m .56331 .46453 L .56592 .46758 L p F P
0 g
s
.651 .757 .928 r
.56592 .46758 m .5759 .46427 L .5733 .46121 L p F P
0 g
s
.364 .802 .961 r
.54039 .70756 m .55034 .70729 L p .54364 .70592 L F P
0 g
s
.364 .802 .961 r
.54364 .70592 m .53773 .7067 L .54039 .70756 L p F P
0 g
s
.013 .583 .77 r
.55296 .70865 m .55034 .70729 L .54039 .70756 L p F P
0 g
s
.78 .767 .841 r
.5912 .70924 m .59522 .71146 L .60324 .70534 L p F P
0 g
s
.65 .757 .927 r
.27789 .46087 m .26845 .46418 L .27157 .46724 L p F P
0 g
s
.65 .757 .927 r
.27157 .46724 m .281 .46394 L .27789 .46087 L p F P
0 g
s
.651 .757 .927 r
.73993 .4609 m .72963 .46422 L .73196 .46728 L p F P
0 g
s
.651 .757 .927 r
.73196 .46728 m .74225 .46396 L .73993 .4609 L p F P
0 g
s
.651 .757 .928 r
.4319 .46094 m .42217 .46426 L .42503 .46732 L p F P
0 g
s
.651 .757 .928 r
.42503 .46732 m .43475 .46401 L .4319 .46094 L p F P
0 g
s
.651 .757 .928 r
.58592 .46095 m .5759 .46427 L .5785 .46733 L p F P
0 g
s
.651 .757 .928 r
.5785 .46733 m .5885 .46402 L .58592 .46095 L p F P
0 g
s
.723 .375 .39 r
.55043 .65552 m .54899 .65534 L .54802 .65901 L p F P
0 g
s
.723 .375 .39 r
.54802 .65901 m .55267 .65957 L .55043 .65552 L p F P
0 g
s
.809 .499 .465 r
.58264 .6694 m .57787 .66807 L .57741 .67224 L p F P
0 g
s
.809 .499 .465 r
.57741 .67224 m .58342 .67393 L .58264 .6694 L p F P
0 g
s
.617 .808 .974 r
.48461 .70673 m .47478 .70959 L .47755 .71162 L p F P
0 g
s
.617 .808 .974 r
.47755 .71162 m .48737 .70889 L .48461 .70673 L p F P
0 g
s
.535 .874 .99 r
.48808 .70918 m .48737 .70889 L .47755 .71162 L p F P
0 g
s
.65 .757 .927 r
.29047 .46062 m .281 .46394 L .2841 .467 L p F P
0 g
s
.65 .757 .927 r
.2841 .467 m .29356 .46369 L .29047 .46062 L p F P
0 g
s
.651 .758 .927 r
.75258 .46063 m .74225 .46396 L .74455 .46702 L p F P
0 g
s
.651 .758 .927 r
.74455 .46702 m .75487 .4637 L .75258 .46063 L p F P
0 g
s
.555 .232 .376 r
.48632 .66138 m .48662 .66015 L .48882 .66098 L closepath p F P
0 g
s
.638 .735 .919 r
.47201 .70643 m .46221 .70916 L .46498 .71244 L p F P
0 g
s
.638 .735 .919 r
.46498 .71244 m .47478 .70959 L .47201 .70643 L p F P
0 g
s
.651 .757 .928 r
.4445 .46069 m .43475 .46401 L .43758 .46707 L p F P
0 g
s
.651 .757 .928 r
.43758 .46707 m .44733 .46376 L .4445 .46069 L p F P
0 g
s
.651 .757 .928 r
.59854 .46069 m .5885 .46402 L .59107 .46707 L p F P
0 g
s
.651 .757 .928 r
.59107 .46707 m .6011 .46376 L .59854 .46069 L p F P
0 g
s
.697 .348 .382 r
.54899 .65534 m .54123 .65474 L .54382 .65869 L p F P
0 g
s
.697 .348 .382 r
.54382 .65869 m .54802 .65901 L .54899 .65534 L p F P
0 g
s
.835 .721 .739 r
.60324 .70534 m .6041 .70413 L .60195 .70306 L closepath p F P
0 g
s
.593 .267 .387 r
.49743 .65969 m .50887 .65852 L .50412 .65524 L p F P
0 g
s
.597 .265 .377 r
.50999 .6547 m .50412 .65524 L .50887 .65852 L p F P
0 g
s
.651 .758 .927 r
.76522 .46036 m .75487 .4637 L .75715 .46675 L p F P
0 g
s
.651 .758 .927 r
.75715 .46675 m .76749 .46343 L .76522 .46036 L p F P
0 g
s
.65 .757 .927 r
.30305 .46038 m .29356 .46369 L .29663 .46675 L p F P
0 g
s
.65 .757 .927 r
.29663 .46675 m .30611 .46345 L .30305 .46038 L p F P
0 g
s
.651 .757 .928 r
.61117 .46043 m .6011 .46376 L .60365 .46681 L p F P
0 g
s
.651 .757 .928 r
.60365 .46681 m .6137 .4635 L .61117 .46043 L p F P
0 g
s
.651 .757 .928 r
.45711 .46044 m .44733 .46376 L .45014 .46682 L p F P
0 g
s
.651 .757 .928 r
.45014 .46682 m .45991 .46351 L .45711 .46044 L p F P
0 g
s
.519 .407 .667 r
.44705 .69698 m .447 .69698 L .44704 .69696 L closepath p F P
0 g
s
.546 .472 .724 r
.447 .69698 m .44705 .69698 L .44879 .70348 L p F P
0 g
s
.78 .767 .841 r
.60324 .70534 m .60195 .70306 L p .5912 .70924 L F P
0 g
s
.549 .427 .667 r
.44705 .69698 m .44704 .69696 L .45609 .6934 L p F P
0 g
s
.528 .38 .624 r
.4553 .68779 m .45609 .6934 L .44704 .69696 L p F P
0 g
s
.466 .79 .999 r
.57355 .7109 m .57816 .71045 L p .56556 .70986 L F P
0 g
s
.466 .79 .999 r
.56556 .70986 m .56568 .70993 L .57355 .7109 L p F P
0 g
s
.549 .427 .667 r
.45609 .6934 m .45676 .69643 L .44705 .69698 L p F P
0 g
s
.556 .465 .707 r
.44879 .70348 m .44705 .69698 L .45676 .69643 L p F P
0 g
s
.757 .426 .424 r
.56807 .66201 m .56954 .66631 L .56246 .66491 L p F P
0 g
s
.757 .426 .424 r
.5627 .66095 m .56807 .66201 L p .56246 .66491 L F P
0 g
s
.651 .758 .927 r
.77787 .4601 m .76749 .46343 L .76976 .46649 L p F P
0 g
s
.651 .758 .927 r
.76976 .46649 m .78012 .46316 L .77787 .4601 L p F P
0 g
s
.65 .757 .927 r
.31563 .46013 m .30611 .46345 L .30917 .46651 L p F P
0 g
s
.65 .757 .927 r
.30917 .46651 m .31868 .4632 L .31563 .46013 L p F P
0 g
s
.651 .757 .928 r
.62379 .46018 m .6137 .4635 L .61623 .46656 L p F P
0 g
s
.651 .757 .928 r
.61623 .46656 m .62631 .46324 L .62379 .46018 L p F P
0 g
s
.651 .757 .928 r
.46971 .46018 m .45991 .46351 L .4627 .46656 L p F P
0 g
s
.651 .757 .928 r
.4627 .46656 m .47249 .46325 L .46971 .46018 L p F P
0 g
s
.503 .834 .999 r
.55296 .70865 m .55986 .70806 L .55152 .70706 L p F P
0 g
s
.503 .834 .999 r
.55152 .70706 m .55034 .70729 L .55296 .70865 L p F P
0 g
s
.582 .522 .754 r
.45779 .69988 m .45946 .70423 L .44971 .70604 L p F P
0 g
s
.582 .522 .754 r
.44971 .70604 m .44879 .70348 L .45779 .69988 L p F P
0 g
s
.617 .633 .844 r
.44971 .70604 m .45946 .70423 L .46187 .70861 L p F P
0 g
s
.535 .345 .569 r
.4553 .68779 m .45502 .68268 L .46455 .67953 L p F P
0 g
s
.51 .286 .511 r
.46466 .67481 m .46455 .67953 L .45502 .68268 L p F P
0 g
s
.651 .758 .927 r
.79052 .45983 m .78012 .46316 L .78236 .46622 L p F P
0 g
s
.651 .758 .927 r
.78236 .46622 m .79275 .4629 L .79052 .45983 L p F P
0 g
s
.693 .349 .388 r
.54123 .65474 m .53523 .65435 L .53426 .65805 L p F P
0 g
s
.693 .349 .388 r
.53426 .65805 m .54382 .65869 L .54123 .65474 L p F P
0 g
s
.818 .538 .515 r
.58927 .67566 m .58342 .67393 L .58353 .67866 L p F P
0 g
s
.818 .538 .515 r
.58353 .67866 m .58939 .6804 L .58927 .67566 L p F P
0 g
s
.65 .757 .927 r
.32822 .45988 m .31868 .4632 L .32171 .46626 L p F P
0 g
s
.65 .757 .927 r
.32171 .46626 m .33124 .46295 L .32822 .45988 L p F P
0 g
s
.651 .757 .928 r
.63643 .45992 m .62631 .46324 L .62882 .4663 L p F P
0 g
s
.651 .757 .928 r
.62882 .4663 m .63892 .46299 L .63643 .45992 L p F P
0 g
s
.627 .294 .386 r
.50906 .65851 m .50999 .6547 L .51915 .65428 L p F P
0 g
s
.597 .265 .377 r
.50887 .65852 m .50906 .65851 L .50999 .6547 L p F P
0 g
s
.651 .757 .928 r
.48232 .45993 m .47249 .46325 L .47526 .46631 L p F P
0 g
s
.651 .757 .928 r
.47526 .46631 m .48508 .463 L .48232 .45993 L p F P
0 g
s
.556 .465 .707 r
.45676 .69643 m .45779 .69988 L .44879 .70348 L p F P
0 g
s
.62 .646 .855 r
.46221 .70916 m .45715 .71041 L .46187 .70861 L closepath p F P
0 g
s
.651 .758 .927 r
.80318 .45956 m .79275 .4629 L .79497 .46595 L p F P
0 g
s
.651 .758 .927 r
.79497 .46595 m .80539 .46263 L .80318 .45956 L p F P
0 g
s
.845 .682 .68 r
.60064 .70048 m .60264 .69637 L .59801 .6943 L p F P
0 g
s
.866 .711 .688 r
.60195 .70306 m .60064 .70048 L .60264 .69637 L p F P
0 g
s
.65 .757 .927 r
.34081 .45963 m .33124 .46295 L .33426 .46601 L p F P
0 g
s
.65 .757 .927 r
.33426 .46601 m .34381 .4627 L .34081 .45963 L p F P
0 g
s
.651 .757 .928 r
.64906 .45966 m .63892 .46299 L .64141 .46604 L p F P
0 g
s
.651 .757 .928 r
.64141 .46604 m .65154 .46273 L .64906 .45966 L p F P
0 g
s
.651 .757 .928 r
.49494 .45967 m .48508 .463 L .48783 .46606 L p F P
0 g
s
.651 .757 .928 r
.48783 .46606 m .49767 .46274 L .49494 .45967 L p F P
0 g
s
.575 .28 .43 r
.48882 .66098 m .48632 .66138 L .48568 .66552 L p F P
0 g
s
.54 .249 .421 r
.48632 .66138 m .48568 .66552 L .47512 .66773 L p F P
0 g
s
.665 .32 .38 r
.53523 .65435 m .53104 .65426 L .53413 .65805 L p F P
0 g
s
.665 .32 .38 r
.53413 .65805 m .53426 .65805 L .53523 .65435 L p F P
0 g
s
.827 .586 .573 r
.59533 .68222 m .59514 .68215 L .59438 .68715 L p F P
0 g
s
.827 .586 .573 r
.59438 .68715 m .59616 .68773 L .59533 .68222 L p F P
0 g
s
.627 .294 .386 r
.51915 .65428 m .52163 .65674 L p .50906 .65851 L F P
0 g
s
.633 .297 .384 r
.52163 .65674 m .51915 .65428 L .52226 .65417 L closepath p F P
0 g
s
.65 .757 .927 r
.3534 .45938 m .34381 .4627 L .34681 .46577 L p F P
0 g
s
.65 .757 .927 r
.34681 .46577 m .35639 .46246 L .3534 .45938 L p F P
0 g
s
.653 .316 .39 r
.53104 .65426 m .53413 .65805 L .52264 .65795 L p F P
0 g
s
.653 .316 .39 r
.52226 .65417 m .53104 .65426 L p .52264 .65795 L F P
0 g
s
.651 .757 .928 r
.6617 .4594 m .65154 .46273 L .654 .46579 L p F P
0 g
s
.651 .757 .928 r
.654 .46579 m .66415 .46247 L .6617 .4594 L p F P
0 g
s
.821 .58 .573 r
.59514 .68215 m .58939 .6804 L .58864 .68539 L p F P
0 g
s
.821 .58 .573 r
.58864 .68539 m .59438 .68715 L .59514 .68215 L p F P
0 g
s
.651 .757 .928 r
.50755 .45942 m .49767 .46274 L .5004 .4658 L p F P
0 g
s
.651 .757 .928 r
.5004 .4658 m .51027 .46249 L .50755 .45942 L p F P
0 g
s
.78 .767 .841 r
.60195 .70306 m .5993 .70212 L .5912 .70924 L p F P
0 g
s
.803 .693 .744 r
.5993 .70212 m .60195 .70306 L .60064 .70048 L closepath p F P
0 g
s
.848 .639 .619 r
.59951 .68908 m .59616 .68773 L .59799 .69429 L p F P
0 g
s
.848 .639 .619 r
.59799 .69429 m .59801 .6943 L .59951 .68908 L p F P
0 g
s
.653 .316 .39 r
.52264 .65795 m .52163 .65674 L .52226 .65417 L p F P
0 g
s
.306 .705 .977 r
.56556 .70986 m .56542 .70985 L .56568 .70993 L closepath p F P
0 g
s
.784 .473 .463 r
.57787 .66807 m .57646 .66775 L .57738 .67223 L p F P
0 g
s
.784 .473 .463 r
.57738 .67223 m .57741 .67224 L .57787 .66807 L p F P
0 g
s
.65 .757 .927 r
.366 .45913 m .35639 .46246 L .35936 .46552 L p F P
0 g
s
.65 .757 .927 r
.35936 .46552 m .36896 .4622 L .366 .45913 L p F P
0 g
s
.305 .705 .977 r
.56556 .70986 m .56542 .70985 L .55986 .70806 L p F P
0 g
s
.651 .757 .928 r
.67434 .45914 m .66415 .46247 L .6666 .46553 L p F P
0 g
s
.651 .757 .928 r
.6666 .46553 m .67677 .46221 L .67434 .45914 L p F P
0 g
s
.651 .757 .928 r
.52017 .45916 m .51027 .46249 L .51298 .46555 L p F P
0 g
s
.651 .757 .928 r
.51298 .46555 m .52287 .46223 L .52017 .45916 L p F P
0 g
s
.575 .28 .43 r
.48568 .66552 m .49359 .66426 L .48882 .66098 L p F P
0 g
s
.578 .278 .424 r
.49743 .65969 m .48882 .66098 L .49359 .66426 L p F P
0 g
s
.757 .426 .424 r
.56246 .66491 m .56211 .66395 L .5627 .66095 L p F P
0 g
s
.743 .412 .422 r
.56211 .66395 m .56079 .66067 L .5627 .66095 L closepath p F P
0 g
s
.603 .726 .932 r
.57295 .70466 m .56295 .70784 L .56556 .70986 L p F P
0 g
s
.603 .726 .932 r
.56556 .70986 m .57556 .70776 L .57295 .70466 L p F P
0 g
s
.466 .79 .999 r
.57816 .71045 m .57556 .70776 L .56556 .70986 L p F P
0 g
s
.305 .705 .977 r
.55986 .70806 m .56295 .70784 L .56556 .70986 L p F P
0 g
s
.547 .315 .516 r
.46455 .67953 m .46466 .67481 L .47471 .67213 L p F P
0 g
s
.524 .264 .462 r
.47512 .66773 m .47471 .67213 L .46466 .67481 L p F P
0 g
s
.65 .757 .927 r
.22442 .45875 m .21507 .46207 L .21829 .46514 L p F P
0 g
s
.65 .757 .927 r
.21829 .46514 m .22763 .46184 L .22442 .45875 L p F P
0 g
s
.65 .757 .928 r
.3786 .45888 m .36896 .4622 L .37191 .46527 L p F P
0 g
s
.65 .757 .928 r
.37191 .46527 m .38154 .46195 L .3786 .45888 L p F P
0 g
s
.651 .757 .927 r
.68699 .45887 m .67677 .46221 L .6792 .46527 L p F P
0 g
s
.651 .757 .927 r
.6792 .46527 m .6894 .46195 L .68699 .45887 L p F P
0 g
s
.776 .468 .467 r
.57646 .66775 m .56954 .66631 L .57039 .67081 L p F P
0 g
s
.776 .468 .467 r
.57039 .67081 m .57738 .67223 L .57646 .66775 L p F P
0 g
s
.651 .757 .928 r
.5328 .4589 m .52287 .46223 L .52555 .46529 L p F P
0 g
s
.651 .757 .928 r
.52555 .46529 m .53547 .46198 L .5328 .4589 L p F P
0 g
s
.56 .294 .47 r
.47471 .67213 m .47512 .66773 L .48568 .66552 L p F P
0 g
s
.734 .403 .42 r
.56079 .66067 m .55267 .65957 L .55431 .66382 L p F P
0 g
s
.734 .403 .42 r
.56211 .66395 m .56079 .66067 L p .55431 .66382 L F P
0 g
s
.65 .757 .927 r
.23701 .45852 m .22763 .46184 L .23082 .4649 L p F P
0 g
s
.65 .757 .927 r
.23082 .4649 m .24019 .4616 L .23701 .45852 L p F P
0 g
s
.651 .757 .927 r
.69964 .45861 m .6894 .46195 L .6918 .46501 L p F P
0 g
s
.651 .757 .927 r
.6918 .46501 m .70203 .46168 L .69964 .45861 L p F P
0 g
s
.651 .757 .928 r
.39121 .45863 m .38154 .46195 L .38447 .46502 L p F P
0 g
s
.651 .757 .928 r
.38447 .46502 m .39413 .4617 L .39121 .45863 L p F P
0 g
s
.651 .757 .928 r
.54543 .45865 m .53547 .46198 L .53814 .46504 L p F P
0 g
s
.651 .757 .928 r
.53814 .46504 m .54808 .46172 L .54543 .45865 L p F P
0 g
s
.845 .682 .68 r
.59801 .6943 m .59801 .69433 L .60064 .70048 L p F P
0 g
s
.805 .667 .711 r
.60064 .70048 m .5993 .70212 L .59398 .70026 L p F P
0 g
s
.805 .667 .711 r
.59398 .70026 m .59801 .69433 L .60064 .70048 L p F P
0 g
s
.768 .76 .846 r
.59074 .70957 m .5912 .70924 L .59007 .70869 L closepath p F P
0 g
s
.815 .762 .803 r
.5993 .70212 m .5912 .70924 L .59007 .70869 L p F P
0 g
s
.65 .757 .927 r
.24959 .45827 m .24019 .4616 L .24336 .46467 L p F P
0 g
s
.65 .757 .927 r
.24336 .46467 m .25275 .46135 L .24959 .45827 L p F P
0 g
s
.692 .763 .906 r
.579 .70597 m .57556 .70776 L .57816 .71045 L p F P
0 g
s
.692 .763 .906 r
.57816 .71045 m .58447 .70779 L .579 .70597 L p F P
0 g
s
.651 .757 .927 r
.71229 .45835 m .70203 .46168 L .70441 .46475 L p F P
0 g
s
.651 .757 .927 r
.70441 .46475 m .71466 .46142 L .71229 .45835 L p F P
0 g
s
.651 .757 .928 r
.40382 .45837 m .39413 .4617 L .39704 .46477 L p F P
0 g
s
.651 .757 .928 r
.39704 .46477 m .40672 .46145 L .40382 .45837 L p F P
0 g
s
.651 .757 .928 r
.55806 .45839 m .54808 .46172 L .55072 .46478 L p F P
0 g
s
.651 .757 .928 r
.55072 .46478 m .56069 .46146 L .55806 .45839 L p F P
0 g
s
.518 .858 .994 r
.48737 .70889 m .48808 .70918 L .49882 .70717 L p F P
0 g
s
.51 .852 .995 r
.49996 .70781 m .49882 .70717 L .48808 .70918 L p F P
0 g
s
.815 .762 .803 r
.59398 .70026 m .5993 .70212 L p .59007 .70869 L F P
0 g
s
.65 .757 .927 r
.26218 .45803 m .25275 .46135 L .2559 .46442 L p F P
0 g
s
.65 .757 .927 r
.2559 .46442 m .26532 .46111 L .26218 .45803 L p F P
0 g
s
.651 .757 .927 r
.72495 .45808 m .71466 .46142 L .71702 .46449 L p F P
0 g
s
.651 .757 .927 r
.71702 .46449 m .72729 .46116 L .72495 .45808 L p F P
0 g
s
.651 .757 .928 r
.41643 .45812 m .40672 .46145 L .4096 .46452 L p F P
0 g
s
.651 .757 .928 r
.4096 .46452 m .41931 .4612 L .41643 .45812 L p F P
0 g
s
.651 .757 .928 r
.57069 .45813 m .56069 .46146 L .56331 .46453 L p F P
0 g
s
.651 .757 .928 r
.56331 .46453 m .5733 .46121 L .57069 .45813 L p F P
0 g
s
.804 .525 .516 r
.58342 .67393 m .58353 .67866 L .57751 .67696 L p F P
0 g
s
.804 .525 .516 r
.57741 .67224 m .58342 .67393 L p .57751 .67696 L F P
0 g
s
.63 .651 .852 r
.47146 .70554 m .47201 .70643 L .46221 .70916 L p F P
0 g
s
.63 .651 .852 r
.46221 .70916 m .46187 .70861 L .47146 .70554 L p F P
0 g
s
.65 .757 .927 r
.27477 .45779 m .26532 .46111 L .26845 .46418 L p F P
0 g
s
.65 .757 .927 r
.26845 .46418 m .27789 .46087 L .27477 .45779 L p F P
0 g
s
.651 .757 .927 r
.73761 .45782 m .72729 .46116 L .72963 .46422 L p F P
0 g
s
.651 .757 .927 r
.72963 .46422 m .73993 .4609 L .73761 .45782 L p F P
0 g
s
.651 .757 .928 r
.42905 .45787 m .41931 .4612 L .42217 .46426 L p F P
0 g
s
.651 .757 .928 r
.42217 .46426 m .4319 .46094 L .42905 .45787 L p F P
0 g
s
.651 .757 .928 r
.58333 .45787 m .5733 .46121 L .5759 .46427 L p F P
0 g
s
.651 .757 .928 r
.5759 .46427 m .58592 .46095 L .58333 .45787 L p F P
0 g
s
.56 .404 .628 r
.45609 .6934 m .4553 .68779 L .46484 .68465 L p F P
0 g
s
.535 .345 .569 r
.46455 .67953 m .46484 .68465 L .4553 .68779 L p F P
0 g
s
.815 .762 .803 r
.59007 .70869 m .58815 .70608 L .59398 .70026 L p F P
0 g
s
.701 .733 .875 r
.58447 .70779 m .59007 .70869 L .58815 .70608 L closepath p F P
0 g
s
.819 .623 .637 r
.59616 .68773 m .59438 .68715 L .5924 .69252 L p F P
0 g
s
.819 .623 .637 r
.5924 .69252 m .59799 .69429 L .59616 .68773 L p F P
0 g
s
.622 .625 .832 r
.46926 .70166 m .47146 .70554 L .46187 .70861 L p F P
0 g
s
.622 .625 .832 r
.46187 .70861 m .45946 .70423 L .46926 .70166 L p F P
0 g
s
.448 .821 .992 r
.5104 .70596 m .51255 .70691 L .52133 .70552 L closepath p F P
0 g
s
.415 .842 .955 r
.51255 .70691 m .5104 .70596 L .50589 .70656 L p F P
0 g
s
.608 .305 .43 r
.49676 .66379 m .49743 .65969 L .50887 .65852 L p F P
0 g
s
.578 .278 .424 r
.49359 .66426 m .49676 .66379 L .49743 .65969 L p F P
0 g
s
.65 .757 .927 r
.28737 .45754 m .27789 .46087 L .281 .46394 L p F P
0 g
s
.65 .757 .927 r
.281 .46394 m .29047 .46062 L .28737 .45754 L p F P
0 g
s
.651 .758 .927 r
.75028 .45755 m .73993 .4609 L .74225 .46396 L p F P
0 g
s
.651 .758 .927 r
.74225 .46396 m .75258 .46063 L .75028 .45755 L p F P
0 g
s
.651 .757 .928 r
.44167 .45761 m .4319 .46094 L .43475 .46401 L p F P
0 g
s
.651 .757 .928 r
.43475 .46401 m .4445 .46069 L .44167 .45761 L p F P
0 g
s
.651 .757 .928 r
.59597 .45762 m .58592 .46095 L .5885 .46402 L p F P
0 g
s
.651 .757 .928 r
.5885 .46402 m .59854 .46069 L .59597 .45762 L p F P
0 g
s
.534 .832 .999 r
.49882 .70717 m .49996 .70781 L .50589 .70656 L closepath p F P
0 g
s
.732 .409 .433 r
.55267 .65957 m .54802 .65901 L .5473 .66297 L p F P
0 g
s
.732 .409 .433 r
.5473 .66297 m .55431 .66382 L .55267 .65957 L p F P
0 g
s
.41 .804 .986 r
.52272 .70545 m .52514 .70652 L .53325 .7055 L closepath p F P
0 g
s
.312 .792 .909 r
.52514 .70652 m .52272 .70545 L .52133 .70552 L p F P
0 g
s
.65 .757 .927 r
.29997 .4573 m .29047 .46062 L .29356 .46369 L p F P
0 g
s
.65 .757 .927 r
.29356 .46369 m .30305 .46038 L .29997 .4573 L p F P
0 g
s
.651 .758 .927 r
.76294 .45729 m .75258 .46063 L .75487 .4637 L p F P
0 g
s
.651 .758 .927 r
.75487 .4637 m .76522 .46036 L .76294 .45729 L p F P
0 g
s
.819 .577 .572 r
.58939 .6804 m .58353 .67866 L .58282 .68365 L p F P
0 g
s
.819 .577 .572 r
.58282 .68365 m .58864 .68539 L .58939 .6804 L p F P
0 g
s
.617 .779 .959 r
.49448 .70379 m .48461 .70673 L .48737 .70889 L p F P
0 g
s
.617 .779 .959 r
.48737 .70889 m .49722 .7063 L .49448 .70379 L p F P
0 g
s
.518 .858 .994 r
.49882 .70717 m .49722 .7063 L .48737 .70889 L p F P
0 g
s
.639 .727 .912 r
.48185 .70343 m .47201 .70643 L .47478 .70959 L p F P
0 g
s
.639 .727 .912 r
.47478 .70959 m .48461 .70673 L .48185 .70343 L p F P
0 g
s
.651 .757 .928 r
.45429 .45736 m .4445 .46069 L .44733 .46376 L p F P
0 g
s
.651 .757 .928 r
.44733 .46376 m .45711 .46044 L .45429 .45736 L p F P
0 g
s
.651 .757 .928 r
.60862 .45736 m .59854 .46069 L .6011 .46376 L p F P
0 g
s
.651 .757 .928 r
.6011 .46376 m .61117 .46043 L .60862 .45736 L p F P
0 g
s
.84 .661 .66 r
.59801 .69433 m .59801 .6943 L .59799 .69429 L closepath p F P
0 g
s
.813 .68 .717 r
.59801 .69433 m .59799 .69429 L p .58873 .69837 L F P
0 g
s
.813 .68 .717 r
.58873 .69837 m .59398 .70026 L .59801 .69433 L p F P
0 g
s
.813 .68 .717 r
.59799 .69429 m .5924 .69252 L .58873 .69837 L p F P
0 g
s
.774 .47 .473 r
.56954 .66631 m .56246 .66491 L .56329 .66942 L p F P
0 g
s
.774 .47 .473 r
.56329 .66942 m .57039 .67081 L .56954 .66631 L p F P
0 g
s
.651 .758 .927 r
.77561 .45702 m .76522 .46036 L .76749 .46343 L p F P
0 g
s
.651 .758 .927 r
.76749 .46343 m .77787 .4601 L .77561 .45702 L p F P
0 g
s
.65 .757 .927 r
.31258 .45705 m .30305 .46038 L .30611 .46345 L p F P
0 g
s
.65 .757 .927 r
.30611 .46345 m .31563 .46013 L .31258 .45705 L p F P
0 g
s
.82 .624 .638 r
.59438 .68715 m .58864 .68539 L .58677 .69072 L p F P
0 g
s
.82 .624 .638 r
.58677 .69072 m .5924 .69252 L .59438 .68715 L p F P
0 g
s
.651 .757 .928 r
.62127 .4571 m .61117 .46043 L .6137 .4635 L p F P
0 g
s
.651 .757 .928 r
.6137 .4635 m .62379 .46018 L .62127 .4571 L p F P
0 g
s
.651 .757 .928 r
.46692 .4571 m .45711 .46044 L .45991 .46351 L p F P
0 g
s
.651 .757 .928 r
.45991 .46351 m .46971 .46018 L .46692 .4571 L p F P
0 g
s
.389 .774 .99 r
.56295 .70784 m .55986 .70806 L .55152 .70706 L p F P
0 g
s
.451 .805 .997 r
.53573 .70562 m .53773 .7067 L .54364 .70592 L closepath p F P
0 g
s
.289 .775 .911 r
.53773 .7067 m .53573 .70562 L .53325 .7055 L p F P
0 g
s
.707 .383 .428 r
.54802 .65901 m .54382 .65869 L .54575 .66285 L p F P
0 g
s
.707 .383 .428 r
.54575 .66285 m .5473 .66297 L .54802 .65901 L p F P
0 g
s
.651 .758 .927 r
.78829 .45675 m .77787 .4601 L .78012 .46316 L p F P
0 g
s
.651 .758 .927 r
.78012 .46316 m .79052 .45983 L .78829 .45675 L p F P
0 g
s
.65 .757 .927 r
.32518 .4568 m .31563 .46013 L .31868 .4632 L p F P
0 g
s
.65 .757 .927 r
.31868 .4632 m .32822 .45988 L .32518 .4568 L p F P
0 g
s
.654 .316 .389 r
.52133 .65795 m .52163 .65674 L .52264 .65795 L closepath p F P
0 g
s
.627 .294 .386 r
.52163 .65674 m .52133 .65795 L .50906 .65851 L p F P
0 g
s
.651 .757 .928 r
.63392 .45684 m .62379 .46018 L .62631 .46324 L p F P
0 g
s
.651 .757 .928 r
.62631 .46324 m .63643 .45992 L .63392 .45684 L p F P
0 g
s
.651 .757 .928 r
.47955 .45685 m .46971 .46018 L .47249 .46325 L p F P
0 g
s
.651 .757 .928 r
.47249 .46325 m .48232 .45993 L .47955 .45685 L p F P
0 g
s
.729 .713 .835 r
.58815 .70608 m .58447 .70779 L .579 .70597 L p F P
0 g
s
.651 .758 .927 r
.80097 .45648 m .79052 .45983 L .79275 .4629 L p F P
0 g
s
.651 .758 .927 r
.79275 .4629 m .80318 .45956 L .80097 .45648 L p F P
0 g
s
.65 .757 .927 r
.3378 .45655 m .32822 .45988 L .33124 .46295 L p F P
0 g
s
.65 .757 .927 r
.33124 .46295 m .34081 .45963 L .3378 .45655 L p F P
0 g
s
.651 .757 .928 r
.64658 .45658 m .63643 .45992 L .63892 .46299 L p F P
0 g
s
.651 .757 .928 r
.63892 .46299 m .64906 .45966 L .64658 .45658 L p F P
0 g
s
.651 .757 .928 r
.49219 .45659 m .48232 .45993 L .48508 .463 L p F P
0 g
s
.651 .757 .928 r
.48508 .463 m .49494 .45967 L .49219 .45659 L p F P
0 g
s
.697 .382 .439 r
.54382 .65869 m .54575 .66285 L .536 .66223 L p F P
0 g
s
.697 .382 .439 r
.53426 .65805 m .54382 .65869 L p .536 .66223 L F P
0 g
s
.568 .37 .572 r
.46484 .68465 m .46455 .67953 L .47462 .67686 L p F P
0 g
s
.547 .315 .516 r
.47471 .67213 m .47462 .67686 L .46455 .67953 L p F P
0 g
s
.757 .426 .424 r
.56194 .66482 m .56211 .66395 L .56246 .66491 L closepath p F P
0 g
s
.734 .403 .42 r
.55431 .66382 m .56194 .66482 L .56211 .66395 L p F P
0 g
s
.591 .32 .475 r
.49359 .66426 m .48568 .66552 L .48529 .66992 L p F P
0 g
s
.56 .294 .47 r
.48568 .66552 m .48529 .66992 L .47471 .67213 L p F P
0 g
s
.548 .808 .994 r
.54996 .70702 m .55034 .70729 L .55152 .70706 L closepath p F P
0 g
s
.364 .802 .961 r
.55034 .70729 m .54996 .70702 L .54364 .70592 L p F P
0 g
s
.608 .305 .43 r
.50887 .65852 m .50903 .65871 L p .49676 .66379 L F P
0 g
s
.616 .314 .434 r
.50903 .65871 m .50887 .65852 L .50906 .65851 L closepath p F P
0 g
s
.65 .757 .927 r
.35041 .4563 m .34081 .45963 L .34381 .4627 L p F P
0 g
s
.65 .757 .927 r
.34381 .4627 m .3534 .45938 L .35041 .4563 L p F P
0 g
s
.651 .757 .928 r
.65924 .45632 m .64906 .45966 L .65154 .46273 L p F P
0 g
s
.651 .757 .928 r
.65154 .46273 m .6617 .4594 L .65924 .45632 L p F P
0 g
s
.637 .333 .439 r
.50906 .65851 m .52133 .65795 L p .51155 .66244 L F P
0 g
s
.637 .333 .439 r
.51155 .66244 m .50903 .65871 L .50906 .65851 L p F P
0 g
s
.651 .757 .928 r
.50483 .45634 m .49494 .45967 L .49767 .46274 L p F P
0 g
s
.651 .757 .928 r
.49767 .46274 m .50755 .45942 L .50483 .45634 L p F P
0 g
s
.579 .456 .677 r
.45676 .69643 m .45609 .6934 L .46565 .69028 L p F P
0 g
s
.56 .404 .628 r
.46484 .68465 m .46565 .69028 L .45609 .6934 L p F P
0 g
s
.637 .333 .439 r
.50843 .66262 m .50903 .65871 L .51155 .66244 L closepath p F P
0 g
s
.608 .305 .43 r
.50903 .65871 m .50843 .66262 L .49676 .66379 L p F P
0 g
s
.79 .711 .777 r
.58815 .70608 m .59398 .70026 L .58873 .69837 L p F P
0 g
s
.607 .548 .763 r
.46733 .69674 m .46926 .70166 L .45946 .70423 L p F P
0 g
s
.607 .548 .763 r
.45946 .70423 m .45779 .69988 L .46733 .69674 L p F P
0 g
s
.65 .757 .927 r
.36303 .45605 m .3534 .45938 L .35639 .46246 L p F P
0 g
s
.65 .757 .927 r
.35639 .46246 m .366 .45913 L .36303 .45605 L p F P
0 g
s
.651 .757 .927 r
.67191 .45605 m .6617 .4594 L .66415 .46247 L p F P
0 g
s
.651 .757 .927 r
.66415 .46247 m .67434 .45914 L .67191 .45605 L p F P
0 g
s
.651 .757 .928 r
.51747 .45608 m .50755 .45942 L .51027 .46249 L p F P
0 g
s
.651 .757 .928 r
.51027 .46249 m .52017 .45916 L .51747 .45608 L p F P
0 g
s
.804 .525 .516 r
.57751 .67696 m .57742 .67362 L .57741 .67224 L p F P
0 g
s
.788 .512 .519 r
.57742 .67362 m .57738 .67223 L .57741 .67224 L closepath p F P
0 g
s
.78 .505 .52 r
.57738 .67223 m .57039 .67081 L .57048 .67555 L p F P
0 g
s
.78 .505 .52 r
.57742 .67362 m .57738 .67223 L p .57048 .67555 L F P
0 g
s
.529 .833 .999 r
.49722 .7063 m .49882 .70717 L .50589 .70656 L p F P
0 g
s
.579 .341 .52 r
.47462 .67686 m .47471 .67213 L .48529 .66992 L p F P
0 g
s
.547 .808 .994 r
.55152 .70706 m .56032 .7054 L p .5477 .70541 L F P
0 g
s
.547 .808 .994 r
.5477 .70541 m .54996 .70702 L .55152 .70706 L p F P
0 g
s
.389 .774 .99 r
.55152 .70706 m .56032 .7054 L .56295 .70784 L p F P
0 g
s
.79 .711 .777 r
.58873 .69837 m .58554 .70202 L .58815 .70608 L p F P
0 g
s
.729 .713 .835 r
.579 .70597 m .58554 .70202 L .58815 .70608 L p F P
0 g
s
.491 .784 .997 r
.5477 .70541 m .54364 .70592 L .54996 .70702 L closepath p F P
0 g
s
.65 .757 .927 r
.37565 .45579 m .366 .45913 L .36896 .4622 L p F P
0 g
s
.65 .757 .927 r
.36896 .4622 m .3786 .45888 L .37565 .45579 L p F P
0 g
s
.651 .757 .927 r
.68457 .45579 m .67434 .45914 L .67677 .46221 L p F P
0 g
s
.651 .757 .927 r
.67677 .46221 m .68699 .45887 L .68457 .45579 L p F P
0 g
s
.697 .382 .439 r
.536 .66223 m .53423 .65825 L .53426 .65805 L p F P
0 g
s
.68 .366 .436 r
.53423 .65825 m .53413 .65805 L .53426 .65805 L closepath p F P
0 g
s
.673 .359 .435 r
.53413 .65805 m .52264 .65795 L .52481 .66203 L p F P
0 g
s
.673 .359 .435 r
.53423 .65825 m .53413 .65805 L p .52481 .66203 L F P
0 g
s
.651 .757 .928 r
.53011 .45582 m .52017 .45916 L .52287 .46223 L p F P
0 g
s
.651 .757 .928 r
.52287 .46223 m .5328 .4589 L .53011 .45582 L p F P
0 g
s
.579 .456 .677 r
.46565 .69028 m .46655 .69423 L .45676 .69643 L p F P
0 g
s
.591 .5 .72 r
.45779 .69988 m .45676 .69643 L .46655 .69423 L p F P
0 g
s
.668 .358 .44 r
.52264 .65795 m .52133 .65795 L .52069 .66203 L p F P
0 g
s
.637 .333 .439 r
.52133 .65795 m .52069 .66203 L .51155 .66244 L p F P
0 g
s
.668 .358 .44 r
.52069 .66203 m .52481 .66203 L .52264 .65795 L p F P
0 g
s
.651 .71 .891 r
.56647 .70276 m .56032 .7054 L .56295 .70784 L p F P
0 g
s
.651 .71 .891 r
.57198 .70333 m .56647 .70276 L p .56295 .70784 L F P
0 g
s
.651 .71 .891 r
.56295 .70784 m .57295 .70466 L .57198 .70333 L p F P
0 g
s
.591 .5 .72 r
.46655 .69423 m .46733 .69674 L .45779 .69988 L p F P
0 g
s
.766 .465 .476 r
.56246 .66491 m .56194 .66482 L .56156 .66911 L p F P
0 g
s
.766 .465 .476 r
.56156 .66911 m .56329 .66942 L .56246 .66491 L p F P
0 g
s
.697 .382 .439 r
.53361 .6621 m .53423 .65825 L .536 .66223 L closepath p F P
0 g
s
.673 .359 .435 r
.52481 .66203 m .53361 .6621 L .53423 .65825 L p F P
0 g
s
.65 .757 .927 r
.23381 .45542 m .22442 .45875 L .22763 .46184 L p F P
0 g
s
.65 .757 .927 r
.22763 .46184 m .23701 .45852 L .23381 .45542 L p F P
0 g
s
.651 .757 .927 r
.69725 .45553 m .68699 .45887 L .6894 .46195 L p F P
0 g
s
.651 .757 .927 r
.6894 .46195 m .69964 .45861 L .69725 .45553 L p F P
0 g
s
.651 .757 .928 r
.38828 .45554 m .3786 .45888 L .38154 .46195 L p F P
0 g
s
.651 .757 .928 r
.38154 .46195 m .39121 .45863 L .38828 .45554 L p F P
0 g
s
.743 .444 .476 r
.56194 .66482 m .55431 .66382 L .55525 .6683 L p F P
0 g
s
.743 .444 .476 r
.55525 .6683 m .56156 .66911 L .56194 .66482 L p F P
0 g
s
.651 .757 .928 r
.54276 .45556 m .5328 .4589 L .53547 .46198 L p F P
0 g
s
.651 .757 .928 r
.53547 .46198 m .54543 .45865 L .54276 .45556 L p F P
0 g
s
.831 .581 .561 r
.58353 .67866 m .58282 .68365 L .5781 .6823 L p F P
0 g
s
.831 .581 .561 r
.57751 .67696 m .58353 .67866 L p .5781 .6823 L F P
0 g
s
.65 .757 .927 r
.24642 .45518 m .23701 .45852 L .24019 .4616 L p F P
0 g
s
.65 .757 .927 r
.24019 .4616 m .24959 .45827 L .24642 .45518 L p F P
0 g
s
.723 .76 .882 r
.57398 .70401 m .57295 .70466 L .57556 .70776 L p F P
0 g
s
.723 .76 .882 r
.57556 .70776 m .579 .70597 L .57398 .70401 L p F P
0 g
s
.651 .757 .927 r
.70992 .45526 m .69964 .45861 L .70203 .46168 L p F P
0 g
s
.651 .757 .927 r
.70203 .46168 m .71229 .45835 L .70992 .45526 L p F P
0 g
s
.529 .833 .999 r
.50589 .70656 m .50984 .70572 L p .49722 .7063 L F P
0 g
s
.495 .846 .994 r
.50984 .70572 m .50589 .70656 L .5104 .70596 L closepath p F P
0 g
s
.651 .757 .928 r
.40091 .45529 m .39121 .45863 L .39413 .4617 L p F P
0 g
s
.651 .757 .928 r
.39413 .4617 m .40382 .45837 L .40091 .45529 L p F P
0 g
s
.651 .757 .928 r
.55542 .4553 m .54543 .45865 L .54808 .46172 L p F P
0 g
s
.651 .757 .928 r
.54808 .46172 m .55806 .45839 L .55542 .4553 L p F P
0 g
s
.802 .524 .517 r
.57745 .67694 m .57742 .67362 L .57751 .67696 L closepath p F P
0 g
s
.78 .505 .52 r
.57048 .67555 m .57745 .67694 L .57742 .67362 L p F P
0 g
s
.816 .673 .705 r
.5924 .69252 m .58677 .69072 L .58343 .69649 L p F P
0 g
s
.816 .673 .705 r
.58343 .69649 m .58873 .69837 L .5924 .69252 L p F P
0 g
s
.65 .757 .927 r
.25903 .45494 m .24959 .45827 L .25275 .46135 L p F P
0 g
s
.65 .757 .927 r
.25275 .46135 m .26218 .45803 L .25903 .45494 L p F P
0 g
s
.819 .618 .631 r
.58864 .68539 m .58282 .68365 L .58108 .68894 L p F P
0 g
s
.819 .618 .631 r
.58108 .68894 m .58677 .69072 L .58864 .68539 L p F P
0 g
s
.651 .757 .927 r
.7226 .455 m .71229 .45835 L .71466 .46142 L p F P
0 g
s
.651 .757 .927 r
.71466 .46142 m .72495 .45808 L .7226 .455 L p F P
0 g
s
.651 .757 .928 r
.41355 .45503 m .40382 .45837 L .40672 .46145 L p F P
0 g
s
.651 .757 .928 r
.40672 .46145 m .41643 .45812 L .41355 .45503 L p F P
0 g
s
.651 .757 .928 r
.56807 .45505 m .55806 .45839 L .56069 .46146 L p F P
0 g
s
.651 .757 .928 r
.56069 .46146 m .57069 .45813 L .56807 .45505 L p F P
0 g
s
.591 .32 .475 r
.48529 .66992 m .4963 .66818 L .49359 .66426 L p F P
0 g
s
.595 .322 .472 r
.49676 .66379 m .49359 .66426 L .4963 .66818 L p F P
0 g
s
.65 .757 .927 r
.27164 .4547 m .26218 .45803 L .26532 .46111 L p F P
0 g
s
.65 .757 .927 r
.26532 .46111 m .27477 .45779 L .27164 .4547 L p F P
0 g
s
.651 .757 .927 r
.73528 .45473 m .72495 .45808 L .72729 .46116 L p F P
0 g
s
.651 .757 .927 r
.72729 .46116 m .73761 .45782 L .73528 .45473 L p F P
0 g
s
.651 .757 .928 r
.42619 .45478 m .41643 .45812 L .41931 .4612 L p F P
0 g
s
.651 .757 .928 r
.41931 .4612 m .42905 .45787 L .42619 .45478 L p F P
0 g
s
.651 .757 .928 r
.58073 .45479 m .57069 .45813 L .5733 .46121 L p F P
0 g
s
.651 .757 .928 r
.5733 .46121 m .58333 .45787 L .58073 .45479 L p F P
0 g
s
.746 .684 .791 r
.58554 .70202 m .579 .70597 L .57398 .70401 L p F P
0 g
s
.439 .82 .99 r
.50984 .70572 m .5104 .70596 L .52133 .70552 L p F P
0 g
s
.65 .757 .927 r
.28426 .45445 m .27477 .45779 L .27789 .46087 L p F P
0 g
s
.65 .757 .927 r
.27789 .46087 m .28737 .45754 L .28426 .45445 L p F P
0 g
s
.445 .804 .996 r
.54364 .70592 m .5477 .70541 L p .53507 .70528 L F P
0 g
s
.445 .804 .996 r
.53507 .70528 m .53573 .70562 L .54364 .70592 L p F P
0 g
s
.64 .661 .854 r
.48152 .70288 m .48185 .70343 L .47201 .70643 L p F P
0 g
s
.64 .661 .854 r
.47201 .70643 m .47146 .70554 L .48152 .70288 L p F P
0 g
s
.651 .758 .927 r
.74797 .45447 m .73761 .45782 L .73993 .4609 L p F P
0 g
s
.651 .758 .927 r
.73993 .4609 m .75028 .45755 L .74797 .45447 L p F P
0 g
s
.651 .757 .928 r
.43883 .45452 m .42905 .45787 L .4319 .46094 L p F P
0 g
s
.651 .757 .928 r
.4319 .46094 m .44167 .45761 L .43883 .45452 L p F P
0 g
s
.651 .757 .928 r
.5934 .45453 m .58333 .45787 L .58592 .46095 L p F P
0 g
s
.651 .757 .928 r
.58592 .46095 m .59597 .45762 L .5934 .45453 L p F P
0 g
s
.74 .443 .478 r
.55431 .66382 m .5473 .66297 L .54691 .66727 L p F P
0 g
s
.74 .443 .478 r
.54691 .66727 m .55525 .6683 L .55431 .66382 L p F P
0 g
s
.779 .505 .522 r
.57039 .67081 m .56329 .66942 L .56339 .67415 L p F P
0 g
s
.779 .505 .522 r
.56339 .67415 m .57048 .67555 L .57039 .67081 L p F P
0 g
s
.623 .346 .476 r
.49636 .66817 m .49676 .66379 L .50843 .66262 L p F P
0 g
s
.595 .322 .472 r
.4963 .66818 m .49636 .66817 L .49676 .66379 L p F P
0 g
s
.65 .757 .927 r
.29688 .4542 m .28737 .45754 L .29047 .46062 L p F P
0 g
s
.65 .757 .927 r
.29047 .46062 m .29997 .4573 L .29688 .4542 L p F P
0 g
s
.651 .758 .927 r
.76066 .4542 m .75028 .45755 L .75258 .46063 L p F P
0 g
s
.651 .758 .927 r
.75258 .46063 m .76294 .45729 L .76066 .4542 L p F P
0 g
s
.651 .757 .928 r
.45147 .45427 m .44167 .45761 L .4445 .46069 L p F P
0 g
s
.651 .757 .928 r
.4445 .46069 m .45429 .45736 L .45147 .45427 L p F P
0 g
s
.651 .757 .928 r
.60607 .45427 m .59597 .45762 L .59854 .46069 L p F P
0 g
s
.651 .757 .928 r
.59854 .46069 m .60862 .45736 L .60607 .45427 L p F P
0 g
s
.588 .425 .628 r
.46565 .69028 m .46484 .68465 L .47492 .68198 L p F P
0 g
s
.568 .37 .572 r
.47462 .67686 m .47492 .68198 L .46484 .68465 L p F P
0 g
s
.436 .799 .996 r
.53507 .70528 m .53325 .7055 L .53573 .70562 L closepath p F P
0 g
s
.642 .641 .833 r
.47911 .69847 m .48152 .70288 L .47146 .70554 L p F P
0 g
s
.642 .641 .833 r
.47146 .70554 m .46926 .70166 L .47911 .69847 L p F P
0 g
s
.439 .82 .99 r
.52133 .70552 m .52245 .70534 L p .50984 .70572 L F P
0 g
s
.437 .821 .989 r
.52245 .70534 m .52133 .70552 L .52272 .70545 L closepath p F P
0 g
s
.4 .802 .984 r
.53325 .7055 m .53507 .70528 L p .52245 .70534 L F P
0 g
s
.4 .802 .984 r
.52245 .70534 m .52272 .70545 L .53325 .7055 L p F P
0 g
s
.651 .758 .927 r
.77335 .45393 m .76294 .45729 L .76522 .46036 L p F P
0 g
s
.651 .758 .927 r
.76522 .46036 m .77561 .45702 L .77335 .45393 L p F P
0 g
s
.65 .757 .927 r
.30951 .45395 m .29997 .4573 L .30305 .46038 L p F P
0 g
s
.65 .757 .927 r
.30305 .46038 m .31258 .45705 L .30951 .45395 L p F P
0 g
s
.641 .704 .892 r
.48696 .70171 m .48185 .70343 L .48461 .70673 L p F P
0 g
s
.641 .704 .892 r
.49228 .70085 m .48696 .70171 L p .48461 .70673 L F P
0 g
s
.641 .704 .892 r
.48461 .70673 m .49448 .70379 L .49228 .70085 L p F P
0 g
s
.651 .757 .928 r
.61874 .45401 m .60862 .45736 L .61117 .46043 L p F P
0 g
s
.651 .757 .928 r
.61117 .46043 m .62127 .4571 L .61874 .45401 L p F P
0 g
s
.651 .757 .928 r
.46412 .45401 m .45429 .45736 L .45711 .46044 L p F P
0 g
s
.651 .757 .928 r
.45711 .46044 m .46692 .4571 L .46412 .45401 L p F P
0 g
s
.799 .7 .755 r
.58554 .70202 m .58873 .69837 L .58343 .69649 L p F P
0 g
s
.628 .738 .926 r
.50438 .70054 m .49448 .70379 L .49722 .7063 L p F P
0 g
s
.628 .738 .926 r
.49722 .7063 m .50711 .70363 L .50438 .70054 L p F P
0 g
s
.529 .833 .999 r
.50984 .70572 m .50711 .70363 L .49722 .7063 L p F P
0 g
s
.61 .75 .944 r
.51704 .70052 m .50711 .70363 L .50984 .70572 L p F P
0 g
s
.61 .75 .944 r
.50984 .70572 m .51975 .70337 L .51704 .70052 L p F P
0 g
s
.439 .82 .99 r
.52245 .70534 m .51975 .70337 L .50984 .70572 L p F P
0 g
s
.651 .758 .927 r
.78604 .45366 m .77561 .45702 L .77787 .4601 L p F P
0 g
s
.651 .758 .927 r
.77787 .4601 m .78829 .45675 L .78604 .45366 L p F P
0 g
s
.65 .757 .927 r
.32214 .4537 m .31258 .45705 L .31563 .46013 L p F P
0 g
s
.65 .757 .927 r
.31563 .46013 m .32518 .4568 L .32214 .4537 L p F P
0 g
s
.651 .757 .928 r
.63141 .45375 m .62127 .4571 L .62379 .46018 L p F P
0 g
s
.651 .757 .928 r
.62379 .46018 m .63392 .45684 L .63141 .45375 L p F P
0 g
s
.651 .757 .928 r
.47677 .45376 m .46692 .4571 L .46971 .46018 L p F P
0 g
s
.651 .757 .928 r
.46971 .46018 m .47955 .45685 L .47677 .45376 L p F P
0 g
s
.601 .743 .944 r
.52971 .70028 m .51975 .70337 L .52245 .70534 L p F P
0 g
s
.601 .743 .944 r
.52245 .70534 m .53239 .70317 L .52971 .70028 L p F P
0 g
s
.4 .802 .984 r
.53507 .70528 m .53239 .70317 L .52245 .70534 L p F P
0 g
s
.651 .758 .927 r
.79874 .45338 m .78829 .45675 L .79052 .45983 L p F P
0 g
s
.651 .758 .927 r
.79052 .45983 m .80097 .45648 L .79874 .45338 L p F P
0 g
s
.799 .7 .755 r
.58343 .69649 m .58291 .69717 L .58554 .70202 L p F P
0 g
s
.746 .684 .791 r
.57398 .70401 m .58291 .69717 L .58554 .70202 L p F P
0 g
s
.65 .757 .927 r
.33477 .45345 m .32518 .4568 L .32822 .45988 L p F P
0 g
s
.65 .757 .927 r
.32822 .45988 m .3378 .45655 L .33477 .45345 L p F P
0 g
s
.651 .757 .928 r
.64409 .45349 m .63392 .45684 L .63643 .45992 L p F P
0 g
s
.651 .757 .928 r
.63643 .45992 m .64658 .45658 L .64409 .45349 L p F P
0 g
s
.651 .757 .928 r
.48943 .4535 m .47955 .45685 L .48232 .45993 L p F P
0 g
s
.651 .757 .928 r
.48232 .45993 m .49219 .45659 L .48943 .4535 L p F P
0 g
s
.716 .42 .475 r
.5473 .66297 m .54575 .66285 L .54687 .66726 L p F P
0 g
s
.716 .42 .475 r
.54687 .66726 m .54691 .66727 L .5473 .66297 L p F P
0 g
s
.803 .554 .561 r
.57748 .67725 m .57751 .67696 L .57745 .67694 L closepath p F P
0 g
s
.831 .581 .561 r
.5781 .6823 m .57748 .67725 L .57751 .67696 L p F P
0 g
s
.783 .545 .576 r
.57745 .67694 m .57048 .67555 L .56964 .68058 L p F P
0 g
s
.783 .545 .576 r
.57748 .67725 m .57745 .67694 L p .56964 .68058 L F P
0 g
s
.606 .364 .523 r
.48521 .67465 m .48529 .66992 L .4963 .66818 L p F P
0 g
s
.579 .341 .52 r
.48529 .66992 m .48521 .67465 L .47462 .67686 L p F P
0 g
s
.597 .391 .573 r
.47492 .68198 m .47462 .67686 L .48521 .67465 L p F P
0 g
s
.71 .416 .478 r
.54575 .66285 m .536 .66223 L .53704 .66666 L p F P
0 g
s
.71 .416 .478 r
.53704 .66666 m .54687 .66726 L .54575 .66285 L p F P
0 g
s
.783 .545 .576 r
.56964 .68058 m .57665 .68199 L .57748 .67725 L p F P
0 g
s
.788 .55 .577 r
.57665 .68199 m .5781 .6823 L .57748 .67725 L closepath p F P
0 g
s
.613 .726 .926 r
.54237 .69978 m .53239 .70317 L .53507 .70528 L p F P
0 g
s
.613 .726 .926 r
.53507 .70528 m .54504 .70296 L .54237 .69978 L p F P
0 g
s
.445 .804 .996 r
.5477 .70541 m .54504 .70296 L .53507 .70528 L p F P
0 g
s
.65 .757 .927 r
.34741 .4532 m .3378 .45655 L .34081 .45963 L p F P
0 g
s
.65 .757 .927 r
.34081 .45963 m .35041 .4563 L .34741 .4532 L p F P
0 g
s
.651 .757 .927 r
.65677 .45322 m .64658 .45658 L .64906 .45966 L p F P
0 g
s
.651 .757 .927 r
.64906 .45966 m .65924 .45632 L .65677 .45322 L p F P
0 g
s
.651 .757 .928 r
.50209 .45324 m .49219 .45659 L .49494 .45967 L p F P
0 g
s
.651 .757 .928 r
.49494 .45967 m .50483 .45634 L .50209 .45324 L p F P
0 g
s
.833 .667 .677 r
.58677 .69072 m .58343 .69649 L .58244 .69617 L p F P
0 g
s
.833 .667 .677 r
.58108 .68894 m .58677 .69072 L p .58244 .69617 L F P
0 g
s
.812 .605 .623 r
.58282 .68365 m .5781 .6823 L .57956 .6885 L p F P
0 g
s
.812 .605 .623 r
.57956 .6885 m .58108 .68894 L .58282 .68365 L p F P
0 g
s
.649 .37 .482 r
.51155 .66244 m .50843 .66262 L .50806 .66701 L p F P
0 g
s
.623 .346 .476 r
.50843 .66262 m .50806 .66701 L .49636 .66817 L p F P
0 g
s
.65 .757 .927 r
.36005 .45295 m .35041 .4563 L .3534 .45938 L p F P
0 g
s
.65 .757 .927 r
.3534 .45938 m .36303 .45605 L .36005 .45295 L p F P
0 g
s
.651 .757 .927 r
.66946 .45296 m .65924 .45632 L .6617 .4594 L p F P
0 g
s
.651 .757 .927 r
.6617 .4594 m .67191 .45605 L .66946 .45296 L p F P
0 g
s
.651 .757 .928 r
.51475 .45298 m .50483 .45634 L .50755 .45942 L p F P
0 g
s
.651 .757 .928 r
.50755 .45942 m .51747 .45608 L .51475 .45298 L p F P
0 g
s
.649 .37 .482 r
.50806 .66701 m .51302 .66674 L .51155 .66244 L p F P
0 g
s
.655 .373 .48 r
.52069 .66203 m .51155 .66244 L .51302 .66674 L p F P
0 g
s
.643 .706 .893 r
.55193 .70011 m .54504 .70296 L .5477 .70541 L p F P
0 g
s
.643 .706 .893 r
.55616 .70034 m .55193 .70011 L p .5477 .70541 L F P
0 g
s
.643 .706 .893 r
.5477 .70541 m .55769 .70243 L .55616 .70034 L p F P
0 g
s
.547 .808 .994 r
.56032 .7054 m .55769 .70243 L .5477 .70541 L p F P
0 g
s
.771 .498 .522 r
.56329 .66942 m .56156 .66911 L .56158 .67383 L p F P
0 g
s
.771 .498 .522 r
.56158 .67383 m .56339 .67415 L .56329 .66942 L p F P
0 g
s
.65 .757 .927 r
.3727 .4527 m .36303 .45605 L .366 .45913 L p F P
0 g
s
.65 .757 .927 r
.366 .45913 m .37565 .45579 L .3727 .4527 L p F P
0 g
s
.651 .757 .927 r
.68215 .4527 m .67191 .45605 L .67434 .45914 L p F P
0 g
s
.651 .757 .927 r
.67434 .45914 m .68457 .45579 L .68215 .4527 L p F P
0 g
s
.651 .757 .928 r
.52742 .45273 m .51747 .45608 L .52017 .45916 L p F P
0 g
s
.651 .757 .928 r
.52017 .45916 m .53011 .45582 L .52742 .45273 L p F P
0 g
s
.604 .475 .679 r
.46655 .69423 m .46565 .69028 L .47573 .68761 L p F P
0 g
s
.588 .425 .628 r
.47492 .68198 m .47573 .68761 L .46565 .69028 L p F P
0 g
s
.706 .416 .482 r
.536 .66223 m .53361 .6621 L .53325 .66646 L p F P
0 g
s
.706 .416 .482 r
.53325 .66646 m .53704 .66666 L .536 .66223 L p F P
0 g
s
.627 .564 .764 r
.47744 .6941 m .47911 .69847 L .46926 .70166 L p F P
0 g
s
.627 .564 .764 r
.46926 .70166 m .46733 .69674 L .47744 .6941 L p F P
0 g
s
.745 .742 .849 r
.57295 .70466 m .57398 .70401 L .57198 .70333 L closepath p F P
0 g
s
.651 .757 .927 r
.69484 .45243 m .68457 .45579 L .68699 .45887 L p F P
0 g
s
.651 .757 .927 r
.68699 .45887 m .69725 .45553 L .69484 .45243 L p F P
0 g
s
.651 .757 .927 r
.38534 .45244 m .37565 .45579 L .3786 .45888 L p F P
0 g
s
.651 .757 .927 r
.3786 .45888 m .38828 .45554 L .38534 .45244 L p F P
0 g
s
.748 .479 .524 r
.56156 .66911 m .55525 .6683 L .55533 .67303 L p F P
0 g
s
.748 .479 .524 r
.55533 .67303 m .56158 .67383 L .56156 .66911 L p F P
0 g
s
.693 .751 .896 r
.55987 .70124 m .55769 .70243 L .56032 .7054 L p F P
0 g
s
.693 .751 .896 r
.56032 .7054 m .56647 .70276 L .55987 .70124 L p F P
0 g
s
.683 .396 .48 r
.53361 .6621 m .52481 .66203 L .52604 .6664 L p F P
0 g
s
.683 .396 .48 r
.52604 .6664 m .53325 .66646 L .53361 .6621 L p F P
0 g
s
.651 .757 .928 r
.54009 .45247 m .53011 .45582 L .5328 .4589 L p F P
0 g
s
.651 .757 .928 r
.5328 .4589 m .54276 .45556 L .54009 .45247 L p F P
0 g
s
.678 .393 .482 r
.52481 .66203 m .52069 .66203 L .52033 .66641 L p F P
0 g
s
.655 .373 .48 r
.51302 .66674 m .52033 .66641 L .52069 .66203 L p F P
0 g
s
.678 .393 .482 r
.52033 .66641 m .52604 .6664 L .52481 .66203 L p F P
0 g
s
.796 .746 .807 r
.58291 .69717 m .57398 .70401 L .57198 .70333 L p F P
0 g
s
.65 .757 .927 r
.24323 .45208 m .23381 .45542 L .23701 .45852 L p F P
0 g
s
.65 .757 .927 r
.23701 .45852 m .24642 .45518 L .24323 .45208 L p F P
0 g
s
.651 .757 .927 r
.70754 .45217 m .69725 .45553 L .69964 .45861 L p F P
0 g
s
.651 .757 .927 r
.69964 .45861 m .70992 .45526 L .70754 .45217 L p F P
0 g
s
.651 .757 .927 r
.398 .45219 m .38828 .45554 L .39121 .45863 L p F P
0 g
s
.651 .757 .927 r
.39121 .45863 m .40091 .45529 L .398 .45219 L p F P
0 g
s
.651 .757 .928 r
.55277 .45221 m .54276 .45556 L .54543 .45865 L p F P
0 g
s
.651 .757 .928 r
.54543 .45865 m .55542 .4553 L .55277 .45221 L p F P
0 g
s
.604 .475 .679 r
.47573 .68761 m .47641 .69064 L .46655 .69423 L p F P
0 g
s
.619 .521 .722 r
.46733 .69674 m .46655 .69423 L .47641 .69064 L p F P
0 g
s
.619 .521 .722 r
.47641 .69064 m .47744 .6941 L .46733 .69674 L p F P
0 g
s
.65 .757 .927 r
.25587 .45184 m .24642 .45518 L .24959 .45827 L p F P
0 g
s
.65 .757 .927 r
.24959 .45827 m .25903 .45494 L .25587 .45184 L p F P
0 g
s
.651 .757 .927 r
.72024 .4519 m .70992 .45526 L .71229 .45835 L p F P
0 g
s
.651 .757 .927 r
.71229 .45835 m .7226 .455 L .72024 .4519 L p F P
0 g
s
.651 .757 .928 r
.41065 .45194 m .40091 .45529 L .40382 .45837 L p F P
0 g
s
.651 .757 .928 r
.40382 .45837 m .41355 .45503 L .41065 .45194 L p F P
0 g
s
.651 .757 .928 r
.56545 .45195 m .55542 .4553 L .55806 .45839 L p F P
0 g
s
.651 .757 .928 r
.55806 .45839 m .56807 .45505 L .56545 .45195 L p F P
0 g
s
.783 .543 .574 r
.57048 .67555 m .56339 .67415 L .56261 .67916 L p F P
0 g
s
.783 .543 .574 r
.56261 .67916 m .56964 .68058 L .57048 .67555 L p F P
0 g
s
.65 .757 .927 r
.2685 .45159 m .25903 .45494 L .26218 .45803 L p F P
0 g
s
.65 .757 .927 r
.26218 .45803 m .27164 .4547 L .2685 .45159 L p F P
0 g
s
.801 .678 .728 r
.58291 .69717 m .58343 .69649 L .58244 .69617 L closepath p F P
0 g
s
.651 .757 .927 r
.73294 .45163 m .7226 .455 L .72495 .45808 L p F P
0 g
s
.651 .757 .927 r
.72495 .45808 m .73528 .45473 L .73294 .45163 L p F P
0 g
s
.651 .757 .928 r
.42331 .45168 m .41355 .45503 L .41643 .45812 L p F P
0 g
s
.651 .757 .928 r
.41643 .45812 m .42619 .45478 L .42331 .45168 L p F P
0 g
s
.651 .757 .928 r
.57813 .45169 m .56807 .45505 L .57069 .45813 L p F P
0 g
s
.651 .757 .928 r
.57069 .45813 m .58073 .45479 L .57813 .45169 L p F P
0 g
s
.796 .746 .807 r
.58244 .69617 m .58291 .69717 L p .57198 .70333 L F P
0 g
s
.74 .472 .525 r
.55525 .6683 m .55533 .67303 L .54698 .672 L p F P
0 g
s
.74 .472 .525 r
.54691 .66727 m .55525 .6683 L p .54698 .672 L F P
0 g
s
.796 .746 .807 r
.57687 .69496 m .58244 .69617 L p .57198 .70333 L F P
0 g
s
.796 .746 .807 r
.57198 .70333 m .57032 .70094 L .57687 .69496 L p F P
0 g
s
.7 .718 .863 r
.56647 .70276 m .57198 .70333 L .57032 .70094 L closepath p F P
0 g
s
.784 .588 .634 r
.5781 .6823 m .57665 .68199 L .57443 .68743 L p F P
0 g
s
.784 .588 .634 r
.57443 .68743 m .57956 .6885 L .5781 .6823 L p F P
0 g
s
.65 .757 .927 r
.28114 .45135 m .27164 .4547 L .27477 .45779 L p F P
0 g
s
.65 .757 .927 r
.27477 .45779 m .28426 .45445 L .28114 .45135 L p F P
0 g
s
.651 .757 .927 r
.74565 .45137 m .73528 .45473 L .73761 .45782 L p F P
0 g
s
.651 .757 .927 r
.73761 .45782 m .74797 .45447 L .74565 .45137 L p F P
0 g
s
.651 .757 .928 r
.43597 .45142 m .42619 .45478 L .42905 .45787 L p F P
0 g
s
.651 .757 .928 r
.42905 .45787 m .43883 .45452 L .43597 .45142 L p F P
0 g
s
.651 .757 .928 r
.59081 .45143 m .58073 .45479 L .58333 .45787 L p F P
0 g
s
.651 .757 .928 r
.58333 .45787 m .5934 .45453 L .59081 .45143 L p F P
0 g
s
.606 .364 .523 r
.4963 .66818 m .49634 .66956 L p .48521 .67465 L F P
0 g
s
.612 .368 .523 r
.49634 .66956 m .4963 .66818 L .49636 .66817 L closepath p F P
0 g
s
.633 .385 .525 r
.49636 .66817 m .50806 .66701 L p .49642 .67288 L F P
0 g
s
.633 .385 .525 r
.49642 .67288 m .49634 .66956 L .49636 .66817 L p F P
0 g
s
.833 .667 .677 r
.58244 .69617 m .58025 .69061 L .58108 .68894 L p F P
0 g
s
.776 .643 .714 r
.57687 .69496 m .58244 .69617 L .58025 .69061 L closepath p F P
0 g
s
.649 .659 .846 r
.48185 .70343 m .48696 .70171 L .48152 .70288 L closepath p F P
0 g
s
.65 .757 .927 r
.29378 .4511 m .28426 .45445 L .28737 .45754 L p F P
0 g
s
.65 .757 .927 r
.28737 .45754 m .29688 .4542 L .29378 .4511 L p F P
0 g
s
.651 .758 .927 r
.75836 .4511 m .74797 .45447 L .75028 .45755 L p F P
0 g
s
.651 .758 .927 r
.75028 .45755 m .76066 .4542 L .75836 .4511 L p F P
0 g
s
.786 .59 .635 r
.57665 .68199 m .56964 .68058 L .56758 .68597 L p F P
0 g
s
.786 .59 .635 r
.56758 .68597 m .57443 .68743 L .57665 .68199 L p F P
0 g
s
.651 .757 .928 r
.44864 .45117 m .43883 .45452 L .44167 .45761 L p F P
0 g
s
.651 .757 .928 r
.44167 .45761 m .45147 .45427 L .44864 .45117 L p F P
0 g
s
.651 .757 .928 r
.6035 .45117 m .5934 .45453 L .59597 .45762 L p F P
0 g
s
.651 .757 .928 r
.59597 .45762 m .60607 .45427 L .6035 .45117 L p F P
0 g
s
.612 .442 .627 r
.47573 .68761 m .47492 .68198 L .48552 .67977 L p F P
0 g
s
.597 .391 .573 r
.48521 .67465 m .48552 .67977 L .47492 .68198 L p F P
0 g
s
.806 .631 .666 r
.58025 .69061 m .58108 .68894 L .57956 .6885 L closepath p F P
0 g
s
.662 .643 .82 r
.49174 .70008 m .48696 .70171 L .48152 .70288 L p F P
0 g
s
.662 .643 .82 r
.48901 .69452 m .49174 .70008 L p .48152 .70288 L F P
0 g
s
.662 .643 .82 r
.48152 .70288 m .47911 .69847 L .48901 .69452 L p F P
0 g
s
.651 .758 .927 r
.77107 .45083 m .76066 .4542 L .76294 .45729 L p F P
0 g
s
.651 .758 .927 r
.76294 .45729 m .77335 .45393 L .77107 .45083 L p F P
0 g
s
.65 .757 .927 r
.30643 .45085 m .29688 .4542 L .29997 .4573 L p F P
0 g
s
.65 .757 .927 r
.29997 .4573 m .30951 .45395 L .30643 .45085 L p F P
0 g
s
.651 .757 .928 r
.6162 .45091 m .60607 .45427 L .60862 .45736 L p F P
0 g
s
.651 .757 .928 r
.60862 .45736 m .61874 .45401 L .6162 .45091 L p F P
0 g
s
.651 .757 .928 r
.46131 .45091 m .45147 .45427 L .45429 .45736 L p F P
0 g
s
.651 .757 .928 r
.45429 .45736 m .46412 .45401 L .46131 .45091 L p F P
0 g
s
.725 .686 .812 r
.57032 .70094 m .56647 .70276 L .55987 .70124 L p F P
0 g
s
.62 .408 .572 r
.49629 .6729 m .48521 .67465 L .48552 .67977 L p F P
0 g
s
.606 .364 .523 r
.49634 .66956 m .49629 .6729 L .48521 .67465 L p F P
0 g
s
.651 .758 .927 r
.78379 .45056 m .77335 .45393 L .77561 .45702 L p F P
0 g
s
.651 .758 .927 r
.77561 .45702 m .78604 .45366 L .78379 .45056 L p F P
0 g
s
.658 .71 .886 r
.50362 .69935 m .50438 .70054 L .49448 .70379 L p F P
0 g
s
.658 .71 .886 r
.49448 .70379 m .49228 .70085 L .50362 .69935 L p F P
0 g
s
.65 .757 .927 r
.31908 .4506 m .30951 .45395 L .31258 .45705 L p F P
0 g
s
.65 .757 .927 r
.31258 .45705 m .32214 .4537 L .31908 .4506 L p F P
0 g
s
.651 .757 .928 r
.62889 .45065 m .61874 .45401 L .62127 .4571 L p F P
0 g
s
.651 .757 .928 r
.62127 .4571 m .63141 .45375 L .62889 .45065 L p F P
0 g
s
.651 .757 .928 r
.47399 .45065 m .46412 .45401 L .46692 .4571 L p F P
0 g
s
.651 .757 .928 r
.46692 .4571 m .47677 .45376 L .47399 .45065 L p F P
0 g
s
.632 .384 .525 r
.49629 .6729 m .49634 .66956 L .49642 .67288 L closepath p F P
0 g
s
.781 .651 .718 r
.58025 .69061 m .57956 .6885 L p .57036 .69341 L F P
0 g
s
.781 .651 .718 r
.57036 .69341 m .57687 .69496 L .58025 .69061 L p F P
0 g
s
.781 .651 .718 r
.57956 .6885 m .57443 .68743 L .57036 .69341 L p F P
0 g
s
.651 .758 .927 r
.79651 .45028 m .78604 .45366 L .78829 .45675 L p F P
0 g
s
.651 .758 .927 r
.78829 .45675 m .79874 .45338 L .79651 .45028 L p F P
0 g
s
.65 .757 .927 r
.33174 .45035 m .32214 .4537 L .32518 .4568 L p F P
0 g
s
.65 .757 .927 r
.32518 .4568 m .33477 .45345 L .33174 .45035 L p F P
0 g
s
.647 .693 .879 r
.50859 .69887 m .50438 .70054 L .50711 .70363 L p F P
0 g
s
.647 .693 .879 r
.51562 .69847 m .50859 .69887 L p .50711 .70363 L F P
0 g
s
.647 .693 .879 r
.50711 .70363 m .51704 .70052 L .51562 .69847 L p F P
0 g
s
.651 .757 .927 r
.64159 .45038 m .63141 .45375 L .63392 .45684 L p F P
0 g
s
.651 .757 .927 r
.63392 .45684 m .64409 .45349 L .64159 .45038 L p F P
0 g
s
.651 .757 .928 r
.48666 .4504 m .47677 .45376 L .47955 .45685 L p F P
0 g
s
.651 .757 .928 r
.47955 .45685 m .48943 .4535 L .48666 .4504 L p F P
0 g
s
.74 .472 .525 r
.54698 .672 m .54691 .66865 L .54691 .66727 L p F P
0 g
s
.724 .459 .526 r
.54691 .66865 m .54687 .66726 L .54691 .66727 L closepath p F P
0 g
s
.718 .454 .526 r
.54687 .66726 m .53704 .66666 L .53712 .6714 L p F P
0 g
s
.718 .454 .526 r
.54691 .66865 m .54687 .66726 L p .53712 .6714 L F P
0 g
s
.774 .532 .57 r
.56339 .67415 m .56158 .67383 L .56209 .67907 L p F P
0 g
s
.774 .532 .57 r
.56209 .67907 m .56261 .67916 L .56339 .67415 L p F P
0 g
s
.646 .696 .882 r
.52247 .6983 m .51704 .70052 L .51975 .70337 L p F P
0 g
s
.646 .696 .882 r
.52826 .69822 m .52247 .6983 L p .51975 .70337 L F P
0 g
s
.646 .696 .882 r
.51975 .70337 m .52971 .70028 L .52826 .69822 L p F P
0 g
s
.65 .757 .927 r
.3444 .4501 m .33477 .45345 L .3378 .45655 L p F P
0 g
s
.65 .757 .927 r
.3378 .45655 m .34741 .4532 L .3444 .4501 L p F P
0 g
s
.651 .757 .927 r
.6543 .45012 m .64409 .45349 L .64658 .45658 L p F P
0 g
s
.651 .757 .927 r
.64658 .45658 m .65677 .45322 L .6543 .45012 L p F P
0 g
s
.651 .757 .928 r
.49935 .45014 m .48943 .4535 L .49219 .45659 L p F P
0 g
s
.651 .757 .928 r
.49219 .45659 m .50209 .45324 L .49935 .45014 L p F P
0 g
s
.66 .407 .527 r
.51302 .66674 m .50806 .66701 L .50801 .67175 L p F P
0 g
s
.633 .385 .525 r
.50806 .66701 m .50801 .67175 L .49642 .67288 L p F P
0 g
s
.765 .684 .772 r
.57036 .69341 m .56768 .69632 L .57032 .70094 L p F P
0 g
s
.765 .684 .772 r
.57032 .70094 m .57687 .69496 L .57036 .69341 L p F P
0 g
s
.725 .686 .812 r
.55987 .70124 m .56768 .69632 L .57032 .70094 L p F P
0 g
s
.656 .689 .87 r
.53364 .69851 m .52971 .70028 L .53239 .70317 L p F P
0 g
s
.656 .689 .87 r
.54166 .69873 m .53364 .69851 L p .53239 .70317 L F P
0 g
s
.656 .689 .87 r
.53239 .70317 m .54237 .69978 L .54166 .69873 L p F P
0 g
s
.65 .757 .927 r
.35706 .44984 m .34741 .4532 L .35041 .4563 L p F P
0 g
s
.65 .757 .927 r
.35041 .4563 m .36005 .45295 L .35706 .44984 L p F P
0 g
s
.651 .757 .927 r
.667 .44986 m .65677 .45322 L .65924 .45632 L p F P
0 g
s
.651 .757 .927 r
.65924 .45632 m .66946 .45296 L .667 .44986 L p F P
0 g
s
.651 .757 .928 r
.51203 .44988 m .50209 .45324 L .50483 .45634 L p F P
0 g
s
.651 .757 .928 r
.50483 .45634 m .51475 .45298 L .51203 .44988 L p F P
0 g
s
.752 .516 .574 r
.56158 .67383 m .55533 .67303 L .55435 .6781 L p F P
0 g
s
.752 .516 .574 r
.55435 .6781 m .56209 .67907 L .56158 .67383 L p F P
0 g
s
.66 .407 .527 r
.50801 .67175 m .51311 .67146 L .51302 .66674 L p F P
0 g
s
.666 .412 .527 r
.52033 .66641 m .51302 .66674 L .51311 .67146 L p F P
0 g
s
.714 .451 .527 r
.53704 .66666 m .53325 .66646 L .53324 .67119 L p F P
0 g
s
.714 .451 .527 r
.53324 .67119 m .53712 .6714 L .53704 .66666 L p F P
0 g
s
.656 .696 .875 r
.48696 .70171 m .49228 .70085 L .49174 .70008 L closepath p F P
0 g
s
.65 .757 .927 r
.36973 .44959 m .36005 .45295 L .36303 .45605 L p F P
0 g
s
.65 .757 .927 r
.36303 .45605 m .3727 .4527 L .36973 .44959 L p F P
0 g
s
.687 .741 .893 r
.54384 .699 m .54237 .69978 L .54504 .70296 L p F P
0 g
s
.687 .741 .893 r
.54504 .70296 m .55193 .70011 L .54384 .699 L p F P
0 g
s
.651 .757 .927 r
.67972 .44959 m .66946 .45296 L .67191 .45605 L p F P
0 g
s
.651 .757 .927 r
.67191 .45605 m .68215 .4527 L .67972 .44959 L p F P
0 g
s
.651 .757 .928 r
.52472 .44962 m .51475 .45298 L .51747 .45608 L p F P
0 g
s
.651 .757 .928 r
.51747 .45608 m .52742 .45273 L .52472 .44962 L p F P
0 g
s
.739 .471 .525 r
.54691 .67199 m .54691 .66865 L .54698 .672 L closepath p F P
0 g
s
.718 .454 .526 r
.53712 .6714 m .54691 .67199 L .54691 .66865 L p F P
0 g
s
.623 .485 .673 r
.47641 .69064 m .47573 .68761 L .48631 .68538 L p F P
0 g
s
.612 .442 .627 r
.48552 .67977 m .48631 .68538 L .47573 .68761 L p F P
0 g
s
.804 .595 .619 r
.56964 .68058 m .56758 .68597 L .56337 .6851 L p F P
0 g
s
.804 .595 .619 r
.56261 .67916 m .56964 .68058 L p .56337 .6851 L F P
0 g
s
.722 .734 .861 r
.55769 .70243 m .55987 .70124 L .55616 .70034 L closepath p F P
0 g
s
.693 .434 .527 r
.53325 .66646 m .52604 .6664 L .52611 .67113 L p F P
0 g
s
.693 .434 .527 r
.52611 .67113 m .53324 .67119 L .53325 .66646 L p F P
0 g
s
.643 .568 .756 r
.48809 .69194 m .48901 .69452 L .47911 .69847 L p F P
0 g
s
.643 .568 .756 r
.47911 .69847 m .47744 .6941 L .48809 .69194 L p F P
0 g
s
.688 .43 .527 r
.52604 .6664 m .52033 .66641 L .5203 .67114 L p F P
0 g
s
.666 .412 .527 r
.51311 .67146 m .5203 .67114 L .52033 .66641 L p F P
0 g
s
.688 .43 .527 r
.5203 .67114 m .52611 .67113 L .52604 .6664 L p F P
0 g
s
.651 .757 .927 r
.69243 .44933 m .68215 .4527 L .68457 .45579 L p F P
0 g
s
.651 .757 .927 r
.68457 .45579 m .69484 .45243 L .69243 .44933 L p F P
0 g
s
.651 .757 .927 r
.3824 .44934 m .3727 .4527 L .37565 .45579 L p F P
0 g
s
.651 .757 .927 r
.37565 .45579 m .38534 .45244 L .3824 .44934 L p F P
0 g
s
.809 .656 .693 r
.57443 .68743 m .57036 .69341 L .56582 .69233 L p F P
0 g
s
.809 .656 .693 r
.56758 .68597 m .57443 .68743 L p .56582 .69233 L F P
0 g
s
.651 .757 .928 r
.53741 .44936 m .52742 .45273 L .53011 .45582 L p F P
0 g
s
.651 .757 .928 r
.53011 .45582 m .54009 .45247 L .53741 .44936 L p F P
0 g
s
.651 .757 .927 r
.70515 .44906 m .69484 .45243 L .69725 .45553 L p F P
0 g
s
.651 .757 .927 r
.69725 .45553 m .70754 .45217 L .70515 .44906 L p F P
0 g
s
.651 .757 .927 r
.39507 .44908 m .38534 .45244 L .38828 .45554 L p F P
0 g
s
.651 .757 .927 r
.38828 .45554 m .398 .45219 L .39507 .44908 L p F P
0 g
s
.777 .74 .819 r
.56768 .69632 m .55987 .70124 L .55616 .70034 L p F P
0 g
s
.651 .757 .928 r
.55011 .4491 m .54009 .45247 L .54276 .45556 L p F P
0 g
s
.651 .757 .928 r
.54276 .45556 m .55277 .45221 L .55011 .4491 L p F P
0 g
s
.623 .485 .673 r
.48631 .68538 m .48632 .6854 L .47641 .69064 L p F P
0 g
s
.645 .532 .712 r
.47744 .6941 m .47641 .69064 L .48632 .6854 L p F P
0 g
s
.645 .532 .712 r
.48632 .6854 m .48809 .69194 L .47744 .6941 L p F P
0 g
s
.772 .531 .57 r
.55533 .67303 m .55435 .6781 L .5474 .67723 L p F P
0 g
s
.772 .531 .57 r
.54698 .672 m .55533 .67303 L p .5474 .67723 L F P
0 g
s
.65 .757 .927 r
.25269 .44872 m .24323 .45208 L .24642 .45518 L p F P
0 g
s
.65 .757 .927 r
.24642 .45518 m .25587 .45184 L .25269 .44872 L p F P
0 g
s
.651 .757 .927 r
.71787 .44879 m .70754 .45217 L .70992 .45526 L p F P
0 g
s
.651 .757 .927 r
.70992 .45526 m .72024 .4519 L .71787 .44879 L p F P
0 g
s
.651 .757 .927 r
.40775 .44883 m .398 .45219 L .40091 .45529 L p F P
0 g
s
.651 .757 .927 r
.40091 .45529 m .41065 .45194 L .40775 .44883 L p F P
0 g
s
.651 .757 .928 r
.56281 .44884 m .55277 .45221 L .55542 .4553 L p F P
0 g
s
.651 .757 .928 r
.55542 .4553 m .56545 .45195 L .56281 .44884 L p F P
0 g
s
.643 .421 .567 r
.49631 .67319 m .49642 .67288 L .49629 .6729 L closepath p F P
0 g
s
.62 .408 .572 r
.49631 .67319 m .49629 .6729 L p .48552 .67977 L F P
0 g
s
.666 .445 .576 r
.49642 .67288 m .50801 .67175 L p .49664 .67805 L F P
0 g
s
.666 .445 .576 r
.49664 .67805 m .49631 .67319 L .49642 .67288 L p F P
0 g
s
.62 .408 .572 r
.48552 .67977 m .49345 .67851 L .49631 .67319 L p F P
0 g
s
.628 .417 .577 r
.49345 .67851 m .49664 .67805 L .49631 .67319 L closepath p F P
0 g
s
.678 .705 .867 r
.50166 .69602 m .50362 .69935 L .49228 .70085 L p F P
0 g
s
.678 .705 .867 r
.49228 .70085 m .49174 .70008 L .50166 .69602 L p F P
0 g
s
.65 .757 .927 r
.26535 .44848 m .25587 .45184 L .25903 .45494 L p F P
0 g
s
.65 .757 .927 r
.25903 .45494 m .2685 .45159 L .26535 .44848 L p F P
0 g
s
.633 .454 .622 r
.49345 .67851 m .48552 .67977 L .48631 .68538 L p F P
0 g
s
.651 .757 .927 r
.7306 .44853 m .72024 .4519 L .7226 .455 L p F P
0 g
s
.651 .757 .927 r
.7226 .455 m .73294 .45163 L .7306 .44853 L p F P
0 g
s
.651 .757 .927 r
.42043 .44857 m .41065 .45194 L .41355 .45503 L p F P
0 g
s
.651 .757 .927 r
.41355 .45503 m .42331 .45168 L .42043 .44857 L p F P
0 g
s
.651 .757 .928 r
.57551 .44858 m .56545 .45195 L .56807 .45505 L p F P
0 g
s
.651 .757 .928 r
.56807 .45505 m .57813 .45169 L .57551 .44858 L p F P
0 g
s
.65 .757 .927 r
.27801 .44823 m .2685 .45159 L .27164 .4547 L p F P
0 g
s
.65 .757 .927 r
.27164 .4547 m .28114 .45135 L .27801 .44823 L p F P
0 g
s
.651 .757 .927 r
.74332 .44826 m .73294 .45163 L .73528 .45473 L p F P
0 g
s
.651 .757 .927 r
.73528 .45473 m .74565 .45137 L .74332 .44826 L p F P
0 g
s
.651 .757 .927 r
.43311 .44831 m .42331 .45168 L .42619 .45478 L p F P
0 g
s
.651 .757 .927 r
.42619 .45478 m .43597 .45142 L .43311 .44831 L p F P
0 g
s
.651 .757 .928 r
.58822 .44832 m .57813 .45169 L .58073 .45479 L p F P
0 g
s
.651 .757 .928 r
.58073 .45479 m .59081 .45143 L .58822 .44832 L p F P
0 g
s
.648 .586 .771 r
.49669 .69061 m .48901 .69452 L .49174 .70008 L p F P
0 g
s
.648 .586 .771 r
.49926 .69026 m .49669 .69061 L p .49174 .70008 L F P
0 g
s
.648 .586 .771 r
.49174 .70008 m .50166 .69602 L .49926 .69026 L p F P
0 g
s
.774 .666 .744 r
.56768 .69632 m .57036 .69341 L .56582 .69233 L closepath p F P
0 g
s
.65 .757 .927 r
.29068 .44798 m .28114 .45135 L .28426 .45445 L p F P
0 g
s
.65 .757 .927 r
.28426 .45445 m .29378 .4511 L .29068 .44798 L p F P
0 g
s
.651 .758 .927 r
.75606 .44799 m .74565 .45137 L .74797 .45447 L p F P
0 g
s
.651 .758 .927 r
.74797 .45447 m .75836 .4511 L .75606 .44799 L p F P
0 g
s
.651 .757 .928 r
.4458 .44806 m .43597 .45142 L .43883 .45452 L p F P
0 g
s
.651 .757 .928 r
.43883 .45452 m .44864 .45117 L .4458 .44806 L p F P
0 g
s
.651 .757 .928 r
.60093 .44806 m .59081 .45143 L .5934 .45453 L p F P
0 g
s
.651 .757 .928 r
.5934 .45453 m .6035 .45117 L .60093 .44806 L p F P
0 g
s
.777 .74 .819 r
.56582 .69233 m .56768 .69632 L p .55616 .70034 L F P
0 g
s
.777 .74 .819 r
.56339 .69198 m .56582 .69233 L p .55616 .70034 L F P
0 g
s
.777 .74 .819 r
.55616 .70034 m .55503 .69872 L .56339 .69198 L p F P
0 g
s
.692 .713 .865 r
.55193 .70011 m .55616 .70034 L .55503 .69872 L closepath p F P
0 g
s
.774 .561 .611 r
.56229 .68016 m .56261 .67916 L .56209 .67907 L closepath p F P
0 g
s
.804 .595 .619 r
.56337 .6851 m .56229 .68016 L .56261 .67916 L p F P
0 g
s
.651 .758 .927 r
.76879 .44772 m .75836 .4511 L .76066 .4542 L p F P
0 g
s
.651 .758 .927 r
.76066 .4542 m .77107 .45083 L .76879 .44772 L p F P
0 g
s
.65 .757 .927 r
.30334 .44773 m .29378 .4511 L .29688 .4542 L p F P
0 g
s
.65 .757 .927 r
.29688 .4542 m .30643 .45085 L .30334 .44773 L p F P
0 g
s
.757 .565 .637 r
.56209 .67907 m .55435 .6781 L .55201 .68357 L p F P
0 g
s
.757 .565 .637 r
.56229 .68016 m .56209 .67907 L p .55201 .68357 L F P
0 g
s
.651 .757 .927 r
.61365 .4478 m .6035 .45117 L .60607 .45427 L p F P
0 g
s
.651 .757 .927 r
.60607 .45427 m .6162 .45091 L .61365 .4478 L p F P
0 g
s
.651 .757 .928 r
.45849 .4478 m .44864 .45117 L .45147 .45427 L p F P
0 g
s
.651 .757 .928 r
.45147 .45427 m .46131 .45091 L .45849 .4478 L p F P
0 g
s
.715 .673 .808 r
.55503 .69872 m .55193 .70011 L .54384 .699 L p F P
0 g
s
.743 .503 .566 r
.54693 .67229 m .54698 .672 L .54691 .67199 L closepath p F P
0 g
s
.772 .531 .57 r
.5474 .67723 m .54693 .67229 L .54698 .672 L p F P
0 g
s
.725 .495 .577 r
.54691 .67199 m .53712 .6714 L .53601 .67649 L p F P
0 g
s
.725 .495 .577 r
.54693 .67229 m .54691 .67199 L p .53601 .67649 L F P
0 g
s
.779 .614 .676 r
.56501 .69026 m .56758 .68597 L .56337 .6851 L closepath p F P
0 g
s
.809 .656 .693 r
.56582 .69233 m .56501 .69026 L .56758 .68597 L p F P
0 g
s
.725 .495 .577 r
.53601 .67649 m .54581 .67711 L .54693 .67229 L p F P
0 g
s
.729 .499 .578 r
.54581 .67711 m .5474 .67723 L .54693 .67229 L closepath p F P
0 g
s
.651 .758 .927 r
.78153 .44744 m .77107 .45083 L .77335 .45393 L p F P
0 g
s
.651 .758 .927 r
.77335 .45393 m .78379 .45056 L .78153 .44744 L p F P
0 g
s
.65 .757 .927 r
.31602 .44748 m .30643 .45085 L .30951 .45395 L p F P
0 g
s
.65 .757 .927 r
.30951 .45395 m .31908 .4506 L .31602 .44748 L p F P
0 g
s
.651 .757 .927 r
.62636 .44753 m .6162 .45091 L .61874 .45401 L p F P
0 g
s
.651 .757 .927 r
.61874 .45401 m .62889 .45065 L .62636 .44753 L p F P
0 g
s
.651 .757 .928 r
.47119 .44754 m .46131 .45091 L .46412 .45401 L p F P
0 g
s
.651 .757 .928 r
.46412 .45401 m .47399 .45065 L .47119 .44754 L p F P
0 g
s
.757 .565 .637 r
.55201 .68357 m .56016 .68466 L .56229 .68016 L p F P
0 g
s
.757 .566 .637 r
.56016 .68466 m .56337 .6851 L .56229 .68016 L closepath p F P
0 g
s
.67 .683 .853 r
.50438 .70054 m .50859 .69887 L .50362 .69935 L closepath p F P
0 g
s
.67 .447 .573 r
.51311 .67146 m .50801 .67175 L .50836 .67688 L p F P
0 g
s
.666 .445 .576 r
.50801 .67175 m .50836 .67688 L .49664 .67805 L p F P
0 g
s
.651 .758 .927 r
.79428 .44717 m .78379 .45056 L .78604 .45366 L p F P
0 g
s
.651 .758 .927 r
.78604 .45366 m .79651 .45028 L .79428 .44717 L p F P
0 g
s
.65 .757 .927 r
.32869 .44723 m .31908 .4506 L .32214 .4537 L p F P
0 g
s
.65 .757 .927 r
.32214 .4537 m .33174 .45035 L .32869 .44723 L p F P
0 g
s
.651 .757 .927 r
.63909 .44727 m .62889 .45065 L .63141 .45375 L p F P
0 g
s
.651 .757 .927 r
.63141 .45375 m .64159 .45038 L .63909 .44727 L p F P
0 g
s
.651 .757 .928 r
.48389 .44728 m .47399 .45065 L .47677 .45376 L p F P
0 g
s
.651 .757 .928 r
.47677 .45376 m .48666 .4504 L .48389 .44728 L p F P
0 g
s
.633 .454 .622 r
.48631 .68538 m .48636 .68537 L .49345 .67851 L p F P
0 g
s
.642 .467 .631 r
.49664 .67805 m .49345 .67851 L .48636 .68537 L p F P
0 g
s
.679 .705 .867 r
.51704 .70052 m .52247 .6983 L .51562 .69847 L closepath p F P
0 g
s
.67 .447 .573 r
.50836 .67688 m .51146 .67671 L .51311 .67146 L p F P
0 g
s
.676 .453 .575 r
.5203 .67114 m .51311 .67146 L .51146 .67671 L p F P
0 g
s
.72 .488 .573 r
.53712 .6714 m .53324 .67119 L .53365 .67637 L p F P
0 g
s
.72 .488 .573 r
.53365 .67637 m .53601 .67649 L .53712 .6714 L p F P
0 g
s
.65 .757 .927 r
.34137 .44698 m .33174 .45035 L .33477 .45345 L p F P
0 g
s
.65 .757 .927 r
.33477 .45345 m .3444 .4501 L .34137 .44698 L p F P
0 g
s
.651 .757 .927 r
.65181 .44701 m .64159 .45038 L .64409 .45349 L p F P
0 g
s
.651 .757 .927 r
.64409 .45349 m .6543 .45012 L .65181 .44701 L p F P
0 g
s
.651 .757 .928 r
.49659 .44702 m .48666 .4504 L .48943 .4535 L p F P
0 g
s
.651 .757 .928 r
.48943 .4535 m .49935 .45014 L .49659 .44702 L p F P
0 g
s
.742 .665 .774 r
.55547 .69083 m .55236 .69387 L .55503 .69872 L p F P
0 g
s
.742 .665 .774 r
.55503 .69872 m .56339 .69198 L .55547 .69083 L p F P
0 g
s
.715 .673 .808 r
.54384 .699 m .55236 .69387 L .55503 .69872 L p F P
0 g
s
.642 .489 .66 r
.48632 .6854 m .48636 .68537 L .48631 .68538 L closepath p F P
0 g
s
.666 .533 .693 r
.48809 .69194 m .48632 .6854 L .48636 .68537 L p F P
0 g
s
.666 .533 .693 r
.48636 .68537 m .49755 .68376 L p .48809 .69194 L F P
0 g
s
.642 .467 .631 r
.48636 .68537 m .49755 .68376 L .49664 .67805 L p F P
0 g
s
.692 .713 .865 r
.52971 .70028 m .53364 .69851 L .52826 .69822 L closepath p F P
0 g
s
.703 .678 .823 r
.51433 .69649 m .50859 .69887 L .50362 .69935 L p F P
0 g
s
.703 .678 .823 r
.51162 .69069 m .51433 .69649 L p .50362 .69935 L F P
0 g
s
.703 .678 .823 r
.50362 .69935 m .50166 .69602 L .51162 .69069 L p F P
0 g
s
.752 .63 .726 r
.56339 .69198 m .56582 .69233 L .56501 .69026 L closepath p F P
0 g
s
.7 .473 .575 r
.53324 .67119 m .52611 .67113 L .52477 .6763 L p F P
0 g
s
.7 .473 .575 r
.52477 .6763 m .53365 .67637 L .53324 .67119 L p F P
0 g
s
.712 .711 .847 r
.54237 .69978 m .54384 .699 L .54166 .69873 L closepath p F P
0 g
s
.65 .757 .927 r
.35406 .44673 m .3444 .4501 L .34741 .4532 L p F P
0 g
s
.65 .757 .927 r
.34741 .4532 m .35706 .44984 L .35406 .44673 L p F P
0 g
s
.651 .757 .927 r
.66454 .44674 m .6543 .45012 L .65677 .45322 L p F P
0 g
s
.651 .757 .927 r
.65677 .45322 m .667 .44986 L .66454 .44674 L p F P
0 g
s
.696 .468 .574 r
.52611 .67113 m .5203 .67114 L .52068 .6763 L p F P
0 g
s
.676 .453 .575 r
.51146 .67671 m .52068 .6763 L .5203 .67114 L p F P
0 g
s
.651 .757 .928 r
.5093 .44676 m .49935 .45014 L .50209 .45324 L p F P
0 g
s
.651 .757 .928 r
.50209 .45324 m .51203 .44988 L .5093 .44676 L p F P
0 g
s
.696 .468 .574 r
.52068 .6763 m .52477 .6763 L .52611 .67113 L p F P
0 g
s
.754 .555 .626 r
.55435 .6781 m .5474 .67723 L .54854 .68313 L p F P
0 g
s
.754 .555 .626 r
.54854 .68313 m .55201 .68357 L .55435 .6781 L p F P
0 g
s
.753 .632 .727 r
.56337 .6851 m .56016 .68466 L .55547 .69083 L p F P
0 g
s
.753 .632 .727 r
.56501 .69026 m .56337 .6851 L p .55547 .69083 L F P
0 g
s
.66 .485 .636 r
.50836 .67688 m .49664 .67805 L .49755 .68376 L p F P
0 g
s
.753 .632 .727 r
.55547 .69083 m .56339 .69198 L .56501 .69026 L p F P
0 g
s
.656 .564 .74 r
.48901 .69452 m .49669 .69061 L .48809 .69194 L closepath p F P
0 g
s
.65 .757 .927 r
.36674 .44647 m .35706 .44984 L .36005 .45295 L p F P
0 g
s
.65 .757 .927 r
.36005 .45295 m .36973 .44959 L .36674 .44647 L p F P
0 g
s
.651 .757 .927 r
.67727 .44648 m .667 .44986 L .66946 .45296 L p F P
0 g
s
.651 .757 .927 r
.66946 .45296 m .67972 .44959 L .67727 .44648 L p F P
0 g
s
.651 .757 .928 r
.52201 .4465 m .51203 .44988 L .51475 .45298 L p F P
0 g
s
.651 .757 .928 r
.51475 .45298 m .52472 .44962 L .52201 .4465 L p F P
0 g
s
.761 .713 .807 r
.55236 .69387 m .54384 .699 L .54166 .69873 L p F P
0 g
s
.666 .533 .693 r
.49894 .68931 m .49669 .69061 L .48809 .69194 L p F P
0 g
s
.666 .533 .693 r
.49755 .68376 m .49894 .68931 L p .48809 .69194 L F P
0 g
s
.677 .689 .854 r
.50859 .69887 m .51562 .69847 L .51433 .69649 L closepath p F P
0 g
s
.651 .757 .927 r
.69001 .44621 m .67972 .44959 L .68215 .4527 L p F P
0 g
s
.651 .757 .927 r
.68215 .4527 m .69243 .44933 L .69001 .44621 L p F P
0 g
s
.651 .757 .927 r
.37944 .44622 m .36973 .44959 L .3727 .4527 L p F P
0 g
s
.651 .757 .927 r
.3727 .4527 m .3824 .44934 L .37944 .44622 L p F P
0 g
s
.651 .757 .928 r
.53472 .44624 m .52472 .44962 L .52742 .45273 L p F P
0 g
s
.651 .757 .928 r
.52742 .45273 m .53741 .44936 L .53472 .44624 L p F P
0 g
s
.761 .713 .807 r
.55074 .69011 m .55236 .69387 L p .54166 .69873 L F P
0 g
s
.761 .713 .807 r
.54703 .68982 m .55074 .69011 L p .54166 .69873 L F P
0 g
s
.761 .713 .807 r
.54166 .69873 m .53969 .69556 L .54703 .68982 L p F P
0 g
s
.696 .69 .84 r
.53364 .69851 m .54166 .69873 L .53969 .69556 L closepath p F P
0 g
s
.784 .632 .692 r
.56016 .68466 m .55547 .69083 L .55074 .69011 L p F P
0 g
s
.784 .632 .692 r
.55201 .68357 m .56016 .68466 L p .55074 .69011 L F P
0 g
s
.651 .757 .927 r
.70275 .44594 m .69243 .44933 L .69484 .45243 L p F P
0 g
s
.651 .757 .927 r
.69484 .45243 m .70515 .44906 L .70275 .44594 L p F P
0 g
s
.651 .757 .927 r
.39213 .44596 m .3824 .44934 L .38534 .45244 L p F P
0 g
s
.651 .757 .927 r
.38534 .45244 m .39507 .44908 L .39213 .44596 L p F P
0 g
s
.651 .757 .928 r
.54744 .44598 m .53741 .44936 L .54009 .45247 L p F P
0 g
s
.651 .757 .928 r
.54009 .45247 m .55011 .4491 L .54744 .44598 L p F P
0 g
s
.74 .716 .829 r
.53969 .69556 m .53364 .69851 L .52826 .69822 L p F P
0 g
s
.72 .705 .836 r
.52701 .69632 m .52247 .6983 L .51562 .69847 L p F P
0 g
s
.72 .705 .836 r
.5243 .69077 m .52701 .69632 L p .51562 .69847 L F P
0 g
s
.72 .705 .836 r
.51562 .69847 m .51433 .69649 L .5243 .69077 L p F P
0 g
s
.651 .757 .927 r
.71549 .44568 m .70515 .44906 L .70754 .45217 L p F P
0 g
s
.651 .757 .927 r
.70754 .45217 m .71787 .44879 L .71549 .44568 L p F P
0 g
s
.651 .757 .927 r
.40483 .44571 m .39507 .44908 L .398 .45219 L p F P
0 g
s
.651 .757 .927 r
.398 .45219 m .40775 .44883 L .40483 .44571 L p F P
0 g
s
.651 .757 .928 r
.56016 .44572 m .55011 .4491 L .55277 .45221 L p F P
0 g
s
.651 .757 .928 r
.55277 .45221 m .56281 .44884 L .56016 .44572 L p F P
0 g
s
.732 .54 .632 r
.5474 .67723 m .54581 .67711 L .54295 .68274 L p F P
0 g
s
.732 .54 .632 r
.54295 .68274 m .54854 .68313 L .5474 .67723 L p F P
0 g
s
.684 .697 .856 r
.52247 .6983 m .52826 .69822 L .52701 .69632 L closepath p F P
0 g
s
.74 .716 .829 r
.537 .68981 m .53969 .69556 L p .52826 .69822 L F P
0 g
s
.74 .716 .829 r
.52826 .69822 m .52701 .69632 L .537 .68981 L p F P
0 g
s
.755 .56 .631 r
.54581 .67711 m .54295 .68274 L .53467 .68216 L p F P
0 g
s
.755 .56 .631 r
.53601 .67649 m .54581 .67711 L p .53467 .68216 L F P
0 g
s
.65 .757 .927 r
.26219 .44535 m .25269 .44872 L .25587 .45184 L p F P
0 g
s
.65 .757 .927 r
.25587 .45184 m .26535 .44848 L .26219 .44535 L p F P
0 g
s
.651 .757 .927 r
.72824 .44541 m .71787 .44879 L .72024 .4519 L p F P
0 g
s
.651 .757 .927 r
.72024 .4519 m .7306 .44853 L .72824 .44541 L p F P
0 g
s
.651 .757 .927 r
.41753 .44545 m .40775 .44883 L .41065 .45194 L p F P
0 g
s
.651 .757 .927 r
.41065 .45194 m .42043 .44857 L .41753 .44545 L p F P
0 g
s
.651 .757 .928 r
.57289 .44546 m .56281 .44884 L .56545 .45195 L p F P
0 g
s
.651 .757 .928 r
.56545 .45195 m .57551 .44858 L .57289 .44546 L p F P
0 g
s
.678 .601 .762 r
.51109 .6892 m .51162 .69069 L .50166 .69602 L p F P
0 g
s
.678 .601 .762 r
.50166 .69602 m .49926 .69026 L .51109 .6892 L p F P
0 g
s
.678 .485 .618 r
.50892 .68075 m .51146 .67671 L .50836 .67688 L closepath p F P
0 g
s
.66 .485 .636 r
.50892 .68075 m .50836 .67688 L p .49755 .68376 L F P
0 g
s
.65 .757 .927 r
.27487 .4451 m .26535 .44848 L .2685 .45159 L p F P
0 g
s
.65 .757 .927 r
.2685 .45159 m .27801 .44823 L .27487 .4451 L p F P
0 g
s
.651 .757 .927 r
.74099 .44514 m .7306 .44853 L .73294 .45163 L p F P
0 g
s
.651 .757 .927 r
.73294 .45163 m .74332 .44826 L .74099 .44514 L p F P
0 g
s
.651 .757 .927 r
.43024 .44519 m .42043 .44857 L .42331 .45168 L p F P
0 g
s
.651 .757 .927 r
.42331 .45168 m .43311 .44831 L .43024 .44519 L p F P
0 g
s
.651 .757 .927 r
.58562 .4452 m .57551 .44858 L .57813 .45169 L p F P
0 g
s
.651 .757 .927 r
.57813 .45169 m .58822 .44832 L .58562 .4452 L p F P
0 g
s
.751 .644 .742 r
.55236 .69387 m .55547 .69083 L .55074 .69011 L closepath p F P
0 g
s
.667 .525 .681 r
.49894 .68931 m .5071 .68277 L .49755 .68376 L closepath p F P
0 g
s
.66 .485 .636 r
.49755 .68376 m .5071 .68277 L .50892 .68075 L p F P
0 g
s
.707 .522 .637 r
.51146 .67671 m .52068 .6763 L p .50926 .68258 L F P
0 g
s
.707 .522 .637 r
.50926 .68258 m .50892 .68075 L .51146 .67671 L p F P
0 g
s
.65 .757 .927 r
.28756 .44486 m .27801 .44823 L .28114 .45135 L p F P
0 g
s
.65 .757 .927 r
.28114 .45135 m .29068 .44798 L .28756 .44486 L p F P
0 g
s
.651 .757 .927 r
.75375 .44487 m .74332 .44826 L .74565 .45137 L p F P
0 g
s
.651 .757 .927 r
.74565 .45137 m .75606 .44799 L .75375 .44487 L p F P
0 g
s
.651 .757 .927 r
.44295 .44493 m .43311 .44831 L .43597 .45142 L p F P
0 g
s
.651 .757 .927 r
.43597 .45142 m .4458 .44806 L .44295 .44493 L p F P
0 g
s
.651 .757 .927 r
.59835 .44494 m .58822 .44832 L .59081 .45143 L p F P
0 g
s
.651 .757 .927 r
.59081 .45143 m .60093 .44806 L .59835 .44494 L p F P
0 g
s
.662 .559 .727 r
.49669 .69061 m .49926 .69026 L .49894 .68931 L closepath p F P
0 g
s
.753 .588 .672 r
.54967 .68713 m .55201 .68357 L .54854 .68313 L closepath p F P
0 g
s
.784 .632 .692 r
.55074 .69011 m .54967 .68713 L .55201 .68357 L p F P
0 g
s
.724 .523 .617 r
.53429 .6803 m .53601 .67649 L .53365 .67637 L closepath p F P
0 g
s
.755 .56 .631 r
.53467 .68216 m .53429 .6803 L .53601 .67649 L p F P
0 g
s
.672 .58 .744 r
.51386 .68907 m .51162 .69069 L .51433 .69649 L p F P
0 g
s
.672 .58 .744 r
.52355 .68874 m .51386 .68907 L p .51433 .69649 L F P
0 g
s
.672 .58 .744 r
.51433 .69649 m .5243 .69077 L .52355 .68874 L p F P
0 g
s
.651 .758 .927 r
.7665 .44459 m .75606 .44799 L .75836 .4511 L p F P
0 g
s
.651 .758 .927 r
.75836 .4511 m .76879 .44772 L .7665 .44459 L p F P
0 g
s
.65 .757 .927 r
.30025 .44461 m .29068 .44798 L .29378 .4511 L p F P
0 g
s
.65 .757 .927 r
.29378 .4511 m .30334 .44773 L .30025 .44461 L p F P
0 g
s
.709 .528 .642 r
.53365 .67637 m .52477 .6763 L .52162 .682 L p F P
0 g
s
.709 .528 .642 r
.53429 .6803 m .53365 .67637 L p .52162 .682 L F P
0 g
s
.651 .757 .927 r
.61109 .44467 m .60093 .44806 L .6035 .45117 L p F P
0 g
s
.651 .757 .927 r
.6035 .45117 m .61365 .4478 L .61109 .44467 L p F P
0 g
s
.651 .757 .927 r
.45566 .44468 m .4458 .44806 L .44864 .45117 L p F P
0 g
s
.651 .757 .927 r
.44864 .45117 m .45849 .4478 L .45566 .44468 L p F P
0 g
s
.702 .507 .622 r
.52477 .6763 m .52068 .6763 L .52159 .682 L p F P
0 g
s
.707 .522 .637 r
.52068 .6763 m .52159 .682 L .50926 .68258 L p F P
0 g
s
.702 .507 .622 r
.52159 .682 m .52162 .682 L .52477 .6763 L p F P
0 g
s
.729 .643 .763 r
.5378 .68904 m .537 .68981 L .53969 .69556 L p F P
0 g
s
.729 .643 .763 r
.53969 .69556 m .54703 .68982 L .5378 .68904 L p F P
0 g
s
.697 .578 .718 r
.50926 .68258 m .51109 .6892 L .49926 .69026 L p F P
0 g
s
.697 .578 .718 r
.5071 .68277 m .50926 .68258 L p .49926 .69026 L F P
0 g
s
.697 .578 .718 r
.49926 .69026 m .49894 .68931 L .5071 .68277 L p F P
0 g
s
.685 .587 .74 r
.52675 .68878 m .5243 .69077 L .52701 .69632 L p F P
0 g
s
.685 .587 .74 r
.53668 .68896 m .52675 .68878 L p .52701 .69632 L F P
0 g
s
.685 .587 .74 r
.52701 .69632 m .537 .68981 L .53668 .68896 L p F P
0 g
s
.651 .758 .927 r
.77927 .44432 m .76879 .44772 L .77107 .45083 L p F P
0 g
s
.651 .758 .927 r
.77107 .45083 m .78153 .44744 L .77927 .44432 L p F P
0 g
s
.65 .757 .927 r
.31294 .44436 m .30334 .44773 L .30643 .45085 L p F P
0 g
s
.65 .757 .927 r
.30643 .45085 m .31602 .44748 L .31294 .44436 L p F P
0 g
s
.651 .757 .927 r
.62383 .44441 m .61365 .4478 L .6162 .45091 L p F P
0 g
s
.651 .757 .927 r
.6162 .45091 m .62636 .44753 L .62383 .44441 L p F P
0 g
s
.651 .757 .927 r
.46838 .44442 m .45849 .4478 L .46131 .45091 L p F P
0 g
s
.651 .757 .927 r
.46131 .45091 m .47119 .44754 L .46838 .44442 L p F P
0 g
s
.735 .61 .719 r
.54854 .68313 m .54295 .68274 L .5378 .68904 L p F P
0 g
s
.735 .61 .719 r
.54967 .68713 m .54854 .68313 L p .5378 .68904 L F P
0 g
s
.733 .607 .717 r
.54703 .68982 m .55074 .69011 L .54967 .68713 L closepath p F P
0 g
s
.651 .758 .927 r
.79203 .44404 m .78153 .44744 L .78379 .45056 L p F P
0 g
s
.651 .758 .927 r
.78379 .45056 m .79428 .44717 L .79203 .44404 L p F P
0 g
s
.65 .757 .927 r
.32564 .4441 m .31602 .44748 L .31908 .4506 L p F P
0 g
s
.65 .757 .927 r
.31908 .4506 m .32869 .44723 L .32564 .4441 L p F P
0 g
s
.651 .757 .927 r
.63657 .44415 m .62636 .44753 L .62889 .45065 L p F P
0 g
s
.651 .757 .927 r
.62889 .45065 m .63909 .44727 L .63657 .44415 L p F P
0 g
s
.651 .757 .927 r
.4811 .44416 m .47119 .44754 L .47399 .45065 L p F P
0 g
s
.651 .757 .927 r
.47399 .45065 m .48389 .44728 L .4811 .44416 L p F P
0 g
s
.668 .496 .643 r
.5071 .68277 m .50926 .68258 L .50892 .68075 L closepath p F P
0 g
s
.735 .61 .719 r
.5378 .68904 m .54703 .68982 L .54967 .68713 L p F P
0 g
s
.65 .757 .927 r
.33834 .44385 m .32869 .44723 L .33174 .45035 L p F P
0 g
s
.65 .757 .927 r
.33174 .45035 m .34137 .44698 L .33834 .44385 L p F P
0 g
s
.732 .582 .687 r
.54295 .68274 m .53467 .68216 L .53668 .68896 L p F P
0 g
s
.732 .582 .687 r
.53668 .68896 m .5378 .68904 L .54295 .68274 L p F P
0 g
s
.651 .757 .927 r
.64932 .44388 m .63909 .44727 L .64159 .45038 L p F P
0 g
s
.651 .757 .927 r
.64159 .45038 m .65181 .44701 L .64932 .44388 L p F P
0 g
s
.651 .757 .927 r
.49383 .4439 m .48389 .44728 L .48666 .4504 L p F P
0 g
s
.651 .757 .927 r
.48666 .4504 m .49659 .44702 L .49383 .4439 L p F P
0 g
s
.69 .549 .689 r
.52159 .682 m .50926 .68258 L .51109 .6892 L p F P
0 g
s
.65 .757 .927 r
.35105 .4436 m .34137 .44698 L .3444 .4501 L p F P
0 g
s
.65 .757 .927 r
.3444 .4501 m .35406 .44673 L .35105 .4436 L p F P
0 g
s
.651 .757 .927 r
.66207 .44362 m .65181 .44701 L .6543 .45012 L p F P
0 g
s
.651 .757 .927 r
.6543 .45012 m .66454 .44674 L .66207 .44362 L p F P
0 g
s
.651 .757 .928 r
.50656 .44364 m .49659 .44702 L .49935 .45014 L p F P
0 g
s
.651 .757 .928 r
.49935 .45014 m .5093 .44676 L .50656 .44364 L p F P
0 g
s
.709 .528 .642 r
.52162 .682 m .5331 .68213 L .53429 .6803 L p F P
0 g
s
.712 .532 .644 r
.5331 .68213 m .53467 .68216 L .53429 .6803 L closepath p F P
0 g
s
.65 .757 .927 r
.36375 .44334 m .35406 .44673 L .35706 .44984 L p F P
0 g
s
.65 .757 .927 r
.35706 .44984 m .36674 .44647 L .36375 .44334 L p F P
0 g
s
.651 .757 .927 r
.67482 .44335 m .66454 .44674 L .667 .44986 L p F P
0 g
s
.651 .757 .927 r
.667 .44986 m .67727 .44648 L .67482 .44335 L p F P
0 g
s
.651 .757 .928 r
.51929 .44338 m .5093 .44676 L .51203 .44988 L p F P
0 g
s
.651 .757 .928 r
.51203 .44988 m .52201 .4465 L .51929 .44338 L p F P
0 g
s
.691 .583 .729 r
.51162 .69069 m .51386 .68907 L .51109 .6892 L closepath p F P
0 g
s
.713 .571 .693 r
.53467 .68216 m .5331 .68213 L .52675 .68878 L p F P
0 g
s
.713 .571 .693 r
.52675 .68878 m .53668 .68896 L .53467 .68216 L p F P
0 g
s
.69 .549 .689 r
.5216 .68203 m .52159 .682 L p .51109 .6892 L F P
0 g
s
.69 .549 .689 r
.51109 .6892 m .51386 .68907 L .5216 .68203 L p F P
0 g
s
.736 .581 .682 r
.5331 .68213 m .52675 .68878 L .52355 .68874 L p F P
0 g
s
.736 .581 .682 r
.52162 .682 m .5331 .68213 L p .52355 .68874 L F P
0 g
s
.651 .757 .927 r
.37647 .44309 m .36674 .44647 L .36973 .44959 L p F P
0 g
s
.651 .757 .927 r
.36973 .44959 m .37944 .44622 L .37647 .44309 L p F P
0 g
s
.651 .757 .927 r
.68758 .44308 m .67727 .44648 L .67972 .44959 L p F P
0 g
s
.651 .757 .927 r
.67972 .44959 m .69001 .44621 L .68758 .44308 L p F P
0 g
s
.651 .757 .927 r
.53202 .44312 m .52201 .4465 L .52472 .44962 L p F P
0 g
s
.651 .757 .927 r
.52472 .44962 m .53472 .44624 L .53202 .44312 L p F P
0 g
s
.695 .558 .695 r
.51386 .68907 m .52355 .68874 L .5216 .68203 L closepath p F P
0 g
s
.705 .537 .658 r
.5216 .68203 m .52162 .682 L .52159 .682 L closepath p F P
0 g
s
.736 .581 .682 r
.52355 .68874 m .5216 .68203 L .52162 .682 L p F P
0 g
s
.73 .61 .724 r
.537 .68981 m .5378 .68904 L .53668 .68896 L closepath p F P
0 g
s
.71 .6 .732 r
.5243 .69077 m .52675 .68878 L .52355 .68874 L closepath p F P
0 g
s
.651 .757 .927 r
.70034 .44281 m .69001 .44621 L .69243 .44933 L p F P
0 g
s
.651 .757 .927 r
.69243 .44933 m .70275 .44594 L .70034 .44281 L p F P
0 g
s
.651 .757 .927 r
.38918 .44283 m .37944 .44622 L .3824 .44934 L p F P
0 g
s
.651 .757 .927 r
.3824 .44934 m .39213 .44596 L .38918 .44283 L p F P
0 g
s
.651 .757 .927 r
.54476 .44286 m .53472 .44624 L .53741 .44936 L p F P
0 g
s
.651 .757 .927 r
.53741 .44936 m .54744 .44598 L .54476 .44286 L p F P
0 g
s
.651 .757 .927 r
.71311 .44255 m .70275 .44594 L .70515 .44906 L p F P
0 g
s
.651 .757 .927 r
.70515 .44906 m .71549 .44568 L .71311 .44255 L p F P
0 g
s
.651 .757 .927 r
.4019 .44258 m .39213 .44596 L .39507 .44908 L p F P
0 g
s
.651 .757 .927 r
.39507 .44908 m .40483 .44571 L .4019 .44258 L p F P
0 g
s
.651 .757 .927 r
.55751 .44259 m .54744 .44598 L .55011 .4491 L p F P
0 g
s
.651 .757 .927 r
.55011 .4491 m .56016 .44572 L .55751 .44259 L p F P
0 g
s
.651 .757 .927 r
.72588 .44228 m .71549 .44568 L .71787 .44879 L p F P
0 g
s
.651 .757 .927 r
.71787 .44879 m .72824 .44541 L .72588 .44228 L p F P
0 g
s
.651 .757 .927 r
.41463 .44232 m .40483 .44571 L .40775 .44883 L p F P
0 g
s
.651 .757 .927 r
.40775 .44883 m .41753 .44545 L .41463 .44232 L p F P
0 g
s
.651 .757 .927 r
.57026 .44233 m .56016 .44572 L .56281 .44884 L p F P
0 g
s
.651 .757 .927 r
.56281 .44884 m .57289 .44546 L .57026 .44233 L p F P
0 g
s
.65 .757 .927 r
.27172 .44197 m .26219 .44535 L .26535 .44848 L p F P
0 g
s
.65 .757 .927 r
.26535 .44848 m .27487 .4451 L .27172 .44197 L p F P
0 g
s
.651 .757 .927 r
.73865 .44201 m .72824 .44541 L .7306 .44853 L p F P
0 g
s
.651 .757 .927 r
.7306 .44853 m .74099 .44514 L .73865 .44201 L p F P
0 g
s
.651 .757 .927 r
.42736 .44206 m .41753 .44545 L .42043 .44857 L p F P
0 g
s
.651 .757 .927 r
.42043 .44857 m .43024 .44519 L .42736 .44206 L p F P
0 g
s
.651 .757 .927 r
.58301 .44207 m .57289 .44546 L .57551 .44858 L p F P
0 g
s
.651 .757 .927 r
.57551 .44858 m .58562 .4452 L .58301 .44207 L p F P
0 g
s
.65 .757 .927 r
.28442 .44172 m .27487 .4451 L .27801 .44823 L p F P
0 g
s
.65 .757 .927 r
.27801 .44823 m .28756 .44486 L .28442 .44172 L p F P
0 g
s
.651 .757 .927 r
.75143 .44173 m .74099 .44514 L .74332 .44826 L p F P
0 g
s
.651 .757 .927 r
.74332 .44826 m .75375 .44487 L .75143 .44173 L p F P
0 g
s
.651 .757 .927 r
.44009 .4418 m .43024 .44519 L .43311 .44831 L p F P
0 g
s
.651 .757 .927 r
.43311 .44831 m .44295 .44493 L .44009 .4418 L p F P
0 g
s
.651 .757 .927 r
.59576 .4418 m .58562 .4452 L .58822 .44832 L p F P
0 g
s
.651 .757 .927 r
.58822 .44832 m .59835 .44494 L .59576 .4418 L p F P
0 g
s
.65 .757 .927 r
.29714 .44147 m .28756 .44486 L .29068 .44798 L p F P
0 g
s
.65 .757 .927 r
.29068 .44798 m .30025 .44461 L .29714 .44147 L p F P
0 g
s
.651 .758 .927 r
.76421 .44146 m .75375 .44487 L .75606 .44799 L p F P
0 g
s
.651 .758 .927 r
.75606 .44799 m .7665 .44459 L .76421 .44146 L p F P
0 g
s
.651 .757 .927 r
.45282 .44154 m .44295 .44493 L .4458 .44806 L p F P
0 g
s
.651 .757 .927 r
.4458 .44806 m .45566 .44468 L .45282 .44154 L p F P
0 g
s
.651 .757 .927 r
.60852 .44154 m .59835 .44494 L .60093 .44806 L p F P
0 g
s
.651 .757 .927 r
.60093 .44806 m .61109 .44467 L .60852 .44154 L p F P
0 g
s
.651 .758 .927 r
.77699 .44119 m .7665 .44459 L .76879 .44772 L p F P
0 g
s
.651 .758 .927 r
.76879 .44772 m .77927 .44432 L .77699 .44119 L p F P
0 g
s
.65 .757 .927 r
.30985 .44122 m .30025 .44461 L .30334 .44773 L p F P
0 g
s
.65 .757 .927 r
.30334 .44773 m .31294 .44436 L .30985 .44122 L p F P
0 g
s
.651 .757 .927 r
.62128 .44128 m .61109 .44467 L .61365 .4478 L p F P
0 g
s
.651 .757 .927 r
.61365 .4478 m .62383 .44441 L .62128 .44128 L p F P
0 g
s
.651 .757 .927 r
.46556 .44128 m .45566 .44468 L .45849 .4478 L p F P
0 g
s
.651 .757 .927 r
.45849 .4478 m .46838 .44442 L .46556 .44128 L p F P
0 g
s
.651 .758 .927 r
.78978 .44091 m .77927 .44432 L .78153 .44744 L p F P
0 g
s
.651 .758 .927 r
.78153 .44744 m .79203 .44404 L .78978 .44091 L p F P
0 g
s
.65 .757 .927 r
.32257 .44097 m .31294 .44436 L .31602 .44748 L p F P
0 g
s
.65 .757 .927 r
.31602 .44748 m .32564 .4441 L .32257 .44097 L p F P
0 g
s
.651 .757 .927 r
.63405 .44101 m .62383 .44441 L .62636 .44753 L p F P
0 g
s
.651 .757 .927 r
.62636 .44753 m .63657 .44415 L .63405 .44101 L p F P
0 g
s
.651 .757 .927 r
.47831 .44102 m .46838 .44442 L .47119 .44754 L p F P
0 g
s
.651 .757 .927 r
.47119 .44754 m .4811 .44416 L .47831 .44102 L p F P
0 g
s
.65 .757 .927 r
.3353 .44071 m .32564 .4441 L .32869 .44723 L p F P
0 g
s
.65 .757 .927 r
.32869 .44723 m .33834 .44385 L .3353 .44071 L p F P
0 g
s
.651 .757 .927 r
.64682 .44074 m .63657 .44415 L .63909 .44727 L p F P
0 g
s
.651 .757 .927 r
.63909 .44727 m .64932 .44388 L .64682 .44074 L p F P
0 g
s
.651 .757 .927 r
.49105 .44076 m .4811 .44416 L .48389 .44728 L p F P
0 g
s
.651 .757 .927 r
.48389 .44728 m .49383 .4439 L .49105 .44076 L p F P
0 g
s
.65 .757 .927 r
.34802 .44046 m .33834 .44385 L .34137 .44698 L p F P
0 g
s
.65 .757 .927 r
.34137 .44698 m .35105 .4436 L .34802 .44046 L p F P
0 g
s
.651 .757 .927 r
.65959 .44048 m .64932 .44388 L .65181 .44701 L p F P
0 g
s
.651 .757 .927 r
.65181 .44701 m .66207 .44362 L .65959 .44048 L p F P
0 g
s
.651 .757 .927 r
.5038 .4405 m .49383 .4439 L .49659 .44702 L p F P
0 g
s
.651 .757 .927 r
.49659 .44702 m .50656 .44364 L .5038 .4405 L p F P
0 g
s
.65 .757 .927 r
.36075 .4402 m .35105 .4436 L .35406 .44673 L p F P
0 g
s
.65 .757 .927 r
.35406 .44673 m .36375 .44334 L .36075 .4402 L p F P
0 g
s
.651 .757 .927 r
.67236 .44021 m .66207 .44362 L .66454 .44674 L p F P
0 g
s
.651 .757 .927 r
.66454 .44674 m .67482 .44335 L .67236 .44021 L p F P
0 g
s
.651 .757 .927 r
.51656 .44024 m .50656 .44364 L .5093 .44676 L p F P
0 g
s
.651 .757 .927 r
.5093 .44676 m .51929 .44338 L .51656 .44024 L p F P
0 g
s
.651 .757 .927 r
.37349 .43995 m .36375 .44334 L .36674 .44647 L p F P
0 g
s
.651 .757 .927 r
.36674 .44647 m .37647 .44309 L .37349 .43995 L p F P
0 g
s
.651 .757 .927 r
.68514 .43994 m .67482 .44335 L .67727 .44648 L p F P
0 g
s
.651 .757 .927 r
.67727 .44648 m .68758 .44308 L .68514 .43994 L p F P
0 g
s
.651 .757 .927 r
.52932 .43998 m .51929 .44338 L .52201 .4465 L p F P
0 g
s
.651 .757 .927 r
.52201 .4465 m .53202 .44312 L .52932 .43998 L p F P
0 g
s
.651 .757 .927 r
.69793 .43967 m .68758 .44308 L .69001 .44621 L p F P
0 g
s
.651 .757 .927 r
.69001 .44621 m .70034 .44281 L .69793 .43967 L p F P
0 g
s
.651 .757 .927 r
.38623 .43969 m .37647 .44309 L .37944 .44622 L p F P
0 g
s
.651 .757 .927 r
.37944 .44622 m .38918 .44283 L .38623 .43969 L p F P
0 g
s
.651 .757 .927 r
.54208 .43972 m .53202 .44312 L .53472 .44624 L p F P
0 g
s
.651 .757 .927 r
.53472 .44624 m .54476 .44286 L .54208 .43972 L p F P
0 g
s
.651 .757 .927 r
.71072 .4394 m .70034 .44281 L .70275 .44594 L p F P
0 g
s
.651 .757 .927 r
.70275 .44594 m .71311 .44255 L .71072 .4394 L p F P
0 g
s
.651 .757 .927 r
.39897 .43943 m .38918 .44283 L .39213 .44596 L p F P
0 g
s
.651 .757 .927 r
.39213 .44596 m .4019 .44258 L .39897 .43943 L p F P
0 g
s
.651 .757 .927 r
.55484 .43945 m .54476 .44286 L .54744 .44598 L p F P
0 g
s
.651 .757 .927 r
.54744 .44598 m .55751 .44259 L .55484 .43945 L p F P
0 g
s
.651 .757 .927 r
.72351 .43913 m .71311 .44255 L .71549 .44568 L p F P
0 g
s
.651 .757 .927 r
.71549 .44568 m .72588 .44228 L .72351 .43913 L p F P
0 g
s
.651 .757 .927 r
.41172 .43917 m .4019 .44258 L .40483 .44571 L p F P
0 g
s
.651 .757 .927 r
.40483 .44571 m .41463 .44232 L .41172 .43917 L p F P
0 g
s
.651 .757 .927 r
.56761 .43919 m .55751 .44259 L .56016 .44572 L p F P
0 g
s
.651 .757 .927 r
.56016 .44572 m .57026 .44233 L .56761 .43919 L p F P
0 g
s
.651 .757 .927 r
.7363 .43886 m .72588 .44228 L .72824 .44541 L p F P
0 g
s
.651 .757 .927 r
.72824 .44541 m .73865 .44201 L .7363 .43886 L p F P
0 g
s
.651 .757 .927 r
.42447 .43892 m .41463 .44232 L .41753 .44545 L p F P
0 g
s
.651 .757 .927 r
.41753 .44545 m .42736 .44206 L .42447 .43892 L p F P
0 g
s
.651 .757 .927 r
.58039 .43893 m .57026 .44233 L .57289 .44546 L p F P
0 g
s
.651 .757 .927 r
.57289 .44546 m .58301 .44207 L .58039 .43893 L p F P
0 g
s
.65 .757 .927 r
.28128 .43857 m .27172 .44197 L .27487 .4451 L p F P
0 g
s
.65 .757 .927 r
.27487 .4451 m .28442 .44172 L .28128 .43857 L p F P
0 g
s
.651 .757 .927 r
.7491 .43859 m .73865 .44201 L .74099 .44514 L p F P
0 g
s
.651 .757 .927 r
.74099 .44514 m .75143 .44173 L .7491 .43859 L p F P
0 g
s
.651 .757 .927 r
.43722 .43866 m .42736 .44206 L .43024 .44519 L p F P
0 g
s
.651 .757 .927 r
.43024 .44519 m .44009 .4418 L .43722 .43866 L p F P
0 g
s
.651 .757 .927 r
.59316 .43866 m .58301 .44207 L .58562 .4452 L p F P
0 g
s
.651 .757 .927 r
.58562 .4452 m .59576 .4418 L .59316 .43866 L p F P
0 g
s
.65 .757 .927 r
.29402 .43832 m .28442 .44172 L .28756 .44486 L p F P
0 g
s
.65 .757 .927 r
.28756 .44486 m .29714 .44147 L .29402 .43832 L p F P
0 g
s
.651 .757 .927 r
.7619 .43832 m .75143 .44173 L .75375 .44487 L p F P
0 g
s
.651 .757 .927 r
.75375 .44487 m .76421 .44146 L .7619 .43832 L p F P
0 g
s
.651 .757 .927 r
.44998 .4384 m .44009 .4418 L .44295 .44493 L p F P
0 g
s
.651 .757 .927 r
.44295 .44493 m .45282 .44154 L .44998 .4384 L p F P
0 g
s
.651 .757 .927 r
.60594 .4384 m .59576 .4418 L .59835 .44494 L p F P
0 g
s
.651 .757 .927 r
.59835 .44494 m .60852 .44154 L .60594 .4384 L p F P
0 g
s
.651 .758 .927 r
.77471 .43804 m .76421 .44146 L .7665 .44459 L p F P
0 g
s
.651 .758 .927 r
.7665 .44459 m .77699 .44119 L .77471 .43804 L p F P
0 g
s
.65 .757 .927 r
.30675 .43807 m .29714 .44147 L .30025 .44461 L p F P
0 g
s
.65 .757 .927 r
.30025 .44461 m .30985 .44122 L .30675 .43807 L p F P
0 g
s
.651 .757 .927 r
.61873 .43813 m .60852 .44154 L .61109 .44467 L p F P
0 g
s
.651 .757 .927 r
.61109 .44467 m .62128 .44128 L .61873 .43813 L p F P
0 g
s
.651 .757 .927 r
.46274 .43814 m .45282 .44154 L .45566 .44468 L p F P
0 g
s
.651 .757 .927 r
.45566 .44468 m .46556 .44128 L .46274 .43814 L p F P
0 g
s
.651 .758 .927 r
.78751 .43776 m .77699 .44119 L .77927 .44432 L p F P
0 g
s
.651 .758 .927 r
.77927 .44432 m .78978 .44091 L .78751 .43776 L p F P
0 g
s
.65 .757 .927 r
.31949 .43782 m .30985 .44122 L .31294 .44436 L p F P
0 g
s
.65 .757 .927 r
.31294 .44436 m .32257 .44097 L .31949 .43782 L p F P
0 g
s
.651 .757 .927 r
.63151 .43786 m .62128 .44128 L .62383 .44441 L p F P
0 g
s
.651 .757 .927 r
.62383 .44441 m .63405 .44101 L .63151 .43786 L p F P
0 g
s
.651 .757 .927 r
.4755 .43788 m .46556 .44128 L .46838 .44442 L p F P
0 g
s
.651 .757 .927 r
.46838 .44442 m .47831 .44102 L .4755 .43788 L p F P
0 g
s
.65 .757 .927 r
.33224 .43756 m .32257 .44097 L .32564 .4441 L p F P
0 g
s
.65 .757 .927 r
.32564 .4441 m .3353 .44071 L .33224 .43756 L p F P
0 g
s
.651 .757 .927 r
.6443 .4376 m .63405 .44101 L .63657 .44415 L p F P
0 g
s
.651 .757 .927 r
.63657 .44415 m .64682 .44074 L .6443 .4376 L p F P
0 g
s
.651 .757 .927 r
.48827 .43761 m .47831 .44102 L .4811 .44416 L p F P
0 g
s
.651 .757 .927 r
.4811 .44416 m .49105 .44076 L .48827 .43761 L p F P
0 g
s
.65 .757 .927 r
.34499 .43731 m .3353 .44071 L .33834 .44385 L p F P
0 g
s
.65 .757 .927 r
.33834 .44385 m .34802 .44046 L .34499 .43731 L p F P
0 g
s
.651 .757 .927 r
.6571 .43733 m .64682 .44074 L .64932 .44388 L p F P
0 g
s
.651 .757 .927 r
.64932 .44388 m .65959 .44048 L .6571 .43733 L p F P
0 g
s
.651 .757 .927 r
.50104 .43735 m .49105 .44076 L .49383 .4439 L p F P
0 g
s
.651 .757 .927 r
.49383 .4439 m .5038 .4405 L .50104 .43735 L p F P
0 g
s
.65 .757 .927 r
.35774 .43705 m .34802 .44046 L .35105 .4436 L p F P
0 g
s
.65 .757 .927 r
.35105 .4436 m .36075 .4402 L .35774 .43705 L p F P
0 g
s
.651 .757 .927 r
.6699 .43706 m .65959 .44048 L .66207 .44362 L p F P
0 g
s
.651 .757 .927 r
.66207 .44362 m .67236 .44021 L .6699 .43706 L p F P
0 g
s
.651 .757 .927 r
.51382 .43709 m .5038 .4405 L .50656 .44364 L p F P
0 g
s
.651 .757 .927 r
.50656 .44364 m .51656 .44024 L .51382 .43709 L p F P
0 g
s
.651 .757 .927 r
.3705 .43679 m .36075 .4402 L .36375 .44334 L p F P
0 g
s
.651 .757 .927 r
.36375 .44334 m .37349 .43995 L .3705 .43679 L p F P
0 g
s
.651 .757 .927 r
.6827 .43679 m .67236 .44021 L .67482 .44335 L p F P
0 g
s
.651 .757 .927 r
.67482 .44335 m .68514 .43994 L .6827 .43679 L p F P
0 g
s
.651 .757 .927 r
.5266 .43683 m .51656 .44024 L .51929 .44338 L p F P
0 g
s
.651 .757 .927 r
.51929 .44338 m .52932 .43998 L .5266 .43683 L p F P
0 g
s
.651 .757 .927 r
.69551 .43652 m .68514 .43994 L .68758 .44308 L p F P
0 g
s
.651 .757 .927 r
.68758 .44308 m .69793 .43967 L .69551 .43652 L p F P
0 g
s
.651 .757 .927 r
.38326 .43654 m .37349 .43995 L .37647 .44309 L p F P
0 g
s
.651 .757 .927 r
.37647 .44309 m .38623 .43969 L .38326 .43654 L p F P
0 g
s
.651 .757 .927 r
.53938 .43656 m .52932 .43998 L .53202 .44312 L p F P
0 g
s
.651 .757 .927 r
.53202 .44312 m .54208 .43972 L .53938 .43656 L p F P
0 g
s
.651 .757 .927 r
.70831 .43625 m .69793 .43967 L .70034 .44281 L p F P
0 g
s
.651 .757 .927 r
.70034 .44281 m .71072 .4394 L .70831 .43625 L p F P
0 g
s
.651 .757 .927 r
.39602 .43628 m .38623 .43969 L .38918 .44283 L p F P
0 g
s
.651 .757 .927 r
.38918 .44283 m .39897 .43943 L .39602 .43628 L p F P
0 g
s
.651 .757 .927 r
.55217 .4363 m .54208 .43972 L .54476 .44286 L p F P
0 g
s
.651 .757 .927 r
.54476 .44286 m .55484 .43945 L .55217 .4363 L p F P
0 g
s
.651 .757 .927 r
.72113 .43598 m .71072 .4394 L .71311 .44255 L p F P
0 g
s
.651 .757 .927 r
.71311 .44255 m .72351 .43913 L .72113 .43598 L p F P
0 g
s
.651 .757 .927 r
.40879 .43602 m .39897 .43943 L .4019 .44258 L p F P
0 g
s
.651 .757 .927 r
.4019 .44258 m .41172 .43917 L .40879 .43602 L p F P
0 g
s
.651 .757 .927 r
.56496 .43604 m .55484 .43945 L .55751 .44259 L p F P
0 g
s
.651 .757 .927 r
.55751 .44259 m .56761 .43919 L .56496 .43604 L p F P
0 g
s
.651 .757 .927 r
.73394 .43571 m .72351 .43913 L .72588 .44228 L p F P
0 g
s
.651 .757 .927 r
.72588 .44228 m .7363 .43886 L .73394 .43571 L p F P
0 g
s
.651 .757 .927 r
.42156 .43576 m .41172 .43917 L .41463 .44232 L p F P
0 g
s
.651 .757 .927 r
.41463 .44232 m .42447 .43892 L .42156 .43576 L p F P
0 g
s
.651 .757 .927 r
.57776 .43577 m .56761 .43919 L .57026 .44233 L p F P
0 g
s
.651 .757 .927 r
.57026 .44233 m .58039 .43893 L .57776 .43577 L p F P
0 g
s
.651 .757 .927 r
.74676 .43544 m .7363 .43886 L .73865 .44201 L p F P
0 g
s
.651 .757 .927 r
.73865 .44201 m .7491 .43859 L .74676 .43544 L p F P
0 g
s
.651 .757 .927 r
.43434 .4355 m .42447 .43892 L .42736 .44206 L p F P
0 g
s
.651 .757 .927 r
.42736 .44206 m .43722 .43866 L .43434 .4355 L p F P
0 g
s
.651 .757 .927 r
.59055 .43551 m .58039 .43893 L .58301 .44207 L p F P
0 g
s
.651 .757 .927 r
.58301 .44207 m .59316 .43866 L .59055 .43551 L p F P
0 g
s
.65 .757 .927 r
.29089 .43516 m .28128 .43857 L .28442 .44172 L p F P
0 g
s
.65 .757 .927 r
.28442 .44172 m .29402 .43832 L .29089 .43516 L p F P
0 g
s
.651 .757 .927 r
.75959 .43516 m .7491 .43859 L .75143 .44173 L p F P
0 g
s
.651 .757 .927 r
.75143 .44173 m .7619 .43832 L .75959 .43516 L p F P
0 g
s
.651 .757 .927 r
.44712 .43524 m .43722 .43866 L .44009 .4418 L p F P
0 g
s
.651 .757 .927 r
.44009 .4418 m .44998 .4384 L .44712 .43524 L p F P
0 g
s
.651 .757 .927 r
.60336 .43524 m .59316 .43866 L .59576 .4418 L p F P
0 g
s
.651 .757 .927 r
.59576 .4418 m .60594 .4384 L .60336 .43524 L p F P
0 g
s
.651 .758 .927 r
.77241 .43488 m .7619 .43832 L .76421 .44146 L p F P
0 g
s
.651 .758 .927 r
.76421 .44146 m .77471 .43804 L .77241 .43488 L p F P
0 g
s
.65 .757 .927 r
.30364 .43491 m .29402 .43832 L .29714 .44147 L p F P
0 g
s
.65 .757 .927 r
.29714 .44147 m .30675 .43807 L .30364 .43491 L p F P
0 g
s
.651 .757 .927 r
.61616 .43497 m .60594 .4384 L .60852 .44154 L p F P
0 g
s
.651 .757 .927 r
.60852 .44154 m .61873 .43813 L .61616 .43497 L p F P
0 g
s
.651 .757 .927 r
.4599 .43498 m .44998 .4384 L .45282 .44154 L p F P
0 g
s
.651 .757 .927 r
.45282 .44154 m .46274 .43814 L .4599 .43498 L p F P
0 g
s
.651 .758 .927 r
.78525 .43461 m .77471 .43804 L .77699 .44119 L p F P
0 g
s
.651 .758 .927 r
.77699 .44119 m .78751 .43776 L .78525 .43461 L p F P
0 g
s
.65 .757 .927 r
.31641 .43465 m .30675 .43807 L .30985 .44122 L p F P
0 g
s
.65 .757 .927 r
.30985 .44122 m .31949 .43782 L .31641 .43465 L p F P
0 g
s
.651 .757 .927 r
.62897 .43471 m .61873 .43813 L .62128 .44128 L p F P
0 g
s
.651 .757 .927 r
.62128 .44128 m .63151 .43786 L .62897 .43471 L p F P
0 g
s
.651 .757 .927 r
.47269 .43472 m .46274 .43814 L .46556 .44128 L p F P
0 g
s
.651 .757 .927 r
.46556 .44128 m .4755 .43788 L .47269 .43472 L p F P
0 g
s
.65 .757 .927 r
.32917 .4344 m .31949 .43782 L .32257 .44097 L p F P
0 g
s
.65 .757 .927 r
.32257 .44097 m .33224 .43756 L .32917 .4344 L p F P
0 g
s
.651 .757 .927 r
.64178 .43444 m .63151 .43786 L .63405 .44101 L p F P
0 g
s
.651 .757 .927 r
.63405 .44101 m .6443 .4376 L .64178 .43444 L p F P
0 g
s
.651 .757 .927 r
.48548 .43446 m .4755 .43788 L .47831 .44102 L p F P
0 g
s
.651 .757 .927 r
.47831 .44102 m .48827 .43761 L .48548 .43446 L p F P
0 g
s
.65 .757 .927 r
.34195 .43414 m .33224 .43756 L .3353 .44071 L p F P
0 g
s
.65 .757 .927 r
.3353 .44071 m .34499 .43731 L .34195 .43414 L p F P
0 g
s
.651 .757 .927 r
.6546 .43417 m .6443 .4376 L .64682 .44074 L p F P
0 g
s
.651 .757 .927 r
.64682 .44074 m .6571 .43733 L .6546 .43417 L p F P
0 g
s
.651 .757 .927 r
.49827 .43419 m .48827 .43761 L .49105 .44076 L p F P
0 g
s
.651 .757 .927 r
.49105 .44076 m .50104 .43735 L .49827 .43419 L p F P
0 g
s
.65 .757 .927 r
.35472 .43389 m .34499 .43731 L .34802 .44046 L p F P
0 g
s
.65 .757 .927 r
.34802 .44046 m .35774 .43705 L .35472 .43389 L p F P
0 g
s
.651 .757 .927 r
.66742 .4339 m .6571 .43733 L .65959 .44048 L p F P
0 g
s
.651 .757 .927 r
.65959 .44048 m .6699 .43706 L .66742 .4339 L p F P
0 g
s
.651 .757 .927 r
.51107 .43393 m .50104 .43735 L .5038 .4405 L p F P
0 g
s
.651 .757 .927 r
.5038 .4405 m .51382 .43709 L .51107 .43393 L p F P
0 g
s
.651 .757 .927 r
.3675 .43363 m .35774 .43705 L .36075 .4402 L p F P
0 g
s
.651 .757 .927 r
.36075 .4402 m .3705 .43679 L .3675 .43363 L p F P
0 g
s
.651 .757 .927 r
.68025 .43363 m .6699 .43706 L .67236 .44021 L p F P
0 g
s
.651 .757 .927 r
.67236 .44021 m .6827 .43679 L .68025 .43363 L p F P
0 g
s
.651 .757 .927 r
.52387 .43367 m .51382 .43709 L .51656 .44024 L p F P
0 g
s
.651 .757 .927 r
.51656 .44024 m .5266 .43683 L .52387 .43367 L p F P
0 g
s
.651 .757 .927 r
.69307 .43336 m .6827 .43679 L .68514 .43994 L p F P
0 g
s
.651 .757 .927 r
.68514 .43994 m .69551 .43652 L .69307 .43336 L p F P
0 g
s
.651 .757 .927 r
.38028 .43337 m .3705 .43679 L .37349 .43995 L p F P
0 g
s
.651 .757 .927 r
.37349 .43995 m .38326 .43654 L .38028 .43337 L p F P
0 g
s
.651 .757 .927 r
.53668 .4334 m .5266 .43683 L .52932 .43998 L p F P
0 g
s
.651 .757 .927 r
.52932 .43998 m .53938 .43656 L .53668 .4334 L p F P
0 g
s
.651 .757 .927 r
.7059 .43309 m .69551 .43652 L .69793 .43967 L p F P
0 g
s
.651 .757 .927 r
.69793 .43967 m .70831 .43625 L .7059 .43309 L p F P
0 g
s
.651 .757 .927 r
.39307 .43311 m .38326 .43654 L .38623 .43969 L p F P
0 g
s
.651 .757 .927 r
.38623 .43969 m .39602 .43628 L .39307 .43311 L p F P
0 g
s
.651 .757 .927 r
.54949 .43314 m .53938 .43656 L .54208 .43972 L p F P
0 g
s
.651 .757 .927 r
.54208 .43972 m .55217 .4363 L .54949 .43314 L p F P
0 g
s
.651 .757 .927 r
.71874 .43282 m .70831 .43625 L .71072 .4394 L p F P
0 g
s
.651 .757 .927 r
.71072 .4394 m .72113 .43598 L .71874 .43282 L p F P
0 g
s
.651 .757 .927 r
.40586 .43285 m .39602 .43628 L .39897 .43943 L p F P
0 g
s
.651 .757 .927 r
.39897 .43943 m .40879 .43602 L .40586 .43285 L p F P
0 g
s
.651 .757 .927 r
.5623 .43287 m .55217 .4363 L .55484 .43945 L p F P
0 g
s
.651 .757 .927 r
.55484 .43945 m .56496 .43604 L .5623 .43287 L p F P
0 g
s
.651 .757 .927 r
.73158 .43254 m .72113 .43598 L .72351 .43913 L p F P
0 g
s
.651 .757 .927 r
.72351 .43913 m .73394 .43571 L .73158 .43254 L p F P
0 g
s
.651 .757 .927 r
.41865 .43259 m .40879 .43602 L .41172 .43917 L p F P
0 g
s
.651 .757 .927 r
.41172 .43917 m .42156 .43576 L .41865 .43259 L p F P
0 g
s
.651 .757 .927 r
.57512 .43261 m .56496 .43604 L .56761 .43919 L p F P
0 g
s
.651 .757 .927 r
.56761 .43919 m .57776 .43577 L .57512 .43261 L p F P
0 g
s
.651 .757 .927 r
.74442 .43227 m .73394 .43571 L .7363 .43886 L p F P
0 g
s
.651 .757 .927 r
.7363 .43886 m .74676 .43544 L .74442 .43227 L p F P
0 g
s
.651 .757 .927 r
.43145 .43233 m .42156 .43576 L .42447 .43892 L p F P
0 g
s
.651 .757 .927 r
.42447 .43892 m .43434 .4355 L .43145 .43233 L p F P
0 g
s
.651 .757 .927 r
.58794 .43234 m .57776 .43577 L .58039 .43893 L p F P
0 g
s
.651 .757 .927 r
.58039 .43893 m .59055 .43551 L .58794 .43234 L p F P
0 g
s
.651 .757 .927 r
.75727 .43199 m .74676 .43544 L .7491 .43859 L p F P
0 g
s
.651 .757 .927 r
.7491 .43859 m .75959 .43516 L .75727 .43199 L p F P
0 g
s
.651 .757 .927 r
.44425 .43207 m .43434 .4355 L .43722 .43866 L p F P
0 g
s
.651 .757 .927 r
.43722 .43866 m .44712 .43524 L .44425 .43207 L p F P
0 g
s
.651 .757 .927 r
.60076 .43207 m .59055 .43551 L .59316 .43866 L p F P
0 g
s
.651 .757 .927 r
.59316 .43866 m .60336 .43524 L .60076 .43207 L p F P
0 g
s
.651 .757 .927 r
.77012 .43172 m .75959 .43516 L .7619 .43832 L p F P
0 g
s
.651 .757 .927 r
.7619 .43832 m .77241 .43488 L .77012 .43172 L p F P
0 g
s
.65 .757 .927 r
.30052 .43173 m .29089 .43516 L .29402 .43832 L p F P
0 g
s
.65 .757 .927 r
.29402 .43832 m .30364 .43491 L .30052 .43173 L p F P
0 g
s
.651 .757 .927 r
.61359 .43181 m .60336 .43524 L .60594 .4384 L p F P
0 g
s
.651 .757 .927 r
.60594 .4384 m .61616 .43497 L .61359 .43181 L p F P
0 g
s
.651 .757 .927 r
.45705 .43181 m .44712 .43524 L .44998 .4384 L p F P
0 g
s
.651 .757 .927 r
.44998 .4384 m .4599 .43498 L .45705 .43181 L p F P
0 g
s
.651 .758 .927 r
.78297 .43144 m .77241 .43488 L .77471 .43804 L p F P
0 g
s
.651 .758 .927 r
.77471 .43804 m .78525 .43461 L .78297 .43144 L p F P
0 g
s
.65 .757 .927 r
.31331 .43148 m .30364 .43491 L .30675 .43807 L p F P
0 g
s
.65 .757 .927 r
.30675 .43807 m .31641 .43465 L .31331 .43148 L p F P
0 g
s
.651 .757 .927 r
.62642 .43154 m .61616 .43497 L .61873 .43813 L p F P
0 g
s
.651 .757 .927 r
.61873 .43813 m .62897 .43471 L .62642 .43154 L p F P
0 g
s
.651 .757 .927 r
.46986 .43155 m .4599 .43498 L .46274 .43814 L p F P
0 g
s
.651 .757 .927 r
.46274 .43814 m .47269 .43472 L .46986 .43155 L p F P
0 g
s
.65 .757 .927 r
.3261 .43123 m .31641 .43465 L .31949 .43782 L p F P
0 g
s
.65 .757 .927 r
.31949 .43782 m .32917 .4344 L .3261 .43123 L p F P
0 g
s
.651 .757 .927 r
.63925 .43127 m .62897 .43471 L .63151 .43786 L p F P
0 g
s
.651 .757 .927 r
.63151 .43786 m .64178 .43444 L .63925 .43127 L p F P
0 g
s
.651 .757 .927 r
.48267 .43128 m .47269 .43472 L .4755 .43788 L p F P
0 g
s
.651 .757 .927 r
.4755 .43788 m .48548 .43446 L .48267 .43128 L p F P
0 g
s
.65 .757 .927 r
.33889 .43097 m .32917 .4344 L .33224 .43756 L p F P
0 g
s
.65 .757 .927 r
.33224 .43756 m .34195 .43414 L .33889 .43097 L p F P
0 g
s
.651 .757 .927 r
.65209 .431 m .64178 .43444 L .6443 .4376 L p F P
0 g
s
.651 .757 .927 r
.6443 .4376 m .6546 .43417 L .65209 .431 L p F P
0 g
s
.651 .757 .927 r
.49549 .43102 m .48548 .43446 L .48827 .43761 L p F P
0 g
s
.651 .757 .927 r
.48827 .43761 m .49827 .43419 L .49549 .43102 L p F P
0 g
s
.65 .757 .927 r
.35169 .43071 m .34195 .43414 L .34499 .43731 L p F P
0 g
s
.65 .757 .927 r
.34499 .43731 m .35472 .43389 L .35169 .43071 L p F P
0 g
s
.651 .757 .927 r
.66494 .43073 m .6546 .43417 L .6571 .43733 L p F P
0 g
s
.651 .757 .927 r
.6571 .43733 m .66742 .4339 L .66494 .43073 L p F P
0 g
s
.651 .757 .927 r
.50831 .43076 m .49827 .43419 L .50104 .43735 L p F P
0 g
s
.651 .757 .927 r
.50104 .43735 m .51107 .43393 L .50831 .43076 L p F P
0 g
s
.651 .757 .927 r
.36449 .43046 m .35472 .43389 L .35774 .43705 L p F P
0 g
s
.651 .757 .927 r
.35774 .43705 m .3675 .43363 L .36449 .43046 L p F P
0 g
s
.651 .757 .927 r
.67778 .43046 m .66742 .4339 L .6699 .43706 L p F P
0 g
s
.651 .757 .927 r
.6699 .43706 m .68025 .43363 L .67778 .43046 L p F P
0 g
s
.651 .757 .927 r
.52113 .43049 m .51107 .43393 L .51382 .43709 L p F P
0 g
s
.651 .757 .927 r
.51382 .43709 m .52387 .43367 L .52113 .43049 L p F P
0 g
s
.651 .757 .927 r
.69063 .43019 m .68025 .43363 L .6827 .43679 L p F P
0 g
s
.651 .757 .927 r
.6827 .43679 m .69307 .43336 L .69063 .43019 L p F P
0 g
s
.651 .757 .927 r
.37729 .4302 m .3675 .43363 L .3705 .43679 L p F P
0 g
s
.651 .757 .927 r
.3705 .43679 m .38028 .43337 L .37729 .4302 L p F P
0 g
s
.651 .757 .927 r
.53396 .43023 m .52387 .43367 L .5266 .43683 L p F P
0 g
s
.651 .757 .927 r
.5266 .43683 m .53668 .4334 L .53396 .43023 L p F P
0 g
s
.651 .757 .927 r
.70349 .42992 m .69307 .43336 L .69551 .43652 L p F P
0 g
s
.651 .757 .927 r
.69551 .43652 m .7059 .43309 L .70349 .42992 L p F P
0 g
s
.651 .757 .927 r
.3901 .42994 m .38028 .43337 L .38326 .43654 L p F P
0 g
s
.651 .757 .927 r
.38326 .43654 m .39307 .43311 L .3901 .42994 L p F P
0 g
s
.651 .757 .927 r
.54679 .42996 m .53668 .4334 L .53938 .43656 L p F P
0 g
s
.651 .757 .927 r
.53938 .43656 m .54949 .43314 L .54679 .42996 L p F P
0 g
s
.651 .757 .927 r
.71634 .42964 m .7059 .43309 L .70831 .43625 L p F P
0 g
s
.651 .757 .927 r
.70831 .43625 m .71874 .43282 L .71634 .42964 L p F P
0 g
s
.651 .757 .927 r
.40291 .42968 m .39307 .43311 L .39602 .43628 L p F P
0 g
s
.651 .757 .927 r
.39602 .43628 m .40586 .43285 L .40291 .42968 L p F P
0 g
s
.651 .757 .927 r
.55963 .4297 m .54949 .43314 L .55217 .4363 L p F P
0 g
s
.651 .757 .927 r
.55217 .4363 m .5623 .43287 L .55963 .4297 L p F P
0 g
s
.651 .757 .927 r
.7292 .42937 m .71874 .43282 L .72113 .43598 L p F P
0 g
s
.651 .757 .927 r
.72113 .43598 m .73158 .43254 L .7292 .42937 L p F P
0 g
s
.651 .757 .927 r
.41573 .42942 m .40586 .43285 L .40879 .43602 L p F P
0 g
s
.651 .757 .927 r
.40879 .43602 m .41865 .43259 L .41573 .42942 L p F P
0 g
s
.651 .757 .927 r
.57247 .42943 m .5623 .43287 L .56496 .43604 L p F P
0 g
s
.651 .757 .927 r
.56496 .43604 m .57512 .43261 L .57247 .42943 L p F P
0 g
s
.651 .757 .927 r
.74207 .42909 m .73158 .43254 L .73394 .43571 L p F P
0 g
s
.651 .757 .927 r
.73394 .43571 m .74442 .43227 L .74207 .42909 L p F P
0 g
s
.651 .757 .927 r
.42855 .42915 m .41865 .43259 L .42156 .43576 L p F P
0 g
s
.651 .757 .927 r
.42156 .43576 m .43145 .43233 L .42855 .42915 L p F P
0 g
s
.651 .757 .927 r
.58531 .42916 m .57512 .43261 L .57776 .43577 L p F P
0 g
s
.651 .757 .927 r
.57776 .43577 m .58794 .43234 L .58531 .42916 L p F P
0 g
s
.651 .757 .927 r
.75494 .42881 m .74442 .43227 L .74676 .43544 L p F P
0 g
s
.651 .757 .927 r
.74676 .43544 m .75727 .43199 L .75494 .42881 L p F P
0 g
s
.651 .757 .927 r
.44137 .42889 m .43145 .43233 L .43434 .4355 L p F P
0 g
s
.651 .757 .927 r
.43434 .4355 m .44425 .43207 L .44137 .42889 L p F P
0 g
s
.651 .757 .927 r
.59816 .4289 m .58794 .43234 L .59055 .43551 L p F P
0 g
s
.651 .757 .927 r
.59055 .43551 m .60076 .43207 L .59816 .4289 L p F P
0 g
s
.651 .757 .927 r
.76781 .42854 m .75727 .43199 L .75959 .43516 L p F P
0 g
s
.651 .757 .927 r
.75959 .43516 m .77012 .43172 L .76781 .42854 L p F P
0 g
s
.651 .757 .927 r
.4542 .42863 m .44425 .43207 L .44712 .43524 L p F P
0 g
s
.651 .757 .927 r
.44712 .43524 m .45705 .43181 L .4542 .42863 L p F P
0 g
s
.651 .757 .927 r
.61101 .42863 m .60076 .43207 L .60336 .43524 L p F P
0 g
s
.651 .757 .927 r
.60336 .43524 m .61359 .43181 L .61101 .42863 L p F P
0 g
s
.651 .758 .927 r
.78068 .42826 m .77012 .43172 L .77241 .43488 L p F P
0 g
s
.651 .758 .927 r
.77241 .43488 m .78297 .43144 L .78068 .42826 L p F P
0 g
s
.65 .757 .927 r
.3102 .4283 m .30052 .43173 L .30364 .43491 L p F P
0 g
s
.65 .757 .927 r
.30364 .43491 m .31331 .43148 L .3102 .4283 L p F P
0 g
s
.651 .757 .927 r
.62386 .42836 m .61359 .43181 L .61616 .43497 L p F P
0 g
s
.651 .757 .927 r
.61616 .43497 m .62642 .43154 L .62386 .42836 L p F P
0 g
s
.651 .757 .927 r
.46703 .42837 m .45705 .43181 L .4599 .43498 L p F P
0 g
s
.651 .757 .927 r
.4599 .43498 m .46986 .43155 L .46703 .42837 L p F P
0 g
s
.65 .757 .927 r
.32301 .42804 m .31331 .43148 L .31641 .43465 L p F P
0 g
s
.65 .757 .927 r
.31641 .43465 m .3261 .43123 L .32301 .42804 L p F P
0 g
s
.651 .757 .927 r
.63672 .42809 m .62642 .43154 L .62897 .43471 L p F P
0 g
s
.651 .757 .927 r
.62897 .43471 m .63925 .43127 L .63672 .42809 L p F P
0 g
s
.651 .757 .927 r
.47986 .4281 m .46986 .43155 L .47269 .43472 L p F P
0 g
s
.651 .757 .927 r
.47269 .43472 m .48267 .43128 L .47986 .4281 L p F P
0 g
s
.65 .757 .927 r
.33583 .42778 m .3261 .43123 L .32917 .4344 L p F P
0 g
s
.65 .757 .927 r
.32917 .4344 m .33889 .43097 L .33583 .42778 L p F P
0 g
s
.651 .757 .927 r
.64958 .42782 m .63925 .43127 L .64178 .43444 L p F P
0 g
s
.651 .757 .927 r
.64178 .43444 m .65209 .431 L .64958 .42782 L p F P
0 g
s
.651 .757 .927 r
.4927 .42784 m .48267 .43128 L .48548 .43446 L p F P
0 g
s
.651 .757 .927 r
.48548 .43446 m .49549 .43102 L .4927 .42784 L p F P
0 g
s
.65 .757 .927 r
.34864 .42753 m .33889 .43097 L .34195 .43414 L p F P
0 g
s
.65 .757 .927 r
.34195 .43414 m .35169 .43071 L .34864 .42753 L p F P
0 g
s
.651 .757 .927 r
.66244 .42755 m .65209 .431 L .6546 .43417 L p F P
0 g
s
.651 .757 .927 r
.6546 .43417 m .66494 .43073 L .66244 .42755 L p F P
0 g
s
.651 .757 .927 r
.50554 .42757 m .49549 .43102 L .49827 .43419 L p F P
0 g
s
.651 .757 .927 r
.49827 .43419 m .50831 .43076 L .50554 .42757 L p F P
0 g
s
.651 .757 .927 r
.36147 .42727 m .35169 .43071 L .35472 .43389 L p F P
0 g
s
.651 .757 .927 r
.35472 .43389 m .36449 .43046 L .36147 .42727 L p F P
0 g
s
.651 .757 .927 r
.67531 .42728 m .66494 .43073 L .66742 .4339 L p F P
0 g
s
.651 .757 .927 r
.66742 .4339 m .67778 .43046 L .67531 .42728 L p F P
0 g
s
.651 .757 .927 r
.51839 .42731 m .50831 .43076 L .51107 .43393 L p F P
0 g
s
.651 .757 .927 r
.51107 .43393 m .52113 .43049 L .51839 .42731 L p F P
0 g
s
.651 .757 .927 r
.37429 .42701 m .36449 .43046 L .3675 .43363 L p F P
0 g
s
.651 .757 .927 r
.3675 .43363 m .37729 .4302 L .37429 .42701 L p F P
0 g
s
.651 .757 .927 r
.68818 .427 m .67778 .43046 L .68025 .43363 L p F P
0 g
s
.651 .757 .927 r
.68025 .43363 m .69063 .43019 L .68818 .427 L p F P
0 g
s
.651 .757 .927 r
.53124 .42704 m .52113 .43049 L .52387 .43367 L p F P
0 g
s
.651 .757 .927 r
.52387 .43367 m .53396 .43023 L .53124 .42704 L p F P
0 g
s
.651 .757 .927 r
.70106 .42673 m .69063 .43019 L .69307 .43336 L p F P
0 g
s
.651 .757 .927 r
.69307 .43336 m .70349 .42992 L .70106 .42673 L p F P
0 g
s
.651 .757 .927 r
.38712 .42675 m .37729 .4302 L .38028 .43337 L p F P
0 g
s
.651 .757 .927 r
.38028 .43337 m .3901 .42994 L .38712 .42675 L p F P
0 g
s
.651 .757 .927 r
.54409 .42678 m .53396 .43023 L .53668 .4334 L p F P
0 g
s
.651 .757 .927 r
.53668 .4334 m .54679 .42996 L .54409 .42678 L p F P
0 g
s
.651 .757 .927 r
.71394 .42646 m .70349 .42992 L .7059 .43309 L p F P
0 g
s
.651 .757 .927 r
.7059 .43309 m .71634 .42964 L .71394 .42646 L p F P
0 g
s
.651 .757 .927 r
.39996 .42649 m .3901 .42994 L .39307 .43311 L p F P
0 g
s
.651 .757 .927 r
.39307 .43311 m .40291 .42968 L .39996 .42649 L p F P
0 g
s
.651 .757 .927 r
.55695 .42651 m .54679 .42996 L .54949 .43314 L p F P
0 g
s
.651 .757 .927 r
.54949 .43314 m .55963 .4297 L .55695 .42651 L p F P
0 g
s
.651 .757 .927 r
.72682 .42618 m .71634 .42964 L .71874 .43282 L p F P
0 g
s
.651 .757 .927 r
.71874 .43282 m .7292 .42937 L .72682 .42618 L p F P
0 g
s
.651 .757 .927 r
.41279 .42623 m .40291 .42968 L .40586 .43285 L p F P
0 g
s
.651 .757 .927 r
.40586 .43285 m .41573 .42942 L .41279 .42623 L p F P
0 g
s
.651 .757 .927 r
.56981 .42624 m .55963 .4297 L .5623 .43287 L p F P
0 g
s
.651 .757 .927 r
.5623 .43287 m .57247 .42943 L .56981 .42624 L p F P
0 g
s
.651 .757 .927 r
.73971 .4259 m .7292 .42937 L .73158 .43254 L p F P
0 g
s
.651 .757 .927 r
.73158 .43254 m .74207 .42909 L .73971 .4259 L p F P
0 g
s
.651 .757 .927 r
.42564 .42597 m .41573 .42942 L .41865 .43259 L p F P
0 g
s
.651 .757 .927 r
.41865 .43259 m .42855 .42915 L .42564 .42597 L p F P
0 g
s
.651 .757 .927 r
.58267 .42597 m .57247 .42943 L .57512 .43261 L p F P
0 g
s
.651 .757 .927 r
.57512 .43261 m .58531 .42916 L .58267 .42597 L p F P
0 g
s
.651 .757 .927 r
.7526 .42563 m .74207 .42909 L .74442 .43227 L p F P
0 g
s
.651 .757 .927 r
.74442 .43227 m .75494 .42881 L .7526 .42563 L p F P
0 g
s
.651 .757 .927 r
.43848 .4257 m .42855 .42915 L .43145 .43233 L p F P
0 g
s
.651 .757 .927 r
.43145 .43233 m .44137 .42889 L .43848 .4257 L p F P
0 g
s
.651 .757 .927 r
.59554 .42571 m .58531 .42916 L .58794 .43234 L p F P
0 g
s
.651 .757 .927 r
.58794 .43234 m .59816 .4289 L .59554 .42571 L p F P
0 g
s
.651 .757 .927 r
.76549 .42535 m .75494 .42881 L .75727 .43199 L p F P
0 g
s
.651 .757 .927 r
.75727 .43199 m .76781 .42854 L .76549 .42535 L p F P
0 g
s
.651 .757 .927 r
.45133 .42544 m .44137 .42889 L .44425 .43207 L p F P
0 g
s
.651 .757 .927 r
.44425 .43207 m .4542 .42863 L .45133 .42544 L p F P
0 g
s
.651 .757 .927 r
.60841 .42544 m .59816 .4289 L .60076 .43207 L p F P
0 g
s
.651 .757 .927 r
.60076 .43207 m .61101 .42863 L .60841 .42544 L p F P
0 g
s
.651 .757 .927 r
.77839 .42506 m .76781 .42854 L .77012 .43172 L p F P
0 g
s
.651 .757 .927 r
.77012 .43172 m .78068 .42826 L .77839 .42506 L p F P
0 g
s
.651 .757 .927 r
.62129 .42517 m .61101 .42863 L .61359 .43181 L p F P
0 g
s
.651 .757 .927 r
.61359 .43181 m .62386 .42836 L .62129 .42517 L p F P
0 g
s
.651 .757 .927 r
.46418 .42517 m .4542 .42863 L .45705 .43181 L p F P
0 g
s
.651 .757 .927 r
.45705 .43181 m .46703 .42837 L .46418 .42517 L p F P
0 g
s
.65 .757 .927 r
.31991 .42484 m .3102 .4283 L .31331 .43148 L p F P
0 g
s
.65 .757 .927 r
.31331 .43148 m .32301 .42804 L .31991 .42484 L p F P
0 g
s
.651 .757 .927 r
.63417 .4249 m .62386 .42836 L .62642 .43154 L p F P
0 g
s
.651 .757 .927 r
.62642 .43154 m .63672 .42809 L .63417 .4249 L p F P
0 g
s
.651 .757 .927 r
.47704 .42491 m .46703 .42837 L .46986 .43155 L p F P
0 g
s
.651 .757 .927 r
.46986 .43155 m .47986 .4281 L .47704 .42491 L p F P
0 g
s
.65 .757 .927 r
.33275 .42459 m .32301 .42804 L .3261 .43123 L p F P
0 g
s
.65 .757 .927 r
.3261 .43123 m .33583 .42778 L .33275 .42459 L p F P
0 g
s
.651 .757 .927 r
.64705 .42463 m .63672 .42809 L .63925 .43127 L p F P
0 g
s
.651 .757 .927 r
.63925 .43127 m .64958 .42782 L .64705 .42463 L p F P
0 g
s
.651 .757 .927 r
.4899 .42465 m .47986 .4281 L .48267 .43128 L p F P
0 g
s
.651 .757 .927 r
.48267 .43128 m .4927 .42784 L .4899 .42465 L p F P
0 g
s
.65 .757 .927 r
.34559 .42433 m .33583 .42778 L .33889 .43097 L p F P
0 g
s
.65 .757 .927 r
.33889 .43097 m .34864 .42753 L .34559 .42433 L p F P
0 g
s
.651 .757 .927 r
.65994 .42435 m .64958 .42782 L .65209 .431 L p F P
0 g
s
.651 .757 .927 r
.65209 .431 m .66244 .42755 L .65994 .42435 L p F P
0 g
s
.651 .757 .927 r
.50276 .42438 m .4927 .42784 L .49549 .43102 L p F P
0 g
s
.651 .757 .927 r
.49549 .43102 m .50554 .42757 L .50276 .42438 L p F P
0 g
s
.651 .757 .927 r
.35843 .42407 m .34864 .42753 L .35169 .43071 L p F P
0 g
s
.651 .757 .927 r
.35169 .43071 m .36147 .42727 L .35843 .42407 L p F P
0 g
s
.651 .757 .927 r
.67283 .42408 m .66244 .42755 L .66494 .43073 L p F P
0 g
s
.651 .757 .927 r
.66494 .43073 m .67531 .42728 L .67283 .42408 L p F P
0 g
s
.651 .757 .927 r
.51563 .42411 m .50554 .42757 L .50831 .43076 L p F P
0 g
s
.651 .757 .927 r
.50831 .43076 m .51839 .42731 L .51563 .42411 L p F P
0 g
s
.651 .757 .927 r
.37128 .42381 m .36147 .42727 L .36449 .43046 L p F P
0 g
s
.651 .757 .927 r
.36449 .43046 m .37429 .42701 L .37128 .42381 L p F P
0 g
s
.651 .757 .927 r
.68573 .42381 m .67531 .42728 L .67778 .43046 L p F P
0 g
s
.651 .757 .927 r
.67778 .43046 m .68818 .427 L .68573 .42381 L p F P
0 g
s
.651 .757 .927 r
.5285 .42385 m .51839 .42731 L .52113 .43049 L p F P
0 g
s
.651 .757 .927 r
.52113 .43049 m .53124 .42704 L .5285 .42385 L p F P
0 g
s
.651 .757 .927 r
.69862 .42353 m .68818 .427 L .69063 .43019 L p F P
0 g
s
.651 .757 .927 r
.69063 .43019 m .70106 .42673 L .69862 .42353 L p F P
0 g
s
.651 .757 .927 r
.38413 .42355 m .37429 .42701 L .37729 .4302 L p F P
0 g
s
.651 .757 .927 r
.37729 .4302 m .38712 .42675 L .38413 .42355 L p F P
0 g
s
.651 .757 .927 r
.54138 .42358 m .53124 .42704 L .53396 .43023 L p F P
0 g
s
.651 .757 .927 r
.53396 .43023 m .54409 .42678 L .54138 .42358 L p F P
0 g
s
.651 .757 .927 r
.71153 .42326 m .70106 .42673 L .70349 .42992 L p F P
0 g
s
.651 .757 .927 r
.70349 .42992 m .71394 .42646 L .71153 .42326 L p F P
0 g
s
.651 .757 .927 r
.39699 .42329 m .38712 .42675 L .3901 .42994 L p F P
0 g
s
.651 .757 .927 r
.3901 .42994 m .39996 .42649 L .39699 .42329 L p F P
0 g
s
.651 .757 .927 r
.55426 .42331 m .54409 .42678 L .54679 .42996 L p F P
0 g
s
.651 .757 .927 r
.54679 .42996 m .55695 .42651 L .55426 .42331 L p F P
0 g
s
.651 .757 .927 r
.72443 .42298 m .71394 .42646 L .71634 .42964 L p F P
0 g
s
.651 .757 .927 r
.71634 .42964 m .72682 .42618 L .72443 .42298 L p F P
0 g
s
.651 .757 .927 r
.40985 .42303 m .39996 .42649 L .40291 .42968 L p F P
0 g
s
.651 .757 .927 r
.40291 .42968 m .41279 .42623 L .40985 .42303 L p F P
0 g
s
.651 .757 .927 r
.56714 .42304 m .55695 .42651 L .55963 .4297 L p F P
0 g
s
.651 .757 .927 r
.55963 .4297 m .56981 .42624 L .56714 .42304 L p F P
0 g
s
.651 .757 .927 r
.73734 .4227 m .72682 .42618 L .7292 .42937 L p F P
0 g
s
.651 .757 .927 r
.7292 .42937 m .73971 .4259 L .73734 .4227 L p F P
0 g
s
.651 .757 .927 r
.42271 .42276 m .41279 .42623 L .41573 .42942 L p F P
0 g
s
.651 .757 .927 r
.41573 .42942 m .42564 .42597 L .42271 .42276 L p F P
0 g
s
.651 .757 .927 r
.58003 .42277 m .56981 .42624 L .57247 .42943 L p F P
0 g
s
.651 .757 .927 r
.57247 .42943 m .58267 .42597 L .58003 .42277 L p F P
0 g
s
.651 .757 .927 r
.75025 .42242 m .73971 .4259 L .74207 .42909 L p F P
0 g
s
.651 .757 .927 r
.74207 .42909 m .7526 .42563 L .75025 .42242 L p F P
0 g
s
.651 .757 .927 r
.43558 .4225 m .42564 .42597 L .42855 .42915 L p F P
0 g
s
.651 .757 .927 r
.42855 .42915 m .43848 .4257 L .43558 .4225 L p F P
0 g
s
.651 .757 .927 r
.59292 .42251 m .58267 .42597 L .58531 .42916 L p F P
0 g
s
.651 .757 .927 r
.58531 .42916 m .59554 .42571 L .59292 .42251 L p F P
0 g
s
.651 .757 .927 r
.76317 .42214 m .7526 .42563 L .75494 .42881 L p F P
0 g
s
.651 .757 .927 r
.75494 .42881 m .76549 .42535 L .76317 .42214 L p F P
0 g
s
.651 .757 .927 r
.44845 .42224 m .43848 .4257 L .44137 .42889 L p F P
0 g
s
.651 .757 .927 r
.44137 .42889 m .45133 .42544 L .44845 .42224 L p F P
0 g
s
.651 .757 .927 r
.60581 .42224 m .59554 .42571 L .59816 .4289 L p F P
0 g
s
.651 .757 .927 r
.59816 .4289 m .60841 .42544 L .60581 .42224 L p F P
0 g
s
.651 .757 .927 r
.77609 .42186 m .76549 .42535 L .76781 .42854 L p F P
0 g
s
.651 .757 .927 r
.76781 .42854 m .77839 .42506 L .77609 .42186 L p F P
0 g
s
.651 .757 .927 r
.61871 .42196 m .60841 .42544 L .61101 .42863 L p F P
0 g
s
.651 .757 .927 r
.61101 .42863 m .62129 .42517 L .61871 .42196 L p F P
0 g
s
.651 .757 .927 r
.46133 .42197 m .45133 .42544 L .4542 .42863 L p F P
0 g
s
.651 .757 .927 r
.4542 .42863 m .46418 .42517 L .46133 .42197 L p F P
0 g
s
.651 .757 .927 r
.63161 .42169 m .62129 .42517 L .62386 .42836 L p F P
0 g
s
.651 .757 .927 r
.62386 .42836 m .63417 .4249 L .63161 .42169 L p F P
0 g
s
.651 .757 .927 r
.47421 .42171 m .46418 .42517 L .46703 .42837 L p F P
0 g
s
.651 .757 .927 r
.46703 .42837 m .47704 .42491 L .47421 .42171 L p F P
0 g
s
.65 .757 .927 r
.32966 .42138 m .31991 .42484 L .32301 .42804 L p F P
0 g
s
.65 .757 .927 r
.32301 .42804 m .33275 .42459 L .32966 .42138 L p F P
0 g
s
.651 .757 .927 r
.64452 .42142 m .63417 .4249 L .63672 .42809 L p F P
0 g
s
.651 .757 .927 r
.63672 .42809 m .64705 .42463 L .64452 .42142 L p F P
0 g
s
.651 .757 .927 r
.48709 .42144 m .47704 .42491 L .47986 .4281 L p F P
0 g
s
.651 .757 .927 r
.47986 .4281 m .4899 .42465 L .48709 .42144 L p F P
0 g
s
.65 .757 .927 r
.34253 .42112 m .33275 .42459 L .33583 .42778 L p F P
0 g
s
.65 .757 .927 r
.33583 .42778 m .34559 .42433 L .34253 .42112 L p F P
0 g
s
.651 .757 .927 r
.65743 .42115 m .64705 .42463 L .64958 .42782 L p F P
0 g
s
.651 .757 .927 r
.64958 .42782 m .65994 .42435 L .65743 .42115 L p F P
0 g
s
.651 .757 .927 r
.49998 .42117 m .4899 .42465 L .4927 .42784 L p F P
0 g
s
.651 .757 .927 r
.4927 .42784 m .50276 .42438 L .49998 .42117 L p F P
0 g
s
.651 .757 .927 r
.35539 .42086 m .34559 .42433 L .34864 .42753 L p F P
0 g
s
.651 .757 .927 r
.34864 .42753 m .35843 .42407 L .35539 .42086 L p F P
0 g
s
.651 .757 .927 r
.67034 .42087 m .65994 .42435 L .66244 .42755 L p F P
0 g
s
.651 .757 .927 r
.66244 .42755 m .67283 .42408 L .67034 .42087 L p F P
0 g
s
.651 .757 .927 r
.51287 .42091 m .50276 .42438 L .50554 .42757 L p F P
0 g
s
.651 .757 .927 r
.50554 .42757 m .51563 .42411 L .51287 .42091 L p F P
0 g
s
.651 .757 .927 r
.36826 .4206 m .35843 .42407 L .36147 .42727 L p F P
0 g
s
.651 .757 .927 r
.36147 .42727 m .37128 .42381 L .36826 .4206 L p F P
0 g
s
.651 .757 .927 r
.68326 .4206 m .67283 .42408 L .67531 .42728 L p F P
0 g
s
.651 .757 .927 r
.67531 .42728 m .68573 .42381 L .68326 .4206 L p F P
0 g
s
.651 .757 .927 r
.52576 .42064 m .51563 .42411 L .51839 .42731 L p F P
0 g
s
.651 .757 .927 r
.51839 .42731 m .5285 .42385 L .52576 .42064 L p F P
0 g
s
.651 .757 .927 r
.69618 .42032 m .68573 .42381 L .68818 .427 L p F P
0 g
s
.651 .757 .927 r
.68818 .427 m .69862 .42353 L .69618 .42032 L p F P
0 g
s
.651 .757 .927 r
.38114 .42034 m .37128 .42381 L .37429 .42701 L p F P
0 g
s
.651 .757 .927 r
.37429 .42701 m .38413 .42355 L .38114 .42034 L p F P
0 g
s
.651 .757 .927 r
.53866 .42037 m .5285 .42385 L .53124 .42704 L p F P
0 g
s
.651 .757 .927 r
.53124 .42704 m .54138 .42358 L .53866 .42037 L p F P
0 g
s
.651 .757 .927 r
.7091 .42005 m .69862 .42353 L .70106 .42673 L p F P
0 g
s
.651 .757 .927 r
.70106 .42673 m .71153 .42326 L .7091 .42005 L p F P
0 g
s
.651 .757 .927 r
.39401 .42008 m .38413 .42355 L .38712 .42675 L p F P
0 g
s
.651 .757 .927 r
.38712 .42675 m .39699 .42329 L .39401 .42008 L p F P
0 g
s
.651 .757 .927 r
.55156 .4201 m .54138 .42358 L .54409 .42678 L p F P
0 g
s
.651 .757 .927 r
.54409 .42678 m .55426 .42331 L .55156 .4201 L p F P
0 g
s
.651 .757 .927 r
.72203 .41977 m .71153 .42326 L .71394 .42646 L p F P
0 g
s
.651 .757 .927 r
.71394 .42646 m .72443 .42298 L .72203 .41977 L p F P
0 g
s
.651 .757 .927 r
.4069 .41981 m .39699 .42329 L .39996 .42649 L p F P
0 g
s
.651 .757 .927 r
.39996 .42649 m .40985 .42303 L .4069 .41981 L p F P
0 g
s
.651 .757 .927 r
.56447 .41983 m .55426 .42331 L .55695 .42651 L p F P
0 g
s
.651 .757 .927 r
.55695 .42651 m .56714 .42304 L .56447 .41983 L p F P
0 g
s
.651 .757 .927 r
.73496 .41949 m .72443 .42298 L .72682 .42618 L p F P
0 g
s
.651 .757 .927 r
.72682 .42618 m .73734 .4227 L .73496 .41949 L p F P
0 g
s
.651 .757 .927 r
.41978 .41955 m .40985 .42303 L .41279 .42623 L p F P
0 g
s
.651 .757 .927 r
.41279 .42623 m .42271 .42276 L .41978 .41955 L p F P
0 g
s
.651 .757 .927 r
.57738 .41956 m .56714 .42304 L .56981 .42624 L p F P
0 g
s
.651 .757 .927 r
.56981 .42624 m .58003 .42277 L .57738 .41956 L p F P
0 g
s
.651 .757 .927 r
.7479 .41921 m .73734 .4227 L .73971 .4259 L p F P
0 g
s
.651 .757 .927 r
.73971 .4259 m .75025 .42242 L .7479 .41921 L p F P
0 g
s
.651 .757 .927 r
.43267 .41929 m .42271 .42276 L .42564 .42597 L p F P
0 g
s
.651 .757 .927 r
.42564 .42597 m .43558 .4225 L .43267 .41929 L p F P
0 g
s
.651 .757 .927 r
.59029 .41929 m .58003 .42277 L .58267 .42597 L p F P
0 g
s
.651 .757 .927 r
.58267 .42597 m .59292 .42251 L .59029 .41929 L p F P
0 g
s
.651 .757 .927 r
.76084 .41893 m .75025 .42242 L .7526 .42563 L p F P
0 g
s
.651 .757 .927 r
.7526 .42563 m .76317 .42214 L .76084 .41893 L p F P
0 g
s
.651 .757 .927 r
.44557 .41902 m .43558 .4225 L .43848 .4257 L p F P
0 g
s
.651 .757 .927 r
.43848 .4257 m .44845 .42224 L .44557 .41902 L p F P
0 g
s
.651 .757 .927 r
.6032 .41902 m .59292 .42251 L .59554 .42571 L p F P
0 g
s
.651 .757 .927 r
.59554 .42571 m .60581 .42224 L .6032 .41902 L p F P
0 g
s
.651 .757 .927 r
.77378 .41865 m .76317 .42214 L .76549 .42535 L p F P
0 g
s
.651 .757 .927 r
.76549 .42535 m .77609 .42186 L .77378 .41865 L p F P
0 g
s
.651 .757 .927 r
.61613 .41875 m .60581 .42224 L .60841 .42544 L p F P
0 g
s
.651 .757 .927 r
.60841 .42544 m .61871 .42196 L .61613 .41875 L p F P
0 g
s
.651 .757 .927 r
.45846 .41876 m .44845 .42224 L .45133 .42544 L p F P
0 g
s
.651 .757 .927 r
.45133 .42544 m .46133 .42197 L .45846 .41876 L p F P
0 g
s
.651 .757 .927 r
.62905 .41848 m .61871 .42196 L .62129 .42517 L p F P
0 g
s
.651 .757 .927 r
.62129 .42517 m .63161 .42169 L .62905 .41848 L p F P
0 g
s
.651 .757 .927 r
.47136 .41849 m .46133 .42197 L .46418 .42517 L p F P
0 g
s
.651 .757 .927 r
.46418 .42517 m .47421 .42171 L .47136 .41849 L p F P
0 g
s
.651 .757 .927 r
.64198 .41821 m .63161 .42169 L .63417 .4249 L p F P
0 g
s
.651 .757 .927 r
.63417 .4249 m .64452 .42142 L .64198 .41821 L p F P
0 g
s
.651 .757 .927 r
.48427 .41822 m .47421 .42171 L .47704 .42491 L p F P
0 g
s
.651 .757 .927 r
.47704 .42491 m .48709 .42144 L .48427 .41822 L p F P
0 g
s
.65 .757 .927 r
.33945 .4179 m .32966 .42138 L .33275 .42459 L p F P
0 g
s
.65 .757 .927 r
.33275 .42459 m .34253 .42112 L .33945 .4179 L p F P
0 g
s
.651 .757 .927 r
.65491 .41793 m .64452 .42142 L .64705 .42463 L p F P
0 g
s
.651 .757 .927 r
.64705 .42463 m .65743 .42115 L .65491 .41793 L p F P
0 g
s
.651 .757 .927 r
.49718 .41796 m .48709 .42144 L .4899 .42465 L p F P
0 g
s
.651 .757 .927 r
.4899 .42465 m .49998 .42117 L .49718 .41796 L p F P
0 g
s
.651 .757 .927 r
.35234 .41764 m .34253 .42112 L .34559 .42433 L p F P
0 g
s
.651 .757 .927 r
.34559 .42433 m .35539 .42086 L .35234 .41764 L p F P
0 g
s
.651 .757 .927 r
.66784 .41766 m .65743 .42115 L .65994 .42435 L p F P
0 g
s
.651 .757 .927 r
.65994 .42435 m .67034 .42087 L .66784 .41766 L p F P
0 g
s
.651 .757 .927 r
.51009 .41769 m .49998 .42117 L .50276 .42438 L p F P
0 g
s
.651 .757 .927 r
.50276 .42438 m .51287 .42091 L .51009 .41769 L p F P
0 g
s
.651 .757 .927 r
.36523 .41738 m .35539 .42086 L .35843 .42407 L p F P
0 g
s
.651 .757 .927 r
.35843 .42407 m .36826 .4206 L .36523 .41738 L p F P
0 g
s
.651 .757 .927 r
.68078 .41738 m .67034 .42087 L .67283 .42408 L p F P
0 g
s
.651 .757 .927 r
.67283 .42408 m .68326 .4206 L .68078 .41738 L p F P
0 g
s
.651 .757 .927 r
.52301 .41742 m .51287 .42091 L .51563 .42411 L p F P
0 g
s
.651 .757 .927 r
.51563 .42411 m .52576 .42064 L .52301 .41742 L p F P
0 g
s
.651 .757 .927 r
.69373 .4171 m .68326 .4206 L .68573 .42381 L p F P
0 g
s
.651 .757 .927 r
.68573 .42381 m .69618 .42032 L .69373 .4171 L p F P
0 g
s
.651 .757 .927 r
.37813 .41712 m .36826 .4206 L .37128 .42381 L p F P
0 g
s
.651 .757 .927 r
.37128 .42381 m .38114 .42034 L .37813 .41712 L p F P
0 g
s
.651 .757 .927 r
.53593 .41715 m .52576 .42064 L .5285 .42385 L p F P
0 g
s
.651 .757 .927 r
.5285 .42385 m .53866 .42037 L .53593 .41715 L p F P
0 g
s
.651 .757 .927 r
.70667 .41683 m .69618 .42032 L .69862 .42353 L p F P
0 g
s
.651 .757 .927 r
.69862 .42353 m .7091 .42005 L .70667 .41683 L p F P
0 g
s
.651 .757 .927 r
.39103 .41685 m .38114 .42034 L .38413 .42355 L p F P
0 g
s
.651 .757 .927 r
.38413 .42355 m .39401 .42008 L .39103 .41685 L p F P
0 g
s
.651 .757 .927 r
.54885 .41688 m .53866 .42037 L .54138 .42358 L p F P
0 g
s
.651 .757 .927 r
.54138 .42358 m .55156 .4201 L .54885 .41688 L p F P
0 g
s
.651 .757 .927 r
.71962 .41655 m .7091 .42005 L .71153 .42326 L p F P
0 g
s
.651 .757 .927 r
.71153 .42326 m .72203 .41977 L .71962 .41655 L p F P
0 g
s
.651 .757 .927 r
.40393 .41659 m .39401 .42008 L .39699 .42329 L p F P
0 g
s
.651 .757 .927 r
.39699 .42329 m .4069 .41981 L .40393 .41659 L p F P
0 g
s
.651 .757 .927 r
.56178 .41661 m .55156 .4201 L .55426 .42331 L p F P
0 g
s
.651 .757 .927 r
.55426 .42331 m .56447 .41983 L .56178 .41661 L p F P
0 g
s
.651 .757 .927 r
.73258 .41627 m .72203 .41977 L .72443 .42298 L p F P
0 g
s
.651 .757 .927 r
.72443 .42298 m .73496 .41949 L .73258 .41627 L p F P
0 g
s
.651 .757 .927 r
.41684 .41633 m .4069 .41981 L .40985 .42303 L p F P
0 g
s
.651 .757 .927 r
.40985 .42303 m .41978 .41955 L .41684 .41633 L p F P
0 g
s
.651 .757 .927 r
.57471 .41634 m .56447 .41983 L .56714 .42304 L p F P
0 g
s
.651 .757 .927 r
.56714 .42304 m .57738 .41956 L .57471 .41634 L p F P
0 g
s
.651 .757 .927 r
.74554 .41599 m .73496 .41949 L .73734 .4227 L p F P
0 g
s
.651 .757 .927 r
.73734 .4227 m .7479 .41921 L .74554 .41599 L p F P
0 g
s
.651 .757 .927 r
.42975 .41606 m .41978 .41955 L .42271 .42276 L p F P
0 g
s
.651 .757 .927 r
.42271 .42276 m .43267 .41929 L .42975 .41606 L p F P
0 g
s
.651 .757 .927 r
.58765 .41607 m .57738 .41956 L .58003 .42277 L p F P
0 g
s
.651 .757 .927 r
.58003 .42277 m .59029 .41929 L .58765 .41607 L p F P
0 g
s
.651 .757 .927 r
.7585 .41571 m .7479 .41921 L .75025 .42242 L p F P
0 g
s
.651 .757 .927 r
.75025 .42242 m .76084 .41893 L .7585 .41571 L p F P
0 g
s
.651 .757 .927 r
.44267 .4158 m .43267 .41929 L .43558 .4225 L p F P
0 g
s
.651 .757 .927 r
.43558 .4225 m .44557 .41902 L .44267 .4158 L p F P
0 g
s
.651 .757 .927 r
.60059 .4158 m .59029 .41929 L .59292 .42251 L p F P
0 g
s
.651 .757 .927 r
.59292 .42251 m .6032 .41902 L .60059 .4158 L p F P
0 g
s
.651 .757 .927 r
.77146 .41542 m .76084 .41893 L .76317 .42214 L p F P
0 g
s
.651 .757 .927 r
.76317 .42214 m .77378 .41865 L .77146 .41542 L p F P
0 g
s
.651 .757 .927 r
.61353 .41552 m .6032 .41902 L .60581 .42224 L p F P
0 g
s
.651 .757 .927 r
.60581 .42224 m .61613 .41875 L .61353 .41552 L p F P
0 g
s
.651 .757 .927 r
.45559 .41553 m .44557 .41902 L .44845 .42224 L p F P
0 g
s
.651 .757 .927 r
.44845 .42224 m .45846 .41876 L .45559 .41553 L p F P
0 g
s
.651 .757 .927 r
.62648 .41525 m .61613 .41875 L .61871 .42196 L p F P
0 g
s
.651 .757 .927 r
.61871 .42196 m .62905 .41848 L .62648 .41525 L p F P
0 g
s
.651 .757 .927 r
.46851 .41526 m .45846 .41876 L .46133 .42197 L p F P
0 g
s
.651 .757 .927 r
.46133 .42197 m .47136 .41849 L .46851 .41526 L p F P
0 g
s
.651 .757 .927 r
.63943 .41498 m .62905 .41848 L .63161 .42169 L p F P
0 g
s
.651 .757 .927 r
.63161 .42169 m .64198 .41821 L .63943 .41498 L p F P
0 g
s
.651 .757 .927 r
.48144 .41499 m .47136 .41849 L .47421 .42171 L p F P
0 g
s
.651 .757 .927 r
.47421 .42171 m .48427 .41822 L .48144 .41499 L p F P
0 g
s
.651 .757 .927 r
.65238 .4147 m .64198 .41821 L .64452 .42142 L p F P
0 g
s
.651 .757 .927 r
.64452 .42142 m .65491 .41793 L .65238 .4147 L p F P
0 g
s
.651 .757 .927 r
.49437 .41473 m .48427 .41822 L .48709 .42144 L p F P
0 g
s
.651 .757 .927 r
.48709 .42144 m .49718 .41796 L .49437 .41473 L p F P
0 g
s
.651 .757 .927 r
.34927 .41441 m .33945 .4179 L .34253 .42112 L p F P
0 g
s
.651 .757 .927 r
.34253 .42112 m .35234 .41764 L .34927 .41441 L p F P
0 g
s
.651 .757 .927 r
.66534 .41443 m .65491 .41793 L .65743 .42115 L p F P
0 g
s
.651 .757 .927 r
.65743 .42115 m .66784 .41766 L .66534 .41443 L p F P
0 g
s
.651 .757 .927 r
.50731 .41446 m .49718 .41796 L .49998 .42117 L p F P
0 g
s
.651 .757 .927 r
.49998 .42117 m .51009 .41769 L .50731 .41446 L p F P
0 g
s
.651 .757 .927 r
.36219 .41414 m .35234 .41764 L .35539 .42086 L p F P
0 g
s
.651 .757 .927 r
.35539 .42086 m .36523 .41738 L .36219 .41414 L p F P
0 g
s
.651 .757 .927 r
.6783 .41415 m .66784 .41766 L .67034 .42087 L p F P
0 g
s
.651 .757 .927 r
.67034 .42087 m .68078 .41738 L .6783 .41415 L p F P
0 g
s
.651 .757 .927 r
.52024 .41419 m .51009 .41769 L .51287 .42091 L p F P
0 g
s
.651 .757 .927 r
.51287 .42091 m .52301 .41742 L .52024 .41419 L p F P
0 g
s
.651 .757 .927 r
.37511 .41388 m .36523 .41738 L .36826 .4206 L p F P
0 g
s
.651 .757 .927 r
.36826 .4206 m .37813 .41712 L .37511 .41388 L p F P
0 g
s
.651 .757 .927 r
.69127 .41387 m .68078 .41738 L .68326 .4206 L p F P
0 g
s
.651 .757 .927 r
.68326 .4206 m .69373 .4171 L .69127 .41387 L p F P
0 g
s
.651 .757 .927 r
.53319 .41392 m .52301 .41742 L .52576 .42064 L p F P
0 g
s
.651 .757 .927 r
.52576 .42064 m .53593 .41715 L .53319 .41392 L p F P
0 g
s
.651 .757 .927 r
.70423 .41359 m .69373 .4171 L .69618 .42032 L p F P
0 g
s
.651 .757 .927 r
.69618 .42032 m .70667 .41683 L .70423 .41359 L p F P
0 g
s
.651 .757 .927 r
.38803 .41362 m .37813 .41712 L .38114 .42034 L p F P
0 g
s
.651 .757 .927 r
.38114 .42034 m .39103 .41685 L .38803 .41362 L p F P
0 g
s
.651 .757 .927 r
.54613 .41365 m .53593 .41715 L .53866 .42037 L p F P
0 g
s
.651 .757 .927 r
.53866 .42037 m .54885 .41688 L .54613 .41365 L p F P
0 g
s
.651 .757 .927 r
.71721 .41332 m .70667 .41683 L .7091 .42005 L p F P
0 g
s
.651 .757 .927 r
.7091 .42005 m .71962 .41655 L .71721 .41332 L p F P
0 g
s
.651 .757 .927 r
.40096 .41335 m .39103 .41685 L .39401 .42008 L p F P
0 g
s
.651 .757 .927 r
.39401 .42008 m .40393 .41659 L .40096 .41335 L p F P
0 g
s
.651 .757 .927 r
.55908 .41338 m .54885 .41688 L .55156 .4201 L p F P
0 g
s
.651 .757 .927 r
.55156 .4201 m .56178 .41661 L .55908 .41338 L p F P
0 g
s
.651 .757 .927 r
.73018 .41303 m .71962 .41655 L .72203 .41977 L p F P
0 g
s
.651 .757 .927 r
.72203 .41977 m .73258 .41627 L .73018 .41303 L p F P
0 g
s
.651 .757 .927 r
.41389 .41309 m .40393 .41659 L .4069 .41981 L p F P
0 g
s
.651 .757 .927 r
.4069 .41981 m .41684 .41633 L .41389 .41309 L p F P
0 g
s
.651 .757 .927 r
.57204 .41311 m .56178 .41661 L .56447 .41983 L p F P
0 g
s
.651 .757 .927 r
.56447 .41983 m .57471 .41634 L .57204 .41311 L p F P
0 g
s
.651 .757 .927 r
.74316 .41275 m .73258 .41627 L .73496 .41949 L p F P
0 g
s
.651 .757 .927 r
.73496 .41949 m .74554 .41599 L .74316 .41275 L p F P
0 g
s
.651 .757 .927 r
.42682 .41282 m .41684 .41633 L .41978 .41955 L p F P
0 g
s
.651 .757 .927 r
.41978 .41955 m .42975 .41606 L .42682 .41282 L p F P
0 g
s
.651 .757 .927 r
.585 .41283 m .57471 .41634 L .57738 .41956 L p F P
0 g
s
.651 .757 .927 r
.57738 .41956 m .58765 .41607 L .585 .41283 L p F P
0 g
s
.651 .757 .927 r
.75615 .41247 m .74554 .41599 L .7479 .41921 L p F P
0 g
s
.651 .757 .927 r
.7479 .41921 m .7585 .41571 L .75615 .41247 L p F P
0 g
s
.651 .757 .927 r
.43976 .41256 m .42975 .41606 L .43267 .41929 L p F P
0 g
s
.651 .757 .927 r
.43267 .41929 m .44267 .4158 L .43976 .41256 L p F P
0 g
s
.651 .757 .927 r
.59796 .41256 m .58765 .41607 L .59029 .41929 L p F P
0 g
s
.651 .757 .927 r
.59029 .41929 m .60059 .4158 L .59796 .41256 L p F P
0 g
s
.651 .757 .927 r
.76913 .41218 m .7585 .41571 L .76084 .41893 L p F P
0 g
s
.651 .757 .927 r
.76084 .41893 m .77146 .41542 L .76913 .41218 L p F P
0 g
s
.651 .757 .927 r
.4527 .41229 m .44267 .4158 L .44557 .41902 L p F P
0 g
s
.651 .757 .927 r
.44557 .41902 m .45559 .41553 L .4527 .41229 L p F P
0 g
s
.651 .757 .927 r
.61092 .41229 m .60059 .4158 L .6032 .41902 L p F P
0 g
s
.651 .757 .927 r
.6032 .41902 m .61353 .41552 L .61092 .41229 L p F P
0 g
s
.651 .757 .927 r
.62389 .41201 m .61353 .41552 L .61613 .41875 L p F P
0 g
s
.651 .757 .927 r
.61613 .41875 m .62648 .41525 L .62389 .41201 L p F P
0 g
s
.651 .757 .927 r
.46565 .41202 m .45559 .41553 L .45846 .41876 L p F P
0 g
s
.651 .757 .927 r
.45846 .41876 m .46851 .41526 L .46565 .41202 L p F P
0 g
s
.651 .757 .927 r
.63687 .41174 m .62648 .41525 L .62905 .41848 L p F P
0 g
s
.651 .757 .927 r
.62905 .41848 m .63943 .41498 L .63687 .41174 L p F P
0 g
s
.651 .757 .927 r
.4786 .41175 m .46851 .41526 L .47136 .41849 L p F P
0 g
s
.651 .757 .927 r
.47136 .41849 m .48144 .41499 L .4786 .41175 L p F P
0 g
s
.651 .757 .927 r
.64984 .41146 m .63943 .41498 L .64198 .41821 L p F P
0 g
s
.651 .757 .927 r
.64198 .41821 m .65238 .4147 L .64984 .41146 L p F P
0 g
s
.651 .757 .927 r
.49155 .41149 m .48144 .41499 L .48427 .41822 L p F P
0 g
s
.651 .757 .927 r
.48427 .41822 m .49437 .41473 L .49155 .41149 L p F P
0 g
s
.651 .757 .927 r
.66282 .41119 m .65238 .4147 L .65491 .41793 L p F P
0 g
s
.651 .757 .927 r
.65491 .41793 m .66534 .41443 L .66282 .41119 L p F P
0 g
s
.651 .757 .927 r
.50451 .41122 m .49437 .41473 L .49718 .41796 L p F P
0 g
s
.651 .757 .927 r
.49718 .41796 m .50731 .41446 L .50451 .41122 L p F P
0 g
s
.651 .757 .927 r
.35914 .4109 m .34927 .41441 L .35234 .41764 L p F P
0 g
s
.651 .757 .927 r
.35234 .41764 m .36219 .41414 L .35914 .4109 L p F P
0 g
s
.651 .757 .927 r
.67581 .41091 m .66534 .41443 L .66784 .41766 L p F P
0 g
s
.651 .757 .927 r
.66784 .41766 m .6783 .41415 L .67581 .41091 L p F P
0 g
s
.651 .757 .927 r
.51747 .41095 m .50731 .41446 L .51009 .41769 L p F P
0 g
s
.651 .757 .927 r
.51009 .41769 m .52024 .41419 L .51747 .41095 L p F P
0 g
s
.651 .757 .927 r
.37208 .41064 m .36219 .41414 L .36523 .41738 L p F P
0 g
s
.651 .757 .927 r
.36523 .41738 m .37511 .41388 L .37208 .41064 L p F P
0 g
s
.651 .757 .927 r
.6888 .41063 m .6783 .41415 L .68078 .41738 L p F P
0 g
s
.651 .757 .927 r
.68078 .41738 m .69127 .41387 L .6888 .41063 L p F P
0 g
s
.651 .757 .927 r
.53044 .41068 m .52024 .41419 L .52301 .41742 L p F P
0 g
s
.651 .757 .927 r
.52301 .41742 m .53319 .41392 L .53044 .41068 L p F P
0 g
s
.651 .757 .927 r
.70179 .41035 m .69127 .41387 L .69373 .4171 L p F P
0 g
s
.651 .757 .927 r
.69373 .4171 m .70423 .41359 L .70179 .41035 L p F P
0 g
s
.651 .757 .927 r
.38502 .41037 m .37511 .41388 L .37813 .41712 L p F P
0 g
s
.651 .757 .927 r
.37813 .41712 m .38803 .41362 L .38502 .41037 L p F P
0 g
s
.651 .757 .927 r
.54341 .4104 m .53319 .41392 L .53593 .41715 L p F P
0 g
s
.651 .757 .927 r
.53593 .41715 m .54613 .41365 L .54341 .4104 L p F P
0 g
s
.651 .757 .927 r
.71478 .41007 m .70423 .41359 L .70667 .41683 L p F P
0 g
s
.651 .757 .927 r
.70667 .41683 m .71721 .41332 L .71478 .41007 L p F P
0 g
s
.651 .757 .927 r
.39797 .41011 m .38803 .41362 L .39103 .41685 L p F P
0 g
s
.651 .757 .927 r
.39103 .41685 m .40096 .41335 L .39797 .41011 L p F P
0 g
s
.651 .757 .927 r
.55638 .41013 m .54613 .41365 L .54885 .41688 L p F P
0 g
s
.651 .757 .927 r
.54885 .41688 m .55908 .41338 L .55638 .41013 L p F P
0 g
s
.651 .757 .927 r
.72778 .40979 m .71721 .41332 L .71962 .41655 L p F P
0 g
s
.651 .757 .927 r
.71962 .41655 m .73018 .41303 L .72778 .40979 L p F P
0 g
s
.651 .757 .927 r
.41093 .40984 m .40096 .41335 L .40393 .41659 L p F P
0 g
s
.651 .757 .927 r
.40393 .41659 m .41389 .41309 L .41093 .40984 L p F P
0 g
s
.651 .757 .927 r
.56936 .40986 m .55908 .41338 L .56178 .41661 L p F P
0 g
s
.651 .757 .927 r
.56178 .41661 m .57204 .41311 L .56936 .40986 L p F P
0 g
s
.651 .757 .927 r
.74078 .4095 m .73018 .41303 L .73258 .41627 L p F P
0 g
s
.651 .757 .927 r
.73258 .41627 m .74316 .41275 L .74078 .4095 L p F P
0 g
s
.651 .757 .927 r
.42388 .40958 m .41389 .41309 L .41684 .41633 L p F P
0 g
s
.651 .757 .927 r
.41684 .41633 m .42682 .41282 L .42388 .40958 L p F P
0 g
s
.651 .757 .927 r
.58234 .40959 m .57204 .41311 L .57471 .41634 L p F P
0 g
s
.651 .757 .927 r
.57471 .41634 m .585 .41283 L .58234 .40959 L p F P
0 g
s
.651 .757 .927 r
.75379 .40922 m .74316 .41275 L .74554 .41599 L p F P
0 g
s
.651 .757 .927 r
.74554 .41599 m .75615 .41247 L .75379 .40922 L p F P
0 g
s
.651 .757 .927 r
.43684 .40931 m .42682 .41282 L .42975 .41606 L p F P
0 g
s
.651 .757 .927 r
.42975 .41606 m .43976 .41256 L .43684 .40931 L p F P
0 g
s
.651 .757 .927 r
.59532 .40931 m .585 .41283 L .58765 .41607 L p F P
0 g
s
.651 .757 .927 r
.58765 .41607 m .59796 .41256 L .59532 .40931 L p F P
0 g
s
.651 .757 .927 r
.7668 .40893 m .75615 .41247 L .7585 .41571 L p F P
0 g
s
.651 .757 .927 r
.7585 .41571 m .76913 .41218 L .7668 .40893 L p F P
0 g
s
.651 .757 .927 r
.44981 .40904 m .43976 .41256 L .44267 .4158 L p F P
0 g
s
.651 .757 .927 r
.44267 .4158 m .4527 .41229 L .44981 .40904 L p F P
0 g
s
.651 .757 .927 r
.60831 .40904 m .59796 .41256 L .60059 .4158 L p F P
0 g
s
.651 .757 .927 r
.60059 .4158 m .61092 .41229 L .60831 .40904 L p F P
0 g
s
.651 .757 .927 r
.6213 .40876 m .61092 .41229 L .61353 .41552 L p F P
0 g
s
.651 .757 .927 r
.61353 .41552 m .62389 .41201 L .6213 .40876 L p F P
0 g
s
.651 .757 .927 r
.46278 .40877 m .4527 .41229 L .45559 .41553 L p F P
0 g
s
.651 .757 .927 r
.45559 .41553 m .46565 .41202 L .46278 .40877 L p F P
0 g
s
.651 .757 .927 r
.6343 .40849 m .62389 .41201 L .62648 .41525 L p F P
0 g
s
.651 .757 .927 r
.62648 .41525 m .63687 .41174 L .6343 .40849 L p F P
0 g
s
.651 .757 .927 r
.47575 .4085 m .46565 .41202 L .46851 .41526 L p F P
0 g
s
.651 .757 .927 r
.46851 .41526 m .4786 .41175 L .47575 .4085 L p F P
0 g
s
.651 .757 .927 r
.6473 .40821 m .63687 .41174 L .63943 .41498 L p F P
0 g
s
.651 .757 .927 r
.63943 .41498 m .64984 .41146 L .6473 .40821 L p F P
0 g
s
.651 .757 .927 r
.48873 .40823 m .4786 .41175 L .48144 .41499 L p F P
0 g
s
.651 .757 .927 r
.48144 .41499 m .49155 .41149 L .48873 .40823 L p F P
0 g
s
.651 .757 .927 r
.6603 .40793 m .64984 .41146 L .65238 .4147 L p F P
0 g
s
.651 .757 .927 r
.65238 .4147 m .66282 .41119 L .6603 .40793 L p F P
0 g
s
.651 .757 .927 r
.50171 .40796 m .49155 .41149 L .49437 .41473 L p F P
0 g
s
.651 .757 .927 r
.49437 .41473 m .50451 .41122 L .50171 .40796 L p F P
0 g
s
.651 .757 .927 r
.67331 .40765 m .66282 .41119 L .66534 .41443 L p F P
0 g
s
.651 .757 .927 r
.66534 .41443 m .67581 .41091 L .67331 .40765 L p F P
0 g
s
.651 .757 .927 r
.51469 .40769 m .50451 .41122 L .50731 .41446 L p F P
0 g
s
.651 .757 .927 r
.50731 .41446 m .51747 .41095 L .51469 .40769 L p F P
0 g
s
.651 .757 .927 r
.36904 .40738 m .35914 .4109 L .36219 .41414 L p F P
0 g
s
.651 .757 .927 r
.36219 .41414 m .37208 .41064 L .36904 .40738 L p F P
0 g
s
.651 .757 .927 r
.68632 .40738 m .67581 .41091 L .6783 .41415 L p F P
0 g
s
.651 .757 .927 r
.6783 .41415 m .6888 .41063 L .68632 .40738 L p F P
0 g
s
.651 .757 .927 r
.52768 .40742 m .51747 .41095 L .52024 .41419 L p F P
0 g
s
.651 .757 .927 r
.52024 .41419 m .53044 .41068 L .52768 .40742 L p F P
0 g
s
.651 .757 .927 r
.69933 .40709 m .6888 .41063 L .69127 .41387 L p F P
0 g
s
.651 .757 .927 r
.69127 .41387 m .70179 .41035 L .69933 .40709 L p F P
0 g
s
.651 .757 .927 r
.38201 .40711 m .37208 .41064 L .37511 .41388 L p F P
0 g
s
.651 .757 .927 r
.37511 .41388 m .38502 .41037 L .38201 .40711 L p F P
0 g
s
.651 .757 .927 r
.54067 .40715 m .53044 .41068 L .53319 .41392 L p F P
0 g
s
.651 .757 .927 r
.53319 .41392 m .54341 .4104 L .54067 .40715 L p F P
0 g
s
.651 .757 .927 r
.71235 .40681 m .70179 .41035 L .70423 .41359 L p F P
0 g
s
.651 .757 .927 r
.70423 .41359 m .71478 .41007 L .71235 .40681 L p F P
0 g
s
.651 .757 .927 r
.39498 .40685 m .38502 .41037 L .38803 .41362 L p F P
0 g
s
.651 .757 .927 r
.38803 .41362 m .39797 .41011 L .39498 .40685 L p F P
0 g
s
.651 .757 .927 r
.55366 .40688 m .54341 .4104 L .54613 .41365 L p F P
0 g
s
.651 .757 .927 r
.54613 .41365 m .55638 .41013 L .55366 .40688 L p F P
0 g
s
.651 .757 .927 r
.72537 .40653 m .71478 .41007 L .71721 .41332 L p F P
0 g
s
.651 .757 .927 r
.71721 .41332 m .72778 .40979 L .72537 .40653 L p F P
0 g
s
.651 .757 .927 r
.40795 .40658 m .39797 .41011 L .40096 .41335 L p F P
0 g
s
.651 .757 .927 r
.40096 .41335 m .41093 .40984 L .40795 .40658 L p F P
0 g
s
.651 .757 .927 r
.56666 .4066 m .55638 .41013 L .55908 .41338 L p F P
0 g
s
.651 .757 .927 r
.55908 .41338 m .56936 .40986 L .56666 .4066 L p F P
0 g
s
.651 .757 .927 r
.7384 .40625 m .72778 .40979 L .73018 .41303 L p F P
0 g
s
.651 .757 .927 r
.73018 .41303 m .74078 .4095 L .7384 .40625 L p F P
0 g
s
.651 .757 .927 r
.42093 .40631 m .41093 .40984 L .41389 .41309 L p F P
0 g
s
.651 .757 .927 r
.41389 .41309 m .42388 .40958 L .42093 .40631 L p F P
0 g
s
.651 .757 .927 r
.57967 .40633 m .56936 .40986 L .57204 .41311 L p F P
0 g
s
.651 .757 .927 r
.57204 .41311 m .58234 .40959 L .57967 .40633 L p F P
0 g
s
.651 .757 .927 r
.75143 .40596 m .74078 .4095 L .74316 .41275 L p F P
0 g
s
.651 .757 .927 r
.74316 .41275 m .75379 .40922 L .75143 .40596 L p F P
0 g
s
.651 .757 .927 r
.43392 .40605 m .42388 .40958 L .42682 .41282 L p F P
0 g
s
.651 .757 .927 r
.42682 .41282 m .43684 .40931 L .43392 .40605 L p F P
0 g
s
.651 .757 .927 r
.59267 .40605 m .58234 .40959 L .585 .41283 L p F P
0 g
s
.651 .757 .927 r
.585 .41283 m .59532 .40931 L .59267 .40605 L p F P
0 g
s
.651 .757 .927 r
.76446 .40567 m .75379 .40922 L .75615 .41247 L p F P
0 g
s
.651 .757 .927 r
.75615 .41247 m .7668 .40893 L .76446 .40567 L p F P
0 g
s
.651 .757 .927 r
.4469 .40578 m .43684 .40931 L .43976 .41256 L p F P
0 g
s
.651 .757 .927 r
.43976 .41256 m .44981 .40904 L .4469 .40578 L p F P
0 g
s
.651 .757 .927 r
.60568 .40578 m .59532 .40931 L .59796 .41256 L p F P
0 g
s
.651 .757 .927 r
.59796 .41256 m .60831 .40904 L .60568 .40578 L p F P
0 g
s
.651 .757 .927 r
.6187 .4055 m .60831 .40904 L .61092 .41229 L p F P
0 g
s
.651 .757 .927 r
.61092 .41229 m .6213 .40876 L .6187 .4055 L p F P
0 g
s
.651 .757 .927 r
.45989 .40551 m .44981 .40904 L .4527 .41229 L p F P
0 g
s
.651 .757 .927 r
.4527 .41229 m .46278 .40877 L .45989 .40551 L p F P
0 g
s
.651 .757 .927 r
.63172 .40522 m .6213 .40876 L .62389 .41201 L p F P
0 g
s
.651 .757 .927 r
.62389 .41201 m .6343 .40849 L .63172 .40522 L p F P
0 g
s
.651 .757 .927 r
.47289 .40524 m .46278 .40877 L .46565 .41202 L p F P
0 g
s
.651 .757 .927 r
.46565 .41202 m .47575 .4085 L .47289 .40524 L p F P
0 g
s
.651 .757 .927 r
.64474 .40495 m .6343 .40849 L .63687 .41174 L p F P
0 g
s
.651 .757 .927 r
.63687 .41174 m .6473 .40821 L .64474 .40495 L p F P
0 g
s
.651 .757 .927 r
.48589 .40497 m .47575 .4085 L .4786 .41175 L p F P
0 g
s
.651 .757 .927 r
.4786 .41175 m .48873 .40823 L .48589 .40497 L p F P
0 g
s
.651 .757 .927 r
.65777 .40467 m .6473 .40821 L .64984 .41146 L p F P
0 g
s
.651 .757 .927 r
.64984 .41146 m .6603 .40793 L .65777 .40467 L p F P
0 g
s
.651 .757 .927 r
.49889 .4047 m .48873 .40823 L .49155 .41149 L p F P
0 g
s
.651 .757 .927 r
.49155 .41149 m .50171 .40796 L .49889 .4047 L p F P
0 g
s
.651 .757 .927 r
.6708 .40439 m .6603 .40793 L .66282 .41119 L p F P
0 g
s
.651 .757 .927 r
.66282 .41119 m .67331 .40765 L .6708 .40439 L p F P
0 g
s
.651 .757 .927 r
.5119 .40443 m .50171 .40796 L .50451 .41122 L p F P
0 g
s
.651 .757 .927 r
.50451 .41122 m .51469 .40769 L .5119 .40443 L p F P
0 g
s
.651 .757 .927 r
.68383 .40411 m .67331 .40765 L .67581 .41091 L p F P
0 g
s
.651 .757 .927 r
.67581 .41091 m .68632 .40738 L .68383 .40411 L p F P
0 g
s
.651 .757 .927 r
.52491 .40415 m .51469 .40769 L .51747 .41095 L p F P
0 g
s
.651 .757 .927 r
.51747 .41095 m .52768 .40742 L .52491 .40415 L p F P
0 g
s
.651 .757 .927 r
.69687 .40383 m .68632 .40738 L .6888 .41063 L p F P
0 g
s
.651 .757 .927 r
.6888 .41063 m .69933 .40709 L .69687 .40383 L p F P
0 g
s
.651 .757 .927 r
.37898 .40384 m .36904 .40738 L .37208 .41064 L p F P
0 g
s
.651 .757 .927 r
.37208 .41064 m .38201 .40711 L .37898 .40384 L p F P
0 g
s
.651 .757 .927 r
.53792 .40388 m .52768 .40742 L .53044 .41068 L p F P
0 g
s
.651 .757 .927 r
.53044 .41068 m .54067 .40715 L .53792 .40388 L p F P
0 g
s
.651 .757 .927 r
.70991 .40354 m .69933 .40709 L .70179 .41035 L p F P
0 g
s
.651 .757 .927 r
.70179 .41035 m .71235 .40681 L .70991 .40354 L p F P
0 g
s
.651 .757 .927 r
.39197 .40358 m .38201 .40711 L .38502 .41037 L p F P
0 g
s
.651 .757 .927 r
.38502 .41037 m .39498 .40685 L .39197 .40358 L p F P
0 g
s
.651 .757 .927 r
.55094 .40361 m .54067 .40715 L .54341 .4104 L p F P
0 g
s
.651 .757 .927 r
.54341 .4104 m .55366 .40688 L .55094 .40361 L p F P
0 g
s
.651 .757 .927 r
.72295 .40326 m .71235 .40681 L .71478 .41007 L p F P
0 g
s
.651 .757 .927 r
.71478 .41007 m .72537 .40653 L .72295 .40326 L p F P
0 g
s
.651 .757 .927 r
.40497 .40331 m .39498 .40685 L .39797 .41011 L p F P
0 g
s
.651 .757 .927 r
.39797 .41011 m .40795 .40658 L .40497 .40331 L p F P
0 g
s
.651 .757 .927 r
.56396 .40333 m .55366 .40688 L .55638 .41013 L p F P
0 g
s
.651 .757 .927 r
.55638 .41013 m .56666 .4066 L .56396 .40333 L p F P
0 g
s
.651 .757 .927 r
.736 .40297 m .72537 .40653 L .72778 .40979 L p F P
0 g
s
.651 .757 .927 r
.72778 .40979 m .7384 .40625 L .736 .40297 L p F P
0 g
s
.651 .757 .927 r
.41797 .40304 m .40795 .40658 L .41093 .40984 L p F P
0 g
s
.651 .757 .927 r
.41093 .40984 m .42093 .40631 L .41797 .40304 L p F P
0 g
s
.651 .757 .927 r
.57699 .40306 m .56666 .4066 L .56936 .40986 L p F P
0 g
s
.651 .757 .927 r
.56936 .40986 m .57967 .40633 L .57699 .40306 L p F P
0 g
s
.651 .757 .927 r
.74905 .40269 m .7384 .40625 L .74078 .4095 L p F P
0 g
s
.651 .757 .927 r
.74078 .4095 m .75143 .40596 L .74905 .40269 L p F P
0 g
s
.651 .757 .927 r
.43098 .40277 m .42093 .40631 L .42388 .40958 L p F P
0 g
s
.651 .757 .927 r
.42388 .40958 m .43392 .40605 L .43098 .40277 L p F P
0 g
s
.651 .757 .927 r
.59002 .40278 m .57967 .40633 L .58234 .40959 L p F P
0 g
s
.651 .757 .927 r
.58234 .40959 m .59267 .40605 L .59002 .40278 L p F P
0 g
s
.651 .757 .927 r
.76211 .4024 m .75143 .40596 L .75379 .40922 L p F P
0 g
s
.651 .757 .927 r
.75379 .40922 m .76446 .40567 L .76211 .4024 L p F P
0 g
s
.651 .757 .927 r
.44399 .4025 m .43392 .40605 L .43684 .40931 L p F P
0 g
s
.651 .757 .927 r
.43684 .40931 m .4469 .40578 L .44399 .4025 L p F P
0 g
s
.651 .757 .927 r
.60305 .4025 m .59267 .40605 L .59532 .40931 L p F P
0 g
s
.651 .757 .927 r
.59532 .40931 m .60568 .40578 L .60305 .4025 L p F P
0 g
s
.651 .757 .927 r
.61609 .40223 m .60568 .40578 L .60831 .40904 L p F P
0 g
s
.651 .757 .927 r
.60831 .40904 m .6187 .4055 L .61609 .40223 L p F P
0 g
s
.651 .757 .927 r
.457 .40223 m .4469 .40578 L .44981 .40904 L p F P
0 g
s
.651 .757 .927 r
.44981 .40904 m .45989 .40551 L .457 .40223 L p F P
0 g
s
.651 .757 .927 r
.62913 .40195 m .6187 .4055 L .6213 .40876 L p F P
0 g
s
.651 .757 .927 r
.6213 .40876 m .63172 .40522 L .62913 .40195 L p F P
0 g
s
.651 .757 .927 r
.47002 .40196 m .45989 .40551 L .46278 .40877 L p F P
0 g
s
.651 .757 .927 r
.46278 .40877 m .47289 .40524 L .47002 .40196 L p F P
0 g
s
.651 .757 .927 r
.64217 .40167 m .63172 .40522 L .6343 .40849 L p F P
0 g
s
.651 .757 .927 r
.6343 .40849 m .64474 .40495 L .64217 .40167 L p F P
0 g
s
.651 .757 .927 r
.48304 .40169 m .47289 .40524 L .47575 .4085 L p F P
0 g
s
.651 .757 .927 r
.47575 .4085 m .48589 .40497 L .48304 .40169 L p F P
0 g
s
.651 .757 .927 r
.65522 .40139 m .64474 .40495 L .6473 .40821 L p F P
0 g
s
.651 .757 .927 r
.6473 .40821 m .65777 .40467 L .65522 .40139 L p F P
0 g
s
.651 .757 .927 r
.49607 .40142 m .48589 .40497 L .48873 .40823 L p F P
0 g
s
.651 .757 .927 r
.48873 .40823 m .49889 .4047 L .49607 .40142 L p F P
0 g
s
.651 .757 .927 r
.66828 .40111 m .65777 .40467 L .6603 .40793 L p F P
0 g
s
.651 .757 .927 r
.6603 .40793 m .6708 .40439 L .66828 .40111 L p F P
0 g
s
.651 .757 .927 r
.50909 .40115 m .49889 .4047 L .50171 .40796 L p F P
0 g
s
.651 .757 .927 r
.50171 .40796 m .5119 .40443 L .50909 .40115 L p F P
0 g
s
.651 .757 .927 r
.68133 .40083 m .6708 .40439 L .67331 .40765 L p F P
0 g
s
.651 .757 .927 r
.67331 .40765 m .68383 .40411 L .68133 .40083 L p F P
0 g
s
.651 .757 .927 r
.52213 .40087 m .5119 .40443 L .51469 .40769 L p F P
0 g
s
.651 .757 .927 r
.51469 .40769 m .52491 .40415 L .52213 .40087 L p F P
0 g
s
.651 .757 .927 r
.69439 .40055 m .68383 .40411 L .68632 .40738 L p F P
0 g
s
.651 .757 .927 r
.68632 .40738 m .69687 .40383 L .69439 .40055 L p F P
0 g
s
.651 .757 .927 r
.53516 .4006 m .52491 .40415 L .52768 .40742 L p F P
0 g
s
.651 .757 .927 r
.52768 .40742 m .53792 .40388 L .53516 .4006 L p F P
0 g
s
.651 .757 .927 r
.70746 .40026 m .69687 .40383 L .69933 .40709 L p F P
0 g
s
.651 .757 .927 r
.69933 .40709 m .70991 .40354 L .70746 .40026 L p F P
0 g
s
.651 .757 .927 r
.38895 .40029 m .37898 .40384 L .38201 .40711 L p F P
0 g
s
.651 .757 .927 r
.38201 .40711 m .39197 .40358 L .38895 .40029 L p F P
0 g
s
.651 .757 .927 r
.54821 .40033 m .53792 .40388 L .54067 .40715 L p F P
0 g
s
.651 .757 .927 r
.54067 .40715 m .55094 .40361 L .54821 .40033 L p F P
0 g
s
.651 .757 .927 r
.72052 .39998 m .70991 .40354 L .71235 .40681 L p F P
0 g
s
.651 .757 .927 r
.71235 .40681 m .72295 .40326 L .72052 .39998 L p F P
0 g
s
.651 .757 .927 r
.40197 .40003 m .39197 .40358 L .39498 .40685 L p F P
0 g
s
.651 .757 .927 r
.39498 .40685 m .40497 .40331 L .40197 .40003 L p F P
0 g
s
.651 .757 .927 r
.56125 .40005 m .55094 .40361 L .55366 .40688 L p F P
0 g
s
.651 .757 .927 r
.55366 .40688 m .56396 .40333 L .56125 .40005 L p F P
0 g
s
.651 .757 .927 r
.73359 .39969 m .72295 .40326 L .72537 .40653 L p F P
0 g
s
.651 .757 .927 r
.72537 .40653 m .736 .40297 L .73359 .39969 L p F P
0 g
s
.651 .757 .927 r
.415 .39976 m .40497 .40331 L .40795 .40658 L p F P
0 g
s
.651 .757 .927 r
.40795 .40658 m .41797 .40304 L .415 .39976 L p F P
0 g
s
.651 .757 .927 r
.5743 .39977 m .56396 .40333 L .56666 .4066 L p F P
0 g
s
.651 .757 .927 r
.56666 .4066 m .57699 .40306 L .5743 .39977 L p F P
0 g
s
.651 .757 .927 r
.74667 .3994 m .736 .40297 L .7384 .40625 L p F P
0 g
s
.651 .757 .927 r
.7384 .40625 m .74905 .40269 L .74667 .3994 L p F P
0 g
s
.651 .757 .927 r
.42803 .39949 m .41797 .40304 L .42093 .40631 L p F P
0 g
s
.651 .757 .927 r
.42093 .40631 m .43098 .40277 L .42803 .39949 L p F P
0 g
s
.651 .757 .927 r
.58735 .3995 m .57699 .40306 L .57967 .40633 L p F P
0 g
s
.651 .757 .927 r
.57967 .40633 m .59002 .40278 L .58735 .3995 L p F P
0 g
s
.651 .757 .927 r
.75975 .39911 m .74905 .40269 L .75143 .40596 L p F P
0 g
s
.651 .757 .927 r
.75143 .40596 m .76211 .4024 L .75975 .39911 L p F P
0 g
s
.651 .757 .927 r
.44106 .39922 m .43098 .40277 L .43392 .40605 L p F P
0 g
s
.651 .757 .927 r
.43392 .40605 m .44399 .4025 L .44106 .39922 L p F P
0 g
s
.651 .757 .927 r
.60041 .39922 m .59002 .40278 L .59267 .40605 L p F P
0 g
s
.651 .757 .927 r
.59267 .40605 m .60305 .4025 L .60041 .39922 L p F P
0 g
s
.651 .757 .927 r
.61347 .39894 m .60305 .4025 L .60568 .40578 L p F P
0 g
s
.651 .757 .927 r
.60568 .40578 m .61609 .40223 L .61347 .39894 L p F P
0 g
s
.651 .757 .927 r
.4541 .39895 m .44399 .4025 L .4469 .40578 L p F P
0 g
s
.651 .757 .927 r
.4469 .40578 m .457 .40223 L .4541 .39895 L p F P
0 g
s
.651 .757 .927 r
.62653 .39866 m .61609 .40223 L .6187 .4055 L p F P
0 g
s
.651 .757 .927 r
.6187 .4055 m .62913 .40195 L .62653 .39866 L p F P
0 g
s
.651 .757 .927 r
.46714 .39868 m .457 .40223 L .45989 .40551 L p F P
0 g
s
.651 .757 .927 r
.45989 .40551 m .47002 .40196 L .46714 .39868 L p F P
0 g
s
.651 .757 .927 r
.6396 .39838 m .62913 .40195 L .63172 .40522 L p F P
0 g
s
.651 .757 .927 r
.63172 .40522 m .64217 .40167 L .6396 .39838 L p F P
0 g
s
.651 .757 .927 r
.48018 .3984 m .47002 .40196 L .47289 .40524 L p F P
0 g
s
.651 .757 .927 r
.47289 .40524 m .48304 .40169 L .48018 .3984 L p F P
0 g
s
.651 .757 .927 r
.65267 .3981 m .64217 .40167 L .64474 .40495 L p F P
0 g
s
.651 .757 .927 r
.64474 .40495 m .65522 .40139 L .65267 .3981 L p F P
0 g
s
.651 .757 .927 r
.49323 .39813 m .48304 .40169 L .48589 .40497 L p F P
0 g
s
.651 .757 .927 r
.48589 .40497 m .49607 .40142 L .49323 .39813 L p F P
0 g
s
.651 .757 .927 r
.66575 .39782 m .65522 .40139 L .65777 .40467 L p F P
0 g
s
.651 .757 .927 r
.65777 .40467 m .66828 .40111 L .66575 .39782 L p F P
0 g
s
.651 .757 .927 r
.50628 .39786 m .49607 .40142 L .49889 .4047 L p F P
0 g
s
.651 .757 .927 r
.49889 .4047 m .50909 .40115 L .50628 .39786 L p F P
0 g
s
.651 .757 .927 r
.67883 .39754 m .66828 .40111 L .6708 .40439 L p F P
0 g
s
.651 .757 .927 r
.6708 .40439 m .68133 .40083 L .67883 .39754 L p F P
0 g
s
.651 .757 .927 r
.51934 .39758 m .50909 .40115 L .5119 .40443 L p F P
0 g
s
.651 .757 .927 r
.5119 .40443 m .52213 .40087 L .51934 .39758 L p F P
0 g
s
.651 .757 .927 r
.69191 .39726 m .68133 .40083 L .68383 .40411 L p F P
0 g
s
.651 .757 .927 r
.68383 .40411 m .69439 .40055 L .69191 .39726 L p F P
0 g
s
.651 .757 .927 r
.5324 .39731 m .52213 .40087 L .52491 .40415 L p F P
0 g
s
.651 .757 .927 r
.52491 .40415 m .53516 .4006 L .5324 .39731 L p F P
0 g
s
.651 .757 .927 r
.705 .39697 m .69439 .40055 L .69687 .40383 L p F P
0 g
s
.651 .757 .927 r
.69687 .40383 m .70746 .40026 L .705 .39697 L p F P
0 g
s
.651 .757 .927 r
.54546 .39703 m .53516 .4006 L .53792 .40388 L p F P
0 g
s
.651 .757 .927 r
.53792 .40388 m .54821 .40033 L .54546 .39703 L p F P
0 g
s
.651 .757 .927 r
.71809 .39668 m .70746 .40026 L .70991 .40354 L p F P
0 g
s
.651 .757 .927 r
.70991 .40354 m .72052 .39998 L .71809 .39668 L p F P
0 g
s
.651 .757 .927 r
.39897 .39673 m .38895 .40029 L .39197 .40358 L p F P
0 g
s
.651 .757 .927 r
.39197 .40358 m .40197 .40003 L .39897 .39673 L p F P
0 g
s
.651 .757 .927 r
.55853 .39676 m .54821 .40033 L .55094 .40361 L p F P
0 g
s
.651 .757 .927 r
.55094 .40361 m .56125 .40005 L .55853 .39676 L p F P
0 g
s
.651 .757 .927 r
.73118 .3964 m .72052 .39998 L .72295 .40326 L p F P
0 g
s
.651 .757 .927 r
.72295 .40326 m .73359 .39969 L .73118 .3964 L p F P
0 g
s
.651 .757 .927 r
.41202 .39646 m .40197 .40003 L .40497 .40331 L p F P
0 g
s
.651 .757 .927 r
.40497 .40331 m .415 .39976 L .41202 .39646 L p F P
0 g
s
.651 .757 .927 r
.5716 .39648 m .56125 .40005 L .56396 .40333 L p F P
0 g
s
.651 .757 .927 r
.56396 .40333 m .5743 .39977 L .5716 .39648 L p F P
0 g
s
.651 .757 .927 r
.74428 .39611 m .73359 .39969 L .736 .40297 L p F P
0 g
s
.651 .757 .927 r
.736 .40297 m .74667 .3994 L .74428 .39611 L p F P
0 g
s
.651 .757 .927 r
.42507 .39619 m .415 .39976 L .41797 .40304 L p F P
0 g
s
.651 .757 .927 r
.41797 .40304 m .42803 .39949 L .42507 .39619 L p F P
0 g
s
.651 .757 .927 r
.58468 .3962 m .5743 .39977 L .57699 .40306 L p F P
0 g
s
.651 .757 .927 r
.57699 .40306 m .58735 .3995 L .58468 .3962 L p F P
0 g
s
.651 .757 .927 r
.75738 .39582 m .74667 .3994 L .74905 .40269 L p F P
0 g
s
.651 .757 .927 r
.74905 .40269 m .75975 .39911 L .75738 .39582 L p F P
0 g
s
.651 .757 .927 r
.43812 .39592 m .42803 .39949 L .43098 .40277 L p F P
0 g
s
.651 .757 .927 r
.43098 .40277 m .44106 .39922 L .43812 .39592 L p F P
0 g
s
.651 .757 .927 r
.59776 .39592 m .58735 .3995 L .59002 .40278 L p F P
0 g
s
.651 .757 .927 r
.59002 .40278 m .60041 .39922 L .59776 .39592 L p F P
0 g
s
.651 .757 .927 r
.45118 .39565 m .44106 .39922 L .44399 .4025 L p F P
0 g
s
.651 .757 .927 r
.44399 .4025 m .4541 .39895 L .45118 .39565 L p F P
0 g
s
.651 .757 .927 r
.61084 .39564 m .60041 .39922 L .60305 .4025 L p F P
0 g
s
.651 .757 .927 r
.60305 .4025 m .61347 .39894 L .61084 .39564 L p F P
0 g
s
.651 .757 .927 r
.62393 .39536 m .61347 .39894 L .61609 .40223 L p F P
0 g
s
.651 .757 .927 r
.61609 .40223 m .62653 .39866 L .62393 .39536 L p F P
0 g
s
.651 .757 .927 r
.46425 .39538 m .4541 .39895 L .457 .40223 L p F P
0 g
s
.651 .757 .927 r
.457 .40223 m .46714 .39868 L .46425 .39538 L p F P
0 g
s
.651 .757 .927 r
.63702 .39508 m .62653 .39866 L .62913 .40195 L p F P
0 g
s
.651 .757 .927 r
.62913 .40195 m .6396 .39838 L .63702 .39508 L p F P
0 g
s
.651 .757 .927 r
.47731 .3951 m .46714 .39868 L .47002 .40196 L p F P
0 g
s
.651 .757 .927 r
.47002 .40196 m .48018 .3984 L .47731 .3951 L p F P
0 g
s
.651 .757 .927 r
.65011 .3948 m .6396 .39838 L .64217 .40167 L p F P
0 g
s
.651 .757 .927 r
.64217 .40167 m .65267 .3981 L .65011 .3948 L p F P
0 g
s
.651 .757 .927 r
.49038 .39483 m .48018 .3984 L .48304 .40169 L p F P
0 g
s
.651 .757 .927 r
.48304 .40169 m .49323 .39813 L .49038 .39483 L p F P
0 g
s
.651 .757 .927 r
.66321 .39452 m .65267 .3981 L .65522 .40139 L p F P
0 g
s
.651 .757 .927 r
.65522 .40139 m .66575 .39782 L .66321 .39452 L p F P
0 g
s
.651 .757 .927 r
.50346 .39455 m .49323 .39813 L .49607 .40142 L p F P
0 g
s
.651 .757 .927 r
.49607 .40142 m .50628 .39786 L .50346 .39455 L p F P
0 g
s
.651 .757 .927 r
.67631 .39424 m .66575 .39782 L .66828 .40111 L p F P
0 g
s
.651 .757 .927 r
.66828 .40111 m .67883 .39754 L .67631 .39424 L p F P
0 g
s
.651 .757 .927 r
.51654 .39428 m .50628 .39786 L .50909 .40115 L p F P
0 g
s
.651 .757 .927 r
.50909 .40115 m .51934 .39758 L .51654 .39428 L p F P
0 g
s
.651 .757 .927 r
.68942 .39395 m .67883 .39754 L .68133 .40083 L p F P
0 g
s
.651 .757 .927 r
.68133 .40083 m .69191 .39726 L .68942 .39395 L p F P
0 g
s
.651 .757 .927 r
.52962 .394 m .51934 .39758 L .52213 .40087 L p F P
0 g
s
.651 .757 .927 r
.52213 .40087 m .5324 .39731 L .52962 .394 L p F P
0 g
s
.651 .757 .927 r
.70253 .39367 m .69191 .39726 L .69439 .40055 L p F P
0 g
s
.651 .757 .927 r
.69439 .40055 m .705 .39697 L .70253 .39367 L p F P
0 g
s
.651 .757 .927 r
.54271 .39373 m .5324 .39731 L .53516 .4006 L p F P
0 g
s
.651 .757 .927 r
.53516 .4006 m .54546 .39703 L .54271 .39373 L p F P
0 g
s
.651 .757 .927 r
.71564 .39338 m .705 .39697 L .70746 .40026 L p F P
0 g
s
.651 .757 .927 r
.70746 .40026 m .71809 .39668 L .71564 .39338 L p F P
0 g
s
.651 .757 .927 r
.5558 .39345 m .54546 .39703 L .54821 .40033 L p F P
0 g
s
.651 .757 .927 r
.54821 .40033 m .55853 .39676 L .5558 .39345 L p F P
0 g
s
.651 .757 .927 r
.72876 .39309 m .71809 .39668 L .72052 .39998 L p F P
0 g
s
.651 .757 .927 r
.72052 .39998 m .73118 .3964 L .72876 .39309 L p F P
0 g
s
.651 .757 .927 r
.40902 .39315 m .39897 .39673 L .40197 .40003 L p F P
0 g
s
.651 .757 .927 r
.40197 .40003 m .41202 .39646 L .40902 .39315 L p F P
0 g
s
.651 .757 .927 r
.56889 .39317 m .55853 .39676 L .56125 .40005 L p F P
0 g
s
.651 .757 .927 r
.56125 .40005 m .5716 .39648 L .56889 .39317 L p F P
0 g
s
.651 .757 .927 r
.74188 .3928 m .73118 .3964 L .73359 .39969 L p F P
0 g
s
.651 .757 .927 r
.73359 .39969 m .74428 .39611 L .74188 .3928 L p F P
0 g
s
.651 .757 .927 r
.4221 .39288 m .41202 .39646 L .415 .39976 L p F P
0 g
s
.651 .757 .927 r
.415 .39976 m .42507 .39619 L .4221 .39288 L p F P
0 g
s
.651 .757 .927 r
.58199 .39289 m .5716 .39648 L .5743 .39977 L p F P
0 g
s
.651 .757 .927 r
.5743 .39977 m .58468 .3962 L .58199 .39289 L p F P
0 g
s
.651 .757 .927 r
.755 .39251 m .74428 .39611 L .74667 .3994 L p F P
0 g
s
.651 .757 .927 r
.74667 .3994 m .75738 .39582 L .755 .39251 L p F P
0 g
s
.651 .757 .927 r
.43518 .39261 m .42507 .39619 L .42803 .39949 L p F P
0 g
s
.651 .757 .927 r
.42803 .39949 m .43812 .39592 L .43518 .39261 L p F P
0 g
s
.651 .757 .927 r
.59509 .39262 m .58468 .3962 L .58735 .3995 L p F P
0 g
s
.651 .757 .927 r
.58735 .3995 m .59776 .39592 L .59509 .39262 L p F P
0 g
s
.651 .757 .927 r
.44826 .39234 m .43812 .39592 L .44106 .39922 L p F P
0 g
s
.651 .757 .927 r
.44106 .39922 m .45118 .39565 L .44826 .39234 L p F P
0 g
s
.651 .757 .927 r
.6082 .39234 m .59776 .39592 L .60041 .39922 L p F P
0 g
s
.651 .757 .927 r
.60041 .39922 m .61084 .39564 L .6082 .39234 L p F P
0 g
s
.651 .757 .927 r
.62131 .39205 m .61084 .39564 L .61347 .39894 L p F P
0 g
s
.651 .757 .927 r
.61347 .39894 m .62393 .39536 L .62131 .39205 L p F P
0 g
s
.651 .757 .927 r
.46135 .39206 m .45118 .39565 L .4541 .39895 L p F P
0 g
s
.651 .757 .927 r
.4541 .39895 m .46425 .39538 L .46135 .39206 L p F P
0 g
s
.651 .757 .927 r
.63442 .39177 m .62393 .39536 L .62653 .39866 L p F P
0 g
s
.651 .757 .927 r
.62653 .39866 m .63702 .39508 L .63442 .39177 L p F P
0 g
s
.651 .757 .927 r
.47444 .39179 m .46425 .39538 L .46714 .39868 L p F P
0 g
s
.651 .757 .927 r
.46714 .39868 m .47731 .3951 L .47444 .39179 L p F P
0 g
s
.651 .757 .927 r
.64754 .39149 m .63702 .39508 L .6396 .39838 L p F P
0 g
s
.651 .757 .927 r
.6396 .39838 m .65011 .3948 L .64754 .39149 L p F P
0 g
s
.651 .757 .927 r
.48753 .39152 m .47731 .3951 L .48018 .3984 L p F P
0 g
s
.651 .757 .927 r
.48018 .3984 m .49038 .39483 L .48753 .39152 L p F P
0 g
s
.651 .757 .927 r
.66066 .39121 m .65011 .3948 L .65267 .3981 L p F P
0 g
s
.651 .757 .927 r
.65267 .3981 m .66321 .39452 L .66066 .39121 L p F P
0 g
s
.651 .757 .927 r
.50063 .39124 m .49038 .39483 L .49323 .39813 L p F P
0 g
s
.651 .757 .927 r
.49323 .39813 m .50346 .39455 L .50063 .39124 L p F P
0 g
s
.651 .757 .927 r
.67379 .39092 m .66321 .39452 L .66575 .39782 L p F P
0 g
s
.651 .757 .927 r
.66575 .39782 m .67631 .39424 L .67379 .39092 L p F P
0 g
s
.651 .757 .927 r
.51373 .39096 m .50346 .39455 L .50628 .39786 L p F P
0 g
s
.651 .757 .927 r
.50628 .39786 m .51654 .39428 L .51373 .39096 L p F P
0 g
s
.651 .757 .927 r
.68692 .39064 m .67631 .39424 L .67883 .39754 L p F P
0 g
s
.651 .757 .927 r
.67883 .39754 m .68942 .39395 L .68692 .39064 L p F P
0 g
s
.651 .757 .927 r
.52684 .39069 m .51654 .39428 L .51934 .39758 L p F P
0 g
s
.651 .757 .927 r
.51934 .39758 m .52962 .394 L .52684 .39069 L p F P
0 g
s
.651 .757 .927 r
.70005 .39035 m .68942 .39395 L .69191 .39726 L p F P
0 g
s
.651 .757 .927 r
.69191 .39726 m .70253 .39367 L .70005 .39035 L p F P
0 g
s
.651 .757 .927 r
.53994 .39041 m .52962 .394 L .5324 .39731 L p F P
0 g
s
.651 .757 .927 r
.5324 .39731 m .54271 .39373 L .53994 .39041 L p F P
0 g
s
.651 .757 .927 r
.71319 .39006 m .70253 .39367 L .705 .39697 L p F P
0 g
s
.651 .757 .927 r
.705 .39697 m .71564 .39338 L .71319 .39006 L p F P
0 g
s
.651 .757 .927 r
.55306 .39013 m .54271 .39373 L .54546 .39703 L p F P
0 g
s
.651 .757 .927 r
.54546 .39703 m .5558 .39345 L .55306 .39013 L p F P
0 g
s
.651 .757 .927 r
.72633 .38977 m .71564 .39338 L .71809 .39668 L p F P
0 g
s
.651 .757 .927 r
.71809 .39668 m .72876 .39309 L .72633 .38977 L p F P
0 g
s
.651 .757 .927 r
.56618 .38985 m .5558 .39345 L .55853 .39676 L p F P
0 g
s
.651 .757 .927 r
.55853 .39676 m .56889 .39317 L .56618 .38985 L p F P
0 g
s
.651 .757 .927 r
.73947 .38948 m .72876 .39309 L .73118 .3964 L p F P
0 g
s
.651 .757 .927 r
.73118 .3964 m .74188 .3928 L .73947 .38948 L p F P
0 g
s
.651 .757 .927 r
.41912 .38956 m .40902 .39315 L .41202 .39646 L p F P
0 g
s
.651 .757 .927 r
.41202 .39646 m .4221 .39288 L .41912 .38956 L p F P
0 g
s
.651 .757 .927 r
.5793 .38957 m .56889 .39317 L .5716 .39648 L p F P
0 g
s
.651 .757 .927 r
.5716 .39648 m .58199 .39289 L .5793 .38957 L p F P
0 g
s
.651 .757 .927 r
.75262 .38919 m .74188 .3928 L .74428 .39611 L p F P
0 g
s
.651 .757 .927 r
.74428 .39611 m .755 .39251 L .75262 .38919 L p F P
0 g
s
.651 .757 .927 r
.43222 .38929 m .4221 .39288 L .42507 .39619 L p F P
0 g
s
.651 .757 .927 r
.42507 .39619 m .43518 .39261 L .43222 .38929 L p F P
0 g
s
.651 .757 .927 r
.59242 .38929 m .58199 .39289 L .58468 .3962 L p F P
0 g
s
.651 .757 .927 r
.58468 .3962 m .59509 .39262 L .59242 .38929 L p F P
0 g
s
.651 .757 .927 r
.44532 .38901 m .43518 .39261 L .43812 .39592 L p F P
0 g
s
.651 .757 .927 r
.43812 .39592 m .44826 .39234 L .44532 .38901 L p F P
0 g
s
.651 .757 .927 r
.60555 .38901 m .59509 .39262 L .59776 .39592 L p F P
0 g
s
.651 .757 .927 r
.59776 .39592 m .6082 .39234 L .60555 .38901 L p F P
0 g
s
.651 .757 .927 r
.61869 .38873 m .6082 .39234 L .61084 .39564 L p F P
0 g
s
.651 .757 .927 r
.61084 .39564 m .62131 .39205 L .61869 .38873 L p F P
0 g
s
.651 .757 .927 r
.45843 .38874 m .44826 .39234 L .45118 .39565 L p F P
0 g
s
.651 .757 .927 r
.45118 .39565 m .46135 .39206 L .45843 .38874 L p F P
0 g
s
.651 .757 .927 r
.63182 .38845 m .62131 .39205 L .62393 .39536 L p F P
0 g
s
.651 .757 .927 r
.62393 .39536 m .63442 .39177 L .63182 .38845 L p F P
0 g
s
.651 .757 .927 r
.47155 .38846 m .46135 .39206 L .46425 .39538 L p F P
0 g
s
.651 .757 .927 r
.46425 .39538 m .47444 .39179 L .47155 .38846 L p F P
0 g
s
.651 .757 .927 r
.64496 .38816 m .63442 .39177 L .63702 .39508 L p F P
0 g
s
.651 .757 .927 r
.63702 .39508 m .64754 .39149 L .64496 .38816 L p F P
0 g
s
.651 .757 .927 r
.48466 .38819 m .47444 .39179 L .47731 .3951 L p F P
0 g
s
.651 .757 .927 r
.47731 .3951 m .48753 .39152 L .48466 .38819 L p F P
0 g
s
.651 .757 .927 r
.65811 .38788 m .64754 .39149 L .65011 .3948 L p F P
0 g
s
.651 .757 .927 r
.65011 .3948 m .66066 .39121 L .65811 .38788 L p F P
0 g
s
.651 .757 .927 r
.49778 .38791 m .48753 .39152 L .49038 .39483 L p F P
0 g
s
.651 .757 .927 r
.49038 .39483 m .50063 .39124 L .49778 .38791 L p F P
0 g
s
.651 .757 .927 r
.67126 .38759 m .66066 .39121 L .66321 .39452 L p F P
0 g
s
.651 .757 .927 r
.66321 .39452 m .67379 .39092 L .67126 .38759 L p F P
0 g
s
.651 .757 .927 r
.51091 .38764 m .50063 .39124 L .50346 .39455 L p F P
0 g
s
.651 .757 .927 r
.50346 .39455 m .51373 .39096 L .51091 .38764 L p F P
0 g
s
.651 .757 .927 r
.68441 .38731 m .67379 .39092 L .67631 .39424 L p F P
0 g
s
.651 .757 .927 r
.67631 .39424 m .68692 .39064 L .68441 .38731 L p F P
0 g
s
.651 .757 .927 r
.52404 .38736 m .51373 .39096 L .51654 .39428 L p F P
0 g
s
.651 .757 .927 r
.51654 .39428 m .52684 .39069 L .52404 .38736 L p F P
0 g
s
.651 .757 .927 r
.69756 .38702 m .68692 .39064 L .68942 .39395 L p F P
0 g
s
.651 .757 .927 r
.68942 .39395 m .70005 .39035 L .69756 .38702 L p F P
0 g
s
.651 .757 .927 r
.53717 .38708 m .52684 .39069 L .52962 .394 L p F P
0 g
s
.651 .757 .927 r
.52962 .394 m .53994 .39041 L .53717 .38708 L p F P
0 g
s
.651 .757 .927 r
.71072 .38673 m .70005 .39035 L .70253 .39367 L p F P
0 g
s
.651 .757 .927 r
.70253 .39367 m .71319 .39006 L .71072 .38673 L p F P
0 g
s
.651 .757 .927 r
.55031 .3868 m .53994 .39041 L .54271 .39373 L p F P
0 g
s
.651 .757 .927 r
.54271 .39373 m .55306 .39013 L .55031 .3868 L p F P
0 g
s
.651 .757 .927 r
.72389 .38644 m .71319 .39006 L .71564 .39338 L p F P
0 g
s
.651 .757 .927 r
.71564 .39338 m .72633 .38977 L .72389 .38644 L p F P
0 g
s
.651 .757 .927 r
.56345 .38652 m .55306 .39013 L .5558 .39345 L p F P
0 g
s
.651 .757 .927 r
.5558 .39345 m .56618 .38985 L .56345 .38652 L p F P
0 g
s
.651 .757 .927 r
.73705 .38615 m .72633 .38977 L .72876 .39309 L p F P
0 g
s
.651 .757 .927 r
.72876 .39309 m .73947 .38948 L .73705 .38615 L p F P
0 g
s
.651 .757 .927 r
.57659 .38624 m .56618 .38985 L .56889 .39317 L p F P
0 g
s
.651 .757 .927 r
.56889 .39317 m .5793 .38957 L .57659 .38624 L p F P
0 g
s
.652 .757 .927 r
.75023 .38585 m .73947 .38948 L .74188 .3928 L p F P
0 g
s
.652 .757 .927 r
.74188 .3928 m .75262 .38919 L .75023 .38585 L p F P
0 g
s
.651 .757 .927 r
.42925 .38595 m .41912 .38956 L .4221 .39288 L p F P
0 g
s
.651 .757 .927 r
.4221 .39288 m .43222 .38929 L .42925 .38595 L p F P
0 g
s
.651 .757 .927 r
.58974 .38596 m .5793 .38957 L .58199 .39289 L p F P
0 g
s
.651 .757 .927 r
.58199 .39289 m .59242 .38929 L .58974 .38596 L p F P
0 g
s
.651 .757 .927 r
.44238 .38568 m .43222 .38929 L .43518 .39261 L p F P
0 g
s
.651 .757 .927 r
.43518 .39261 m .44532 .38901 L .44238 .38568 L p F P
0 g
s
.651 .757 .927 r
.60289 .38568 m .59242 .38929 L .59509 .39262 L p F P
0 g
s
.651 .757 .927 r
.59509 .39262 m .60555 .38901 L .60289 .38568 L p F P
0 g
s
.651 .757 .927 r
.61605 .3854 m .60555 .38901 L .6082 .39234 L p F P
0 g
s
.651 .757 .927 r
.6082 .39234 m .61869 .38873 L .61605 .3854 L p F P
0 g
s
.651 .757 .927 r
.45551 .3854 m .44532 .38901 L .44826 .39234 L p F P
0 g
s
.651 .757 .927 r
.44826 .39234 m .45843 .38874 L .45551 .3854 L p F P
0 g
s
.651 .757 .927 r
.62921 .38511 m .61869 .38873 L .62131 .39205 L p F P
0 g
s
.651 .757 .927 r
.62131 .39205 m .63182 .38845 L .62921 .38511 L p F P
0 g
s
.651 .757 .927 r
.46865 .38513 m .45843 .38874 L .46135 .39206 L p F P
0 g
s
.651 .757 .927 r
.46135 .39206 m .47155 .38846 L .46865 .38513 L p F P
0 g
s
.651 .757 .927 r
.64237 .38483 m .63182 .38845 L .63442 .39177 L p F P
0 g
s
.651 .757 .927 r
.63442 .39177 m .64496 .38816 L .64237 .38483 L p F P
0 g
s
.651 .757 .927 r
.48179 .38485 m .47155 .38846 L .47444 .39179 L p F P
0 g
s
.651 .757 .927 r
.47444 .39179 m .48466 .38819 L .48179 .38485 L p F P
0 g
s
.651 .757 .927 r
.65554 .38454 m .64496 .38816 L .64754 .39149 L p F P
0 g
s
.651 .757 .927 r
.64754 .39149 m .65811 .38788 L .65554 .38454 L p F P
0 g
s
.651 .757 .927 r
.49493 .38457 m .48466 .38819 L .48753 .39152 L p F P
0 g
s
.651 .757 .927 r
.48753 .39152 m .49778 .38791 L .49493 .38457 L p F P
0 g
s
.651 .757 .927 r
.66871 .38426 m .65811 .38788 L .66066 .39121 L p F P
0 g
s
.651 .757 .927 r
.66066 .39121 m .67126 .38759 L .66871 .38426 L p F P
0 g
s
.651 .757 .927 r
.50808 .3843 m .49778 .38791 L .50063 .39124 L p F P
0 g
s
.651 .757 .927 r
.50063 .39124 m .51091 .38764 L .50808 .3843 L p F P
0 g
s
.651 .757 .927 r
.68189 .38397 m .67126 .38759 L .67379 .39092 L p F P
0 g
s
.651 .757 .927 r
.67379 .39092 m .68441 .38731 L .68189 .38397 L p F P
0 g
s
.651 .757 .927 r
.52123 .38402 m .51091 .38764 L .51373 .39096 L p F P
0 g
s
.651 .757 .927 r
.51373 .39096 m .52404 .38736 L .52123 .38402 L p F P
0 g
s
.651 .757 .927 r
.69507 .38368 m .68441 .38731 L .68692 .39064 L p F P
0 g
s
.651 .757 .927 r
.68692 .39064 m .69756 .38702 L .69507 .38368 L p F P
0 g
s
.651 .757 .927 r
.53439 .38374 m .52404 .38736 L .52684 .39069 L p F P
0 g
s
.651 .757 .927 r
.52684 .39069 m .53717 .38708 L .53439 .38374 L p F P
0 g
s
.651 .757 .927 r
.70825 .38339 m .69756 .38702 L .70005 .39035 L p F P
0 g
s
.651 .757 .927 r
.70005 .39035 m .71072 .38673 L .70825 .38339 L p F P
0 g
s
.651 .757 .927 r
.54755 .38346 m .53717 .38708 L .53994 .39041 L p F P
0 g
s
.651 .757 .927 r
.53994 .39041 m .55031 .3868 L .54755 .38346 L p F P
0 g
s
.651 .757 .927 r
.72144 .3831 m .71072 .38673 L .71319 .39006 L p F P
0 g
s
.651 .757 .927 r
.71319 .39006 m .72389 .38644 L .72144 .3831 L p F P
0 g
s
.651 .757 .927 r
.56071 .38318 m .55031 .3868 L .55306 .39013 L p F P
0 g
s
.651 .757 .927 r
.55306 .39013 m .56345 .38652 L .56071 .38318 L p F P
0 g
s
.651 .757 .927 r
.73463 .3828 m .72389 .38644 L .72633 .38977 L p F P
0 g
s
.651 .757 .927 r
.72633 .38977 m .73705 .38615 L .73463 .3828 L p F P
0 g
s
.651 .757 .927 r
.57388 .3829 m .56345 .38652 L .56618 .38985 L p F P
0 g
s
.651 .757 .927 r
.56618 .38985 m .57659 .38624 L .57388 .3829 L p F P
0 g
s
.652 .757 .927 r
.74782 .38251 m .73705 .38615 L .73947 .38948 L p F P
0 g
s
.652 .757 .927 r
.73947 .38948 m .75023 .38585 L .74782 .38251 L p F P
0 g
s
.651 .757 .927 r
.58705 .38262 m .57659 .38624 L .5793 .38957 L p F P
0 g
s
.651 .757 .927 r
.5793 .38957 m .58974 .38596 L .58705 .38262 L p F P
0 g
s
.651 .757 .927 r
.43942 .38233 m .42925 .38595 L .43222 .38929 L p F P
0 g
s
.651 .757 .927 r
.43222 .38929 m .44238 .38568 L .43942 .38233 L p F P
0 g
s
.651 .757 .927 r
.60023 .38233 m .58974 .38596 L .59242 .38929 L p F P
0 g
s
.651 .757 .927 r
.59242 .38929 m .60289 .38568 L .60023 .38233 L p F P
0 g
s
.651 .757 .927 r
.45258 .38205 m .44238 .38568 L .44532 .38901 L p F P
0 g
s
.651 .757 .927 r
.44532 .38901 m .45551 .3854 L .45258 .38205 L p F P
0 g
s
.651 .757 .927 r
.61341 .38205 m .60289 .38568 L .60555 .38901 L p F P
0 g
s
.651 .757 .927 r
.60555 .38901 m .61605 .3854 L .61341 .38205 L p F P
0 g
s
.651 .757 .927 r
.62659 .38176 m .61605 .3854 L .61869 .38873 L p F P
0 g
s
.651 .757 .927 r
.61869 .38873 m .62921 .38511 L .62659 .38176 L p F P
0 g
s
.651 .757 .927 r
.46574 .38178 m .45551 .3854 L .45843 .38874 L p F P
0 g
s
.651 .757 .927 r
.45843 .38874 m .46865 .38513 L .46574 .38178 L p F P
0 g
s
.651 .757 .927 r
.63978 .38148 m .62921 .38511 L .63182 .38845 L p F P
0 g
s
.651 .757 .927 r
.63182 .38845 m .64237 .38483 L .63978 .38148 L p F P
0 g
s
.651 .757 .927 r
.4789 .3815 m .46865 .38513 L .47155 .38846 L p F P
0 g
s
.651 .757 .927 r
.47155 .38846 m .48179 .38485 L .4789 .3815 L p F P
0 g
s
.651 .757 .927 r
.65297 .38119 m .64237 .38483 L .64496 .38816 L p F P
0 g
s
.651 .757 .927 r
.64496 .38816 m .65554 .38454 L .65297 .38119 L p F P
0 g
s
.651 .757 .927 r
.49207 .38122 m .48179 .38485 L .48466 .38819 L p F P
0 g
s
.651 .757 .927 r
.48466 .38819 m .49493 .38457 L .49207 .38122 L p F P
0 g
s
.651 .757 .927 r
.66616 .3809 m .65554 .38454 L .65811 .38788 L p F P
0 g
s
.651 .757 .927 r
.65811 .38788 m .66871 .38426 L .66616 .3809 L p F P
0 g
s
.651 .757 .927 r
.50524 .38094 m .49493 .38457 L .49778 .38791 L p F P
0 g
s
.651 .757 .927 r
.49778 .38791 m .50808 .3843 L .50524 .38094 L p F P
0 g
s
.651 .757 .927 r
.67936 .38061 m .66871 .38426 L .67126 .38759 L p F P
0 g
s
.651 .757 .927 r
.67126 .38759 m .68189 .38397 L .67936 .38061 L p F P
0 g
s
.651 .757 .927 r
.51842 .38067 m .50808 .3843 L .51091 .38764 L p F P
0 g
s
.651 .757 .927 r
.51091 .38764 m .52123 .38402 L .51842 .38067 L p F P
0 g
s
.651 .757 .927 r
.69256 .38032 m .68189 .38397 L .68441 .38731 L p F P
0 g
s
.651 .757 .927 r
.68441 .38731 m .69507 .38368 L .69256 .38032 L p F P
0 g
s
.651 .757 .927 r
.53159 .38039 m .52123 .38402 L .52404 .38736 L p F P
0 g
s
.651 .757 .927 r
.52404 .38736 m .53439 .38374 L .53159 .38039 L p F P
0 g
s
.651 .757 .927 r
.70577 .38003 m .69507 .38368 L .69756 .38702 L p F P
0 g
s
.651 .757 .927 r
.69756 .38702 m .70825 .38339 L .70577 .38003 L p F P
0 g
s
.651 .757 .927 r
.54478 .3801 m .53439 .38374 L .53717 .38708 L p F P
0 g
s
.651 .757 .927 r
.53717 .38708 m .54755 .38346 L .54478 .3801 L p F P
0 g
s
.651 .757 .927 r
.71898 .37974 m .70825 .38339 L .71072 .38673 L p F P
0 g
s
.651 .757 .927 r
.71072 .38673 m .72144 .3831 L .71898 .37974 L p F P
0 g
s
.651 .757 .927 r
.55797 .37982 m .54755 .38346 L .55031 .3868 L p F P
0 g
s
.651 .757 .927 r
.55031 .3868 m .56071 .38318 L .55797 .37982 L p F P
0 g
s
.651 .757 .927 r
.7322 .37945 m .72144 .3831 L .72389 .38644 L p F P
0 g
s
.651 .757 .927 r
.72389 .38644 m .73463 .3828 L .7322 .37945 L p F P
0 g
s
.651 .757 .927 r
.57116 .37954 m .56071 .38318 L .56345 .38652 L p F P
0 g
s
.651 .757 .927 r
.56345 .38652 m .57388 .3829 L .57116 .37954 L p F P
0 g
s
.652 .757 .927 r
.74541 .37915 m .73463 .3828 L .73705 .38615 L p F P
0 g
s
.652 .757 .927 r
.73705 .38615 m .74782 .38251 L .74541 .37915 L p F P
0 g
s
.651 .757 .927 r
.58435 .37926 m .57388 .3829 L .57659 .38624 L p F P
0 g
s
.651 .757 .927 r
.57659 .38624 m .58705 .38262 L .58435 .37926 L p F P
0 g
s
.651 .757 .927 r
.59755 .37897 m .58705 .38262 L .58974 .38596 L p F P
0 g
s
.651 .757 .927 r
.58974 .38596 m .60023 .38233 L .59755 .37897 L p F P
0 g
s
.651 .757 .927 r
.44964 .37869 m .43942 .38233 L .44238 .38568 L p F P
0 g
s
.651 .757 .927 r
.44238 .38568 m .45258 .38205 L .44964 .37869 L p F P
0 g
s
.651 .757 .927 r
.61075 .37869 m .60023 .38233 L .60289 .38568 L p F P
0 g
s
.651 .757 .927 r
.60289 .38568 m .61341 .38205 L .61075 .37869 L p F P
0 g
s
.651 .757 .927 r
.62396 .3784 m .61341 .38205 L .61605 .3854 L p F P
0 g
s
.651 .757 .927 r
.61605 .3854 m .62659 .38176 L .62396 .3784 L p F P
0 g
s
.651 .757 .927 r
.46282 .37842 m .45258 .38205 L .45551 .3854 L p F P
0 g
s
.651 .757 .927 r
.45551 .3854 m .46574 .38178 L .46282 .37842 L p F P
0 g
s
.651 .757 .927 r
.63717 .37812 m .62659 .38176 L .62921 .38511 L p F P
0 g
s
.651 .757 .927 r
.62921 .38511 m .63978 .38148 L .63717 .37812 L p F P
0 g
s
.651 .757 .927 r
.476 .37814 m .46574 .38178 L .46865 .38513 L p F P
0 g
s
.651 .757 .927 r
.46865 .38513 m .4789 .3815 L .476 .37814 L p F P
0 g
s
.651 .757 .927 r
.65039 .37783 m .63978 .38148 L .64237 .38483 L p F P
0 g
s
.651 .757 .927 r
.64237 .38483 m .65297 .38119 L .65039 .37783 L p F P
0 g
s
.651 .757 .927 r
.4892 .37786 m .4789 .3815 L .48179 .38485 L p F P
0 g
s
.651 .757 .927 r
.48179 .38485 m .49207 .38122 L .4892 .37786 L p F P
0 g
s
.651 .757 .927 r
.6636 .37754 m .65297 .38119 L .65554 .38454 L p F P
0 g
s
.651 .757 .927 r
.65554 .38454 m .66616 .3809 L .6636 .37754 L p F P
0 g
s
.651 .757 .927 r
.50239 .37758 m .49207 .38122 L .49493 .38457 L p F P
0 g
s
.651 .757 .927 r
.49493 .38457 m .50524 .38094 L .50239 .37758 L p F P
0 g
s
.651 .757 .927 r
.67683 .37725 m .66616 .3809 L .66871 .38426 L p F P
0 g
s
.651 .757 .927 r
.66871 .38426 m .67936 .38061 L .67683 .37725 L p F P
0 g
s
.651 .757 .927 r
.51559 .3773 m .50524 .38094 L .50808 .3843 L p F P
0 g
s
.651 .757 .927 r
.50808 .3843 m .51842 .38067 L .51559 .3773 L p F P
0 g
s
.651 .757 .927 r
.69005 .37696 m .67936 .38061 L .68189 .38397 L p F P
0 g
s
.651 .757 .927 r
.68189 .38397 m .69256 .38032 L .69005 .37696 L p F P
0 g
s
.651 .757 .927 r
.52879 .37702 m .51842 .38067 L .52123 .38402 L p F P
0 g
s
.651 .757 .927 r
.52123 .38402 m .53159 .38039 L .52879 .37702 L p F P
0 g
s
.651 .757 .927 r
.70328 .37667 m .69256 .38032 L .69507 .38368 L p F P
0 g
s
.651 .757 .927 r
.69507 .38368 m .70577 .38003 L .70328 .37667 L p F P
0 g
s
.651 .757 .927 r
.542 .37674 m .53159 .38039 L .53439 .38374 L p F P
0 g
s
.651 .757 .927 r
.53439 .38374 m .54478 .3801 L .542 .37674 L p F P
0 g
s
.651 .757 .927 r
.71652 .37637 m .70577 .38003 L .70825 .38339 L p F P
0 g
s
.651 .757 .927 r
.70825 .38339 m .71898 .37974 L .71652 .37637 L p F P
0 g
s
.651 .757 .927 r
.55521 .37646 m .54478 .3801 L .54755 .38346 L p F P
0 g
s
.651 .757 .927 r
.54755 .38346 m .55797 .37982 L .55521 .37646 L p F P
0 g
s
.651 .757 .927 r
.72975 .37608 m .71898 .37974 L .72144 .3831 L p F P
0 g
s
.651 .757 .927 r
.72144 .3831 m .7322 .37945 L .72975 .37608 L p F P
0 g
s
.651 .757 .927 r
.56842 .37617 m .55797 .37982 L .56071 .38318 L p F P
0 g
s
.651 .757 .927 r
.56071 .38318 m .57116 .37954 L .56842 .37617 L p F P
0 g
s
.652 .757 .927 r
.74299 .37578 m .7322 .37945 L .73463 .3828 L p F P
0 g
s
.652 .757 .927 r
.73463 .3828 m .74541 .37915 L .74299 .37578 L p F P
0 g
s
.651 .757 .927 r
.58164 .37589 m .57116 .37954 L .57388 .3829 L p F P
0 g
s
.651 .757 .927 r
.57388 .3829 m .58435 .37926 L .58164 .37589 L p F P
0 g
s
.651 .757 .927 r
.59486 .3756 m .58435 .37926 L .58705 .38262 L p F P
0 g
s
.651 .757 .927 r
.58705 .38262 m .59755 .37897 L .59486 .3756 L p F P
0 g
s
.651 .757 .927 r
.60809 .37532 m .59755 .37897 L .60023 .38233 L p F P
0 g
s
.651 .757 .927 r
.60023 .38233 m .61075 .37869 L .60809 .37532 L p F P
0 g
s
.651 .757 .927 r
.62132 .37503 m .61075 .37869 L .61341 .38205 L p F P
0 g
s
.651 .757 .927 r
.61341 .38205 m .62396 .3784 L .62132 .37503 L p F P
0 g
s
.651 .757 .927 r
.45989 .37504 m .44964 .37869 L .45258 .38205 L p F P
0 g
s
.651 .757 .927 r
.45258 .38205 m .46282 .37842 L .45989 .37504 L p F P
0 g
s
.651 .757 .927 r
.63455 .37474 m .62396 .3784 L .62659 .38176 L p F P
0 g
s
.651 .757 .927 r
.62659 .38176 m .63717 .37812 L .63455 .37474 L p F P
0 g
s
.651 .757 .927 r
.4731 .37476 m .46282 .37842 L .46574 .38178 L p F P
0 g
s
.651 .757 .927 r
.46574 .38178 m .476 .37814 L .4731 .37476 L p F P
0 g
s
.651 .757 .927 r
.64779 .37445 m .63717 .37812 L .63978 .38148 L p F P
0 g
s
.651 .757 .927 r
.63978 .38148 m .65039 .37783 L .64779 .37445 L p F P
0 g
s
.651 .757 .927 r
.48631 .37448 m .476 .37814 L .4789 .3815 L p F P
0 g
s
.651 .757 .927 r
.4789 .3815 m .4892 .37786 L .48631 .37448 L p F P
0 g
s
.651 .757 .927 r
.66103 .37416 m .65039 .37783 L .65297 .38119 L p F P
0 g
s
.651 .757 .927 r
.65297 .38119 m .6636 .37754 L .66103 .37416 L p F P
0 g
s
.651 .757 .927 r
.49953 .3742 m .4892 .37786 L .49207 .38122 L p F P
0 g
s
.651 .757 .927 r
.49207 .38122 m .50239 .37758 L .49953 .3742 L p F P
0 g
s
.651 .757 .927 r
.67428 .37387 m .6636 .37754 L .66616 .3809 L p F P
0 g
s
.651 .757 .927 r
.66616 .3809 m .67683 .37725 L .67428 .37387 L p F P
0 g
s
.651 .757 .927 r
.51275 .37392 m .50239 .37758 L .50524 .38094 L p F P
0 g
s
.651 .757 .927 r
.50524 .38094 m .51559 .3773 L .51275 .37392 L p F P
0 g
s
.651 .757 .927 r
.68753 .37358 m .67683 .37725 L .67936 .38061 L p F P
0 g
s
.651 .757 .927 r
.67936 .38061 m .69005 .37696 L .68753 .37358 L p F P
0 g
s
.651 .757 .927 r
.52598 .37364 m .51559 .3773 L .51842 .38067 L p F P
0 g
s
.651 .757 .927 r
.51842 .38067 m .52879 .37702 L .52598 .37364 L p F P
0 g
s
.651 .757 .927 r
.70078 .37329 m .69005 .37696 L .69256 .38032 L p F P
0 g
s
.651 .757 .927 r
.69256 .38032 m .70328 .37667 L .70078 .37329 L p F P
0 g
s
.651 .757 .927 r
.53921 .37336 m .52879 .37702 L .53159 .38039 L p F P
0 g
s
.651 .757 .927 r
.53159 .38039 m .542 .37674 L .53921 .37336 L p F P
0 g
s
.651 .757 .927 r
.71404 .37299 m .70328 .37667 L .70577 .38003 L p F P
0 g
s
.651 .757 .927 r
.70577 .38003 m .71652 .37637 L .71404 .37299 L p F P
0 g
s
.651 .757 .927 r
.55244 .37307 m .542 .37674 L .54478 .3801 L p F P
0 g
s
.651 .757 .927 r
.54478 .3801 m .55521 .37646 L .55244 .37307 L p F P
0 g
s
.652 .757 .927 r
.7273 .37269 m .71652 .37637 L .71898 .37974 L p F P
0 g
s
.652 .757 .927 r
.71898 .37974 m .72975 .37608 L .7273 .37269 L p F P
0 g
s
.651 .757 .927 r
.56568 .37279 m .55521 .37646 L .55797 .37982 L p F P
0 g
s
.651 .757 .927 r
.55797 .37982 m .56842 .37617 L .56568 .37279 L p F P
0 g
s
.652 .757 .927 r
.74057 .37239 m .72975 .37608 L .7322 .37945 L p F P
0 g
s
.652 .757 .927 r
.7322 .37945 m .74299 .37578 L .74057 .37239 L p F P
0 g
s
.651 .757 .927 r
.57892 .3725 m .56842 .37617 L .57116 .37954 L p F P
0 g
s
.651 .757 .927 r
.57116 .37954 m .58164 .37589 L .57892 .3725 L p F P
0 g
s
.651 .757 .927 r
.59217 .37222 m .58164 .37589 L .58435 .37926 L p F P
0 g
s
.651 .757 .927 r
.58435 .37926 m .59486 .3756 L .59217 .37222 L p F P
0 g
s
.651 .757 .927 r
.60542 .37193 m .59486 .3756 L .59755 .37897 L p F P
0 g
s
.651 .757 .927 r
.59755 .37897 m .60809 .37532 L .60542 .37193 L p F P
0 g
s
.651 .757 .927 r
.61867 .37164 m .60809 .37532 L .61075 .37869 L p F P
0 g
s
.651 .757 .927 r
.61075 .37869 m .62132 .37503 L .61867 .37164 L p F P
0 g
s
.651 .757 .927 r
.63193 .37136 m .62132 .37503 L .62396 .3784 L p F P
0 g
s
.651 .757 .927 r
.62396 .3784 m .63455 .37474 L .63193 .37136 L p F P
0 g
s
.651 .757 .927 r
.47018 .37137 m .45989 .37504 L .46282 .37842 L p F P
0 g
s
.651 .757 .927 r
.46282 .37842 m .4731 .37476 L .47018 .37137 L p F P
0 g
s
.651 .757 .927 r
.64519 .37107 m .63455 .37474 L .63717 .37812 L p F P
0 g
s
.651 .757 .927 r
.63717 .37812 m .64779 .37445 L .64519 .37107 L p F P
0 g
s
.651 .757 .927 r
.48342 .37109 m .4731 .37476 L .476 .37814 L p F P
0 g
s
.651 .757 .927 r
.476 .37814 m .48631 .37448 L .48342 .37109 L p F P
0 g
s
.651 .757 .927 r
.65846 .37077 m .64779 .37445 L .65039 .37783 L p F P
0 g
s
.651 .757 .927 r
.65039 .37783 m .66103 .37416 L .65846 .37077 L p F P
0 g
s
.651 .757 .927 r
.49666 .37081 m .48631 .37448 L .4892 .37786 L p F P
0 g
s
.651 .757 .927 r
.4892 .37786 m .49953 .3742 L .49666 .37081 L p F P
0 g
s
.651 .757 .927 r
.67172 .37048 m .66103 .37416 L .6636 .37754 L p F P
0 g
s
.651 .757 .927 r
.6636 .37754 m .67428 .37387 L .67172 .37048 L p F P
0 g
s
.651 .757 .927 r
.5099 .37053 m .49953 .3742 L .50239 .37758 L p F P
0 g
s
.651 .757 .927 r
.50239 .37758 m .51275 .37392 L .5099 .37053 L p F P
0 g
s
.651 .757 .927 r
.685 .37019 m .67428 .37387 L .67683 .37725 L p F P
0 g
s
.651 .757 .927 r
.67683 .37725 m .68753 .37358 L .685 .37019 L p F P
0 g
s
.651 .757 .927 r
.52315 .37025 m .51275 .37392 L .51559 .3773 L p F P
0 g
s
.651 .757 .927 r
.51559 .3773 m .52598 .37364 L .52315 .37025 L p F P
0 g
s
.651 .757 .927 r
.69827 .36989 m .68753 .37358 L .69005 .37696 L p F P
0 g
s
.651 .757 .927 r
.69005 .37696 m .70078 .37329 L .69827 .36989 L p F P
0 g
s
.651 .757 .927 r
.53641 .36996 m .52598 .37364 L .52879 .37702 L p F P
0 g
s
.651 .757 .927 r
.52879 .37702 m .53921 .37336 L .53641 .36996 L p F P
0 g
s
.651 .757 .927 r
.71156 .3696 m .70078 .37329 L .70328 .37667 L p F P
0 g
s
.651 .757 .927 r
.70328 .37667 m .71404 .37299 L .71156 .3696 L p F P
0 g
s
.651 .757 .927 r
.54966 .36968 m .53921 .37336 L .542 .37674 L p F P
0 g
s
.651 .757 .927 r
.542 .37674 m .55244 .37307 L .54966 .36968 L p F P
0 g
s
.652 .757 .927 r
.72484 .3693 m .71404 .37299 L .71652 .37637 L p F P
0 g
s
.652 .757 .927 r
.71652 .37637 m .7273 .37269 L .72484 .3693 L p F P
0 g
s
.651 .757 .927 r
.56293 .3694 m .55244 .37307 L .55521 .37646 L p F P
0 g
s
.651 .757 .927 r
.55521 .37646 m .56568 .37279 L .56293 .3694 L p F P
0 g
s
.652 .757 .927 r
.73813 .369 m .7273 .37269 L .72975 .37608 L p F P
0 g
s
.652 .757 .927 r
.72975 .37608 m .74057 .37239 L .73813 .369 L p F P
0 g
s
.651 .757 .927 r
.57619 .36911 m .56568 .37279 L .56842 .37617 L p F P
0 g
s
.651 .757 .927 r
.56842 .37617 m .57892 .3725 L .57619 .36911 L p F P
0 g
s
.651 .757 .927 r
.58946 .36882 m .57892 .3725 L .58164 .37589 L p F P
0 g
s
.651 .757 .927 r
.58164 .37589 m .59217 .37222 L .58946 .36882 L p F P
0 g
s
.651 .757 .927 r
.60273 .36853 m .59217 .37222 L .59486 .3756 L p F P
0 g
s
.651 .757 .927 r
.59486 .3756 m .60542 .37193 L .60273 .36853 L p F P
0 g
s
.651 .757 .927 r
.61601 .36825 m .60542 .37193 L .60809 .37532 L p F P
0 g
s
.651 .757 .927 r
.60809 .37532 m .61867 .37164 L .61601 .36825 L p F P
0 g
s
.651 .757 .927 r
.62929 .36796 m .61867 .37164 L .62132 .37503 L p F P
0 g
s
.651 .757 .927 r
.62132 .37503 m .63193 .37136 L .62929 .36796 L p F P
0 g
s
.651 .757 .927 r
.64258 .36766 m .63193 .37136 L .63455 .37474 L p F P
0 g
s
.651 .757 .927 r
.63455 .37474 m .64519 .37107 L .64258 .36766 L p F P
0 g
s
.651 .757 .927 r
.48051 .36769 m .47018 .37137 L .4731 .37476 L p F P
0 g
s
.651 .757 .927 r
.4731 .37476 m .48342 .37109 L .48051 .36769 L p F P
0 g
s
.651 .757 .927 r
.65587 .36737 m .64519 .37107 L .64779 .37445 L p F P
0 g
s
.651 .757 .927 r
.64779 .37445 m .65846 .37077 L .65587 .36737 L p F P
0 g
s
.651 .757 .927 r
.49378 .36741 m .48342 .37109 L .48631 .37448 L p F P
0 g
s
.651 .757 .927 r
.48631 .37448 m .49666 .37081 L .49378 .36741 L p F P
0 g
s
.651 .757 .927 r
.66916 .36708 m .65846 .37077 L .66103 .37416 L p F P
0 g
s
.651 .757 .927 r
.66103 .37416 m .67172 .37048 L .66916 .36708 L p F P
0 g
s
.651 .757 .927 r
.50705 .36713 m .49666 .37081 L .49953 .3742 L p F P
0 g
s
.651 .757 .927 r
.49953 .3742 m .5099 .37053 L .50705 .36713 L p F P
0 g
s
.651 .757 .927 r
.68246 .36678 m .67172 .37048 L .67428 .37387 L p F P
0 g
s
.651 .757 .927 r
.67428 .37387 m .685 .37019 L .68246 .36678 L p F P
0 g
s
.651 .757 .927 r
.52032 .36684 m .5099 .37053 L .51275 .37392 L p F P
0 g
s
.651 .757 .927 r
.51275 .37392 m .52315 .37025 L .52032 .36684 L p F P
0 g
s
.651 .757 .927 r
.69576 .36649 m .685 .37019 L .68753 .37358 L p F P
0 g
s
.651 .757 .927 r
.68753 .37358 m .69827 .36989 L .69576 .36649 L p F P
0 g
s
.651 .757 .927 r
.5336 .36656 m .52315 .37025 L .52598 .37364 L p F P
0 g
s
.651 .757 .927 r
.52598 .37364 m .53641 .36996 L .5336 .36656 L p F P
0 g
s
.651 .757 .927 r
.70906 .36619 m .69827 .36989 L .70078 .37329 L p F P
0 g
s
.651 .757 .927 r
.70078 .37329 m .71156 .3696 L .70906 .36619 L p F P
0 g
s
.651 .757 .927 r
.54688 .36627 m .53641 .36996 L .53921 .37336 L p F P
0 g
s
.651 .757 .927 r
.53921 .37336 m .54966 .36968 L .54688 .36627 L p F P
0 g
s
.652 .757 .927 r
.72237 .36589 m .71156 .3696 L .71404 .37299 L p F P
0 g
s
.652 .757 .927 r
.71404 .37299 m .72484 .3693 L .72237 .36589 L p F P
0 g
s
.651 .757 .927 r
.56016 .36599 m .54966 .36968 L .55244 .37307 L p F P
0 g
s
.651 .757 .927 r
.55244 .37307 m .56293 .3694 L .56016 .36599 L p F P
0 g
s
.652 .757 .927 r
.73568 .36559 m .72484 .3693 L .7273 .37269 L p F P
0 g
s
.652 .757 .927 r
.7273 .37269 m .73813 .369 L .73568 .36559 L p F P
0 g
s
.651 .757 .927 r
.57345 .3657 m .56293 .3694 L .56568 .37279 L p F P
0 g
s
.651 .757 .927 r
.56568 .37279 m .57619 .36911 L .57345 .3657 L p F P
0 g
s
.651 .757 .927 r
.58675 .36541 m .57619 .36911 L .57892 .3725 L p F P
0 g
s
.651 .757 .927 r
.57892 .3725 m .58946 .36882 L .58675 .36541 L p F P
0 g
s
.651 .757 .927 r
.60004 .36512 m .58946 .36882 L .59217 .37222 L p F P
0 g
s
.651 .757 .927 r
.59217 .37222 m .60273 .36853 L .60004 .36512 L p F P
0 g
s
.651 .757 .927 r
.61334 .36483 m .60273 .36853 L .60542 .37193 L p F P
0 g
s
.651 .757 .927 r
.60542 .37193 m .61601 .36825 L .61334 .36483 L p F P
0 g
s
.651 .757 .927 r
.62665 .36454 m .61601 .36825 L .61867 .37164 L p F P
0 g
s
.651 .757 .927 r
.61867 .37164 m .62929 .36796 L .62665 .36454 L p F P
0 g
s
.651 .757 .927 r
.63996 .36425 m .62929 .36796 L .63193 .37136 L p F P
0 g
s
.651 .757 .927 r
.63193 .37136 m .64258 .36766 L .63996 .36425 L p F P
0 g
s
.651 .757 .927 r
.65327 .36396 m .64258 .36766 L .64519 .37107 L p F P
0 g
s
.651 .757 .927 r
.64519 .37107 m .65587 .36737 L .65327 .36396 L p F P
0 g
s
.651 .757 .927 r
.49089 .36399 m .48051 .36769 L .48342 .37109 L p F P
0 g
s
.651 .757 .927 r
.48342 .37109 m .49378 .36741 L .49089 .36399 L p F P
0 g
s
.651 .757 .927 r
.66659 .36366 m .65587 .36737 L .65846 .37077 L p F P
0 g
s
.651 .757 .927 r
.65846 .37077 m .66916 .36708 L .66659 .36366 L p F P
0 g
s
.651 .757 .927 r
.50418 .36371 m .49378 .36741 L .49666 .37081 L p F P
0 g
s
.651 .757 .927 r
.49666 .37081 m .50705 .36713 L .50418 .36371 L p F P
0 g
s
.651 .757 .927 r
.67991 .36337 m .66916 .36708 L .67172 .37048 L p F P
0 g
s
.651 .757 .927 r
.67172 .37048 m .68246 .36678 L .67991 .36337 L p F P
0 g
s
.651 .757 .927 r
.51748 .36343 m .50705 .36713 L .5099 .37053 L p F P
0 g
s
.651 .757 .927 r
.5099 .37053 m .52032 .36684 L .51748 .36343 L p F P
0 g
s
.651 .757 .927 r
.69323 .36307 m .68246 .36678 L .685 .37019 L p F P
0 g
s
.651 .757 .927 r
.685 .37019 m .69576 .36649 L .69323 .36307 L p F P
0 g
s
.651 .757 .927 r
.53078 .36314 m .52032 .36684 L .52315 .37025 L p F P
0 g
s
.651 .757 .927 r
.52315 .37025 m .5336 .36656 L .53078 .36314 L p F P
0 g
s
.652 .757 .927 r
.70656 .36277 m .69576 .36649 L .69827 .36989 L p F P
0 g
s
.652 .757 .927 r
.69827 .36989 m .70906 .36619 L .70656 .36277 L p F P
0 g
s
.651 .757 .927 r
.54408 .36286 m .5336 .36656 L .53641 .36996 L p F P
0 g
s
.651 .757 .927 r
.53641 .36996 m .54688 .36627 L .54408 .36286 L p F P
0 g
s
.652 .757 .927 r
.71989 .36247 m .70906 .36619 L .71156 .3696 L p F P
0 g
s
.652 .757 .927 r
.71156 .3696 m .72237 .36589 L .71989 .36247 L p F P
0 g
s
.651 .757 .927 r
.55739 .36257 m .54688 .36627 L .54966 .36968 L p F P
0 g
s
.651 .757 .927 r
.54966 .36968 m .56016 .36599 L .55739 .36257 L p F P
0 g
s
.652 .757 .927 r
.73323 .36217 m .72237 .36589 L .72484 .3693 L p F P
0 g
s
.652 .757 .927 r
.72484 .3693 m .73568 .36559 L .73323 .36217 L p F P
0 g
s
.651 .757 .927 r
.5707 .36228 m .56016 .36599 L .56293 .3694 L p F P
0 g
s
.651 .757 .927 r
.56293 .3694 m .57345 .3657 L .5707 .36228 L p F P
0 g
s
.651 .757 .927 r
.58402 .36199 m .57345 .3657 L .57619 .36911 L p F P
0 g
s
.651 .757 .927 r
.57619 .36911 m .58675 .36541 L .58402 .36199 L p F P
0 g
s
.651 .757 .927 r
.59734 .3617 m .58675 .36541 L .58946 .36882 L p F P
0 g
s
.651 .757 .927 r
.58946 .36882 m .60004 .36512 L .59734 .3617 L p F P
0 g
s
.651 .757 .927 r
.61067 .36141 m .60004 .36512 L .60273 .36853 L p F P
0 g
s
.651 .757 .927 r
.60273 .36853 m .61334 .36483 L .61067 .36141 L p F P
0 g
s
.651 .757 .927 r
.62399 .36112 m .61334 .36483 L .61601 .36825 L p F P
0 g
s
.651 .757 .927 r
.61601 .36825 m .62665 .36454 L .62399 .36112 L p F P
0 g
s
.651 .757 .927 r
.63733 .36083 m .62665 .36454 L .62929 .36796 L p F P
0 g
s
.651 .757 .927 r
.62929 .36796 m .63996 .36425 L .63733 .36083 L p F P
0 g
s
.651 .757 .927 r
.65066 .36053 m .63996 .36425 L .64258 .36766 L p F P
0 g
s
.651 .757 .927 r
.64258 .36766 m .65327 .36396 L .65066 .36053 L p F P
0 g
s
.651 .757 .927 r
.664 .36023 m .65327 .36396 L .65587 .36737 L p F P
0 g
s
.651 .757 .927 r
.65587 .36737 m .66659 .36366 L .664 .36023 L p F P
0 g
s
.651 .757 .927 r
.5013 .36028 m .49089 .36399 L .49378 .36741 L p F P
0 g
s
.651 .757 .927 r
.49378 .36741 m .50418 .36371 L .5013 .36028 L p F P
0 g
s
.651 .757 .927 r
.67735 .35994 m .66659 .36366 L .66916 .36708 L p F P
0 g
s
.651 .757 .927 r
.66916 .36708 m .67991 .36337 L .67735 .35994 L p F P
0 g
s
.651 .757 .927 r
.51462 .36 m .50418 .36371 L .50705 .36713 L p F P
0 g
s
.651 .757 .927 r
.50705 .36713 m .51748 .36343 L .51462 .36 L p F P
0 g
s
.651 .757 .927 r
.6907 .35964 m .67991 .36337 L .68246 .36678 L p F P
0 g
s
.651 .757 .927 r
.68246 .36678 m .69323 .36307 L .6907 .35964 L p F P
0 g
s
.651 .757 .927 r
.52795 .35971 m .51748 .36343 L .52032 .36684 L p F P
0 g
s
.651 .757 .927 r
.52032 .36684 m .53078 .36314 L .52795 .35971 L p F P
0 g
s
.652 .757 .927 r
.70405 .35934 m .69323 .36307 L .69576 .36649 L p F P
0 g
s
.652 .757 .927 r
.69576 .36649 m .70656 .36277 L .70405 .35934 L p F P
0 g
s
.651 .757 .927 r
.54127 .35942 m .53078 .36314 L .5336 .36656 L p F P
0 g
s
.651 .757 .927 r
.5336 .36656 m .54408 .36286 L .54127 .35942 L p F P
0 g
s
.652 .757 .927 r
.7174 .35904 m .70656 .36277 L .70906 .36619 L p F P
0 g
s
.652 .757 .927 r
.70906 .36619 m .71989 .36247 L .7174 .35904 L p F P
0 g
s
.651 .757 .927 r
.55461 .35914 m .54408 .36286 L .54688 .36627 L p F P
0 g
s
.651 .757 .927 r
.54688 .36627 m .55739 .36257 L .55461 .35914 L p F P
0 g
s
.652 .757 .927 r
.73076 .35873 m .71989 .36247 L .72237 .36589 L p F P
0 g
s
.652 .757 .927 r
.72237 .36589 m .73323 .36217 L .73076 .35873 L p F P
0 g
s
.651 .757 .927 r
.56794 .35885 m .55739 .36257 L .56016 .36599 L p F P
0 g
s
.651 .757 .927 r
.56016 .36599 m .5707 .36228 L .56794 .35885 L p F P
0 g
s
.651 .757 .927 r
.58128 .35856 m .5707 .36228 L .57345 .3657 L p F P
0 g
s
.651 .757 .927 r
.57345 .3657 m .58402 .36199 L .58128 .35856 L p F P
0 g
s
.651 .757 .927 r
.59463 .35827 m .58402 .36199 L .58675 .36541 L p F P
0 g
s
.651 .757 .927 r
.58675 .36541 m .59734 .3617 L .59463 .35827 L p F P
0 g
s
.651 .757 .927 r
.60798 .35797 m .59734 .3617 L .60004 .36512 L p F P
0 g
s
.651 .757 .927 r
.60004 .36512 m .61067 .36141 L .60798 .35797 L p F P
0 g
s
.651 .757 .927 r
.62133 .35768 m .61067 .36141 L .61334 .36483 L p F P
0 g
s
.651 .757 .927 r
.61334 .36483 m .62399 .36112 L .62133 .35768 L p F P
0 g
s
.651 .757 .927 r
.63469 .35739 m .62399 .36112 L .62665 .36454 L p F P
0 g
s
.651 .757 .927 r
.62665 .36454 m .63733 .36083 L .63469 .35739 L p F P
0 g
s
.651 .757 .927 r
.64805 .35709 m .63733 .36083 L .63996 .36425 L p F P
0 g
s
.651 .757 .927 r
.63996 .36425 m .65066 .36053 L .64805 .35709 L p F P
0 g
s
.651 .757 .927 r
.66141 .35679 m .65066 .36053 L .65327 .36396 L p F P
0 g
s
.651 .757 .927 r
.65327 .36396 m .664 .36023 L .66141 .35679 L p F P
0 g
s
.651 .757 .927 r
.67478 .3565 m .664 .36023 L .66659 .36366 L p F P
0 g
s
.651 .757 .927 r
.66659 .36366 m .67735 .35994 L .67478 .3565 L p F P
0 g
s
.651 .757 .927 r
.51176 .35655 m .5013 .36028 L .50418 .36371 L p F P
0 g
s
.651 .757 .927 r
.50418 .36371 m .51462 .36 L .51176 .35655 L p F P
0 g
s
.651 .757 .927 r
.68815 .3562 m .67735 .35994 L .67991 .36337 L p F P
0 g
s
.651 .757 .927 r
.67991 .36337 m .6907 .35964 L .68815 .3562 L p F P
0 g
s
.651 .757 .927 r
.5251 .35627 m .51462 .36 L .51748 .36343 L p F P
0 g
s
.651 .757 .927 r
.51748 .36343 m .52795 .35971 L .5251 .35627 L p F P
0 g
s
.652 .757 .927 r
.70153 .35589 m .6907 .35964 L .69323 .36307 L p F P
0 g
s
.652 .757 .927 r
.69323 .36307 m .70405 .35934 L .70153 .35589 L p F P
0 g
s
.651 .757 .927 r
.53846 .35598 m .52795 .35971 L .53078 .36314 L p F P
0 g
s
.651 .757 .927 r
.53078 .36314 m .54127 .35942 L .53846 .35598 L p F P
0 g
s
.652 .757 .927 r
.71491 .35559 m .70405 .35934 L .70656 .36277 L p F P
0 g
s
.652 .757 .927 r
.70656 .36277 m .7174 .35904 L .71491 .35559 L p F P
0 g
s
.651 .757 .927 r
.55181 .35569 m .54127 .35942 L .54408 .36286 L p F P
0 g
s
.651 .757 .927 r
.54408 .36286 m .55461 .35914 L .55181 .35569 L p F P
0 g
s
.652 .757 .927 r
.72829 .35529 m .7174 .35904 L .71989 .36247 L p F P
0 g
s
.652 .757 .927 r
.71989 .36247 m .73076 .35873 L .72829 .35529 L p F P
0 g
s
.651 .757 .927 r
.56517 .3554 m .55461 .35914 L .55739 .36257 L p F P
0 g
s
.651 .757 .927 r
.55739 .36257 m .56794 .35885 L .56517 .3554 L p F P
0 g
s
.651 .757 .927 r
.57854 .35511 m .56794 .35885 L .5707 .36228 L p F P
0 g
s
.651 .757 .927 r
.5707 .36228 m .58128 .35856 L .57854 .35511 L p F P
0 g
s
.651 .757 .927 r
.59191 .35482 m .58128 .35856 L .58402 .36199 L p F P
0 g
s
.651 .757 .927 r
.58402 .36199 m .59463 .35827 L .59191 .35482 L p F P
0 g
s
.651 .757 .927 r
.60528 .35452 m .59463 .35827 L .59734 .3617 L p F P
0 g
s
.651 .757 .927 r
.59734 .3617 m .60798 .35797 L .60528 .35452 L p F P
0 g
s
.651 .757 .927 r
.61866 .35423 m .60798 .35797 L .61067 .36141 L p F P
0 g
s
.651 .757 .927 r
.61067 .36141 m .62133 .35768 L .61866 .35423 L p F P
0 g
s
.651 .757 .927 r
.63204 .35393 m .62133 .35768 L .62399 .36112 L p F P
0 g
s
.651 .757 .927 r
.62399 .36112 m .63469 .35739 L .63204 .35393 L p F P
0 g
s
.651 .757 .927 r
.64542 .35364 m .63469 .35739 L .63733 .36083 L p F P
0 g
s
.651 .757 .927 r
.63733 .36083 m .64805 .35709 L .64542 .35364 L p F P
0 g
s
.651 .757 .927 r
.65881 .35334 m .64805 .35709 L .65066 .36053 L p F P
0 g
s
.651 .757 .927 r
.65066 .36053 m .66141 .35679 L .65881 .35334 L p F P
0 g
s
.651 .757 .927 r
.6722 .35304 m .66141 .35679 L .664 .36023 L p F P
0 g
s
.651 .757 .927 r
.664 .36023 m .67478 .3565 L .6722 .35304 L p F P
0 g
s
.652 .757 .927 r
.6856 .35274 m .67478 .3565 L .67735 .35994 L p F P
0 g
s
.652 .757 .927 r
.67735 .35994 m .68815 .3562 L .6856 .35274 L p F P
0 g
s
.651 .757 .927 r
.52225 .35281 m .51176 .35655 L .51462 .36 L p F P
0 g
s
.651 .757 .927 r
.51462 .36 m .5251 .35627 L .52225 .35281 L p F P
0 g
s
.652 .757 .927 r
.699 .35244 m .68815 .3562 L .6907 .35964 L p F P
0 g
s
.652 .757 .927 r
.6907 .35964 m .70153 .35589 L .699 .35244 L p F P
0 g
s
.651 .757 .927 r
.53563 .35252 m .5251 .35627 L .52795 .35971 L p F P
0 g
s
.651 .757 .927 r
.52795 .35971 m .53846 .35598 L .53563 .35252 L p F P
0 g
s
.652 .757 .927 r
.7124 .35213 m .70153 .35589 L .70405 .35934 L p F P
0 g
s
.652 .757 .927 r
.70405 .35934 m .71491 .35559 L .7124 .35213 L p F P
0 g
s
.651 .757 .927 r
.54901 .35223 m .53846 .35598 L .54127 .35942 L p F P
0 g
s
.651 .757 .927 r
.54127 .35942 m .55181 .35569 L .54901 .35223 L p F P
0 g
s
.652 .757 .927 r
.72581 .35183 m .71491 .35559 L .7174 .35904 L p F P
0 g
s
.652 .757 .927 r
.7174 .35904 m .72829 .35529 L .72581 .35183 L p F P
0 g
s
.651 .757 .927 r
.56239 .35194 m .55181 .35569 L .55461 .35914 L p F P
0 g
s
.651 .757 .927 r
.55461 .35914 m .56517 .3554 L .56239 .35194 L p F P
0 g
s
.651 .757 .927 r
.57578 .35165 m .56517 .3554 L .56794 .35885 L p F P
0 g
s
.651 .757 .927 r
.56794 .35885 m .57854 .35511 L .57578 .35165 L p F P
0 g
s
.651 .757 .927 r
.58918 .35135 m .57854 .35511 L .58128 .35856 L p F P
0 g
s
.651 .757 .927 r
.58128 .35856 m .59191 .35482 L .58918 .35135 L p F P
0 g
s
.651 .757 .927 r
.60257 .35106 m .59191 .35482 L .59463 .35827 L p F P
0 g
s
.651 .757 .927 r
.59463 .35827 m .60528 .35452 L .60257 .35106 L p F P
0 g
s
.651 .757 .927 r
.61597 .35076 m .60528 .35452 L .60798 .35797 L p F P
0 g
s
.651 .757 .927 r
.60798 .35797 m .61866 .35423 L .61597 .35076 L p F P
0 g
s
.651 .757 .927 r
.62938 .35047 m .61866 .35423 L .62133 .35768 L p F P
0 g
s
.651 .757 .927 r
.62133 .35768 m .63204 .35393 L .62938 .35047 L p F P
0 g
s
.651 .757 .927 r
.64279 .35017 m .63204 .35393 L .63469 .35739 L p F P
0 g
s
.651 .757 .927 r
.63469 .35739 m .64542 .35364 L .64279 .35017 L p F P
0 g
s
.651 .757 .927 r
.6562 .34987 m .64542 .35364 L .64805 .35709 L p F P
0 g
s
.651 .757 .927 r
.64805 .35709 m .65881 .35334 L .6562 .34987 L p F P
0 g
s
.651 .757 .927 r
.66961 .34957 m .65881 .35334 L .66141 .35679 L p F P
0 g
s
.651 .757 .927 r
.66141 .35679 m .6722 .35304 L .66961 .34957 L p F P
0 g
s
.652 .757 .927 r
.68303 .34927 m .6722 .35304 L .67478 .3565 L p F P
0 g
s
.652 .757 .927 r
.67478 .3565 m .6856 .35274 L .68303 .34927 L p F P
0 g
s
.652 .757 .927 r
.69646 .34896 m .6856 .35274 L .68815 .3562 L p F P
0 g
s
.652 .757 .927 r
.68815 .3562 m .699 .35244 L .69646 .34896 L p F P
0 g
s
.651 .757 .927 r
.53279 .34905 m .52225 .35281 L .5251 .35627 L p F P
0 g
s
.651 .757 .927 r
.5251 .35627 m .53563 .35252 L .53279 .34905 L p F P
0 g
s
.652 .757 .927 r
.70989 .34866 m .699 .35244 L .70153 .35589 L p F P
0 g
s
.652 .757 .927 r
.70153 .35589 m .7124 .35213 L .70989 .34866 L p F P
0 g
s
.651 .757 .927 r
.5462 .34876 m .53563 .35252 L .53846 .35598 L p F P
0 g
s
.651 .757 .927 r
.53846 .35598 m .54901 .35223 L .5462 .34876 L p F P
0 g
s
.652 .757 .927 r
.72332 .34835 m .7124 .35213 L .71491 .35559 L p F P
0 g
s
.652 .757 .927 r
.71491 .35559 m .72581 .35183 L .72332 .34835 L p F P
0 g
s
.651 .757 .927 r
.5596 .34847 m .54901 .35223 L .55181 .35569 L p F P
0 g
s
.651 .757 .927 r
.55181 .35569 m .56239 .35194 L .5596 .34847 L p F P
0 g
s
.651 .757 .927 r
.57302 .34817 m .56239 .35194 L .56517 .3554 L p F P
0 g
s
.651 .757 .927 r
.56517 .3554 m .57578 .35165 L .57302 .34817 L p F P
0 g
s
.651 .757 .927 r
.58643 .34788 m .57578 .35165 L .57854 .35511 L p F P
0 g
s
.651 .757 .927 r
.57854 .35511 m .58918 .35135 L .58643 .34788 L p F P
0 g
s
.651 .757 .927 r
.59985 .34758 m .58918 .35135 L .59191 .35482 L p F P
0 g
s
.651 .757 .927 r
.59191 .35482 m .60257 .35106 L .59985 .34758 L p F P
0 g
s
.651 .757 .927 r
.61328 .34729 m .60257 .35106 L .60528 .35452 L p F P
0 g
s
.651 .757 .927 r
.60528 .35452 m .61597 .35076 L .61328 .34729 L p F P
0 g
s
.651 .757 .927 r
.62671 .34699 m .61597 .35076 L .61866 .35423 L p F P
0 g
s
.651 .757 .927 r
.61866 .35423 m .62938 .35047 L .62671 .34699 L p F P
0 g
s
.651 .757 .927 r
.64014 .34669 m .62938 .35047 L .63204 .35393 L p F P
0 g
s
.651 .757 .927 r
.63204 .35393 m .64279 .35017 L .64014 .34669 L p F P
0 g
s
.651 .757 .927 r
.65358 .34639 m .64279 .35017 L .64542 .35364 L p F P
0 g
s
.651 .757 .927 r
.64542 .35364 m .6562 .34987 L .65358 .34639 L p F P
0 g
s
.652 .757 .927 r
.66702 .34609 m .6562 .34987 L .65881 .35334 L p F P
0 g
s
.652 .757 .927 r
.65881 .35334 m .66961 .34957 L .66702 .34609 L p F P
0 g
s
.652 .757 .927 r
.68046 .34579 m .66961 .34957 L .6722 .35304 L p F P
0 g
s
.652 .757 .927 r
.6722 .35304 m .68303 .34927 L .68046 .34579 L p F P
0 g
s
.652 .757 .927 r
.69391 .34548 m .68303 .34927 L .6856 .35274 L p F P
0 g
s
.652 .757 .927 r
.6856 .35274 m .69646 .34896 L .69391 .34548 L p F P
0 g
s
.652 .757 .927 r
.70736 .34517 m .69646 .34896 L .699 .35244 L p F P
0 g
s
.652 .757 .927 r
.699 .35244 m .70989 .34866 L .70736 .34517 L p F P
0 g
s
.651 .757 .927 r
.54337 .34527 m .53279 .34905 L .53563 .35252 L p F P
0 g
s
.651 .757 .927 r
.53563 .35252 m .5462 .34876 L .54337 .34527 L p F P
0 g
s
.652 .757 .927 r
.72082 .34486 m .70989 .34866 L .7124 .35213 L p F P
0 g
s
.652 .757 .927 r
.7124 .35213 m .72332 .34835 L .72082 .34486 L p F P
0 g
s
.651 .757 .927 r
.5568 .34498 m .5462 .34876 L .54901 .35223 L p F P
0 g
s
.651 .757 .927 r
.54901 .35223 m .5596 .34847 L .5568 .34498 L p F P
0 g
s
.651 .757 .927 r
.57024 .34469 m .5596 .34847 L .56239 .35194 L p F P
0 g
s
.651 .757 .927 r
.56239 .35194 m .57302 .34817 L .57024 .34469 L p F P
0 g
s
.651 .757 .927 r
.58368 .34439 m .57302 .34817 L .57578 .35165 L p F P
0 g
s
.651 .757 .927 r
.57578 .35165 m .58643 .34788 L .58368 .34439 L p F P
0 g
s
.651 .757 .927 r
.59713 .34409 m .58643 .34788 L .58918 .35135 L p F P
0 g
s
.651 .757 .927 r
.58918 .35135 m .59985 .34758 L .59713 .34409 L p F P
0 g
s
.651 .757 .927 r
.61058 .3438 m .59985 .34758 L .60257 .35106 L p F P
0 g
s
.651 .757 .927 r
.60257 .35106 m .61328 .34729 L .61058 .3438 L p F P
0 g
s
.651 .757 .927 r
.62403 .3435 m .61328 .34729 L .61597 .35076 L p F P
0 g
s
.651 .757 .927 r
.61597 .35076 m .62671 .34699 L .62403 .3435 L p F P
0 g
s
.651 .757 .927 r
.63749 .3432 m .62671 .34699 L .62938 .35047 L p F P
0 g
s
.651 .757 .927 r
.62938 .35047 m .64014 .34669 L .63749 .3432 L p F P
0 g
s
.651 .757 .927 r
.65095 .3429 m .64014 .34669 L .64279 .35017 L p F P
0 g
s
.651 .757 .927 r
.64279 .35017 m .65358 .34639 L .65095 .3429 L p F P
0 g
s
.652 .757 .927 r
.66441 .34259 m .65358 .34639 L .6562 .34987 L p F P
0 g
s
.652 .757 .927 r
.6562 .34987 m .66702 .34609 L .66441 .34259 L p F P
0 g
s
.652 .757 .927 r
.67788 .34229 m .66702 .34609 L .66961 .34957 L p F P
0 g
s
.652 .757 .927 r
.66961 .34957 m .68046 .34579 L .67788 .34229 L p F P
0 g
s
.652 .757 .927 r
.69135 .34198 m .68046 .34579 L .68303 .34927 L p F P
0 g
s
.652 .757 .927 r
.68303 .34927 m .69391 .34548 L .69135 .34198 L p F P
0 g
s
.652 .757 .927 r
.70483 .34167 m .69391 .34548 L .69646 .34896 L p F P
0 g
s
.652 .757 .927 r
.69646 .34896 m .70736 .34517 L .70483 .34167 L p F P
0 g
s
.652 .757 .927 r
.71831 .34136 m .70736 .34517 L .70989 .34866 L p F P
0 g
s
.652 .757 .927 r
.70989 .34866 m .72082 .34486 L .71831 .34136 L p F P
0 g
s
.651 .757 .927 r
.55399 .34148 m .54337 .34527 L .5462 .34876 L p F P
0 g
s
.651 .757 .927 r
.5462 .34876 m .5568 .34498 L .55399 .34148 L p F P
0 g
s
.651 .757 .927 r
.56745 .34118 m .5568 .34498 L .5596 .34847 L p F P
0 g
s
.651 .757 .927 r
.5596 .34847 m .57024 .34469 L .56745 .34118 L p F P
0 g
s
.651 .757 .927 r
.58092 .34089 m .57024 .34469 L .57302 .34817 L p F P
0 g
s
.651 .757 .927 r
.57302 .34817 m .58368 .34439 L .58092 .34089 L p F P
0 g
s
.651 .757 .927 r
.59439 .34059 m .58368 .34439 L .58643 .34788 L p F P
0 g
s
.651 .757 .927 r
.58643 .34788 m .59713 .34409 L .59439 .34059 L p F P
0 g
s
.651 .757 .927 r
.60786 .34029 m .59713 .34409 L .59985 .34758 L p F P
0 g
s
.651 .757 .927 r
.59985 .34758 m .61058 .3438 L .60786 .34029 L p F P
0 g
s
.651 .757 .927 r
.62134 .33999 m .61058 .3438 L .61328 .34729 L p F P
0 g
s
.651 .757 .927 r
.61328 .34729 m .62403 .3435 L .62134 .33999 L p F P
0 g
s
.651 .757 .927 r
.63482 .33969 m .62403 .3435 L .62671 .34699 L p F P
0 g
s
.651 .757 .927 r
.62671 .34699 m .63749 .3432 L .63482 .33969 L p F P
0 g
s
.652 .757 .927 r
.64831 .33939 m .63749 .3432 L .64014 .34669 L p F P
0 g
s
.652 .757 .927 r
.64014 .34669 m .65095 .3429 L .64831 .33939 L p F P
0 g
s
.652 .757 .927 r
.66179 .33908 m .65095 .3429 L .65358 .34639 L p F P
0 g
s
.652 .757 .927 r
.65358 .34639 m .66441 .34259 L .66179 .33908 L p F P
0 g
s
.652 .757 .927 r
.67529 .33878 m .66441 .34259 L .66702 .34609 L p F P
0 g
s
.652 .757 .927 r
.66702 .34609 m .67788 .34229 L .67529 .33878 L p F P
0 g
s
.652 .757 .927 r
.68878 .33847 m .67788 .34229 L .68046 .34579 L p F P
0 g
s
.652 .757 .927 r
.68046 .34579 m .69135 .34198 L .68878 .33847 L p F P
0 g
s
.652 .757 .927 r
.70229 .33816 m .69135 .34198 L .69391 .34548 L p F P
0 g
s
.652 .757 .927 r
.69391 .34548 m .70483 .34167 L .70229 .33816 L p F P
0 g
s
.652 .757 .927 r
.71579 .33785 m .70483 .34167 L .70736 .34517 L p F P
0 g
s
.652 .757 .927 r
.70736 .34517 m .71831 .34136 L .71579 .33785 L p F P
0 g
s
.651 .757 .927 r
.56466 .33767 m .55399 .34148 L .5568 .34498 L p F P
0 g
s
.651 .757 .927 r
.5568 .34498 m .56745 .34118 L .56466 .33767 L p F P
0 g
s
.651 .757 .927 r
.57815 .33737 m .56745 .34118 L .57024 .34469 L p F P
0 g
s
.651 .757 .927 r
.57024 .34469 m .58092 .34089 L .57815 .33737 L p F P
0 g
s
.651 .757 .927 r
.59164 .33707 m .58092 .34089 L .58368 .34439 L p F P
0 g
s
.651 .757 .927 r
.58368 .34439 m .59439 .34059 L .59164 .33707 L p F P
0 g
s
.651 .757 .927 r
.60514 .33677 m .59439 .34059 L .59713 .34409 L p F P
0 g
s
.651 .757 .927 r
.59713 .34409 m .60786 .34029 L .60514 .33677 L p F P
0 g
s
.651 .757 .927 r
.61864 .33647 m .60786 .34029 L .61058 .3438 L p F P
0 g
s
.651 .757 .927 r
.61058 .3438 m .62134 .33999 L .61864 .33647 L p F P
0 g
s
.651 .757 .927 r
.63215 .33617 m .62134 .33999 L .62403 .3435 L p F P
0 g
s
.651 .757 .927 r
.62403 .3435 m .63482 .33969 L .63215 .33617 L p F P
0 g
s
.652 .757 .927 r
.64566 .33587 m .63482 .33969 L .63749 .3432 L p F P
0 g
s
.652 .757 .927 r
.63749 .3432 m .64831 .33939 L .64566 .33587 L p F P
0 g
s
.652 .757 .927 r
.65917 .33556 m .64831 .33939 L .65095 .3429 L p F P
0 g
s
.652 .757 .927 r
.65095 .3429 m .66179 .33908 L .65917 .33556 L p F P
0 g
s
.652 .757 .927 r
.67269 .33526 m .66179 .33908 L .66441 .34259 L p F P
0 g
s
.652 .757 .927 r
.66441 .34259 m .67529 .33878 L .67269 .33526 L p F P
0 g
s
.652 .757 .927 r
.68621 .33495 m .67529 .33878 L .67788 .34229 L p F P
0 g
s
.652 .757 .927 r
.67788 .34229 m .68878 .33847 L .68621 .33495 L p F P
0 g
s
.652 .757 .927 r
.69973 .33464 m .68878 .33847 L .69135 .34198 L p F P
0 g
s
.652 .757 .927 r
.69135 .34198 m .70229 .33816 L .69973 .33464 L p F P
0 g
s
.652 .757 .927 r
.71326 .33432 m .70229 .33816 L .70483 .34167 L p F P
0 g
s
.652 .757 .927 r
.70483 .34167 m .71579 .33785 L .71326 .33432 L p F P
0 g
s
.651 .757 .927 r
.57537 .33384 m .56466 .33767 L .56745 .34118 L p F P
0 g
s
.651 .757 .927 r
.56745 .34118 m .57815 .33737 L .57537 .33384 L p F P
0 g
s
.651 .757 .927 r
.58888 .33354 m .57815 .33737 L .58092 .34089 L p F P
0 g
s
.651 .757 .927 r
.58092 .34089 m .59164 .33707 L .58888 .33354 L p F P
0 g
s
.651 .757 .927 r
.60241 .33324 m .59164 .33707 L .59439 .34059 L p F P
0 g
s
.651 .757 .927 r
.59439 .34059 m .60514 .33677 L .60241 .33324 L p F P
0 g
s
.651 .757 .927 r
.61593 .33294 m .60514 .33677 L .60786 .34029 L p F P
0 g
s
.651 .757 .927 r
.60786 .34029 m .61864 .33647 L .61593 .33294 L p F P
0 g
s
.651 .757 .927 r
.62946 .33264 m .61864 .33647 L .62134 .33999 L p F P
0 g
s
.651 .757 .927 r
.62134 .33999 m .63215 .33617 L .62946 .33264 L p F P
0 g
s
.652 .757 .927 r
.643 .33233 m .63215 .33617 L .63482 .33969 L p F P
0 g
s
.652 .757 .927 r
.63482 .33969 m .64566 .33587 L .643 .33233 L p F P
0 g
s
.652 .757 .927 r
.65653 .33203 m .64566 .33587 L .64831 .33939 L p F P
0 g
s
.652 .757 .927 r
.64831 .33939 m .65917 .33556 L .65653 .33203 L p F P
0 g
s
.652 .757 .927 r
.67008 .33172 m .65917 .33556 L .66179 .33908 L p F P
0 g
s
.652 .757 .927 r
.66179 .33908 m .67269 .33526 L .67008 .33172 L p F P
0 g
s
.652 .757 .927 r
.68362 .33141 m .67269 .33526 L .67529 .33878 L p F P
0 g
s
.652 .757 .927 r
.67529 .33878 m .68621 .33495 L .68362 .33141 L p F P
0 g
s
.652 .757 .927 r
.69717 .3311 m .68621 .33495 L .68878 .33847 L p F P
0 g
s
.652 .757 .927 r
.68878 .33847 m .69973 .33464 L .69717 .3311 L p F P
0 g
s
.652 .757 .927 r
.71073 .33078 m .69973 .33464 L .70229 .33816 L p F P
0 g
s
.652 .757 .927 r
.70229 .33816 m .71326 .33432 L .71073 .33078 L p F P
0 g
s
.651 .757 .927 r
.58612 .33 m .57537 .33384 L .57815 .33737 L p F P
0 g
s
.651 .757 .927 r
.57815 .33737 m .58888 .33354 L .58612 .33 L p F P
0 g
s
.651 .757 .927 r
.59966 .3297 m .58888 .33354 L .59164 .33707 L p F P
0 g
s
.651 .757 .927 r
.59164 .33707 m .60241 .33324 L .59966 .3297 L p F P
0 g
s
.651 .757 .927 r
.61321 .3294 m .60241 .33324 L .60514 .33677 L p F P
0 g
s
.651 .757 .927 r
.60514 .33677 m .61593 .33294 L .61321 .3294 L p F P
0 g
s
.652 .757 .927 r
.62677 .32909 m .61593 .33294 L .61864 .33647 L p F P
0 g
s
.652 .757 .927 r
.61864 .33647 m .62946 .33264 L .62677 .32909 L p F P
0 g
s
.652 .757 .927 r
.64033 .32878 m .62946 .33264 L .63215 .33617 L p F P
0 g
s
.652 .757 .927 r
.63215 .33617 m .643 .33233 L .64033 .32878 L p F P
0 g
s
.652 .757 .927 r
.65389 .32848 m .643 .33233 L .64566 .33587 L p F P
0 g
s
.652 .757 .927 r
.64566 .33587 m .65653 .33203 L .65389 .32848 L p F P
0 g
s
.652 .757 .927 r
.66746 .32817 m .65653 .33203 L .65917 .33556 L p F P
0 g
s
.652 .757 .927 r
.65917 .33556 m .67008 .33172 L .66746 .32817 L p F P
0 g
s
.652 .757 .927 r
.68103 .32786 m .67008 .33172 L .67269 .33526 L p F P
0 g
s
.652 .757 .927 r
.67269 .33526 m .68362 .33141 L .68103 .32786 L p F P
0 g
s
.652 .757 .927 r
.6946 .32754 m .68362 .33141 L .68621 .33495 L p F P
0 g
s
.652 .757 .927 r
.68621 .33495 m .69717 .3311 L .6946 .32754 L p F P
0 g
s
.652 .757 .926 r
.70818 .32723 m .69717 .3311 L .69973 .33464 L p F P
0 g
s
.652 .757 .926 r
.69973 .33464 m .71073 .33078 L .70818 .32723 L p F P
0 g
s
.651 .757 .927 r
.59691 .32614 m .58612 .33 L .58888 .33354 L p F P
0 g
s
.651 .757 .927 r
.58888 .33354 m .59966 .3297 L .59691 .32614 L p F P
0 g
s
.652 .757 .927 r
.61048 .32584 m .59966 .3297 L .60241 .33324 L p F P
0 g
s
.652 .757 .927 r
.60241 .33324 m .61321 .3294 L .61048 .32584 L p F P
0 g
s
.652 .757 .927 r
.62406 .32553 m .61321 .3294 L .61593 .33294 L p F P
0 g
s
.652 .757 .927 r
.61593 .33294 m .62677 .32909 L .62406 .32553 L p F P
0 g
s
.652 .757 .927 r
.63765 .32522 m .62677 .32909 L .62946 .33264 L p F P
0 g
s
.652 .757 .927 r
.62946 .33264 m .64033 .32878 L .63765 .32522 L p F P
0 g
s
.652 .757 .927 r
.65123 .32491 m .64033 .32878 L .643 .33233 L p F P
0 g
s
.652 .757 .927 r
.643 .33233 m .65389 .32848 L .65123 .32491 L p F P
0 g
s
.652 .757 .927 r
.66482 .3246 m .65389 .32848 L .65653 .33203 L p F P
0 g
s
.652 .757 .927 r
.65653 .33203 m .66746 .32817 L .66482 .3246 L p F P
0 g
s
.652 .757 .927 r
.67842 .32429 m .66746 .32817 L .67008 .33172 L p F P
0 g
s
.652 .757 .927 r
.67008 .33172 m .68103 .32786 L .67842 .32429 L p F P
0 g
s
.652 .757 .926 r
.69202 .32398 m .68103 .32786 L .68362 .33141 L p F P
0 g
s
.652 .757 .926 r
.68362 .33141 m .6946 .32754 L .69202 .32398 L p F P
0 g
s
.652 .757 .926 r
.70562 .32366 m .6946 .32754 L .69717 .3311 L p F P
0 g
s
.652 .757 .926 r
.69717 .3311 m .70818 .32723 L .70562 .32366 L p F P
0 g
s
.652 .757 .927 r
.60774 .32226 m .59691 .32614 L .59966 .3297 L p F P
0 g
s
.652 .757 .927 r
.59966 .3297 m .61048 .32584 L .60774 .32226 L p F P
0 g
s
.652 .757 .927 r
.62135 .32195 m .61048 .32584 L .61321 .3294 L p F P
0 g
s
.652 .757 .927 r
.61321 .3294 m .62406 .32553 L .62135 .32195 L p F P
0 g
s
.652 .757 .927 r
.63496 .32165 m .62406 .32553 L .62677 .32909 L p F P
0 g
s
.652 .757 .927 r
.62677 .32909 m .63765 .32522 L .63496 .32165 L p F P
0 g
s
.652 .757 .927 r
.64857 .32134 m .63765 .32522 L .64033 .32878 L p F P
0 g
s
.652 .757 .927 r
.64033 .32878 m .65123 .32491 L .64857 .32134 L p F P
0 g
s
.652 .757 .927 r
.66218 .32102 m .65123 .32491 L .65389 .32848 L p F P
0 g
s
.652 .757 .927 r
.65389 .32848 m .66482 .3246 L .66218 .32102 L p F P
0 g
s
.652 .757 .926 r
.6758 .32071 m .66482 .3246 L .66746 .32817 L p F P
0 g
s
.652 .757 .926 r
.66746 .32817 m .67842 .32429 L .6758 .32071 L p F P
0 g
s
.652 .757 .926 r
.68943 .32039 m .67842 .32429 L .68103 .32786 L p F P
0 g
s
.652 .757 .926 r
.68103 .32786 m .69202 .32398 L .68943 .32039 L p F P
0 g
s
.652 .757 .926 r
.70306 .32008 m .69202 .32398 L .6946 .32754 L p F P
0 g
s
.652 .757 .926 r
.6946 .32754 m .70562 .32366 L .70306 .32008 L p F P
0 g
s
.652 .757 .927 r
.61862 .31837 m .60774 .32226 L .61048 .32584 L p F P
0 g
s
.652 .757 .927 r
.61048 .32584 m .62135 .32195 L .61862 .31837 L p F P
0 g
s
.652 .757 .927 r
.63226 .31806 m .62135 .32195 L .62406 .32553 L p F P
0 g
s
.652 .757 .927 r
.62406 .32553 m .63496 .32165 L .63226 .31806 L p F P
0 g
s
.652 .757 .926 r
.64589 .31774 m .63496 .32165 L .63765 .32522 L p F P
0 g
s
.652 .757 .926 r
.63765 .32522 m .64857 .32134 L .64589 .31774 L p F P
0 g
s
.652 .757 .926 r
.65953 .31743 m .64857 .32134 L .65123 .32491 L p F P
0 g
s
.652 .757 .926 r
.65123 .32491 m .66218 .32102 L .65953 .31743 L p F P
0 g
s
.652 .757 .926 r
.67318 .31712 m .66218 .32102 L .66482 .3246 L p F P
0 g
s
.652 .757 .926 r
.66482 .3246 m .6758 .32071 L .67318 .31712 L p F P
0 g
s
.652 .757 .926 r
.68683 .3168 m .6758 .32071 L .67842 .32429 L p F P
0 g
s
.652 .757 .926 r
.67842 .32429 m .68943 .32039 L .68683 .3168 L p F P
0 g
s
.652 .757 .926 r
.70048 .31648 m .68943 .32039 L .69202 .32398 L p F P
0 g
s
.652 .757 .926 r
.69202 .32398 m .70306 .32008 L .70048 .31648 L p F P
0 g
s
.652 .757 .926 r
.62955 .31445 m .61862 .31837 L .62135 .32195 L p F P
0 g
s
.652 .757 .926 r
.62135 .32195 m .63226 .31806 L .62955 .31445 L p F P
0 g
s
.652 .757 .926 r
.64321 .31414 m .63226 .31806 L .63496 .32165 L p F P
0 g
s
.652 .757 .926 r
.63496 .32165 m .64589 .31774 L .64321 .31414 L p F P
0 g
s
.652 .757 .926 r
.65687 .31382 m .64589 .31774 L .64857 .32134 L p F P
0 g
s
.652 .757 .926 r
.64857 .32134 m .65953 .31743 L .65687 .31382 L p F P
0 g
s
.652 .757 .926 r
.67054 .31351 m .65953 .31743 L .66218 .32102 L p F P
0 g
s
.652 .757 .926 r
.66218 .32102 m .67318 .31712 L .67054 .31351 L p F P
0 g
s
.652 .757 .926 r
.68422 .31319 m .67318 .31712 L .6758 .32071 L p F P
0 g
s
.652 .757 .926 r
.6758 .32071 m .68683 .3168 L .68422 .31319 L p F P
0 g
s
.652 .757 .926 r
.6979 .31287 m .68683 .3168 L .68943 .32039 L p F P
0 g
s
.652 .757 .926 r
.68943 .32039 m .70048 .31648 L .6979 .31287 L p F P
0 g
s
.652 .757 .926 r
.64051 .31052 m .62955 .31445 L .63226 .31806 L p F P
0 g
s
.652 .757 .926 r
.63226 .31806 m .64321 .31414 L .64051 .31052 L p F P
0 g
s
.652 .757 .926 r
.65421 .3102 m .64321 .31414 L .64589 .31774 L p F P
0 g
s
.652 .757 .926 r
.64589 .31774 m .65687 .31382 L .65421 .3102 L p F P
0 g
s
.652 .757 .926 r
.6679 .30989 m .65687 .31382 L .65953 .31743 L p F P
0 g
s
.652 .757 .926 r
.65953 .31743 m .67054 .31351 L .6679 .30989 L p F P
0 g
s
.652 .757 .926 r
.6816 .30957 m .67054 .31351 L .67318 .31712 L p F P
0 g
s
.652 .757 .926 r
.67318 .31712 m .68422 .31319 L .6816 .30957 L p F P
0 g
s
.652 .757 .926 r
.6953 .30924 m .68422 .31319 L .68683 .3168 L p F P
0 g
s
.652 .757 .926 r
.68683 .3168 m .6979 .31287 L .6953 .30924 L p F P
0 g
s
.652 .757 .926 r
.65153 .30657 m .64051 .31052 L .64321 .31414 L p F P
0 g
s
.652 .757 .926 r
.64321 .31414 m .65421 .3102 L .65153 .30657 L p F P
0 g
s
.652 .757 .926 r
.66525 .30625 m .65421 .3102 L .65687 .31382 L p F P
0 g
s
.652 .757 .926 r
.65687 .31382 m .6679 .30989 L .66525 .30625 L p F P
0 g
s
.652 .757 .926 r
.67897 .30593 m .6679 .30989 L .67054 .31351 L p F P
0 g
s
.652 .757 .926 r
.67054 .31351 m .6816 .30957 L .67897 .30593 L p F P
0 g
s
.652 .757 .926 r
.6927 .3056 m .6816 .30957 L .68422 .31319 L p F P
0 g
s
.652 .757 .926 r
.68422 .31319 m .6953 .30924 L .6927 .3056 L p F P
0 g
s
.652 .757 .926 r
.66258 .3026 m .65153 .30657 L .65421 .3102 L p F P
0 g
s
.652 .757 .926 r
.65421 .3102 m .66525 .30625 L .66258 .3026 L p F P
0 g
s
.652 .757 .926 r
.67633 .30227 m .66525 .30625 L .6679 .30989 L p F P
0 g
s
.652 .757 .926 r
.6679 .30989 m .67897 .30593 L .67633 .30227 L p F P
0 g
s
.652 .757 .926 r
.69008 .30195 m .67897 .30593 L .6816 .30957 L p F P
0 g
s
.652 .757 .926 r
.6816 .30957 m .6927 .3056 L .69008 .30195 L p F P
0 g
s
.652 .757 .926 r
.67368 .29861 m .66258 .3026 L .66525 .30625 L p F P
0 g
s
.652 .757 .926 r
.66525 .30625 m .67633 .30227 L .67368 .29861 L p F P
0 g
s
.652 .757 .926 r
.68746 .29828 m .67633 .30227 L .67897 .30593 L p F P
0 g
s
.652 .757 .926 r
.67897 .30593 m .69008 .30195 L .68746 .29828 L p F P
0 g
s
.652 .757 .926 r
.68483 .2946 m .67368 .29861 L .67633 .30227 L p F P
0 g
s
.652 .757 .926 r
.67633 .30227 m .68746 .29828 L .68483 .2946 L p F P
0 g
s
.25 Mabswid
.67831 0 m
.94247 .42094 L
s
.94247 .42094 m
1 .84185 L
s
1 .84185 m
.70509 .46146 L
s
.70509 .46146 m
.67831 0 L
s
.06979 .24949 m
0 .68989 L
s
0 .68989 m
.70509 .46146 L
s
.70509 .46146 m
.67831 0 L
s
.67831 0 m
.06979 .24949 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0111908 0.97619 0.458825 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00998489 1.01529 0 1.01529 [
[ 0 0 0 0 ]
[ 1 .97483 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06283 .27285 m
0 .79565 L
s
0 .79565 m
.24085 .97483 L
s
.24085 .97483 m
.27039 .47798 L
s
.27039 .47798 m
.06283 .27285 L
s
.7767 0 m
.93606 .25393 L
s
.93606 .25393 m
1 .77889 L
s
1 .77889 m
.82258 .55004 L
s
.82258 .55004 m
.7767 0 L
s
.06283 .27285 m
0 .79565 L
s
0 .79565 m
.82258 .55004 L
s
.82258 .55004 m
.7767 0 L
s
.7767 0 m
.06283 .27285 L
s
.27039 .47798 m
.93606 .25393 L
s
.93606 .25393 m
1 .77889 L
s
1 .77889 m
.24085 .97483 L
s
.24085 .97483 m
.27039 .47798 L
s
0 0 m
1 0 L
1 .97483 L
0 .97483 L
closepath
clip
newpath
.5 Mabswid
.648 .759 .93 r
.27268 .76886 m .26298 .77162 L .25991 .76905 L p F P
0 g
s
.648 .759 .93 r
.25991 .76905 m .26963 .76627 L .27268 .76886 L p F P
0 g
s
.648 .759 .93 r
.26963 .76627 m .25991 .76905 L .25684 .76647 L p F P
0 g
s
.648 .759 .93 r
.28242 .76608 m .27268 .76886 L .26963 .76627 L p F P
0 g
s
.648 .759 .93 r
.25684 .76647 m .26656 .76368 L .26963 .76627 L p F P
0 g
s
.648 .759 .93 r
.26656 .76368 m .25684 .76647 L .25375 .76388 L p F P
0 g
s
.648 .759 .93 r
.26963 .76627 m .27937 .76349 L .28242 .76608 L p F P
0 g
s
.649 .759 .93 r
.27937 .76349 m .26963 .76627 L .26656 .76368 L p F P
0 g
s
.649 .759 .93 r
.29219 .76329 m .28242 .76608 L .27937 .76349 L p F P
0 g
s
.648 .759 .93 r
.25375 .76388 m .26348 .76109 L .26656 .76368 L p F P
0 g
s
.648 .758 .93 r
.26348 .76109 m .25375 .76388 L .25066 .76128 L p F P
0 g
s
.649 .759 .93 r
.26656 .76368 m .27631 .76089 L .27937 .76349 L p F P
0 g
s
.649 .758 .93 r
.27631 .76089 m .26656 .76368 L .26348 .76109 L p F P
0 g
s
.649 .759 .93 r
.27937 .76349 m .28915 .76069 L .29219 .76329 L p F P
0 g
s
.649 .758 .929 r
.28915 .76069 m .27937 .76349 L .27631 .76089 L p F P
0 g
s
.649 .758 .929 r
.30198 .76049 m .29219 .76329 L .28915 .76069 L p F P
0 g
s
.648 .758 .93 r
.25066 .76128 m .2604 .75848 L .26348 .76109 L p F P
0 g
s
.649 .758 .929 r
.2604 .75848 m .25066 .76128 L .24755 .75868 L p F P
0 g
s
.649 .758 .93 r
.26348 .76109 m .27325 .75828 L .27631 .76089 L p F P
0 g
s
.649 .758 .929 r
.27325 .75828 m .26348 .76109 L .2604 .75848 L p F P
0 g
s
.649 .758 .929 r
.27631 .76089 m .2861 .75808 L .28915 .76069 L p F P
0 g
s
.649 .758 .929 r
.2861 .75808 m .27631 .76089 L .27325 .75828 L p F P
0 g
s
.649 .758 .929 r
.28915 .76069 m .29895 .75788 L .30198 .76049 L p F P
0 g
s
.649 .758 .929 r
.29895 .75788 m .28915 .76069 L .2861 .75808 L p F P
0 g
s
.649 .758 .929 r
.31181 .75767 m .30198 .76049 L .29895 .75788 L p F P
0 g
s
.649 .758 .929 r
.24755 .75868 m .25731 .75586 L .2604 .75848 L p F P
0 g
s
.649 .758 .929 r
.25731 .75586 m .24755 .75868 L .24444 .75606 L p F P
0 g
s
.649 .758 .929 r
.2604 .75848 m .27017 .75566 L .27325 .75828 L p F P
0 g
s
.649 .758 .929 r
.27017 .75566 m .2604 .75848 L .25731 .75586 L p F P
0 g
s
.649 .758 .929 r
.27325 .75828 m .28304 .75546 L .2861 .75808 L p F P
0 g
s
.649 .758 .929 r
.28304 .75546 m .27325 .75828 L .27017 .75566 L p F P
0 g
s
.649 .758 .929 r
.2861 .75808 m .29591 .75526 L .29895 .75788 L p F P
0 g
s
.649 .758 .929 r
.29591 .75526 m .2861 .75808 L .28304 .75546 L p F P
0 g
s
.649 .758 .929 r
.29895 .75788 m .30879 .75505 L .31181 .75767 L p F P
0 g
s
.649 .758 .929 r
.30879 .75505 m .29895 .75788 L .29591 .75526 L p F P
0 g
s
.649 .758 .929 r
.32167 .75485 m .31181 .75767 L .30879 .75505 L p F P
0 g
s
.649 .758 .929 r
.24444 .75606 m .2542 .75324 L .25731 .75586 L p F P
0 g
s
.649 .758 .929 r
.2542 .75324 m .24444 .75606 L .24132 .75344 L p F P
0 g
s
.649 .758 .929 r
.25731 .75586 m .26709 .75304 L .27017 .75566 L p F P
0 g
s
.649 .758 .929 r
.26709 .75304 m .25731 .75586 L .2542 .75324 L p F P
0 g
s
.649 .758 .929 r
.27017 .75566 m .27998 .75284 L .28304 .75546 L p F P
0 g
s
.649 .758 .929 r
.27998 .75284 m .27017 .75566 L .26709 .75304 L p F P
0 g
s
.649 .758 .929 r
.28304 .75546 m .29287 .75263 L .29591 .75526 L p F P
0 g
s
.649 .758 .929 r
.29287 .75263 m .28304 .75546 L .27998 .75284 L p F P
0 g
s
.649 .758 .929 r
.29591 .75526 m .30576 .75243 L .30879 .75505 L p F P
0 g
s
.649 .758 .929 r
.30576 .75243 m .29591 .75526 L .29287 .75263 L p F P
0 g
s
.649 .758 .929 r
.30879 .75505 m .31866 .75222 L .32167 .75485 L p F P
0 g
s
.649 .758 .929 r
.31866 .75222 m .30879 .75505 L .30576 .75243 L p F P
0 g
s
.649 .758 .929 r
.33156 .75201 m .32167 .75485 L .31866 .75222 L p F P
0 g
s
.649 .758 .929 r
.24132 .75344 m .25109 .75061 L .2542 .75324 L p F P
0 g
s
.649 .758 .929 r
.25109 .75061 m .24132 .75344 L .23819 .75081 L p F P
0 g
s
.649 .758 .929 r
.2542 .75324 m .264 .75041 L .26709 .75304 L p F P
0 g
s
.649 .758 .929 r
.264 .75041 m .2542 .75324 L .25109 .75061 L p F P
0 g
s
.649 .758 .929 r
.26709 .75304 m .2769 .7502 L .27998 .75284 L p F P
0 g
s
.649 .758 .929 r
.2769 .7502 m .26709 .75304 L .264 .75041 L p F P
0 g
s
.649 .758 .929 r
.27998 .75284 m .28981 .75 L .29287 .75263 L p F P
0 g
s
.649 .758 .929 r
.28981 .75 m .27998 .75284 L .2769 .7502 L p F P
0 g
s
.649 .758 .929 r
.29287 .75263 m .30273 .74979 L .30576 .75243 L p F P
0 g
s
.649 .758 .929 r
.30273 .74979 m .29287 .75263 L .28981 .75 L p F P
0 g
s
.649 .758 .929 r
.30576 .75243 m .31564 .74958 L .31866 .75222 L p F P
0 g
s
.649 .758 .929 r
.31564 .74958 m .30576 .75243 L .30273 .74979 L p F P
0 g
s
.649 .758 .929 r
.31866 .75222 m .32856 .74937 L .33156 .75201 L p F P
0 g
s
.649 .758 .929 r
.32856 .74937 m .31866 .75222 L .31564 .74958 L p F P
0 g
s
.649 .758 .929 r
.34148 .74916 m .33156 .75201 L .32856 .74937 L p F P
0 g
s
.649 .758 .929 r
.23819 .75081 m .24797 .74797 L .25109 .75061 L p F P
0 g
s
.649 .758 .929 r
.24797 .74797 m .23819 .75081 L .23505 .74817 L p F P
0 g
s
.649 .758 .929 r
.25109 .75061 m .26089 .74777 L .264 .75041 L p F P
0 g
s
.649 .758 .929 r
.26089 .74777 m .25109 .75061 L .24797 .74797 L p F P
0 g
s
.649 .758 .929 r
.264 .75041 m .27382 .74756 L .2769 .7502 L p F P
0 g
s
.649 .758 .929 r
.27382 .74756 m .264 .75041 L .26089 .74777 L p F P
0 g
s
.649 .758 .929 r
.2769 .7502 m .28675 .74735 L .28981 .75 L p F P
0 g
s
.649 .758 .929 r
.28675 .74735 m .2769 .7502 L .27382 .74756 L p F P
0 g
s
.649 .758 .929 r
.28981 .75 m .29968 .74715 L .30273 .74979 L p F P
0 g
s
.649 .758 .929 r
.29968 .74715 m .28981 .75 L .28675 .74735 L p F P
0 g
s
.649 .758 .929 r
.30273 .74979 m .31261 .74694 L .31564 .74958 L p F P
0 g
s
.649 .758 .929 r
.31261 .74694 m .30273 .74979 L .29968 .74715 L p F P
0 g
s
.649 .758 .929 r
.31564 .74958 m .32555 .74673 L .32856 .74937 L p F P
0 g
s
.649 .758 .929 r
.32555 .74673 m .31564 .74958 L .31261 .74694 L p F P
0 g
s
.649 .758 .929 r
.32856 .74937 m .33849 .74651 L .34148 .74916 L p F P
0 g
s
.649 .758 .929 r
.33849 .74651 m .32856 .74937 L .32555 .74673 L p F P
0 g
s
.649 .758 .929 r
.35144 .7463 m .34148 .74916 L .33849 .74651 L p F P
0 g
s
.649 .758 .929 r
.23505 .74817 m .24484 .74532 L .24797 .74797 L p F P
0 g
s
.649 .758 .929 r
.24484 .74532 m .23505 .74817 L .23191 .74552 L p F P
0 g
s
.649 .758 .929 r
.24797 .74797 m .25778 .74512 L .26089 .74777 L p F P
0 g
s
.649 .758 .929 r
.25778 .74512 m .24797 .74797 L .24484 .74532 L p F P
0 g
s
.649 .758 .929 r
.26089 .74777 m .27073 .74491 L .27382 .74756 L p F P
0 g
s
.649 .758 .929 r
.27073 .74491 m .26089 .74777 L .25778 .74512 L p F P
0 g
s
.649 .758 .929 r
.27382 .74756 m .28367 .7447 L .28675 .74735 L p F P
0 g
s
.649 .758 .929 r
.28367 .7447 m .27382 .74756 L .27073 .74491 L p F P
0 g
s
.649 .758 .929 r
.28675 .74735 m .29662 .74449 L .29968 .74715 L p F P
0 g
s
.649 .758 .929 r
.29662 .74449 m .28675 .74735 L .28367 .7447 L p F P
0 g
s
.649 .758 .929 r
.29968 .74715 m .30958 .74428 L .31261 .74694 L p F P
0 g
s
.649 .758 .929 r
.30958 .74428 m .29968 .74715 L .29662 .74449 L p F P
0 g
s
.649 .758 .929 r
.31261 .74694 m .32253 .74407 L .32555 .74673 L p F P
0 g
s
.649 .758 .929 r
.32253 .74407 m .31261 .74694 L .30958 .74428 L p F P
0 g
s
.649 .758 .929 r
.32555 .74673 m .33549 .74386 L .33849 .74651 L p F P
0 g
s
.649 .758 .929 r
.33549 .74386 m .32555 .74673 L .32253 .74407 L p F P
0 g
s
.649 .758 .929 r
.33849 .74651 m .34846 .74364 L .35144 .7463 L p F P
0 g
s
.649 .758 .929 r
.34846 .74364 m .33849 .74651 L .33549 .74386 L p F P
0 g
s
.649 .758 .929 r
.36142 .74343 m .35144 .7463 L .34846 .74364 L p F P
0 g
s
.649 .758 .929 r
.23191 .74552 m .24171 .74266 L .24484 .74532 L p F P
0 g
s
.649 .758 .929 r
.24171 .74266 m .23191 .74552 L .22875 .74286 L p F P
0 g
s
.649 .758 .929 r
.24484 .74532 m .25466 .74246 L .25778 .74512 L p F P
0 g
s
.649 .758 .929 r
.25466 .74246 m .24484 .74532 L .24171 .74266 L p F P
0 g
s
.649 .758 .929 r
.25778 .74512 m .26763 .74225 L .27073 .74491 L p F P
0 g
s
.649 .758 .929 r
.26763 .74225 m .25778 .74512 L .25466 .74246 L p F P
0 g
s
.649 .758 .929 r
.27073 .74491 m .28059 .74204 L .28367 .7447 L p F P
0 g
s
.649 .758 .929 r
.28059 .74204 m .27073 .74491 L .26763 .74225 L p F P
0 g
s
.649 .758 .929 r
.28367 .7447 m .29356 .74183 L .29662 .74449 L p F P
0 g
s
.649 .758 .929 r
.29356 .74183 m .28367 .7447 L .28059 .74204 L p F P
0 g
s
.649 .758 .929 r
.29662 .74449 m .30653 .74162 L .30958 .74428 L p F P
0 g
s
.649 .758 .929 r
.30653 .74162 m .29662 .74449 L .29356 .74183 L p F P
0 g
s
.649 .758 .929 r
.30958 .74428 m .31951 .74141 L .32253 .74407 L p F P
0 g
s
.649 .758 .929 r
.31951 .74141 m .30958 .74428 L .30653 .74162 L p F P
0 g
s
.649 .758 .929 r
.32253 .74407 m .33249 .74119 L .33549 .74386 L p F P
0 g
s
.649 .758 .929 r
.33249 .74119 m .32253 .74407 L .31951 .74141 L p F P
0 g
s
.649 .758 .929 r
.33549 .74386 m .34547 .74098 L .34846 .74364 L p F P
0 g
s
.649 .758 .929 r
.34547 .74098 m .33549 .74386 L .33249 .74119 L p F P
0 g
s
.649 .758 .929 r
.34846 .74364 m .35845 .74076 L .36142 .74343 L p F P
0 g
s
.65 .758 .929 r
.35845 .74076 m .34846 .74364 L .34547 .74098 L p F P
0 g
s
.65 .758 .929 r
.37144 .74054 m .36142 .74343 L .35845 .74076 L p F P
0 g
s
.649 .758 .929 r
.22875 .74286 m .23856 .73999 L .24171 .74266 L p F P
0 g
s
.649 .758 .929 r
.23856 .73999 m .22875 .74286 L .22558 .7402 L p F P
0 g
s
.649 .758 .929 r
.24171 .74266 m .25153 .73979 L .25466 .74246 L p F P
0 g
s
.649 .758 .929 r
.25153 .73979 m .24171 .74266 L .23856 .73999 L p F P
0 g
s
.649 .758 .929 r
.25466 .74246 m .26452 .73958 L .26763 .74225 L p F P
0 g
s
.649 .758 .929 r
.26452 .73958 m .25466 .74246 L .25153 .73979 L p F P
0 g
s
.649 .758 .929 r
.26763 .74225 m .2775 .73937 L .28059 .74204 L p F P
0 g
s
.649 .758 .929 r
.2775 .73937 m .26763 .74225 L .26452 .73958 L p F P
0 g
s
.649 .758 .929 r
.28059 .74204 m .29049 .73916 L .29356 .74183 L p F P
0 g
s
.649 .758 .929 r
.29049 .73916 m .28059 .74204 L .2775 .73937 L p F P
0 g
s
.649 .758 .929 r
.29356 .74183 m .30348 .73895 L .30653 .74162 L p F P
0 g
s
.649 .758 .929 r
.30348 .73895 m .29356 .74183 L .29049 .73916 L p F P
0 g
s
.649 .758 .929 r
.30653 .74162 m .31647 .73874 L .31951 .74141 L p F P
0 g
s
.649 .758 .929 r
.31647 .73874 m .30653 .74162 L .30348 .73895 L p F P
0 g
s
.649 .758 .929 r
.31951 .74141 m .32947 .73852 L .33249 .74119 L p F P
0 g
s
.649 .758 .929 r
.32947 .73852 m .31951 .74141 L .31647 .73874 L p F P
0 g
s
.649 .758 .929 r
.33249 .74119 m .34247 .73831 L .34547 .74098 L p F P
0 g
s
.65 .758 .929 r
.34247 .73831 m .33249 .74119 L .32947 .73852 L p F P
0 g
s
.65 .758 .929 r
.34547 .74098 m .35547 .73809 L .35845 .74076 L p F P
0 g
s
.65 .758 .929 r
.35547 .73809 m .34547 .74098 L .34247 .73831 L p F P
0 g
s
.65 .758 .929 r
.35845 .74076 m .36848 .73787 L .37144 .74054 L p F P
0 g
s
.65 .758 .929 r
.36848 .73787 m .35845 .74076 L .35547 .73809 L p F P
0 g
s
.65 .758 .929 r
.38149 .73765 m .37144 .74054 L .36848 .73787 L p F P
0 g
s
.649 .758 .929 r
.22558 .7402 m .2354 .73732 L .23856 .73999 L p F P
0 g
s
.649 .758 .929 r
.2354 .73732 m .22558 .7402 L .22241 .73752 L p F P
0 g
s
.649 .758 .929 r
.23856 .73999 m .2484 .73711 L .25153 .73979 L p F P
0 g
s
.649 .758 .929 r
.2484 .73711 m .23856 .73999 L .2354 .73732 L p F P
0 g
s
.649 .758 .929 r
.25153 .73979 m .2614 .73691 L .26452 .73958 L p F P
0 g
s
.649 .758 .929 r
.2614 .73691 m .25153 .73979 L .2484 .73711 L p F P
0 g
s
.649 .758 .929 r
.26452 .73958 m .2744 .7367 L .2775 .73937 L p F P
0 g
s
.649 .758 .929 r
.2744 .7367 m .26452 .73958 L .2614 .73691 L p F P
0 g
s
.649 .758 .929 r
.2775 .73937 m .2874 .73649 L .29049 .73916 L p F P
0 g
s
.649 .758 .929 r
.2874 .73649 m .2775 .73937 L .2744 .7367 L p F P
0 g
s
.649 .758 .929 r
.29049 .73916 m .30041 .73627 L .30348 .73895 L p F P
0 g
s
.649 .758 .929 r
.30041 .73627 m .29049 .73916 L .2874 .73649 L p F P
0 g
s
.649 .758 .929 r
.30348 .73895 m .31343 .73606 L .31647 .73874 L p F P
0 g
s
.649 .758 .929 r
.31343 .73606 m .30348 .73895 L .30041 .73627 L p F P
0 g
s
.649 .758 .929 r
.31647 .73874 m .32644 .73584 L .32947 .73852 L p F P
0 g
s
.649 .758 .929 r
.32644 .73584 m .31647 .73874 L .31343 .73606 L p F P
0 g
s
.65 .758 .929 r
.32947 .73852 m .33946 .73563 L .34247 .73831 L p F P
0 g
s
.65 .758 .929 r
.33946 .73563 m .32947 .73852 L .32644 .73584 L p F P
0 g
s
.65 .758 .929 r
.34247 .73831 m .35248 .73541 L .35547 .73809 L p F P
0 g
s
.65 .758 .929 r
.35248 .73541 m .34247 .73831 L .33946 .73563 L p F P
0 g
s
.65 .758 .929 r
.35547 .73809 m .36551 .73519 L .36848 .73787 L p F P
0 g
s
.65 .758 .929 r
.36551 .73519 m .35547 .73809 L .35248 .73541 L p F P
0 g
s
.65 .758 .929 r
.36848 .73787 m .37854 .73497 L .38149 .73765 L p F P
0 g
s
.65 .758 .929 r
.37854 .73497 m .36848 .73787 L .36551 .73519 L p F P
0 g
s
.649 .758 .929 r
.22241 .73752 m .23223 .73464 L .2354 .73732 L p F P
0 g
s
.649 .758 .929 r
.23223 .73464 m .22241 .73752 L .21922 .73484 L p F P
0 g
s
.65 .758 .929 r
.39157 .73475 m .38149 .73765 L .37854 .73497 L p F P
0 g
s
.649 .758 .929 r
.2354 .73732 m .24525 .73443 L .2484 .73711 L p F P
0 g
s
.649 .758 .929 r
.24525 .73443 m .2354 .73732 L .23223 .73464 L p F P
0 g
s
.649 .758 .929 r
.2484 .73711 m .25827 .73422 L .2614 .73691 L p F P
0 g
s
.649 .758 .929 r
.25827 .73422 m .2484 .73711 L .24525 .73443 L p F P
0 g
s
.649 .758 .929 r
.2614 .73691 m .27129 .73401 L .2744 .7367 L p F P
0 g
s
.649 .758 .929 r
.27129 .73401 m .2614 .73691 L .25827 .73422 L p F P
0 g
s
.649 .758 .929 r
.2744 .7367 m .28431 .7338 L .2874 .73649 L p F P
0 g
s
.649 .758 .929 r
.28431 .7338 m .2744 .7367 L .27129 .73401 L p F P
0 g
s
.649 .758 .929 r
.2874 .73649 m .29734 .73359 L .30041 .73627 L p F P
0 g
s
.649 .758 .929 r
.29734 .73359 m .2874 .73649 L .28431 .7338 L p F P
0 g
s
.649 .758 .929 r
.30041 .73627 m .31037 .73337 L .31343 .73606 L p F P
0 g
s
.649 .758 .929 r
.31037 .73337 m .30041 .73627 L .29734 .73359 L p F P
0 g
s
.649 .758 .929 r
.31343 .73606 m .32341 .73315 L .32644 .73584 L p F P
0 g
s
.65 .758 .929 r
.32341 .73315 m .31343 .73606 L .31037 .73337 L p F P
0 g
s
.65 .758 .929 r
.32644 .73584 m .33645 .73294 L .33946 .73563 L p F P
0 g
s
.65 .758 .929 r
.33645 .73294 m .32644 .73584 L .32341 .73315 L p F P
0 g
s
.65 .758 .929 r
.33946 .73563 m .34949 .73272 L .35248 .73541 L p F P
0 g
s
.65 .758 .929 r
.34949 .73272 m .33946 .73563 L .33645 .73294 L p F P
0 g
s
.65 .758 .929 r
.35248 .73541 m .36253 .7325 L .36551 .73519 L p F P
0 g
s
.65 .758 .929 r
.36253 .7325 m .35248 .73541 L .34949 .73272 L p F P
0 g
s
.65 .758 .929 r
.36551 .73519 m .37558 .73228 L .37854 .73497 L p F P
0 g
s
.65 .758 .929 r
.37558 .73228 m .36551 .73519 L .36253 .7325 L p F P
0 g
s
.649 .758 .929 r
.21922 .73484 m .22906 .73195 L .23223 .73464 L p F P
0 g
s
.649 .758 .929 r
.22906 .73195 m .21922 .73484 L .21603 .73215 L p F P
0 g
s
.65 .758 .929 r
.37854 .73497 m .38863 .73205 L .39157 .73475 L p F P
0 g
s
.65 .758 .929 r
.38863 .73205 m .37854 .73497 L .37558 .73228 L p F P
0 g
s
.649 .758 .929 r
.23223 .73464 m .24209 .73174 L .24525 .73443 L p F P
0 g
s
.649 .758 .929 r
.24209 .73174 m .23223 .73464 L .22906 .73195 L p F P
0 g
s
.65 .758 .929 r
.40169 .73183 m .39157 .73475 L .38863 .73205 L p F P
0 g
s
.649 .758 .929 r
.24525 .73443 m .25513 .73153 L .25827 .73422 L p F P
0 g
s
.649 .758 .929 r
.25513 .73153 m .24525 .73443 L .24209 .73174 L p F P
0 g
s
.649 .758 .929 r
.25827 .73422 m .26817 .73132 L .27129 .73401 L p F P
0 g
s
.649 .758 .929 r
.26817 .73132 m .25827 .73422 L .25513 .73153 L p F P
0 g
s
.649 .758 .929 r
.27129 .73401 m .28121 .7311 L .28431 .7338 L p F P
0 g
s
.649 .758 .929 r
.28121 .7311 m .27129 .73401 L .26817 .73132 L p F P
0 g
s
.649 .758 .929 r
.28431 .7338 m .29426 .73089 L .29734 .73359 L p F P
0 g
s
.649 .758 .929 r
.29426 .73089 m .28431 .7338 L .28121 .7311 L p F P
0 g
s
.649 .758 .929 r
.29734 .73359 m .30731 .73067 L .31037 .73337 L p F P
0 g
s
.649 .758 .929 r
.30731 .73067 m .29734 .73359 L .29426 .73089 L p F P
0 g
s
.65 .758 .929 r
.31037 .73337 m .32036 .73046 L .32341 .73315 L p F P
0 g
s
.65 .758 .929 r
.32036 .73046 m .31037 .73337 L .30731 .73067 L p F P
0 g
s
.65 .758 .929 r
.32341 .73315 m .33342 .73024 L .33645 .73294 L p F P
0 g
s
.65 .758 .929 r
.33342 .73024 m .32341 .73315 L .32036 .73046 L p F P
0 g
s
.65 .758 .929 r
.33645 .73294 m .34648 .73002 L .34949 .73272 L p F P
0 g
s
.65 .758 .929 r
.34648 .73002 m .33645 .73294 L .33342 .73024 L p F P
0 g
s
.65 .758 .929 r
.34949 .73272 m .35954 .7298 L .36253 .7325 L p F P
0 g
s
.65 .758 .929 r
.35954 .7298 m .34949 .73272 L .34648 .73002 L p F P
0 g
s
.65 .758 .929 r
.36253 .7325 m .37261 .72958 L .37558 .73228 L p F P
0 g
s
.65 .758 .929 r
.37261 .72958 m .36253 .7325 L .35954 .7298 L p F P
0 g
s
.649 .758 .929 r
.21603 .73215 m .22588 .72925 L .22906 .73195 L p F P
0 g
s
.649 .758 .929 r
.22588 .72925 m .21603 .73215 L .21283 .72945 L p F P
0 g
s
.65 .758 .929 r
.37558 .73228 m .38568 .72935 L .38863 .73205 L p F P
0 g
s
.65 .758 .929 r
.38568 .72935 m .37558 .73228 L .37261 .72958 L p F P
0 g
s
.649 .758 .929 r
.22906 .73195 m .23893 .72904 L .24209 .73174 L p F P
0 g
s
.649 .758 .929 r
.23893 .72904 m .22906 .73195 L .22588 .72925 L p F P
0 g
s
.65 .758 .929 r
.38863 .73205 m .39875 .72913 L .40169 .73183 L p F P
0 g
s
.65 .758 .929 r
.39875 .72913 m .38863 .73205 L .38568 .72935 L p F P
0 g
s
.649 .758 .929 r
.24209 .73174 m .25198 .72883 L .25513 .73153 L p F P
0 g
s
.649 .758 .929 r
.25198 .72883 m .24209 .73174 L .23893 .72904 L p F P
0 g
s
.65 .758 .929 r
.41183 .7289 m .40169 .73183 L .39875 .72913 L p F P
0 g
s
.649 .758 .929 r
.25513 .73153 m .26504 .72861 L .26817 .73132 L p F P
0 g
s
.649 .758 .929 r
.26504 .72861 m .25513 .73153 L .25198 .72883 L p F P
0 g
s
.649 .758 .929 r
.26817 .73132 m .2781 .7284 L .28121 .7311 L p F P
0 g
s
.649 .758 .929 r
.2781 .7284 m .26817 .73132 L .26504 .72861 L p F P
0 g
s
.649 .758 .929 r
.28121 .7311 m .29117 .72819 L .29426 .73089 L p F P
0 g
s
.649 .758 .929 r
.29117 .72819 m .28121 .7311 L .2781 .7284 L p F P
0 g
s
.649 .758 .929 r
.29426 .73089 m .30424 .72797 L .30731 .73067 L p F P
0 g
s
.65 .758 .929 r
.30424 .72797 m .29426 .73089 L .29117 .72819 L p F P
0 g
s
.65 .758 .929 r
.30731 .73067 m .31731 .72775 L .32036 .73046 L p F P
0 g
s
.65 .758 .929 r
.31731 .72775 m .30731 .73067 L .30424 .72797 L p F P
0 g
s
.65 .758 .929 r
.32036 .73046 m .33039 .72753 L .33342 .73024 L p F P
0 g
s
.65 .758 .929 r
.33039 .72753 m .32036 .73046 L .31731 .72775 L p F P
0 g
s
.65 .758 .929 r
.33342 .73024 m .34347 .72731 L .34648 .73002 L p F P
0 g
s
.65 .758 .929 r
.34347 .72731 m .33342 .73024 L .33039 .72753 L p F P
0 g
s
.65 .758 .929 r
.34648 .73002 m .35655 .72709 L .35954 .7298 L p F P
0 g
s
.65 .758 .929 r
.35655 .72709 m .34648 .73002 L .34347 .72731 L p F P
0 g
s
.65 .758 .929 r
.35954 .7298 m .36963 .72687 L .37261 .72958 L p F P
0 g
s
.65 .758 .929 r
.36963 .72687 m .35954 .7298 L .35655 .72709 L p F P
0 g
s
.649 .758 .929 r
.21283 .72945 m .22268 .72654 L .22588 .72925 L p F P
0 g
s
.649 .758 .929 r
.22268 .72654 m .21283 .72945 L .20961 .72674 L p F P
0 g
s
.65 .758 .929 r
.37261 .72958 m .38272 .72664 L .38568 .72935 L p F P
0 g
s
.65 .758 .929 r
.38272 .72664 m .37261 .72958 L .36963 .72687 L p F P
0 g
s
.649 .758 .929 r
.22588 .72925 m .23575 .72633 L .23893 .72904 L p F P
0 g
s
.649 .758 .929 r
.23575 .72633 m .22588 .72925 L .22268 .72654 L p F P
0 g
s
.65 .758 .929 r
.38568 .72935 m .39582 .72642 L .39875 .72913 L p F P
0 g
s
.65 .758 .929 r
.39582 .72642 m .38568 .72935 L .38272 .72664 L p F P
0 g
s
.649 .758 .929 r
.23893 .72904 m .24883 .72612 L .25198 .72883 L p F P
0 g
s
.649 .758 .929 r
.24883 .72612 m .23893 .72904 L .23575 .72633 L p F P
0 g
s
.65 .758 .929 r
.39875 .72913 m .40891 .72619 L .41183 .7289 L p F P
0 g
s
.65 .758 .929 r
.40891 .72619 m .39875 .72913 L .39582 .72642 L p F P
0 g
s
.649 .758 .929 r
.25198 .72883 m .2619 .7259 L .26504 .72861 L p F P
0 g
s
.649 .758 .929 r
.2619 .7259 m .25198 .72883 L .24883 .72612 L p F P
0 g
s
.65 .758 .929 r
.42201 .72597 m .41183 .7289 L .40891 .72619 L p F P
0 g
s
.649 .758 .929 r
.26504 .72861 m .27499 .72569 L .2781 .7284 L p F P
0 g
s
.649 .758 .929 r
.27499 .72569 m .26504 .72861 L .2619 .7259 L p F P
0 g
s
.649 .758 .929 r
.2781 .7284 m .28807 .72547 L .29117 .72819 L p F P
0 g
s
.649 .758 .929 r
.28807 .72547 m .2781 .7284 L .27499 .72569 L p F P
0 g
s
.65 .758 .929 r
.29117 .72819 m .30116 .72526 L .30424 .72797 L p F P
0 g
s
.65 .758 .929 r
.30116 .72526 m .29117 .72819 L .28807 .72547 L p F P
0 g
s
.65 .758 .929 r
.30424 .72797 m .31425 .72504 L .31731 .72775 L p F P
0 g
s
.65 .758 .929 r
.31425 .72504 m .30424 .72797 L .30116 .72526 L p F P
0 g
s
.65 .758 .929 r
.31731 .72775 m .32734 .72482 L .33039 .72753 L p F P
0 g
s
.65 .758 .929 r
.32734 .72482 m .31731 .72775 L .31425 .72504 L p F P
0 g
s
.65 .758 .929 r
.33039 .72753 m .34044 .7246 L .34347 .72731 L p F P
0 g
s
.65 .758 .929 r
.34044 .7246 m .33039 .72753 L .32734 .72482 L p F P
0 g
s
.65 .758 .929 r
.34347 .72731 m .35354 .72437 L .35655 .72709 L p F P
0 g
s
.65 .758 .929 r
.35354 .72437 m .34347 .72731 L .34044 .7246 L p F P
0 g
s
.65 .758 .929 r
.35655 .72709 m .36665 .72415 L .36963 .72687 L p F P
0 g
s
.65 .758 .929 r
.36665 .72415 m .35655 .72709 L .35354 .72437 L p F P
0 g
s
.649 .758 .929 r
.20961 .72674 m .21948 .72382 L .22268 .72654 L p F P
0 g
s
.649 .758 .929 r
.21948 .72382 m .20961 .72674 L .20639 .72403 L p F P
0 g
s
.65 .758 .929 r
.36963 .72687 m .37976 .72393 L .38272 .72664 L p F P
0 g
s
.65 .758 .929 r
.37976 .72393 m .36963 .72687 L .36665 .72415 L p F P
0 g
s
.649 .758 .929 r
.23257 .72361 m .22268 .72654 L .21948 .72382 L p F P
0 g
s
.649 .758 .929 r
.22268 .72654 m .23257 .72361 L .23575 .72633 L p F P
0 g
s
.65 .758 .929 r
.38272 .72664 m .39287 .7237 L .39582 .72642 L p F P
0 g
s
.65 .758 .929 r
.39287 .7237 m .38272 .72664 L .37976 .72393 L p F P
0 g
s
.649 .758 .929 r
.23575 .72633 m .24566 .7234 L .24883 .72612 L p F P
0 g
s
.649 .758 .929 r
.24566 .7234 m .23575 .72633 L .23257 .72361 L p F P
0 g
s
.65 .758 .929 r
.39582 .72642 m .40598 .72348 L .40891 .72619 L p F P
0 g
s
.65 .758 .929 r
.40598 .72348 m .39582 .72642 L .39287 .7237 L p F P
0 g
s
.649 .758 .929 r
.24883 .72612 m .25876 .72318 L .2619 .7259 L p F P
0 g
s
.649 .758 .929 r
.25876 .72318 m .24883 .72612 L .24566 .7234 L p F P
0 g
s
.65 .758 .929 r
.40891 .72619 m .4191 .72325 L .42201 .72597 L p F P
0 g
s
.65 .758 .928 r
.4191 .72325 m .40891 .72619 L .40598 .72348 L p F P
0 g
s
.649 .758 .929 r
.2619 .7259 m .27186 .72297 L .27499 .72569 L p F P
0 g
s
.649 .758 .929 r
.27186 .72297 m .2619 .7259 L .25876 .72318 L p F P
0 g
s
.65 .758 .928 r
.43222 .72302 m .42201 .72597 L .4191 .72325 L p F P
0 g
s
.649 .758 .929 r
.27499 .72569 m .28496 .72275 L .28807 .72547 L p F P
0 g
s
.65 .758 .929 r
.28496 .72275 m .27499 .72569 L .27186 .72297 L p F P
0 g
s
.65 .758 .929 r
.28807 .72547 m .29807 .72253 L .30116 .72526 L p F P
0 g
s
.65 .758 .929 r
.29807 .72253 m .28807 .72547 L .28496 .72275 L p F P
0 g
s
.65 .758 .929 r
.30116 .72526 m .31118 .72232 L .31425 .72504 L p F P
0 g
s
.65 .758 .929 r
.31118 .72232 m .30116 .72526 L .29807 .72253 L p F P
0 g
s
.65 .758 .929 r
.31425 .72504 m .32429 .72209 L .32734 .72482 L p F P
0 g
s
.65 .758 .929 r
.32429 .72209 m .31425 .72504 L .31118 .72232 L p F P
0 g
s
.65 .758 .929 r
.32734 .72482 m .33741 .72187 L .34044 .7246 L p F P
0 g
s
.65 .758 .929 r
.33741 .72187 m .32734 .72482 L .32429 .72209 L p F P
0 g
s
.65 .758 .929 r
.34044 .7246 m .35053 .72165 L .35354 .72437 L p F P
0 g
s
.65 .758 .929 r
.35053 .72165 m .34044 .7246 L .33741 .72187 L p F P
0 g
s
.65 .758 .929 r
.35354 .72437 m .36365 .72143 L .36665 .72415 L p F P
0 g
s
.65 .758 .928 r
.36365 .72143 m .35354 .72437 L .35053 .72165 L p F P
0 g
s
.649 .758 .929 r
.20639 .72403 m .21627 .72109 L .21948 .72382 L p F P
0 g
s
.649 .758 .929 r
.21627 .72109 m .20639 .72403 L .20316 .7213 L p F P
0 g
s
.65 .758 .929 r
.36665 .72415 m .37678 .7212 L .37976 .72393 L p F P
0 g
s
.65 .758 .928 r
.37678 .7212 m .36665 .72415 L .36365 .72143 L p F P
0 g
s
.649 .758 .929 r
.21948 .72382 m .22937 .72088 L .23257 .72361 L p F P
0 g
s
.649 .758 .929 r
.22937 .72088 m .21948 .72382 L .21627 .72109 L p F P
0 g
s
.65 .758 .929 r
.37976 .72393 m .38991 .72098 L .39287 .7237 L p F P
0 g
s
.65 .758 .928 r
.38991 .72098 m .37976 .72393 L .37678 .7212 L p F P
0 g
s
.649 .758 .929 r
.24249 .72067 m .23257 .72361 L .22937 .72088 L p F P
0 g
s
.649 .758 .929 r
.23257 .72361 m .24249 .72067 L .24566 .7234 L p F P
0 g
s
.65 .758 .929 r
.39287 .7237 m .40304 .72075 L .40598 .72348 L p F P
0 g
s
.65 .758 .928 r
.40304 .72075 m .39287 .7237 L .38991 .72098 L p F P
0 g
s
.649 .758 .929 r
.24566 .7234 m .2556 .72046 L .25876 .72318 L p F P
0 g
s
.649 .758 .929 r
.2556 .72046 m .24566 .7234 L .24249 .72067 L p F P
0 g
s
.65 .758 .928 r
.40598 .72348 m .41618 .72052 L .4191 .72325 L p F P
0 g
s
.65 .758 .928 r
.41618 .72052 m .40598 .72348 L .40304 .72075 L p F P
0 g
s
.649 .758 .929 r
.25876 .72318 m .26872 .72024 L .27186 .72297 L p F P
0 g
s
.649 .758 .929 r
.26872 .72024 m .25876 .72318 L .2556 .72046 L p F P
0 g
s
.65 .758 .928 r
.4191 .72325 m .42932 .72029 L .43222 .72302 L p F P
0 g
s
.65 .758 .928 r
.42932 .72029 m .4191 .72325 L .41618 .72052 L p F P
0 g
s
.65 .758 .929 r
.27186 .72297 m .28184 .72002 L .28496 .72275 L p F P
0 g
s
.65 .758 .929 r
.28184 .72002 m .27186 .72297 L .26872 .72024 L p F P
0 g
s
.65 .758 .928 r
.44246 .72006 m .43222 .72302 L .42932 .72029 L p F P
0 g
s
.65 .758 .929 r
.28496 .72275 m .29497 .7198 L .29807 .72253 L p F P
0 g
s
.65 .758 .929 r
.29497 .7198 m .28496 .72275 L .28184 .72002 L p F P
0 g
s
.65 .758 .929 r
.29807 .72253 m .3081 .71958 L .31118 .72232 L p F P
0 g
s
.65 .758 .929 r
.3081 .71958 m .29807 .72253 L .29497 .7198 L p F P
0 g
s
.65 .758 .929 r
.31118 .72232 m .32123 .71936 L .32429 .72209 L p F P
0 g
s
.65 .758 .929 r
.32123 .71936 m .31118 .72232 L .3081 .71958 L p F P
0 g
s
.65 .758 .929 r
.32429 .72209 m .33437 .71914 L .33741 .72187 L p F P
0 g
s
.65 .758 .928 r
.33437 .71914 m .32429 .72209 L .32123 .71936 L p F P
0 g
s
.65 .758 .929 r
.33741 .72187 m .34751 .71892 L .35053 .72165 L p F P
0 g
s
.65 .758 .928 r
.34751 .71892 m .33741 .72187 L .33437 .71914 L p F P
0 g
s
.65 .758 .928 r
.35053 .72165 m .36065 .71869 L .36365 .72143 L p F P
0 g
s
.65 .758 .928 r
.36065 .71869 m .35053 .72165 L .34751 .71892 L p F P
0 g
s
.649 .758 .929 r
.20316 .7213 m .21304 .71836 L .21627 .72109 L p F P
0 g
s
.649 .758 .929 r
.21304 .71836 m .20316 .7213 L .19992 .71857 L p F P
0 g
s
.65 .758 .928 r
.36365 .72143 m .3738 .71847 L .37678 .7212 L p F P
0 g
s
.65 .758 .928 r
.3738 .71847 m .36365 .72143 L .36065 .71869 L p F P
0 g
s
.649 .758 .929 r
.21627 .72109 m .22617 .71815 L .22937 .72088 L p F P
0 g
s
.649 .758 .929 r
.22617 .71815 m .21627 .72109 L .21304 .71836 L p F P
0 g
s
.65 .758 .928 r
.37678 .7212 m .38695 .71824 L .38991 .72098 L p F P
0 g
s
.65 .758 .928 r
.38695 .71824 m .37678 .7212 L .3738 .71847 L p F P
0 g
s
.649 .758 .929 r
.22937 .72088 m .2393 .71793 L .24249 .72067 L p F P
0 g
s
.649 .758 .929 r
.2393 .71793 m .22937 .72088 L .22617 .71815 L p F P
0 g
s
.65 .758 .928 r
.38991 .72098 m .4001 .71801 L .40304 .72075 L p F P
0 g
s
.65 .758 .928 r
.4001 .71801 m .38991 .72098 L .38695 .71824 L p F P
0 g
s
.649 .758 .929 r
.24249 .72067 m .25244 .71772 L .2556 .72046 L p F P
0 g
s
.649 .758 .929 r
.25244 .71772 m .24249 .72067 L .2393 .71793 L p F P
0 g
s
.65 .758 .928 r
.40304 .72075 m .41325 .71779 L .41618 .72052 L p F P
0 g
s
.65 .758 .928 r
.41325 .71779 m .40304 .72075 L .4001 .71801 L p F P
0 g
s
.649 .758 .929 r
.2556 .72046 m .26558 .7175 L .26872 .72024 L p F P
0 g
s
.65 .758 .929 r
.26558 .7175 m .2556 .72046 L .25244 .71772 L p F P
0 g
s
.65 .758 .928 r
.41618 .72052 m .42641 .71756 L .42932 .72029 L p F P
0 g
s
.65 .758 .928 r
.42641 .71756 m .41618 .72052 L .41325 .71779 L p F P
0 g
s
.65 .758 .929 r
.26872 .72024 m .27872 .71728 L .28184 .72002 L p F P
0 g
s
.65 .758 .929 r
.27872 .71728 m .26872 .72024 L .26558 .7175 L p F P
0 g
s
.65 .758 .928 r
.42932 .72029 m .43958 .71733 L .44246 .72006 L p F P
0 g
s
.65 .758 .928 r
.43958 .71733 m .42932 .72029 L .42641 .71756 L p F P
0 g
s
.65 .758 .929 r
.28184 .72002 m .29186 .71706 L .29497 .7198 L p F P
0 g
s
.65 .758 .929 r
.29186 .71706 m .28184 .72002 L .27872 .71728 L p F P
0 g
s
.65 .758 .928 r
.45274 .71709 m .44246 .72006 L .43958 .71733 L p F P
0 g
s
.65 .758 .929 r
.29497 .7198 m .30501 .71684 L .3081 .71958 L p F P
0 g
s
.65 .758 .928 r
.30501 .71684 m .29497 .7198 L .29186 .71706 L p F P
0 g
s
.65 .758 .929 r
.3081 .71958 m .31816 .71662 L .32123 .71936 L p F P
0 g
s
.65 .758 .928 r
.31816 .71662 m .3081 .71958 L .30501 .71684 L p F P
0 g
s
.65 .758 .928 r
.32123 .71936 m .33132 .7164 L .33437 .71914 L p F P
0 g
s
.65 .758 .928 r
.33132 .7164 m .32123 .71936 L .31816 .71662 L p F P
0 g
s
.65 .758 .928 r
.33437 .71914 m .34448 .71617 L .34751 .71892 L p F P
0 g
s
.65 .758 .928 r
.34448 .71617 m .33437 .71914 L .33132 .7164 L p F P
0 g
s
.65 .758 .928 r
.34751 .71892 m .35764 .71595 L .36065 .71869 L p F P
0 g
s
.65 .758 .928 r
.35764 .71595 m .34751 .71892 L .34448 .71617 L p F P
0 g
s
.649 .758 .929 r
.19992 .71857 m .20981 .71562 L .21304 .71836 L p F P
0 g
s
.649 .758 .929 r
.20981 .71562 m .19992 .71857 L .19667 .71583 L p F P
0 g
s
.65 .758 .928 r
.36065 .71869 m .3708 .71572 L .3738 .71847 L p F P
0 g
s
.65 .758 .928 r
.3708 .71572 m .36065 .71869 L .35764 .71595 L p F P
0 g
s
.649 .758 .929 r
.21304 .71836 m .22296 .7154 L .22617 .71815 L p F P
0 g
s
.649 .758 .929 r
.22296 .7154 m .21304 .71836 L .20981 .71562 L p F P
0 g
s
.65 .758 .928 r
.3738 .71847 m .38397 .7155 L .38695 .71824 L p F P
0 g
s
.65 .758 .928 r
.38397 .7155 m .3738 .71847 L .3708 .71572 L p F P
0 g
s
.649 .758 .929 r
.22617 .71815 m .23611 .71519 L .2393 .71793 L p F P
0 g
s
.649 .758 .929 r
.23611 .71519 m .22617 .71815 L .22296 .7154 L p F P
0 g
s
.65 .758 .928 r
.38695 .71824 m .39714 .71527 L .4001 .71801 L p F P
0 g
s
.65 .758 .928 r
.39714 .71527 m .38695 .71824 L .38397 .7155 L p F P
0 g
s
.649 .758 .929 r
.2393 .71793 m .24926 .71497 L .25244 .71772 L p F P
0 g
s
.649 .758 .929 r
.24926 .71497 m .2393 .71793 L .23611 .71519 L p F P
0 g
s
.65 .758 .928 r
.4001 .71801 m .41032 .71504 L .41325 .71779 L p F P
0 g
s
.65 .758 .928 r
.41032 .71504 m .4001 .71801 L .39714 .71527 L p F P
0 g
s
.65 .758 .929 r
.26242 .71476 m .25244 .71772 L .24926 .71497 L p F P
0 g
s
.65 .758 .929 r
.25244 .71772 m .26242 .71476 L .26558 .7175 L p F P
0 g
s
.65 .758 .928 r
.41325 .71779 m .4235 .71481 L .42641 .71756 L p F P
0 g
s
.65 .758 .928 r
.4235 .71481 m .41325 .71779 L .41032 .71504 L p F P
0 g
s
.65 .758 .929 r
.26558 .7175 m .27558 .71454 L .27872 .71728 L p F P
0 g
s
.65 .758 .929 r
.27558 .71454 m .26558 .7175 L .26242 .71476 L p F P
0 g
s
.65 .758 .928 r
.42641 .71756 m .43668 .71458 L .43958 .71733 L p F P
0 g
s
.65 .758 .928 r
.43668 .71458 m .42641 .71756 L .4235 .71481 L p F P
0 g
s
.65 .758 .929 r
.27872 .71728 m .28875 .71432 L .29186 .71706 L p F P
0 g
s
.65 .758 .928 r
.28875 .71432 m .27872 .71728 L .27558 .71454 L p F P
0 g
s
.65 .758 .928 r
.43958 .71733 m .44986 .71435 L .45274 .71709 L p F P
0 g
s
.65 .758 .928 r
.44986 .71435 m .43958 .71733 L .43668 .71458 L p F P
0 g
s
.65 .758 .928 r
.29186 .71706 m .30191 .7141 L .30501 .71684 L p F P
0 g
s
.65 .758 .928 r
.30191 .7141 m .29186 .71706 L .28875 .71432 L p F P
0 g
s
.65 .758 .928 r
.46305 .71412 m .45274 .71709 L .44986 .71435 L p F P
0 g
s
.65 .758 .928 r
.30501 .71684 m .31508 .71387 L .31816 .71662 L p F P
0 g
s
.65 .758 .928 r
.31508 .71387 m .30501 .71684 L .30191 .7141 L p F P
0 g
s
.65 .758 .928 r
.31816 .71662 m .32826 .71365 L .33132 .7164 L p F P
0 g
s
.65 .758 .928 r
.32826 .71365 m .31816 .71662 L .31508 .71387 L p F P
0 g
s
.65 .758 .928 r
.33132 .7164 m .34144 .71342 L .34448 .71617 L p F P
0 g
s
.65 .758 .928 r
.34144 .71342 m .33132 .7164 L .32826 .71365 L p F P
0 g
s
.65 .758 .928 r
.34448 .71617 m .35462 .7132 L .35764 .71595 L p F P
0 g
s
.65 .758 .928 r
.35462 .7132 m .34448 .71617 L .34144 .71342 L p F P
0 g
s
.649 .758 .929 r
.19667 .71583 m .20657 .71286 L .20981 .71562 L p F P
0 g
s
.649 .758 .929 r
.20657 .71286 m .19667 .71583 L .19341 .71308 L p F P
0 g
s
.65 .758 .928 r
.35764 .71595 m .3678 .71297 L .3708 .71572 L p F P
0 g
s
.65 .758 .928 r
.3678 .71297 m .35764 .71595 L .35462 .7132 L p F P
0 g
s
.649 .758 .929 r
.20981 .71562 m .21974 .71265 L .22296 .7154 L p F P
0 g
s
.649 .758 .929 r
.21974 .71265 m .20981 .71562 L .20657 .71286 L p F P
0 g
s
.65 .758 .928 r
.3708 .71572 m .38099 .71274 L .38397 .7155 L p F P
0 g
s
.65 .758 .928 r
.38099 .71274 m .3708 .71572 L .3678 .71297 L p F P
0 g
s
.649 .758 .929 r
.22296 .7154 m .23291 .71244 L .23611 .71519 L p F P
0 g
s
.649 .758 .929 r
.23291 .71244 m .22296 .7154 L .21974 .71265 L p F P
0 g
s
.65 .758 .928 r
.38397 .7155 m .39418 .71252 L .39714 .71527 L p F P
0 g
s
.65 .758 .928 r
.39418 .71252 m .38397 .7155 L .38099 .71274 L p F P
0 g
s
.649 .758 .929 r
.23611 .71519 m .24608 .71222 L .24926 .71497 L p F P
0 g
s
.649 .758 .929 r
.24608 .71222 m .23611 .71519 L .23291 .71244 L p F P
0 g
s
.65 .758 .928 r
.39714 .71527 m .40737 .71229 L .41032 .71504 L p F P
0 g
s
.65 .758 .928 r
.40737 .71229 m .39714 .71527 L .39418 .71252 L p F P
0 g
s
.65 .758 .929 r
.24926 .71497 m .25926 .712 L .26242 .71476 L p F P
0 g
s
.65 .758 .929 r
.25926 .712 m .24926 .71497 L .24608 .71222 L p F P
0 g
s
.65 .758 .928 r
.41032 .71504 m .42057 .71206 L .4235 .71481 L p F P
0 g
s
.65 .758 .928 r
.42057 .71206 m .41032 .71504 L .40737 .71229 L p F P
0 g
s
.65 .758 .929 r
.26242 .71476 m .27244 .71178 L .27558 .71454 L p F P
0 g
s
.65 .758 .928 r
.27244 .71178 m .26242 .71476 L .25926 .712 L p F P
0 g
s
.65 .758 .928 r
.4235 .71481 m .43377 .71183 L .43668 .71458 L p F P
0 g
s
.65 .758 .928 r
.43377 .71183 m .4235 .71481 L .42057 .71206 L p F P
0 g
s
.65 .758 .928 r
.27558 .71454 m .28562 .71156 L .28875 .71432 L p F P
0 g
s
.65 .758 .928 r
.28562 .71156 m .27558 .71454 L .27244 .71178 L p F P
0 g
s
.65 .758 .928 r
.43668 .71458 m .44698 .71159 L .44986 .71435 L p F P
0 g
s
.65 .758 .928 r
.44698 .71159 m .43668 .71458 L .43377 .71183 L p F P
0 g
s
.65 .758 .928 r
.29881 .71134 m .28875 .71432 L .28562 .71156 L p F P
0 g
s
.65 .758 .928 r
.28875 .71432 m .29881 .71134 L .30191 .7141 L p F P
0 g
s
.65 .758 .928 r
.44986 .71435 m .46018 .71136 L .46305 .71412 L p F P
0 g
s
.65 .758 .928 r
.46018 .71136 m .44986 .71435 L .44698 .71159 L p F P
0 g
s
.65 .758 .928 r
.30191 .7141 m .312 .71112 L .31508 .71387 L p F P
0 g
s
.65 .758 .928 r
.312 .71112 m .30191 .7141 L .29881 .71134 L p F P
0 g
s
.65 .758 .928 r
.47339 .71113 m .46305 .71412 L .46018 .71136 L p F P
0 g
s
.65 .758 .928 r
.31508 .71387 m .32519 .71089 L .32826 .71365 L p F P
0 g
s
.65 .758 .928 r
.32519 .71089 m .31508 .71387 L .312 .71112 L p F P
0 g
s
.65 .758 .928 r
.32826 .71365 m .33839 .71067 L .34144 .71342 L p F P
0 g
s
.65 .758 .928 r
.33839 .71067 m .32826 .71365 L .32519 .71089 L p F P
0 g
s
.65 .758 .928 r
.34144 .71342 m .35159 .71044 L .35462 .7132 L p F P
0 g
s
.65 .758 .928 r
.35159 .71044 m .34144 .71342 L .33839 .71067 L p F P
0 g
s
.649 .758 .929 r
.19341 .71308 m .20332 .7101 L .20657 .71286 L p F P
0 g
s
.649 .758 .929 r
.20332 .7101 m .19341 .71308 L .19014 .71032 L p F P
0 g
s
.65 .758 .928 r
.35462 .7132 m .36479 .71021 L .3678 .71297 L p F P
0 g
s
.65 .758 .928 r
.36479 .71021 m .35462 .7132 L .35159 .71044 L p F P
0 g
s
.649 .758 .929 r
.20657 .71286 m .2165 .70989 L .21974 .71265 L p F P
0 g
s
.649 .758 .929 r
.2165 .70989 m .20657 .71286 L .20332 .7101 L p F P
0 g
s
.65 .758 .928 r
.3678 .71297 m .378 .70998 L .38099 .71274 L p F P
0 g
s
.65 .758 .928 r
.378 .70998 m .3678 .71297 L .36479 .71021 L p F P
0 g
s
.649 .758 .929 r
.21974 .71265 m .22969 .70967 L .23291 .71244 L p F P
0 g
s
.649 .758 .929 r
.22969 .70967 m .21974 .71265 L .2165 .70989 L p F P
0 g
s
.65 .758 .928 r
.38099 .71274 m .39121 .70975 L .39418 .71252 L p F P
0 g
s
.65 .758 .928 r
.39121 .70975 m .38099 .71274 L .378 .70998 L p F P
0 g
s
.649 .758 .929 r
.23291 .71244 m .24289 .70946 L .24608 .71222 L p F P
0 g
s
.65 .758 .929 r
.24289 .70946 m .23291 .71244 L .22969 .70967 L p F P
0 g
s
.65 .758 .928 r
.39418 .71252 m .40442 .70952 L .40737 .71229 L p F P
0 g
s
.65 .758 .928 r
.40442 .70952 m .39418 .71252 L .39121 .70975 L p F P
0 g
s
.65 .758 .929 r
.24608 .71222 m .25608 .70924 L .25926 .712 L p F P
0 g
s
.65 .758 .928 r
.25608 .70924 m .24608 .71222 L .24289 .70946 L p F P
0 g
s
.65 .758 .928 r
.40737 .71229 m .41764 .70929 L .42057 .71206 L p F P
0 g
s
.65 .758 .928 r
.41764 .70929 m .40737 .71229 L .40442 .70952 L p F P
0 g
s
.65 .758 .928 r
.25926 .712 m .26928 .70902 L .27244 .71178 L p F P
0 g
s
.65 .758 .928 r
.26928 .70902 m .25926 .712 L .25608 .70924 L p F P
0 g
s
.65 .758 .928 r
.42057 .71206 m .43086 .70906 L .43377 .71183 L p F P
0 g
s
.65 .758 .928 r
.43086 .70906 m .42057 .71206 L .41764 .70929 L p F P
0 g
s
.65 .758 .928 r
.27244 .71178 m .28248 .7088 L .28562 .71156 L p F P
0 g
s
.65 .758 .928 r
.28248 .7088 m .27244 .71178 L .26928 .70902 L p F P
0 g
s
.65 .758 .928 r
.43377 .71183 m .44408 .70883 L .44698 .71159 L p F P
0 g
s
.65 .758 .928 r
.44408 .70883 m .43377 .71183 L .43086 .70906 L p F P
0 g
s
.65 .758 .928 r
.28562 .71156 m .29569 .70857 L .29881 .71134 L p F P
0 g
s
.65 .758 .928 r
.29569 .70857 m .28562 .71156 L .28248 .7088 L p F P
0 g
s
.65 .758 .928 r
.44698 .71159 m .45731 .7086 L .46018 .71136 L p F P
0 g
s
.65 .758 .928 r
.45731 .7086 m .44698 .71159 L .44408 .70883 L p F P
0 g
s
.65 .758 .928 r
.29881 .71134 m .3089 .70835 L .312 .71112 L p F P
0 g
s
.65 .758 .928 r
.3089 .70835 m .29881 .71134 L .29569 .70857 L p F P
0 g
s
.65 .758 .928 r
.46018 .71136 m .47054 .70836 L .47339 .71113 L p F P
0 g
s
.65 .758 .928 r
.47054 .70836 m .46018 .71136 L .45731 .7086 L p F P
0 g
s
.65 .758 .928 r
.312 .71112 m .32211 .70812 L .32519 .71089 L p F P
0 g
s
.65 .758 .928 r
.32211 .70812 m .312 .71112 L .3089 .70835 L p F P
0 g
s
.65 .758 .928 r
.48377 .70813 m .47339 .71113 L .47054 .70836 L p F P
0 g
s
.65 .758 .928 r
.32519 .71089 m .33533 .7079 L .33839 .71067 L p F P
0 g
s
.65 .758 .928 r
.33533 .7079 m .32519 .71089 L .32211 .70812 L p F P
0 g
s
.65 .758 .928 r
.33839 .71067 m .34855 .70767 L .35159 .71044 L p F P
0 g
s
.65 .758 .928 r
.34855 .70767 m .33839 .71067 L .33533 .7079 L p F P
0 g
s
.649 .758 .929 r
.19014 .71032 m .20006 .70734 L .20332 .7101 L p F P
0 g
s
.649 .758 .929 r
.20006 .70734 m .19014 .71032 L .18686 .70755 L p F P
0 g
s
.65 .758 .928 r
.35159 .71044 m .36177 .70744 L .36479 .71021 L p F P
0 g
s
.65 .758 .928 r
.36177 .70744 m .35159 .71044 L .34855 .70767 L p F P
0 g
s
.649 .758 .929 r
.20332 .7101 m .21326 .70712 L .2165 .70989 L p F P
0 g
s
.649 .758 .929 r
.21326 .70712 m .20332 .7101 L .20006 .70734 L p F P
0 g
s
.65 .758 .928 r
.36479 .71021 m .375 .70721 L .378 .70998 L p F P
0 g
s
.65 .758 .928 r
.375 .70721 m .36479 .71021 L .36177 .70744 L p F P
0 g
s
.649 .758 .929 r
.2165 .70989 m .22647 .7069 L .22969 .70967 L p F P
0 g
s
.649 .758 .929 r
.22647 .7069 m .2165 .70989 L .21326 .70712 L p F P
0 g
s
.65 .758 .928 r
.378 .70998 m .38823 .70698 L .39121 .70975 L p F P
0 g
s
.65 .758 .928 r
.38823 .70698 m .378 .70998 L .375 .70721 L p F P
0 g
s
.65 .758 .929 r
.22969 .70967 m .23968 .70669 L .24289 .70946 L p F P
0 g
s
.65 .758 .928 r
.23968 .70669 m .22969 .70967 L .22647 .7069 L p F P
0 g
s
.65 .758 .928 r
.39121 .70975 m .40146 .70675 L .40442 .70952 L p F P
0 g
s
.65 .758 .928 r
.40146 .70675 m .39121 .70975 L .38823 .70698 L p F P
0 g
s
.65 .758 .928 r
.24289 .70946 m .2529 .70647 L .25608 .70924 L p F P
0 g
s
.65 .758 .928 r
.2529 .70647 m .24289 .70946 L .23968 .70669 L p F P
0 g
s
.65 .758 .928 r
.40442 .70952 m .41469 .70652 L .41764 .70929 L p F P
0 g
s
.65 .758 .928 r
.41469 .70652 m .40442 .70952 L .40146 .70675 L p F P
0 g
s
.65 .758 .928 r
.25608 .70924 m .26612 .70624 L .26928 .70902 L p F P
0 g
s
.65 .758 .928 r
.26612 .70624 m .25608 .70924 L .2529 .70647 L p F P
0 g
s
.65 .758 .928 r
.41764 .70929 m .42793 .70629 L .43086 .70906 L p F P
0 g
s
.65 .758 .928 r
.42793 .70629 m .41764 .70929 L .41469 .70652 L p F P
0 g
s
.65 .758 .928 r
.26928 .70902 m .27934 .70602 L .28248 .7088 L p F P
0 g
s
.65 .758 .928 r
.27934 .70602 m .26928 .70902 L .26612 .70624 L p F P
0 g
s
.65 .758 .928 r
.43086 .70906 m .44118 .70606 L .44408 .70883 L p F P
0 g
s
.65 .758 .928 r
.44118 .70606 m .43086 .70906 L .42793 .70629 L p F P
0 g
s
.65 .758 .928 r
.28248 .7088 m .29256 .7058 L .29569 .70857 L p F P
0 g
s
.65 .758 .928 r
.29256 .7058 m .28248 .7088 L .27934 .70602 L p F P
0 g
s
.65 .758 .928 r
.44408 .70883 m .45442 .70582 L .45731 .7086 L p F P
0 g
s
.65 .758 .928 r
.45442 .70582 m .44408 .70883 L .44118 .70606 L p F P
0 g
s
.65 .758 .928 r
.29569 .70857 m .30579 .70557 L .3089 .70835 L p F P
0 g
s
.65 .758 .928 r
.30579 .70557 m .29569 .70857 L .29256 .7058 L p F P
0 g
s
.65 .758 .928 r
.45731 .7086 m .46767 .70559 L .47054 .70836 L p F P
0 g
s
.65 .758 .928 r
.46767 .70559 m .45731 .7086 L .45442 .70582 L p F P
0 g
s
.65 .758 .928 r
.3089 .70835 m .31902 .70535 L .32211 .70812 L p F P
0 g
s
.65 .758 .928 r
.31902 .70535 m .3089 .70835 L .30579 .70557 L p F P
0 g
s
.65 .758 .928 r
.47054 .70836 m .48092 .70535 L .48377 .70813 L p F P
0 g
s
.65 .758 .928 r
.48092 .70535 m .47054 .70836 L .46767 .70559 L p F P
0 g
s
.65 .758 .928 r
.32211 .70812 m .33226 .70512 L .33533 .7079 L p F P
0 g
s
.65 .758 .928 r
.33226 .70512 m .32211 .70812 L .31902 .70535 L p F P
0 g
s
.65 .758 .928 r
.49418 .70512 m .48377 .70813 L .48092 .70535 L p F P
0 g
s
.65 .758 .928 r
.33533 .7079 m .3455 .70489 L .34855 .70767 L p F P
0 g
s
.65 .758 .928 r
.3455 .70489 m .33533 .7079 L .33226 .70512 L p F P
0 g
s
.649 .758 .929 r
.18686 .70755 m .19679 .70456 L .20006 .70734 L p F P
0 g
s
.649 .758 .929 r
.19679 .70456 m .18686 .70755 L .18357 .70477 L p F P
0 g
s
.65 .758 .928 r
.34855 .70767 m .35874 .70466 L .36177 .70744 L p F P
0 g
s
.65 .758 .928 r
.35874 .70466 m .34855 .70767 L .3455 .70489 L p F P
0 g
s
.649 .758 .929 r
.20006 .70734 m .21001 .70434 L .21326 .70712 L p F P
0 g
s
.649 .758 .929 r
.21001 .70434 m .20006 .70734 L .19679 .70456 L p F P
0 g
s
.65 .758 .928 r
.36177 .70744 m .37199 .70444 L .375 .70721 L p F P
0 g
s
.65 .758 .928 r
.37199 .70444 m .36177 .70744 L .35874 .70466 L p F P
0 g
s
.649 .758 .929 r
.21326 .70712 m .22324 .70412 L .22647 .7069 L p F P
0 g
s
.649 .758 .928 r
.22324 .70412 m .21326 .70712 L .21001 .70434 L p F P
0 g
s
.65 .758 .928 r
.375 .70721 m .38524 .70421 L .38823 .70698 L p F P
0 g
s
.65 .758 .928 r
.38524 .70421 m .375 .70721 L .37199 .70444 L p F P
0 g
s
.65 .758 .928 r
.22647 .7069 m .23647 .70391 L .23968 .70669 L p F P
0 g
s
.65 .758 .928 r
.23647 .70391 m .22647 .7069 L .22324 .70412 L p F P
0 g
s
.65 .758 .928 r
.38823 .70698 m .39849 .70397 L .40146 .70675 L p F P
0 g
s
.65 .758 .928 r
.39849 .70397 m .38823 .70698 L .38524 .70421 L p F P
0 g
s
.65 .758 .928 r
.23968 .70669 m .2497 .70368 L .2529 .70647 L p F P
0 g
s
.65 .758 .928 r
.2497 .70368 m .23968 .70669 L .23647 .70391 L p F P
0 g
s
.65 .758 .928 r
.40146 .70675 m .41174 .70374 L .41469 .70652 L p F P
0 g
s
.65 .758 .928 r
.41174 .70374 m .40146 .70675 L .39849 .70397 L p F P
0 g
s
.65 .758 .928 r
.2529 .70647 m .26294 .70346 L .26612 .70624 L p F P
0 g
s
.65 .758 .928 r
.26294 .70346 m .2529 .70647 L .2497 .70368 L p F P
0 g
s
.65 .758 .928 r
.41469 .70652 m .425 .70351 L .42793 .70629 L p F P
0 g
s
.65 .758 .928 r
.425 .70351 m .41469 .70652 L .41174 .70374 L p F P
0 g
s
.65 .758 .928 r
.26612 .70624 m .27618 .70324 L .27934 .70602 L p F P
0 g
s
.65 .758 .928 r
.27618 .70324 m .26612 .70624 L .26294 .70346 L p F P
0 g
s
.65 .758 .928 r
.42793 .70629 m .43826 .70328 L .44118 .70606 L p F P
0 g
s
.65 .758 .928 r
.43826 .70328 m .42793 .70629 L .425 .70351 L p F P
0 g
s
.65 .758 .928 r
.27934 .70602 m .28943 .70302 L .29256 .7058 L p F P
0 g
s
.65 .758 .928 r
.28943 .70302 m .27934 .70602 L .27618 .70324 L p F P
0 g
s
.65 .758 .928 r
.44118 .70606 m .45153 .70304 L .45442 .70582 L p F P
0 g
s
.65 .758 .928 r
.45153 .70304 m .44118 .70606 L .43826 .70328 L p F P
0 g
s
.65 .758 .928 r
.29256 .7058 m .30268 .70279 L .30579 .70557 L p F P
0 g
s
.65 .758 .928 r
.30268 .70279 m .29256 .7058 L .28943 .70302 L p F P
0 g
s
.65 .758 .928 r
.45442 .70582 m .4648 .70281 L .46767 .70559 L p F P
0 g
s
.65 .758 .928 r
.4648 .70281 m .45442 .70582 L .45153 .70304 L p F P
0 g
s
.65 .758 .928 r
.30579 .70557 m .31593 .70256 L .31902 .70535 L p F P
0 g
s
.65 .758 .928 r
.31593 .70256 m .30579 .70557 L .30268 .70279 L p F P
0 g
s
.65 .758 .928 r
.46767 .70559 m .47807 .70257 L .48092 .70535 L p F P
0 g
s
.65 .758 .928 r
.47807 .70257 m .46767 .70559 L .4648 .70281 L p F P
0 g
s
.65 .758 .928 r
.32918 .70234 m .31902 .70535 L .31593 .70256 L p F P
0 g
s
.65 .758 .928 r
.31902 .70535 m .32918 .70234 L .33226 .70512 L p F P
0 g
s
.65 .758 .928 r
.48092 .70535 m .49135 .70233 L .49418 .70512 L p F P
0 g
s
.65 .758 .928 r
.49135 .70233 m .48092 .70535 L .47807 .70257 L p F P
0 g
s
.65 .758 .928 r
.50462 .7021 m .49418 .70512 L .49135 .70233 L p F P
0 g
s
.65 .758 .928 r
.33226 .70512 m .34244 .70211 L .3455 .70489 L p F P
0 g
s
.65 .758 .928 r
.34244 .70211 m .33226 .70512 L .32918 .70234 L p F P
0 g
s
.649 .758 .929 r
.18357 .70477 m .19351 .70177 L .19679 .70456 L p F P
0 g
s
.649 .758 .929 r
.19351 .70177 m .18357 .70477 L .18027 .70199 L p F P
0 g
s
.65 .758 .928 r
.3455 .70489 m .3557 .70188 L .35874 .70466 L p F P
0 g
s
.65 .758 .928 r
.3557 .70188 m .3455 .70489 L .34244 .70211 L p F P
0 g
s
.649 .758 .929 r
.19679 .70456 m .20675 .70156 L .21001 .70434 L p F P
0 g
s
.649 .758 .928 r
.20675 .70156 m .19679 .70456 L .19351 .70177 L p F P
0 g
s
.65 .758 .928 r
.35874 .70466 m .36897 .70165 L .37199 .70444 L p F P
0 g
s
.65 .758 .928 r
.36897 .70165 m .35874 .70466 L .3557 .70188 L p F P
0 g
s
.649 .758 .928 r
.21001 .70434 m .22 .70134 L .22324 .70412 L p F P
0 g
s
.65 .758 .928 r
.22 .70134 m .21001 .70434 L .20675 .70156 L p F P
0 g
s
.65 .758 .928 r
.37199 .70444 m .38224 .70142 L .38524 .70421 L p F P
0 g
s
.65 .758 .928 r
.38224 .70142 m .37199 .70444 L .36897 .70165 L p F P
0 g
s
.65 .758 .928 r
.22324 .70412 m .23325 .70112 L .23647 .70391 L p F P
0 g
s
.65 .758 .928 r
.23325 .70112 m .22324 .70412 L .22 .70134 L p F P
0 g
s
.65 .758 .928 r
.38524 .70421 m .39551 .70119 L .39849 .70397 L p F P
0 g
s
.65 .758 .928 r
.39551 .70119 m .38524 .70421 L .38224 .70142 L p F P
0 g
s
.65 .758 .928 r
.23647 .70391 m .2465 .7009 L .2497 .70368 L p F P
0 g
s
.65 .758 .928 r
.2465 .7009 m .23647 .70391 L .23325 .70112 L p F P
0 g
s
.65 .758 .928 r
.39849 .70397 m .40878 .70095 L .41174 .70374 L p F P
0 g
s
.65 .758 .928 r
.40878 .70095 m .39849 .70397 L .39551 .70119 L p F P
0 g
s
.65 .758 .928 r
.2497 .70368 m .25976 .70067 L .26294 .70346 L p F P
0 g
s
.65 .758 .928 r
.25976 .70067 m .2497 .70368 L .2465 .7009 L p F P
0 g
s
.65 .758 .928 r
.41174 .70374 m .42206 .70072 L .425 .70351 L p F P
0 g
s
.65 .758 .928 r
.42206 .70072 m .41174 .70374 L .40878 .70095 L p F P
0 g
s
.65 .758 .928 r
.26294 .70346 m .27302 .70045 L .27618 .70324 L p F P
0 g
s
.65 .758 .928 r
.27302 .70045 m .26294 .70346 L .25976 .70067 L p F P
0 g
s
.65 .758 .928 r
.425 .70351 m .43534 .70049 L .43826 .70328 L p F P
0 g
s
.65 .758 .928 r
.43534 .70049 m .425 .70351 L .42206 .70072 L p F P
0 g
s
.65 .758 .928 r
.27618 .70324 m .28628 .70022 L .28943 .70302 L p F P
0 g
s
.65 .758 .928 r
.28628 .70022 m .27618 .70324 L .27302 .70045 L p F P
0 g
s
.65 .758 .928 r
.43826 .70328 m .44863 .70025 L .45153 .70304 L p F P
0 g
s
.65 .758 .928 r
.44863 .70025 m .43826 .70328 L .43534 .70049 L p F P
0 g
s
.65 .758 .928 r
.28943 .70302 m .29955 .7 L .30268 .70279 L p F P
0 g
s
.65 .758 .928 r
.29955 .7 m .28943 .70302 L .28628 .70022 L p F P
0 g
s
.65 .758 .928 r
.45153 .70304 m .46192 .70002 L .4648 .70281 L p F P
0 g
s
.65 .758 .928 r
.46192 .70002 m .45153 .70304 L .44863 .70025 L p F P
0 g
s
.65 .758 .928 r
.31282 .69977 m .30268 .70279 L .29955 .7 L p F P
0 g
s
.65 .758 .928 r
.30268 .70279 m .31282 .69977 L .31593 .70256 L p F P
0 g
s
.65 .758 .928 r
.4648 .70281 m .47521 .69978 L .47807 .70257 L p F P
0 g
s
.65 .758 .928 r
.47521 .69978 m .4648 .70281 L .46192 .70002 L p F P
0 g
s
.65 .758 .928 r
.31593 .70256 m .3261 .69954 L .32918 .70234 L p F P
0 g
s
.65 .758 .928 r
.3261 .69954 m .31593 .70256 L .31282 .69977 L p F P
0 g
s
.65 .758 .928 r
.47807 .70257 m .4885 .69954 L .49135 .70233 L p F P
0 g
s
.65 .758 .928 r
.4885 .69954 m .47807 .70257 L .47521 .69978 L p F P
0 g
s
.65 .758 .928 r
.49135 .70233 m .5018 .6993 L .50462 .7021 L p F P
0 g
s
.65 .758 .928 r
.5018 .6993 m .49135 .70233 L .4885 .69954 L p F P
0 g
s
.65 .758 .928 r
.32918 .70234 m .33937 .69931 L .34244 .70211 L p F P
0 g
s
.65 .758 .928 r
.33937 .69931 m .32918 .70234 L .3261 .69954 L p F P
0 g
s
.649 .758 .929 r
.18027 .70199 m .19022 .69898 L .19351 .70177 L p F P
0 g
s
.649 .758 .929 r
.19022 .69898 m .18027 .70199 L .17696 .69919 L p F P
0 g
s
.65 .758 .928 r
.5151 .69906 m .50462 .7021 L .5018 .6993 L p F P
0 g
s
.65 .758 .928 r
.34244 .70211 m .35266 .69908 L .3557 .70188 L p F P
0 g
s
.65 .758 .928 r
.35266 .69908 m .34244 .70211 L .33937 .69931 L p F P
0 g
s
.649 .758 .928 r
.19351 .70177 m .20348 .69876 L .20675 .70156 L p F P
0 g
s
.649 .758 .928 r
.20348 .69876 m .19351 .70177 L .19022 .69898 L p F P
0 g
s
.65 .758 .928 r
.3557 .70188 m .36594 .69885 L .36897 .70165 L p F P
0 g
s
.65 .758 .928 r
.36594 .69885 m .3557 .70188 L .35266 .69908 L p F P
0 g
s
.65 .758 .928 r
.20675 .70156 m .21675 .69854 L .22 .70134 L p F P
0 g
s
.65 .758 .928 r
.21675 .69854 m .20675 .70156 L .20348 .69876 L p F P
0 g
s
.65 .758 .928 r
.36897 .70165 m .37923 .69862 L .38224 .70142 L p F P
0 g
s
.65 .758 .928 r
.37923 .69862 m .36897 .70165 L .36594 .69885 L p F P
0 g
s
.65 .758 .928 r
.22 .70134 m .23002 .69832 L .23325 .70112 L p F P
0 g
s
.65 .758 .928 r
.23002 .69832 m .22 .70134 L .21675 .69854 L p F P
0 g
s
.65 .758 .928 r
.38224 .70142 m .39252 .69839 L .39551 .70119 L p F P
0 g
s
.65 .758 .928 r
.39252 .69839 m .38224 .70142 L .37923 .69862 L p F P
0 g
s
.65 .758 .928 r
.23325 .70112 m .24329 .6981 L .2465 .7009 L p F P
0 g
s
.65 .758 .928 r
.24329 .6981 m .23325 .70112 L .23002 .69832 L p F P
0 g
s
.65 .758 .928 r
.39551 .70119 m .40581 .69816 L .40878 .70095 L p F P
0 g
s
.65 .758 .928 r
.40581 .69816 m .39551 .70119 L .39252 .69839 L p F P
0 g
s
.65 .758 .928 r
.2465 .7009 m .25657 .69787 L .25976 .70067 L p F P
0 g
s
.65 .758 .928 r
.25657 .69787 m .2465 .7009 L .24329 .6981 L p F P
0 g
s
.65 .758 .928 r
.40878 .70095 m .41911 .69792 L .42206 .70072 L p F P
0 g
s
.65 .758 .928 r
.41911 .69792 m .40878 .70095 L .40581 .69816 L p F P
0 g
s
.65 .758 .928 r
.25976 .70067 m .26985 .69765 L .27302 .70045 L p F P
0 g
s
.65 .758 .928 r
.26985 .69765 m .25976 .70067 L .25657 .69787 L p F P
0 g
s
.65 .758 .928 r
.42206 .70072 m .43241 .69769 L .43534 .70049 L p F P
0 g
s
.65 .758 .928 r
.43241 .69769 m .42206 .70072 L .41911 .69792 L p F P
0 g
s
.65 .758 .928 r
.27302 .70045 m .28313 .69742 L .28628 .70022 L p F P
0 g
s
.65 .758 .928 r
.28313 .69742 m .27302 .70045 L .26985 .69765 L p F P
0 g
s
.65 .758 .928 r
.43534 .70049 m .44572 .69745 L .44863 .70025 L p F P
0 g
s
.65 .758 .928 r
.44572 .69745 m .43534 .70049 L .43241 .69769 L p F P
0 g
s
.65 .758 .928 r
.28628 .70022 m .29642 .6972 L .29955 .7 L p F P
0 g
s
.65 .758 .928 r
.29642 .6972 m .28628 .70022 L .28313 .69742 L p F P
0 g
s
.65 .758 .928 r
.44863 .70025 m .45902 .69722 L .46192 .70002 L p F P
0 g
s
.65 .758 .928 r
.45902 .69722 m .44863 .70025 L .44572 .69745 L p F P
0 g
s
.65 .758 .928 r
.29955 .7 m .30971 .69697 L .31282 .69977 L p F P
0 g
s
.65 .758 .928 r
.30971 .69697 m .29955 .7 L .29642 .6972 L p F P
0 g
s
.65 .758 .928 r
.46192 .70002 m .47234 .69698 L .47521 .69978 L p F P
0 g
s
.65 .758 .928 r
.47234 .69698 m .46192 .70002 L .45902 .69722 L p F P
0 g
s
.65 .758 .928 r
.31282 .69977 m .323 .69674 L .3261 .69954 L p F P
0 g
s
.65 .758 .928 r
.323 .69674 m .31282 .69977 L .30971 .69697 L p F P
0 g
s
.65 .758 .928 r
.47521 .69978 m .48565 .69674 L .4885 .69954 L p F P
0 g
s
.65 .758 .928 r
.48565 .69674 m .47521 .69978 L .47234 .69698 L p F P
0 g
s
.65 .758 .928 r
.4885 .69954 m .49897 .6965 L .5018 .6993 L p F P
0 g
s
.65 .758 .928 r
.49897 .6965 m .4885 .69954 L .48565 .69674 L p F P
0 g
s
.65 .758 .928 r
.3261 .69954 m .3363 .69651 L .33937 .69931 L p F P
0 g
s
.65 .758 .928 r
.3363 .69651 m .3261 .69954 L .323 .69674 L p F P
0 g
s
.649 .758 .929 r
.17696 .69919 m .18692 .69617 L .19022 .69898 L p F P
0 g
s
.649 .758 .928 r
.18692 .69617 m .17696 .69919 L .17364 .69639 L p F P
0 g
s
.65 .758 .928 r
.5018 .6993 m .51229 .69626 L .5151 .69906 L p F P
0 g
s
.65 .758 .928 r
.51229 .69626 m .5018 .6993 L .49897 .6965 L p F P
0 g
s
.65 .758 .928 r
.3496 .69628 m .33937 .69931 L .3363 .69651 L p F P
0 g
s
.65 .758 .928 r
.33937 .69931 m .3496 .69628 L .35266 .69908 L p F P
0 g
s
.649 .758 .928 r
.19022 .69898 m .2002 .69596 L .20348 .69876 L p F P
0 g
s
.649 .758 .928 r
.2002 .69596 m .19022 .69898 L .18692 .69617 L p F P
0 g
s
.65 .758 .928 r
.52561 .69602 m .5151 .69906 L .51229 .69626 L p F P
0 g
s
.65 .758 .928 r
.35266 .69908 m .3629 .69605 L .36594 .69885 L p F P
0 g
s
.65 .758 .928 r
.3629 .69605 m .35266 .69908 L .3496 .69628 L p F P
0 g
s
.65 .758 .928 r
.20348 .69876 m .21349 .69573 L .21675 .69854 L p F P
0 g
s
.65 .758 .928 r
.21349 .69573 m .20348 .69876 L .2002 .69596 L p F P
0 g
s
.65 .758 .928 r
.36594 .69885 m .37621 .69582 L .37923 .69862 L p F P
0 g
s
.65 .758 .928 r
.37621 .69582 m .36594 .69885 L .3629 .69605 L p F P
0 g
s
.65 .758 .928 r
.21675 .69854 m .22678 .69551 L .23002 .69832 L p F P
0 g
s
.65 .758 .928 r
.22678 .69551 m .21675 .69854 L .21349 .69573 L p F P
0 g
s
.65 .758 .928 r
.37923 .69862 m .38952 .69558 L .39252 .69839 L p F P
0 g
s
.65 .758 .928 r
.38952 .69558 m .37923 .69862 L .37621 .69582 L p F P
0 g
s
.65 .758 .928 r
.23002 .69832 m .24007 .69529 L .24329 .6981 L p F P
0 g
s
.65 .758 .928 r
.24007 .69529 m .23002 .69832 L .22678 .69551 L p F P
0 g
s
.65 .758 .928 r
.39252 .69839 m .40284 .69535 L .40581 .69816 L p F P
0 g
s
.65 .758 .928 r
.40284 .69535 m .39252 .69839 L .38952 .69558 L p F P
0 g
s
.65 .758 .928 r
.24329 .6981 m .25336 .69507 L .25657 .69787 L p F P
0 g
s
.65 .758 .928 r
.25336 .69507 m .24329 .6981 L .24007 .69529 L p F P
0 g
s
.65 .758 .928 r
.40581 .69816 m .41615 .69511 L .41911 .69792 L p F P
0 g
s
.65 .758 .928 r
.41615 .69511 m .40581 .69816 L .40284 .69535 L p F P
0 g
s
.65 .758 .928 r
.25657 .69787 m .26666 .69484 L .26985 .69765 L p F P
0 g
s
.65 .758 .928 r
.26666 .69484 m .25657 .69787 L .25336 .69507 L p F P
0 g
s
.65 .758 .928 r
.41911 .69792 m .42947 .69488 L .43241 .69769 L p F P
0 g
s
.65 .758 .928 r
.42947 .69488 m .41911 .69792 L .41615 .69511 L p F P
0 g
s
.65 .758 .928 r
.26985 .69765 m .27997 .69461 L .28313 .69742 L p F P
0 g
s
.65 .758 .928 r
.27997 .69461 m .26985 .69765 L .26666 .69484 L p F P
0 g
s
.65 .758 .928 r
.43241 .69769 m .4428 .69464 L .44572 .69745 L p F P
0 g
s
.65 .758 .928 r
.4428 .69464 m .43241 .69769 L .42947 .69488 L p F P
0 g
s
.65 .758 .928 r
.28313 .69742 m .29327 .69439 L .29642 .6972 L p F P
0 g
s
.65 .758 .928 r
.29327 .69439 m .28313 .69742 L .27997 .69461 L p F P
0 g
s
.65 .758 .928 r
.44572 .69745 m .45613 .69441 L .45902 .69722 L p F P
0 g
s
.65 .758 .928 r
.45613 .69441 m .44572 .69745 L .4428 .69464 L p F P
0 g
s
.65 .758 .928 r
.29642 .6972 m .30658 .69416 L .30971 .69697 L p F P
0 g
s
.65 .758 .928 r
.30658 .69416 m .29642 .6972 L .29327 .69439 L p F P
0 g
s
.65 .758 .928 r
.45902 .69722 m .46946 .69417 L .47234 .69698 L p F P
0 g
s
.65 .758 .928 r
.46946 .69417 m .45902 .69722 L .45613 .69441 L p F P
0 g
s
.65 .758 .928 r
.30971 .69697 m .3199 .69393 L .323 .69674 L p F P
0 g
s
.65 .758 .928 r
.3199 .69393 m .30971 .69697 L .30658 .69416 L p F P
0 g
s
.65 .758 .928 r
.47234 .69698 m .48279 .69393 L .48565 .69674 L p F P
0 g
s
.65 .758 .928 r
.48279 .69393 m .47234 .69698 L .46946 .69417 L p F P
0 g
s
.65 .758 .928 r
.323 .69674 m .33321 .6937 L .3363 .69651 L p F P
0 g
s
.65 .758 .928 r
.33321 .6937 m .323 .69674 L .3199 .69393 L p F P
0 g
s
.65 .758 .928 r
.48565 .69674 m .49613 .69369 L .49897 .6965 L p F P
0 g
s
.65 .758 .928 r
.49613 .69369 m .48565 .69674 L .48279 .69393 L p F P
0 g
s
.649 .758 .928 r
.17364 .69639 m .18361 .69336 L .18692 .69617 L p F P
0 g
s
.649 .758 .928 r
.18361 .69336 m .17364 .69639 L .17031 .69358 L p F P
0 g
s
.65 .758 .928 r
.49897 .6965 m .50947 .69345 L .51229 .69626 L p F P
0 g
s
.65 .758 .928 r
.50947 .69345 m .49897 .6965 L .49613 .69369 L p F P
0 g
s
.65 .758 .928 r
.3363 .69651 m .34653 .69347 L .3496 .69628 L p F P
0 g
s
.65 .758 .928 r
.34653 .69347 m .3363 .69651 L .33321 .6937 L p F P
0 g
s
.649 .758 .928 r
.18692 .69617 m .19691 .69314 L .2002 .69596 L p F P
0 g
s
.65 .758 .928 r
.19691 .69314 m .18692 .69617 L .18361 .69336 L p F P
0 g
s
.65 .758 .928 r
.51229 .69626 m .52281 .69321 L .52561 .69602 L p F P
0 g
s
.65 .758 .928 r
.52281 .69321 m .51229 .69626 L .50947 .69345 L p F P
0 g
s
.65 .758 .928 r
.3496 .69628 m .35986 .69323 L .3629 .69605 L p F P
0 g
s
.65 .758 .928 r
.35986 .69323 m .3496 .69628 L .34653 .69347 L p F P
0 g
s
.65 .758 .928 r
.2002 .69596 m .21022 .69292 L .21349 .69573 L p F P
0 g
s
.65 .758 .928 r
.21022 .69292 m .2002 .69596 L .19691 .69314 L p F P
0 g
s
.65 .758 .928 r
.53616 .69297 m .52561 .69602 L .52281 .69321 L p F P
0 g
s
.65 .758 .928 r
.3629 .69605 m .37318 .693 L .37621 .69582 L p F P
0 g
s
.65 .758 .928 r
.37318 .693 m .3629 .69605 L .35986 .69323 L p F P
0 g
s
.65 .758 .928 r
.21349 .69573 m .22352 .6927 L .22678 .69551 L p F P
0 g
s
.65 .758 .928 r
.22352 .6927 m .21349 .69573 L .21022 .69292 L p F P
0 g
s
.65 .758 .928 r
.37621 .69582 m .38651 .69277 L .38952 .69558 L p F P
0 g
s
.65 .758 .928 r
.38651 .69277 m .37621 .69582 L .37318 .693 L p F P
0 g
s
.65 .758 .928 r
.22678 .69551 m .23684 .69247 L .24007 .69529 L p F P
0 g
s
.65 .758 .928 r
.23684 .69247 m .22678 .69551 L .22352 .6927 L p F P
0 g
s
.65 .758 .928 r
.38952 .69558 m .39985 .69253 L .40284 .69535 L p F P
0 g
s
.65 .758 .928 r
.39985 .69253 m .38952 .69558 L .38651 .69277 L p F P
0 g
s
.65 .758 .928 r
.24007 .69529 m .25015 .69225 L .25336 .69507 L p F P
0 g
s
.65 .758 .928 r
.25015 .69225 m .24007 .69529 L .23684 .69247 L p F P
0 g
s
.65 .758 .928 r
.40284 .69535 m .41319 .6923 L .41615 .69511 L p F P
0 g
s
.65 .758 .928 r
.41319 .6923 m .40284 .69535 L .39985 .69253 L p F P
0 g
s
.65 .758 .928 r
.25336 .69507 m .26347 .69202 L .26666 .69484 L p F P
0 g
s
.65 .758 .928 r
.26347 .69202 m .25336 .69507 L .25015 .69225 L p F P
0 g
s
.65 .758 .928 r
.41615 .69511 m .42653 .69206 L .42947 .69488 L p F P
0 g
s
.65 .758 .928 r
.42653 .69206 m .41615 .69511 L .41319 .6923 L p F P
0 g
s
.65 .758 .928 r
.26666 .69484 m .27679 .6918 L .27997 .69461 L p F P
0 g
s
.65 .758 .928 r
.27679 .6918 m .26666 .69484 L .26347 .69202 L p F P
0 g
s
.65 .758 .928 r
.42947 .69488 m .43987 .69183 L .4428 .69464 L p F P
0 g
s
.65 .758 .928 r
.43987 .69183 m .42947 .69488 L .42653 .69206 L p F P
0 g
s
.65 .758 .928 r
.27997 .69461 m .29012 .69157 L .29327 .69439 L p F P
0 g
s
.65 .758 .928 r
.29012 .69157 m .27997 .69461 L .27679 .6918 L p F P
0 g
s
.65 .758 .928 r
.4428 .69464 m .45322 .69159 L .45613 .69441 L p F P
0 g
s
.65 .758 .928 r
.45322 .69159 m .4428 .69464 L .43987 .69183 L p F P
0 g
s
.65 .758 .928 r
.29327 .69439 m .30345 .69134 L .30658 .69416 L p F P
0 g
s
.65 .758 .928 r
.30345 .69134 m .29327 .69439 L .29012 .69157 L p F P
0 g
s
.65 .758 .928 r
.45613 .69441 m .46657 .69135 L .46946 .69417 L p F P
0 g
s
.65 .758 .928 r
.46657 .69135 m .45613 .69441 L .45322 .69159 L p F P
0 g
s
.65 .758 .928 r
.30658 .69416 m .31678 .69111 L .3199 .69393 L p F P
0 g
s
.65 .758 .928 r
.31678 .69111 m .30658 .69416 L .30345 .69134 L p F P
0 g
s
.65 .758 .928 r
.46946 .69417 m .47992 .69111 L .48279 .69393 L p F P
0 g
s
.65 .758 .928 r
.47992 .69111 m .46946 .69417 L .46657 .69135 L p F P
0 g
s
.65 .758 .928 r
.3199 .69393 m .33012 .69088 L .33321 .6937 L p F P
0 g
s
.65 .758 .928 r
.33012 .69088 m .3199 .69393 L .31678 .69111 L p F P
0 g
s
.65 .758 .928 r
.48279 .69393 m .49328 .69087 L .49613 .69369 L p F P
0 g
s
.65 .758 .928 r
.49328 .69087 m .48279 .69393 L .47992 .69111 L p F P
0 g
s
.649 .758 .928 r
.17031 .69358 m .18029 .69054 L .18361 .69336 L p F P
0 g
s
.649 .758 .928 r
.18029 .69054 m .17031 .69358 L .16697 .69076 L p F P
0 g
s
.65 .758 .928 r
.49613 .69369 m .50664 .69063 L .50947 .69345 L p F P
0 g
s
.65 .758 .928 r
.50664 .69063 m .49613 .69369 L .49328 .69087 L p F P
0 g
s
.65 .758 .928 r
.33321 .6937 m .34346 .69065 L .34653 .69347 L p F P
0 g
s
.65 .758 .928 r
.34346 .69065 m .33321 .6937 L .33012 .69088 L p F P
0 g
s
.65 .758 .928 r
.18361 .69336 m .19361 .69032 L .19691 .69314 L p F P
0 g
s
.65 .758 .928 r
.19361 .69032 m .18361 .69336 L .18029 .69054 L p F P
0 g
s
.65 .758 .928 r
.50947 .69345 m .52 .69039 L .52281 .69321 L p F P
0 g
s
.65 .758 .928 r
.52 .69039 m .50947 .69345 L .50664 .69063 L p F P
0 g
s
.65 .758 .928 r
.34653 .69347 m .3568 .69041 L .35986 .69323 L p F P
0 g
s
.65 .758 .928 r
.3568 .69041 m .34653 .69347 L .34346 .69065 L p F P
0 g
s
.65 .758 .928 r
.19691 .69314 m .20694 .6901 L .21022 .69292 L p F P
0 g
s
.65 .758 .928 r
.20694 .6901 m .19691 .69314 L .19361 .69032 L p F P
0 g
s
.65 .758 .928 r
.52281 .69321 m .53337 .69015 L .53616 .69297 L p F P
0 g
s
.65 .758 .928 r
.53337 .69015 m .52281 .69321 L .52 .69039 L p F P
0 g
s
.65 .758 .928 r
.35986 .69323 m .37015 .69018 L .37318 .693 L p F P
0 g
s
.65 .758 .928 r
.37015 .69018 m .35986 .69323 L .3568 .69041 L p F P
0 g
s
.65 .758 .928 r
.21022 .69292 m .22026 .68987 L .22352 .6927 L p F P
0 g
s
.65 .758 .928 r
.22026 .68987 m .21022 .69292 L .20694 .6901 L p F P
0 g
s
.65 .758 .928 r
.54674 .68991 m .53616 .69297 L .53337 .69015 L p F P
0 g
s
.65 .758 .928 r
.37318 .693 m .3835 .68994 L .38651 .69277 L p F P
0 g
s
.65 .758 .928 r
.3835 .68994 m .37318 .693 L .37015 .69018 L p F P
0 g
s
.65 .758 .928 r
.22352 .6927 m .2336 .68965 L .23684 .69247 L p F P
0 g
s
.65 .758 .928 r
.2336 .68965 m .22352 .6927 L .22026 .68987 L p F P
0 g
s
.65 .758 .928 r
.38651 .69277 m .39685 .68971 L .39985 .69253 L p F P
0 g
s
.65 .758 .928 r
.39685 .68971 m .38651 .69277 L .3835 .68994 L p F P
0 g
s
.65 .758 .928 r
.23684 .69247 m .24693 .68942 L .25015 .69225 L p F P
0 g
s
.65 .758 .928 r
.24693 .68942 m .23684 .69247 L .2336 .68965 L p F P
0 g
s
.65 .758 .928 r
.39985 .69253 m .41021 .68947 L .41319 .6923 L p F P
0 g
s
.65 .758 .928 r
.41021 .68947 m .39985 .69253 L .39685 .68971 L p F P
0 g
s
.65 .758 .928 r
.25015 .69225 m .26027 .6892 L .26347 .69202 L p F P
0 g
s
.65 .758 .928 r
.26027 .6892 m .25015 .69225 L .24693 .68942 L p F P
0 g
s
.65 .758 .928 r
.41319 .6923 m .42357 .68924 L .42653 .69206 L p F P
0 g
s
.65 .758 .928 r
.42357 .68924 m .41319 .6923 L .41021 .68947 L p F P
0 g
s
.65 .758 .928 r
.26347 .69202 m .27361 .68897 L .27679 .6918 L p F P
0 g
s
.65 .758 .928 r
.27361 .68897 m .26347 .69202 L .26027 .6892 L p F P
0 g
s
.65 .758 .928 r
.42653 .69206 m .43693 .689 L .43987 .69183 L p F P
0 g
s
.65 .758 .928 r
.43693 .689 m .42653 .69206 L .42357 .68924 L p F P
0 g
s
.65 .758 .928 r
.27679 .6918 m .28696 .68874 L .29012 .69157 L p F P
0 g
s
.65 .758 .928 r
.28696 .68874 m .27679 .6918 L .27361 .68897 L p F P
0 g
s
.65 .758 .928 r
.43987 .69183 m .4503 .68876 L .45322 .69159 L p F P
0 g
s
.65 .758 .928 r
.4503 .68876 m .43987 .69183 L .43693 .689 L p F P
0 g
s
.65 .758 .928 r
.29012 .69157 m .30031 .68851 L .30345 .69134 L p F P
0 g
s
.65 .758 .928 r
.30031 .68851 m .29012 .69157 L .28696 .68874 L p F P
0 g
s
.65 .758 .928 r
.45322 .69159 m .46367 .68852 L .46657 .69135 L p F P
0 g
s
.65 .758 .928 r
.46367 .68852 m .45322 .69159 L .4503 .68876 L p F P
0 g
s
.65 .758 .928 r
.30345 .69134 m .31366 .68828 L .31678 .69111 L p F P
0 g
s
.65 .758 .928 r
.31366 .68828 m .30345 .69134 L .30031 .68851 L p F P
0 g
s
.65 .758 .928 r
.46657 .69135 m .47704 .68829 L .47992 .69111 L p F P
0 g
s
.65 .758 .928 r
.47704 .68829 m .46657 .69135 L .46367 .68852 L p F P
0 g
s
.65 .758 .928 r
.31678 .69111 m .32702 .68805 L .33012 .69088 L p F P
0 g
s
.65 .758 .928 r
.32702 .68805 m .31678 .69111 L .31366 .68828 L p F P
0 g
s
.65 .758 .928 r
.47992 .69111 m .49042 .68805 L .49328 .69087 L p F P
0 g
s
.65 .758 .928 r
.49042 .68805 m .47992 .69111 L .47704 .68829 L p F P
0 g
s
.649 .758 .928 r
.16697 .69076 m .17696 .68771 L .18029 .69054 L p F P
0 g
s
.649 .758 .928 r
.17696 .68771 m .16697 .69076 L .16362 .68793 L p F P
0 g
s
.65 .758 .928 r
.49328 .69087 m .5038 .68781 L .50664 .69063 L p F P
0 g
s
.65 .758 .928 r
.5038 .68781 m .49328 .69087 L .49042 .68805 L p F P
0 g
s
.65 .758 .928 r
.33012 .69088 m .34038 .68781 L .34346 .69065 L p F P
0 g
s
.65 .758 .928 r
.34038 .68781 m .33012 .69088 L .32702 .68805 L p F P
0 g
s
.65 .758 .928 r
.18029 .69054 m .1903 .68749 L .19361 .69032 L p F P
0 g
s
.65 .758 .928 r
.1903 .68749 m .18029 .69054 L .17696 .68771 L p F P
0 g
s
.65 .758 .928 r
.50664 .69063 m .51718 .68756 L .52 .69039 L p F P
0 g
s
.65 .758 .928 r
.51718 .68756 m .50664 .69063 L .5038 .68781 L p F P
0 g
s
.65 .758 .928 r
.34346 .69065 m .35374 .68758 L .3568 .69041 L p F P
0 g
s
.65 .758 .928 r
.35374 .68758 m .34346 .69065 L .34038 .68781 L p F P
0 g
s
.65 .758 .928 r
.19361 .69032 m .20364 .68727 L .20694 .6901 L p F P
0 g
s
.65 .758 .928 r
.20364 .68727 m .19361 .69032 L .1903 .68749 L p F P
0 g
s
.65 .758 .928 r
.52 .69039 m .53057 .68732 L .53337 .69015 L p F P
0 g
s
.65 .758 .928 r
.53057 .68732 m .52 .69039 L .51718 .68756 L p F P
0 g
s
.65 .758 .928 r
.3568 .69041 m .3671 .68735 L .37015 .69018 L p F P
0 g
s
.65 .758 .928 r
.3671 .68735 m .3568 .69041 L .35374 .68758 L p F P
0 g
s
.65 .758 .928 r
.20694 .6901 m .21699 .68704 L .22026 .68987 L p F P
0 g
s
.65 .758 .928 r
.21699 .68704 m .20694 .6901 L .20364 .68727 L p F P
0 g
s
.65 .758 .928 r
.53337 .69015 m .54396 .68708 L .54674 .68991 L p F P
0 g
s
.65 .758 .928 r
.54396 .68708 m .53337 .69015 L .53057 .68732 L p F P
0 g
s
.65 .758 .928 r
.38047 .68711 m .37015 .69018 L .3671 .68735 L p F P
0 g
s
.65 .758 .928 r
.37015 .69018 m .38047 .68711 L .3835 .68994 L p F P
0 g
s
.65 .758 .928 r
.22026 .68987 m .23034 .68682 L .2336 .68965 L p F P
0 g
s
.65 .758 .928 r
.23034 .68682 m .22026 .68987 L .21699 .68704 L p F P
0 g
s
.65 .758 .928 r
.55735 .68683 m .54674 .68991 L .54396 .68708 L p F P
0 g
s
.65 .758 .928 r
.3835 .68994 m .39385 .68688 L .39685 .68971 L p F P
0 g
s
.65 .758 .928 r
.39385 .68688 m .3835 .68994 L .38047 .68711 L p F P
0 g
s
.65 .758 .928 r
.2336 .68965 m .2437 .68659 L .24693 .68942 L p F P
0 g
s
.65 .758 .928 r
.2437 .68659 m .2336 .68965 L .23034 .68682 L p F P
0 g
s
.65 .758 .928 r
.39685 .68971 m .40722 .68664 L .41021 .68947 L p F P
0 g
s
.65 .758 .928 r
.40722 .68664 m .39685 .68971 L .39385 .68688 L p F P
0 g
s
.65 .758 .928 r
.24693 .68942 m .25706 .68636 L .26027 .6892 L p F P
0 g
s
.65 .758 .928 r
.25706 .68636 m .24693 .68942 L .2437 .68659 L p F P
0 g
s
.65 .758 .928 r
.41021 .68947 m .4206 .6864 L .42357 .68924 L p F P
0 g
s
.65 .758 .928 r
.4206 .6864 m .41021 .68947 L .40722 .68664 L p F P
0 g
s
.65 .758 .928 r
.26027 .6892 m .27042 .68613 L .27361 .68897 L p F P
0 g
s
.65 .758 .928 r
.27042 .68613 m .26027 .6892 L .25706 .68636 L p F P
0 g
s
.65 .758 .928 r
.42357 .68924 m .43399 .68617 L .43693 .689 L p F P
0 g
s
.65 .758 .928 r
.43399 .68617 m .42357 .68924 L .4206 .6864 L p F P
0 g
s
.65 .758 .928 r
.27361 .68897 m .28379 .6859 L .28696 .68874 L p F P
0 g
s
.65 .758 .928 r
.28379 .6859 m .27361 .68897 L .27042 .68613 L p F P
0 g
s
.65 .758 .928 r
.43693 .689 m .44737 .68593 L .4503 .68876 L p F P
0 g
s
.65 .758 .928 r
.44737 .68593 m .43693 .689 L .43399 .68617 L p F P
0 g
s
.65 .758 .928 r
.28696 .68874 m .29715 .68567 L .30031 .68851 L p F P
0 g
s
.65 .758 .928 r
.29715 .68567 m .28696 .68874 L .28379 .6859 L p F P
0 g
s
.65 .758 .928 r
.4503 .68876 m .46076 .68569 L .46367 .68852 L p F P
0 g
s
.65 .758 .928 r
.46076 .68569 m .4503 .68876 L .44737 .68593 L p F P
0 g
s
.65 .758 .928 r
.30031 .68851 m .31053 .68544 L .31366 .68828 L p F P
0 g
s
.65 .758 .928 r
.31053 .68544 m .30031 .68851 L .29715 .68567 L p F P
0 g
s
.65 .758 .928 r
.46367 .68852 m .47416 .68545 L .47704 .68829 L p F P
0 g
s
.65 .758 .928 r
.47416 .68545 m .46367 .68852 L .46076 .68569 L p F P
0 g
s
.65 .758 .928 r
.31366 .68828 m .3239 .68521 L .32702 .68805 L p F P
0 g
s
.65 .758 .928 r
.3239 .68521 m .31366 .68828 L .31053 .68544 L p F P
0 g
s
.65 .758 .928 r
.47704 .68829 m .48755 .68521 L .49042 .68805 L p F P
0 g
s
.65 .758 .928 r
.48755 .68521 m .47704 .68829 L .47416 .68545 L p F P
0 g
s
.649 .758 .928 r
.16362 .68793 m .17362 .68487 L .17696 .68771 L p F P
0 g
s
.649 .758 .928 r
.17362 .68487 m .16362 .68793 L .16026 .68509 L p F P
0 g
s
.65 .758 .928 r
.49042 .68805 m .50095 .68497 L .5038 .68781 L p F P
0 g
s
.65 .758 .928 r
.50095 .68497 m .49042 .68805 L .48755 .68521 L p F P
0 g
s
.65 .758 .928 r
.32702 .68805 m .33728 .68498 L .34038 .68781 L p F P
0 g
s
.65 .758 .928 r
.33728 .68498 m .32702 .68805 L .3239 .68521 L p F P
0 g
s
.65 .758 .928 r
.17696 .68771 m .18698 .68465 L .1903 .68749 L p F P
0 g
s
.65 .758 .928 r
.18698 .68465 m .17696 .68771 L .17362 .68487 L p F P
0 g
s
.65 .758 .928 r
.5038 .68781 m .51436 .68473 L .51718 .68756 L p F P
0 g
s
.65 .758 .928 r
.51436 .68473 m .5038 .68781 L .50095 .68497 L p F P
0 g
s
.65 .758 .928 r
.34038 .68781 m .35067 .68474 L .35374 .68758 L p F P
0 g
s
.65 .758 .928 r
.35067 .68474 m .34038 .68781 L .33728 .68498 L p F P
0 g
s
.65 .758 .928 r
.1903 .68749 m .20034 .68443 L .20364 .68727 L p F P
0 g
s
.65 .758 .928 r
.20034 .68443 m .1903 .68749 L .18698 .68465 L p F P
0 g
s
.65 .758 .928 r
.51718 .68756 m .52776 .68448 L .53057 .68732 L p F P
0 g
s
.65 .758 .928 r
.52776 .68448 m .51718 .68756 L .51436 .68473 L p F P
0 g
s
.65 .758 .928 r
.36405 .68451 m .35374 .68758 L .35067 .68474 L p F P
0 g
s
.65 .758 .928 r
.35374 .68758 m .36405 .68451 L .3671 .68735 L p F P
0 g
s
.65 .758 .928 r
.20364 .68727 m .21371 .6842 L .21699 .68704 L p F P
0 g
s
.65 .758 .928 r
.21371 .6842 m .20364 .68727 L .20034 .68443 L p F P
0 g
s
.65 .758 .928 r
.53057 .68732 m .54117 .68424 L .54396 .68708 L p F P
0 g
s
.65 .758 .928 r
.54117 .68424 m .53057 .68732 L .52776 .68448 L p F P
0 g
s
.65 .758 .928 r
.3671 .68735 m .37744 .68427 L .38047 .68711 L p F P
0 g
s
.65 .758 .928 r
.37744 .68427 m .3671 .68735 L .36405 .68451 L p F P
0 g
s
.65 .758 .928 r
.21699 .68704 m .22708 .68398 L .23034 .68682 L p F P
0 g
s
.65 .758 .928 r
.22708 .68398 m .21699 .68704 L .21371 .6842 L p F P
0 g
s
.65 .758 .928 r
.54396 .68708 m .55459 .684 L .55735 .68683 L p F P
0 g
s
.65 .758 .928 r
.55459 .684 m .54396 .68708 L .54117 .68424 L p F P
0 g
s
.65 .758 .928 r
.38047 .68711 m .39083 .68404 L .39385 .68688 L p F P
0 g
s
.65 .758 .928 r
.39083 .68404 m .38047 .68711 L .37744 .68427 L p F P
0 g
s
.65 .758 .928 r
.23034 .68682 m .24046 .68375 L .2437 .68659 L p F P
0 g
s
.65 .758 .928 r
.24046 .68375 m .23034 .68682 L .22708 .68398 L p F P
0 g
s
.65 .758 .928 r
.568 .68375 m .55735 .68683 L .55459 .684 L p F P
0 g
s
.65 .758 .928 r
.39385 .68688 m .40423 .6838 L .40722 .68664 L p F P
0 g
s
.65 .758 .928 r
.40423 .6838 m .39385 .68688 L .39083 .68404 L p F P
0 g
s
.65 .758 .928 r
.2437 .68659 m .25384 .68352 L .25706 .68636 L p F P
0 g
s
.65 .758 .928 r
.25384 .68352 m .2437 .68659 L .24046 .68375 L p F P
0 g
s
.65 .758 .928 r
.40722 .68664 m .41763 .68356 L .4206 .6864 L p F P
0 g
s
.65 .758 .928 r
.41763 .68356 m .40722 .68664 L .40423 .6838 L p F P
0 g
s
.65 .758 .928 r
.25706 .68636 m .26722 .68329 L .27042 .68613 L p F P
0 g
s
.65 .758 .928 r
.26722 .68329 m .25706 .68636 L .25384 .68352 L p F P
0 g
s
.65 .758 .928 r
.4206 .6864 m .43103 .68332 L .43399 .68617 L p F P
0 g
s
.65 .758 .928 r
.43103 .68332 m .4206 .6864 L .41763 .68356 L p F P
0 g
s
.65 .758 .928 r
.27042 .68613 m .2806 .68306 L .28379 .6859 L p F P
0 g
s
.65 .758 .928 r
.2806 .68306 m .27042 .68613 L .26722 .68329 L p F P
0 g
s
.65 .758 .928 r
.43399 .68617 m .44444 .68308 L .44737 .68593 L p F P
0 g
s
.65 .758 .928 r
.44444 .68308 m .43399 .68617 L .43103 .68332 L p F P
0 g
s
.65 .758 .928 r
.28379 .6859 m .29399 .68283 L .29715 .68567 L p F P
0 g
s
.65 .758 .928 r
.29399 .68283 m .28379 .6859 L .2806 .68306 L p F P
0 g
s
.65 .758 .928 r
.44737 .68593 m .45785 .68284 L .46076 .68569 L p F P
0 g
s
.65 .758 .928 r
.45785 .68284 m .44737 .68593 L .44444 .68308 L p F P
0 g
s
.65 .758 .928 r
.29715 .68567 m .30739 .6826 L .31053 .68544 L p F P
0 g
s
.65 .758 .928 r
.30739 .6826 m .29715 .68567 L .29399 .68283 L p F P
0 g
s
.65 .758 .928 r
.46076 .68569 m .47126 .6826 L .47416 .68545 L p F P
0 g
s
.65 .758 .928 r
.47126 .6826 m .46076 .68569 L .45785 .68284 L p F P
0 g
s
.65 .758 .928 r
.31053 .68544 m .32078 .68236 L .3239 .68521 L p F P
0 g
s
.65 .758 .928 r
.32078 .68236 m .31053 .68544 L .30739 .6826 L p F P
0 g
s
.65 .758 .928 r
.47416 .68545 m .48468 .68236 L .48755 .68521 L p F P
0 g
s
.65 .758 .928 r
.48468 .68236 m .47416 .68545 L .47126 .6826 L p F P
0 g
s
.649 .758 .928 r
.16026 .68509 m .17027 .68202 L .17362 .68487 L p F P
0 g
s
.65 .758 .928 r
.17027 .68202 m .16026 .68509 L .15689 .68224 L p F P
0 g
s
.65 .758 .928 r
.3239 .68521 m .33418 .68213 L .33728 .68498 L p F P
0 g
s
.65 .758 .928 r
.33418 .68213 m .3239 .68521 L .32078 .68236 L p F P
0 g
s
.65 .758 .928 r
.48755 .68521 m .4981 .68212 L .50095 .68497 L p F P
0 g
s
.65 .758 .928 r
.4981 .68212 m .48755 .68521 L .48468 .68236 L p F P
0 g
s
.65 .758 .928 r
.17362 .68487 m .18365 .6818 L .18698 .68465 L p F P
0 g
s
.65 .758 .928 r
.18365 .6818 m .17362 .68487 L .17027 .68202 L p F P
0 g
s
.65 .758 .928 r
.50095 .68497 m .51152 .68188 L .51436 .68473 L p F P
0 g
s
.65 .758 .928 r
.51152 .68188 m .50095 .68497 L .4981 .68212 L p F P
0 g
s
.65 .758 .928 r
.33728 .68498 m .34758 .68189 L .35067 .68474 L p F P
0 g
s
.65 .758 .928 r
.34758 .68189 m .33728 .68498 L .33418 .68213 L p F P
0 g
s
.65 .758 .928 r
.18698 .68465 m .19703 .68158 L .20034 .68443 L p F P
0 g
s
.65 .758 .928 r
.19703 .68158 m .18698 .68465 L .18365 .6818 L p F P
0 g
s
.65 .758 .928 r
.51436 .68473 m .52495 .68164 L .52776 .68448 L p F P
0 g
s
.65 .758 .928 r
.52495 .68164 m .51436 .68473 L .51152 .68188 L p F P
0 g
s
.65 .758 .928 r
.35067 .68474 m .36099 .68166 L .36405 .68451 L p F P
0 g
s
.65 .758 .928 r
.36099 .68166 m .35067 .68474 L .34758 .68189 L p F P
0 g
s
.65 .758 .928 r
.20034 .68443 m .21042 .68135 L .21371 .6842 L p F P
0 g
s
.65 .758 .928 r
.21042 .68135 m .20034 .68443 L .19703 .68158 L p F P
0 g
s
.65 .758 .928 r
.52776 .68448 m .53838 .68139 L .54117 .68424 L p F P
0 g
s
.65 .758 .928 r
.53838 .68139 m .52776 .68448 L .52495 .68164 L p F P
0 g
s
.65 .758 .928 r
.36405 .68451 m .3744 .68142 L .37744 .68427 L p F P
0 g
s
.65 .758 .928 r
.3744 .68142 m .36405 .68451 L .36099 .68166 L p F P
0 g
s
.65 .758 .928 r
.21371 .6842 m .22381 .68112 L .22708 .68398 L p F P
0 g
s
.65 .758 .928 r
.22381 .68112 m .21371 .6842 L .21042 .68135 L p F P
0 g
s
.65 .758 .928 r
.54117 .68424 m .55181 .68115 L .55459 .684 L p F P
0 g
s
.65 .758 .928 r
.55181 .68115 m .54117 .68424 L .53838 .68139 L p F P
0 g
s
.65 .758 .928 r
.37744 .68427 m .38781 .68118 L .39083 .68404 L p F P
0 g
s
.65 .758 .928 r
.38781 .68118 m .37744 .68427 L .3744 .68142 L p F P
0 g
s
.65 .758 .928 r
.22708 .68398 m .23721 .6809 L .24046 .68375 L p F P
0 g
s
.65 .758 .928 r
.23721 .6809 m .22708 .68398 L .22381 .68112 L p F P
0 g
s
.65 .758 .928 r
.55459 .684 m .56525 .6809 L .568 .68375 L p F P
0 g
s
.65 .758 .928 r
.56525 .6809 m .55459 .684 L .55181 .68115 L p F P
0 g
s
.65 .758 .928 r
.39083 .68404 m .40123 .68095 L .40423 .6838 L p F P
0 g
s
.65 .758 .928 r
.40123 .68095 m .39083 .68404 L .38781 .68118 L p F P
0 g
s
.65 .758 .928 r
.24046 .68375 m .25061 .68067 L .25384 .68352 L p F P
0 g
s
.65 .758 .928 r
.25061 .68067 m .24046 .68375 L .23721 .6809 L p F P
0 g
s
.65 .758 .928 r
.57869 .68066 m .568 .68375 L .56525 .6809 L p F P
0 g
s
.65 .758 .928 r
.40423 .6838 m .41465 .68071 L .41763 .68356 L p F P
0 g
s
.65 .758 .928 r
.41465 .68071 m .40423 .6838 L .40123 .68095 L p F P
0 g
s
.65 .758 .928 r
.25384 .68352 m .26401 .68044 L .26722 .68329 L p F P
0 g
s
.65 .758 .928 r
.26401 .68044 m .25384 .68352 L .25061 .68067 L p F P
0 g
s
.65 .758 .928 r
.41763 .68356 m .42807 .68047 L .43103 .68332 L p F P
0 g
s
.65 .758 .928 r
.42807 .68047 m .41763 .68356 L .41465 .68071 L p F P
0 g
s
.65 .758 .928 r
.26722 .68329 m .27741 .68021 L .2806 .68306 L p F P
0 g
s
.65 .758 .928 r
.27741 .68021 m .26722 .68329 L .26401 .68044 L p F P
0 g
s
.65 .758 .928 r
.43103 .68332 m .4415 .68023 L .44444 .68308 L p F P
0 g
s
.65 .758 .928 r
.4415 .68023 m .43103 .68332 L .42807 .68047 L p F P
0 g
s
.65 .758 .928 r
.2806 .68306 m .29082 .67997 L .29399 .68283 L p F P
0 g
s
.65 .758 .928 r
.29082 .67997 m .2806 .68306 L .27741 .68021 L p F P
0 g
s
.65 .758 .928 r
.44444 .68308 m .45492 .67999 L .45785 .68284 L p F P
0 g
s
.65 .758 .928 r
.45492 .67999 m .44444 .68308 L .4415 .68023 L p F P
0 g
s
.65 .758 .928 r
.29399 .68283 m .30423 .67974 L .30739 .6826 L p F P
0 g
s
.65 .758 .928 r
.30423 .67974 m .29399 .68283 L .29082 .67997 L p F P
0 g
s
.65 .758 .928 r
.45785 .68284 m .46836 .67975 L .47126 .6826 L p F P
0 g
s
.65 .758 .928 r
.46836 .67975 m .45785 .68284 L .45492 .67999 L p F P
0 g
s
.65 .758 .928 r
.30739 .6826 m .31765 .67951 L .32078 .68236 L p F P
0 g
s
.65 .758 .928 r
.31765 .67951 m .30739 .6826 L .30423 .67974 L p F P
0 g
s
.65 .758 .928 r
.47126 .6826 m .48179 .67951 L .48468 .68236 L p F P
0 g
s
.65 .758 .928 r
.48179 .67951 m .47126 .6826 L .46836 .67975 L p F P
0 g
s
.65 .758 .928 r
.15689 .68224 m .16691 .67917 L .17027 .68202 L p F P
0 g
s
.65 .758 .928 r
.16691 .67917 m .15689 .68224 L .15351 .67939 L p F P
0 g
s
.65 .758 .928 r
.32078 .68236 m .33107 .67927 L .33418 .68213 L p F P
0 g
s
.65 .758 .928 r
.33107 .67927 m .32078 .68236 L .31765 .67951 L p F P
0 g
s
.65 .758 .928 r
.48468 .68236 m .49523 .67927 L .4981 .68212 L p F P
0 g
s
.65 .758 .928 r
.49523 .67927 m .48468 .68236 L .48179 .67951 L p F P
0 g
s
.65 .758 .928 r
.17027 .68202 m .18031 .67894 L .18365 .6818 L p F P
0 g
s
.65 .758 .928 r
.18031 .67894 m .17027 .68202 L .16691 .67917 L p F P
0 g
s
.65 .758 .928 r
.4981 .68212 m .50868 .67902 L .51152 .68188 L p F P
0 g
s
.65 .758 .928 r
.50868 .67902 m .4981 .68212 L .49523 .67927 L p F P
0 g
s
.65 .758 .928 r
.33418 .68213 m .34449 .67904 L .34758 .68189 L p F P
0 g
s
.65 .758 .928 r
.34449 .67904 m .33418 .68213 L .33107 .67927 L p F P
0 g
s
.65 .758 .928 r
.18365 .6818 m .19371 .67872 L .19703 .68158 L p F P
0 g
s
.65 .758 .928 r
.19371 .67872 m .18365 .6818 L .18031 .67894 L p F P
0 g
s
.65 .758 .928 r
.51152 .68188 m .52212 .67878 L .52495 .68164 L p F P
0 g
s
.65 .758 .928 r
.52212 .67878 m .51152 .68188 L .50868 .67902 L p F P
0 g
s
.65 .758 .928 r
.34758 .68189 m .35792 .6788 L .36099 .68166 L p F P
0 g
s
.65 .758 .928 r
.35792 .6788 m .34758 .68189 L .34449 .67904 L p F P
0 g
s
.65 .758 .928 r
.19703 .68158 m .20712 .67849 L .21042 .68135 L p F P
0 g
s
.65 .758 .928 r
.20712 .67849 m .19703 .68158 L .19371 .67872 L p F P
0 g
s
.65 .758 .928 r
.52495 .68164 m .53557 .67854 L .53838 .68139 L p F P
0 g
s
.65 .758 .928 r
.53557 .67854 m .52495 .68164 L .52212 .67878 L p F P
0 g
s
.65 .758 .928 r
.36099 .68166 m .37135 .67856 L .3744 .68142 L p F P
0 g
s
.65 .758 .928 r
.37135 .67856 m .36099 .68166 L .35792 .6788 L p F P
0 g
s
.65 .758 .928 r
.21042 .68135 m .22053 .67826 L .22381 .68112 L p F P
0 g
s
.65 .758 .928 r
.22053 .67826 m .21042 .68135 L .20712 .67849 L p F P
0 g
s
.65 .758 .928 r
.53838 .68139 m .54903 .67829 L .55181 .68115 L p F P
0 g
s
.65 .758 .928 r
.54903 .67829 m .53838 .68139 L .53557 .67854 L p F P
0 g
s
.65 .758 .928 r
.3744 .68142 m .38478 .67833 L .38781 .68118 L p F P
0 g
s
.65 .758 .928 r
.38478 .67833 m .3744 .68142 L .37135 .67856 L p F P
0 g
s
.65 .758 .928 r
.22381 .68112 m .23395 .67804 L .23721 .6809 L p F P
0 g
s
.65 .758 .928 r
.23395 .67804 m .22381 .68112 L .22053 .67826 L p F P
0 g
s
.65 .758 .928 r
.55181 .68115 m .56248 .67805 L .56525 .6809 L p F P
0 g
s
.65 .758 .928 r
.56248 .67805 m .55181 .68115 L .54903 .67829 L p F P
0 g
s
.65 .758 .928 r
.38781 .68118 m .39821 .67809 L .40123 .68095 L p F P
0 g
s
.65 .758 .928 r
.39821 .67809 m .38781 .68118 L .38478 .67833 L p F P
0 g
s
.65 .758 .928 r
.23721 .6809 m .24737 .67781 L .25061 .68067 L p F P
0 g
s
.65 .758 .928 r
.24737 .67781 m .23721 .6809 L .23395 .67804 L p F P
0 g
s
.65 .758 .928 r
.56525 .6809 m .57594 .6778 L .57869 .68066 L p F P
0 g
s
.65 .758 .928 r
.57594 .6778 m .56525 .6809 L .56248 .67805 L p F P
0 g
s
.65 .758 .928 r
.40123 .68095 m .41165 .67785 L .41465 .68071 L p F P
0 g
s
.65 .758 .928 r
.41165 .67785 m .40123 .68095 L .39821 .67809 L p F P
0 g
s
.65 .758 .928 r
.58941 .67755 m .57869 .68066 L .57594 .6778 L p F P
0 g
s
.65 .758 .928 r
.25061 .68067 m .26079 .67757 L .26401 .68044 L p F P
0 g
s
.65 .758 .928 r
.26079 .67757 m .25061 .68067 L .24737 .67781 L p F P
0 g
s
.65 .758 .928 r
.41465 .68071 m .4251 .67761 L .42807 .68047 L p F P
0 g
s
.65 .758 .928 r
.4251 .67761 m .41465 .68071 L .41165 .67785 L p F P
0 g
s
.65 .758 .928 r
.26401 .68044 m .27421 .67734 L .27741 .68021 L p F P
0 g
s
.65 .758 .928 r
.27421 .67734 m .26401 .68044 L .26079 .67757 L p F P
0 g
s
.65 .758 .928 r
.42807 .68047 m .43854 .67737 L .4415 .68023 L p F P
0 g
s
.65 .758 .928 r
.43854 .67737 m .42807 .68047 L .4251 .67761 L p F P
0 g
s
.65 .758 .928 r
.27741 .68021 m .28764 .67711 L .29082 .67997 L p F P
0 g
s
.65 .758 .928 r
.28764 .67711 m .27741 .68021 L .27421 .67734 L p F P
0 g
s
.65 .758 .928 r
.4415 .68023 m .45199 .67713 L .45492 .67999 L p F P
0 g
s
.65 .758 .928 r
.45199 .67713 m .4415 .68023 L .43854 .67737 L p F P
0 g
s
.65 .758 .928 r
.29082 .67997 m .30107 .67688 L .30423 .67974 L p F P
0 g
s
.65 .758 .928 r
.30107 .67688 m .29082 .67997 L .28764 .67711 L p F P
0 g
s
.65 .758 .928 r
.45492 .67999 m .46545 .67689 L .46836 .67975 L p F P
0 g
s
.65 .758 .928 r
.46545 .67689 m .45492 .67999 L .45199 .67713 L p F P
0 g
s
.65 .758 .928 r
.30423 .67974 m .31451 .67664 L .31765 .67951 L p F P
0 g
s
.65 .758 .928 r
.31451 .67664 m .30423 .67974 L .30107 .67688 L p F P
0 g
s
.65 .758 .928 r
.46836 .67975 m .4789 .67665 L .48179 .67951 L p F P
0 g
s
.65 .758 .928 r
.4789 .67665 m .46836 .67975 L .46545 .67689 L p F P
0 g
s
.65 .758 .928 r
.15351 .67939 m .16354 .6763 L .16691 .67917 L p F P
0 g
s
.65 .758 .928 r
.16354 .6763 m .15351 .67939 L .15012 .67652 L p F P
0 g
s
.65 .758 .928 r
.31765 .67951 m .32795 .67641 L .33107 .67927 L p F P
0 g
s
.65 .758 .928 r
.32795 .67641 m .31765 .67951 L .31451 .67664 L p F P
0 g
s
.65 .758 .928 r
.48179 .67951 m .49236 .6764 L .49523 .67927 L p F P
0 g
s
.65 .758 .928 r
.49236 .6764 m .48179 .67951 L .4789 .67665 L p F P
0 g
s
.65 .758 .928 r
.16691 .67917 m .17696 .67608 L .18031 .67894 L p F P
0 g
s
.65 .758 .928 r
.17696 .67608 m .16691 .67917 L .16354 .6763 L p F P
0 g
s
.65 .758 .928 r
.49523 .67927 m .50582 .67616 L .50868 .67902 L p F P
0 g
s
.65 .758 .928 r
.50582 .67616 m .49523 .67927 L .49236 .6764 L p F P
0 g
s
.65 .758 .928 r
.33107 .67927 m .34139 .67617 L .34449 .67904 L p F P
0 g
s
.65 .758 .928 r
.34139 .67617 m .33107 .67927 L .32795 .67641 L p F P
0 g
s
.65 .758 .928 r
.18031 .67894 m .19038 .67585 L .19371 .67872 L p F P
0 g
s
.65 .758 .928 r
.19038 .67585 m .18031 .67894 L .17696 .67608 L p F P
0 g
s
.65 .758 .928 r
.50868 .67902 m .51929 .67592 L .52212 .67878 L p F P
0 g
s
.65 .758 .928 r
.51929 .67592 m .50868 .67902 L .50582 .67616 L p F P
0 g
s
.65 .758 .928 r
.34449 .67904 m .35483 .67593 L .35792 .6788 L p F P
0 g
s
.65 .758 .928 r
.35483 .67593 m .34449 .67904 L .34139 .67617 L p F P
0 g
s
.65 .758 .928 r
.19371 .67872 m .20381 .67562 L .20712 .67849 L p F P
0 g
s
.65 .758 .928 r
.20381 .67562 m .19371 .67872 L .19038 .67585 L p F P
0 g
s
.65 .758 .928 r
.52212 .67878 m .53276 .67567 L .53557 .67854 L p F P
0 g
s
.65 .758 .928 r
.53276 .67567 m .52212 .67878 L .51929 .67592 L p F P
0 g
s
.65 .758 .928 r
.35792 .6788 m .36828 .67569 L .37135 .67856 L p F P
0 g
s
.65 .758 .928 r
.36828 .67569 m .35792 .6788 L .35483 .67593 L p F P
0 g
s
.65 .758 .928 r
.20712 .67849 m .21724 .6754 L .22053 .67826 L p F P
0 g
s
.65 .758 .928 r
.21724 .6754 m .20712 .67849 L .20381 .67562 L p F P
0 g
s
.65 .758 .928 r
.53557 .67854 m .54623 .67543 L .54903 .67829 L p F P
0 g
s
.65 .758 .928 r
.54623 .67543 m .53557 .67854 L .53276 .67567 L p F P
0 g
s
.65 .758 .928 r
.37135 .67856 m .38174 .67546 L .38478 .67833 L p F P
0 g
s
.65 .758 .928 r
.38174 .67546 m .37135 .67856 L .36828 .67569 L p F P
0 g
s
.65 .758 .928 r
.22053 .67826 m .23068 .67517 L .23395 .67804 L p F P
0 g
s
.65 .758 .928 r
.23068 .67517 m .22053 .67826 L .21724 .6754 L p F P
0 g
s
.65 .758 .928 r
.54903 .67829 m .55971 .67518 L .56248 .67805 L p F P
0 g
s
.65 .758 .928 r
.55971 .67518 m .54903 .67829 L .54623 .67543 L p F P
0 g
s
.65 .758 .928 r
.39519 .67522 m .38478 .67833 L .38174 .67546 L p F P
0 g
s
.65 .758 .928 r
.38478 .67833 m .39519 .67522 L .39821 .67809 L p F P
0 g
s
.65 .758 .928 r
.23395 .67804 m .24411 .67494 L .24737 .67781 L p F P
0 g
s
.65 .758 .928 r
.24411 .67494 m .23395 .67804 L .23068 .67517 L p F P
0 g
s
.65 .758 .928 r
.56248 .67805 m .57319 .67493 L .57594 .6778 L p F P
0 g
s
.65 .758 .928 r
.57319 .67493 m .56248 .67805 L .55971 .67518 L p F P
0 g
s
.65 .758 .928 r
.39821 .67809 m .40865 .67498 L .41165 .67785 L p F P
0 g
s
.65 .758 .928 r
.40865 .67498 m .39821 .67809 L .39519 .67522 L p F P
0 g
s
.65 .758 .928 r
.57594 .6778 m .58667 .67468 L .58941 .67755 L p F P
0 g
s
.65 .758 .928 r
.58667 .67468 m .57594 .6778 L .57319 .67493 L p F P
0 g
s
.65 .758 .928 r
.24737 .67781 m .25756 .6747 L .26079 .67757 L p F P
0 g
s
.65 .758 .928 r
.25756 .6747 m .24737 .67781 L .24411 .67494 L p F P
0 g
s
.65 .758 .928 r
.41165 .67785 m .42211 .67474 L .4251 .67761 L p F P
0 g
s
.65 .758 .928 r
.42211 .67474 m .41165 .67785 L .40865 .67498 L p F P
0 g
s
.65 .758 .928 r
.60016 .67443 m .58941 .67755 L .58667 .67468 L p F P
0 g
s
.65 .758 .928 r
.26079 .67757 m .271 .67447 L .27421 .67734 L p F P
0 g
s
.65 .758 .928 r
.271 .67447 m .26079 .67757 L .25756 .6747 L p F P
0 g
s
.65 .758 .928 r
.4251 .67761 m .43558 .6745 L .43854 .67737 L p F P
0 g
s
.65 .758 .928 r
.43558 .6745 m .4251 .67761 L .42211 .67474 L p F P
0 g
s
.65 .758 .928 r
.27421 .67734 m .28445 .67424 L .28764 .67711 L p F P
0 g
s
.65 .758 .928 r
.28445 .67424 m .27421 .67734 L .271 .67447 L p F P
0 g
s
.65 .758 .928 r
.43854 .67737 m .44905 .67426 L .45199 .67713 L p F P
0 g
s
.65 .758 .928 r
.44905 .67426 m .43854 .67737 L .43558 .6745 L p F P
0 g
s
.65 .758 .928 r
.28764 .67711 m .2979 .674 L .30107 .67688 L p F P
0 g
s
.65 .758 .928 r
.2979 .674 m .28764 .67711 L .28445 .67424 L p F P
0 g
s
.65 .758 .928 r
.45199 .67713 m .46252 .67402 L .46545 .67689 L p F P
0 g
s
.65 .758 .928 r
.46252 .67402 m .45199 .67713 L .44905 .67426 L p F P
0 g
s
.65 .758 .928 r
.30107 .67688 m .31136 .67377 L .31451 .67664 L p F P
0 g
s
.65 .758 .928 r
.31136 .67377 m .30107 .67688 L .2979 .674 L p F P
0 g
s
.65 .758 .928 r
.46545 .67689 m .476 .67377 L .4789 .67665 L p F P
0 g
s
.65 .758 .928 r
.476 .67377 m .46545 .67689 L .46252 .67402 L p F P
0 g
s
.65 .758 .928 r
.15012 .67652 m .16016 .67343 L .16354 .6763 L p F P
0 g
s
.65 .758 .928 r
.16016 .67343 m .15012 .67652 L .14672 .67365 L p F P
0 g
s
.65 .758 .928 r
.31451 .67664 m .32482 .67353 L .32795 .67641 L p F P
0 g
s
.65 .758 .928 r
.32482 .67353 m .31451 .67664 L .31136 .67377 L p F P
0 g
s
.65 .758 .928 r
.4789 .67665 m .48948 .67353 L .49236 .6764 L p F P
0 g
s
.65 .758 .928 r
.48948 .67353 m .4789 .67665 L .476 .67377 L p F P
0 g
s
.65 .758 .928 r
.16354 .6763 m .1736 .6732 L .17696 .67608 L p F P
0 g
s
.65 .758 .928 r
.1736 .6732 m .16354 .6763 L .16016 .67343 L p F P
0 g
s
.65 .758 .928 r
.49236 .6764 m .50296 .67329 L .50582 .67616 L p F P
0 g
s
.65 .758 .928 r
.50296 .67329 m .49236 .6764 L .48948 .67353 L p F P
0 g
s
.65 .758 .928 r
.32795 .67641 m .33828 .67329 L .34139 .67617 L p F P
0 g
s
.65 .758 .928 r
.33828 .67329 m .32795 .67641 L .32482 .67353 L p F P
0 g
s
.65 .758 .928 r
.17696 .67608 m .18704 .67298 L .19038 .67585 L p F P
0 g
s
.65 .758 .928 r
.18704 .67298 m .17696 .67608 L .1736 .6732 L p F P
0 g
s
.65 .758 .928 r
.50582 .67616 m .51645 .67304 L .51929 .67592 L p F P
0 g
s
.65 .758 .928 r
.51645 .67304 m .50582 .67616 L .50296 .67329 L p F P
0 g
s
.65 .758 .928 r
.34139 .67617 m .35174 .67306 L .35483 .67593 L p F P
0 g
s
.65 .758 .928 r
.35174 .67306 m .34139 .67617 L .33828 .67329 L p F P
0 g
s
.65 .758 .928 r
.19038 .67585 m .20049 .67275 L .20381 .67562 L p F P
0 g
s
.65 .758 .928 r
.20049 .67275 m .19038 .67585 L .18704 .67298 L p F P
0 g
s
.65 .758 .928 r
.51929 .67592 m .52994 .6728 L .53276 .67567 L p F P
0 g
s
.65 .758 .928 r
.52994 .6728 m .51929 .67592 L .51645 .67304 L p F P
0 g
s
.65 .758 .928 r
.35483 .67593 m .36521 .67282 L .36828 .67569 L p F P
0 g
s
.65 .758 .928 r
.36521 .67282 m .35483 .67593 L .35174 .67306 L p F P
0 g
s
.65 .758 .928 r
.20381 .67562 m .21394 .67252 L .21724 .6754 L p F P
0 g
s
.65 .758 .928 r
.21394 .67252 m .20381 .67562 L .20049 .67275 L p F P
0 g
s
.65 .758 .928 r
.53276 .67567 m .54343 .67255 L .54623 .67543 L p F P
0 g
s
.65 .758 .928 r
.54343 .67255 m .53276 .67567 L .52994 .6728 L p F P
0 g
s
.65 .758 .928 r
.36828 .67569 m .37869 .67258 L .38174 .67546 L p F P
0 g
s
.65 .758 .928 r
.37869 .67258 m .36828 .67569 L .36521 .67282 L p F P
0 g
s
.65 .758 .928 r
.21724 .6754 m .2274 .67229 L .23068 .67517 L p F P
0 g
s
.65 .758 .928 r
.2274 .67229 m .21724 .6754 L .21394 .67252 L p F P
0 g
s
.65 .758 .928 r
.54623 .67543 m .55693 .6723 L .55971 .67518 L p F P
0 g
s
.65 .758 .928 r
.55693 .6723 m .54623 .67543 L .54343 .67255 L p F P
0 g
s
.65 .758 .928 r
.38174 .67546 m .39216 .67234 L .39519 .67522 L p F P
0 g
s
.65 .758 .928 r
.39216 .67234 m .38174 .67546 L .37869 .67258 L p F P
0 g
s
.65 .758 .928 r
.23068 .67517 m .24085 .67206 L .24411 .67494 L p F P
0 g
s
.65 .758 .928 r
.24085 .67206 m .23068 .67517 L .2274 .67229 L p F P
0 g
s
.65 .758 .928 r
.55971 .67518 m .57043 .67206 L .57319 .67493 L p F P
0 g
s
.65 .758 .928 r
.57043 .67206 m .55971 .67518 L .55693 .6723 L p F P
0 g
s
.65 .758 .928 r
.39519 .67522 m .40564 .6721 L .40865 .67498 L p F P
0 g
s
.65 .758 .928 r
.40564 .6721 m .39519 .67522 L .39216 .67234 L p F P
0 g
s
.65 .758 .928 r
.57319 .67493 m .58393 .67181 L .58667 .67468 L p F P
0 g
s
.65 .758 .928 r
.58393 .67181 m .57319 .67493 L .57043 .67206 L p F P
0 g
s
.65 .758 .928 r
.24411 .67494 m .25432 .67182 L .25756 .6747 L p F P
0 g
s
.65 .758 .928 r
.25432 .67182 m .24411 .67494 L .24085 .67206 L p F P
0 g
s
.65 .758 .928 r
.40865 .67498 m .41912 .67186 L .42211 .67474 L p F P
0 g
s
.65 .758 .928 r
.41912 .67186 m .40865 .67498 L .40564 .6721 L p F P
0 g
s
.65 .758 .928 r
.58667 .67468 m .59744 .67156 L .60016 .67443 L p F P
0 g
s
.65 .758 .928 r
.59744 .67156 m .58667 .67468 L .58393 .67181 L p F P
0 g
s
.65 .758 .928 r
.25756 .6747 m .26778 .67159 L .271 .67447 L p F P
0 g
s
.65 .758 .928 r
.26778 .67159 m .25756 .6747 L .25432 .67182 L p F P
0 g
s
.65 .758 .928 r
.43261 .67162 m .42211 .67474 L .41912 .67186 L p F P
0 g
s
.65 .758 .928 r
.42211 .67474 m .43261 .67162 L .43558 .6745 L p F P
0 g
s
.65 .758 .928 r
.61095 .67131 m .60016 .67443 L .59744 .67156 L p F P
0 g
s
.65 .758 .928 r
.271 .67447 m .28125 .67136 L .28445 .67424 L p F P
0 g
s
.65 .758 .928 r
.28125 .67136 m .271 .67447 L .26778 .67159 L p F P
0 g
s
.65 .758 .928 r
.43558 .6745 m .4461 .67138 L .44905 .67426 L p F P
0 g
s
.65 .758 .928 r
.4461 .67138 m .43558 .6745 L .43261 .67162 L p F P
0 g
s
.65 .758 .928 r
.28445 .67424 m .29472 .67112 L .2979 .674 L p F P
0 g
s
.65 .758 .928 r
.29472 .67112 m .28445 .67424 L .28125 .67136 L p F P
0 g
s
.65 .758 .928 r
.44905 .67426 m .45959 .67113 L .46252 .67402 L p F P
0 g
s
.65 .758 .928 r
.45959 .67113 m .44905 .67426 L .4461 .67138 L p F P
0 g
s
.65 .758 .928 r
.2979 .674 m .3082 .67088 L .31136 .67377 L p F P
0 g
s
.65 .758 .928 r
.3082 .67088 m .2979 .674 L .29472 .67112 L p F P
0 g
s
.65 .758 .928 r
.46252 .67402 m .47309 .67089 L .476 .67377 L p F P
0 g
s
.65 .758 .928 r
.47309 .67089 m .46252 .67402 L .45959 .67113 L p F P
0 g
s
.65 .758 .928 r
.14672 .67365 m .15677 .67054 L .16016 .67343 L p F P
0 g
s
.65 .758 .928 r
.15677 .67054 m .14672 .67365 L .14331 .67077 L p F P
0 g
s
.65 .758 .928 r
.31136 .67377 m .32168 .67065 L .32482 .67353 L p F P
0 g
s
.65 .758 .928 r
.32168 .67065 m .31136 .67377 L .3082 .67088 L p F P
0 g
s
.65 .758 .928 r
.476 .67377 m .48659 .67065 L .48948 .67353 L p F P
0 g
s
.65 .758 .928 r
.48659 .67065 m .476 .67377 L .47309 .67089 L p F P
0 g
s
.65 .758 .928 r
.16016 .67343 m .17023 .67032 L .1736 .6732 L p F P
0 g
s
.65 .758 .928 r
.17023 .67032 m .16016 .67343 L .15677 .67054 L p F P
0 g
s
.65 .758 .928 r
.48948 .67353 m .50009 .6704 L .50296 .67329 L p F P
0 g
s
.65 .758 .928 r
.50009 .6704 m .48948 .67353 L .48659 .67065 L p F P
0 g
s
.65 .758 .928 r
.32482 .67353 m .33516 .67041 L .33828 .67329 L p F P
0 g
s
.65 .758 .928 r
.33516 .67041 m .32482 .67353 L .32168 .67065 L p F P
0 g
s
.65 .758 .928 r
.1736 .6732 m .18369 .67009 L .18704 .67298 L p F P
0 g
s
.65 .758 .928 r
.18369 .67009 m .1736 .6732 L .17023 .67032 L p F P
0 g
s
.65 .758 .928 r
.50296 .67329 m .5136 .67016 L .51645 .67304 L p F P
0 g
s
.65 .758 .928 r
.5136 .67016 m .50296 .67329 L .50009 .6704 L p F P
0 g
s
.65 .758 .928 r
.33828 .67329 m .34864 .67017 L .35174 .67306 L p F P
0 g
s
.65 .758 .928 r
.34864 .67017 m .33828 .67329 L .33516 .67041 L p F P
0 g
s
.65 .758 .928 r
.18704 .67298 m .19716 .66986 L .20049 .67275 L p F P
0 g
s
.65 .758 .928 r
.19716 .66986 m .18704 .67298 L .18369 .67009 L p F P
0 g
s
.65 .758 .928 r
.51645 .67304 m .52711 .66991 L .52994 .6728 L p F P
0 g
s
.65 .758 .928 r
.52711 .66991 m .51645 .67304 L .5136 .67016 L p F P
0 g
s
.65 .758 .928 r
.35174 .67306 m .36213 .66993 L .36521 .67282 L p F P
0 g
s
.65 .758 .928 r
.36213 .66993 m .35174 .67306 L .34864 .67017 L p F P
0 g
s
.65 .758 .928 r
.20049 .67275 m .21063 .66963 L .21394 .67252 L p F P
0 g
s
.65 .758 .928 r
.21063 .66963 m .20049 .67275 L .19716 .66986 L p F P
0 g
s
.65 .758 .928 r
.52994 .6728 m .54062 .66967 L .54343 .67255 L p F P
0 g
s
.65 .758 .928 r
.54062 .66967 m .52994 .6728 L .52711 .66991 L p F P
0 g
s
.65 .758 .928 r
.36521 .67282 m .37563 .66969 L .37869 .67258 L p F P
0 g
s
.65 .758 .928 r
.37563 .66969 m .36521 .67282 L .36213 .66993 L p F P
0 g
s
.65 .758 .928 r
.21394 .67252 m .22411 .6694 L .2274 .67229 L p F P
0 g
s
.65 .758 .928 r
.22411 .6694 m .21394 .67252 L .21063 .66963 L p F P
0 g
s
.65 .758 .928 r
.54343 .67255 m .55414 .66942 L .55693 .6723 L p F P
0 g
s
.65 .758 .928 r
.55414 .66942 m .54343 .67255 L .54062 .66967 L p F P
0 g
s
.65 .758 .928 r
.37869 .67258 m .38912 .66945 L .39216 .67234 L p F P
0 g
s
.65 .758 .928 r
.38912 .66945 m .37869 .67258 L .37563 .66969 L p F P
0 g
s
.65 .758 .928 r
.2274 .67229 m .23758 .66917 L .24085 .67206 L p F P
0 g
s
.65 .758 .928 r
.23758 .66917 m .2274 .67229 L .22411 .6694 L p F P
0 g
s
.65 .758 .928 r
.55693 .6723 m .56766 .66917 L .57043 .67206 L p F P
0 g
s
.65 .758 .928 r
.56766 .66917 m .55693 .6723 L .55414 .66942 L p F P
0 g
s
.65 .758 .928 r
.39216 .67234 m .40262 .66921 L .40564 .6721 L p F P
0 g
s
.65 .758 .928 r
.40262 .66921 m .39216 .67234 L .38912 .66945 L p F P
0 g
s
.65 .758 .928 r
.24085 .67206 m .25107 .66893 L .25432 .67182 L p F P
0 g
s
.65 .758 .928 r
.25107 .66893 m .24085 .67206 L .23758 .66917 L p F P
0 g
s
.65 .758 .928 r
.57043 .67206 m .58118 .66892 L .58393 .67181 L p F P
0 g
s
.65 .758 .928 r
.58118 .66892 m .57043 .67206 L .56766 .66917 L p F P
0 g
s
.65 .758 .928 r
.41612 .66897 m .40564 .6721 L .40262 .66921 L p F P
0 g
s
.65 .758 .928 r
.40564 .6721 m .41612 .66897 L .41912 .67186 L p F P
0 g
s
.65 .758 .928 r
.58393 .67181 m .59471 .66867 L .59744 .67156 L p F P
0 g
s
.65 .758 .928 r
.59471 .66867 m .58393 .67181 L .58118 .66892 L p F P
0 g
s
.65 .758 .928 r
.25432 .67182 m .26455 .6687 L .26778 .67159 L p F P
0 g
s
.65 .758 .928 r
.26455 .6687 m .25432 .67182 L .25107 .66893 L p F P
0 g
s
.65 .758 .928 r
.41912 .67186 m .42963 .66873 L .43261 .67162 L p F P
0 g
s
.65 .758 .928 r
.42963 .66873 m .41912 .67186 L .41612 .66897 L p F P
0 g
s
.65 .758 .928 r
.59744 .67156 m .60824 .66842 L .61095 .67131 L p F P
0 g
s
.65 .758 .928 r
.60824 .66842 m .59744 .67156 L .59471 .66867 L p F P
0 g
s
.65 .758 .928 r
.26778 .67159 m .27804 .66846 L .28125 .67136 L p F P
0 g
s
.65 .758 .928 r
.27804 .66846 m .26778 .67159 L .26455 .6687 L p F P
0 g
s
.65 .758 .928 r
.43261 .67162 m .44314 .66849 L .4461 .67138 L p F P
0 g
s
.65 .758 .928 r
.44314 .66849 m .43261 .67162 L .42963 .66873 L p F P
0 g
s
.65 .758 .928 r
.62178 .66817 m .61095 .67131 L .60824 .66842 L p F P
0 g
s
.65 .758 .928 r
.28125 .67136 m .29153 .66823 L .29472 .67112 L p F P
0 g
s
.65 .758 .928 r
.29153 .66823 m .28125 .67136 L .27804 .66846 L p F P
0 g
s
.65 .758 .928 r
.4461 .67138 m .45665 .66824 L .45959 .67113 L p F P
0 g
s
.65 .758 .928 r
.45665 .66824 m .4461 .67138 L .44314 .66849 L p F P
0 g
s
.65 .758 .928 r
.29472 .67112 m .30503 .66799 L .3082 .67088 L p F P
0 g
s
.65 .758 .928 r
.30503 .66799 m .29472 .67112 L .29153 .66823 L p F P
0 g
s
.65 .758 .928 r
.45959 .67113 m .47017 .668 L .47309 .67089 L p F P
0 g
s
.65 .758 .928 r
.47017 .668 m .45959 .67113 L .45665 .66824 L p F P
0 g
s
.65 .758 .928 r
.14331 .67077 m .15337 .66765 L .15677 .67054 L p F P
0 g
s
.65 .758 .928 r
.15337 .66765 m .14331 .67077 L .13989 .66788 L p F P
0 g
s
.65 .758 .928 r
.3082 .67088 m .31853 .66775 L .32168 .67065 L p F P
0 g
s
.65 .758 .928 r
.31853 .66775 m .3082 .67088 L .30503 .66799 L p F P
0 g
s
.65 .758 .928 r
.47309 .67089 m .48369 .66776 L .48659 .67065 L p F P
0 g
s
.65 .758 .928 r
.48369 .66776 m .47309 .67089 L .47017 .668 L p F P
0 g
s
.65 .758 .928 r
.15677 .67054 m .16685 .66742 L .17023 .67032 L p F P
0 g
s
.65 .758 .928 r
.16685 .66742 m .15677 .67054 L .15337 .66765 L p F P
0 g
s
.65 .758 .928 r
.32168 .67065 m .33203 .66752 L .33516 .67041 L p F P
0 g
s
.65 .758 .928 r
.33203 .66752 m .32168 .67065 L .31853 .66775 L p F P
0 g
s
.65 .758 .928 r
.48659 .67065 m .49721 .66751 L .50009 .6704 L p F P
0 g
s
.65 .758 .928 r
.49721 .66751 m .48659 .67065 L .48369 .66776 L p F P
0 g
s
.65 .758 .928 r
.17023 .67032 m .18033 .6672 L .18369 .67009 L p F P
0 g
s
.65 .758 .928 r
.18033 .6672 m .17023 .67032 L .16685 .66742 L p F P
0 g
s
.65 .758 .928 r
.50009 .6704 m .51074 .66727 L .5136 .67016 L p F P
0 g
s
.65 .758 .928 r
.51074 .66727 m .50009 .6704 L .49721 .66751 L p F P
0 g
s
.65 .758 .928 r
.33516 .67041 m .34553 .66728 L .34864 .67017 L p F P
0 g
s
.65 .758 .928 r
.34553 .66728 m .33516 .67041 L .33203 .66752 L p F P
0 g
s
.65 .758 .928 r
.18369 .67009 m .19382 .66697 L .19716 .66986 L p F P
0 g
s
.65 .758 .928 r
.19382 .66697 m .18369 .67009 L .18033 .6672 L p F P
0 g
s
.65 .758 .928 r
.5136 .67016 m .52427 .66702 L .52711 .66991 L p F P
0 g
s
.65 .758 .928 r
.52427 .66702 m .5136 .67016 L .51074 .66727 L p F P
0 g
s
.65 .758 .928 r
.34864 .67017 m .35904 .66704 L .36213 .66993 L p F P
0 g
s
.65 .758 .928 r
.35904 .66704 m .34864 .67017 L .34553 .66728 L p F P
0 g
s
.65 .758 .928 r
.19716 .66986 m .20731 .66674 L .21063 .66963 L p F P
0 g
s
.65 .758 .928 r
.20731 .66674 m .19716 .66986 L .19382 .66697 L p F P
0 g
s
.65 .758 .928 r
.52711 .66991 m .53781 .66677 L .54062 .66967 L p F P
0 g
s
.65 .758 .928 r
.53781 .66677 m .52711 .66991 L .52427 .66702 L p F P
0 g
s
.65 .758 .928 r
.36213 .66993 m .37256 .6668 L .37563 .66969 L p F P
0 g
s
.65 .758 .928 r
.37256 .6668 m .36213 .66993 L .35904 .66704 L p F P
0 g
s
.65 .758 .928 r
.21063 .66963 m .22081 .6665 L .22411 .6694 L p F P
0 g
s
.65 .758 .928 r
.22081 .6665 m .21063 .66963 L .20731 .66674 L p F P
0 g
s
.65 .758 .928 r
.54062 .66967 m .55134 .66653 L .55414 .66942 L p F P
0 g
s
.65 .758 .928 r
.55134 .66653 m .54062 .66967 L .53781 .66677 L p F P
0 g
s
.65 .758 .928 r
.37563 .66969 m .38607 .66656 L .38912 .66945 L p F P
0 g
s
.65 .758 .928 r
.38607 .66656 m .37563 .66969 L .37256 .6668 L p F P
0 g
s
.65 .758 .928 r
.22411 .6694 m .2343 .66627 L .23758 .66917 L p F P
0 g
s
.65 .758 .928 r
.2343 .66627 m .22411 .6694 L .22081 .6665 L p F P
0 g
s
.65 .758 .928 r
.55414 .66942 m .56488 .66628 L .56766 .66917 L p F P
0 g
s
.65 .758 .928 r
.56488 .66628 m .55414 .66942 L .55134 .66653 L p F P
0 g
s
.65 .758 .928 r
.38912 .66945 m .39959 .66632 L .40262 .66921 L p F P
0 g
s
.65 .758 .928 r
.39959 .66632 m .38912 .66945 L .38607 .66656 L p F P
0 g
s
.65 .758 .928 r
.23758 .66917 m .24781 .66604 L .25107 .66893 L p F P
0 g
s
.65 .758 .928 r
.24781 .66604 m .23758 .66917 L .2343 .66627 L p F P
0 g
s
.65 .758 .928 r
.56766 .66917 m .57843 .66603 L .58118 .66892 L p F P
0 g
s
.65 .758 .928 r
.57843 .66603 m .56766 .66917 L .56488 .66628 L p F P
0 g
s
.65 .758 .928 r
.40262 .66921 m .41312 .66607 L .41612 .66897 L p F P
0 g
s
.65 .758 .928 r
.41312 .66607 m .40262 .66921 L .39959 .66632 L p F P
0 g
s
.65 .758 .928 r
.58118 .66892 m .59197 .66578 L .59471 .66867 L p F P
0 g
s
.65 .758 .928 r
.59197 .66578 m .58118 .66892 L .57843 .66603 L p F P
0 g
s
.65 .758 .928 r
.25107 .66893 m .26131 .6658 L .26455 .6687 L p F P
0 g
s
.65 .758 .928 r
.26131 .6658 m .25107 .66893 L .24781 .66604 L p F P
0 g
s
.65 .758 .928 r
.41612 .66897 m .42664 .66583 L .42963 .66873 L p F P
0 g
s
.65 .758 .928 r
.42664 .66583 m .41612 .66897 L .41312 .66607 L p F P
0 g
s
.65 .758 .928 r
.59471 .66867 m .60553 .66553 L .60824 .66842 L p F P
0 g
s
.65 .758 .928 r
.60553 .66553 m .59471 .66867 L .59197 .66578 L p F P
0 g
s
.65 .758 .928 r
.26455 .6687 m .27482 .66557 L .27804 .66846 L p F P
0 g
s
.65 .758 .928 r
.27482 .66557 m .26455 .6687 L .26131 .6658 L p F P
0 g
s
.65 .758 .928 r
.42963 .66873 m .44017 .66559 L .44314 .66849 L p F P
0 g
s
.65 .758 .928 r
.44017 .66559 m .42963 .66873 L .42664 .66583 L p F P
0 g
s
.65 .758 .928 r
.60824 .66842 m .61908 .66527 L .62178 .66817 L p F P
0 g
s
.65 .758 .928 r
.61908 .66527 m .60824 .66842 L .60553 .66553 L p F P
0 g
s
.65 .758 .928 r
.27804 .66846 m .28833 .66533 L .29153 .66823 L p F P
0 g
s
.65 .758 .928 r
.28833 .66533 m .27804 .66846 L .27482 .66557 L p F P
0 g
s
.65 .758 .928 r
.45371 .66534 m .44314 .66849 L .44017 .66559 L p F P
0 g
s
.65 .758 .928 r
.44314 .66849 m .45371 .66534 L .45665 .66824 L p F P
0 g
s
.651 .758 .928 r
.63264 .66502 m .62178 .66817 L .61908 .66527 L p F P
0 g
s
.65 .758 .928 r
.29153 .66823 m .30185 .66509 L .30503 .66799 L p F P
0 g
s
.65 .758 .928 r
.30185 .66509 m .29153 .66823 L .28833 .66533 L p F P
0 g
s
.65 .758 .928 r
.45665 .66824 m .46724 .6651 L .47017 .668 L p F P
0 g
s
.65 .758 .928 r
.46724 .6651 m .45665 .66824 L .45371 .66534 L p F P
0 g
s
.65 .758 .928 r
.13989 .66788 m .14996 .66475 L .15337 .66765 L p F P
0 g
s
.65 .758 .928 r
.14996 .66475 m .13989 .66788 L .13646 .66497 L p F P
0 g
s
.65 .758 .928 r
.30503 .66799 m .31537 .66485 L .31853 .66775 L p F P
0 g
s
.65 .758 .928 r
.31537 .66485 m .30503 .66799 L .30185 .66509 L p F P
0 g
s
.65 .758 .928 r
.47017 .668 m .48078 .66486 L .48369 .66776 L p F P
0 g
s
.65 .758 .928 r
.48078 .66486 m .47017 .668 L .46724 .6651 L p F P
0 g
s
.65 .758 .928 r
.15337 .66765 m .16346 .66452 L .16685 .66742 L p F P
0 g
s
.65 .758 .928 r
.16346 .66452 m .15337 .66765 L .14996 .66475 L p F P
0 g
s
.65 .758 .928 r
.31853 .66775 m .32889 .66461 L .33203 .66752 L p F P
0 g
s
.65 .758 .928 r
.32889 .66461 m .31853 .66775 L .31537 .66485 L p F P
0 g
s
.65 .758 .928 r
.48369 .66776 m .49433 .66461 L .49721 .66751 L p F P
0 g
s
.65 .758 .928 r
.49433 .66461 m .48369 .66776 L .48078 .66486 L p F P
0 g
s
.65 .758 .928 r
.16685 .66742 m .17696 .66429 L .18033 .6672 L p F P
0 g
s
.65 .758 .928 r
.17696 .66429 m .16685 .66742 L .16346 .66452 L p F P
0 g
s
.65 .758 .928 r
.49721 .66751 m .50787 .66436 L .51074 .66727 L p F P
0 g
s
.65 .758 .928 r
.50787 .66436 m .49721 .66751 L .49433 .66461 L p F P
0 g
s
.65 .758 .928 r
.33203 .66752 m .34242 .66437 L .34553 .66728 L p F P
0 g
s
.65 .758 .928 r
.34242 .66437 m .33203 .66752 L .32889 .66461 L p F P
0 g
s
.65 .758 .928 r
.18033 .6672 m .19047 .66406 L .19382 .66697 L p F P
0 g
s
.65 .758 .928 r
.19047 .66406 m .18033 .6672 L .17696 .66429 L p F P
0 g
s
.65 .758 .928 r
.51074 .66727 m .52142 .66412 L .52427 .66702 L p F P
0 g
s
.65 .758 .928 r
.52142 .66412 m .51074 .66727 L .50787 .66436 L p F P
0 g
s
.65 .758 .928 r
.34553 .66728 m .35594 .66413 L .35904 .66704 L p F P
0 g
s
.65 .758 .928 r
.35594 .66413 m .34553 .66728 L .34242 .66437 L p F P
0 g
s
.65 .758 .928 r
.19382 .66697 m .20398 .66383 L .20731 .66674 L p F P
0 g
s
.65 .758 .928 r
.20398 .66383 m .19382 .66697 L .19047 .66406 L p F P
0 g
s
.65 .758 .928 r
.52427 .66702 m .53498 .66387 L .53781 .66677 L p F P
0 g
s
.65 .758 .928 r
.53498 .66387 m .52427 .66702 L .52142 .66412 L p F P
0 g
s
.65 .758 .928 r
.35904 .66704 m .36948 .66389 L .37256 .6668 L p F P
0 g
s
.65 .758 .928 r
.36948 .66389 m .35904 .66704 L .35594 .66413 L p F P
0 g
s
.65 .758 .928 r
.20731 .66674 m .2175 .6636 L .22081 .6665 L p F P
0 g
s
.65 .758 .928 r
.2175 .6636 m .20731 .66674 L .20398 .66383 L p F P
0 g
s
.65 .758 .928 r
.53781 .66677 m .54854 .66362 L .55134 .66653 L p F P
0 g
s
.65 .758 .928 r
.54854 .66362 m .53781 .66677 L .53498 .66387 L p F P
0 g
s
.65 .758 .928 r
.37256 .6668 m .38301 .66365 L .38607 .66656 L p F P
0 g
s
.65 .758 .928 r
.38301 .66365 m .37256 .6668 L .36948 .66389 L p F P
0 g
s
.65 .758 .928 r
.22081 .6665 m .23101 .66336 L .2343 .66627 L p F P
0 g
s
.65 .758 .928 r
.23101 .66336 m .22081 .6665 L .2175 .6636 L p F P
0 g
s
.65 .758 .928 r
.55134 .66653 m .5621 .66337 L .56488 .66628 L p F P
0 g
s
.65 .758 .928 r
.5621 .66337 m .55134 .66653 L .54854 .66362 L p F P
0 g
s
.65 .758 .928 r
.38607 .66656 m .39655 .66341 L .39959 .66632 L p F P
0 g
s
.65 .758 .928 r
.39655 .66341 m .38607 .66656 L .38301 .66365 L p F P
0 g
s
.65 .758 .928 r
.2343 .66627 m .24454 .66313 L .24781 .66604 L p F P
0 g
s
.65 .758 .928 r
.24454 .66313 m .2343 .66627 L .23101 .66336 L p F P
0 g
s
.65 .758 .928 r
.56488 .66628 m .57566 .66312 L .57843 .66603 L p F P
0 g
s
.65 .758 .928 r
.57566 .66312 m .56488 .66628 L .5621 .66337 L p F P
0 g
s
.65 .758 .928 r
.39959 .66632 m .4101 .66317 L .41312 .66607 L p F P
0 g
s
.65 .758 .928 r
.4101 .66317 m .39959 .66632 L .39655 .66341 L p F P
0 g
s
.65 .758 .928 r
.57843 .66603 m .58923 .66287 L .59197 .66578 L p F P
0 g
s
.65 .758 .928 r
.58923 .66287 m .57843 .66603 L .57566 .66312 L p F P
0 g
s
.65 .758 .928 r
.24781 .66604 m .25806 .66289 L .26131 .6658 L p F P
0 g
s
.65 .758 .928 r
.25806 .66289 m .24781 .66604 L .24454 .66313 L p F P
0 g
s
.65 .758 .928 r
.41312 .66607 m .42364 .66292 L .42664 .66583 L p F P
0 g
s
.65 .758 .928 r
.42364 .66292 m .41312 .66607 L .4101 .66317 L p F P
0 g
s
.65 .758 .928 r
.59197 .66578 m .6028 .66262 L .60553 .66553 L p F P
0 g
s
.65 .758 .928 r
.6028 .66262 m .59197 .66578 L .58923 .66287 L p F P
0 g
s
.65 .758 .928 r
.26131 .6658 m .27159 .66266 L .27482 .66557 L p F P
0 g
s
.65 .758 .928 r
.27159 .66266 m .26131 .6658 L .25806 .66289 L p F P
0 g
s
.65 .758 .928 r
.42664 .66583 m .4372 .66268 L .44017 .66559 L p F P
0 g
s
.65 .758 .928 r
.4372 .66268 m .42664 .66583 L .42364 .66292 L p F P
0 g
s
.65 .758 .928 r
.60553 .66553 m .61637 .66237 L .61908 .66527 L p F P
0 g
s
.651 .758 .928 r
.61637 .66237 m .60553 .66553 L .6028 .66262 L p F P
0 g
s
.65 .758 .928 r
.27482 .66557 m .28512 .66242 L .28833 .66533 L p F P
0 g
s
.65 .758 .928 r
.28512 .66242 m .27482 .66557 L .27159 .66266 L p F P
0 g
s
.65 .758 .928 r
.44017 .66559 m .45075 .66244 L .45371 .66534 L p F P
0 g
s
.65 .758 .928 r
.45075 .66244 m .44017 .66559 L .4372 .66268 L p F P
0 g
s
.651 .758 .928 r
.61908 .66527 m .62995 .66211 L .63264 .66502 L p F P
0 g
s
.651 .758 .928 r
.62995 .66211 m .61908 .66527 L .61637 .66237 L p F P
0 g
s
.65 .758 .928 r
.28833 .66533 m .29866 .66218 L .30185 .66509 L p F P
0 g
s
.65 .758 .928 r
.29866 .66218 m .28833 .66533 L .28512 .66242 L p F P
0 g
s
.65 .758 .928 r
.45371 .66534 m .46431 .66219 L .46724 .6651 L p F P
0 g
s
.65 .758 .928 r
.46431 .66219 m .45371 .66534 L .45075 .66244 L p F P
0 g
s
.65 .758 .928 r
.13646 .66497 m .14654 .66184 L .14996 .66475 L p F P
0 g
s
.65 .758 .928 r
.14654 .66184 m .13646 .66497 L .13302 .66206 L p F P
0 g
s
.651 .758 .928 r
.64353 .66186 m .63264 .66502 L .62995 .66211 L p F P
0 g
s
.65 .758 .928 r
.30185 .66509 m .3122 .66194 L .31537 .66485 L p F P
0 g
s
.65 .758 .928 r
.3122 .66194 m .30185 .66509 L .29866 .66218 L p F P
0 g
s
.65 .758 .928 r
.46724 .6651 m .47787 .66195 L .48078 .66486 L p F P
0 g
s
.65 .758 .928 r
.47787 .66195 m .46724 .6651 L .46431 .66219 L p F P
0 g
s
.65 .758 .928 r
.14996 .66475 m .16006 .66161 L .16346 .66452 L p F P
0 g
s
.65 .758 .928 r
.16006 .66161 m .14996 .66475 L .14654 .66184 L p F P
0 g
s
.65 .758 .928 r
.31537 .66485 m .32574 .6617 L .32889 .66461 L p F P
0 g
s
.65 .758 .928 r
.32574 .6617 m .31537 .66485 L .3122 .66194 L p F P
0 g
s
.65 .758 .928 r
.48078 .66486 m .49143 .6617 L .49433 .66461 L p F P
0 g
s
.65 .758 .928 r
.49143 .6617 m .48078 .66486 L .47787 .66195 L p F P
0 g
s
.65 .758 .928 r
.16346 .66452 m .17358 .66138 L .17696 .66429 L p F P
0 g
s
.65 .758 .928 r
.17358 .66138 m .16346 .66452 L .16006 .66161 L p F P
0 g
s
.65 .758 .928 r
.49433 .66461 m .505 .66145 L .50787 .66436 L p F P
0 g
s
.65 .758 .928 r
.505 .66145 m .49433 .66461 L .49143 .6617 L p F P
0 g
s
.65 .758 .928 r
.32889 .66461 m .33929 .66146 L .34242 .66437 L p F P
0 g
s
.65 .758 .928 r
.33929 .66146 m .32889 .66461 L .32574 .6617 L p F P
0 g
s
.65 .758 .928 r
.17696 .66429 m .18711 .66115 L .19047 .66406 L p F P
0 g
s
.65 .758 .928 r
.18711 .66115 m .17696 .66429 L .17358 .66138 L p F P
0 g
s
.65 .758 .928 r
.50787 .66436 m .51857 .66121 L .52142 .66412 L p F P
0 g
s
.65 .758 .928 r
.51857 .66121 m .50787 .66436 L .505 .66145 L p F P
0 g
s
.65 .758 .928 r
.34242 .66437 m .35284 .66122 L .35594 .66413 L p F P
0 g
s
.65 .758 .928 r
.35284 .66122 m .34242 .66437 L .33929 .66146 L p F P
0 g
s
.65 .758 .928 r
.19047 .66406 m .20064 .66092 L .20398 .66383 L p F P
0 g
s
.65 .758 .928 r
.20064 .66092 m .19047 .66406 L .18711 .66115 L p F P
0 g
s
.65 .758 .928 r
.52142 .66412 m .53214 .66096 L .53498 .66387 L p F P
0 g
s
.65 .758 .928 r
.53214 .66096 m .52142 .66412 L .51857 .66121 L p F P
0 g
s
.65 .758 .928 r
.35594 .66413 m .36639 .66098 L .36948 .66389 L p F P
0 g
s
.65 .758 .928 r
.36639 .66098 m .35594 .66413 L .35284 .66122 L p F P
0 g
s
.65 .758 .928 r
.20398 .66383 m .21418 .66068 L .2175 .6636 L p F P
0 g
s
.65 .758 .928 r
.21418 .66068 m .20398 .66383 L .20064 .66092 L p F P
0 g
s
.65 .758 .928 r
.53498 .66387 m .54572 .66071 L .54854 .66362 L p F P
0 g
s
.65 .758 .928 r
.54572 .66071 m .53498 .66387 L .53214 .66096 L p F P
0 g
s
.65 .758 .928 r
.36948 .66389 m .37995 .66074 L .38301 .66365 L p F P
0 g
s
.65 .758 .928 r
.37995 .66074 m .36948 .66389 L .36639 .66098 L p F P
0 g
s
.65 .758 .928 r
.2175 .6636 m .22771 .66045 L .23101 .66336 L p F P
0 g
s
.65 .758 .928 r
.22771 .66045 m .2175 .6636 L .21418 .66068 L p F P
0 g
s
.65 .758 .928 r
.54854 .66362 m .5593 .66046 L .5621 .66337 L p F P
0 g
s
.65 .758 .928 r
.5593 .66046 m .54854 .66362 L .54572 .66071 L p F P
0 g
s
.65 .758 .928 r
.38301 .66365 m .39351 .66049 L .39655 .66341 L p F P
0 g
s
.65 .758 .928 r
.39351 .66049 m .38301 .66365 L .37995 .66074 L p F P
0 g
s
.65 .758 .928 r
.23101 .66336 m .24126 .66021 L .24454 .66313 L p F P
0 g
s
.65 .758 .928 r
.24126 .66021 m .23101 .66336 L .22771 .66045 L p F P
0 g
s
.65 .758 .928 r
.5621 .66337 m .57289 .66021 L .57566 .66312 L p F P
0 g
s
.65 .758 .928 r
.57289 .66021 m .5621 .66337 L .5593 .66046 L p F P
0 g
s
.65 .758 .928 r
.39655 .66341 m .40707 .66025 L .4101 .66317 L p F P
0 g
s
.65 .758 .928 r
.40707 .66025 m .39655 .66341 L .39351 .66049 L p F P
0 g
s
.65 .758 .928 r
.57566 .66312 m .58648 .65996 L .58923 .66287 L p F P
0 g
s
.65 .758 .928 r
.58648 .65996 m .57566 .66312 L .57289 .66021 L p F P
0 g
s
.65 .758 .928 r
.24454 .66313 m .2548 .65998 L .25806 .66289 L p F P
0 g
s
.65 .758 .928 r
.2548 .65998 m .24454 .66313 L .24126 .66021 L p F P
0 g
s
.65 .758 .928 r
.4101 .66317 m .42064 .66001 L .42364 .66292 L p F P
0 g
s
.65 .758 .928 r
.42064 .66001 m .4101 .66317 L .40707 .66025 L p F P
0 g
s
.65 .758 .928 r
.58923 .66287 m .60007 .65971 L .6028 .66262 L p F P
0 g
s
.65 .758 .928 r
.60007 .65971 m .58923 .66287 L .58648 .65996 L p F P
0 g
s
.65 .758 .928 r
.25806 .66289 m .26835 .65974 L .27159 .66266 L p F P
0 g
s
.65 .758 .928 r
.26835 .65974 m .25806 .66289 L .2548 .65998 L p F P
0 g
s
.65 .758 .928 r
.42364 .66292 m .43421 .65976 L .4372 .66268 L p F P
0 g
s
.65 .758 .928 r
.43421 .65976 m .42364 .66292 L .42064 .66001 L p F P
0 g
s
.651 .758 .928 r
.6028 .66262 m .61366 .65946 L .61637 .66237 L p F P
0 g
s
.651 .758 .928 r
.61366 .65946 m .6028 .66262 L .60007 .65971 L p F P
0 g
s
.65 .758 .928 r
.27159 .66266 m .2819 .6595 L .28512 .66242 L p F P
0 g
s
.65 .758 .928 r
.2819 .6595 m .27159 .66266 L .26835 .65974 L p F P
0 g
s
.65 .758 .928 r
.44778 .65952 m .4372 .66268 L .43421 .65976 L p F P
0 g
s
.65 .758 .928 r
.4372 .66268 m .44778 .65952 L .45075 .66244 L p F P
0 g
s
.651 .758 .928 r
.61637 .66237 m .62726 .6592 L .62995 .66211 L p F P
0 g
s
.651 .758 .928 r
.62726 .6592 m .61637 .66237 L .61366 .65946 L p F P
0 g
s
.65 .758 .928 r
.28512 .66242 m .29546 .65926 L .29866 .66218 L p F P
0 g
s
.65 .758 .928 r
.29546 .65926 m .28512 .66242 L .2819 .6595 L p F P
0 g
s
.65 .758 .928 r
.45075 .66244 m .46136 .65927 L .46431 .66219 L p F P
0 g
s
.65 .758 .928 r
.46136 .65927 m .45075 .66244 L .44778 .65952 L p F P
0 g
s
.65 .758 .928 r
.13302 .66206 m .14311 .65892 L .14654 .66184 L p F P
0 g
s
.65 .757 .928 r
.14311 .65892 m .13302 .66206 L .12957 .65915 L p F P
0 g
s
.651 .758 .928 r
.62995 .66211 m .64086 .65895 L .64353 .66186 L p F P
0 g
s
.651 .758 .928 r
.64086 .65895 m .62995 .66211 L .62726 .6592 L p F P
0 g
s
.65 .758 .928 r
.29866 .66218 m .30902 .65902 L .3122 .66194 L p F P
0 g
s
.65 .758 .928 r
.30902 .65902 m .29866 .66218 L .29546 .65926 L p F P
0 g
s
.65 .758 .928 r
.46431 .66219 m .47494 .65903 L .47787 .66195 L p F P
0 g
s
.65 .758 .928 r
.47494 .65903 m .46431 .66219 L .46136 .65927 L p F P
0 g
s
.65 .758 .928 r
.14654 .66184 m .15665 .65869 L .16006 .66161 L p F P
0 g
s
.65 .758 .928 r
.15665 .65869 m .14654 .66184 L .14311 .65892 L p F P
0 g
s
.651 .758 .928 r
.65447 .65869 m .64353 .66186 L .64086 .65895 L p F P
0 g
s
.65 .758 .928 r
.3122 .66194 m .32258 .65878 L .32574 .6617 L p F P
0 g
s
.65 .758 .928 r
.32258 .65878 m .3122 .66194 L .30902 .65902 L p F P
0 g
s
.65 .758 .928 r
.47787 .66195 m .48853 .65878 L .49143 .6617 L p F P
0 g
s
.65 .758 .928 r
.48853 .65878 m .47787 .66195 L .47494 .65903 L p F P
0 g
s
.65 .758 .928 r
.16006 .66161 m .17019 .65846 L .17358 .66138 L p F P
0 g
s
.65 .758 .928 r
.17019 .65846 m .16006 .66161 L .15665 .65869 L p F P
0 g
s
.65 .758 .928 r
.49143 .6617 m .50211 .65853 L .505 .66145 L p F P
0 g
s
.65 .758 .928 r
.50211 .65853 m .49143 .6617 L .48853 .65878 L p F P
0 g
s
.65 .758 .928 r
.32574 .6617 m .33615 .65854 L .33929 .66146 L p F P
0 g
s
.65 .758 .928 r
.33615 .65854 m .32574 .6617 L .32258 .65878 L p F P
0 g
s
.65 .758 .928 r
.17358 .66138 m .18374 .65823 L .18711 .66115 L p F P
0 g
s
.65 .758 .928 r
.18374 .65823 m .17358 .66138 L .17019 .65846 L p F P
0 g
s
.65 .758 .928 r
.505 .66145 m .5157 .65829 L .51857 .66121 L p F P
0 g
s
.65 .758 .928 r
.5157 .65829 m .505 .66145 L .50211 .65853 L p F P
0 g
s
.65 .758 .928 r
.33929 .66146 m .34972 .6583 L .35284 .66122 L p F P
0 g
s
.65 .758 .928 r
.34972 .6583 m .33929 .66146 L .33615 .65854 L p F P
0 g
s
.65 .758 .928 r
.18711 .66115 m .19729 .65799 L .20064 .66092 L p F P
0 g
s
.65 .758 .928 r
.19729 .65799 m .18711 .66115 L .18374 .65823 L p F P
0 g
s
.65 .758 .928 r
.51857 .66121 m .5293 .65804 L .53214 .66096 L p F P
0 g
s
.65 .758 .928 r
.5293 .65804 m .51857 .66121 L .5157 .65829 L p F P
0 g
s
.65 .758 .928 r
.35284 .66122 m .36329 .65806 L .36639 .66098 L p F P
0 g
s
.65 .758 .928 r
.36329 .65806 m .35284 .66122 L .34972 .6583 L p F P
0 g
s
.65 .758 .928 r
.20064 .66092 m .21084 .65776 L .21418 .66068 L p F P
0 g
s
.65 .758 .928 r
.21084 .65776 m .20064 .66092 L .19729 .65799 L p F P
0 g
s
.65 .758 .928 r
.53214 .66096 m .5429 .65779 L .54572 .66071 L p F P
0 g
s
.65 .758 .928 r
.5429 .65779 m .53214 .66096 L .5293 .65804 L p F P
0 g
s
.65 .758 .928 r
.36639 .66098 m .37687 .65781 L .37995 .66074 L p F P
0 g
s
.65 .758 .928 r
.37687 .65781 m .36639 .66098 L .36329 .65806 L p F P
0 g
s
.65 .758 .928 r
.21418 .66068 m .2244 .65752 L .22771 .66045 L p F P
0 g
s
.65 .758 .928 r
.2244 .65752 m .21418 .66068 L .21084 .65776 L p F P
0 g
s
.65 .758 .928 r
.54572 .66071 m .5565 .65754 L .5593 .66046 L p F P
0 g
s
.65 .758 .928 r
.5565 .65754 m .54572 .66071 L .5429 .65779 L p F P
0 g
s
.65 .758 .928 r
.37995 .66074 m .39045 .65757 L .39351 .66049 L p F P
0 g
s
.65 .758 .928 r
.39045 .65757 m .37995 .66074 L .37687 .65781 L p F P
0 g
s
.65 .758 .928 r
.22771 .66045 m .23797 .65729 L .24126 .66021 L p F P
0 g
s
.65 .758 .928 r
.23797 .65729 m .22771 .66045 L .2244 .65752 L p F P
0 g
s
.65 .758 .928 r
.5593 .66046 m .5701 .65729 L .57289 .66021 L p F P
0 g
s
.65 .758 .928 r
.5701 .65729 m .5593 .66046 L .5565 .65754 L p F P
0 g
s
.65 .758 .928 r
.39351 .66049 m .40403 .65733 L .40707 .66025 L p F P
0 g
s
.65 .758 .928 r
.40403 .65733 m .39351 .66049 L .39045 .65757 L p F P
0 g
s
.65 .758 .928 r
.57289 .66021 m .58371 .65704 L .58648 .65996 L p F P
0 g
s
.65 .758 .928 r
.58371 .65704 m .57289 .66021 L .5701 .65729 L p F P
0 g
s
.65 .758 .928 r
.24126 .66021 m .25153 .65705 L .2548 .65998 L p F P
0 g
s
.65 .758 .928 r
.25153 .65705 m .24126 .66021 L .23797 .65729 L p F P
0 g
s
.65 .758 .928 r
.40707 .66025 m .41762 .65708 L .42064 .66001 L p F P
0 g
s
.65 .758 .928 r
.41762 .65708 m .40707 .66025 L .40403 .65733 L p F P
0 g
s
.65 .758 .928 r
.58648 .65996 m .59732 .65679 L .60007 .65971 L p F P
0 g
s
.65 .758 .928 r
.59732 .65679 m .58648 .65996 L .58371 .65704 L p F P
0 g
s
.65 .758 .928 r
.2548 .65998 m .2651 .65681 L .26835 .65974 L p F P
0 g
s
.65 .758 .928 r
.2651 .65681 m .2548 .65998 L .25153 .65705 L p F P
0 g
s
.65 .758 .928 r
.42064 .66001 m .43121 .65684 L .43421 .65976 L p F P
0 g
s
.65 .758 .928 r
.43121 .65684 m .42064 .66001 L .41762 .65708 L p F P
0 g
s
.651 .758 .928 r
.60007 .65971 m .61094 .65653 L .61366 .65946 L p F P
0 g
s
.651 .758 .928 r
.61094 .65653 m .60007 .65971 L .59732 .65679 L p F P
0 g
s
.65 .758 .928 r
.26835 .65974 m .27867 .65657 L .2819 .6595 L p F P
0 g
s
.65 .758 .928 r
.27867 .65657 m .26835 .65974 L .2651 .65681 L p F P
0 g
s
.65 .758 .928 r
.43421 .65976 m .44481 .65659 L .44778 .65952 L p F P
0 g
s
.65 .758 .928 r
.44481 .65659 m .43421 .65976 L .43121 .65684 L p F P
0 g
s
.651 .758 .928 r
.61366 .65946 m .62456 .65628 L .62726 .6592 L p F P
0 g
s
.651 .758 .928 r
.62456 .65628 m .61366 .65946 L .61094 .65653 L p F P
0 g
s
.65 .758 .928 r
.2819 .6595 m .29225 .65633 L .29546 .65926 L p F P
0 g
s
.65 .758 .928 r
.29225 .65633 m .2819 .6595 L .27867 .65657 L p F P
0 g
s
.65 .758 .928 r
.44778 .65952 m .45841 .65635 L .46136 .65927 L p F P
0 g
s
.65 .758 .928 r
.45841 .65635 m .44778 .65952 L .44481 .65659 L p F P
0 g
s
.65 .757 .928 r
.12957 .65915 m .13966 .65599 L .14311 .65892 L p F P
0 g
s
.65 .757 .928 r
.13966 .65599 m .12957 .65915 L .12611 .65622 L p F P
0 g
s
.651 .758 .928 r
.62726 .6592 m .63818 .65602 L .64086 .65895 L p F P
0 g
s
.651 .758 .928 r
.63818 .65602 m .62726 .6592 L .62456 .65628 L p F P
0 g
s
.65 .758 .928 r
.29546 .65926 m .30583 .65609 L .30902 .65902 L p F P
0 g
s
.65 .758 .928 r
.30583 .65609 m .29546 .65926 L .29225 .65633 L p F P
0 g
s
.65 .758 .928 r
.46136 .65927 m .47201 .6561 L .47494 .65903 L p F P
0 g
s
.65 .758 .928 r
.47201 .6561 m .46136 .65927 L .45841 .65635 L p F P
0 g
s
.65 .758 .928 r
.14311 .65892 m .15322 .65576 L .15665 .65869 L p F P
0 g
s
.65 .757 .928 r
.15322 .65576 m .14311 .65892 L .13966 .65599 L p F P
0 g
s
.651 .758 .928 r
.64086 .65895 m .65181 .65576 L .65447 .65869 L p F P
0 g
s
.651 .758 .928 r
.65181 .65576 m .64086 .65895 L .63818 .65602 L p F P
0 g
s
.65 .758 .928 r
.30902 .65902 m .31941 .65585 L .32258 .65878 L p F P
0 g
s
.65 .758 .928 r
.31941 .65585 m .30902 .65902 L .30583 .65609 L p F P
0 g
s
.65 .758 .928 r
.47494 .65903 m .48561 .65585 L .48853 .65878 L p F P
0 g
s
.65 .758 .928 r
.48561 .65585 m .47494 .65903 L .47201 .6561 L p F P
0 g
s
.651 .758 .928 r
.66543 .65551 m .65447 .65869 L .65181 .65576 L p F P
0 g
s
.65 .758 .928 r
.15665 .65869 m .16679 .65553 L .17019 .65846 L p F P
0 g
s
.65 .758 .928 r
.16679 .65553 m .15665 .65869 L .15322 .65576 L p F P
0 g
s
.65 .758 .928 r
.48853 .65878 m .49922 .65561 L .50211 .65853 L p F P
0 g
s
.65 .758 .928 r
.49922 .65561 m .48853 .65878 L .48561 .65585 L p F P
0 g
s
.65 .758 .928 r
.32258 .65878 m .333 .65561 L .33615 .65854 L p F P
0 g
s
.65 .758 .928 r
.333 .65561 m .32258 .65878 L .31941 .65585 L p F P
0 g
s
.65 .758 .928 r
.17019 .65846 m .18036 .6553 L .18374 .65823 L p F P
0 g
s
.65 .758 .928 r
.18036 .6553 m .17019 .65846 L .16679 .65553 L p F P
0 g
s
.65 .758 .928 r
.50211 .65853 m .51283 .65536 L .5157 .65829 L p F P
0 g
s
.65 .758 .928 r
.51283 .65536 m .50211 .65853 L .49922 .65561 L p F P
0 g
s
.65 .758 .928 r
.33615 .65854 m .34659 .65537 L .34972 .6583 L p F P
0 g
s
.65 .758 .928 r
.34659 .65537 m .33615 .65854 L .333 .65561 L p F P
0 g
s
.65 .758 .928 r
.18374 .65823 m .19393 .65506 L .19729 .65799 L p F P
0 g
s
.65 .758 .928 r
.19393 .65506 m .18374 .65823 L .18036 .6553 L p F P
0 g
s
.65 .758 .928 r
.5157 .65829 m .52645 .65511 L .5293 .65804 L p F P
0 g
s
.65 .758 .928 r
.52645 .65511 m .5157 .65829 L .51283 .65536 L p F P
0 g
s
.65 .758 .928 r
.34972 .6583 m .36019 .65512 L .36329 .65806 L p F P
0 g
s
.65 .758 .928 r
.36019 .65512 m .34972 .6583 L .34659 .65537 L p F P
0 g
s
.65 .758 .928 r
.19729 .65799 m .2075 .65483 L .21084 .65776 L p F P
0 g
s
.65 .758 .928 r
.2075 .65483 m .19729 .65799 L .19393 .65506 L p F P
0 g
s
.65 .758 .928 r
.5293 .65804 m .54007 .65486 L .5429 .65779 L p F P
0 g
s
.65 .758 .928 r
.54007 .65486 m .5293 .65804 L .52645 .65511 L p F P
0 g
s
.65 .758 .928 r
.36329 .65806 m .37378 .65488 L .37687 .65781 L p F P
0 g
s
.65 .758 .928 r
.37378 .65488 m .36329 .65806 L .36019 .65512 L p F P
0 g
s
.65 .758 .928 r
.21084 .65776 m .22108 .65459 L .2244 .65752 L p F P
0 g
s
.65 .758 .928 r
.22108 .65459 m .21084 .65776 L .2075 .65483 L p F P
0 g
s
.65 .758 .928 r
.5429 .65779 m .55369 .65461 L .5565 .65754 L p F P
0 g
s
.65 .758 .928 r
.55369 .65461 m .5429 .65779 L .54007 .65486 L p F P
0 g
s
.65 .758 .928 r
.37687 .65781 m .38738 .65464 L .39045 .65757 L p F P
0 g
s
.65 .758 .928 r
.38738 .65464 m .37687 .65781 L .37378 .65488 L p F P
0 g
s
.65 .758 .928 r
.2244 .65752 m .23467 .65435 L .23797 .65729 L p F P
0 g
s
.65 .758 .928 r
.23467 .65435 m .2244 .65752 L .22108 .65459 L p F P
0 g
s
.65 .758 .928 r
.5565 .65754 m .56731 .65436 L .5701 .65729 L p F P
0 g
s
.65 .758 .928 r
.56731 .65436 m .5565 .65754 L .55369 .65461 L p F P
0 g
s
.65 .758 .928 r
.39045 .65757 m .40099 .65439 L .40403 .65733 L p F P
0 g
s
.65 .758 .928 r
.40099 .65439 m .39045 .65757 L .38738 .65464 L p F P
0 g
s
.65 .758 .928 r
.23797 .65729 m .24825 .65412 L .25153 .65705 L p F P
0 g
s
.65 .758 .928 r
.24825 .65412 m .23797 .65729 L .23467 .65435 L p F P
0 g
s
.65 .758 .928 r
.5701 .65729 m .58094 .65411 L .58371 .65704 L p F P
0 g
s
.65 .758 .928 r
.58094 .65411 m .5701 .65729 L .56731 .65436 L p F P
0 g
s
.65 .758 .928 r
.40403 .65733 m .4146 .65415 L .41762 .65708 L p F P
0 g
s
.65 .758 .928 r
.4146 .65415 m .40403 .65733 L .40099 .65439 L p F P
0 g
s
.65 .758 .928 r
.58371 .65704 m .59457 .65385 L .59732 .65679 L p F P
0 g
s
.65 .758 .928 r
.59457 .65385 m .58371 .65704 L .58094 .65411 L p F P
0 g
s
.65 .758 .928 r
.25153 .65705 m .26184 .65388 L .2651 .65681 L p F P
0 g
s
.65 .758 .928 r
.26184 .65388 m .25153 .65705 L .24825 .65412 L p F P
0 g
s
.65 .758 .928 r
.41762 .65708 m .42821 .6539 L .43121 .65684 L p F P
0 g
s
.65 .758 .928 r
.42821 .6539 m .41762 .65708 L .4146 .65415 L p F P
0 g
s
.651 .758 .928 r
.59732 .65679 m .60821 .6536 L .61094 .65653 L p F P
0 g
s
.651 .758 .928 r
.60821 .6536 m .59732 .65679 L .59457 .65385 L p F P
0 g
s
.65 .758 .928 r
.2651 .65681 m .27543 .65364 L .27867 .65657 L p F P
0 g
s
.65 .758 .928 r
.27543 .65364 m .2651 .65681 L .26184 .65388 L p F P
0 g
s
.65 .758 .928 r
.43121 .65684 m .44182 .65366 L .44481 .65659 L p F P
0 g
s
.65 .758 .928 r
.44182 .65366 m .43121 .65684 L .42821 .6539 L p F P
0 g
s
.651 .758 .928 r
.61094 .65653 m .62185 .65334 L .62456 .65628 L p F P
0 g
s
.651 .758 .928 r
.62185 .65334 m .61094 .65653 L .60821 .6536 L p F P
0 g
s
.65 .758 .928 r
.27867 .65657 m .28903 .6534 L .29225 .65633 L p F P
0 g
s
.65 .758 .928 r
.28903 .6534 m .27867 .65657 L .27543 .65364 L p F P
0 g
s
.65 .758 .928 r
.44481 .65659 m .45544 .65341 L .45841 .65635 L p F P
0 g
s
.65 .758 .928 r
.45544 .65341 m .44481 .65659 L .44182 .65366 L p F P
0 g
s
.65 .757 .928 r
.12611 .65622 m .13621 .65305 L .13966 .65599 L p F P
0 g
s
.65 .757 .928 r
.13621 .65305 m .12611 .65622 L .12263 .65328 L p F P
0 g
s
.651 .758 .928 r
.62456 .65628 m .63549 .65309 L .63818 .65602 L p F P
0 g
s
.651 .758 .928 r
.63549 .65309 m .62456 .65628 L .62185 .65334 L p F P
0 g
s
.65 .758 .928 r
.29225 .65633 m .30263 .65315 L .30583 .65609 L p F P
0 g
s
.65 .758 .928 r
.30263 .65315 m .29225 .65633 L .28903 .6534 L p F P
0 g
s
.65 .758 .928 r
.46906 .65316 m .45841 .65635 L .45544 .65341 L p F P
0 g
s
.65 .758 .928 r
.45841 .65635 m .46906 .65316 L .47201 .6561 L p F P
0 g
s
.65 .757 .928 r
.13966 .65599 m .14979 .65282 L .15322 .65576 L p F P
0 g
s
.65 .757 .928 r
.14979 .65282 m .13966 .65599 L .13621 .65305 L p F P
0 g
s
.651 .758 .928 r
.63818 .65602 m .64914 .65283 L .65181 .65576 L p F P
0 g
s
.651 .758 .928 r
.64914 .65283 m .63818 .65602 L .63549 .65309 L p F P
0 g
s
.65 .758 .928 r
.30583 .65609 m .31624 .65291 L .31941 .65585 L p F P
0 g
s
.65 .758 .928 r
.31624 .65291 m .30583 .65609 L .30263 .65315 L p F P
0 g
s
.65 .758 .928 r
.47201 .6561 m .48269 .65292 L .48561 .65585 L p F P
0 g
s
.65 .758 .928 r
.48269 .65292 m .47201 .6561 L .46906 .65316 L p F P
0 g
s
.65 .758 .928 r
.15322 .65576 m .16338 .65259 L .16679 .65553 L p F P
0 g
s
.65 .758 .928 r
.16338 .65259 m .15322 .65576 L .14979 .65282 L p F P
0 g
s
.651 .758 .928 r
.65181 .65576 m .66279 .65257 L .66543 .65551 L p F P
0 g
s
.651 .758 .928 r
.66279 .65257 m .65181 .65576 L .64914 .65283 L p F P
0 g
s
.65 .758 .928 r
.31941 .65585 m .32984 .65267 L .333 .65561 L p F P
0 g
s
.65 .758 .928 r
.32984 .65267 m .31941 .65585 L .31624 .65291 L p F P
0 g
s
.65 .758 .928 r
.49632 .65267 m .48561 .65585 L .48269 .65292 L p F P
0 g
s
.65 .758 .928 r
.48561 .65585 m .49632 .65267 L .49922 .65561 L p F P
0 g
s
.651 .758 .928 r
.67644 .65231 m .66543 .65551 L .66279 .65257 L p F P
0 g
s
.65 .758 .928 r
.16679 .65553 m .17696 .65236 L .18036 .6553 L p F P
0 g
s
.65 .758 .928 r
.17696 .65236 m .16679 .65553 L .16338 .65259 L p F P
0 g
s
.65 .758 .928 r
.49922 .65561 m .50995 .65242 L .51283 .65536 L p F P
0 g
s
.65 .758 .928 r
.50995 .65242 m .49922 .65561 L .49632 .65267 L p F P
0 g
s
.65 .758 .928 r
.333 .65561 m .34345 .65243 L .34659 .65537 L p F P
0 g
s
.65 .758 .928 r
.34345 .65243 m .333 .65561 L .32984 .65267 L p F P
0 g
s
.65 .758 .928 r
.18036 .6553 m .19056 .65212 L .19393 .65506 L p F P
0 g
s
.65 .758 .928 r
.19056 .65212 m .18036 .6553 L .17696 .65236 L p F P
0 g
s
.65 .758 .928 r
.51283 .65536 m .52359 .65217 L .52645 .65511 L p F P
0 g
s
.65 .758 .928 r
.52359 .65217 m .51283 .65536 L .50995 .65242 L p F P
0 g
s
.65 .758 .928 r
.34659 .65537 m .35707 .65218 L .36019 .65512 L p F P
0 g
s
.65 .758 .928 r
.35707 .65218 m .34659 .65537 L .34345 .65243 L p F P
0 g
s
.65 .758 .928 r
.19393 .65506 m .20415 .65189 L .2075 .65483 L p F P
0 g
s
.65 .758 .928 r
.20415 .65189 m .19393 .65506 L .19056 .65212 L p F P
0 g
s
.65 .758 .928 r
.52645 .65511 m .53722 .65192 L .54007 .65486 L p F P
0 g
s
.65 .758 .928 r
.53722 .65192 m .52645 .65511 L .52359 .65217 L p F P
0 g
s
.65 .758 .928 r
.36019 .65512 m .37069 .65194 L .37378 .65488 L p F P
0 g
s
.65 .758 .928 r
.37069 .65194 m .36019 .65512 L .35707 .65218 L p F P
0 g
s
.65 .758 .928 r
.2075 .65483 m .21775 .65165 L .22108 .65459 L p F P
0 g
s
.65 .758 .928 r
.21775 .65165 m .2075 .65483 L .20415 .65189 L p F P
0 g
s
.65 .758 .928 r
.54007 .65486 m .55087 .65167 L .55369 .65461 L p F P
0 g
s
.65 .758 .928 r
.55087 .65167 m .54007 .65486 L .53722 .65192 L p F P
0 g
s
.65 .758 .928 r
.37378 .65488 m .38431 .65169 L .38738 .65464 L p F P
0 g
s
.65 .758 .928 r
.38431 .65169 m .37378 .65488 L .37069 .65194 L p F P
0 g
s
.65 .758 .928 r
.22108 .65459 m .23136 .65141 L .23467 .65435 L p F P
0 g
s
.65 .758 .928 r
.23136 .65141 m .22108 .65459 L .21775 .65165 L p F P
0 g
s
.65 .758 .928 r
.55369 .65461 m .56451 .65142 L .56731 .65436 L p F P
0 g
s
.65 .758 .928 r
.56451 .65142 m .55369 .65461 L .55087 .65167 L p F P
0 g
s
.65 .758 .928 r
.38738 .65464 m .39793 .65145 L .40099 .65439 L p F P
0 g
s
.65 .758 .928 r
.39793 .65145 m .38738 .65464 L .38431 .65169 L p F P
0 g
s
.65 .758 .928 r
.23467 .65435 m .24496 .65117 L .24825 .65412 L p F P
0 g
s
.65 .758 .928 r
.24496 .65117 m .23467 .65435 L .23136 .65141 L p F P
0 g
s
.65 .758 .928 r
.56731 .65436 m .57816 .65116 L .58094 .65411 L p F P
0 g
s
.65 .758 .928 r
.57816 .65116 m .56731 .65436 L .56451 .65142 L p F P
0 g
s
.65 .758 .928 r
.40099 .65439 m .41156 .6512 L .4146 .65415 L p F P
0 g
s
.65 .758 .928 r
.41156 .6512 m .40099 .65439 L .39793 .65145 L p F P
0 g
s
.65 .758 .928 r
.58094 .65411 m .59182 .65091 L .59457 .65385 L p F P
0 g
s
.65 .758 .928 r
.59182 .65091 m .58094 .65411 L .57816 .65116 L p F P
0 g
s
.65 .758 .928 r
.24825 .65412 m .25857 .65093 L .26184 .65388 L p F P
0 g
s
.65 .758 .928 r
.25857 .65093 m .24825 .65412 L .24496 .65117 L p F P
0 g
s
.65 .758 .928 r
.4146 .65415 m .42519 .65096 L .42821 .6539 L p F P
0 g
s
.65 .758 .928 r
.42519 .65096 m .4146 .65415 L .41156 .6512 L p F P
0 g
s
.651 .758 .928 r
.59457 .65385 m .60547 .65066 L .60821 .6536 L p F P
0 g
s
.651 .758 .928 r
.60547 .65066 m .59457 .65385 L .59182 .65091 L p F P
0 g
s
.65 .758 .928 r
.26184 .65388 m .27219 .65069 L .27543 .65364 L p F P
0 g
s
.65 .758 .928 r
.27219 .65069 m .26184 .65388 L .25857 .65093 L p F P
0 g
s
.65 .758 .928 r
.42821 .6539 m .43883 .65071 L .44182 .65366 L p F P
0 g
s
.65 .758 .928 r
.43883 .65071 m .42821 .6539 L .42519 .65096 L p F P
0 g
s
.651 .758 .928 r
.60821 .6536 m .61913 .6504 L .62185 .65334 L p F P
0 g
s
.651 .758 .928 r
.61913 .6504 m .60821 .6536 L .60547 .65066 L p F P
0 g
s
.65 .758 .928 r
.27543 .65364 m .2858 .65045 L .28903 .6534 L p F P
0 g
s
.65 .758 .928 r
.2858 .65045 m .27543 .65364 L .27219 .65069 L p F P
0 g
s
.65 .758 .928 r
.44182 .65366 m .45247 .65046 L .45544 .65341 L p F P
0 g
s
.65 .758 .928 r
.45247 .65046 m .44182 .65366 L .43883 .65071 L p F P
0 g
s
.65 .757 .928 r
.12263 .65328 m .13275 .6501 L .13621 .65305 L p F P
0 g
s
.65 .757 .928 r
.13275 .6501 m .12263 .65328 L .11915 .65033 L p F P
0 g
s
.651 .758 .928 r
.62185 .65334 m .6328 .65015 L .63549 .65309 L p F P
0 g
s
.651 .758 .928 r
.6328 .65015 m .62185 .65334 L .61913 .6504 L p F P
0 g
s
.65 .758 .928 r
.28903 .6534 m .29942 .65021 L .30263 .65315 L p F P
0 g
s
.65 .758 .928 r
.29942 .65021 m .28903 .6534 L .2858 .65045 L p F P
0 g
s
.65 .758 .928 r
.45544 .65341 m .46611 .65022 L .46906 .65316 L p F P
0 g
s
.65 .758 .928 r
.46611 .65022 m .45544 .65341 L .45247 .65046 L p F P
0 g
s
.65 .757 .928 r
.13621 .65305 m .14635 .64987 L .14979 .65282 L p F P
0 g
s
.65 .757 .928 r
.14635 .64987 m .13621 .65305 L .13275 .6501 L p F P
0 g
s
.651 .758 .928 r
.63549 .65309 m .64646 .64989 L .64914 .65283 L p F P
0 g
s
.651 .758 .928 r
.64646 .64989 m .63549 .65309 L .6328 .65015 L p F P
0 g
s
.65 .758 .928 r
.30263 .65315 m .31305 .64996 L .31624 .65291 L p F P
0 g
s
.65 .758 .928 r
.31305 .64996 m .30263 .65315 L .29942 .65021 L p F P
0 g
s
.65 .758 .928 r
.47976 .64997 m .46906 .65316 L .46611 .65022 L p F P
0 g
s
.65 .758 .928 r
.46906 .65316 m .47976 .64997 L .48269 .65292 L p F P
0 g
s
.65 .758 .928 r
.14979 .65282 m .15995 .64964 L .16338 .65259 L p F P
0 g
s
.65 .757 .928 r
.15995 .64964 m .14979 .65282 L .14635 .64987 L p F P
0 g
s
.651 .758 .928 r
.64914 .65283 m .66013 .64963 L .66279 .65257 L p F P
0 g
s
.651 .758 .928 r
.66013 .64963 m .64914 .65283 L .64646 .64989 L p F P
0 g
s
.65 .758 .928 r
.31624 .65291 m .32668 .64972 L .32984 .65267 L p F P
0 g
s
.65 .758 .928 r
.32668 .64972 m .31624 .65291 L .31305 .64996 L p F P
0 g
s
.65 .758 .928 r
.48269 .65292 m .49341 .64972 L .49632 .65267 L p F P
0 g
s
.65 .758 .928 r
.49341 .64972 m .48269 .65292 L .47976 .64997 L p F P
0 g
s
.651 .758 .928 r
.66279 .65257 m .6738 .64937 L .67644 .65231 L p F P
0 g
s
.651 .758 .928 r
.6738 .64937 m .66279 .65257 L .66013 .64963 L p F P
0 g
s
.65 .758 .928 r
.16338 .65259 m .17356 .64941 L .17696 .65236 L p F P
0 g
s
.65 .758 .928 r
.17356 .64941 m .16338 .65259 L .15995 .64964 L p F P
0 g
s
.65 .758 .928 r
.50706 .64947 m .49632 .65267 L .49341 .64972 L p F P
0 g
s
.65 .758 .928 r
.49632 .65267 m .50706 .64947 L .50995 .65242 L p F P
0 g
s
.65 .758 .928 r
.32984 .65267 m .34031 .64948 L .34345 .65243 L p F P
0 g
s
.65 .758 .928 r
.34031 .64948 m .32984 .65267 L .32668 .64972 L p F P
0 g
s
.651 .758 .928 r
.68748 .64911 m .67644 .65231 L .6738 .64937 L p F P
0 g
s
.65 .758 .928 r
.17696 .65236 m .18718 .64917 L .19056 .65212 L p F P
0 g
s
.65 .758 .928 r
.18718 .64917 m .17696 .65236 L .17356 .64941 L p F P
0 g
s
.65 .758 .928 r
.50995 .65242 m .52072 .64922 L .52359 .65217 L p F P
0 g
s
.65 .758 .928 r
.52072 .64922 m .50995 .65242 L .50706 .64947 L p F P
0 g
s
.65 .758 .928 r
.34345 .65243 m .35394 .64923 L .35707 .65218 L p F P
0 g
s
.65 .758 .928 r
.35394 .64923 m .34345 .65243 L .34031 .64948 L p F P
0 g
s
.65 .758 .928 r
.19056 .65212 m .20079 .64893 L .20415 .65189 L p F P
0 g
s
.65 .758 .928 r
.20079 .64893 m .19056 .65212 L .18718 .64917 L p F P
0 g
s
.65 .758 .928 r
.52359 .65217 m .53437 .64897 L .53722 .65192 L p F P
0 g
s
.65 .758 .928 r
.53437 .64897 m .52359 .65217 L .52072 .64922 L p F P
0 g
s
.65 .758 .928 r
.35707 .65218 m .36758 .64899 L .37069 .65194 L p F P
0 g
s
.65 .758 .928 r
.36758 .64899 m .35707 .65218 L .35394 .64923 L p F P
0 g
s
.65 .758 .928 r
.20415 .65189 m .21441 .6487 L .21775 .65165 L p F P
0 g
s
.65 .758 .928 r
.21441 .6487 m .20415 .65189 L .20079 .64893 L p F P
0 g
s
.65 .758 .928 r
.53722 .65192 m .54804 .64872 L .55087 .65167 L p F P
0 g
s
.65 .758 .928 r
.54804 .64872 m .53722 .65192 L .53437 .64897 L p F P
0 g
s
.65 .758 .928 r
.37069 .65194 m .38122 .64874 L .38431 .65169 L p F P
0 g
s
.65 .758 .928 r
.38122 .64874 m .37069 .65194 L .36758 .64899 L p F P
0 g
s
.65 .758 .928 r
.21775 .65165 m .22804 .64846 L .23136 .65141 L p F P
0 g
s
.65 .758 .928 r
.22804 .64846 m .21775 .65165 L .21441 .6487 L p F P
0 g
s
.65 .758 .928 r
.55087 .65167 m .5617 .64847 L .56451 .65142 L p F P
0 g
s
.65 .758 .928 r
.5617 .64847 m .55087 .65167 L .54804 .64872 L p F P
0 g
s
.65 .758 .928 r
.38431 .65169 m .39487 .6485 L .39793 .65145 L p F P
0 g
s
.65 .758 .928 r
.39487 .6485 m .38431 .65169 L .38122 .64874 L p F P
0 g
s
.65 .758 .928 r
.23136 .65141 m .24166 .64822 L .24496 .65117 L p F P
0 g
s
.65 .758 .928 r
.24166 .64822 m .23136 .65141 L .22804 .64846 L p F P
0 g
s
.65 .758 .928 r
.56451 .65142 m .57538 .64821 L .57816 .65116 L p F P
0 g
s
.65 .758 .928 r
.57538 .64821 m .56451 .65142 L .5617 .64847 L p F P
0 g
s
.65 .758 .928 r
.39793 .65145 m .40852 .64825 L .41156 .6512 L p F P
0 g
s
.65 .758 .928 r
.40852 .64825 m .39793 .65145 L .39487 .6485 L p F P
0 g
s
.65 .758 .928 r
.57816 .65116 m .58905 .64796 L .59182 .65091 L p F P
0 g
s
.65 .758 .928 r
.58905 .64796 m .57816 .65116 L .57538 .64821 L p F P
0 g
s
.65 .758 .928 r
.24496 .65117 m .25529 .64798 L .25857 .65093 L p F P
0 g
s
.65 .758 .928 r
.25529 .64798 m .24496 .65117 L .24166 .64822 L p F P
0 g
s
.65 .758 .928 r
.41156 .6512 m .42217 .648 L .42519 .65096 L p F P
0 g
s
.65 .758 .928 r
.42217 .648 m .41156 .6512 L .40852 .64825 L p F P
0 g
s
.651 .758 .928 r
.59182 .65091 m .60273 .64771 L .60547 .65066 L p F P
0 g
s
.651 .758 .928 r
.60273 .64771 m .59182 .65091 L .58905 .64796 L p F P
0 g
s
.65 .758 .928 r
.25857 .65093 m .26893 .64774 L .27219 .65069 L p F P
0 g
s
.65 .758 .928 r
.26893 .64774 m .25857 .65093 L .25529 .64798 L p F P
0 g
s
.65 .758 .928 r
.42519 .65096 m .43583 .64776 L .43883 .65071 L p F P
0 g
s
.65 .758 .928 r
.43583 .64776 m .42519 .65096 L .42217 .648 L p F P
0 g
s
.651 .758 .928 r
.60547 .65066 m .61641 .64745 L .61913 .6504 L p F P
0 g
s
.651 .758 .928 r
.61641 .64745 m .60547 .65066 L .60273 .64771 L p F P
0 g
s
.65 .758 .928 r
.27219 .65069 m .28256 .64749 L .2858 .65045 L p F P
0 g
s
.65 .758 .928 r
.28256 .64749 m .27219 .65069 L .26893 .64774 L p F P
0 g
s
.65 .758 .928 r
.43883 .65071 m .44949 .64751 L .45247 .65046 L p F P
0 g
s
.65 .758 .928 r
.44949 .64751 m .43883 .65071 L .43583 .64776 L p F P
0 g
s
.65 .757 .928 r
.11915 .65033 m .12927 .64715 L .13275 .6501 L p F P
0 g
s
.65 .757 .928 r
.12927 .64715 m .11915 .65033 L .11565 .64738 L p F P
0 g
s
.651 .758 .928 r
.61913 .6504 m .63009 .64719 L .6328 .65015 L p F P
0 g
s
.651 .758 .928 r
.63009 .64719 m .61913 .6504 L .61641 .64745 L p F P
0 g
s
.65 .758 .928 r
.2858 .65045 m .29621 .64725 L .29942 .65021 L p F P
0 g
s
.65 .758 .928 r
.29621 .64725 m .2858 .65045 L .28256 .64749 L p F P
0 g
s
.65 .758 .928 r
.45247 .65046 m .46315 .64726 L .46611 .65022 L p F P
0 g
s
.65 .758 .928 r
.46315 .64726 m .45247 .65046 L .44949 .64751 L p F P
0 g
s
.65 .757 .928 r
.13275 .6501 m .1429 .64692 L .14635 .64987 L p F P
0 g
s
.65 .757 .928 r
.1429 .64692 m .13275 .6501 L .12927 .64715 L p F P
0 g
s
.651 .758 .928 r
.6328 .65015 m .64378 .64694 L .64646 .64989 L p F P
0 g
s
.651 .758 .928 r
.64378 .64694 m .6328 .65015 L .63009 .64719 L p F P
0 g
s
.65 .758 .928 r
.29942 .65021 m .30985 .64701 L .31305 .64996 L p F P
0 g
s
.65 .758 .928 r
.30985 .64701 m .29942 .65021 L .29621 .64725 L p F P
0 g
s
.65 .758 .928 r
.46611 .65022 m .47682 .64701 L .47976 .64997 L p F P
0 g
s
.65 .758 .928 r
.47682 .64701 m .46611 .65022 L .46315 .64726 L p F P
0 g
s
.65 .757 .928 r
.14635 .64987 m .15652 .64668 L .15995 .64964 L p F P
0 g
s
.65 .757 .928 r
.15652 .64668 m .14635 .64987 L .1429 .64692 L p F P
0 g
s
.651 .758 .928 r
.64646 .64989 m .65747 .64668 L .66013 .64963 L p F P
0 g
s
.651 .758 .928 r
.65747 .64668 m .64646 .64989 L .64378 .64694 L p F P
0 g
s
.65 .758 .928 r
.31305 .64996 m .3235 .64676 L .32668 .64972 L p F P
0 g
s
.65 .758 .928 r
.3235 .64676 m .31305 .64996 L .30985 .64701 L p F P
0 g
s
.65 .758 .928 r
.49049 .64676 m .47976 .64997 L .47682 .64701 L p F P
0 g
s
.65 .758 .928 r
.47976 .64997 m .49049 .64676 L .49341 .64972 L p F P
0 g
s
.651 .758 .928 r
.66013 .64963 m .67116 .64642 L .6738 .64937 L p F P
0 g
s
.651 .758 .928 r
.67116 .64642 m .66013 .64963 L .65747 .64668 L p F P
0 g
s
.65 .758 .928 r
.15995 .64964 m .17015 .64645 L .17356 .64941 L p F P
0 g
s
.65 .757 .928 r
.17015 .64645 m .15995 .64964 L .15652 .64668 L p F P
0 g
s
.65 .758 .928 r
.49341 .64972 m .50416 .64651 L .50706 .64947 L p F P
0 g
s
.65 .758 .928 r
.50416 .64651 m .49341 .64972 L .49049 .64676 L p F P
0 g
s
.65 .758 .928 r
.32668 .64972 m .33715 .64652 L .34031 .64948 L p F P
0 g
s
.65 .758 .928 r
.33715 .64652 m .32668 .64972 L .3235 .64676 L p F P
0 g
s
.651 .758 .928 r
.6738 .64937 m .68486 .64616 L .68748 .64911 L p F P
0 g
s
.651 .758 .928 r
.68486 .64616 m .6738 .64937 L .67116 .64642 L p F P
0 g
s
.65 .758 .928 r
.17356 .64941 m .18378 .64621 L .18718 .64917 L p F P
0 g
s
.65 .758 .928 r
.18378 .64621 m .17356 .64941 L .17015 .64645 L p F P
0 g
s
.65 .758 .928 r
.51784 .64626 m .50706 .64947 L .50416 .64651 L p F P
0 g
s
.65 .758 .928 r
.50706 .64947 m .51784 .64626 L .52072 .64922 L p F P
0 g
s
.65 .758 .928 r
.34031 .64948 m .35081 .64627 L .35394 .64923 L p F P
0 g
s
.65 .758 .928 r
.35081 .64627 m .34031 .64948 L .33715 .64652 L p F P
0 g
s
.651 .758 .928 r
.69856 .64589 m .68748 .64911 L .68486 .64616 L p F P
0 g
s
.65 .758 .928 r
.18718 .64917 m .19742 .64597 L .20079 .64893 L p F P
0 g
s
.65 .758 .928 r
.19742 .64597 m .18718 .64917 L .18378 .64621 L p F P
0 g
s
.65 .758 .928 r
.52072 .64922 m .53152 .64601 L .53437 .64897 L p F P
0 g
s
.65 .758 .928 r
.53152 .64601 m .52072 .64922 L .51784 .64626 L p F P
0 g
s
.65 .758 .928 r
.35394 .64923 m .36447 .64603 L .36758 .64899 L p F P
0 g
s
.65 .758 .928 r
.36447 .64603 m .35394 .64923 L .35081 .64627 L p F P
0 g
s
.65 .758 .928 r
.20079 .64893 m .21106 .64574 L .21441 .6487 L p F P
0 g
s
.65 .758 .928 r
.21106 .64574 m .20079 .64893 L .19742 .64597 L p F P
0 g
s
.65 .758 .928 r
.53437 .64897 m .5452 .64576 L .54804 .64872 L p F P
0 g
s
.65 .758 .928 r
.5452 .64576 m .53437 .64897 L .53152 .64601 L p F P
0 g
s
.65 .758 .928 r
.36758 .64899 m .37813 .64578 L .38122 .64874 L p F P
0 g
s
.65 .758 .928 r
.37813 .64578 m .36758 .64899 L .36447 .64603 L p F P
0 g
s
.65 .758 .928 r
.21441 .6487 m .2247 .6455 L .22804 .64846 L p F P
0 g
s
.65 .758 .928 r
.2247 .6455 m .21441 .6487 L .21106 .64574 L p F P
0 g
s
.65 .758 .928 r
.54804 .64872 m .55889 .64551 L .5617 .64847 L p F P
0 g
s
.65 .758 .928 r
.55889 .64551 m .54804 .64872 L .5452 .64576 L p F P
0 g
s
.65 .758 .928 r
.38122 .64874 m .3918 .64554 L .39487 .6485 L p F P
0 g
s
.65 .758 .928 r
.3918 .64554 m .38122 .64874 L .37813 .64578 L p F P
0 g
s
.65 .758 .928 r
.22804 .64846 m .23835 .64526 L .24166 .64822 L p F P
0 g
s
.65 .758 .928 r
.23835 .64526 m .22804 .64846 L .2247 .6455 L p F P
0 g
s
.65 .758 .928 r
.5617 .64847 m .57258 .64525 L .57538 .64821 L p F P
0 g
s
.65 .758 .928 r
.57258 .64525 m .5617 .64847 L .55889 .64551 L p F P
0 g
s
.65 .758 .928 r
.39487 .6485 m .40546 .64529 L .40852 .64825 L p F P
0 g
s
.65 .758 .928 r
.40546 .64529 m .39487 .6485 L .3918 .64554 L p F P
0 g
s
.65 .758 .928 r
.57538 .64821 m .58627 .645 L .58905 .64796 L p F P
0 g
s
.65 .758 .928 r
.58627 .645 m .57538 .64821 L .57258 .64525 L p F P
0 g
s
.65 .758 .928 r
.24166 .64822 m .252 .64501 L .25529 .64798 L p F P
0 g
s
.65 .758 .928 r
.252 .64501 m .24166 .64822 L .23835 .64526 L p F P
0 g
s
.65 .758 .928 r
.40852 .64825 m .41914 .64504 L .42217 .648 L p F P
0 g
s
.65 .758 .928 r
.41914 .64504 m .40852 .64825 L .40546 .64529 L p F P
0 g
s
.651 .758 .928 r
.58905 .64796 m .59997 .64475 L .60273 .64771 L p F P
0 g
s
.651 .758 .928 r
.59997 .64475 m .58905 .64796 L .58627 .645 L p F P
0 g
s
.65 .758 .928 r
.25529 .64798 m .26566 .64477 L .26893 .64774 L p F P
0 g
s
.65 .758 .928 r
.26566 .64477 m .25529 .64798 L .252 .64501 L p F P
0 g
s
.65 .758 .928 r
.42217 .648 m .43281 .64479 L .43583 .64776 L p F P
0 g
s
.65 .758 .928 r
.43281 .64479 m .42217 .648 L .41914 .64504 L p F P
0 g
s
.651 .758 .928 r
.60273 .64771 m .61367 .64449 L .61641 .64745 L p F P
0 g
s
.651 .758 .928 r
.61367 .64449 m .60273 .64771 L .59997 .64475 L p F P
0 g
s
.65 .758 .928 r
.26893 .64774 m .27932 .64453 L .28256 .64749 L p F P
0 g
s
.65 .758 .928 r
.27932 .64453 m .26893 .64774 L .26566 .64477 L p F P
0 g
s
.65 .758 .928 r
.43583 .64776 m .44649 .64454 L .44949 .64751 L p F P
0 g
s
.65 .758 .928 r
.44649 .64454 m .43583 .64776 L .43281 .64479 L p F P
0 g
s
.65 .757 .928 r
.11565 .64738 m .12579 .64418 L .12927 .64715 L p F P
0 g
s
.65 .757 .928 r
.12579 .64418 m .11565 .64738 L .11215 .64441 L p F P
0 g
s
.651 .758 .928 r
.61641 .64745 m .62738 .64423 L .63009 .64719 L p F P
0 g
s
.651 .758 .928 r
.62738 .64423 m .61641 .64745 L .61367 .64449 L p F P
0 g
s
.65 .758 .928 r
.28256 .64749 m .29298 .64429 L .29621 .64725 L p F P
0 g
s
.65 .758 .928 r
.29298 .64429 m .28256 .64749 L .27932 .64453 L p F P
0 g
s
.65 .758 .928 r
.44949 .64751 m .46018 .6443 L .46315 .64726 L p F P
0 g
s
.65 .758 .928 r
.46018 .6443 m .44949 .64751 L .44649 .64454 L p F P
0 g
s
.65 .757 .928 r
.12927 .64715 m .13943 .64395 L .1429 .64692 L p F P
0 g
s
.65 .757 .928 r
.13943 .64395 m .12927 .64715 L .12579 .64418 L p F P
0 g
s
.651 .758 .928 r
.63009 .64719 m .64108 .64397 L .64378 .64694 L p F P
0 g
s
.651 .758 .928 r
.64108 .64397 m .63009 .64719 L .62738 .64423 L p F P
0 g
s
.65 .758 .928 r
.29621 .64725 m .30664 .64404 L .30985 .64701 L p F P
0 g
s
.65 .758 .928 r
.30664 .64404 m .29621 .64725 L .29298 .64429 L p F P
0 g
s
.65 .758 .928 r
.46315 .64726 m .47387 .64405 L .47682 .64701 L p F P
0 g
s
.65 .758 .928 r
.47387 .64405 m .46315 .64726 L .46018 .6443 L p F P
0 g
s
.65 .757 .928 r
.1429 .64692 m .15308 .64371 L .15652 .64668 L p F P
0 g
s
.65 .757 .928 r
.15308 .64371 m .1429 .64692 L .13943 .64395 L p F P
0 g
s
.651 .758 .928 r
.64378 .64694 m .6548 .64372 L .65747 .64668 L p F P
0 g
s
.651 .758 .928 r
.6548 .64372 m .64378 .64694 L .64108 .64397 L p F P
0 g
s
.65 .758 .928 r
.30985 .64701 m .32031 .6438 L .3235 .64676 L p F P
0 g
s
.65 .758 .928 r
.32031 .6438 m .30985 .64701 L .30664 .64404 L p F P
0 g
s
.65 .758 .928 r
.47682 .64701 m .48756 .6438 L .49049 .64676 L p F P
0 g
s
.65 .758 .928 r
.48756 .6438 m .47682 .64701 L .47387 .64405 L p F P
0 g
s
.651 .758 .928 r
.65747 .64668 m .66851 .64346 L .67116 .64642 L p F P
0 g
s
.651 .758 .928 r
.66851 .64346 m .65747 .64668 L .6548 .64372 L p F P
0 g
s
.65 .757 .928 r
.15652 .64668 m .16673 .64348 L .17015 .64645 L p F P
0 g
s
.65 .757 .928 r
.16673 .64348 m .15652 .64668 L .15308 .64371 L p F P
0 g
s
.65 .758 .928 r
.50125 .64355 m .49049 .64676 L .48756 .6438 L p F P
0 g
s
.65 .758 .928 r
.49049 .64676 m .50125 .64355 L .50416 .64651 L p F P
0 g
s
.65 .758 .928 r
.3235 .64676 m .33399 .64355 L .33715 .64652 L p F P
0 g
s
.65 .758 .928 r
.33399 .64355 m .3235 .64676 L .32031 .6438 L p F P
0 g
s
0 0 .27 r
.40446 .16555 m .40438 .16574 L .40451 .16125 L p F P
0 g
s
0 0 .27 r
.40451 .16125 m .40459 .16105 L .40446 .16555 L p F P
0 g
s
.764 .494 .526 r
.4041 .16568 m .40438 .16574 L .40451 .16125 L p F P
0 g
s
.764 .494 .526 r
.40451 .16125 m .40421 .16119 L .4041 .16568 L p F P
0 g
s
.651 .758 .928 r
.67116 .64642 m .68223 .64319 L .68486 .64616 L p F P
0 g
s
.651 .758 .928 r
.68223 .64319 m .67116 .64642 L .66851 .64346 L p F P
0 g
s
.65 .758 .928 r
.17015 .64645 m .18038 .64324 L .18378 .64621 L p F P
0 g
s
.65 .758 .928 r
.18038 .64324 m .17015 .64645 L .16673 .64348 L p F P
0 g
s
.65 .758 .928 r
.50416 .64651 m .51495 .6433 L .51784 .64626 L p F P
0 g
s
.65 .758 .928 r
.51495 .6433 m .50416 .64651 L .50125 .64355 L p F P
0 g
s
.65 .758 .928 r
.33715 .64652 m .34766 .64331 L .35081 .64627 L p F P
0 g
s
.65 .758 .928 r
.34766 .64331 m .33715 .64652 L .33399 .64355 L p F P
0 g
s
.651 .758 .928 r
.68486 .64616 m .69595 .64293 L .69856 .64589 L p F P
0 g
s
.651 .758 .928 r
.69595 .64293 m .68486 .64616 L .68223 .64319 L p F P
0 g
s
.65 .758 .928 r
.18378 .64621 m .19404 .643 L .19742 .64597 L p F P
0 g
s
.65 .758 .928 r
.19404 .643 m .18378 .64621 L .18038 .64324 L p F P
0 g
s
.65 .758 .928 r
.52865 .64304 m .51784 .64626 L .51495 .6433 L p F P
0 g
s
.65 .758 .928 r
.51784 .64626 m .52865 .64304 L .53152 .64601 L p F P
0 g
s
.65 .758 .928 r
.35081 .64627 m .36134 .64306 L .36447 .64603 L p F P
0 g
s
.65 .758 .928 r
.36134 .64306 m .35081 .64627 L .34766 .64331 L p F P
0 g
s
.651 .758 .928 r
.70968 .64266 m .69856 .64589 L .69595 .64293 L p F P
0 g
s
.65 .758 .928 r
.19742 .64597 m .2077 .64276 L .21106 .64574 L p F P
0 g
s
.65 .758 .928 r
.2077 .64276 m .19742 .64597 L .19404 .643 L p F P
0 g
s
.65 .758 .928 r
.53152 .64601 m .54235 .64279 L .5452 .64576 L p F P
0 g
s
.65 .758 .928 r
.54235 .64279 m .53152 .64601 L .52865 .64304 L p F P
0 g
s
.65 .758 .928 r
.36447 .64603 m .37502 .64281 L .37813 .64578 L p F P
0 g
s
.65 .758 .928 r
.37502 .64281 m .36447 .64603 L .36134 .64306 L p F P
0 g
s
.65 .758 .928 r
.21106 .64574 m .22136 .64252 L .2247 .6455 L p F P
0 g
s
.65 .758 .928 r
.22136 .64252 m .21106 .64574 L .2077 .64276 L p F P
0 g
s
.65 .758 .928 r
.5452 .64576 m .55606 .64254 L .55889 .64551 L p F P
0 g
s
.65 .758 .928 r
.55606 .64254 m .5452 .64576 L .54235 .64279 L p F P
0 g
s
.65 .758 .928 r
.37813 .64578 m .38871 .64256 L .3918 .64554 L p F P
0 g
s
.65 .758 .928 r
.38871 .64256 m .37813 .64578 L .37502 .64281 L p F P
0 g
s
.65 .758 .928 r
.2247 .6455 m .23503 .64228 L .23835 .64526 L p F P
0 g
s
.65 .758 .928 r
.23503 .64228 m .2247 .6455 L .22136 .64252 L p F P
0 g
s
.65 .758 .928 r
.55889 .64551 m .56977 .64228 L .57258 .64525 L p F P
0 g
s
.65 .758 .928 r
.56977 .64228 m .55889 .64551 L .55606 .64254 L p F P
0 g
s
.65 .758 .928 r
.3918 .64554 m .4024 .64232 L .40546 .64529 L p F P
0 g
s
.65 .758 .928 r
.4024 .64232 m .3918 .64554 L .38871 .64256 L p F P
0 g
s
.65 .758 .928 r
.57258 .64525 m .58349 .64203 L .58627 .645 L p F P
0 g
s
.65 .758 .928 r
.58349 .64203 m .57258 .64525 L .56977 .64228 L p F P
0 g
s
.65 .758 .928 r
.23835 .64526 m .2487 .64204 L .252 .64501 L p F P
0 g
s
.65 .758 .928 r
.2487 .64204 m .23835 .64526 L .23503 .64228 L p F P
0 g
s
.65 .758 .928 r
.40546 .64529 m .4161 .64207 L .41914 .64504 L p F P
0 g
s
.65 .758 .928 r
.4161 .64207 m .40546 .64529 L .4024 .64232 L p F P
0 g
s
.651 .758 .928 r
.58627 .645 m .59721 .64177 L .59997 .64475 L p F P
0 g
s
.651 .758 .928 r
.59721 .64177 m .58627 .645 L .58349 .64203 L p F P
0 g
s
.65 .758 .928 r
.252 .64501 m .26238 .6418 L .26566 .64477 L p F P
0 g
s
.65 .758 .928 r
.26238 .6418 m .252 .64501 L .2487 .64204 L p F P
0 g
s
.65 .758 .928 r
.41914 .64504 m .42979 .64182 L .43281 .64479 L p F P
0 g
s
.65 .758 .928 r
.42979 .64182 m .41914 .64504 L .4161 .64207 L p F P
0 g
s
.651 .758 .928 r
.59997 .64475 m .61093 .64152 L .61367 .64449 L p F P
0 g
s
.651 .758 .928 r
.61093 .64152 m .59997 .64475 L .59721 .64177 L p F P
0 g
s
.65 .758 .928 r
.26566 .64477 m .27606 .64155 L .27932 .64453 L p F P
0 g
s
.65 .758 .928 r
.27606 .64155 m .26566 .64477 L .26238 .6418 L p F P
0 g
s
.65 .758 .928 r
.43281 .64479 m .44349 .64157 L .44649 .64454 L p F P
0 g
s
.65 .758 .928 r
.44349 .64157 m .43281 .64479 L .42979 .64182 L p F P
0 g
s
.65 .757 .928 r
.11215 .64441 m .12229 .64121 L .12579 .64418 L p F P
0 g
s
.65 .757 .928 r
.12229 .64121 m .11215 .64441 L .10863 .64144 L p F P
0 g
s
.651 .758 .928 r
.61367 .64449 m .62465 .64126 L .62738 .64423 L p F P
0 g
s
.651 .758 .928 r
.62465 .64126 m .61367 .64449 L .61093 .64152 L p F P
0 g
s
.65 .758 .928 r
.27932 .64453 m .28974 .64131 L .29298 .64429 L p F P
0 g
s
.65 .758 .928 r
.28974 .64131 m .27932 .64453 L .27606 .64155 L p F P
0 g
s
.65 .758 .928 r
.44649 .64454 m .4572 .64132 L .46018 .6443 L p F P
0 g
s
.65 .758 .928 r
.4572 .64132 m .44649 .64454 L .44349 .64157 L p F P
0 g
s
.65 .757 .928 r
.12579 .64418 m .13596 .64097 L .13943 .64395 L p F P
0 g
s
.65 .757 .928 r
.13596 .64097 m .12579 .64418 L .12229 .64121 L p F P
0 g
s
.651 .758 .928 r
.62738 .64423 m .63838 .641 L .64108 .64397 L p F P
0 g
s
.651 .758 .928 r
.63838 .641 m .62738 .64423 L .62465 .64126 L p F P
0 g
s
.65 .758 .928 r
.29298 .64429 m .30343 .64107 L .30664 .64404 L p F P
0 g
s
.65 .758 .928 r
.30343 .64107 m .29298 .64429 L .28974 .64131 L p F P
0 g
s
.65 .758 .928 r
.46018 .6443 m .47091 .64107 L .47387 .64405 L p F P
0 g
s
.65 .758 .928 r
.47091 .64107 m .46018 .6443 L .4572 .64132 L p F P
0 g
s
0 0 .27 r
.40433 .17006 m .40426 .17024 L .40438 .16574 L p F P
0 g
s
0 0 .27 r
.40438 .16574 m .40446 .16555 L .40433 .17006 L p F P
0 g
s
.764 .494 .526 r
.40399 .17019 m .40426 .17024 L .40438 .16574 L p F P
0 g
s
.764 .494 .526 r
.40438 .16574 m .4041 .16568 L .40399 .17019 L p F P
0 g
s
.65 .757 .928 r
.13943 .64395 m .14962 .64074 L .15308 .64371 L p F P
0 g
s
.65 .757 .928 r
.14962 .64074 m .13943 .64395 L .13596 .64097 L p F P
0 g
s
.651 .758 .928 r
.64108 .64397 m .65212 .64074 L .6548 .64372 L p F P
0 g
s
.651 .758 .928 r
.65212 .64074 m .64108 .64397 L .63838 .641 L p F P
0 g
s
.65 .758 .928 r
.30664 .64404 m .31712 .64082 L .32031 .6438 L p F P
0 g
s
.65 .758 .928 r
.31712 .64082 m .30664 .64404 L .30343 .64107 L p F P
0 g
s
.65 .758 .928 r
.47387 .64405 m .48462 .64082 L .48756 .6438 L p F P
0 g
s
.65 .758 .928 r
.48462 .64082 m .47387 .64405 L .47091 .64107 L p F P
0 g
s
.65 .757 .928 r
.15308 .64371 m .16329 .6405 L .16673 .64348 L p F P
0 g
s
.65 .757 .928 r
.16329 .6405 m .15308 .64371 L .14962 .64074 L p F P
0 g
s
.651 .758 .928 r
.6548 .64372 m .66585 .64048 L .66851 .64346 L p F P
0 g
s
.651 .758 .928 r
.66585 .64048 m .6548 .64372 L .65212 .64074 L p F P
0 g
s
.65 .758 .928 r
.32031 .6438 m .33081 .64057 L .33399 .64355 L p F P
0 g
s
.65 .758 .928 r
.33081 .64057 m .32031 .6438 L .31712 .64082 L p F P
0 g
s
.65 .758 .928 r
.48756 .6438 m .49833 .64057 L .50125 .64355 L p F P
0 g
s
.65 .758 .928 r
.49833 .64057 m .48756 .6438 L .48462 .64082 L p F P
0 g
s
.651 .758 .928 r
.66851 .64346 m .67959 .64022 L .68223 .64319 L p F P
0 g
s
.651 .758 .928 r
.67959 .64022 m .66851 .64346 L .66585 .64048 L p F P
0 g
s
.65 .758 .928 r
.16673 .64348 m .17697 .64026 L .18038 .64324 L p F P
0 g
s
.65 .757 .928 r
.17697 .64026 m .16673 .64348 L .16329 .6405 L p F P
0 g
s
.65 .758 .928 r
.51205 .64032 m .50125 .64355 L .49833 .64057 L p F P
0 g
s
.65 .758 .928 r
.50125 .64355 m .51205 .64032 L .51495 .6433 L p F P
0 g
s
.65 .758 .928 r
.33399 .64355 m .34451 .64033 L .34766 .64331 L p F P
0 g
s
.65 .758 .928 r
.34451 .64033 m .33399 .64355 L .33081 .64057 L p F P
0 g
s
.651 .758 .928 r
.68223 .64319 m .69333 .63996 L .69595 .64293 L p F P
0 g
s
.651 .758 .928 r
.69333 .63996 m .68223 .64319 L .67959 .64022 L p F P
0 g
s
.65 .758 .928 r
.18038 .64324 m .19065 .64002 L .19404 .643 L p F P
0 g
s
.65 .758 .928 r
.19065 .64002 m .18038 .64324 L .17697 .64026 L p F P
0 g
s
.65 .758 .928 r
.51495 .6433 m .52577 .64007 L .52865 .64304 L p F P
0 g
s
.65 .758 .928 r
.52577 .64007 m .51495 .6433 L .51205 .64032 L p F P
0 g
s
.65 .758 .928 r
.34766 .64331 m .35821 .64008 L .36134 .64306 L p F P
0 g
s
.65 .758 .928 r
.35821 .64008 m .34766 .64331 L .34451 .64033 L p F P
0 g
s
.651 .758 .928 r
.69595 .64293 m .70708 .63969 L .70968 .64266 L p F P
0 g
s
.651 .758 .928 r
.70708 .63969 m .69595 .64293 L .69333 .63996 L p F P
0 g
s
.65 .758 .928 r
.20433 .63978 m .19404 .643 L .19065 .64002 L p F P
0 g
s
.65 .758 .928 r
.19404 .643 m .20433 .63978 L .2077 .64276 L p F P
0 g
s
.65 .758 .928 r
.5395 .63981 m .52865 .64304 L .52577 .64007 L p F P
0 g
s
.65 .758 .928 r
.52865 .64304 m .5395 .63981 L .54235 .64279 L p F P
0 g
s
.65 .758 .928 r
.36134 .64306 m .37191 .63983 L .37502 .64281 L p F P
0 g
s
.65 .758 .928 r
.37191 .63983 m .36134 .64306 L .35821 .64008 L p F P
0 g
s
.651 .758 .928 r
.72083 .63942 m .70968 .64266 L .70708 .63969 L p F P
0 g
s
.65 .758 .928 r
.2077 .64276 m .21801 .63954 L .22136 .64252 L p F P
0 g
s
.65 .758 .928 r
.21801 .63954 m .2077 .64276 L .20433 .63978 L p F P
0 g
s
.65 .758 .928 r
.54235 .64279 m .55323 .63956 L .55606 .64254 L p F P
0 g
s
.65 .758 .928 r
.55323 .63956 m .54235 .64279 L .5395 .63981 L p F P
0 g
s
.65 .758 .928 r
.37502 .64281 m .38562 .63958 L .38871 .64256 L p F P
0 g
s
.65 .758 .928 r
.38562 .63958 m .37502 .64281 L .37191 .63983 L p F P
0 g
s
.65 .758 .928 r
.22136 .64252 m .2317 .6393 L .23503 .64228 L p F P
0 g
s
.65 .758 .928 r
.2317 .6393 m .22136 .64252 L .21801 .63954 L p F P
0 g
s
.65 .758 .928 r
.55606 .64254 m .56696 .63931 L .56977 .64228 L p F P
0 g
s
.65 .758 .928 r
.56696 .63931 m .55606 .64254 L .55323 .63956 L p F P
0 g
s
.65 .758 .928 r
.38871 .64256 m .39933 .63934 L .4024 .64232 L p F P
0 g
s
.65 .758 .928 r
.39933 .63934 m .38871 .64256 L .38562 .63958 L p F P
0 g
s
.65 .758 .928 r
.23503 .64228 m .24539 .63906 L .2487 .64204 L p F P
0 g
s
.65 .758 .928 r
.24539 .63906 m .23503 .64228 L .2317 .6393 L p F P
0 g
s
.65 .758 .928 r
.56977 .64228 m .5807 .63905 L .58349 .64203 L p F P
0 g
s
.65 .758 .928 r
.5807 .63905 m .56977 .64228 L .56696 .63931 L p F P
0 g
s
.65 .758 .928 r
.4024 .64232 m .41304 .63909 L .4161 .64207 L p F P
0 g
s
.65 .758 .928 r
.41304 .63909 m .4024 .64232 L .39933 .63934 L p F P
0 g
s
.651 .758 .928 r
.58349 .64203 m .59444 .6388 L .59721 .64177 L p F P
0 g
s
.651 .758 .928 r
.59444 .6388 m .58349 .64203 L .5807 .63905 L p F P
0 g
s
.65 .758 .928 r
.2487 .64204 m .25909 .63882 L .26238 .6418 L p F P
0 g
s
.65 .758 .928 r
.25909 .63882 m .2487 .64204 L .24539 .63906 L p F P
0 g
s
.65 .758 .928 r
.4161 .64207 m .42676 .63884 L .42979 .64182 L p F P
0 g
s
.65 .758 .928 r
.42676 .63884 m .4161 .64207 L .41304 .63909 L p F P
0 g
s
.651 .758 .928 r
.59721 .64177 m .60818 .63854 L .61093 .64152 L p F P
0 g
s
.651 .758 .928 r
.60818 .63854 m .59721 .64177 L .59444 .6388 L p F P
0 g
s
.65 .758 .928 r
.26238 .6418 m .27279 .63857 L .27606 .64155 L p F P
0 g
s
.65 .758 .928 r
.27279 .63857 m .26238 .6418 L .25909 .63882 L p F P
0 g
s
.65 .758 .928 r
.42979 .64182 m .44048 .63859 L .44349 .64157 L p F P
0 g
s
.65 .758 .928 r
.44048 .63859 m .42979 .64182 L .42676 .63884 L p F P
0 g
s
.65 .757 .928 r
.10863 .64144 m .11879 .63822 L .12229 .64121 L p F P
0 g
s
.65 .757 .928 r
.11879 .63822 m .10863 .64144 L .10511 .63845 L p F P
0 g
s
0 0 .27 r
.4042 .17459 m .40413 .17476 L .40426 .17024 L p F P
0 g
s
0 0 .27 r
.40426 .17024 m .40433 .17006 L .4042 .17459 L p F P
0 g
s
.764 .494 .526 r
.40388 .17471 m .40413 .17476 L .40426 .17024 L p F P
0 g
s
.764 .494 .526 r
.40426 .17024 m .40399 .17019 L .40388 .17471 L p F P
0 g
s
.651 .758 .928 r
.61093 .64152 m .62192 .63828 L .62465 .64126 L p F P
0 g
s
.651 .758 .928 r
.62192 .63828 m .61093 .64152 L .60818 .63854 L p F P
0 g
s
.65 .758 .928 r
.27606 .64155 m .28649 .63833 L .28974 .64131 L p F P
0 g
s
.65 .758 .928 r
.28649 .63833 m .27606 .64155 L .27279 .63857 L p F P
0 g
s
.65 .758 .928 r
.44349 .64157 m .45421 .63834 L .4572 .64132 L p F P
0 g
s
.65 .758 .928 r
.45421 .63834 m .44349 .64157 L .44048 .63859 L p F P
0 g
s
.65 .757 .928 r
.12229 .64121 m .13247 .63799 L .13596 .64097 L p F P
0 g
s
.65 .757 .928 r
.13247 .63799 m .12229 .64121 L .11879 .63822 L p F P
0 g
s
.651 .758 .928 r
.62465 .64126 m .63567 .63802 L .63838 .641 L p F P
0 g
s
.651 .758 .928 r
.63567 .63802 m .62465 .64126 L .62192 .63828 L p F P
0 g
s
.65 .758 .928 r
.28974 .64131 m .3002 .63808 L .30343 .64107 L p F P
0 g
s
.65 .758 .928 r
.3002 .63808 m .28974 .64131 L .28649 .63833 L p F P
0 g
s
.65 .758 .928 r
.4572 .64132 m .46794 .63809 L .47091 .64107 L p F P
0 g
s
.65 .758 .928 r
.46794 .63809 m .4572 .64132 L .45421 .63834 L p F P
0 g
s
.65 .757 .928 r
.13596 .64097 m .14616 .63775 L .14962 .64074 L p F P
0 g
s
.65 .757 .928 r
.14616 .63775 m .13596 .64097 L .13247 .63799 L p F P
0 g
s
.651 .758 .928 r
.63838 .641 m .64943 .63776 L .65212 .64074 L p F P
0 g
s
.651 .758 .928 r
.64943 .63776 m .63838 .641 L .63567 .63802 L p F P
0 g
s
.65 .758 .928 r
.30343 .64107 m .31391 .63783 L .31712 .64082 L p F P
0 g
s
.65 .758 .928 r
.31391 .63783 m .30343 .64107 L .3002 .63808 L p F P
0 g
s
.65 .758 .928 r
.47091 .64107 m .48167 .63784 L .48462 .64082 L p F P
0 g
s
.65 .758 .928 r
.48167 .63784 m .47091 .64107 L .46794 .63809 L p F P
0 g
s
.65 .757 .928 r
.14962 .64074 m .15985 .63751 L .16329 .6405 L p F P
0 g
s
.65 .757 .928 r
.15985 .63751 m .14962 .64074 L .14616 .63775 L p F P
0 g
s
.651 .758 .928 r
.65212 .64074 m .66318 .6375 L .66585 .64048 L p F P
0 g
s
.651 .758 .928 r
.66318 .6375 m .65212 .64074 L .64943 .63776 L p F P
0 g
s
.65 .758 .928 r
.31712 .64082 m .32762 .63759 L .33081 .64057 L p F P
0 g
s
.65 .758 .928 r
.32762 .63759 m .31712 .64082 L .31391 .63783 L p F P
0 g
s
.65 .758 .928 r
.48462 .64082 m .49541 .63758 L .49833 .64057 L p F P
0 g
s
.65 .758 .928 r
.49541 .63758 m .48462 .64082 L .48167 .63784 L p F P
0 g
s
.651 .758 .928 r
.66585 .64048 m .67694 .63724 L .67959 .64022 L p F P
0 g
s
.651 .758 .928 r
.67694 .63724 m .66585 .64048 L .66318 .6375 L p F P
0 g
s
.65 .757 .928 r
.16329 .6405 m .17354 .63728 L .17697 .64026 L p F P
0 g
s
.65 .757 .928 r
.17354 .63728 m .16329 .6405 L .15985 .63751 L p F P
0 g
s
.65 .758 .928 r
.49833 .64057 m .50915 .63733 L .51205 .64032 L p F P
0 g
s
.65 .758 .928 r
.50915 .63733 m .49833 .64057 L .49541 .63758 L p F P
0 g
s
.65 .758 .928 r
.33081 .64057 m .34134 .63734 L .34451 .64033 L p F P
0 g
s
.65 .758 .928 r
.34134 .63734 m .33081 .64057 L .32762 .63759 L p F P
0 g
s
.651 .758 .928 r
.67959 .64022 m .69071 .63698 L .69333 .63996 L p F P
0 g
s
.651 .758 .928 r
.69071 .63698 m .67959 .64022 L .67694 .63724 L p F P
0 g
s
.65 .758 .928 r
.17697 .64026 m .18724 .63704 L .19065 .64002 L p F P
0 g
s
.65 .757 .928 r
.18724 .63704 m .17697 .64026 L .17354 .63728 L p F P
0 g
s
.65 .758 .928 r
.52289 .63708 m .51205 .64032 L .50915 .63733 L p F P
0 g
s
.65 .758 .928 r
.51205 .64032 m .52289 .63708 L .52577 .64007 L p F P
0 g
s
.65 .758 .928 r
.34451 .64033 m .35506 .63709 L .35821 .64008 L p F P
0 g
s
.65 .758 .928 r
.35506 .63709 m .34451 .64033 L .34134 .63734 L p F P
0 g
s
.651 .758 .928 r
.69333 .63996 m .70447 .63671 L .70708 .63969 L p F P
0 g
s
.651 .758 .928 r
.70447 .63671 m .69333 .63996 L .69071 .63698 L p F P
0 g
s
.65 .758 .928 r
.19065 .64002 m .20095 .6368 L .20433 .63978 L p F P
0 g
s
.65 .758 .928 r
.20095 .6368 m .19065 .64002 L .18724 .63704 L p F P
0 g
s
.65 .758 .928 r
.52577 .64007 m .53663 .63683 L .5395 .63981 L p F P
0 g
s
.65 .758 .928 r
.53663 .63683 m .52577 .64007 L .52289 .63708 L p F P
0 g
s
.65 .758 .928 r
.35821 .64008 m .36879 .63684 L .37191 .63983 L p F P
0 g
s
.65 .758 .928 r
.36879 .63684 m .35821 .64008 L .35506 .63709 L p F P
0 g
s
.651 .758 .928 r
.70708 .63969 m .71824 .63644 L .72083 .63942 L p F P
0 g
s
.651 .758 .928 r
.71824 .63644 m .70708 .63969 L .70447 .63671 L p F P
0 g
s
.65 .758 .928 r
.21465 .63655 m .20433 .63978 L .20095 .6368 L p F P
0 g
s
.65 .758 .928 r
.20433 .63978 m .21465 .63655 L .21801 .63954 L p F P
0 g
s
.65 .758 .928 r
.55038 .63657 m .5395 .63981 L .53663 .63683 L p F P
0 g
s
.65 .758 .928 r
.5395 .63981 m .55038 .63657 L .55323 .63956 L p F P
0 g
s
.65 .758 .928 r
.37191 .63983 m .38252 .6366 L .38562 .63958 L p F P
0 g
s
.65 .758 .928 r
.38252 .6366 m .37191 .63983 L .36879 .63684 L p F P
0 g
s
.651 .758 .928 r
.73202 .63617 m .72083 .63942 L .71824 .63644 L p F P
0 g
s
.65 .758 .928 r
.21801 .63954 m .22836 .63631 L .2317 .6393 L p F P
0 g
s
.65 .758 .928 r
.22836 .63631 m .21801 .63954 L .21465 .63655 L p F P
0 g
s
.65 .758 .928 r
.55323 .63956 m .56414 .63632 L .56696 .63931 L p F P
0 g
s
.65 .758 .928 r
.56414 .63632 m .55323 .63956 L .55038 .63657 L p F P
0 g
s
.65 .758 .928 r
.38562 .63958 m .39625 .63635 L .39933 .63934 L p F P
0 g
s
.65 .758 .928 r
.39625 .63635 m .38562 .63958 L .38252 .6366 L p F P
0 g
s
.65 .758 .928 r
.2317 .6393 m .24207 .63607 L .24539 .63906 L p F P
0 g
s
.65 .758 .928 r
.24207 .63607 m .2317 .6393 L .22836 .63631 L p F P
0 g
s
.65 .758 .928 r
.56696 .63931 m .57789 .63606 L .5807 .63905 L p F P
0 g
s
.65 .758 .928 r
.57789 .63606 m .56696 .63931 L .56414 .63632 L p F P
0 g
s
.65 .758 .928 r
.39933 .63934 m .40998 .6361 L .41304 .63909 L p F P
0 g
s
.65 .758 .928 r
.40998 .6361 m .39933 .63934 L .39625 .63635 L p F P
0 g
s
0 0 .271 r
.40407 .17912 m .40401 .17928 L .40413 .17476 L p F P
0 g
s
0 0 .271 r
.40413 .17476 m .4042 .17459 L .40407 .17912 L p F P
0 g
s
.764 .494 .526 r
.40377 .17924 m .40401 .17928 L .40413 .17476 L p F P
0 g
s
.764 .494 .526 r
.40413 .17476 m .40388 .17471 L .40377 .17924 L p F P
0 g
s
.651 .758 .928 r
.5807 .63905 m .59165 .63581 L .59444 .6388 L p F P
0 g
s
.651 .758 .928 r
.59165 .63581 m .5807 .63905 L .57789 .63606 L p F P
0 g
s
.65 .758 .928 r
.24539 .63906 m .25579 .63582 L .25909 .63882 L p F P
0 g
s
.65 .758 .928 r
.25579 .63582 m .24539 .63906 L .24207 .63607 L p F P
0 g
s
.65 .758 .928 r
.41304 .63909 m .42372 .63585 L .42676 .63884 L p F P
0 g
s
.65 .758 .928 r
.42372 .63585 m .41304 .63909 L .40998 .6361 L p F P
0 g
s
.651 .758 .928 r
.59444 .6388 m .60542 .63555 L .60818 .63854 L p F P
0 g
s
.651 .758 .928 r
.60542 .63555 m .59444 .6388 L .59165 .63581 L p F P
0 g
s
.65 .758 .928 r
.25909 .63882 m .26951 .63558 L .27279 .63857 L p F P
0 g
s
.65 .758 .928 r
.26951 .63558 m .25909 .63882 L .25579 .63582 L p F P
0 g
s
.65 .758 .928 r
.42676 .63884 m .43746 .6356 L .44048 .63859 L p F P
0 g
s
.65 .758 .928 r
.43746 .6356 m .42676 .63884 L .42372 .63585 L p F P
0 g
s
.65 .757 .928 r
.10511 .63845 m .11527 .63523 L .11879 .63822 L p F P
0 g
s
.65 .757 .928 r
.11527 .63523 m .10511 .63845 L .10157 .63546 L p F P
0 g
s
.651 .758 .928 r
.60818 .63854 m .61919 .63529 L .62192 .63828 L p F P
0 g
s
.651 .758 .928 r
.61919 .63529 m .60818 .63854 L .60542 .63555 L p F P
0 g
s
.65 .758 .928 r
.27279 .63857 m .28324 .63533 L .28649 .63833 L p F P
0 g
s
.65 .758 .928 r
.28324 .63533 m .27279 .63857 L .26951 .63558 L p F P
0 g
s
.65 .758 .928 r
.44048 .63859 m .45121 .63535 L .45421 .63834 L p F P
0 g
s
.65 .758 .928 r
.45121 .63535 m .44048 .63859 L .43746 .6356 L p F P
0 g
s
.65 .757 .928 r
.11879 .63822 m .12897 .63499 L .13247 .63799 L p F P
0 g
s
.65 .757 .928 r
.12897 .63499 m .11879 .63822 L .11527 .63523 L p F P
0 g
s
.651 .758 .928 r
.62192 .63828 m .63296 .63503 L .63567 .63802 L p F P
0 g
s
.651 .758 .928 r
.63296 .63503 m .62192 .63828 L .61919 .63529 L p F P
0 g
s
.65 .758 .928 r
.28649 .63833 m .29696 .63509 L .3002 .63808 L p F P
0 g
s
.65 .758 .928 r
.29696 .63509 m .28649 .63833 L .28324 .63533 L p F P
0 g
s
.65 .758 .928 r
.45421 .63834 m .46496 .63509 L .46794 .63809 L p F P
0 g
s
.65 .758 .928 r
.46496 .63509 m .45421 .63834 L .45121 .63535 L p F P
0 g
s
.65 .757 .928 r
.13247 .63799 m .14268 .63476 L .14616 .63775 L p F P
0 g
s
.65 .757 .928 r
.14268 .63476 m .13247 .63799 L .12897 .63499 L p F P
0 g
s
.651 .758 .928 r
.63567 .63802 m .64673 .63477 L .64943 .63776 L p F P
0 g
s
.651 .758 .928 r
.64673 .63477 m .63567 .63802 L .63296 .63503 L p F P
0 g
s
.65 .758 .928 r
.3002 .63808 m .31069 .63484 L .31391 .63783 L p F P
0 g
s
.65 .758 .928 r
.31069 .63484 m .3002 .63808 L .29696 .63509 L p F P
0 g
s
.65 .758 .928 r
.46794 .63809 m .47871 .63484 L .48167 .63784 L p F P
0 g
s
.65 .758 .928 r
.47871 .63484 m .46794 .63809 L .46496 .63509 L p F P
0 g
s
.65 .757 .928 r
.14616 .63775 m .15639 .63452 L .15985 .63751 L p F P
0 g
s
.65 .757 .928 r
.15639 .63452 m .14616 .63775 L .14268 .63476 L p F P
0 g
s
.651 .758 .928 r
.64943 .63776 m .66051 .63451 L .66318 .6375 L p F P
0 g
s
.651 .758 .928 r
.66051 .63451 m .64943 .63776 L .64673 .63477 L p F P
0 g
s
.65 .758 .928 r
.31391 .63783 m .32443 .63459 L .32762 .63759 L p F P
0 g
s
.65 .758 .928 r
.32443 .63459 m .31391 .63783 L .31069 .63484 L p F P
0 g
s
.65 .758 .928 r
.48167 .63784 m .49247 .63459 L .49541 .63758 L p F P
0 g
s
.65 .758 .928 r
.49247 .63459 m .48167 .63784 L .47871 .63484 L p F P
0 g
s
.651 .758 .928 r
.66318 .6375 m .67429 .63425 L .67694 .63724 L p F P
0 g
s
.651 .758 .928 r
.67429 .63425 m .66318 .6375 L .66051 .63451 L p F P
0 g
s
.65 .757 .928 r
.15985 .63751 m .17011 .63428 L .17354 .63728 L p F P
0 g
s
.65 .757 .928 r
.17011 .63428 m .15985 .63751 L .15639 .63452 L p F P
0 g
s
.65 .758 .928 r
.49541 .63758 m .50623 .63434 L .50915 .63733 L p F P
0 g
s
.65 .758 .928 r
.50623 .63434 m .49541 .63758 L .49247 .63459 L p F P
0 g
s
.65 .758 .928 r
.32762 .63759 m .33817 .63434 L .34134 .63734 L p F P
0 g
s
.65 .758 .928 r
.33817 .63434 m .32762 .63759 L .32443 .63459 L p F P
0 g
s
.651 .758 .928 r
.67694 .63724 m .68807 .63398 L .69071 .63698 L p F P
0 g
s
.651 .758 .928 r
.68807 .63398 m .67694 .63724 L .67429 .63425 L p F P
0 g
s
.65 .757 .928 r
.17354 .63728 m .18383 .63404 L .18724 .63704 L p F P
0 g
s
.65 .757 .928 r
.18383 .63404 m .17354 .63728 L .17011 .63428 L p F P
0 g
s
.65 .758 .928 r
.50915 .63733 m .51999 .63408 L .52289 .63708 L p F P
0 g
s
.65 .758 .928 r
.51999 .63408 m .50915 .63733 L .50623 .63434 L p F P
0 g
s
.65 .758 .928 r
.34134 .63734 m .35191 .63409 L .35506 .63709 L p F P
0 g
s
.65 .758 .928 r
.35191 .63409 m .34134 .63734 L .33817 .63434 L p F P
0 g
s
.651 .758 .928 r
.69071 .63698 m .70186 .63372 L .70447 .63671 L p F P
0 g
s
.651 .758 .928 r
.70186 .63372 m .69071 .63698 L .68807 .63398 L p F P
0 g
s
.65 .758 .928 r
.18724 .63704 m .19755 .6338 L .20095 .6368 L p F P
0 g
s
.65 .757 .928 r
.19755 .6338 m .18724 .63704 L .18383 .63404 L p F P
0 g
s
.65 .758 .928 r
.53376 .63383 m .52289 .63708 L .51999 .63408 L p F P
0 g
s
.65 .758 .928 r
.52289 .63708 m .53376 .63383 L .53663 .63683 L p F P
0 g
s
.65 .758 .928 r
.35506 .63709 m .36566 .63385 L .36879 .63684 L p F P
0 g
s
.65 .758 .928 r
.36566 .63385 m .35506 .63709 L .35191 .63409 L p F P
0 g
s
.651 .758 .928 r
.70447 .63671 m .71565 .63345 L .71824 .63644 L p F P
0 g
s
.651 .758 .928 r
.71565 .63345 m .70447 .63671 L .70186 .63372 L p F P
0 g
s
.65 .758 .928 r
.20095 .6368 m .21128 .63355 L .21465 .63655 L p F P
0 g
s
.65 .758 .928 r
.21128 .63355 m .20095 .6368 L .19755 .6338 L p F P
0 g
s
.65 .758 .928 r
.53663 .63683 m .54753 .63357 L .55038 .63657 L p F P
0 g
s
.65 .758 .928 r
.54753 .63357 m .53663 .63683 L .53376 .63383 L p F P
0 g
s
.65 .758 .928 r
.36879 .63684 m .3794 .6336 L .38252 .6366 L p F P
0 g
s
.65 .758 .928 r
.3794 .6336 m .36879 .63684 L .36566 .63385 L p F P
0 g
s
.651 .758 .928 r
.71824 .63644 m .72945 .63318 L .73202 .63617 L p F P
0 g
s
.651 .758 .928 r
.72945 .63318 m .71824 .63644 L .71565 .63345 L p F P
0 g
s
0 0 .271 r
.40395 .18367 m .40388 .18382 L .40401 .17928 L p F P
0 g
s
0 0 .271 r
.40401 .17928 m .40407 .17912 L .40395 .18367 L p F P
0 g
s
.764 .494 .526 r
.40365 .18378 m .40388 .18382 L .40401 .17928 L p F P
0 g
s
.764 .494 .526 r
.40401 .17928 m .40377 .17924 L .40365 .18378 L p F P
0 g
s
.65 .758 .928 r
.21465 .63655 m .22501 .63331 L .22836 .63631 L p F P
0 g
s
.65 .758 .928 r
.22501 .63331 m .21465 .63655 L .21128 .63355 L p F P
0 g
s
.65 .758 .928 r
.56131 .63332 m .55038 .63657 L .54753 .63357 L p F P
0 g
s
.65 .758 .928 r
.55038 .63657 m .56131 .63332 L .56414 .63632 L p F P
0 g
s
.65 .758 .928 r
.38252 .6366 m .39316 .63335 L .39625 .63635 L p F P
0 g
s
.65 .758 .928 r
.39316 .63335 m .38252 .6366 L .3794 .6336 L p F P
0 g
s
.651 .758 .928 r
.74324 .63291 m .73202 .63617 L .72945 .63318 L p F P
0 g
s
.65 .758 .928 r
.22836 .63631 m .23874 .63307 L .24207 .63607 L p F P
0 g
s
.65 .758 .928 r
.23874 .63307 m .22836 .63631 L .22501 .63331 L p F P
0 g
s
.65 .758 .928 r
.56414 .63632 m .57508 .63306 L .57789 .63606 L p F P
0 g
s
.65 .758 .928 r
.57508 .63306 m .56414 .63632 L .56131 .63332 L p F P
0 g
s
.65 .758 .928 r
.39625 .63635 m .40691 .6331 L .40998 .6361 L p F P
0 g
s
.65 .758 .928 r
.40691 .6331 m .39625 .63635 L .39316 .63335 L p F P
0 g
s
.651 .758 .928 r
.57789 .63606 m .58887 .63281 L .59165 .63581 L p F P
0 g
s
.651 .758 .928 r
.58887 .63281 m .57789 .63606 L .57508 .63306 L p F P
0 g
s
.65 .758 .928 r
.24207 .63607 m .25248 .63282 L .25579 .63582 L p F P
0 g
s
.65 .758 .928 r
.25248 .63282 m .24207 .63607 L .23874 .63307 L p F P
0 g
s
.65 .758 .928 r
.40998 .6361 m .42067 .63285 L .42372 .63585 L p F P
0 g
s
.65 .758 .928 r
.42067 .63285 m .40998 .6361 L .40691 .6331 L p F P
0 g
s
.651 .758 .928 r
.59165 .63581 m .60265 .63255 L .60542 .63555 L p F P
0 g
s
.651 .758 .928 r
.60265 .63255 m .59165 .63581 L .58887 .63281 L p F P
0 g
s
.65 .758 .928 r
.25579 .63582 m .26622 .63258 L .26951 .63558 L p F P
0 g
s
.65 .758 .928 r
.26622 .63258 m .25579 .63582 L .25248 .63282 L p F P
0 g
s
.65 .758 .928 r
.42372 .63585 m .43444 .63259 L .43746 .6356 L p F P
0 g
s
.65 .758 .928 r
.43444 .63259 m .42372 .63585 L .42067 .63285 L p F P
0 g
s
.65 .757 .928 r
.10157 .63546 m .11174 .63222 L .11527 .63523 L p F P
0 g
s
.65 .757 .928 r
.11174 .63222 m .10157 .63546 L .09802 .63246 L p F P
0 g
s
.651 .758 .928 r
.60542 .63555 m .61644 .63229 L .61919 .63529 L p F P
0 g
s
.651 .758 .928 r
.61644 .63229 m .60542 .63555 L .60265 .63255 L p F P
0 g
s
.65 .758 .928 r
.26951 .63558 m .27997 .63233 L .28324 .63533 L p F P
0 g
s
.65 .758 .928 r
.27997 .63233 m .26951 .63558 L .26622 .63258 L p F P
0 g
s
.65 .758 .928 r
.43746 .6356 m .4482 .63234 L .45121 .63535 L p F P
0 g
s
.65 .758 .928 r
.4482 .63234 m .43746 .6356 L .43444 .63259 L p F P
0 g
s
.65 .757 .928 r
.11527 .63523 m .12547 .63199 L .12897 .63499 L p F P
0 g
s
.65 .757 .928 r
.12547 .63199 m .11527 .63523 L .11174 .63222 L p F P
0 g
s
.651 .758 .928 r
.61919 .63529 m .63023 .63203 L .63296 .63503 L p F P
0 g
s
.651 .758 .928 r
.63023 .63203 m .61919 .63529 L .61644 .63229 L p F P
0 g
s
.65 .758 .928 r
.28324 .63533 m .29372 .63208 L .29696 .63509 L p F P
0 g
s
.65 .758 .928 r
.29372 .63208 m .28324 .63533 L .27997 .63233 L p F P
0 g
s
.65 .758 .928 r
.45121 .63535 m .46197 .63209 L .46496 .63509 L p F P
0 g
s
.65 .758 .928 r
.46197 .63209 m .45121 .63535 L .4482 .63234 L p F P
0 g
s
.65 .757 .928 r
.12897 .63499 m .1392 .63175 L .14268 .63476 L p F P
0 g
s
.65 .757 .928 r
.1392 .63175 m .12897 .63499 L .12547 .63199 L p F P
0 g
s
.651 .758 .928 r
.63296 .63503 m .64403 .63177 L .64673 .63477 L p F P
0 g
s
.651 .758 .928 r
.64403 .63177 m .63296 .63503 L .63023 .63203 L p F P
0 g
s
.65 .758 .928 r
.29696 .63509 m .30747 .63183 L .31069 .63484 L p F P
0 g
s
.65 .758 .928 r
.30747 .63183 m .29696 .63509 L .29372 .63208 L p F P
0 g
s
.65 .758 .928 r
.46496 .63509 m .47575 .63184 L .47871 .63484 L p F P
0 g
s
.65 .758 .928 r
.47575 .63184 m .46496 .63509 L .46197 .63209 L p F P
0 g
s
.65 .757 .928 r
.14268 .63476 m .15293 .63151 L .15639 .63452 L p F P
0 g
s
.65 .757 .928 r
.15293 .63151 m .14268 .63476 L .1392 .63175 L p F P
0 g
s
.651 .758 .928 r
.64673 .63477 m .65782 .63151 L .66051 .63451 L p F P
0 g
s
.651 .758 .928 r
.65782 .63151 m .64673 .63477 L .64403 .63177 L p F P
0 g
s
.65 .758 .928 r
.31069 .63484 m .32122 .63159 L .32443 .63459 L p F P
0 g
s
.65 .758 .928 r
.32122 .63159 m .31069 .63484 L .30747 .63183 L p F P
0 g
s
.65 .758 .928 r
.47871 .63484 m .48953 .63159 L .49247 .63459 L p F P
0 g
s
.65 .758 .928 r
.48953 .63159 m .47871 .63484 L .47575 .63184 L p F P
0 g
s
.651 .758 .928 r
.66051 .63451 m .67163 .63125 L .67429 .63425 L p F P
0 g
s
.651 .758 .928 r
.67163 .63125 m .66051 .63451 L .65782 .63151 L p F P
0 g
s
.65 .757 .928 r
.15639 .63452 m .16667 .63127 L .17011 .63428 L p F P
0 g
s
.65 .757 .928 r
.16667 .63127 m .15639 .63452 L .15293 .63151 L p F P
0 g
s
.65 .758 .928 r
.49247 .63459 m .50331 .63133 L .50623 .63434 L p F P
0 g
s
.65 .758 .928 r
.50331 .63133 m .49247 .63459 L .48953 .63159 L p F P
0 g
s
.65 .758 .928 r
.32443 .63459 m .33498 .63134 L .33817 .63434 L p F P
0 g
s
.65 .758 .928 r
.33498 .63134 m .32443 .63459 L .32122 .63159 L p F P
0 g
s
.651 .758 .928 r
.67429 .63425 m .68543 .63098 L .68807 .63398 L p F P
0 g
s
.651 .758 .928 r
.68543 .63098 m .67429 .63425 L .67163 .63125 L p F P
0 g
s
.65 .757 .928 r
.17011 .63428 m .18041 .63103 L .18383 .63404 L p F P
0 g
s
.65 .757 .928 r
.18041 .63103 m .17011 .63428 L .16667 .63127 L p F P
0 g
s
.65 .758 .928 r
.50623 .63434 m .51709 .63108 L .51999 .63408 L p F P
0 g
s
.65 .758 .928 r
.51709 .63108 m .50623 .63434 L .50331 .63133 L p F P
0 g
s
.65 .758 .928 r
.33817 .63434 m .34875 .63109 L .35191 .63409 L p F P
0 g
s
.65 .758 .928 r
.34875 .63109 m .33817 .63434 L .33498 .63134 L p F P
0 g
s
.651 .758 .928 r
.68807 .63398 m .69924 .63072 L .70186 .63372 L p F P
0 g
s
.651 .758 .928 r
.69924 .63072 m .68807 .63398 L .68543 .63098 L p F P
0 g
s
0 0 .271 r
.40382 .18823 m .40376 .18837 L .40388 .18382 L p F P
0 g
s
0 0 .271 r
.40388 .18382 m .40395 .18367 L .40382 .18823 L p F P
0 g
s
.764 .494 .526 r
.40354 .18833 m .40376 .18837 L .40388 .18382 L p F P
0 g
s
.764 .494 .526 r
.40388 .18382 m .40365 .18378 L .40354 .18833 L p F P
0 g
s
.65 .757 .928 r
.18383 .63404 m .19415 .63079 L .19755 .6338 L p F P
0 g
s
.65 .757 .928 r
.19415 .63079 m .18383 .63404 L .18041 .63103 L p F P
0 g
s
.65 .758 .928 r
.51999 .63408 m .53088 .63082 L .53376 .63383 L p F P
0 g
s
.65 .758 .928 r
.53088 .63082 m .51999 .63408 L .51709 .63108 L p F P
0 g
s
.65 .758 .928 r
.35191 .63409 m .36251 .63084 L .36566 .63385 L p F P
0 g
s
.65 .758 .928 r
.36251 .63084 m .35191 .63409 L .34875 .63109 L p F P
0 g
s
.651 .758 .928 r
.70186 .63372 m .71305 .63045 L .71565 .63345 L p F P
0 g
s
.651 .758 .928 r
.71305 .63045 m .70186 .63372 L .69924 .63072 L p F P
0 g
s
.65 .758 .928 r
.19755 .6338 m .2079 .63055 L .21128 .63355 L p F P
0 g
s
.65 .758 .928 r
.2079 .63055 m .19755 .6338 L .19415 .63079 L p F P
0 g
s
.65 .758 .928 r
.54467 .63057 m .53376 .63383 L .53088 .63082 L p F P
0 g
s
.65 .758 .928 r
.53376 .63383 m .54467 .63057 L .54753 .63357 L p F P
0 g
s
.65 .758 .928 r
.36566 .63385 m .37628 .63059 L .3794 .6336 L p F P
0 g
s
.65 .758 .928 r
.37628 .63059 m .36566 .63385 L .36251 .63084 L p F P
0 g
s
.651 .758 .928 r
.71565 .63345 m .72687 .63018 L .72945 .63318 L p F P
0 g
s
.651 .758 .928 r
.72687 .63018 m .71565 .63345 L .71305 .63045 L p F P
0 g
s
.65 .758 .928 r
.21128 .63355 m .22165 .6303 L .22501 .63331 L p F P
0 g
s
.65 .758 .928 r
.22165 .6303 m .21128 .63355 L .2079 .63055 L p F P
0 g
s
.65 .758 .928 r
.54753 .63357 m .55847 .63031 L .56131 .63332 L p F P
0 g
s
.65 .758 .928 r
.55847 .63031 m .54753 .63357 L .54467 .63057 L p F P
0 g
s
.65 .758 .928 r
.3794 .6336 m .39006 .63034 L .39316 .63335 L p F P
0 g
s
.65 .758 .928 r
.39006 .63034 m .3794 .6336 L .37628 .63059 L p F P
0 g
s
.651 .758 .928 r
.72945 .63318 m .74069 .62991 L .74324 .63291 L p F P
0 g
s
.651 .758 .928 r
.74069 .62991 m .72945 .63318 L .72687 .63018 L p F P
0 g
s
.65 .758 .928 r
.22501 .63331 m .2354 .63006 L .23874 .63307 L p F P
0 g
s
.65 .758 .928 r
.2354 .63006 m .22501 .63331 L .22165 .6303 L p F P
0 g
s
.65 .758 .928 r
.57227 .63006 m .56131 .63332 L .55847 .63031 L p F P
0 g
s
.65 .758 .928 r
.56131 .63332 m .57227 .63006 L .57508 .63306 L p F P
0 g
s
.65 .758 .928 r
.39316 .63335 m .40383 .63009 L .40691 .6331 L p F P
0 g
s
.65 .758 .928 r
.40383 .63009 m .39316 .63335 L .39006 .63034 L p F P
0 g
s
.651 .758 .928 r
.75451 .62964 m .74324 .63291 L .74069 .62991 L p F P
0 g
s
.651 .758 .928 r
.57508 .63306 m .58607 .6298 L .58887 .63281 L p F P
0 g
s
.651 .758 .928 r
.58607 .6298 m .57508 .63306 L .57227 .63006 L p F P
0 g
s
.65 .758 .928 r
.23874 .63307 m .24916 .62981 L .25248 .63282 L p F P
0 g
s
.65 .758 .928 r
.24916 .62981 m .23874 .63307 L .2354 .63006 L p F P
0 g
s
.65 .758 .928 r
.40691 .6331 m .41761 .62983 L .42067 .63285 L p F P
0 g
s
.65 .758 .928 r
.41761 .62983 m .40691 .6331 L .40383 .63009 L p F P
0 g
s
.651 .758 .928 r
.58887 .63281 m .59987 .62954 L .60265 .63255 L p F P
0 g
s
.651 .758 .928 r
.59987 .62954 m .58887 .63281 L .58607 .6298 L p F P
0 g
s
.65 .758 .928 r
.25248 .63282 m .26292 .62956 L .26622 .63258 L p F P
0 g
s
.65 .758 .928 r
.26292 .62956 m .25248 .63282 L .24916 .62981 L p F P
0 g
s
.65 .758 .928 r
.42067 .63285 m .4314 .62958 L .43444 .63259 L p F P
0 g
s
.65 .758 .928 r
.4314 .62958 m .42067 .63285 L .41761 .62983 L p F P
0 g
s
.65 .757 .928 r
.09802 .63246 m .1082 .62921 L .11174 .63222 L p F P
0 g
s
.65 .757 .928 r
.1082 .62921 m .09802 .63246 L .09446 .62945 L p F P
0 g
s
.651 .758 .928 r
.60265 .63255 m .61368 .62928 L .61644 .63229 L p F P
0 g
s
.651 .758 .928 r
.61368 .62928 m .60265 .63255 L .59987 .62954 L p F P
0 g
s
.65 .758 .928 r
.26622 .63258 m .27669 .62932 L .27997 .63233 L p F P
0 g
s
.65 .758 .928 r
.27669 .62932 m .26622 .63258 L .26292 .62956 L p F P
0 g
s
.65 .758 .928 r
.43444 .63259 m .44519 .62933 L .4482 .63234 L p F P
0 g
s
.65 .758 .928 r
.44519 .62933 m .43444 .63259 L .4314 .62958 L p F P
0 g
s
.65 .757 .928 r
.11174 .63222 m .12195 .62898 L .12547 .63199 L p F P
0 g
s
.65 .757 .928 r
.12195 .62898 m .11174 .63222 L .1082 .62921 L p F P
0 g
s
.651 .758 .928 r
.61644 .63229 m .6275 .62902 L .63023 .63203 L p F P
0 g
s
.651 .758 .928 r
.6275 .62902 m .61644 .63229 L .61368 .62928 L p F P
0 g
s
.65 .758 .928 r
.27997 .63233 m .29046 .62907 L .29372 .63208 L p F P
0 g
s
.65 .758 .928 r
.29046 .62907 m .27997 .63233 L .27669 .62932 L p F P
0 g
s
.65 .758 .928 r
.4482 .63234 m .45898 .62908 L .46197 .63209 L p F P
0 g
s
.65 .758 .928 r
.45898 .62908 m .4482 .63234 L .44519 .62933 L p F P
0 g
s
.65 .757 .928 r
.12547 .63199 m .1357 .62874 L .1392 .63175 L p F P
0 g
s
.65 .757 .928 r
.1357 .62874 m .12547 .63199 L .12195 .62898 L p F P
0 g
s
.651 .758 .928 r
.63023 .63203 m .64131 .62876 L .64403 .63177 L p F P
0 g
s
.651 .758 .928 r
.64131 .62876 m .63023 .63203 L .6275 .62902 L p F P
0 g
s
.65 .758 .928 r
.29372 .63208 m .30423 .62882 L .30747 .63183 L p F P
0 g
s
.65 .758 .928 r
.30423 .62882 m .29372 .63208 L .29046 .62907 L p F P
0 g
s
.65 .758 .928 r
.46197 .63209 m .47277 .62882 L .47575 .63184 L p F P
0 g
s
.65 .758 .928 r
.47277 .62882 m .46197 .63209 L .45898 .62908 L p F P
0 g
s
.65 .757 .928 r
.1392 .63175 m .14945 .6285 L .15293 .63151 L p F P
0 g
s
.65 .757 .928 r
.14945 .6285 m .1392 .63175 L .1357 .62874 L p F P
0 g
s
.651 .758 .928 r
.64403 .63177 m .65513 .6285 L .65782 .63151 L p F P
0 g
s
.651 .758 .928 r
.65513 .6285 m .64403 .63177 L .64131 .62876 L p F P
0 g
s
.65 .758 .928 r
.30747 .63183 m .31801 .62857 L .32122 .63159 L p F P
0 g
s
.65 .758 .928 r
.31801 .62857 m .30747 .63183 L .30423 .62882 L p F P
0 g
s
.65 .758 .928 r
.47575 .63184 m .48657 .62857 L .48953 .63159 L p F P
0 g
s
.65 .758 .928 r
.48657 .62857 m .47575 .63184 L .47277 .62882 L p F P
0 g
s
0 0 .271 r
.40369 .1928 m .40363 .19294 L .40376 .18837 L p F P
0 g
s
0 0 .271 r
.40376 .18837 m .40382 .18823 L .40369 .1928 L p F P
0 g
s
.764 .494 .526 r
.40343 .19289 m .40363 .19294 L .40376 .18837 L p F P
0 g
s
.764 .494 .526 r
.40376 .18837 m .40354 .18833 L .40343 .19289 L p F P
0 g
s
.651 .758 .928 r
.65782 .63151 m .66895 .62824 L .67163 .63125 L p F P
0 g
s
.651 .758 .928 r
.66895 .62824 m .65782 .63151 L .65513 .6285 L p F P
0 g
s
.65 .757 .928 r
.15293 .63151 m .16321 .62826 L .16667 .63127 L p F P
0 g
s
.65 .757 .928 r
.16321 .62826 m .15293 .63151 L .14945 .6285 L p F P
0 g
s
.65 .758 .928 r
.48953 .63159 m .50037 .62832 L .50331 .63133 L p F P
0 g
s
.65 .758 .928 r
.50037 .62832 m .48953 .63159 L .48657 .62857 L p F P
0 g
s
.65 .758 .928 r
.32122 .63159 m .33179 .62832 L .33498 .63134 L p F P
0 g
s
.65 .758 .928 r
.33179 .62832 m .32122 .63159 L .31801 .62857 L p F P
0 g
s
.651 .758 .928 r
.67163 .63125 m .68278 .62797 L .68543 .63098 L p F P
0 g
s
.651 .758 .928 r
.68278 .62797 m .67163 .63125 L .66895 .62824 L p F P
0 g
s
.65 .757 .928 r
.16667 .63127 m .17697 .62801 L .18041 .63103 L p F P
0 g
s
.65 .757 .928 r
.17697 .62801 m .16667 .63127 L .16321 .62826 L p F P
0 g
s
.65 .758 .928 r
.50331 .63133 m .51418 .62806 L .51709 .63108 L p F P
0 g
s
.65 .758 .928 r
.51418 .62806 m .50331 .63133 L .50037 .62832 L p F P
0 g
s
.65 .758 .928 r
.33498 .63134 m .34557 .62807 L .34875 .63109 L p F P
0 g
s
.65 .758 .928 r
.34557 .62807 m .33498 .63134 L .33179 .62832 L p F P
0 g
s
.651 .758 .928 r
.68543 .63098 m .69661 .62771 L .69924 .63072 L p F P
0 g
s
.651 .758 .928 r
.69661 .62771 m .68543 .63098 L .68278 .62797 L p F P
0 g
s
.65 .757 .928 r
.18041 .63103 m .19074 .62777 L .19415 .63079 L p F P
0 g
s
.65 .757 .928 r
.19074 .62777 m .18041 .63103 L .17697 .62801 L p F P
0 g
s
.65 .758 .928 r
.51709 .63108 m .52799 .62781 L .53088 .63082 L p F P
0 g
s
.65 .758 .928 r
.52799 .62781 m .51709 .63108 L .51418 .62806 L p F P
0 g
s
.65 .758 .928 r
.34875 .63109 m .35936 .62782 L .36251 .63084 L p F P
0 g
s
.65 .758 .928 r
.35936 .62782 m .34875 .63109 L .34557 .62807 L p F P
0 g
s
.651 .758 .928 r
.69924 .63072 m .71044 .62744 L .71305 .63045 L p F P
0 g
s
.651 .758 .928 r
.71044 .62744 m .69924 .63072 L .69661 .62771 L p F P
0 g
s
.65 .758 .928 r
.19415 .63079 m .2045 .62753 L .2079 .63055 L p F P
0 g
s
.65 .757 .928 r
.2045 .62753 m .19415 .63079 L .19074 .62777 L p F P
0 g
s
.65 .758 .928 r
.53088 .63082 m .5418 .62755 L .54467 .63057 L p F P
0 g
s
.65 .758 .928 r
.5418 .62755 m .53088 .63082 L .52799 .62781 L p F P
0 g
s
.65 .758 .928 r
.36251 .63084 m .37315 .62757 L .37628 .63059 L p F P
0 g
s
.65 .758 .928 r
.37315 .62757 m .36251 .63084 L .35936 .62782 L p F P
0 g
s
.651 .758 .928 r
.71305 .63045 m .72428 .62717 L .72687 .63018 L p F P
0 g
s
.651 .758 .928 r
.72428 .62717 m .71305 .63045 L .71044 .62744 L p F P
0 g
s
.65 .758 .928 r
.2079 .63055 m .21828 .62728 L .22165 .6303 L p F P
0 g
s
.65 .758 .928 r
.21828 .62728 m .2079 .63055 L .2045 .62753 L p F P
0 g
s
.65 .758 .928 r
.54467 .63057 m .55562 .6273 L .55847 .63031 L p F P
0 g
s
.65 .758 .928 r
.55562 .6273 m .54467 .63057 L .5418 .62755 L p F P
0 g
s
.65 .758 .928 r
.37628 .63059 m .38695 .62732 L .39006 .63034 L p F P
0 g
s
.65 .758 .928 r
.38695 .62732 m .37628 .63059 L .37315 .62757 L p F P
0 g
s
.651 .758 .928 r
.72687 .63018 m .73812 .6269 L .74069 .62991 L p F P
0 g
s
.651 .758 .928 r
.73812 .6269 m .72687 .63018 L .72428 .62717 L p F P
0 g
s
.65 .758 .928 r
.22165 .6303 m .23205 .62704 L .2354 .63006 L p F P
0 g
s
.65 .758 .928 r
.23205 .62704 m .22165 .6303 L .21828 .62728 L p F P
0 g
s
.65 .758 .928 r
.55847 .63031 m .56944 .62704 L .57227 .63006 L p F P
0 g
s
.65 .758 .928 r
.56944 .62704 m .55847 .63031 L .55562 .6273 L p F P
0 g
s
.65 .758 .928 r
.39006 .63034 m .40074 .62707 L .40383 .63009 L p F P
0 g
s
.65 .758 .928 r
.40074 .62707 m .39006 .63034 L .38695 .62732 L p F P
0 g
s
.651 .758 .928 r
.74069 .62991 m .75197 .62662 L .75451 .62964 L p F P
0 g
s
.651 .758 .928 r
.75197 .62662 m .74069 .62991 L .73812 .6269 L p F P
0 g
s
.651 .758 .928 r
.57227 .63006 m .58326 .62678 L .58607 .6298 L p F P
0 g
s
.651 .758 .928 r
.58326 .62678 m .57227 .63006 L .56944 .62704 L p F P
0 g
s
.65 .758 .928 r
.24583 .62679 m .2354 .63006 L .23205 .62704 L p F P
0 g
s
.65 .758 .928 r
.2354 .63006 m .24583 .62679 L .24916 .62981 L p F P
0 g
s
.65 .758 .928 r
.40383 .63009 m .41455 .62681 L .41761 .62983 L p F P
0 g
s
.65 .758 .928 r
.41455 .62681 m .40383 .63009 L .40074 .62707 L p F P
0 g
s
.651 .758 .928 r
.76581 .62635 m .75451 .62964 L .75197 .62662 L p F P
0 g
s
.651 .758 .928 r
.58607 .6298 m .59709 .62652 L .59987 .62954 L p F P
0 g
s
.651 .758 .928 r
.59709 .62652 m .58607 .6298 L .58326 .62678 L p F P
0 g
s
.65 .758 .928 r
.24916 .62981 m .25961 .62654 L .26292 .62956 L p F P
0 g
s
.65 .758 .928 r
.25961 .62654 m .24916 .62981 L .24583 .62679 L p F P
0 g
s
.65 .758 .928 r
.41761 .62983 m .42835 .62656 L .4314 .62958 L p F P
0 g
s
.65 .758 .928 r
.42835 .62656 m .41761 .62983 L .41455 .62681 L p F P
0 g
s
.65 .757 .928 r
.09446 .62945 m .10465 .62619 L .1082 .62921 L p F P
0 g
s
.65 .757 .928 r
.10465 .62619 m .09446 .62945 L .09089 .62643 L p F P
0 g
s
.651 .758 .928 r
.59987 .62954 m .61092 .62626 L .61368 .62928 L p F P
0 g
s
.651 .758 .928 r
.61092 .62626 m .59987 .62954 L .59709 .62652 L p F P
0 g
s
.65 .758 .928 r
.26292 .62956 m .2734 .62629 L .27669 .62932 L p F P
0 g
s
.65 .758 .928 r
.2734 .62629 m .26292 .62956 L .25961 .62654 L p F P
0 g
s
.65 .758 .928 r
.4314 .62958 m .44216 .62631 L .44519 .62933 L p F P
0 g
s
.65 .758 .928 r
.44216 .62631 m .4314 .62958 L .42835 .62656 L p F P
0 g
s
.65 .757 .928 r
.1082 .62921 m .11842 .62595 L .12195 .62898 L p F P
0 g
s
.65 .757 .928 r
.11842 .62595 m .1082 .62921 L .10465 .62619 L p F P
0 g
s
.651 .758 .928 r
.61368 .62928 m .62475 .626 L .6275 .62902 L p F P
0 g
s
.651 .758 .928 r
.62475 .626 m .61368 .62928 L .61092 .62626 L p F P
0 g
s
.65 .758 .928 r
.27669 .62932 m .28719 .62605 L .29046 .62907 L p F P
0 g
s
.65 .758 .928 r
.28719 .62605 m .27669 .62932 L .2734 .62629 L p F P
0 g
s
.65 .758 .928 r
.44519 .62933 m .45597 .62606 L .45898 .62908 L p F P
0 g
s
.65 .758 .928 r
.45597 .62606 m .44519 .62933 L .44216 .62631 L p F P
0 g
s
.65 .757 .928 r
.12195 .62898 m .13219 .62571 L .1357 .62874 L p F P
0 g
s
.65 .757 .928 r
.13219 .62571 m .12195 .62898 L .11842 .62595 L p F P
0 g
s
0 0 .271 r
.40356 .19738 m .40351 .19751 L .40363 .19294 L p F P
0 g
s
0 0 .271 r
.40363 .19294 m .40369 .1928 L .40356 .19738 L p F P
0 g
s
.764 .494 .526 r
.40331 .19747 m .40351 .19751 L .40363 .19294 L p F P
0 g
s
.764 .494 .526 r
.40363 .19294 m .40343 .19289 L .40331 .19747 L p F P
0 g
s
.651 .758 .928 r
.6275 .62902 m .63859 .62574 L .64131 .62876 L p F P
0 g
s
.651 .758 .928 r
.63859 .62574 m .6275 .62902 L .62475 .626 L p F P
0 g
s
.65 .758 .928 r
.29046 .62907 m .30099 .6258 L .30423 .62882 L p F P
0 g
s
.65 .758 .928 r
.30099 .6258 m .29046 .62907 L .28719 .62605 L p F P
0 g
s
.65 .758 .928 r
.45898 .62908 m .46979 .6258 L .47277 .62882 L p F P
0 g
s
.65 .758 .928 r
.46979 .6258 m .45898 .62908 L .45597 .62606 L p F P
0 g
s
.65 .757 .928 r
.1357 .62874 m .14597 .62547 L .14945 .6285 L p F P
0 g
s
.65 .757 .928 r
.14597 .62547 m .1357 .62874 L .13219 .62571 L p F P
0 g
s
.651 .758 .928 r
.64131 .62876 m .65243 .62548 L .65513 .6285 L p F P
0 g
s
.651 .758 .928 r
.65243 .62548 m .64131 .62876 L .63859 .62574 L p F P
0 g
s
.65 .758 .928 r
.30423 .62882 m .31478 .62555 L .31801 .62857 L p F P
0 g
s
.65 .758 .928 r
.31478 .62555 m .30423 .62882 L .30099 .6258 L p F P
0 g
s
.65 .758 .928 r
.47277 .62882 m .48361 .62555 L .48657 .62857 L p F P
0 g
s
.65 .758 .928 r
.48361 .62555 m .47277 .62882 L .46979 .6258 L p F P
0 g
s
.65 .757 .928 r
.14945 .6285 m .15974 .62523 L .16321 .62826 L p F P
0 g
s
.65 .757 .928 r
.15974 .62523 m .14945 .6285 L .14597 .62547 L p F P
0 g
s
.651 .758 .928 r
.65513 .6285 m .66627 .62522 L .66895 .62824 L p F P
0 g
s
.651 .758 .928 r
.66627 .62522 m .65513 .6285 L .65243 .62548 L p F P
0 g
s
.65 .758 .928 r
.31801 .62857 m .32858 .6253 L .33179 .62832 L p F P
0 g
s
.65 .758 .928 r
.32858 .6253 m .31801 .62857 L .31478 .62555 L p F P
0 g
s
.65 .758 .928 r
.48657 .62857 m .49743 .62529 L .50037 .62832 L p F P
0 g
s
.65 .758 .928 r
.49743 .62529 m .48657 .62857 L .48361 .62555 L p F P
0 g
s
.651 .758 .928 r
.66895 .62824 m .68012 .62495 L .68278 .62797 L p F P
0 g
s
.651 .758 .928 r
.68012 .62495 m .66895 .62824 L .66627 .62522 L p F P
0 g
s
.65 .757 .928 r
.16321 .62826 m .17353 .62499 L .17697 .62801 L p F P
0 g
s
.65 .757 .928 r
.17353 .62499 m .16321 .62826 L .15974 .62523 L p F P
0 g
s
.65 .758 .928 r
.50037 .62832 m .51126 .62504 L .51418 .62806 L p F P
0 g
s
.65 .758 .928 r
.51126 .62504 m .50037 .62832 L .49743 .62529 L p F P
0 g
s
.65 .758 .928 r
.33179 .62832 m .34239 .62505 L .34557 .62807 L p F P
0 g
s
.65 .758 .928 r
.34239 .62505 m .33179 .62832 L .32858 .6253 L p F P
0 g
s
.651 .758 .928 r
.68278 .62797 m .69397 .62469 L .69661 .62771 L p F P
0 g
s
.651 .758 .928 r
.69397 .62469 m .68278 .62797 L .68012 .62495 L p F P
0 g
s
.65 .757 .928 r
.17697 .62801 m .18731 .62474 L .19074 .62777 L p F P
0 g
s
.65 .757 .928 r
.18731 .62474 m .17697 .62801 L .17353 .62499 L p F P
0 g
s
.65 .758 .928 r
.51418 .62806 m .52509 .62478 L .52799 .62781 L p F P
0 g
s
.65 .758 .928 r
.52509 .62478 m .51418 .62806 L .51126 .62504 L p F P
0 g
s
.65 .758 .928 r
.34557 .62807 m .3562 .62479 L .35936 .62782 L p F P
0 g
s
.65 .758 .928 r
.3562 .62479 m .34557 .62807 L .34239 .62505 L p F P
0 g
s
.651 .758 .928 r
.69661 .62771 m .70783 .62442 L .71044 .62744 L p F P
0 g
s
.651 .758 .928 r
.70783 .62442 m .69661 .62771 L .69397 .62469 L p F P
0 g
s
.65 .757 .928 r
.19074 .62777 m .2011 .6245 L .2045 .62753 L p F P
0 g
s
.65 .757 .928 r
.2011 .6245 m .19074 .62777 L .18731 .62474 L p F P
0 g
s
.65 .758 .928 r
.52799 .62781 m .53892 .62453 L .5418 .62755 L p F P
0 g
s
.65 .758 .928 r
.53892 .62453 m .52799 .62781 L .52509 .62478 L p F P
0 g
s
.65 .758 .928 r
.35936 .62782 m .37001 .62454 L .37315 .62757 L p F P
0 g
s
.65 .758 .928 r
.37001 .62454 m .35936 .62782 L .3562 .62479 L p F P
0 g
s
.651 .758 .928 r
.71044 .62744 m .72169 .62415 L .72428 .62717 L p F P
0 g
s
.651 .758 .928 r
.72169 .62415 m .71044 .62744 L .70783 .62442 L p F P
0 g
s
.65 .758 .928 r
.2045 .62753 m .21489 .62425 L .21828 .62728 L p F P
0 g
s
.65 .757 .928 r
.21489 .62425 m .2045 .62753 L .2011 .6245 L p F P
0 g
s
.65 .758 .928 r
.5418 .62755 m .55276 .62427 L .55562 .6273 L p F P
0 g
s
.65 .758 .928 r
.55276 .62427 m .5418 .62755 L .53892 .62453 L p F P
0 g
s
.65 .758 .928 r
.37315 .62757 m .38383 .62429 L .38695 .62732 L p F P
0 g
s
.65 .758 .928 r
.38383 .62429 m .37315 .62757 L .37001 .62454 L p F P
0 g
s
.651 .758 .928 r
.72428 .62717 m .73555 .62388 L .73812 .6269 L p F P
0 g
s
.651 .758 .928 r
.73555 .62388 m .72428 .62717 L .72169 .62415 L p F P
0 g
s
.65 .758 .928 r
.21828 .62728 m .22869 .62401 L .23205 .62704 L p F P
0 g
s
.65 .758 .928 r
.22869 .62401 m .21828 .62728 L .21489 .62425 L p F P
0 g
s
.65 .758 .928 r
.5666 .62401 m .55562 .6273 L .55276 .62427 L p F P
0 g
s
.65 .758 .928 r
.55562 .6273 m .5666 .62401 L .56944 .62704 L p F P
0 g
s
.65 .758 .928 r
.38695 .62732 m .39765 .62404 L .40074 .62707 L p F P
0 g
s
.65 .758 .928 r
.39765 .62404 m .38695 .62732 L .38383 .62429 L p F P
0 g
s
.651 .758 .928 r
.73812 .6269 m .74941 .6236 L .75197 .62662 L p F P
0 g
s
.651 .758 .928 r
.74941 .6236 m .73812 .6269 L .73555 .62388 L p F P
0 g
s
.65 .758 .928 r
.23205 .62704 m .24249 .62376 L .24583 .62679 L p F P
0 g
s
.65 .758 .928 r
.24249 .62376 m .23205 .62704 L .22869 .62401 L p F P
0 g
s
.651 .758 .928 r
.56944 .62704 m .58045 .62375 L .58326 .62678 L p F P
0 g
s
.651 .758 .928 r
.58045 .62375 m .56944 .62704 L .5666 .62401 L p F P
0 g
s
.65 .758 .928 r
.40074 .62707 m .41147 .62379 L .41455 .62681 L p F P
0 g
s
.65 .758 .928 r
.41147 .62379 m .40074 .62707 L .39765 .62404 L p F P
0 g
s
.651 .758 .928 r
.75197 .62662 m .76328 .62333 L .76581 .62635 L p F P
0 g
s
.651 .758 .928 r
.76328 .62333 m .75197 .62662 L .74941 .6236 L p F P
0 g
s
.651 .758 .928 r
.59429 .62349 m .58326 .62678 L .58045 .62375 L p F P
0 g
s
.651 .758 .928 r
.58326 .62678 m .59429 .62349 L .59709 .62652 L p F P
0 g
s
.65 .758 .928 r
.2563 .62351 m .24583 .62679 L .24249 .62376 L p F P
0 g
s
.65 .758 .928 r
.24583 .62679 m .2563 .62351 L .25961 .62654 L p F P
0 g
s
.65 .758 .928 r
.41455 .62681 m .42529 .62353 L .42835 .62656 L p F P
0 g
s
.65 .758 .928 r
.42529 .62353 m .41455 .62681 L .41147 .62379 L p F P
0 g
s
.651 .759 .928 r
.77715 .62305 m .76581 .62635 L .76328 .62333 L p F P
0 g
s
.65 .757 .928 r
.09089 .62643 m .10109 .62316 L .10465 .62619 L p F P
0 g
s
.65 .757 .928 r
.10109 .62316 m .09089 .62643 L .08731 .62339 L p F P
0 g
s
0 0 .271 r
.40343 .20197 m .40338 .2021 L .40351 .19751 L p F P
0 g
s
0 0 .271 r
.40351 .19751 m .40356 .19738 L .40343 .20197 L p F P
0 g
s
.764 .494 .526 r
.40319 .20206 m .40338 .2021 L .40351 .19751 L p F P
0 g
s
.764 .494 .526 r
.40351 .19751 m .40331 .19747 L .40319 .20206 L p F P
0 g
s
.651 .758 .928 r
.59709 .62652 m .60815 .62323 L .61092 .62626 L p F P
0 g
s
.651 .758 .928 r
.60815 .62323 m .59709 .62652 L .59429 .62349 L p F P
0 g
s
.65 .758 .928 r
.25961 .62654 m .2701 .62326 L .2734 .62629 L p F P
0 g
s
.65 .758 .928 r
.2701 .62326 m .25961 .62654 L .2563 .62351 L p F P
0 g
s
.65 .758 .928 r
.42835 .62656 m .43912 .62328 L .44216 .62631 L p F P
0 g
s
.65 .758 .928 r
.43912 .62328 m .42835 .62656 L .42529 .62353 L p F P
0 g
s
.65 .757 .928 r
.10465 .62619 m .11488 .62292 L .11842 .62595 L p F P
0 g
s
.65 .757 .928 r
.11488 .62292 m .10465 .62619 L .10109 .62316 L p F P
0 g
s
.651 .758 .928 r
.61092 .62626 m .622 .62297 L .62475 .626 L p F P
0 g
s
.651 .758 .928 r
.622 .62297 m .61092 .62626 L .60815 .62323 L p F P
0 g
s
.65 .758 .928 r
.2734 .62629 m .28391 .62301 L .28719 .62605 L p F P
0 g
s
.65 .758 .928 r
.28391 .62301 m .2734 .62629 L .2701 .62326 L p F P
0 g
s
.65 .758 .928 r
.44216 .62631 m .45296 .62302 L .45597 .62606 L p F P
0 g
s
.65 .758 .928 r
.45296 .62302 m .44216 .62631 L .43912 .62328 L p F P
0 g
s
.65 .757 .928 r
.11842 .62595 m .12867 .62268 L .13219 .62571 L p F P
0 g
s
.65 .757 .928 r
.12867 .62268 m .11842 .62595 L .11488 .62292 L p F P
0 g
s
.651 .758 .928 r
.62475 .626 m .63586 .62271 L .63859 .62574 L p F P
0 g
s
.651 .758 .928 r
.63586 .62271 m .62475 .626 L .622 .62297 L p F P
0 g
s
.65 .758 .928 r
.28719 .62605 m .29773 .62276 L .30099 .6258 L p F P
0 g
s
.65 .758 .928 r
.29773 .62276 m .28719 .62605 L .28391 .62301 L p F P
0 g
s
.65 .758 .928 r
.45597 .62606 m .4668 .62277 L .46979 .6258 L p F P
0 g
s
.65 .758 .928 r
.4668 .62277 m .45597 .62606 L .45296 .62302 L p F P
0 g
s
.65 .757 .928 r
.13219 .62571 m .14247 .62244 L .14597 .62547 L p F P
0 g
s
.65 .757 .928 r
.14247 .62244 m .13219 .62571 L .12867 .62268 L p F P
0 g
s
.651 .758 .928 r
.63859 .62574 m .64972 .62245 L .65243 .62548 L p F P
0 g
s
.651 .758 .928 r
.64972 .62245 m .63859 .62574 L .63586 .62271 L p F P
0 g
s
.65 .758 .928 r
.30099 .6258 m .31155 .62251 L .31478 .62555 L p F P
0 g
s
.65 .758 .928 r
.31155 .62251 m .30099 .6258 L .29773 .62276 L p F P
0 g
s
.65 .758 .928 r
.46979 .6258 m .48064 .62251 L .48361 .62555 L p F P
0 g
s
.65 .758 .928 r
.48064 .62251 m .46979 .6258 L .4668 .62277 L p F P
0 g
s
.65 .757 .928 r
.14597 .62547 m .15627 .6222 L .15974 .62523 L p F P
0 g
s
.65 .757 .928 r
.15627 .6222 m .14597 .62547 L .14247 .62244 L p F P
0 g
s
.651 .758 .928 r
.65243 .62548 m .66359 .62219 L .66627 .62522 L p F P
0 g
s
.651 .758 .928 r
.66359 .62219 m .65243 .62548 L .64972 .62245 L p F P
0 g
s
.65 .758 .928 r
.31478 .62555 m .32537 .62226 L .32858 .6253 L p F P
0 g
s
.65 .758 .928 r
.32537 .62226 m .31478 .62555 L .31155 .62251 L p F P
0 g
s
.65 .758 .928 r
.48361 .62555 m .49448 .62226 L .49743 .62529 L p F P
0 g
s
.65 .758 .928 r
.49448 .62226 m .48361 .62555 L .48064 .62251 L p F P
0 g
s
.651 .758 .928 r
.66627 .62522 m .67746 .62192 L .68012 .62495 L p F P
0 g
s
.651 .758 .928 r
.67746 .62192 m .66627 .62522 L .66359 .62219 L p F P
0 g
s
.65 .757 .928 r
.15974 .62523 m .17007 .62195 L .17353 .62499 L p F P
0 g
s
.65 .757 .928 r
.17007 .62195 m .15974 .62523 L .15627 .6222 L p F P
0 g
s
.65 .758 .928 r
.49743 .62529 m .50833 .622 L .51126 .62504 L p F P
0 g
s
.65 .758 .928 r
.50833 .622 m .49743 .62529 L .49448 .62226 L p F P
0 g
s
.65 .758 .928 r
.32858 .6253 m .3392 .62201 L .34239 .62505 L p F P
0 g
s
.65 .758 .928 r
.3392 .62201 m .32858 .6253 L .32537 .62226 L p F P
0 g
s
.651 .758 .928 r
.68012 .62495 m .69133 .62165 L .69397 .62469 L p F P
0 g
s
.651 .758 .928 r
.69133 .62165 m .68012 .62495 L .67746 .62192 L p F P
0 g
s
.65 .757 .928 r
.17353 .62499 m .18388 .62171 L .18731 .62474 L p F P
0 g
s
.65 .757 .928 r
.18388 .62171 m .17353 .62499 L .17007 .62195 L p F P
0 g
s
.65 .758 .928 r
.51126 .62504 m .52218 .62175 L .52509 .62478 L p F P
0 g
s
.65 .758 .928 r
.52218 .62175 m .51126 .62504 L .50833 .622 L p F P
0 g
s
.65 .758 .928 r
.34239 .62505 m .35303 .62176 L .3562 .62479 L p F P
0 g
s
.65 .758 .928 r
.35303 .62176 m .34239 .62505 L .3392 .62201 L p F P
0 g
s
.651 .758 .928 r
.69397 .62469 m .7052 .62139 L .70783 .62442 L p F P
0 g
s
.651 .758 .928 r
.7052 .62139 m .69397 .62469 L .69133 .62165 L p F P
0 g
s
.65 .757 .928 r
.18731 .62474 m .19769 .62146 L .2011 .6245 L p F P
0 g
s
.65 .757 .928 r
.19769 .62146 m .18731 .62474 L .18388 .62171 L p F P
0 g
s
.65 .758 .928 r
.52509 .62478 m .53603 .62149 L .53892 .62453 L p F P
0 g
s
.65 .758 .928 r
.53603 .62149 m .52509 .62478 L .52218 .62175 L p F P
0 g
s
.65 .758 .928 r
.3562 .62479 m .36686 .62151 L .37001 .62454 L p F P
0 g
s
.65 .758 .928 r
.36686 .62151 m .3562 .62479 L .35303 .62176 L p F P
0 g
s
.651 .758 .928 r
.70783 .62442 m .71908 .62112 L .72169 .62415 L p F P
0 g
s
.651 .758 .928 r
.71908 .62112 m .70783 .62442 L .7052 .62139 L p F P
0 g
s
.65 .757 .928 r
.2011 .6245 m .2115 .62122 L .21489 .62425 L p F P
0 g
s
.65 .757 .928 r
.2115 .62122 m .2011 .6245 L .19769 .62146 L p F P
0 g
s
.65 .758 .928 r
.53892 .62453 m .54989 .62123 L .55276 .62427 L p F P
0 g
s
.65 .758 .928 r
.54989 .62123 m .53892 .62453 L .53603 .62149 L p F P
0 g
s
.65 .758 .928 r
.37001 .62454 m .3807 .62125 L .38383 .62429 L p F P
0 g
s
.65 .758 .928 r
.3807 .62125 m .37001 .62454 L .36686 .62151 L p F P
0 g
s
.651 .758 .928 r
.72169 .62415 m .73297 .62085 L .73555 .62388 L p F P
0 g
s
.651 .758 .928 r
.73297 .62085 m .72169 .62415 L .71908 .62112 L p F P
0 g
s
.65 .758 .928 r
.21489 .62425 m .22532 .62097 L .22869 .62401 L p F P
0 g
s
.65 .758 .928 r
.22532 .62097 m .21489 .62425 L .2115 .62122 L p F P
0 g
s
.65 .758 .928 r
.55276 .62427 m .56376 .62097 L .5666 .62401 L p F P
0 g
s
.651 .758 .928 r
.56376 .62097 m .55276 .62427 L .54989 .62123 L p F P
0 g
s
.65 .758 .928 r
.38383 .62429 m .39454 .621 L .39765 .62404 L p F P
0 g
s
.65 .758 .928 r
.39454 .621 m .38383 .62429 L .3807 .62125 L p F P
0 g
s
.651 .758 .928 r
.73555 .62388 m .74685 .62057 L .74941 .6236 L p F P
0 g
s
.651 .758 .928 r
.74685 .62057 m .73555 .62388 L .73297 .62085 L p F P
0 g
s
0 0 .271 r
.4033 .20658 m .40326 .2067 L .40338 .2021 L p F P
0 g
s
0 0 .271 r
.40338 .2021 m .40343 .20197 L .4033 .20658 L p F P
0 g
s
.764 .494 .526 r
.40308 .20666 m .40326 .2067 L .40338 .2021 L p F P
0 g
s
.764 .494 .526 r
.40338 .2021 m .40319 .20206 L .40308 .20666 L p F P
0 g
s
.65 .758 .928 r
.22869 .62401 m .23914 .62072 L .24249 .62376 L p F P
0 g
s
.65 .758 .928 r
.23914 .62072 m .22869 .62401 L .22532 .62097 L p F P
0 g
s
.651 .758 .928 r
.57762 .62072 m .5666 .62401 L .56376 .62097 L p F P
0 g
s
.651 .758 .928 r
.5666 .62401 m .57762 .62072 L .58045 .62375 L p F P
0 g
s
.65 .758 .928 r
.39765 .62404 m .40838 .62075 L .41147 .62379 L p F P
0 g
s
.65 .758 .928 r
.40838 .62075 m .39765 .62404 L .39454 .621 L p F P
0 g
s
.651 .758 .928 r
.74941 .6236 m .76074 .6203 L .76328 .62333 L p F P
0 g
s
.651 .758 .928 r
.76074 .6203 m .74941 .6236 L .74685 .62057 L p F P
0 g
s
.651 .758 .928 r
.58045 .62375 m .59149 .62046 L .59429 .62349 L p F P
0 g
s
.651 .758 .928 r
.59149 .62046 m .58045 .62375 L .57762 .62072 L p F P
0 g
s
.65 .758 .928 r
.24249 .62376 m .25297 .62047 L .2563 .62351 L p F P
0 g
s
.65 .758 .928 r
.25297 .62047 m .24249 .62376 L .23914 .62072 L p F P
0 g
s
.65 .758 .928 r
.41147 .62379 m .42223 .62049 L .42529 .62353 L p F P
0 g
s
.65 .758 .928 r
.42223 .62049 m .41147 .62379 L .40838 .62075 L p F P
0 g
s
.651 .759 .928 r
.76328 .62333 m .77463 .62002 L .77715 .62305 L p F P
0 g
s
.651 .758 .928 r
.77463 .62002 m .76328 .62333 L .76074 .6203 L p F P
0 g
s
.65 .757 .928 r
.08731 .62339 m .09752 .62012 L .10109 .62316 L p F P
0 g
s
.65 .757 .928 r
.09752 .62012 m .08731 .62339 L .08372 .62035 L p F P
0 g
s
.651 .758 .928 r
.60536 .6202 m .59429 .62349 L .59149 .62046 L p F P
0 g
s
.651 .758 .928 r
.59429 .62349 m .60536 .6202 L .60815 .62323 L p F P
0 g
s
.65 .758 .928 r
.26679 .62022 m .2563 .62351 L .25297 .62047 L p F P
0 g
s
.65 .758 .928 r
.2563 .62351 m .26679 .62022 L .2701 .62326 L p F P
0 g
s
.65 .758 .928 r
.42529 .62353 m .43608 .62024 L .43912 .62328 L p F P
0 g
s
.65 .758 .928 r
.43608 .62024 m .42529 .62353 L .42223 .62049 L p F P
0 g
s
.651 .759 .928 r
.78853 .61974 m .77715 .62305 L .77463 .62002 L p F P
0 g
s
.65 .757 .928 r
.10109 .62316 m .11133 .61988 L .11488 .62292 L p F P
0 g
s
.65 .757 .928 r
.11133 .61988 m .10109 .62316 L .09752 .62012 L p F P
0 g
s
.651 .758 .928 r
.60815 .62323 m .61924 .61994 L .622 .62297 L p F P
0 g
s
.651 .758 .928 r
.61924 .61994 m .60815 .62323 L .60536 .6202 L p F P
0 g
s
.65 .758 .928 r
.2701 .62326 m .28063 .61997 L .28391 .62301 L p F P
0 g
s
.65 .758 .928 r
.28063 .61997 m .2701 .62326 L .26679 .62022 L p F P
0 g
s
.65 .758 .928 r
.43912 .62328 m .44993 .61998 L .45296 .62302 L p F P
0 g
s
.65 .758 .928 r
.44993 .61998 m .43912 .62328 L .43608 .62024 L p F P
0 g
s
.65 .757 .928 r
.11488 .62292 m .12514 .61964 L .12867 .62268 L p F P
0 g
s
.65 .757 .928 r
.12514 .61964 m .11488 .62292 L .11133 .61988 L p F P
0 g
s
.651 .758 .928 r
.622 .62297 m .63312 .61967 L .63586 .62271 L p F P
0 g
s
.651 .758 .928 r
.63312 .61967 m .622 .62297 L .61924 .61994 L p F P
0 g
s
.65 .758 .928 r
.28391 .62301 m .29446 .61972 L .29773 .62276 L p F P
0 g
s
.65 .758 .928 r
.29446 .61972 m .28391 .62301 L .28063 .61997 L p F P
0 g
s
.65 .758 .928 r
.45296 .62302 m .46379 .61973 L .4668 .62277 L p F P
0 g
s
.65 .758 .928 r
.46379 .61973 m .45296 .62302 L .44993 .61998 L p F P
0 g
s
.65 .757 .928 r
.12867 .62268 m .13896 .6194 L .14247 .62244 L p F P
0 g
s
.65 .757 .928 r
.13896 .6194 m .12867 .62268 L .12514 .61964 L p F P
0 g
s
.651 .758 .928 r
.63586 .62271 m .647 .61941 L .64972 .62245 L p F P
0 g
s
.651 .758 .928 r
.647 .61941 m .63586 .62271 L .63312 .61967 L p F P
0 g
s
.65 .758 .928 r
.29773 .62276 m .3083 .61947 L .31155 .62251 L p F P
0 g
s
.65 .758 .928 r
.3083 .61947 m .29773 .62276 L .29446 .61972 L p F P
0 g
s
.65 .758 .928 r
.4668 .62277 m .47765 .61947 L .48064 .62251 L p F P
0 g
s
.65 .758 .928 r
.47765 .61947 m .4668 .62277 L .46379 .61973 L p F P
0 g
s
.65 .757 .928 r
.14247 .62244 m .15278 .61915 L .15627 .6222 L p F P
0 g
s
.65 .757 .928 r
.15278 .61915 m .14247 .62244 L .13896 .6194 L p F P
0 g
s
.651 .758 .928 r
.64972 .62245 m .66089 .61915 L .66359 .62219 L p F P
0 g
s
.651 .758 .928 r
.66089 .61915 m .64972 .62245 L .647 .61941 L p F P
0 g
s
.65 .758 .928 r
.31155 .62251 m .32215 .61922 L .32537 .62226 L p F P
0 g
s
.65 .758 .928 r
.32215 .61922 m .31155 .62251 L .3083 .61947 L p F P
0 g
s
.65 .758 .928 r
.48064 .62251 m .49152 .61922 L .49448 .62226 L p F P
0 g
s
.65 .758 .928 r
.49152 .61922 m .48064 .62251 L .47765 .61947 L p F P
0 g
s
.651 .758 .928 r
.66359 .62219 m .67478 .61888 L .67746 .62192 L p F P
0 g
s
.651 .758 .928 r
.67478 .61888 m .66359 .62219 L .66089 .61915 L p F P
0 g
s
.65 .757 .928 r
.15627 .6222 m .1666 .61891 L .17007 .62195 L p F P
0 g
s
.65 .757 .928 r
.1666 .61891 m .15627 .6222 L .15278 .61915 L p F P
0 g
s
.65 .758 .928 r
.49448 .62226 m .50539 .61896 L .50833 .622 L p F P
0 g
s
.65 .758 .928 r
.50539 .61896 m .49448 .62226 L .49152 .61922 L p F P
0 g
s
.65 .758 .928 r
.32537 .62226 m .33599 .61896 L .3392 .62201 L p F P
0 g
s
.65 .758 .928 r
.33599 .61896 m .32537 .62226 L .32215 .61922 L p F P
0 g
s
.651 .758 .928 r
.67746 .62192 m .68867 .61861 L .69133 .62165 L p F P
0 g
s
.651 .758 .928 r
.68867 .61861 m .67746 .62192 L .67478 .61888 L p F P
0 g
s
.65 .757 .928 r
.17007 .62195 m .18043 .61866 L .18388 .62171 L p F P
0 g
s
.65 .757 .928 r
.18043 .61866 m .17007 .62195 L .1666 .61891 L p F P
0 g
s
.65 .758 .928 r
.50833 .622 m .51926 .6187 L .52218 .62175 L p F P
0 g
s
.65 .758 .928 r
.51926 .6187 m .50833 .622 L .50539 .61896 L p F P
0 g
s
.65 .758 .928 r
.3392 .62201 m .34984 .61871 L .35303 .62176 L p F P
0 g
s
.65 .758 .928 r
.34984 .61871 m .3392 .62201 L .33599 .61896 L p F P
0 g
s
.651 .758 .928 r
.69133 .62165 m .70257 .61835 L .7052 .62139 L p F P
0 g
s
.651 .758 .928 r
.70257 .61835 m .69133 .62165 L .68867 .61861 L p F P
0 g
s
.65 .757 .928 r
.18388 .62171 m .19426 .61842 L .19769 .62146 L p F P
0 g
s
.65 .757 .928 r
.19426 .61842 m .18388 .62171 L .18043 .61866 L p F P
0 g
s
.65 .758 .928 r
.52218 .62175 m .53314 .61844 L .53603 .62149 L p F P
0 g
s
.65 .758 .928 r
.53314 .61844 m .52218 .62175 L .51926 .6187 L p F P
0 g
s
.65 .758 .928 r
.35303 .62176 m .3637 .61846 L .36686 .62151 L p F P
0 g
s
.65 .758 .928 r
.3637 .61846 m .35303 .62176 L .34984 .61871 L p F P
0 g
s
.651 .758 .928 r
.7052 .62139 m .71647 .61808 L .71908 .62112 L p F P
0 g
s
.651 .758 .928 r
.71647 .61808 m .7052 .62139 L .70257 .61835 L p F P
0 g
s
0 0 .271 r
.40318 .21119 m .40313 .21131 L .40326 .2067 L p F P
0 g
s
0 0 .271 r
.40326 .2067 m .4033 .20658 L .40318 .21119 L p F P
0 g
s
.764 .494 .526 r
.40296 .21127 m .40313 .21131 L .40326 .2067 L p F P
0 g
s
.764 .494 .526 r
.40326 .2067 m .40308 .20666 L .40296 .21127 L p F P
0 g
s
.65 .757 .928 r
.19769 .62146 m .2081 .61817 L .2115 .62122 L p F P
0 g
s
.65 .757 .928 r
.2081 .61817 m .19769 .62146 L .19426 .61842 L p F P
0 g
s
.65 .758 .928 r
.53603 .62149 m .54702 .61819 L .54989 .62123 L p F P
0 g
s
.65 .758 .928 r
.54702 .61819 m .53603 .62149 L .53314 .61844 L p F P
0 g
s
.65 .758 .928 r
.36686 .62151 m .37756 .61821 L .3807 .62125 L p F P
0 g
s
.65 .758 .928 r
.37756 .61821 m .36686 .62151 L .3637 .61846 L p F P
0 g
s
.651 .758 .928 r
.71908 .62112 m .73038 .6178 L .73297 .62085 L p F P
0 g
s
.651 .758 .928 r
.73038 .6178 m .71908 .62112 L .71647 .61808 L p F P
0 g
s
.65 .758 .928 r
.2115 .62122 m .22194 .61792 L .22532 .62097 L p F P
0 g
s
.65 .757 .928 r
.22194 .61792 m .2115 .62122 L .2081 .61817 L p F P
0 g
s
.651 .758 .928 r
.54989 .62123 m .5609 .61793 L .56376 .62097 L p F P
0 g
s
.651 .758 .928 r
.5609 .61793 m .54989 .62123 L .54702 .61819 L p F P
0 g
s
.65 .758 .928 r
.3807 .62125 m .39142 .61795 L .39454 .621 L p F P
0 g
s
.65 .758 .928 r
.39142 .61795 m .3807 .62125 L .37756 .61821 L p F P
0 g
s
.651 .758 .928 r
.73297 .62085 m .74428 .61753 L .74685 .62057 L p F P
0 g
s
.651 .758 .928 r
.74428 .61753 m .73297 .62085 L .73038 .6178 L p F P
0 g
s
.65 .758 .928 r
.22532 .62097 m .23578 .61767 L .23914 .62072 L p F P
0 g
s
.65 .758 .928 r
.23578 .61767 m .22532 .62097 L .22194 .61792 L p F P
0 g
s
.651 .758 .928 r
.56376 .62097 m .57479 .61767 L .57762 .62072 L p F P
0 g
s
.651 .758 .928 r
.57479 .61767 m .56376 .62097 L .5609 .61793 L p F P
0 g
s
.65 .758 .928 r
.39454 .621 m .40528 .6177 L .40838 .62075 L p F P
0 g
s
.65 .758 .928 r
.40528 .6177 m .39454 .621 L .39142 .61795 L p F P
0 g
s
.651 .758 .928 r
.74685 .62057 m .7582 .61726 L .76074 .6203 L p F P
0 g
s
.651 .758 .928 r
.7582 .61726 m .74685 .62057 L .74428 .61753 L p F P
0 g
s
.651 .758 .928 r
.58868 .61741 m .57762 .62072 L .57479 .61767 L p F P
0 g
s
.651 .758 .928 r
.57762 .62072 m .58868 .61741 L .59149 .62046 L p F P
0 g
s
.65 .758 .928 r
.23914 .62072 m .24963 .61742 L .25297 .62047 L p F P
0 g
s
.65 .758 .928 r
.24963 .61742 m .23914 .62072 L .23578 .61767 L p F P
0 g
s
.65 .758 .928 r
.40838 .62075 m .41915 .61744 L .42223 .62049 L p F P
0 g
s
.65 .758 .928 r
.41915 .61744 m .40838 .62075 L .40528 .6177 L p F P
0 g
s
.651 .758 .928 r
.76074 .6203 m .77211 .61698 L .77463 .62002 L p F P
0 g
s
.651 .758 .928 r
.77211 .61698 m .76074 .6203 L .7582 .61726 L p F P
0 g
s
.65 .757 .928 r
.08372 .62035 m .09394 .61706 L .09752 .62012 L p F P
0 g
s
.65 .757 .928 r
.09394 .61706 m .08372 .62035 L .08011 .6173 L p F P
0 g
s
.651 .758 .928 r
.59149 .62046 m .60257 .61715 L .60536 .6202 L p F P
0 g
s
.651 .758 .928 r
.60257 .61715 m .59149 .62046 L .58868 .61741 L p F P
0 g
s
.65 .758 .928 r
.25297 .62047 m .26348 .61717 L .26679 .62022 L p F P
0 g
s
.65 .758 .928 r
.26348 .61717 m .25297 .62047 L .24963 .61742 L p F P
0 g
s
.65 .758 .928 r
.42223 .62049 m .43302 .61719 L .43608 .62024 L p F P
0 g
s
.65 .758 .928 r
.43302 .61719 m .42223 .62049 L .41915 .61744 L p F P
0 g
s
.651 .759 .928 r
.77463 .62002 m .78603 .6167 L .78853 .61974 L p F P
0 g
s
.651 .759 .928 r
.78603 .6167 m .77463 .62002 L .77211 .61698 L p F P
0 g
s
.65 .757 .928 r
.09752 .62012 m .10777 .61683 L .11133 .61988 L p F P
0 g
s
.65 .757 .928 r
.10777 .61683 m .09752 .62012 L .09394 .61706 L p F P
0 g
s
.651 .758 .928 r
.61647 .61689 m .60536 .6202 L .60257 .61715 L p F P
0 g
s
.651 .758 .928 r
.60536 .6202 m .61647 .61689 L .61924 .61994 L p F P
0 g
s
.65 .758 .928 r
.26679 .62022 m .27733 .61692 L .28063 .61997 L p F P
0 g
s
.65 .758 .928 r
.27733 .61692 m .26679 .62022 L .26348 .61717 L p F P
0 g
s
.65 .758 .928 r
.43608 .62024 m .4469 .61693 L .44993 .61998 L p F P
0 g
s
.65 .758 .928 r
.4469 .61693 m .43608 .62024 L .43302 .61719 L p F P
0 g
s
.651 .759 .928 r
.79995 .61641 m .78853 .61974 L .78603 .6167 L p F P
0 g
s
.65 .757 .928 r
.11133 .61988 m .1216 .61658 L .12514 .61964 L p F P
0 g
s
.65 .757 .928 r
.1216 .61658 m .11133 .61988 L .10777 .61683 L p F P
0 g
s
.651 .758 .928 r
.61924 .61994 m .63037 .61662 L .63312 .61967 L p F P
0 g
s
.651 .758 .928 r
.63037 .61662 m .61924 .61994 L .61647 .61689 L p F P
0 g
s
.65 .758 .928 r
.28063 .61997 m .29119 .61667 L .29446 .61972 L p F P
0 g
s
.65 .758 .928 r
.29119 .61667 m .28063 .61997 L .27733 .61692 L p F P
0 g
s
.65 .758 .928 r
.44993 .61998 m .46078 .61668 L .46379 .61973 L p F P
0 g
s
.65 .758 .928 r
.46078 .61668 m .44993 .61998 L .4469 .61693 L p F P
0 g
s
.65 .757 .928 r
.12514 .61964 m .13544 .61634 L .13896 .6194 L p F P
0 g
s
.65 .757 .928 r
.13544 .61634 m .12514 .61964 L .1216 .61658 L p F P
0 g
s
.651 .758 .928 r
.63312 .61967 m .64428 .61636 L .647 .61941 L p F P
0 g
s
.651 .758 .928 r
.64428 .61636 m .63312 .61967 L .63037 .61662 L p F P
0 g
s
.65 .758 .928 r
.29446 .61972 m .30505 .61642 L .3083 .61947 L p F P
0 g
s
.65 .758 .928 r
.30505 .61642 m .29446 .61972 L .29119 .61667 L p F P
0 g
s
.65 .758 .928 r
.46379 .61973 m .47466 .61642 L .47765 .61947 L p F P
0 g
s
.65 .758 .928 r
.47466 .61642 m .46379 .61973 L .46078 .61668 L p F P
0 g
s
.65 .757 .928 r
.13896 .6194 m .14928 .6161 L .15278 .61915 L p F P
0 g
s
.65 .757 .928 r
.14928 .6161 m .13896 .6194 L .13544 .61634 L p F P
0 g
s
.651 .758 .928 r
.647 .61941 m .65819 .6161 L .66089 .61915 L p F P
0 g
s
.651 .758 .928 r
.65819 .6161 m .647 .61941 L .64428 .61636 L p F P
0 g
s
.65 .758 .928 r
.3083 .61947 m .31891 .61616 L .32215 .61922 L p F P
0 g
s
.65 .758 .928 r
.31891 .61616 m .3083 .61947 L .30505 .61642 L p F P
0 g
s
.65 .758 .928 r
.47765 .61947 m .48855 .61616 L .49152 .61922 L p F P
0 g
s
.65 .758 .928 r
.48855 .61616 m .47765 .61947 L .47466 .61642 L p F P
0 g
s
.651 .758 .928 r
.66089 .61915 m .6721 .61583 L .67478 .61888 L p F P
0 g
s
.651 .758 .928 r
.6721 .61583 m .66089 .61915 L .65819 .6161 L p F P
0 g
s
.65 .757 .928 r
.15278 .61915 m .16313 .61585 L .1666 .61891 L p F P
0 g
s
.65 .757 .928 r
.16313 .61585 m .15278 .61915 L .14928 .6161 L p F P
0 g
s
.65 .758 .928 r
.49152 .61922 m .50244 .61591 L .50539 .61896 L p F P
0 g
s
.65 .758 .928 r
.50244 .61591 m .49152 .61922 L .48855 .61616 L p F P
0 g
s
.65 .758 .928 r
.32215 .61922 m .33278 .61591 L .33599 .61896 L p F P
0 g
s
.65 .758 .928 r
.33278 .61591 m .32215 .61922 L .31891 .61616 L p F P
0 g
s
.651 .758 .928 r
.67478 .61888 m .68601 .61556 L .68867 .61861 L p F P
0 g
s
.651 .758 .928 r
.68601 .61556 m .67478 .61888 L .6721 .61583 L p F P
0 g
s
0 0 .271 r
.40305 .21582 m .403 .21593 L .40313 .21131 L p F P
0 g
s
0 0 .271 r
.40313 .21131 m .40318 .21119 L .40305 .21582 L p F P
0 g
s
.764 .494 .526 r
.40284 .2159 m .403 .21593 L .40313 .21131 L p F P
0 g
s
.764 .494 .526 r
.40313 .21131 m .40296 .21127 L .40284 .2159 L p F P
0 g
s
.65 .757 .928 r
.1666 .61891 m .17697 .61561 L .18043 .61866 L p F P
0 g
s
.65 .757 .928 r
.17697 .61561 m .1666 .61891 L .16313 .61585 L p F P
0 g
s
.65 .758 .928 r
.50539 .61896 m .51633 .61565 L .51926 .6187 L p F P
0 g
s
.65 .758 .928 r
.51633 .61565 m .50539 .61896 L .50244 .61591 L p F P
0 g
s
.65 .758 .928 r
.33599 .61896 m .34665 .61566 L .34984 .61871 L p F P
0 g
s
.65 .758 .928 r
.34665 .61566 m .33599 .61896 L .33278 .61591 L p F P
0 g
s
.651 .758 .928 r
.68867 .61861 m .69993 .6153 L .70257 .61835 L p F P
0 g
s
.651 .758 .928 r
.69993 .6153 m .68867 .61861 L .68601 .61556 L p F P
0 g
s
.65 .757 .928 r
.18043 .61866 m .19083 .61536 L .19426 .61842 L p F P
0 g
s
.65 .757 .928 r
.19083 .61536 m .18043 .61866 L .17697 .61561 L p F P
0 g
s
.65 .758 .928 r
.51926 .6187 m .53023 .61539 L .53314 .61844 L p F P
0 g
s
.65 .758 .928 r
.53023 .61539 m .51926 .6187 L .51633 .61565 L p F P
0 g
s
.65 .758 .928 r
.34984 .61871 m .36053 .6154 L .3637 .61846 L p F P
0 g
s
.65 .758 .928 r
.36053 .6154 m .34984 .61871 L .34665 .61566 L p F P
0 g
s
.651 .758 .928 r
.70257 .61835 m .71385 .61503 L .71647 .61808 L p F P
0 g
s
.651 .758 .928 r
.71385 .61503 m .70257 .61835 L .69993 .6153 L p F P
0 g
s
.65 .757 .928 r
.19426 .61842 m .20468 .61511 L .2081 .61817 L p F P
0 g
s
.65 .757 .928 r
.20468 .61511 m .19426 .61842 L .19083 .61536 L p F P
0 g
s
.65 .758 .928 r
.53314 .61844 m .54413 .61513 L .54702 .61819 L p F P
0 g
s
.65 .758 .928 r
.54413 .61513 m .53314 .61844 L .53023 .61539 L p F P
0 g
s
.65 .758 .928 r
.3637 .61846 m .37441 .61515 L .37756 .61821 L p F P
0 g
s
.65 .758 .928 r
.37441 .61515 m .3637 .61846 L .36053 .6154 L p F P
0 g
s
.651 .758 .928 r
.71647 .61808 m .72778 .61475 L .73038 .6178 L p F P
0 g
s
.651 .758 .928 r
.72778 .61475 m .71647 .61808 L .71385 .61503 L p F P
0 g
s
.65 .757 .928 r
.2081 .61817 m .21854 .61486 L .22194 .61792 L p F P
0 g
s
.65 .757 .928 r
.21854 .61486 m .2081 .61817 L .20468 .61511 L p F P
0 g
s
.651 .758 .928 r
.54702 .61819 m .55804 .61487 L .5609 .61793 L p F P
0 g
s
.651 .758 .928 r
.55804 .61487 m .54702 .61819 L .54413 .61513 L p F P
0 g
s
.65 .758 .928 r
.37756 .61821 m .38829 .61489 L .39142 .61795 L p F P
0 g
s
.65 .758 .928 r
.38829 .61489 m .37756 .61821 L .37441 .61515 L p F P
0 g
s
.651 .758 .928 r
.73038 .6178 m .74171 .61448 L .74428 .61753 L p F P
0 g
s
.651 .758 .928 r
.74171 .61448 m .73038 .6178 L .72778 .61475 L p F P
0 g
s
.65 .758 .928 r
.22194 .61792 m .23241 .61461 L .23578 .61767 L p F P
0 g
s
.65 .757 .928 r
.23241 .61461 m .22194 .61792 L .21854 .61486 L p F P
0 g
s
.651 .758 .928 r
.5609 .61793 m .57195 .61461 L .57479 .61767 L p F P
0 g
s
.651 .758 .928 r
.57195 .61461 m .5609 .61793 L .55804 .61487 L p F P
0 g
s
.65 .758 .928 r
.39142 .61795 m .40218 .61464 L .40528 .6177 L p F P
0 g
s
.65 .758 .928 r
.40218 .61464 m .39142 .61795 L .38829 .61489 L p F P
0 g
s
.651 .758 .928 r
.74428 .61753 m .75564 .6142 L .7582 .61726 L p F P
0 g
s
.651 .758 .928 r
.75564 .6142 m .74428 .61753 L .74171 .61448 L p F P
0 g
s
.651 .758 .928 r
.57479 .61767 m .58586 .61435 L .58868 .61741 L p F P
0 g
s
.651 .758 .928 r
.58586 .61435 m .57479 .61767 L .57195 .61461 L p F P
0 g
s
.65 .758 .928 r
.23578 .61767 m .24627 .61436 L .24963 .61742 L p F P
0 g
s
.65 .758 .928 r
.24627 .61436 m .23578 .61767 L .23241 .61461 L p F P
0 g
s
.65 .758 .928 r
.40528 .6177 m .41607 .61438 L .41915 .61744 L p F P
0 g
s
.65 .758 .928 r
.41607 .61438 m .40528 .6177 L .40218 .61464 L p F P
0 g
s
.651 .758 .928 r
.7582 .61726 m .76958 .61393 L .77211 .61698 L p F P
0 g
s
.651 .758 .928 r
.76958 .61393 m .7582 .61726 L .75564 .6142 L p F P
0 g
s
.65 .757 .928 r
.08011 .6173 m .09034 .614 L .09394 .61706 L p F P
0 g
s
.65 .757 .928 r
.09034 .614 m .08011 .6173 L .0765 .61424 L p F P
0 g
s
.651 .758 .928 r
.59977 .61409 m .58868 .61741 L .58586 .61435 L p F P
0 g
s
.651 .758 .928 r
.58868 .61741 m .59977 .61409 L .60257 .61715 L p F P
0 g
s
.65 .758 .928 r
.24963 .61742 m .26015 .61411 L .26348 .61717 L p F P
0 g
s
.65 .758 .928 r
.26015 .61411 m .24963 .61742 L .24627 .61436 L p F P
0 g
s
.65 .758 .928 r
.41915 .61744 m .42996 .61413 L .43302 .61719 L p F P
0 g
s
.65 .758 .928 r
.42996 .61413 m .41915 .61744 L .41607 .61438 L p F P
0 g
s
.651 .759 .928 r
.77211 .61698 m .78352 .61365 L .78603 .6167 L p F P
0 g
s
.651 .758 .928 r
.78352 .61365 m .77211 .61698 L .76958 .61393 L p F P
0 g
s
.65 .757 .928 r
.09394 .61706 m .10419 .61376 L .10777 .61683 L p F P
0 g
s
.65 .757 .928 r
.10419 .61376 m .09394 .61706 L .09034 .614 L p F P
0 g
s
.651 .758 .928 r
.60257 .61715 m .61369 .61383 L .61647 .61689 L p F P
0 g
s
.651 .758 .928 r
.61369 .61383 m .60257 .61715 L .59977 .61409 L p F P
0 g
s
.65 .758 .928 r
.26348 .61717 m .27402 .61386 L .27733 .61692 L p F P
0 g
s
.65 .758 .928 r
.27402 .61386 m .26348 .61717 L .26015 .61411 L p F P
0 g
s
.65 .758 .928 r
.43302 .61719 m .44386 .61387 L .4469 .61693 L p F P
0 g
s
.65 .758 .928 r
.44386 .61387 m .43302 .61719 L .42996 .61413 L p F P
0 g
s
.651 .759 .928 r
.78603 .6167 m .79746 .61336 L .79995 .61641 L p F P
0 g
s
.651 .759 .928 r
.79746 .61336 m .78603 .6167 L .78352 .61365 L p F P
0 g
s
.65 .757 .928 r
.10777 .61683 m .11805 .61352 L .1216 .61658 L p F P
0 g
s
.65 .757 .928 r
.11805 .61352 m .10777 .61683 L .10419 .61376 L p F P
0 g
s
.651 .758 .928 r
.62762 .61357 m .61647 .61689 L .61369 .61383 L p F P
0 g
s
.651 .758 .928 r
.61647 .61689 m .62762 .61357 L .63037 .61662 L p F P
0 g
s
.65 .758 .928 r
.27733 .61692 m .2879 .61361 L .29119 .61667 L p F P
0 g
s
.65 .758 .928 r
.2879 .61361 m .27733 .61692 L .27402 .61386 L p F P
0 g
s
.65 .758 .928 r
.4469 .61693 m .45776 .61361 L .46078 .61668 L p F P
0 g
s
.65 .758 .928 r
.45776 .61361 m .4469 .61693 L .44386 .61387 L p F P
0 g
s
.651 .759 .928 r
.8114 .61308 m .79995 .61641 L .79746 .61336 L p F P
0 g
s
.65 .757 .928 r
.1216 .61658 m .13191 .61328 L .13544 .61634 L p F P
0 g
s
.65 .757 .928 r
.13191 .61328 m .1216 .61658 L .11805 .61352 L p F P
0 g
s
.651 .758 .928 r
.63037 .61662 m .64154 .6133 L .64428 .61636 L p F P
0 g
s
.651 .758 .928 r
.64154 .6133 m .63037 .61662 L .62762 .61357 L p F P
0 g
s
.65 .758 .928 r
.29119 .61667 m .30178 .61335 L .30505 .61642 L p F P
0 g
s
.65 .758 .928 r
.30178 .61335 m .29119 .61667 L .2879 .61361 L p F P
0 g
s
.65 .758 .928 r
.46078 .61668 m .47166 .61336 L .47466 .61642 L p F P
0 g
s
.65 .758 .928 r
.47166 .61336 m .46078 .61668 L .45776 .61361 L p F P
0 g
s
.65 .757 .928 r
.13544 .61634 m .14577 .61303 L .14928 .6161 L p F P
0 g
s
.65 .757 .928 r
.14577 .61303 m .13544 .61634 L .13191 .61328 L p F P
0 g
s
0 0 .271 r
.40292 .22046 m .40288 .22057 L .403 .21593 L p F P
0 g
s
0 0 .271 r
.403 .21593 m .40305 .21582 L .40292 .22046 L p F P
0 g
s
.764 .494 .526 r
.40272 .22054 m .40288 .22057 L .403 .21593 L p F P
0 g
s
.764 .494 .526 r
.403 .21593 m .40284 .2159 L .40272 .22054 L p F P
0 g
s
.651 .758 .928 r
.64428 .61636 m .65547 .61304 L .65819 .6161 L p F P
0 g
s
.651 .758 .928 r
.65547 .61304 m .64428 .61636 L .64154 .6133 L p F P
0 g
s
.65 .758 .928 r
.30505 .61642 m .31567 .6131 L .31891 .61616 L p F P
0 g
s
.65 .758 .928 r
.31567 .6131 m .30505 .61642 L .30178 .61335 L p F P
0 g
s
.65 .758 .928 r
.47466 .61642 m .48557 .6131 L .48855 .61616 L p F P
0 g
s
.65 .758 .928 r
.48557 .6131 m .47466 .61642 L .47166 .61336 L p F P
0 g
s
.651 .758 .928 r
.65819 .6161 m .66941 .61277 L .6721 .61583 L p F P
0 g
s
.651 .758 .928 r
.66941 .61277 m .65819 .6161 L .65547 .61304 L p F P
0 g
s
.65 .757 .928 r
.14928 .6161 m .15964 .61279 L .16313 .61585 L p F P
0 g
s
.65 .757 .928 r
.15964 .61279 m .14928 .6161 L .14577 .61303 L p F P
0 g
s
.65 .758 .928 r
.48855 .61616 m .49948 .61284 L .50244 .61591 L p F P
0 g
s
.65 .758 .928 r
.49948 .61284 m .48855 .61616 L .48557 .6131 L p F P
0 g
s
.65 .758 .928 r
.31891 .61616 m .32956 .61285 L .33278 .61591 L p F P
0 g
s
.65 .758 .928 r
.32956 .61285 m .31891 .61616 L .31567 .6131 L p F P
0 g
s
.651 .758 .928 r
.6721 .61583 m .68334 .6125 L .68601 .61556 L p F P
0 g
s
.651 .758 .928 r
.68334 .6125 m .6721 .61583 L .66941 .61277 L p F P
0 g
s
.65 .757 .928 r
.16313 .61585 m .17351 .61254 L .17697 .61561 L p F P
0 g
s
.65 .757 .928 r
.17351 .61254 m .16313 .61585 L .15964 .61279 L p F P
0 g
s
.65 .758 .928 r
.50244 .61591 m .5134 .61258 L .51633 .61565 L p F P
0 g
s
.65 .758 .928 r
.5134 .61258 m .50244 .61591 L .49948 .61284 L p F P
0 g
s
.65 .758 .928 r
.33278 .61591 m .34345 .61259 L .34665 .61566 L p F P
0 g
s
.65 .758 .928 r
.34345 .61259 m .33278 .61591 L .32956 .61285 L p F P
0 g
s
.651 .758 .928 r
.68601 .61556 m .69728 .61223 L .69993 .6153 L p F P
0 g
s
.651 .758 .928 r
.69728 .61223 m .68601 .61556 L .68334 .6125 L p F P
0 g
s
.65 .757 .928 r
.17697 .61561 m .18738 .61229 L .19083 .61536 L p F P
0 g
s
.65 .757 .928 r
.18738 .61229 m .17697 .61561 L .17351 .61254 L p F P
0 g
s
.65 .758 .928 r
.51633 .61565 m .52732 .61233 L .53023 .61539 L p F P
0 g
s
.65 .758 .928 r
.52732 .61233 m .51633 .61565 L .5134 .61258 L p F P
0 g
s
.65 .758 .928 r
.34665 .61566 m .35735 .61234 L .36053 .6154 L p F P
0 g
s
.65 .758 .928 r
.35735 .61234 m .34665 .61566 L .34345 .61259 L p F P
0 g
s
.651 .758 .928 r
.69993 .6153 m .71123 .61196 L .71385 .61503 L p F P
0 g
s
.651 .758 .928 r
.71123 .61196 m .69993 .6153 L .69728 .61223 L p F P
0 g
s
.65 .757 .928 r
.19083 .61536 m .20126 .61204 L .20468 .61511 L p F P
0 g
s
.65 .757 .928 r
.20126 .61204 m .19083 .61536 L .18738 .61229 L p F P
0 g
s
.65 .758 .928 r
.53023 .61539 m .54124 .61207 L .54413 .61513 L p F P
0 g
s
.65 .758 .928 r
.54124 .61207 m .53023 .61539 L .52732 .61233 L p F P
0 g
s
.65 .758 .928 r
.36053 .6154 m .37125 .61208 L .37441 .61515 L p F P
0 g
s
.65 .758 .928 r
.37125 .61208 m .36053 .6154 L .35735 .61234 L p F P
0 g
s
.651 .758 .928 r
.71385 .61503 m .72517 .61169 L .72778 .61475 L p F P
0 g
s
.651 .758 .928 r
.72517 .61169 m .71385 .61503 L .71123 .61196 L p F P
0 g
s
.65 .757 .928 r
.20468 .61511 m .21514 .61179 L .21854 .61486 L p F P
0 g
s
.65 .757 .928 r
.21514 .61179 m .20468 .61511 L .20126 .61204 L p F P
0 g
s
.651 .758 .928 r
.54413 .61513 m .55517 .61181 L .55804 .61487 L p F P
0 g
s
.651 .758 .928 r
.55517 .61181 m .54413 .61513 L .54124 .61207 L p F P
0 g
s
.65 .758 .928 r
.37441 .61515 m .38515 .61183 L .38829 .61489 L p F P
0 g
s
.65 .758 .928 r
.38515 .61183 m .37441 .61515 L .37125 .61208 L p F P
0 g
s
.651 .758 .928 r
.72778 .61475 m .73912 .61142 L .74171 .61448 L p F P
0 g
s
.651 .758 .928 r
.73912 .61142 m .72778 .61475 L .72517 .61169 L p F P
0 g
s
.65 .757 .928 r
.21854 .61486 m .22903 .61154 L .23241 .61461 L p F P
0 g
s
.65 .757 .928 r
.22903 .61154 m .21854 .61486 L .21514 .61179 L p F P
0 g
s
.651 .758 .928 r
.55804 .61487 m .5691 .61155 L .57195 .61461 L p F P
0 g
s
.651 .758 .928 r
.5691 .61155 m .55804 .61487 L .55517 .61181 L p F P
0 g
s
.65 .758 .928 r
.38829 .61489 m .39906 .61157 L .40218 .61464 L p F P
0 g
s
.65 .758 .928 r
.39906 .61157 m .38829 .61489 L .38515 .61183 L p F P
0 g
s
.651 .758 .928 r
.74171 .61448 m .75308 .61114 L .75564 .6142 L p F P
0 g
s
.651 .758 .928 r
.75308 .61114 m .74171 .61448 L .73912 .61142 L p F P
0 g
s
.65 .758 .928 r
.23241 .61461 m .24291 .61129 L .24627 .61436 L p F P
0 g
s
.65 .757 .928 r
.24291 .61129 m .23241 .61461 L .22903 .61154 L p F P
0 g
s
.651 .758 .928 r
.57195 .61461 m .58303 .61128 L .58586 .61435 L p F P
0 g
s
.651 .758 .928 r
.58303 .61128 m .57195 .61461 L .5691 .61155 L p F P
0 g
s
.65 .758 .928 r
.40218 .61464 m .41297 .61131 L .41607 .61438 L p F P
0 g
s
.65 .758 .928 r
.41297 .61131 m .40218 .61464 L .39906 .61157 L p F P
0 g
s
.651 .758 .928 r
.75564 .6142 m .76703 .61087 L .76958 .61393 L p F P
0 g
s
.651 .758 .928 r
.76703 .61087 m .75564 .6142 L .75308 .61114 L p F P
0 g
s
.65 .757 .928 r
.0765 .61424 m .08674 .61093 L .09034 .614 L p F P
0 g
s
.65 .757 .928 r
.08674 .61093 m .0765 .61424 L .07287 .61117 L p F P
0 g
s
.651 .758 .928 r
.58586 .61435 m .59697 .61102 L .59977 .61409 L p F P
0 g
s
.651 .758 .928 r
.59697 .61102 m .58586 .61435 L .58303 .61128 L p F P
0 g
s
.65 .758 .928 r
.24627 .61436 m .25681 .61104 L .26015 .61411 L p F P
0 g
s
.65 .758 .928 r
.25681 .61104 m .24627 .61436 L .24291 .61129 L p F P
0 g
s
.65 .758 .928 r
.41607 .61438 m .42689 .61106 L .42996 .61413 L p F P
0 g
s
.65 .758 .928 r
.42689 .61106 m .41607 .61438 L .41297 .61131 L p F P
0 g
s
.651 .758 .928 r
.76958 .61393 m .781 .61059 L .78352 .61365 L p F P
0 g
s
.651 .758 .928 r
.781 .61059 m .76958 .61393 L .76703 .61087 L p F P
0 g
s
.65 .757 .928 r
.09034 .614 m .10061 .61069 L .10419 .61376 L p F P
0 g
s
.65 .757 .928 r
.10061 .61069 m .09034 .614 L .08674 .61093 L p F P
0 g
s
.651 .758 .928 r
.61091 .61076 m .59977 .61409 L .59697 .61102 L p F P
0 g
s
.651 .758 .928 r
.59977 .61409 m .61091 .61076 L .61369 .61383 L p F P
0 g
s
.65 .758 .928 r
.26015 .61411 m .2707 .61079 L .27402 .61386 L p F P
0 g
s
.65 .758 .928 r
.2707 .61079 m .26015 .61411 L .25681 .61104 L p F P
0 g
s
.65 .758 .928 r
.42996 .61413 m .4408 .6108 L .44386 .61387 L p F P
0 g
s
.65 .758 .928 r
.4408 .6108 m .42996 .61413 L .42689 .61106 L p F P
0 g
s
.651 .759 .928 r
.78352 .61365 m .79496 .6103 L .79746 .61336 L p F P
0 g
s
.651 .759 .928 r
.79496 .6103 m .78352 .61365 L .781 .61059 L p F P
0 g
s
.65 .757 .928 r
.10419 .61376 m .11449 .61045 L .11805 .61352 L p F P
0 g
s
.65 .757 .928 r
.11449 .61045 m .10419 .61376 L .10061 .61069 L p F P
0 g
s
0 0 .272 r
.40279 .22512 m .40275 .22521 L .40288 .22057 L p F P
0 g
s
0 0 .272 r
.40288 .22057 m .40292 .22046 L .40279 .22512 L p F P
0 g
s
.764 .494 .526 r
.40261 .22519 m .40275 .22521 L .40288 .22057 L p F P
0 g
s
.764 .494 .526 r
.40288 .22057 m .40272 .22054 L .40261 .22519 L p F P
0 g
s
.651 .758 .928 r
.61369 .61383 m .62485 .6105 L .62762 .61357 L p F P
0 g
s
.651 .758 .928 r
.62485 .6105 m .61369 .61383 L .61091 .61076 L p F P
0 g
s
.65 .758 .928 r
.27402 .61386 m .2846 .61053 L .2879 .61361 L p F P
0 g
s
.65 .758 .928 r
.2846 .61053 m .27402 .61386 L .2707 .61079 L p F P
0 g
s
.65 .758 .928 r
.44386 .61387 m .45473 .61054 L .45776 .61361 L p F P
0 g
s
.65 .758 .928 r
.45473 .61054 m .44386 .61387 L .4408 .6108 L p F P
0 g
s
.651 .759 .928 r
.79746 .61336 m .80893 .61002 L .8114 .61308 L p F P
0 g
s
.651 .759 .928 r
.80893 .61002 m .79746 .61336 L .79496 .6103 L p F P
0 g
s
.65 .757 .928 r
.11805 .61352 m .12837 .61021 L .13191 .61328 L p F P
0 g
s
.65 .757 .928 r
.12837 .61021 m .11805 .61352 L .11449 .61045 L p F P
0 g
s
.651 .758 .928 r
.62762 .61357 m .6388 .61023 L .64154 .6133 L p F P
0 g
s
.651 .758 .928 r
.6388 .61023 m .62762 .61357 L .62485 .6105 L p F P
0 g
s
.65 .758 .928 r
.29851 .61028 m .2879 .61361 L .2846 .61053 L p F P
0 g
s
.65 .758 .928 r
.2879 .61361 m .29851 .61028 L .30178 .61335 L p F P
0 g
s
.65 .758 .928 r
.45776 .61361 m .46865 .61029 L .47166 .61336 L p F P
0 g
s
.65 .758 .928 r
.46865 .61029 m .45776 .61361 L .45473 .61054 L p F P
0 g
s
.651 .759 .928 r
.8229 .60973 m .8114 .61308 L .80893 .61002 L p F P
0 g
s
.65 .757 .928 r
.13191 .61328 m .14225 .60996 L .14577 .61303 L p F P
0 g
s
.65 .757 .928 r
.14225 .60996 m .13191 .61328 L .12837 .61021 L p F P
0 g
s
.651 .758 .928 r
.64154 .6133 m .65275 .60997 L .65547 .61304 L p F P
0 g
s
.651 .758 .928 r
.65275 .60997 m .64154 .6133 L .6388 .61023 L p F P
0 g
s
.65 .758 .928 r
.30178 .61335 m .31241 .61003 L .31567 .6131 L p F P
0 g
s
.65 .758 .928 r
.31241 .61003 m .30178 .61335 L .29851 .61028 L p F P
0 g
s
.65 .758 .928 r
.47166 .61336 m .48258 .61003 L .48557 .6131 L p F P
0 g
s
.65 .758 .928 r
.48258 .61003 m .47166 .61336 L .46865 .61029 L p F P
0 g
s
.65 .757 .928 r
.14577 .61303 m .15614 .60971 L .15964 .61279 L p F P
0 g
s
.65 .757 .928 r
.15614 .60971 m .14577 .61303 L .14225 .60996 L p F P
0 g
s
.651 .758 .928 r
.65547 .61304 m .6667 .6097 L .66941 .61277 L p F P
0 g
s
.651 .758 .928 r
.6667 .6097 m .65547 .61304 L .65275 .60997 L p F P
0 g
s
.65 .758 .928 r
.31567 .6131 m .32632 .60977 L .32956 .61285 L p F P
0 g
s
.65 .758 .928 r
.32632 .60977 m .31567 .6131 L .31241 .61003 L p F P
0 g
s
.65 .758 .928 r
.48557 .6131 m .49652 .60977 L .49948 .61284 L p F P
0 g
s
.65 .758 .928 r
.49652 .60977 m .48557 .6131 L .48258 .61003 L p F P
0 g
s
.651 .758 .928 r
.66941 .61277 m .68066 .60943 L .68334 .6125 L p F P
0 g
s
.651 .758 .928 r
.68066 .60943 m .66941 .61277 L .6667 .6097 L p F P
0 g
s
.65 .757 .928 r
.15964 .61279 m .17003 .60947 L .17351 .61254 L p F P
0 g
s
.65 .757 .928 r
.17003 .60947 m .15964 .61279 L .15614 .60971 L p F P
0 g
s
.65 .758 .928 r
.49948 .61284 m .51045 .60951 L .5134 .61258 L p F P
0 g
s
.65 .758 .928 r
.51045 .60951 m .49948 .61284 L .49652 .60977 L p F P
0 g
s
.65 .758 .928 r
.32956 .61285 m .34024 .60952 L .34345 .61259 L p F P
0 g
s
.65 .758 .928 r
.34024 .60952 m .32956 .61285 L .32632 .60977 L p F P
0 g
s
.651 .758 .928 r
.68334 .6125 m .69462 .60916 L .69728 .61223 L p F P
0 g
s
.651 .758 .928 r
.69462 .60916 m .68334 .6125 L .68066 .60943 L p F P
0 g
s
.65 .757 .928 r
.17351 .61254 m .18392 .60922 L .18738 .61229 L p F P
0 g
s
.65 .757 .928 r
.18392 .60922 m .17351 .61254 L .17003 .60947 L p F P
0 g
s
.65 .758 .928 r
.5134 .61258 m .52439 .60925 L .52732 .61233 L p F P
0 g
s
.65 .758 .928 r
.52439 .60925 m .5134 .61258 L .51045 .60951 L p F P
0 g
s
.65 .758 .928 r
.34345 .61259 m .35416 .60926 L .35735 .61234 L p F P
0 g
s
.65 .758 .928 r
.35416 .60926 m .34345 .61259 L .34024 .60952 L p F P
0 g
s
.651 .758 .928 r
.69728 .61223 m .70859 .60889 L .71123 .61196 L p F P
0 g
s
.651 .758 .928 r
.70859 .60889 m .69728 .61223 L .69462 .60916 L p F P
0 g
s
.65 .757 .928 r
.18738 .61229 m .19782 .60897 L .20126 .61204 L p F P
0 g
s
.65 .757 .928 r
.19782 .60897 m .18738 .61229 L .18392 .60922 L p F P
0 g
s
.65 .758 .928 r
.52732 .61233 m .53834 .60899 L .54124 .61207 L p F P
0 g
s
.65 .758 .928 r
.53834 .60899 m .52732 .61233 L .52439 .60925 L p F P
0 g
s
.65 .758 .928 r
.35735 .61234 m .36808 .60901 L .37125 .61208 L p F P
0 g
s
.65 .758 .928 r
.36808 .60901 m .35735 .61234 L .35416 .60926 L p F P
0 g
s
.651 .758 .928 r
.71123 .61196 m .72256 .60862 L .72517 .61169 L p F P
0 g
s
.651 .758 .928 r
.72256 .60862 m .71123 .61196 L .70859 .60889 L p F P
0 g
s
.65 .757 .928 r
.20126 .61204 m .21173 .60872 L .21514 .61179 L p F P
0 g
s
.65 .757 .928 r
.21173 .60872 m .20126 .61204 L .19782 .60897 L p F P
0 g
s
.651 .758 .928 r
.54124 .61207 m .55228 .60873 L .55517 .61181 L p F P
0 g
s
.651 .758 .928 r
.55228 .60873 m .54124 .61207 L .53834 .60899 L p F P
0 g
s
.65 .758 .928 r
.37125 .61208 m .382 .60875 L .38515 .61183 L p F P
0 g
s
.65 .758 .928 r
.382 .60875 m .37125 .61208 L .36808 .60901 L p F P
0 g
s
.651 .758 .928 r
.72517 .61169 m .73653 .60835 L .73912 .61142 L p F P
0 g
s
.651 .758 .928 r
.73653 .60835 m .72517 .61169 L .72256 .60862 L p F P
0 g
s
.65 .757 .928 r
.21514 .61179 m .22563 .60846 L .22903 .61154 L p F P
0 g
s
.65 .757 .928 r
.22563 .60846 m .21514 .61179 L .21173 .60872 L p F P
0 g
s
.651 .758 .928 r
.55517 .61181 m .56624 .60847 L .5691 .61155 L p F P
0 g
s
.651 .758 .928 r
.56624 .60847 m .55517 .61181 L .55228 .60873 L p F P
0 g
s
.65 .758 .928 r
.38515 .61183 m .39593 .60849 L .39906 .61157 L p F P
0 g
s
.65 .758 .928 r
.39593 .60849 m .38515 .61183 L .382 .60875 L p F P
0 g
s
.651 .758 .928 r
.73912 .61142 m .75051 .60807 L .75308 .61114 L p F P
0 g
s
.651 .758 .928 r
.75051 .60807 m .73912 .61142 L .73653 .60835 L p F P
0 g
s
.65 .757 .928 r
.22903 .61154 m .23954 .60821 L .24291 .61129 L p F P
0 g
s
.65 .757 .928 r
.23954 .60821 m .22903 .61154 L .22563 .60846 L p F P
0 g
s
.651 .758 .928 r
.5691 .61155 m .58019 .60821 L .58303 .61128 L p F P
0 g
s
.651 .758 .928 r
.58019 .60821 m .5691 .61155 L .56624 .60847 L p F P
0 g
s
.65 .758 .928 r
.39906 .61157 m .40987 .60824 L .41297 .61131 L p F P
0 g
s
.65 .758 .928 r
.40987 .60824 m .39906 .61157 L .39593 .60849 L p F P
0 g
s
.651 .758 .928 r
.75308 .61114 m .76449 .60779 L .76703 .61087 L p F P
0 g
s
.651 .758 .928 r
.76449 .60779 m .75308 .61114 L .75051 .60807 L p F P
0 g
s
.65 .757 .928 r
.07287 .61117 m .08312 .60785 L .08674 .61093 L p F P
0 g
s
.65 .757 .928 r
.08312 .60785 m .07287 .61117 L .06923 .60809 L p F P
0 g
s
0 0 .272 r
.40266 .22978 m .40262 .22987 L .40275 .22521 L p F P
0 g
s
0 0 .272 r
.40275 .22521 m .40279 .22512 L .40266 .22978 L p F P
0 g
s
.764 .494 .526 r
.40249 .22985 m .40262 .22987 L .40275 .22521 L p F P
0 g
s
.764 .494 .526 r
.40275 .22521 m .40261 .22519 L .40249 .22985 L p F P
0 g
s
.651 .758 .928 r
.58303 .61128 m .59415 .60795 L .59697 .61102 L p F P
0 g
s
.651 .758 .928 r
.59415 .60795 m .58303 .61128 L .58019 .60821 L p F P
0 g
s
.65 .758 .928 r
.24291 .61129 m .25346 .60796 L .25681 .61104 L p F P
0 g
s
.65 .758 .928 r
.25346 .60796 m .24291 .61129 L .23954 .60821 L p F P
0 g
s
.65 .758 .928 r
.41297 .61131 m .4238 .60798 L .42689 .61106 L p F P
0 g
s
.65 .758 .928 r
.4238 .60798 m .41297 .61131 L .40987 .60824 L p F P
0 g
s
.651 .758 .928 r
.76703 .61087 m .77847 .60751 L .781 .61059 L p F P
0 g
s
.651 .758 .928 r
.77847 .60751 m .76703 .61087 L .76449 .60779 L p F P
0 g
s
.65 .757 .928 r
.08674 .61093 m .09701 .60761 L .10061 .61069 L p F P
0 g
s
.65 .757 .928 r
.09701 .60761 m .08674 .61093 L .08312 .60785 L p F P
0 g
s
.651 .758 .928 r
.59697 .61102 m .60811 .60768 L .61091 .61076 L p F P
0 g
s
.651 .758 .928 r
.60811 .60768 m .59697 .61102 L .59415 .60795 L p F P
0 g
s
.65 .758 .928 r
.25681 .61104 m .26737 .60771 L .2707 .61079 L p F P
0 g
s
.65 .758 .928 r
.26737 .60771 m .25681 .61104 L .25346 .60796 L p F P
0 g
s
.65 .758 .928 r
.42689 .61106 m .43774 .60772 L .4408 .6108 L p F P
0 g
s
.65 .758 .928 r
.43774 .60772 m .42689 .61106 L .4238 .60798 L p F P
0 g
s
.651 .759 .928 r
.781 .61059 m .79245 .60723 L .79496 .6103 L p F P
0 g
s
.651 .758 .928 r
.79245 .60723 m .781 .61059 L .77847 .60751 L p F P
0 g
s
.65 .757 .928 r
.10061 .61069 m .11091 .60737 L .11449 .61045 L p F P
0 g
s
.65 .757 .928 r
.11091 .60737 m .10061 .61069 L .09701 .60761 L p F P
0 g
s
.651 .758 .928 r
.62208 .60742 m .61091 .61076 L .60811 .60768 L p F P
0 g
s
.651 .758 .928 r
.61091 .61076 m .62208 .60742 L .62485 .6105 L p F P
0 g
s
.65 .758 .928 r
.2707 .61079 m .28129 .60745 L .2846 .61053 L p F P
0 g
s
.65 .758 .928 r
.28129 .60745 m .2707 .61079 L .26737 .60771 L p F P
0 g
s
.65 .758 .928 r
.4408 .6108 m .45169 .60746 L .45473 .61054 L p F P
0 g
s
.65 .758 .928 r
.45169 .60746 m .4408 .6108 L .43774 .60772 L p F P
0 g
s
.651 .759 .928 r
.79496 .6103 m .80644 .60694 L .80893 .61002 L p F P
0 g
s
.651 .759 .928 r
.80644 .60694 m .79496 .6103 L .79245 .60723 L p F P
0 g
s
.65 .757 .928 r
.11449 .61045 m .12481 .60712 L .12837 .61021 L p F P
0 g
s
.65 .757 .928 r
.12481 .60712 m .11449 .61045 L .11091 .60737 L p F P
0 g
s
.651 .758 .928 r
.62485 .6105 m .63605 .60715 L .6388 .61023 L p F P
0 g
s
.651 .758 .928 r
.63605 .60715 m .62485 .6105 L .62208 .60742 L p F P
0 g
s
.65 .758 .928 r
.2846 .61053 m .29522 .6072 L .29851 .61028 L p F P
0 g
s
.65 .758 .928 r
.29522 .6072 m .2846 .61053 L .28129 .60745 L p F P
0 g
s
.65 .758 .928 r
.45473 .61054 m .46563 .6072 L .46865 .61029 L p F P
0 g
s
.65 .758 .928 r
.46563 .6072 m .45473 .61054 L .45169 .60746 L p F P
0 g
s
.651 .759 .928 r
.80893 .61002 m .82043 .60666 L .8229 .60973 L p F P
0 g
s
.651 .759 .928 r
.82043 .60666 m .80893 .61002 L .80644 .60694 L p F P
0 g
s
.65 .757 .928 r
.12837 .61021 m .13872 .60688 L .14225 .60996 L p F P
0 g
s
.65 .757 .928 r
.13872 .60688 m .12837 .61021 L .12481 .60712 L p F P
0 g
s
.651 .758 .928 r
.65002 .60689 m .6388 .61023 L .63605 .60715 L p F P
0 g
s
.651 .758 .928 r
.6388 .61023 m .65002 .60689 L .65275 .60997 L p F P
0 g
s
.65 .758 .928 r
.30915 .60694 m .29851 .61028 L .29522 .6072 L p F P
0 g
s
.65 .758 .928 r
.29851 .61028 m .30915 .60694 L .31241 .61003 L p F P
0 g
s
.65 .758 .928 r
.46865 .61029 m .47958 .60695 L .48258 .61003 L p F P
0 g
s
.65 .758 .928 r
.47958 .60695 m .46865 .61029 L .46563 .6072 L p F P
0 g
s
.651 .759 .928 r
.83443 .60636 m .8229 .60973 L .82043 .60666 L p F P
0 g
s
.65 .757 .928 r
.14225 .60996 m .15263 .60663 L .15614 .60971 L p F P
0 g
s
.65 .757 .928 r
.15263 .60663 m .14225 .60996 L .13872 .60688 L p F P
0 g
s
.651 .758 .928 r
.65275 .60997 m .664 .60662 L .6667 .6097 L p F P
0 g
s
.651 .758 .928 r
.664 .60662 m .65275 .60997 L .65002 .60689 L p F P
0 g
s
.65 .758 .928 r
.31241 .61003 m .32308 .60669 L .32632 .60977 L p F P
0 g
s
.65 .758 .928 r
.32308 .60669 m .31241 .61003 L .30915 .60694 L p F P
0 g
s
.65 .758 .928 r
.48258 .61003 m .49354 .60669 L .49652 .60977 L p F P
0 g
s
.65 .758 .928 r
.49354 .60669 m .48258 .61003 L .47958 .60695 L p F P
0 g
s
.651 .758 .928 r
.6667 .6097 m .67798 .60635 L .68066 .60943 L p F P
0 g
s
.651 .758 .928 r
.67798 .60635 m .6667 .6097 L .664 .60662 L p F P
0 g
s
.65 .757 .928 r
.15614 .60971 m .16654 .60638 L .17003 .60947 L p F P
0 g
s
.65 .757 .928 r
.16654 .60638 m .15614 .60971 L .15263 .60663 L p F P
0 g
s
.65 .758 .928 r
.49652 .60977 m .5075 .60643 L .51045 .60951 L p F P
0 g
s
.65 .758 .928 r
.5075 .60643 m .49652 .60977 L .49354 .60669 L p F P
0 g
s
.65 .758 .928 r
.32632 .60977 m .33702 .60643 L .34024 .60952 L p F P
0 g
s
.65 .758 .928 r
.33702 .60643 m .32632 .60977 L .32308 .60669 L p F P
0 g
s
.651 .758 .928 r
.68066 .60943 m .69196 .60608 L .69462 .60916 L p F P
0 g
s
.651 .758 .928 r
.69196 .60608 m .68066 .60943 L .67798 .60635 L p F P
0 g
s
.65 .757 .928 r
.17003 .60947 m .18046 .60613 L .18392 .60922 L p F P
0 g
s
.65 .757 .928 r
.18046 .60613 m .17003 .60947 L .16654 .60638 L p F P
0 g
s
.65 .758 .928 r
.51045 .60951 m .52146 .60617 L .52439 .60925 L p F P
0 g
s
.65 .758 .928 r
.52146 .60617 m .51045 .60951 L .5075 .60643 L p F P
0 g
s
.65 .758 .928 r
.34024 .60952 m .35096 .60618 L .35416 .60926 L p F P
0 g
s
.65 .758 .928 r
.35096 .60618 m .34024 .60952 L .33702 .60643 L p F P
0 g
s
.651 .758 .928 r
.69462 .60916 m .70595 .60581 L .70859 .60889 L p F P
0 g
s
.651 .758 .928 r
.70595 .60581 m .69462 .60916 L .69196 .60608 L p F P
0 g
s
.65 .757 .928 r
.18392 .60922 m .19438 .60588 L .19782 .60897 L p F P
0 g
s
.65 .757 .928 r
.19438 .60588 m .18392 .60922 L .18046 .60613 L p F P
0 g
s
.65 .758 .928 r
.52439 .60925 m .53543 .60591 L .53834 .60899 L p F P
0 g
s
.65 .758 .928 r
.53543 .60591 m .52439 .60925 L .52146 .60617 L p F P
0 g
s
.65 .758 .928 r
.35416 .60926 m .3649 .60592 L .36808 .60901 L p F P
0 g
s
.65 .758 .928 r
.3649 .60592 m .35416 .60926 L .35096 .60618 L p F P
0 g
s
.651 .758 .928 r
.70859 .60889 m .71994 .60554 L .72256 .60862 L p F P
0 g
s
.651 .758 .928 r
.71994 .60554 m .70859 .60889 L .70595 .60581 L p F P
0 g
s
.65 .757 .928 r
.19782 .60897 m .2083 .60563 L .21173 .60872 L p F P
0 g
s
.65 .757 .928 r
.2083 .60563 m .19782 .60897 L .19438 .60588 L p F P
0 g
s
.651 .758 .928 r
.53834 .60899 m .54939 .60564 L .55228 .60873 L p F P
0 g
s
.651 .758 .928 r
.54939 .60564 m .53834 .60899 L .53543 .60591 L p F P
0 g
s
.65 .758 .928 r
.36808 .60901 m .37885 .60566 L .382 .60875 L p F P
0 g
s
.65 .758 .928 r
.37885 .60566 m .36808 .60901 L .3649 .60592 L p F P
0 g
s
.651 .758 .928 r
.72256 .60862 m .73393 .60527 L .73653 .60835 L p F P
0 g
s
.651 .758 .928 r
.73393 .60527 m .72256 .60862 L .71994 .60554 L p F P
0 g
s
0 0 .272 r
.40253 .23446 m .4025 .23455 L .40262 .22987 L p F P
0 g
s
0 0 .272 r
.40262 .22987 m .40266 .22978 L .40253 .23446 L p F P
0 g
s
.764 .494 .526 r
.40237 .23452 m .4025 .23455 L .40262 .22987 L p F P
0 g
s
.764 .494 .526 r
.40262 .22987 m .40249 .22985 L .40237 .23452 L p F P
0 g
s
.65 .757 .928 r
.21173 .60872 m .22223 .60538 L .22563 .60846 L p F P
0 g
s
.65 .757 .928 r
.22223 .60538 m .21173 .60872 L .2083 .60563 L p F P
0 g
s
.651 .758 .928 r
.55228 .60873 m .56337 .60538 L .56624 .60847 L p F P
0 g
s
.651 .758 .928 r
.56337 .60538 m .55228 .60873 L .54939 .60564 L p F P
0 g
s
.65 .758 .928 r
.382 .60875 m .3928 .60541 L .39593 .60849 L p F P
0 g
s
.65 .758 .928 r
.3928 .60541 m .382 .60875 L .37885 .60566 L p F P
0 g
s
.651 .758 .928 r
.73653 .60835 m .74793 .60499 L .75051 .60807 L p F P
0 g
s
.651 .758 .928 r
.74793 .60499 m .73653 .60835 L .73393 .60527 L p F P
0 g
s
.65 .757 .928 r
.22563 .60846 m .23616 .60512 L .23954 .60821 L p F P
0 g
s
.65 .757 .928 r
.23616 .60512 m .22563 .60846 L .22223 .60538 L p F P
0 g
s
.651 .758 .928 r
.56624 .60847 m .57734 .60512 L .58019 .60821 L p F P
0 g
s
.651 .758 .928 r
.57734 .60512 m .56624 .60847 L .56337 .60538 L p F P
0 g
s
.65 .758 .928 r
.39593 .60849 m .40675 .60515 L .40987 .60824 L p F P
0 g
s
.65 .758 .928 r
.40675 .60515 m .39593 .60849 L .3928 .60541 L p F P
0 g
s
.651 .758 .928 r
.75051 .60807 m .76193 .60471 L .76449 .60779 L p F P
0 g
s
.651 .758 .928 r
.76193 .60471 m .75051 .60807 L .74793 .60499 L p F P
0 g
s
.65 .757 .928 r
.06923 .60809 m .07949 .60476 L .08312 .60785 L p F P
0 g
s
.65 .757 .928 r
.07949 .60476 m .06923 .60809 L .06558 .605 L p F P
0 g
s
.651 .758 .928 r
.58019 .60821 m .59132 .60486 L .59415 .60795 L p F P
0 g
s
.651 .758 .928 r
.59132 .60486 m .58019 .60821 L .57734 .60512 L p F P
0 g
s
.65 .758 .928 r
.23954 .60821 m .2501 .60487 L .25346 .60796 L p F P
0 g
s
.65 .757 .928 r
.2501 .60487 m .23954 .60821 L .23616 .60512 L p F P
0 g
s
.65 .758 .928 r
.40987 .60824 m .42071 .60489 L .4238 .60798 L p F P
0 g
s
.65 .758 .928 r
.42071 .60489 m .40987 .60824 L .40675 .60515 L p F P
0 g
s
.651 .758 .928 r
.76449 .60779 m .77593 .60443 L .77847 .60751 L p F P
0 g
s
.651 .758 .928 r
.77593 .60443 m .76449 .60779 L .76193 .60471 L p F P
0 g
s
.65 .757 .928 r
.08312 .60785 m .09341 .60452 L .09701 .60761 L p F P
0 g
s
.65 .757 .928 r
.09341 .60452 m .08312 .60785 L .07949 .60476 L p F P
0 g
s
.651 .758 .928 r
.59415 .60795 m .60531 .60459 L .60811 .60768 L p F P
0 g
s
.651 .758 .928 r
.60531 .60459 m .59415 .60795 L .59132 .60486 L p F P
0 g
s
.65 .758 .928 r
.25346 .60796 m .26403 .60462 L .26737 .60771 L p F P
0 g
s
.65 .758 .928 r
.26403 .60462 m .25346 .60796 L .2501 .60487 L p F P
0 g
s
.65 .758 .928 r
.4238 .60798 m .43467 .60463 L .43774 .60772 L p F P
0 g
s
.65 .758 .928 r
.43467 .60463 m .4238 .60798 L .42071 .60489 L p F P
0 g
s
.651 .758 .928 r
.77847 .60751 m .78994 .60415 L .79245 .60723 L p F P
0 g
s
.651 .758 .928 r
.78994 .60415 m .77847 .60751 L .77593 .60443 L p F P
0 g
s
.65 .757 .928 r
.09701 .60761 m .10733 .60428 L .11091 .60737 L p F P
0 g
s
.65 .757 .928 r
.10733 .60428 m .09701 .60761 L .09341 .60452 L p F P
0 g
s
.651 .758 .928 r
.60811 .60768 m .61929 .60433 L .62208 .60742 L p F P
0 g
s
.651 .758 .928 r
.61929 .60433 m .60811 .60768 L .60531 .60459 L p F P
0 g
s
.65 .758 .928 r
.26737 .60771 m .27798 .60436 L .28129 .60745 L p F P
0 g
s
.65 .758 .928 r
.27798 .60436 m .26737 .60771 L .26403 .60462 L p F P
0 g
s
.65 .758 .928 r
.43774 .60772 m .44864 .60437 L .45169 .60746 L p F P
0 g
s
.65 .758 .928 r
.44864 .60437 m .43774 .60772 L .43467 .60463 L p F P
0 g
s
.651 .759 .928 r
.79245 .60723 m .80395 .60386 L .80644 .60694 L p F P
0 g
s
.651 .759 .928 r
.80395 .60386 m .79245 .60723 L .78994 .60415 L p F P
0 g
s
.65 .757 .928 r
.11091 .60737 m .12125 .60403 L .12481 .60712 L p F P
0 g
s
.65 .757 .928 r
.12125 .60403 m .11091 .60737 L .10733 .60428 L p F P
0 g
s
.651 .758 .928 r
.63329 .60406 m .62208 .60742 L .61929 .60433 L p F P
0 g
s
.651 .758 .928 r
.62208 .60742 m .63329 .60406 L .63605 .60715 L p F P
0 g
s
.65 .758 .928 r
.28129 .60745 m .29192 .60411 L .29522 .6072 L p F P
0 g
s
.65 .758 .928 r
.29192 .60411 m .28129 .60745 L .27798 .60436 L p F P
0 g
s
.65 .758 .928 r
.45169 .60746 m .46261 .60411 L .46563 .6072 L p F P
0 g
s
.65 .758 .928 r
.46261 .60411 m .45169 .60746 L .44864 .60437 L p F P
0 g
s
.651 .759 .928 r
.80644 .60694 m .81796 .60357 L .82043 .60666 L p F P
0 g
s
.651 .759 .928 r
.81796 .60357 m .80644 .60694 L .80395 .60386 L p F P
0 g
s
.65 .757 .928 r
.12481 .60712 m .13518 .60378 L .13872 .60688 L p F P
0 g
s
.65 .757 .928 r
.13518 .60378 m .12481 .60712 L .12125 .60403 L p F P
0 g
s
.651 .758 .928 r
.63605 .60715 m .64728 .6038 L .65002 .60689 L p F P
0 g
s
.651 .758 .928 r
.64728 .6038 m .63605 .60715 L .63329 .60406 L p F P
0 g
s
.65 .758 .928 r
.29522 .6072 m .30587 .60385 L .30915 .60694 L p F P
0 g
s
.65 .758 .928 r
.30587 .60385 m .29522 .6072 L .29192 .60411 L p F P
0 g
s
.65 .758 .928 r
.46563 .6072 m .47658 .60385 L .47958 .60695 L p F P
0 g
s
.65 .758 .928 r
.47658 .60385 m .46563 .6072 L .46261 .60411 L p F P
0 g
s
.651 .759 .928 r
.82043 .60666 m .83198 .60328 L .83443 .60636 L p F P
0 g
s
.651 .759 .928 r
.83198 .60328 m .82043 .60666 L .81796 .60357 L p F P
0 g
s
.65 .757 .928 r
.13872 .60688 m .14911 .60354 L .15263 .60663 L p F P
0 g
s
.65 .757 .928 r
.14911 .60354 m .13872 .60688 L .13518 .60378 L p F P
0 g
s
.651 .758 .928 r
.66128 .60353 m .65002 .60689 L .64728 .6038 L p F P
0 g
s
.651 .758 .928 r
.65002 .60689 m .66128 .60353 L .664 .60662 L p F P
0 g
s
.65 .758 .928 r
.30915 .60694 m .31983 .60359 L .32308 .60669 L p F P
0 g
s
.65 .758 .928 r
.31983 .60359 m .30915 .60694 L .30587 .60385 L p F P
0 g
s
.65 .758 .928 r
.47958 .60695 m .49055 .60359 L .49354 .60669 L p F P
0 g
s
.65 .758 .928 r
.49055 .60359 m .47958 .60695 L .47658 .60385 L p F P
0 g
s
.651 .759 .928 r
.846 .60298 m .83443 .60636 L .83198 .60328 L p F P
0 g
s
.651 .758 .928 r
.664 .60662 m .67528 .60326 L .67798 .60635 L p F P
0 g
s
.651 .758 .928 r
.67528 .60326 m .664 .60662 L .66128 .60353 L p F P
0 g
s
.65 .757 .928 r
.15263 .60663 m .16304 .60329 L .16654 .60638 L p F P
0 g
s
.65 .757 .928 r
.16304 .60329 m .15263 .60663 L .14911 .60354 L p F P
0 g
s
.65 .758 .928 r
.49354 .60669 m .50453 .60333 L .5075 .60643 L p F P
0 g
s
.65 .758 .928 r
.50453 .60333 m .49354 .60669 L .49055 .60359 L p F P
0 g
s
.65 .758 .928 r
.32308 .60669 m .33378 .60334 L .33702 .60643 L p F P
0 g
s
.65 .758 .928 r
.33378 .60334 m .32308 .60669 L .31983 .60359 L p F P
0 g
s
.651 .758 .928 r
.67798 .60635 m .68928 .60299 L .69196 .60608 L p F P
0 g
s
.651 .758 .928 r
.68928 .60299 m .67798 .60635 L .67528 .60326 L p F P
0 g
s
.65 .757 .928 r
.16654 .60638 m .17698 .60304 L .18046 .60613 L p F P
0 g
s
.65 .757 .928 r
.17698 .60304 m .16654 .60638 L .16304 .60329 L p F P
0 g
s
.65 .758 .928 r
.5075 .60643 m .51852 .60307 L .52146 .60617 L p F P
0 g
s
.65 .758 .928 r
.51852 .60307 m .5075 .60643 L .50453 .60333 L p F P
0 g
s
.65 .758 .928 r
.33702 .60643 m .34775 .60308 L .35096 .60618 L p F P
0 g
s
.65 .758 .928 r
.34775 .60308 m .33702 .60643 L .33378 .60334 L p F P
0 g
s
.651 .758 .928 r
.69196 .60608 m .70329 .60272 L .70595 .60581 L p F P
0 g
s
.651 .758 .928 r
.70329 .60272 m .69196 .60608 L .68928 .60299 L p F P
0 g
s
0 0 .272 r
.4024 .23915 m .40237 .23923 L .4025 .23455 L p F P
0 g
s
0 0 .272 r
.4025 .23455 m .40253 .23446 L .4024 .23915 L p F P
0 g
s
.764 .494 .526 r
.40225 .23921 m .40237 .23923 L .4025 .23455 L p F P
0 g
s
.764 .494 .526 r
.4025 .23455 m .40237 .23452 L .40225 .23921 L p F P
0 g
s
.65 .757 .928 r
.18046 .60613 m .19092 .60278 L .19438 .60588 L p F P
0 g
s
.65 .757 .928 r
.19092 .60278 m .18046 .60613 L .17698 .60304 L p F P
0 g
s
.65 .758 .928 r
.52146 .60617 m .5325 .60281 L .53543 .60591 L p F P
0 g
s
.65 .758 .928 r
.5325 .60281 m .52146 .60617 L .51852 .60307 L p F P
0 g
s
.65 .758 .928 r
.35096 .60618 m .36171 .60282 L .3649 .60592 L p F P
0 g
s
.65 .758 .928 r
.36171 .60282 m .35096 .60618 L .34775 .60308 L p F P
0 g
s
.651 .758 .928 r
.70595 .60581 m .71731 .60245 L .71994 .60554 L p F P
0 g
s
.651 .758 .928 r
.71731 .60245 m .70595 .60581 L .70329 .60272 L p F P
0 g
s
.65 .757 .928 r
.19438 .60588 m .20487 .60253 L .2083 .60563 L p F P
0 g
s
.65 .757 .928 r
.20487 .60253 m .19438 .60588 L .19092 .60278 L p F P
0 g
s
.651 .758 .928 r
.53543 .60591 m .5465 .60255 L .54939 .60564 L p F P
0 g
s
.651 .758 .928 r
.5465 .60255 m .53543 .60591 L .5325 .60281 L p F P
0 g
s
.65 .758 .928 r
.3649 .60592 m .37568 .60257 L .37885 .60566 L p F P
0 g
s
.65 .758 .928 r
.37568 .60257 m .3649 .60592 L .36171 .60282 L p F P
0 g
s
.651 .758 .928 r
.71994 .60554 m .73132 .60218 L .73393 .60527 L p F P
0 g
s
.651 .758 .928 r
.73132 .60218 m .71994 .60554 L .71731 .60245 L p F P
0 g
s
.65 .757 .928 r
.2083 .60563 m .21881 .60228 L .22223 .60538 L p F P
0 g
s
.65 .757 .928 r
.21881 .60228 m .2083 .60563 L .20487 .60253 L p F P
0 g
s
.651 .758 .928 r
.54939 .60564 m .56049 .60229 L .56337 .60538 L p F P
0 g
s
.651 .758 .928 r
.56049 .60229 m .54939 .60564 L .5465 .60255 L p F P
0 g
s
.65 .758 .928 r
.37885 .60566 m .38965 .60231 L .3928 .60541 L p F P
0 g
s
.65 .758 .928 r
.38965 .60231 m .37885 .60566 L .37568 .60257 L p F P
0 g
s
.651 .758 .928 r
.73393 .60527 m .74534 .6019 L .74793 .60499 L p F P
0 g
s
.651 .758 .928 r
.74534 .6019 m .73393 .60527 L .73132 .60218 L p F P
0 g
s
.65 .757 .928 r
.22223 .60538 m .23277 .60203 L .23616 .60512 L p F P
0 g
s
.65 .757 .928 r
.23277 .60203 m .22223 .60538 L .21881 .60228 L p F P
0 g
s
.651 .758 .928 r
.56337 .60538 m .57449 .60202 L .57734 .60512 L p F P
0 g
s
.651 .758 .928 r
.57449 .60202 m .56337 .60538 L .56049 .60229 L p F P
0 g
s
.65 .758 .928 r
.3928 .60541 m .40363 .60205 L .40675 .60515 L p F P
0 g
s
.65 .758 .928 r
.40363 .60205 m .3928 .60541 L .38965 .60231 L p F P
0 g
s
.651 .758 .928 r
.74793 .60499 m .75936 .60162 L .76193 .60471 L p F P
0 g
s
.651 .758 .928 r
.75936 .60162 m .74793 .60499 L .74534 .6019 L p F P
0 g
s
.65 .757 .928 r
.06558 .605 m .07585 .60166 L .07949 .60476 L p F P
0 g
s
.65 .757 .928 r
.07585 .60166 m .06558 .605 L .06192 .6019 L p F P
0 g
s
.651 .758 .928 r
.57734 .60512 m .58849 .60176 L .59132 .60486 L p F P
0 g
s
.651 .758 .928 r
.58849 .60176 m .57734 .60512 L .57449 .60202 L p F P
0 g
s
.65 .757 .928 r
.23616 .60512 m .24672 .60177 L .2501 .60487 L p F P
0 g
s
.65 .757 .928 r
.24672 .60177 m .23616 .60512 L .23277 .60203 L p F P
0 g
s
.65 .758 .928 r
.40675 .60515 m .41761 .60179 L .42071 .60489 L p F P
0 g
s
.65 .758 .928 r
.41761 .60179 m .40675 .60515 L .40363 .60205 L p F P
0 g
s
.651 .758 .928 r
.76193 .60471 m .77339 .60134 L .77593 .60443 L p F P
0 g
s
.651 .758 .928 r
.77339 .60134 m .76193 .60471 L .75936 .60162 L p F P
0 g
s
.65 .757 .928 r
.07949 .60476 m .08979 .60142 L .09341 .60452 L p F P
0 g
s
.65 .757 .928 r
.08979 .60142 m .07949 .60476 L .07585 .60166 L p F P
0 g
s
.651 .758 .928 r
.59132 .60486 m .60249 .6015 L .60531 .60459 L p F P
0 g
s
.651 .758 .928 r
.60249 .6015 m .59132 .60486 L .58849 .60176 L p F P
0 g
s
.65 .758 .928 r
.2501 .60487 m .26068 .60152 L .26403 .60462 L p F P
0 g
s
.65 .757 .928 r
.26068 .60152 m .2501 .60487 L .24672 .60177 L p F P
0 g
s
.65 .758 .928 r
.42071 .60489 m .43159 .60153 L .43467 .60463 L p F P
0 g
s
.65 .758 .928 r
.43159 .60153 m .42071 .60489 L .41761 .60179 L p F P
0 g
s
.651 .758 .928 r
.77593 .60443 m .78742 .60106 L .78994 .60415 L p F P
0 g
s
.651 .758 .928 r
.78742 .60106 m .77593 .60443 L .77339 .60134 L p F P
0 g
s
.65 .757 .928 r
.09341 .60452 m .10373 .60117 L .10733 .60428 L p F P
0 g
s
.65 .757 .928 r
.10373 .60117 m .09341 .60452 L .08979 .60142 L p F P
0 g
s
.651 .758 .928 r
.60531 .60459 m .6165 .60123 L .61929 .60433 L p F P
0 g
s
.651 .758 .928 r
.6165 .60123 m .60531 .60459 L .60249 .6015 L p F P
0 g
s
.65 .758 .928 r
.26403 .60462 m .27465 .60126 L .27798 .60436 L p F P
0 g
s
.65 .758 .928 r
.27465 .60126 m .26403 .60462 L .26068 .60152 L p F P
0 g
s
.65 .758 .928 r
.43467 .60463 m .44558 .60127 L .44864 .60437 L p F P
0 g
s
.65 .758 .928 r
.44558 .60127 m .43467 .60463 L .43159 .60153 L p F P
0 g
s
.651 .759 .928 r
.78994 .60415 m .80145 .60077 L .80395 .60386 L p F P
0 g
s
.651 .758 .928 r
.80145 .60077 m .78994 .60415 L .78742 .60106 L p F P
0 g
s
.65 .757 .928 r
.10733 .60428 m .11767 .60093 L .12125 .60403 L p F P
0 g
s
.65 .757 .928 r
.11767 .60093 m .10733 .60428 L .10373 .60117 L p F P
0 g
s
.651 .758 .928 r
.61929 .60433 m .63052 .60097 L .63329 .60406 L p F P
0 g
s
.651 .758 .928 r
.63052 .60097 m .61929 .60433 L .6165 .60123 L p F P
0 g
s
.65 .758 .928 r
.27798 .60436 m .28862 .601 L .29192 .60411 L p F P
0 g
s
.65 .758 .928 r
.28862 .601 m .27798 .60436 L .27465 .60126 L p F P
0 g
s
.65 .758 .928 r
.44864 .60437 m .45957 .60101 L .46261 .60411 L p F P
0 g
s
.65 .758 .928 r
.45957 .60101 m .44864 .60437 L .44558 .60127 L p F P
0 g
s
.651 .759 .928 r
.80395 .60386 m .81549 .60048 L .81796 .60357 L p F P
0 g
s
.651 .759 .928 r
.81549 .60048 m .80395 .60386 L .80145 .60077 L p F P
0 g
s
.65 .757 .928 r
.12125 .60403 m .13162 .60068 L .13518 .60378 L p F P
0 g
s
.65 .757 .928 r
.13162 .60068 m .12125 .60403 L .11767 .60093 L p F P
0 g
s
.651 .758 .928 r
.64453 .6007 m .63329 .60406 L .63052 .60097 L p F P
0 g
s
.651 .758 .928 r
.63329 .60406 m .64453 .6007 L .64728 .6038 L p F P
0 g
s
.65 .758 .928 r
.29192 .60411 m .30259 .60075 L .30587 .60385 L p F P
0 g
s
.65 .758 .928 r
.30259 .60075 m .29192 .60411 L .28862 .601 L p F P
0 g
s
.65 .758 .928 r
.46261 .60411 m .47356 .60075 L .47658 .60385 L p F P
0 g
s
.65 .758 .928 r
.47356 .60075 m .46261 .60411 L .45957 .60101 L p F P
0 g
s
.651 .759 .928 r
.81796 .60357 m .82952 .60019 L .83198 .60328 L p F P
0 g
s
.651 .759 .928 r
.82952 .60019 m .81796 .60357 L .81549 .60048 L p F P
0 g
s
.65 .757 .928 r
.13518 .60378 m .14557 .60043 L .14911 .60354 L p F P
0 g
s
.65 .757 .928 r
.14557 .60043 m .13518 .60378 L .13162 .60068 L p F P
0 g
s
.651 .758 .928 r
.64728 .6038 m .65855 .60043 L .66128 .60353 L p F P
0 g
s
.651 .758 .928 r
.65855 .60043 m .64728 .6038 L .64453 .6007 L p F P
0 g
s
.65 .758 .928 r
.30587 .60385 m .31656 .60049 L .31983 .60359 L p F P
0 g
s
.65 .758 .928 r
.31656 .60049 m .30587 .60385 L .30259 .60075 L p F P
0 g
s
.65 .758 .928 r
.47658 .60385 m .48756 .60049 L .49055 .60359 L p F P
0 g
s
.65 .758 .928 r
.48756 .60049 m .47658 .60385 L .47356 .60075 L p F P
0 g
s
.651 .759 .928 r
.83198 .60328 m .84357 .5999 L .846 .60298 L p F P
0 g
s
.651 .759 .928 r
.84357 .5999 m .83198 .60328 L .82952 .60019 L p F P
0 g
s
.651 .758 .928 r
.67258 .60016 m .66128 .60353 L .65855 .60043 L p F P
0 g
s
.651 .758 .928 r
.66128 .60353 m .67258 .60016 L .67528 .60326 L p F P
0 g
s
.65 .757 .928 r
.14911 .60354 m .15953 .60018 L .16304 .60329 L p F P
0 g
s
.65 .757 .928 r
.15953 .60018 m .14911 .60354 L .14557 .60043 L p F P
0 g
s
0 0 .272 r
.40228 .24385 m .40224 .24393 L .40237 .23923 L p F P
0 g
s
0 0 .272 r
.40237 .23923 m .4024 .23915 L .40228 .24385 L p F P
0 g
s
.764 .494 .526 r
.40212 .24391 m .40224 .24393 L .40237 .23923 L p F P
0 g
s
.764 .494 .526 r
.40237 .23923 m .40225 .23921 L .40212 .24391 L p F P
0 g
s
.65 .758 .928 r
.49055 .60359 m .50156 .60023 L .50453 .60333 L p F P
0 g
s
.65 .758 .928 r
.50156 .60023 m .49055 .60359 L .48756 .60049 L p F P
0 g
s
.65 .758 .928 r
.31983 .60359 m .33054 .60023 L .33378 .60334 L p F P
0 g
s
.65 .758 .928 r
.33054 .60023 m .31983 .60359 L .31656 .60049 L p F P
0 g
s
.651 .759 .928 r
.85761 .59959 m .846 .60298 L .84357 .5999 L p F P
0 g
s
.651 .758 .928 r
.67528 .60326 m .6866 .59989 L .68928 .60299 L p F P
0 g
s
.651 .758 .928 r
.6866 .59989 m .67528 .60326 L .67258 .60016 L p F P
0 g
s
.65 .757 .928 r
.16304 .60329 m .17349 .59993 L .17698 .60304 L p F P
0 g
s
.65 .757 .928 r
.17349 .59993 m .16304 .60329 L .15953 .60018 L p F P
0 g
s
.65 .758 .928 r
.50453 .60333 m .51557 .59997 L .51852 .60307 L p F P
0 g
s
.65 .758 .928 r
.51557 .59997 m .50453 .60333 L .50156 .60023 L p F P
0 g
s
.65 .758 .928 r
.33378 .60334 m .34453 .59998 L .34775 .60308 L p F P
0 g
s
.65 .758 .928 r
.34453 .59998 m .33378 .60334 L .33054 .60023 L p F P
0 g
s
.651 .758 .928 r
.68928 .60299 m .70063 .59962 L .70329 .60272 L p F P
0 g
s
.651 .758 .928 r
.70063 .59962 m .68928 .60299 L .6866 .59989 L p F P
0 g
s
.65 .757 .928 r
.17698 .60304 m .18745 .59968 L .19092 .60278 L p F P
0 g
s
.65 .757 .928 r
.18745 .59968 m .17698 .60304 L .17349 .59993 L p F P
0 g
s
.65 .758 .928 r
.51852 .60307 m .52957 .59971 L .5325 .60281 L p F P
0 g
s
.65 .758 .928 r
.52957 .59971 m .51852 .60307 L .51557 .59997 L p F P
0 g
s
.65 .758 .928 r
.34775 .60308 m .35851 .59972 L .36171 .60282 L p F P
0 g
s
.65 .758 .928 r
.35851 .59972 m .34775 .60308 L .34453 .59998 L p F P
0 g
s
.651 .758 .928 r
.70329 .60272 m .71467 .59935 L .71731 .60245 L p F P
0 g
s
.651 .758 .928 r
.71467 .59935 m .70329 .60272 L .70063 .59962 L p F P
0 g
s
.65 .757 .928 r
.19092 .60278 m .20142 .59942 L .20487 .60253 L p F P
0 g
s
.65 .757 .928 r
.20142 .59942 m .19092 .60278 L .18745 .59968 L p F P
0 g
s
.651 .758 .928 r
.5325 .60281 m .54359 .59944 L .5465 .60255 L p F P
0 g
s
.651 .758 .928 r
.54359 .59944 m .5325 .60281 L .52957 .59971 L p F P
0 g
s
.65 .758 .928 r
.36171 .60282 m .3725 .59946 L .37568 .60257 L p F P
0 g
s
.65 .758 .928 r
.3725 .59946 m .36171 .60282 L .35851 .59972 L p F P
0 g
s
.651 .758 .928 r
.71731 .60245 m .7287 .59907 L .73132 .60218 L p F P
0 g
s
.651 .758 .928 r
.7287 .59907 m .71731 .60245 L .71467 .59935 L p F P
0 g
s
.65 .757 .928 r
.20487 .60253 m .21539 .59917 L .21881 .60228 L p F P
0 g
s
.65 .757 .928 r
.21539 .59917 m .20487 .60253 L .20142 .59942 L p F P
0 g
s
.651 .758 .928 r
.5465 .60255 m .5576 .59918 L .56049 .60229 L p F P
0 g
s
.651 .758 .928 r
.5576 .59918 m .5465 .60255 L .54359 .59944 L p F P
0 g
s
.65 .758 .928 r
.37568 .60257 m .3865 .5992 L .38965 .60231 L p F P
0 g
s
.65 .758 .928 r
.3865 .5992 m .37568 .60257 L .3725 .59946 L p F P
0 g
s
.651 .758 .928 r
.73132 .60218 m .74274 .5988 L .74534 .6019 L p F P
0 g
s
.651 .758 .928 r
.74274 .5988 m .73132 .60218 L .7287 .59907 L p F P
0 g
s
.65 .757 .928 r
.21881 .60228 m .22936 .59892 L .23277 .60203 L p F P
0 g
s
.65 .757 .928 r
.22936 .59892 m .21881 .60228 L .21539 .59917 L p F P
0 g
s
.651 .758 .928 r
.56049 .60229 m .57162 .59892 L .57449 .60202 L p F P
0 g
s
.651 .758 .928 r
.57162 .59892 m .56049 .60229 L .5576 .59918 L p F P
0 g
s
.65 .758 .928 r
.38965 .60231 m .40049 .59894 L .40363 .60205 L p F P
0 g
s
.65 .758 .928 r
.40049 .59894 m .38965 .60231 L .3865 .5992 L p F P
0 g
s
.651 .758 .928 r
.74534 .6019 m .75679 .59852 L .75936 .60162 L p F P
0 g
s
.651 .758 .928 r
.75679 .59852 m .74534 .6019 L .74274 .5988 L p F P
0 g
s
.65 .757 .928 r
.06192 .6019 m .0722 .59855 L .07585 .60166 L p F P
0 g
s
.65 .757 .928 r
.0722 .59855 m .06192 .6019 L .05825 .59879 L p F P
0 g
s
.651 .758 .928 r
.57449 .60202 m .58565 .59865 L .58849 .60176 L p F P
0 g
s
.651 .758 .928 r
.58565 .59865 m .57449 .60202 L .57162 .59892 L p F P
0 g
s
.65 .757 .928 r
.23277 .60203 m .24334 .59866 L .24672 .60177 L p F P
0 g
s
.65 .757 .928 r
.24334 .59866 m .23277 .60203 L .22936 .59892 L p F P
0 g
s
.65 .758 .928 r
.40363 .60205 m .41449 .59868 L .41761 .60179 L p F P
0 g
s
.65 .758 .928 r
.41449 .59868 m .40363 .60205 L .40049 .59894 L p F P
0 g
s
.651 .758 .928 r
.75936 .60162 m .77084 .59824 L .77339 .60134 L p F P
0 g
s
.651 .758 .928 r
.77084 .59824 m .75936 .60162 L .75679 .59852 L p F P
0 g
s
.65 .757 .928 r
.07585 .60166 m .08616 .59831 L .08979 .60142 L p F P
0 g
s
.65 .757 .928 r
.08616 .59831 m .07585 .60166 L .0722 .59855 L p F P
0 g
s
.651 .758 .928 r
.58849 .60176 m .59967 .59839 L .60249 .6015 L p F P
0 g
s
.651 .758 .928 r
.59967 .59839 m .58849 .60176 L .58565 .59865 L p F P
0 g
s
.65 .757 .928 r
.24672 .60177 m .25732 .59841 L .26068 .60152 L p F P
0 g
s
.65 .757 .928 r
.25732 .59841 m .24672 .60177 L .24334 .59866 L p F P
0 g
s
.65 .758 .928 r
.41761 .60179 m .4285 .59842 L .43159 .60153 L p F P
0 g
s
.65 .758 .928 r
.4285 .59842 m .41761 .60179 L .41449 .59868 L p F P
0 g
s
.651 .758 .928 r
.77339 .60134 m .78489 .59796 L .78742 .60106 L p F P
0 g
s
.651 .758 .928 r
.78489 .59796 m .77339 .60134 L .77084 .59824 L p F P
0 g
s
.65 .757 .928 r
.08979 .60142 m .10012 .59806 L .10373 .60117 L p F P
0 g
s
.65 .757 .928 r
.10012 .59806 m .08979 .60142 L .08616 .59831 L p F P
0 g
s
.651 .758 .928 r
.60249 .6015 m .6137 .59812 L .6165 .60123 L p F P
0 g
s
.651 .758 .928 r
.6137 .59812 m .60249 .6015 L .59967 .59839 L p F P
0 g
s
.65 .758 .928 r
.26068 .60152 m .27131 .59815 L .27465 .60126 L p F P
0 g
s
.65 .757 .928 r
.27131 .59815 m .26068 .60152 L .25732 .59841 L p F P
0 g
s
.65 .758 .928 r
.43159 .60153 m .44251 .59816 L .44558 .60127 L p F P
0 g
s
.65 .758 .928 r
.44251 .59816 m .43159 .60153 L .4285 .59842 L p F P
0 g
s
.651 .758 .928 r
.78742 .60106 m .79894 .59767 L .80145 .60077 L p F P
0 g
s
.651 .758 .928 r
.79894 .59767 m .78742 .60106 L .78489 .59796 L p F P
0 g
s
.65 .757 .928 r
.10373 .60117 m .11409 .59782 L .11767 .60093 L p F P
0 g
s
.65 .757 .928 r
.11409 .59782 m .10373 .60117 L .10012 .59806 L p F P
0 g
s
.651 .758 .928 r
.6165 .60123 m .62774 .59786 L .63052 .60097 L p F P
0 g
s
.651 .758 .928 r
.62774 .59786 m .6165 .60123 L .6137 .59812 L p F P
0 g
s
.65 .758 .928 r
.27465 .60126 m .2853 .59789 L .28862 .601 L p F P
0 g
s
.65 .758 .928 r
.2853 .59789 m .27465 .60126 L .27131 .59815 L p F P
0 g
s
.65 .758 .928 r
.44558 .60127 m .45652 .5979 L .45957 .60101 L p F P
0 g
s
.65 .758 .928 r
.45652 .5979 m .44558 .60127 L .44251 .59816 L p F P
0 g
s
.651 .759 .928 r
.80145 .60077 m .813 .59738 L .81549 .60048 L p F P
0 g
s
.651 .759 .928 r
.813 .59738 m .80145 .60077 L .79894 .59767 L p F P
0 g
s
.65 .757 .928 r
.11767 .60093 m .12806 .59757 L .13162 .60068 L p F P
0 g
s
.65 .757 .928 r
.12806 .59757 m .11767 .60093 L .11409 .59782 L p F P
0 g
s
.651 .758 .928 r
.63052 .60097 m .64178 .59759 L .64453 .6007 L p F P
0 g
s
.651 .758 .928 r
.64178 .59759 m .63052 .60097 L .62774 .59786 L p F P
0 g
s
0 0 .272 r
.40215 .24856 m .40212 .24864 L .40224 .24393 L p F P
0 g
s
0 0 .272 r
.40224 .24393 m .40228 .24385 L .40215 .24856 L p F P
0 g
s
.764 .494 .526 r
.402 .24862 m .40212 .24864 L .40224 .24393 L p F P
0 g
s
.764 .494 .526 r
.40224 .24393 m .40212 .24391 L .402 .24862 L p F P
0 g
s
.65 .758 .928 r
.28862 .601 m .29929 .59764 L .30259 .60075 L p F P
0 g
s
.65 .758 .928 r
.29929 .59764 m .28862 .601 L .2853 .59789 L p F P
0 g
s
.65 .758 .928 r
.45957 .60101 m .47054 .59764 L .47356 .60075 L p F P
0 g
s
.65 .758 .928 r
.47054 .59764 m .45957 .60101 L .45652 .5979 L p F P
0 g
s
.651 .759 .928 r
.81549 .60048 m .82706 .59709 L .82952 .60019 L p F P
0 g
s
.651 .759 .928 r
.82706 .59709 m .81549 .60048 L .813 .59738 L p F P
0 g
s
.65 .757 .928 r
.13162 .60068 m .14203 .59732 L .14557 .60043 L p F P
0 g
s
.65 .757 .928 r
.14203 .59732 m .13162 .60068 L .12806 .59757 L p F P
0 g
s
.651 .758 .928 r
.64453 .6007 m .65582 .59732 L .65855 .60043 L p F P
0 g
s
.651 .758 .928 r
.65582 .59732 m .64453 .6007 L .64178 .59759 L p F P
0 g
s
.65 .758 .928 r
.30259 .60075 m .31329 .59738 L .31656 .60049 L p F P
0 g
s
.65 .758 .928 r
.31329 .59738 m .30259 .60075 L .29929 .59764 L p F P
0 g
s
.65 .758 .928 r
.47356 .60075 m .48455 .59738 L .48756 .60049 L p F P
0 g
s
.65 .758 .928 r
.48455 .59738 m .47356 .60075 L .47054 .59764 L p F P
0 g
s
.651 .759 .928 r
.82952 .60019 m .84112 .5968 L .84357 .5999 L p F P
0 g
s
.651 .759 .928 r
.84112 .5968 m .82952 .60019 L .82706 .59709 L p F P
0 g
s
.65 .757 .928 r
.14557 .60043 m .15601 .59707 L .15953 .60018 L p F P
0 g
s
.65 .757 .928 r
.15601 .59707 m .14557 .60043 L .14203 .59732 L p F P
0 g
s
.651 .758 .928 r
.65855 .60043 m .66986 .59705 L .67258 .60016 L p F P
0 g
s
.651 .758 .928 r
.66986 .59705 m .65855 .60043 L .65582 .59732 L p F P
0 g
s
.65 .758 .928 r
.31656 .60049 m .32729 .59712 L .33054 .60023 L p F P
0 g
s
.65 .758 .928 r
.32729 .59712 m .31656 .60049 L .31329 .59738 L p F P
0 g
s
.65 .758 .928 r
.48756 .60049 m .49858 .59712 L .50156 .60023 L p F P
0 g
s
.65 .758 .928 r
.49858 .59712 m .48756 .60049 L .48455 .59738 L p F P
0 g
s
.651 .759 .928 r
.84357 .5999 m .85519 .5965 L .85761 .59959 L p F P
0 g
s
.651 .759 .928 r
.85519 .5965 m .84357 .5999 L .84112 .5968 L p F P
0 g
s
.651 .758 .928 r
.68391 .59678 m .67258 .60016 L .66986 .59705 L p F P
0 g
s
.651 .758 .928 r
.67258 .60016 m .68391 .59678 L .6866 .59989 L p F P
0 g
s
.65 .757 .928 r
.15953 .60018 m .16999 .59681 L .17349 .59993 L p F P
0 g
s
.65 .757 .928 r
.16999 .59681 m .15953 .60018 L .15601 .59707 L p F P
0 g
s
.65 .758 .928 r
.50156 .60023 m .5126 .59685 L .51557 .59997 L p F P
0 g
s
.65 .758 .928 r
.5126 .59685 m .50156 .60023 L .49858 .59712 L p F P
0 g
s
.65 .758 .928 r
.34129 .59686 m .33054 .60023 L .32729 .59712 L p F P
0 g
s
.65 .758 .928 r
.33054 .60023 m .34129 .59686 L .34453 .59998 L p F P
0 g
s
.651 .759 .928 r
.86926 .59619 m .85761 .59959 L .85519 .5965 L p F P
0 g
s
.651 .758 .928 r
.6866 .59989 m .69796 .59651 L .70063 .59962 L p F P
0 g
s
.651 .758 .928 r
.69796 .59651 m .6866 .59989 L .68391 .59678 L p F P
0 g
s
.65 .757 .928 r
.17349 .59993 m .18397 .59656 L .18745 .59968 L p F P
0 g
s
.65 .757 .928 r
.18397 .59656 m .17349 .59993 L .16999 .59681 L p F P
0 g
s
.65 .758 .928 r
.51557 .59997 m .52664 .59659 L .52957 .59971 L p F P
0 g
s
.65 .758 .928 r
.52664 .59659 m .51557 .59997 L .5126 .59685 L p F P
0 g
s
.65 .758 .928 r
.34453 .59998 m .3553 .5966 L .35851 .59972 L p F P
0 g
s
.65 .758 .928 r
.3553 .5966 m .34453 .59998 L .34129 .59686 L p F P
0 g
s
.651 .758 .928 r
.70063 .59962 m .71202 .59624 L .71467 .59935 L p F P
0 g
s
.651 .758 .928 r
.71202 .59624 m .70063 .59962 L .69796 .59651 L p F P
0 g
s
.65 .757 .928 r
.18745 .59968 m .19796 .59631 L .20142 .59942 L p F P
0 g
s
.65 .757 .928 r
.19796 .59631 m .18745 .59968 L .18397 .59656 L p F P
0 g
s
.651 .758 .928 r
.52957 .59971 m .54067 .59633 L .54359 .59944 L p F P
0 g
s
.651 .758 .928 r
.54067 .59633 m .52957 .59971 L .52664 .59659 L p F P
0 g
s
.65 .758 .928 r
.35851 .59972 m .36931 .59634 L .3725 .59946 L p F P
0 g
s
.65 .758 .928 r
.36931 .59634 m .35851 .59972 L .3553 .5966 L p F P
0 g
s
.651 .758 .928 r
.71467 .59935 m .72608 .59596 L .7287 .59907 L p F P
0 g
s
.651 .758 .928 r
.72608 .59596 m .71467 .59935 L .71202 .59624 L p F P
0 g
s
.65 .757 .928 r
.20142 .59942 m .21195 .59605 L .21539 .59917 L p F P
0 g
s
.65 .757 .928 r
.21195 .59605 m .20142 .59942 L .19796 .59631 L p F P
0 g
s
.651 .758 .928 r
.54359 .59944 m .55471 .59607 L .5576 .59918 L p F P
0 g
s
.651 .758 .928 r
.55471 .59607 m .54359 .59944 L .54067 .59633 L p F P
0 g
s
.65 .758 .928 r
.3725 .59946 m .38333 .59608 L .3865 .5992 L p F P
0 g
s
.65 .758 .928 r
.38333 .59608 m .3725 .59946 L .36931 .59634 L p F P
0 g
s
.651 .758 .928 r
.7287 .59907 m .74014 .59569 L .74274 .5988 L p F P
0 g
s
.651 .758 .928 r
.74014 .59569 m .7287 .59907 L .72608 .59596 L p F P
0 g
s
.65 .757 .928 r
.21539 .59917 m .22595 .5958 L .22936 .59892 L p F P
0 g
s
.65 .757 .928 r
.22595 .5958 m .21539 .59917 L .21195 .59605 L p F P
0 g
s
.651 .758 .928 r
.5576 .59918 m .56875 .5958 L .57162 .59892 L p F P
0 g
s
.651 .758 .928 r
.56875 .5958 m .5576 .59918 L .55471 .59607 L p F P
0 g
s
.65 .758 .928 r
.3865 .5992 m .39735 .59582 L .40049 .59894 L p F P
0 g
s
.65 .758 .928 r
.39735 .59582 m .3865 .5992 L .38333 .59608 L p F P
0 g
s
.65 .757 .928 r
.05825 .59879 m .06854 .59543 L .0722 .59855 L p F P
0 g
s
.65 .757 .928 r
.06854 .59543 m .05825 .59879 L .05456 .59568 L p F P
0 g
s
.651 .758 .928 r
.74274 .5988 m .75421 .59541 L .75679 .59852 L p F P
0 g
s
.651 .758 .928 r
.75421 .59541 m .74274 .5988 L .74014 .59569 L p F P
0 g
s
.65 .757 .928 r
.22936 .59892 m .23995 .59554 L .24334 .59866 L p F P
0 g
s
.65 .757 .928 r
.23995 .59554 m .22936 .59892 L .22595 .5958 L p F P
0 g
s
.651 .758 .928 r
.57162 .59892 m .58279 .59554 L .58565 .59865 L p F P
0 g
s
.651 .758 .928 r
.58279 .59554 m .57162 .59892 L .56875 .5958 L p F P
0 g
s
.65 .758 .928 r
.40049 .59894 m .41137 .59556 L .41449 .59868 L p F P
0 g
s
.65 .758 .928 r
.41137 .59556 m .40049 .59894 L .39735 .59582 L p F P
0 g
s
.651 .758 .928 r
.75679 .59852 m .76828 .59513 L .77084 .59824 L p F P
0 g
s
.651 .758 .928 r
.76828 .59513 m .75679 .59852 L .75421 .59541 L p F P
0 g
s
.65 .757 .928 r
.0722 .59855 m .08252 .59519 L .08616 .59831 L p F P
0 g
s
.65 .757 .928 r
.08252 .59519 m .0722 .59855 L .06854 .59543 L p F P
0 g
s
.651 .758 .928 r
.58565 .59865 m .59684 .59527 L .59967 .59839 L p F P
0 g
s
.651 .758 .928 r
.59684 .59527 m .58565 .59865 L .58279 .59554 L p F P
0 g
s
.65 .757 .928 r
.24334 .59866 m .25395 .59529 L .25732 .59841 L p F P
0 g
s
.65 .757 .928 r
.25395 .59529 m .24334 .59866 L .23995 .59554 L p F P
0 g
s
.65 .758 .928 r
.41449 .59868 m .4254 .5953 L .4285 .59842 L p F P
0 g
s
.65 .758 .928 r
.4254 .5953 m .41449 .59868 L .41137 .59556 L p F P
0 g
s
.651 .758 .928 r
.77084 .59824 m .78235 .59485 L .78489 .59796 L p F P
0 g
s
.651 .758 .928 r
.78235 .59485 m .77084 .59824 L .76828 .59513 L p F P
0 g
s
.65 .757 .928 r
.08616 .59831 m .0965 .59494 L .10012 .59806 L p F P
0 g
s
.65 .757 .928 r
.0965 .59494 m .08616 .59831 L .08252 .59519 L p F P
0 g
s
0 0 .272 r
.40202 .25329 m .40199 .25336 L .40212 .24864 L p F P
0 g
s
0 0 .272 r
.40212 .24864 m .40215 .24856 L .40202 .25329 L p F P
0 g
s
.764 .494 .526 r
.40188 .25334 m .40199 .25336 L .40212 .24864 L p F P
0 g
s
.764 .494 .526 r
.40212 .24864 m .402 .24862 L .40188 .25334 L p F P
0 g
s
.651 .758 .928 r
.59967 .59839 m .6109 .595 L .6137 .59812 L p F P
0 g
s
.651 .758 .928 r
.6109 .595 m .59967 .59839 L .59684 .59527 L p F P
0 g
s
.65 .757 .928 r
.25732 .59841 m .26796 .59503 L .27131 .59815 L p F P
0 g
s
.65 .757 .928 r
.26796 .59503 m .25732 .59841 L .25395 .59529 L p F P
0 g
s
.65 .758 .928 r
.4285 .59842 m .43943 .59504 L .44251 .59816 L p F P
0 g
s
.65 .758 .928 r
.43943 .59504 m .4285 .59842 L .4254 .5953 L p F P
0 g
s
.651 .758 .928 r
.78489 .59796 m .79643 .59456 L .79894 .59767 L p F P
0 g
s
.651 .758 .928 r
.79643 .59456 m .78489 .59796 L .78235 .59485 L p F P
0 g
s
.65 .757 .928 r
.10012 .59806 m .11049 .59469 L .11409 .59782 L p F P
0 g
s
.65 .757 .928 r
.11049 .59469 m .10012 .59806 L .0965 .59494 L p F P
0 g
s
.651 .758 .928 r
.6137 .59812 m .62495 .59474 L .62774 .59786 L p F P
0 g
s
.651 .758 .928 r
.62495 .59474 m .6137 .59812 L .6109 .595 L p F P
0 g
s
.65 .758 .928 r
.27131 .59815 m .28197 .59477 L .2853 .59789 L p F P
0 g
s
.65 .758 .928 r
.28197 .59477 m .27131 .59815 L .26796 .59503 L p F P
0 g
s
.65 .758 .928 r
.44251 .59816 m .45346 .59478 L .45652 .5979 L p F P
0 g
s
.65 .758 .928 r
.45346 .59478 m .44251 .59816 L .43943 .59504 L p F P
0 g
s
.651 .759 .928 r
.79894 .59767 m .81051 .59427 L .813 .59738 L p F P
0 g
s
.651 .758 .928 r
.81051 .59427 m .79894 .59767 L .79643 .59456 L p F P
0 g
s
.65 .757 .928 r
.11409 .59782 m .12448 .59444 L .12806 .59757 L p F P
0 g
s
.65 .757 .928 r
.12448 .59444 m .11409 .59782 L .11049 .59469 L p F P
0 g
s
.651 .758 .928 r
.62774 .59786 m .63901 .59447 L .64178 .59759 L p F P
0 g
s
.651 .758 .928 r
.63901 .59447 m .62774 .59786 L .62495 .59474 L p F P
0 g
s
.65 .758 .928 r
.2853 .59789 m .29599 .59451 L .29929 .59764 L p F P
0 g
s
.65 .758 .928 r
.29599 .59451 m .2853 .59789 L .28197 .59477 L p F P
0 g
s
.65 .758 .928 r
.45652 .5979 m .4675 .59452 L .47054 .59764 L p F P
0 g
s
.65 .758 .928 r
.4675 .59452 m .45652 .5979 L .45346 .59478 L p F P
0 g
s
.651 .759 .928 r
.813 .59738 m .82459 .59398 L .82706 .59709 L p F P
0 g
s
.651 .759 .928 r
.82459 .59398 m .813 .59738 L .81051 .59427 L p F P
0 g
s
.65 .757 .928 r
.12806 .59757 m .13847 .59419 L .14203 .59732 L p F P
0 g
s
.65 .757 .928 r
.13847 .59419 m .12806 .59757 L .12448 .59444 L p F P
0 g
s
.651 .758 .928 r
.64178 .59759 m .65307 .5942 L .65582 .59732 L p F P
0 g
s
.651 .758 .928 r
.65307 .5942 m .64178 .59759 L .63901 .59447 L p F P
0 g
s
.65 .758 .928 r
.29929 .59764 m .31001 .59425 L .31329 .59738 L p F P
0 g
s
.65 .758 .928 r
.31001 .59425 m .29929 .59764 L .29599 .59451 L p F P
0 g
s
.65 .758 .928 r
.47054 .59764 m .48154 .59426 L .48455 .59738 L p F P
0 g
s
.65 .758 .928 r
.48154 .59426 m .47054 .59764 L .4675 .59452 L p F P
0 g
s
.651 .759 .928 r
.82706 .59709 m .83868 .59368 L .84112 .5968 L p F P
0 g
s
.651 .759 .928 r
.83868 .59368 m .82706 .59709 L .82459 .59398 L p F P
0 g
s
.65 .757 .928 r
.14203 .59732 m .15247 .59394 L .15601 .59707 L p F P
0 g
s
.65 .757 .928 r
.15247 .59394 m .14203 .59732 L .13847 .59419 L p F P
0 g
s
.651 .758 .928 r
.66714 .59393 m .65582 .59732 L .65307 .5942 L p F P
0 g
s
.651 .758 .928 r
.65582 .59732 m .66714 .59393 L .66986 .59705 L p F P
0 g
s
.65 .758 .928 r
.31329 .59738 m .32403 .594 L .32729 .59712 L p F P
0 g
s
.65 .758 .928 r
.32403 .594 m .31329 .59738 L .31001 .59425 L p F P
0 g
s
.65 .758 .928 r
.48455 .59738 m .49559 .59399 L .49858 .59712 L p F P
0 g
s
.65 .758 .928 r
.49559 .59399 m .48455 .59738 L .48154 .59426 L p F P
0 g
s
.651 .759 .928 r
.84112 .5968 m .85276 .59339 L .85519 .5965 L p F P
0 g
s
.651 .759 .928 r
.85276 .59339 m .84112 .5968 L .83868 .59368 L p F P
0 g
s
.651 .758 .928 r
.66986 .59705 m .68121 .59366 L .68391 .59678 L p F P
0 g
s
.651 .758 .928 r
.68121 .59366 m .66986 .59705 L .66714 .59393 L p F P
0 g
s
.65 .757 .928 r
.15601 .59707 m .16648 .59369 L .16999 .59681 L p F P
0 g
s
.65 .757 .928 r
.16648 .59369 m .15601 .59707 L .15247 .59394 L p F P
0 g
s
.65 .758 .928 r
.49858 .59712 m .50963 .59373 L .5126 .59685 L p F P
0 g
s
.65 .758 .928 r
.50963 .59373 m .49858 .59712 L .49559 .59399 L p F P
0 g
s
.65 .758 .928 r
.32729 .59712 m .33805 .59374 L .34129 .59686 L p F P
0 g
s
.65 .758 .928 r
.33805 .59374 m .32729 .59712 L .32403 .594 L p F P
0 g
s
.651 .759 .928 r
.85519 .5965 m .86686 .59308 L .86926 .59619 L p F P
0 g
s
.651 .759 .928 r
.86686 .59308 m .85519 .5965 L .85276 .59339 L p F P
0 g
s
.651 .758 .928 r
.68391 .59678 m .69529 .59339 L .69796 .59651 L p F P
0 g
s
.651 .758 .928 r
.69529 .59339 m .68391 .59678 L .68121 .59366 L p F P
0 g
s
.65 .757 .928 r
.16999 .59681 m .18048 .59344 L .18397 .59656 L p F P
0 g
s
.65 .757 .928 r
.18048 .59344 m .16999 .59681 L .16648 .59369 L p F P
0 g
s
.65 .758 .928 r
.5126 .59685 m .52369 .59347 L .52664 .59659 L p F P
0 g
s
.65 .758 .928 r
.52369 .59347 m .5126 .59685 L .50963 .59373 L p F P
0 g
s
.65 .758 .928 r
.35208 .59348 m .34129 .59686 L .33805 .59374 L p F P
0 g
s
.65 .758 .928 r
.34129 .59686 m .35208 .59348 L .3553 .5966 L p F P
0 g
s
.651 .759 .928 r
.88095 .59277 m .86926 .59619 L .86686 .59308 L p F P
0 g
s
.651 .758 .928 r
.69796 .59651 m .70936 .59312 L .71202 .59624 L p F P
0 g
s
.651 .758 .928 r
.70936 .59312 m .69796 .59651 L .69529 .59339 L p F P
0 g
s
.65 .757 .928 r
.18397 .59656 m .19449 .59318 L .19796 .59631 L p F P
0 g
s
.65 .757 .928 r
.19449 .59318 m .18397 .59656 L .18048 .59344 L p F P
0 g
s
.651 .758 .928 r
.52664 .59659 m .53774 .5932 L .54067 .59633 L p F P
0 g
s
.651 .758 .928 r
.53774 .5932 m .52664 .59659 L .52369 .59347 L p F P
0 g
s
.65 .758 .928 r
.3553 .5966 m .36612 .59322 L .36931 .59634 L p F P
0 g
s
.65 .758 .928 r
.36612 .59322 m .3553 .5966 L .35208 .59348 L p F P
0 g
s
.651 .758 .928 r
.71202 .59624 m .72344 .59284 L .72608 .59596 L p F P
0 g
s
.651 .758 .928 r
.72344 .59284 m .71202 .59624 L .70936 .59312 L p F P
0 g
s
.65 .757 .928 r
.19796 .59631 m .20851 .59293 L .21195 .59605 L p F P
0 g
s
.65 .757 .928 r
.20851 .59293 m .19796 .59631 L .19449 .59318 L p F P
0 g
s
.651 .758 .928 r
.54067 .59633 m .5518 .59294 L .55471 .59607 L p F P
0 g
s
.651 .758 .928 r
.5518 .59294 m .54067 .59633 L .53774 .5932 L p F P
0 g
s
.65 .758 .928 r
.36931 .59634 m .38015 .59296 L .38333 .59608 L p F P
0 g
s
.65 .758 .928 r
.38015 .59296 m .36931 .59634 L .36612 .59322 L p F P
0 g
s
.651 .758 .928 r
.72608 .59596 m .73753 .59256 L .74014 .59569 L p F P
0 g
s
.651 .758 .928 r
.73753 .59256 m .72608 .59596 L .72344 .59284 L p F P
0 g
s
.65 .757 .928 r
.21195 .59605 m .22252 .59267 L .22595 .5958 L p F P
0 g
s
.65 .757 .928 r
.22252 .59267 m .21195 .59605 L .20851 .59293 L p F P
0 g
s
.651 .758 .928 r
.55471 .59607 m .56587 .59267 L .56875 .5958 L p F P
0 g
s
.651 .758 .928 r
.56587 .59267 m .55471 .59607 L .5518 .59294 L p F P
0 g
s
.65 .758 .928 r
.38333 .59608 m .39419 .5927 L .39735 .59582 L p F P
0 g
s
.65 .758 .928 r
.39419 .5927 m .38333 .59608 L .38015 .59296 L p F P
0 g
s
.65 .757 .928 r
.05456 .59568 m .06487 .5923 L .06854 .59543 L p F P
0 g
s
.65 .757 .928 r
.06487 .5923 m .05456 .59568 L .05087 .59255 L p F P
0 g
s
.651 .758 .928 r
.74014 .59569 m .75162 .59229 L .75421 .59541 L p F P
0 g
s
.651 .758 .928 r
.75162 .59229 m .74014 .59569 L .73753 .59256 L p F P
0 g
s
0 0 .272 r
.40189 .25803 m .40186 .2581 L .40199 .25336 L p F P
0 g
s
0 0 .272 r
.40199 .25336 m .40202 .25329 L .40189 .25803 L p F P
0 g
s
.764 .494 .526 r
.40176 .25808 m .40186 .2581 L .40199 .25336 L p F P
0 g
s
.764 .494 .526 r
.40199 .25336 m .40188 .25334 L .40176 .25808 L p F P
0 g
s
.65 .757 .928 r
.22595 .5958 m .23655 .59241 L .23995 .59554 L p F P
0 g
s
.65 .757 .928 r
.23655 .59241 m .22595 .5958 L .22252 .59267 L p F P
0 g
s
.651 .758 .928 r
.56875 .5958 m .57993 .59241 L .58279 .59554 L p F P
0 g
s
.651 .758 .928 r
.57993 .59241 m .56875 .5958 L .56587 .59267 L p F P
0 g
s
.65 .758 .928 r
.39735 .59582 m .40824 .59243 L .41137 .59556 L p F P
0 g
s
.65 .758 .928 r
.40824 .59243 m .39735 .59582 L .39419 .5927 L p F P
0 g
s
.651 .758 .928 r
.75421 .59541 m .76571 .59201 L .76828 .59513 L p F P
0 g
s
.651 .758 .928 r
.76571 .59201 m .75421 .59541 L .75162 .59229 L p F P
0 g
s
.65 .757 .928 r
.06854 .59543 m .07887 .59206 L .08252 .59519 L p F P
0 g
s
.65 .757 .928 r
.07887 .59206 m .06854 .59543 L .06487 .5923 L p F P
0 g
s
.651 .758 .928 r
.58279 .59554 m .594 .59214 L .59684 .59527 L p F P
0 g
s
.651 .758 .928 r
.594 .59214 m .58279 .59554 L .57993 .59241 L p F P
0 g
s
.65 .757 .928 r
.23995 .59554 m .25057 .59216 L .25395 .59529 L p F P
0 g
s
.65 .757 .928 r
.25057 .59216 m .23995 .59554 L .23655 .59241 L p F P
0 g
s
.65 .758 .928 r
.41137 .59556 m .42229 .59217 L .4254 .5953 L p F P
0 g
s
.65 .758 .928 r
.42229 .59217 m .41137 .59556 L .40824 .59243 L p F P
0 g
s
.651 .758 .928 r
.76828 .59513 m .7798 .59172 L .78235 .59485 L p F P
0 g
s
.651 .758 .928 r
.7798 .59172 m .76828 .59513 L .76571 .59201 L p F P
0 g
s
.65 .757 .928 r
.08252 .59519 m .09287 .59181 L .0965 .59494 L p F P
0 g
s
.65 .757 .928 r
.09287 .59181 m .08252 .59519 L .07887 .59206 L p F P
0 g
s
.651 .758 .928 r
.59684 .59527 m .60808 .59188 L .6109 .595 L p F P
0 g
s
.651 .758 .928 r
.60808 .59188 m .59684 .59527 L .594 .59214 L p F P
0 g
s
.65 .757 .928 r
.25395 .59529 m .2646 .5919 L .26796 .59503 L p F P
0 g
s
.65 .757 .928 r
.2646 .5919 m .25395 .59529 L .25057 .59216 L p F P
0 g
s
.65 .758 .928 r
.4254 .5953 m .43634 .59191 L .43943 .59504 L p F P
0 g
s
.65 .758 .928 r
.43634 .59191 m .4254 .5953 L .42229 .59217 L p F P
0 g
s
.651 .758 .928 r
.78235 .59485 m .7939 .59144 L .79643 .59456 L p F P
0 g
s
.651 .758 .928 r
.7939 .59144 m .78235 .59485 L .7798 .59172 L p F P
0 g
s
.65 .757 .928 r
.0965 .59494 m .10688 .59156 L .11049 .59469 L p F P
0 g
s
.65 .757 .928 r
.10688 .59156 m .0965 .59494 L .09287 .59181 L p F P
0 g
s
.651 .758 .928 r
.6109 .595 m .62216 .59161 L .62495 .59474 L p F P
0 g
s
.651 .758 .928 r
.62216 .59161 m .6109 .595 L .60808 .59188 L p F P
0 g
s
.65 .758 .928 r
.26796 .59503 m .27863 .59164 L .28197 .59477 L p F P
0 g
s
.65 .757 .928 r
.27863 .59164 m .26796 .59503 L .2646 .5919 L p F P
0 g
s
.65 .758 .928 r
.43943 .59504 m .45039 .59165 L .45346 .59478 L p F P
0 g
s
.65 .758 .928 r
.45039 .59165 m .43943 .59504 L .43634 .59191 L p F P
0 g
s
.651 .758 .928 r
.79643 .59456 m .808 .59115 L .81051 .59427 L p F P
0 g
s
.651 .758 .928 r
.808 .59115 m .79643 .59456 L .7939 .59144 L p F P
0 g
s
.65 .757 .928 r
.11049 .59469 m .12089 .59131 L .12448 .59444 L p F P
0 g
s
.65 .757 .928 r
.12089 .59131 m .11049 .59469 L .10688 .59156 L p F P
0 g
s
.651 .758 .928 r
.62495 .59474 m .63624 .59134 L .63901 .59447 L p F P
0 g
s
.651 .758 .928 r
.63624 .59134 m .62495 .59474 L .62216 .59161 L p F P
0 g
s
.65 .758 .928 r
.28197 .59477 m .29267 .59138 L .29599 .59451 L p F P
0 g
s
.65 .758 .928 r
.29267 .59138 m .28197 .59477 L .27863 .59164 L p F P
0 g
s
.65 .758 .928 r
.45346 .59478 m .46445 .59139 L .4675 .59452 L p F P
0 g
s
.65 .758 .928 r
.46445 .59139 m .45346 .59478 L .45039 .59165 L p F P
0 g
s
.651 .759 .928 r
.81051 .59427 m .82211 .59086 L .82459 .59398 L p F P
0 g
s
.651 .759 .928 r
.82211 .59086 m .81051 .59427 L .808 .59115 L p F P
0 g
s
.65 .757 .928 r
.12448 .59444 m .13491 .59106 L .13847 .59419 L p F P
0 g
s
.65 .757 .928 r
.13491 .59106 m .12448 .59444 L .12089 .59131 L p F P
0 g
s
.651 .758 .928 r
.63901 .59447 m .65032 .59107 L .65307 .5942 L p F P
0 g
s
.651 .758 .928 r
.65032 .59107 m .63901 .59447 L .63624 .59134 L p F P
0 g
s
.65 .758 .928 r
.29599 .59451 m .30671 .59112 L .31001 .59425 L p F P
0 g
s
.65 .758 .928 r
.30671 .59112 m .29599 .59451 L .29267 .59138 L p F P
0 g
s
.65 .758 .928 r
.4675 .59452 m .47852 .59112 L .48154 .59426 L p F P
0 g
s
.65 .758 .928 r
.47852 .59112 m .4675 .59452 L .46445 .59139 L p F P
0 g
s
.651 .759 .928 r
.82459 .59398 m .83622 .59056 L .83868 .59368 L p F P
0 g
s
.651 .759 .928 r
.83622 .59056 m .82459 .59398 L .82211 .59086 L p F P
0 g
s
.65 .757 .928 r
.13847 .59419 m .14893 .59081 L .15247 .59394 L p F P
0 g
s
.65 .757 .928 r
.14893 .59081 m .13847 .59419 L .13491 .59106 L p F P
0 g
s
.651 .758 .928 r
.65307 .5942 m .66441 .5908 L .66714 .59393 L p F P
0 g
s
.651 .758 .928 r
.66441 .5908 m .65307 .5942 L .65032 .59107 L p F P
0 g
s
.65 .758 .928 r
.31001 .59425 m .32075 .59086 L .32403 .594 L p F P
0 g
s
.65 .758 .928 r
.32075 .59086 m .31001 .59425 L .30671 .59112 L p F P
0 g
s
.65 .758 .928 r
.48154 .59426 m .49258 .59086 L .49559 .59399 L p F P
0 g
s
.65 .758 .928 r
.49258 .59086 m .48154 .59426 L .47852 .59112 L p F P
0 g
s
.651 .759 .928 r
.83868 .59368 m .85033 .59026 L .85276 .59339 L p F P
0 g
s
.651 .759 .928 r
.85033 .59026 m .83868 .59368 L .83622 .59056 L p F P
0 g
s
.651 .758 .928 r
.6785 .59053 m .66714 .59393 L .66441 .5908 L p F P
0 g
s
.651 .758 .928 r
.66714 .59393 m .6785 .59053 L .68121 .59366 L p F P
0 g
s
.65 .757 .928 r
.15247 .59394 m .16295 .59055 L .16648 .59369 L p F P
0 g
s
.65 .757 .928 r
.16295 .59055 m .15247 .59394 L .14893 .59081 L p F P
0 g
s
.65 .758 .928 r
.49559 .59399 m .50665 .5906 L .50963 .59373 L p F P
0 g
s
.65 .758 .928 r
.50665 .5906 m .49559 .59399 L .49258 .59086 L p F P
0 g
s
.65 .758 .928 r
.32403 .594 m .3348 .5906 L .33805 .59374 L p F P
0 g
s
.65 .758 .928 r
.3348 .5906 m .32403 .594 L .32075 .59086 L p F P
0 g
s
.651 .759 .928 r
.85276 .59339 m .86444 .58996 L .86686 .59308 L p F P
0 g
s
.651 .759 .928 r
.86444 .58996 m .85276 .59339 L .85033 .59026 L p F P
0 g
s
.651 .758 .928 r
.68121 .59366 m .6926 .59026 L .69529 .59339 L p F P
0 g
s
.651 .758 .928 r
.6926 .59026 m .68121 .59366 L .6785 .59053 L p F P
0 g
s
.65 .757 .928 r
.16648 .59369 m .17698 .5903 L .18048 .59344 L p F P
0 g
s
.65 .757 .928 r
.17698 .5903 m .16648 .59369 L .16295 .59055 L p F P
0 g
s
.65 .758 .928 r
.50963 .59373 m .52073 .59033 L .52369 .59347 L p F P
0 g
s
.65 .758 .928 r
.52073 .59033 m .50963 .59373 L .50665 .5906 L p F P
0 g
s
.65 .758 .928 r
.33805 .59374 m .34885 .59034 L .35208 .59348 L p F P
0 g
s
.65 .758 .928 r
.34885 .59034 m .33805 .59374 L .3348 .5906 L p F P
0 g
s
.651 .759 .928 r
.86686 .59308 m .87856 .58965 L .88095 .59277 L p F P
0 g
s
.651 .759 .928 r
.87856 .58965 m .86686 .59308 L .86444 .58996 L p F P
0 g
s
.651 .758 .928 r
.7067 .58998 m .69529 .59339 L .6926 .59026 L p F P
0 g
s
.651 .758 .928 r
.69529 .59339 m .7067 .58998 L .70936 .59312 L p F P
0 g
s
.65 .757 .928 r
.18048 .59344 m .19101 .59004 L .19449 .59318 L p F P
0 g
s
.65 .757 .928 r
.19101 .59004 m .18048 .59344 L .17698 .5903 L p F P
0 g
s
.651 .758 .928 r
.52369 .59347 m .53481 .59007 L .53774 .5932 L p F P
0 g
s
.651 .758 .928 r
.53481 .59007 m .52369 .59347 L .52073 .59033 L p F P
0 g
s
.65 .758 .928 r
.35208 .59348 m .36291 .59008 L .36612 .59322 L p F P
0 g
s
.65 .758 .928 r
.36291 .59008 m .35208 .59348 L .34885 .59034 L p F P
0 g
s
.652 .759 .928 r
.89268 .58934 m .88095 .59277 L .87856 .58965 L p F P
0 g
s
.651 .758 .928 r
.70936 .59312 m .7208 .58971 L .72344 .59284 L p F P
0 g
s
.651 .758 .928 r
.7208 .58971 m .70936 .59312 L .7067 .58998 L p F P
0 g
s
0 0 .272 r
.40176 .26278 m .40173 .26284 L .40186 .2581 L p F P
0 g
s
0 0 .272 r
.40186 .2581 m .40189 .25803 L .40176 .26278 L p F P
0 g
s
.764 .494 .526 r
.40164 .26282 m .40173 .26284 L .40186 .2581 L p F P
0 g
s
.764 .494 .526 r
.40186 .2581 m .40176 .25808 L .40164 .26282 L p F P
0 g
s
.65 .757 .928 r
.19449 .59318 m .20505 .58979 L .20851 .59293 L p F P
0 g
s
.65 .757 .928 r
.20505 .58979 m .19449 .59318 L .19101 .59004 L p F P
0 g
s
.651 .758 .928 r
.53774 .5932 m .54889 .5898 L .5518 .59294 L p F P
0 g
s
.651 .758 .928 r
.54889 .5898 m .53774 .5932 L .53481 .59007 L p F P
0 g
s
.65 .758 .928 r
.36612 .59322 m .37697 .58982 L .38015 .59296 L p F P
0 g
s
.65 .758 .928 r
.37697 .58982 m .36612 .59322 L .36291 .59008 L p F P
0 g
s
.651 .758 .928 r
.72344 .59284 m .73491 .58943 L .73753 .59256 L p F P
0 g
s
.651 .758 .928 r
.73491 .58943 m .72344 .59284 L .7208 .58971 L p F P
0 g
s
.65 .757 .928 r
.20851 .59293 m .21909 .58953 L .22252 .59267 L p F P
0 g
s
.65 .757 .928 r
.21909 .58953 m .20851 .59293 L .20505 .58979 L p F P
0 g
s
.651 .758 .928 r
.5518 .59294 m .56297 .58954 L .56587 .59267 L p F P
0 g
s
.651 .758 .928 r
.56297 .58954 m .5518 .59294 L .54889 .5898 L p F P
0 g
s
.65 .758 .928 r
.38015 .59296 m .39103 .58956 L .39419 .5927 L p F P
0 g
s
.65 .758 .928 r
.39103 .58956 m .38015 .59296 L .37697 .58982 L p F P
0 g
s
.65 .757 .928 r
.05087 .59255 m .06118 .58916 L .06487 .5923 L p F P
0 g
s
.65 .757 .928 r
.06118 .58916 m .05087 .59255 L .04716 .58941 L p F P
0 g
s
.651 .758 .928 r
.73753 .59256 m .74902 .58915 L .75162 .59229 L p F P
0 g
s
.651 .758 .928 r
.74902 .58915 m .73753 .59256 L .73491 .58943 L p F P
0 g
s
.65 .757 .928 r
.22252 .59267 m .23313 .58927 L .23655 .59241 L p F P
0 g
s
.65 .757 .928 r
.23313 .58927 m .22252 .59267 L .21909 .58953 L p F P
0 g
s
.651 .758 .928 r
.56587 .59267 m .57706 .58927 L .57993 .59241 L p F P
0 g
s
.651 .758 .928 r
.57706 .58927 m .56587 .59267 L .56297 .58954 L p F P
0 g
s
.65 .758 .928 r
.39419 .5927 m .4051 .5893 L .40824 .59243 L p F P
0 g
s
.65 .758 .928 r
.4051 .5893 m .39419 .5927 L .39103 .58956 L p F P
0 g
s
.651 .758 .928 r
.75162 .59229 m .76313 .58887 L .76571 .59201 L p F P
0 g
s
.651 .758 .928 r
.76313 .58887 m .75162 .59229 L .74902 .58915 L p F P
0 g
s
.65 .757 .928 r
.06487 .5923 m .0752 .58892 L .07887 .59206 L p F P
0 g
s
.65 .757 .928 r
.0752 .58892 m .06487 .5923 L .06118 .58916 L p F P
0 g
s
.651 .758 .928 r
.57993 .59241 m .59115 .58901 L .594 .59214 L p F P
0 g
s
.651 .758 .928 r
.59115 .58901 m .57993 .59241 L .57706 .58927 L p F P
0 g
s
.65 .757 .928 r
.23655 .59241 m .24718 .58902 L .25057 .59216 L p F P
0 g
s
.65 .757 .928 r
.24718 .58902 m .23655 .59241 L .23313 .58927 L p F P
0 g
s
.65 .758 .928 r
.40824 .59243 m .41917 .58903 L .42229 .59217 L p F P
0 g
s
.65 .758 .928 r
.41917 .58903 m .40824 .59243 L .4051 .5893 L p F P
0 g
s
.651 .758 .928 r
.76571 .59201 m .77725 .58859 L .7798 .59172 L p F P
0 g
s
.651 .758 .928 r
.77725 .58859 m .76571 .59201 L .76313 .58887 L p F P
0 g
s
.65 .757 .928 r
.07887 .59206 m .08923 .58867 L .09287 .59181 L p F P
0 g
s
.65 .757 .928 r
.08923 .58867 m .07887 .59206 L .0752 .58892 L p F P
0 g
s
.651 .758 .928 r
.594 .59214 m .60525 .58874 L .60808 .59188 L p F P
0 g
s
.651 .758 .928 r
.60525 .58874 m .594 .59214 L .59115 .58901 L p F P
0 g
s
.65 .757 .928 r
.25057 .59216 m .26123 .58876 L .2646 .5919 L p F P
0 g
s
.65 .757 .928 r
.26123 .58876 m .25057 .59216 L .24718 .58902 L p F P
0 g
s
.65 .758 .928 r
.42229 .59217 m .43324 .58877 L .43634 .59191 L p F P
0 g
s
.65 .758 .928 r
.43324 .58877 m .42229 .59217 L .41917 .58903 L p F P
0 g
s
.651 .758 .928 r
.7798 .59172 m .79137 .58831 L .7939 .59144 L p F P
0 g
s
.651 .758 .928 r
.79137 .58831 m .7798 .59172 L .77725 .58859 L p F P
0 g
s
.65 .757 .928 r
.09287 .59181 m .10326 .58842 L .10688 .59156 L p F P
0 g
s
.65 .757 .928 r
.10326 .58842 m .09287 .59181 L .08923 .58867 L p F P
0 g
s
.651 .758 .928 r
.60808 .59188 m .61935 .58847 L .62216 .59161 L p F P
0 g
s
.651 .758 .928 r
.61935 .58847 m .60808 .59188 L .60525 .58874 L p F P
0 g
s
.65 .757 .928 r
.2646 .5919 m .27528 .5885 L .27863 .59164 L p F P
0 g
s
.65 .757 .928 r
.27528 .5885 m .2646 .5919 L .26123 .58876 L p F P
0 g
s
.65 .758 .928 r
.43634 .59191 m .44732 .58851 L .45039 .59165 L p F P
0 g
s
.65 .758 .928 r
.44732 .58851 m .43634 .59191 L .43324 .58877 L p F P
0 g
s
.651 .758 .928 r
.7939 .59144 m .80549 .58802 L .808 .59115 L p F P
0 g
s
.651 .758 .928 r
.80549 .58802 m .7939 .59144 L .79137 .58831 L p F P
0 g
s
.65 .757 .928 r
.10688 .59156 m .11729 .58817 L .12089 .59131 L p F P
0 g
s
.65 .757 .928 r
.11729 .58817 m .10688 .59156 L .10326 .58842 L p F P
0 g
s
.651 .758 .928 r
.62216 .59161 m .63345 .5882 L .63624 .59134 L p F P
0 g
s
.651 .758 .928 r
.63345 .5882 m .62216 .59161 L .61935 .58847 L p F P
0 g
s
.65 .758 .928 r
.27863 .59164 m .28934 .58824 L .29267 .59138 L p F P
0 g
s
.65 .757 .928 r
.28934 .58824 m .27863 .59164 L .27528 .5885 L p F P
0 g
s
.65 .758 .928 r
.45039 .59165 m .4614 .58825 L .46445 .59139 L p F P
0 g
s
.65 .758 .928 r
.4614 .58825 m .45039 .59165 L .44732 .58851 L p F P
0 g
s
.651 .759 .928 r
.808 .59115 m .81962 .58773 L .82211 .59086 L p F P
0 g
s
.651 .759 .928 r
.81962 .58773 m .808 .59115 L .80549 .58802 L p F P
0 g
s
.65 .757 .928 r
.12089 .59131 m .13133 .58792 L .13491 .59106 L p F P
0 g
s
.65 .757 .928 r
.13133 .58792 m .12089 .59131 L .11729 .58817 L p F P
0 g
s
.651 .758 .928 r
.63624 .59134 m .64756 .58793 L .65032 .59107 L p F P
0 g
s
.651 .758 .928 r
.64756 .58793 m .63624 .59134 L .63345 .5882 L p F P
0 g
s
.65 .758 .928 r
.29267 .59138 m .30341 .58798 L .30671 .59112 L p F P
0 g
s
.65 .758 .928 r
.30341 .58798 m .29267 .59138 L .28934 .58824 L p F P
0 g
s
.65 .758 .928 r
.46445 .59139 m .47548 .58798 L .47852 .59112 L p F P
0 g
s
.65 .758 .928 r
.47548 .58798 m .46445 .59139 L .4614 .58825 L p F P
0 g
s
.651 .759 .928 r
.82211 .59086 m .83375 .58743 L .83622 .59056 L p F P
0 g
s
.651 .759 .928 r
.83375 .58743 m .82211 .59086 L .81962 .58773 L p F P
0 g
s
.65 .757 .928 r
.13491 .59106 m .14537 .58766 L .14893 .59081 L p F P
0 g
s
.65 .757 .928 r
.14537 .58766 m .13491 .59106 L .13133 .58792 L p F P
0 g
s
.651 .758 .928 r
.65032 .59107 m .66167 .58766 L .66441 .5908 L p F P
0 g
s
.651 .758 .928 r
.66167 .58766 m .65032 .59107 L .64756 .58793 L p F P
0 g
s
.65 .758 .928 r
.30671 .59112 m .31747 .58772 L .32075 .59086 L p F P
0 g
s
.65 .758 .928 r
.31747 .58772 m .30671 .59112 L .30341 .58798 L p F P
0 g
s
.65 .758 .928 r
.47852 .59112 m .48957 .58772 L .49258 .59086 L p F P
0 g
s
.65 .758 .928 r
.48957 .58772 m .47852 .59112 L .47548 .58798 L p F P
0 g
s
.651 .759 .928 r
.83622 .59056 m .84789 .58713 L .85033 .59026 L p F P
0 g
s
.651 .759 .928 r
.84789 .58713 m .83622 .59056 L .83375 .58743 L p F P
0 g
s
.651 .758 .928 r
.66441 .5908 m .67579 .58739 L .6785 .59053 L p F P
0 g
s
.651 .758 .928 r
.67579 .58739 m .66441 .5908 L .66167 .58766 L p F P
0 g
s
.65 .757 .928 r
.14893 .59081 m .15942 .58741 L .16295 .59055 L p F P
0 g
s
.65 .757 .928 r
.15942 .58741 m .14893 .59081 L .14537 .58766 L p F P
0 g
s
.65 .758 .928 r
.49258 .59086 m .50367 .58745 L .50665 .5906 L p F P
0 g
s
.65 .758 .928 r
.50367 .58745 m .49258 .59086 L .48957 .58772 L p F P
0 g
s
.65 .758 .928 r
.32075 .59086 m .33154 .58746 L .3348 .5906 L p F P
0 g
s
.65 .758 .928 r
.33154 .58746 m .32075 .59086 L .31747 .58772 L p F P
0 g
s
.651 .759 .928 r
.85033 .59026 m .86202 .58683 L .86444 .58996 L p F P
0 g
s
.651 .759 .928 r
.86202 .58683 m .85033 .59026 L .84789 .58713 L p F P
0 g
s
.651 .758 .928 r
.6899 .58712 m .6785 .59053 L .67579 .58739 L p F P
0 g
s
.651 .758 .928 r
.6785 .59053 m .6899 .58712 L .6926 .59026 L p F P
0 g
s
.65 .757 .928 r
.16295 .59055 m .17347 .58715 L .17698 .5903 L p F P
0 g
s
.65 .757 .928 r
.17347 .58715 m .16295 .59055 L .15942 .58741 L p F P
0 g
s
0 0 .272 r
.40163 .26754 m .4016 .2676 L .40173 .26284 L p F P
0 g
s
0 0 .272 r
.40173 .26284 m .40176 .26278 L .40163 .26754 L p F P
0 g
s
.764 .494 .526 r
.40151 .26759 m .4016 .2676 L .40173 .26284 L p F P
0 g
s
.764 .494 .526 r
.40173 .26284 m .40164 .26282 L .40151 .26759 L p F P
0 g
s
.65 .758 .928 r
.50665 .5906 m .51776 .58719 L .52073 .59033 L p F P
0 g
s
.65 .758 .928 r
.51776 .58719 m .50665 .5906 L .50367 .58745 L p F P
0 g
s
.65 .758 .928 r
.3348 .5906 m .34561 .5872 L .34885 .59034 L p F P
0 g
s
.65 .758 .928 r
.34561 .5872 m .3348 .5906 L .33154 .58746 L p F P
0 g
s
.651 .759 .928 r
.86444 .58996 m .87616 .58652 L .87856 .58965 L p F P
0 g
s
.651 .759 .928 r
.87616 .58652 m .86444 .58996 L .86202 .58683 L p F P
0 g
s
.651 .758 .928 r
.6926 .59026 m .70403 .58684 L .7067 .58998 L p F P
0 g
s
.651 .758 .928 r
.70403 .58684 m .6926 .59026 L .6899 .58712 L p F P
0 g
s
.65 .757 .928 r
.17698 .5903 m .18752 .5869 L .19101 .59004 L p F P
0 g
s
.65 .757 .928 r
.18752 .5869 m .17698 .5903 L .17347 .58715 L p F P
0 g
s
.651 .758 .928 r
.52073 .59033 m .53186 .58692 L .53481 .59007 L p F P
0 g
s
.651 .758 .928 r
.53186 .58692 m .52073 .59033 L .51776 .58719 L p F P
0 g
s
.65 .758 .928 r
.34885 .59034 m .35969 .58693 L .36291 .59008 L p F P
0 g
s
.65 .758 .928 r
.35969 .58693 m .34885 .59034 L .34561 .5872 L p F P
0 g
s
.652 .759 .928 r
.87856 .58965 m .8903 .58621 L .89268 .58934 L p F P
0 g
s
.652 .759 .928 r
.8903 .58621 m .87856 .58965 L .87616 .58652 L p F P
0 g
s
.651 .758 .928 r
.71815 .58657 m .7067 .58998 L .70403 .58684 L p F P
0 g
s
.651 .758 .928 r
.7067 .58998 m .71815 .58657 L .7208 .58971 L p F P
0 g
s
.65 .757 .928 r
.19101 .59004 m .20158 .58664 L .20505 .58979 L p F P
0 g
s
.65 .757 .928 r
.20158 .58664 m .19101 .59004 L .18752 .5869 L p F P
0 g
s
.651 .758 .928 r
.53481 .59007 m .54596 .58666 L .54889 .5898 L p F P
0 g
s
.651 .758 .928 r
.54596 .58666 m .53481 .59007 L .53186 .58692 L p F P
0 g
s
.65 .758 .928 r
.36291 .59008 m .37377 .58667 L .37697 .58982 L p F P
0 g
s
.65 .758 .928 r
.37377 .58667 m .36291 .59008 L .35969 .58693 L p F P
0 g
s
.652 .759 .928 r
.90445 .58589 m .89268 .58934 L .8903 .58621 L p F P
0 g
s
.651 .758 .928 r
.7208 .58971 m .73228 .58629 L .73491 .58943 L p F P
0 g
s
.651 .758 .928 r
.73228 .58629 m .7208 .58971 L .71815 .58657 L p F P
0 g
s
.65 .757 .928 r
.20505 .58979 m .21564 .58638 L .21909 .58953 L p F P
0 g
s
.65 .757 .928 r
.21564 .58638 m .20505 .58979 L .20158 .58664 L p F P
0 g
s
.651 .758 .928 r
.54889 .5898 m .56007 .58639 L .56297 .58954 L p F P
0 g
s
.651 .758 .928 r
.56007 .58639 m .54889 .5898 L .54596 .58666 L p F P
0 g
s
.65 .758 .928 r
.37697 .58982 m .38786 .58641 L .39103 .58956 L p F P
0 g
s
.65 .758 .928 r
.38786 .58641 m .37697 .58982 L .37377 .58667 L p F P
0 g
s
.65 .757 .928 r
.04716 .58941 m .05748 .58601 L .06118 .58916 L p F P
0 g
s
.651 .758 .928 r
.73491 .58943 m .74641 .58601 L .74902 .58915 L p F P
0 g
s
.651 .758 .928 r
.74641 .58601 m .73491 .58943 L .73228 .58629 L p F P
0 g
s
.65 .757 .928 r
.21909 .58953 m .22971 .58612 L .23313 .58927 L p F P
0 g
s
.65 .757 .928 r
.22971 .58612 m .21909 .58953 L .21564 .58638 L p F P
0 g
s
.651 .758 .928 r
.56297 .58954 m .57418 .58612 L .57706 .58927 L p F P
0 g
s
.651 .758 .928 r
.57418 .58612 m .56297 .58954 L .56007 .58639 L p F P
0 g
s
.65 .758 .928 r
.39103 .58956 m .40194 .58615 L .4051 .5893 L p F P
0 g
s
.65 .758 .928 r
.40194 .58615 m .39103 .58956 L .38786 .58641 L p F P
0 g
s
.651 .758 .928 r
.74902 .58915 m .76055 .58573 L .76313 .58887 L p F P
0 g
s
.651 .758 .928 r
.76055 .58573 m .74902 .58915 L .74641 .58601 L p F P
0 g
s
.65 .757 .928 r
.06118 .58916 m .07153 .58577 L .0752 .58892 L p F P
0 g
s
.65 .757 .928 r
.07153 .58577 m .06118 .58916 L .05748 .58601 L p F P
0 g
s
.651 .758 .928 r
.57706 .58927 m .5883 .58586 L .59115 .58901 L p F P
0 g
s
.651 .758 .928 r
.5883 .58586 m .57706 .58927 L .57418 .58612 L p F P
0 g
s
.65 .757 .928 r
.23313 .58927 m .24378 .58587 L .24718 .58902 L p F P
0 g
s
.65 .757 .928 r
.24378 .58587 m .23313 .58927 L .22971 .58612 L p F P
0 g
s
.65 .758 .928 r
.4051 .5893 m .41604 .58588 L .41917 .58903 L p F P
0 g
s
.65 .758 .928 r
.41604 .58588 m .4051 .5893 L .40194 .58615 L p F P
0 g
s
.651 .758 .928 r
.76313 .58887 m .77469 .58545 L .77725 .58859 L p F P
0 g
s
.651 .758 .928 r
.77469 .58545 m .76313 .58887 L .76055 .58573 L p F P
0 g
s
.65 .757 .928 r
.0752 .58892 m .08557 .58552 L .08923 .58867 L p F P
0 g
s
.65 .757 .928 r
.08557 .58552 m .0752 .58892 L .07153 .58577 L p F P
0 g
s
.651 .758 .928 r
.59115 .58901 m .60242 .58559 L .60525 .58874 L p F P
0 g
s
.651 .758 .928 r
.60242 .58559 m .59115 .58901 L .5883 .58586 L p F P
0 g
s
.65 .757 .928 r
.24718 .58902 m .25785 .58561 L .26123 .58876 L p F P
0 g
s
.65 .757 .928 r
.25785 .58561 m .24718 .58902 L .24378 .58587 L p F P
0 g
s
.65 .758 .928 r
.41917 .58903 m .43013 .58562 L .43324 .58877 L p F P
0 g
s
.65 .758 .928 r
.43013 .58562 m .41917 .58903 L .41604 .58588 L p F P
0 g
s
.651 .758 .928 r
.77725 .58859 m .78883 .58516 L .79137 .58831 L p F P
0 g
s
.651 .758 .928 r
.78883 .58516 m .77725 .58859 L .77469 .58545 L p F P
0 g
s
.65 .757 .928 r
.08923 .58867 m .09963 .58527 L .10326 .58842 L p F P
0 g
s
.65 .757 .928 r
.09963 .58527 m .08923 .58867 L .08557 .58552 L p F P
0 g
s
.651 .758 .928 r
.60525 .58874 m .61654 .58532 L .61935 .58847 L p F P
0 g
s
.651 .758 .928 r
.61654 .58532 m .60525 .58874 L .60242 .58559 L p F P
0 g
s
.65 .757 .928 r
.26123 .58876 m .27193 .58535 L .27528 .5885 L p F P
0 g
s
.65 .757 .928 r
.27193 .58535 m .26123 .58876 L .25785 .58561 L p F P
0 g
s
.65 .758 .928 r
.43324 .58877 m .44423 .58536 L .44732 .58851 L p F P
0 g
s
.65 .758 .928 r
.44423 .58536 m .43324 .58877 L .43013 .58562 L p F P
0 g
s
.651 .758 .928 r
.79137 .58831 m .80298 .58487 L .80549 .58802 L p F P
0 g
s
.651 .758 .928 r
.80298 .58487 m .79137 .58831 L .78883 .58516 L p F P
0 g
s
.65 .757 .928 r
.10326 .58842 m .11368 .58502 L .11729 .58817 L p F P
0 g
s
.65 .757 .928 r
.11368 .58502 m .10326 .58842 L .09963 .58527 L p F P
0 g
s
.651 .758 .928 r
.61935 .58847 m .63066 .58505 L .63345 .5882 L p F P
0 g
s
.651 .758 .928 r
.63066 .58505 m .61935 .58847 L .61654 .58532 L p F P
0 g
s
.65 .757 .928 r
.27528 .5885 m .28601 .58509 L .28934 .58824 L p F P
0 g
s
.65 .757 .928 r
.28601 .58509 m .27528 .5885 L .27193 .58535 L p F P
0 g
s
.65 .758 .928 r
.44732 .58851 m .45833 .58509 L .4614 .58825 L p F P
0 g
s
.65 .758 .928 r
.45833 .58509 m .44732 .58851 L .44423 .58536 L p F P
0 g
s
.651 .759 .928 r
.80549 .58802 m .81713 .58458 L .81962 .58773 L p F P
0 g
s
.651 .758 .928 r
.81713 .58458 m .80549 .58802 L .80298 .58487 L p F P
0 g
s
.65 .757 .928 r
.11729 .58817 m .12774 .58476 L .13133 .58792 L p F P
0 g
s
.65 .757 .928 r
.12774 .58476 m .11729 .58817 L .11368 .58502 L p F P
0 g
s
.651 .758 .928 r
.63345 .5882 m .64479 .58478 L .64756 .58793 L p F P
0 g
s
.651 .758 .928 r
.64479 .58478 m .63345 .5882 L .63066 .58505 L p F P
0 g
s
.65 .758 .928 r
.28934 .58824 m .30009 .58483 L .30341 .58798 L p F P
0 g
s
.65 .758 .928 r
.30009 .58483 m .28934 .58824 L .28601 .58509 L p F P
0 g
s
.65 .758 .928 r
.4614 .58825 m .47244 .58483 L .47548 .58798 L p F P
0 g
s
.65 .758 .928 r
.47244 .58483 m .4614 .58825 L .45833 .58509 L p F P
0 g
s
.651 .759 .928 r
.81962 .58773 m .83128 .58429 L .83375 .58743 L p F P
0 g
s
.651 .759 .928 r
.83128 .58429 m .81962 .58773 L .81713 .58458 L p F P
0 g
s
.65 .757 .928 r
.13133 .58792 m .14181 .58451 L .14537 .58766 L p F P
0 g
s
.65 .757 .928 r
.14181 .58451 m .13133 .58792 L .12774 .58476 L p F P
0 g
s
.651 .758 .928 r
.64756 .58793 m .65892 .58451 L .66167 .58766 L p F P
0 g
s
.651 .758 .928 r
.65892 .58451 m .64756 .58793 L .64479 .58478 L p F P
0 g
s
0 0 .272 r
.4015 .27232 m .40148 .27238 L .4016 .2676 L p F P
0 g
s
0 0 .272 r
.4016 .2676 m .40163 .26754 L .4015 .27232 L p F P
0 g
s
.764 .494 .526 r
.40139 .27236 m .40148 .27238 L .4016 .2676 L p F P
0 g
s
.764 .494 .526 r
.4016 .2676 m .40151 .26759 L .40139 .27236 L p F P
0 g
s
.65 .758 .928 r
.30341 .58798 m .31418 .58456 L .31747 .58772 L p F P
0 g
s
.65 .758 .928 r
.31418 .58456 m .30341 .58798 L .30009 .58483 L p F P
0 g
s
.65 .758 .928 r
.47548 .58798 m .48655 .58456 L .48957 .58772 L p F P
0 g
s
.65 .758 .928 r
.48655 .58456 m .47548 .58798 L .47244 .58483 L p F P
0 g
s
.651 .759 .928 r
.83375 .58743 m .84543 .58399 L .84789 .58713 L p F P
0 g
s
.651 .759 .928 r
.84543 .58399 m .83375 .58743 L .83128 .58429 L p F P
0 g
s
.651 .758 .928 r
.66167 .58766 m .67306 .58424 L .67579 .58739 L p F P
0 g
s
.651 .758 .928 r
.67306 .58424 m .66167 .58766 L .65892 .58451 L p F P
0 g
s
.65 .757 .928 r
.14537 .58766 m .15587 .58425 L .15942 .58741 L p F P
0 g
s
.65 .757 .928 r
.15587 .58425 m .14537 .58766 L .14181 .58451 L p F P
0 g
s
.65 .758 .928 r
.48957 .58772 m .50067 .5843 L .50367 .58745 L p F P
0 g
s
.65 .758 .928 r
.50067 .5843 m .48957 .58772 L .48655 .58456 L p F P
0 g
s
.65 .758 .928 r
.31747 .58772 m .32827 .5843 L .33154 .58746 L p F P
0 g
s
.65 .758 .928 r
.32827 .5843 m .31747 .58772 L .31418 .58456 L p F P
0 g
s
.651 .759 .928 r
.84789 .58713 m .85959 .58369 L .86202 .58683 L p F P
0 g
s
.651 .759 .928 r
.85959 .58369 m .84789 .58713 L .84543 .58399 L p F P
0 g
s
.651 .758 .928 r
.67579 .58739 m .6872 .58396 L .6899 .58712 L p F P
0 g
s
.651 .758 .928 r
.6872 .58396 m .67579 .58739 L .67306 .58424 L p F P
0 g
s
.65 .757 .928 r
.15942 .58741 m .16995 .584 L .17347 .58715 L p F P
0 g
s
.65 .757 .928 r
.16995 .584 m .15942 .58741 L .15587 .58425 L p F P
0 g
s
.65 .758 .928 r
.50367 .58745 m .51478 .58403 L .51776 .58719 L p F P
0 g
s
.65 .758 .928 r
.51478 .58403 m .50367 .58745 L .50067 .5843 L p F P
0 g
s
.65 .758 .928 r
.33154 .58746 m .34236 .58404 L .34561 .5872 L p F P
0 g
s
.65 .758 .928 r
.34236 .58404 m .33154 .58746 L .32827 .5843 L p F P
0 g
s
.651 .759 .928 r
.86202 .58683 m .87376 .58338 L .87616 .58652 L p F P
0 g
s
.651 .759 .928 r
.87376 .58338 m .86202 .58683 L .85959 .58369 L p F P
0 g
s
.651 .758 .928 r
.70135 .58369 m .6899 .58712 L .6872 .58396 L p F P
0 g
s
.651 .758 .928 r
.6899 .58712 m .70135 .58369 L .70403 .58684 L p F P
0 g
s
.65 .757 .928 r
.17347 .58715 m .18402 .58374 L .18752 .5869 L p F P
0 g
s
.65 .757 .928 r
.18402 .58374 m .17347 .58715 L .16995 .584 L p F P
0 g
s
.651 .758 .928 r
.51776 .58719 m .52891 .58377 L .53186 .58692 L p F P
0 g
s
.651 .758 .928 r
.52891 .58377 m .51776 .58719 L .51478 .58403 L p F P
0 g
s
.65 .758 .928 r
.34561 .5872 m .35646 .58378 L .35969 .58693 L p F P
0 g
s
.65 .758 .928 r
.35646 .58378 m .34561 .5872 L .34236 .58404 L p F P
0 g
s
.652 .759 .928 r
.87616 .58652 m .88792 .58307 L .8903 .58621 L p F P
0 g
s
.652 .759 .928 r
.88792 .58307 m .87616 .58652 L .87376 .58338 L p F P
0 g
s
.651 .758 .928 r
.70403 .58684 m .71549 .58341 L .71815 .58657 L p F P
0 g
s
.651 .758 .928 r
.71549 .58341 m .70403 .58684 L .70135 .58369 L p F P
0 g
s
.65 .757 .928 r
.18752 .5869 m .1981 .58348 L .20158 .58664 L p F P
0 g
s
.65 .757 .928 r
.1981 .58348 m .18752 .5869 L .18402 .58374 L p F P
0 g
s
.651 .758 .928 r
.53186 .58692 m .54303 .5835 L .54596 .58666 L p F P
0 g
s
.651 .758 .928 r
.54303 .5835 m .53186 .58692 L .52891 .58377 L p F P
0 g
s
.65 .758 .928 r
.35969 .58693 m .37057 .58352 L .37377 .58667 L p F P
0 g
s
.65 .758 .928 r
.37057 .58352 m .35969 .58693 L .35646 .58378 L p F P
0 g
s
.652 .759 .928 r
.8903 .58621 m .90209 .58275 L .90445 .58589 L p F P
0 g
s
.652 .759 .928 r
.90209 .58275 m .8903 .58621 L .88792 .58307 L p F P
0 g
s
.651 .758 .928 r
.72964 .58314 m .71815 .58657 L .71549 .58341 L p F P
0 g
s
.651 .758 .928 r
.71815 .58657 m .72964 .58314 L .73228 .58629 L p F P
0 g
s
.65 .757 .928 r
.20158 .58664 m .21218 .58322 L .21564 .58638 L p F P
0 g
s
.65 .757 .928 r
.21218 .58322 m .20158 .58664 L .1981 .58348 L p F P
0 g
s
.651 .758 .928 r
.54596 .58666 m .55716 .58323 L .56007 .58639 L p F P
0 g
s
.651 .758 .928 r
.55716 .58323 m .54596 .58666 L .54303 .5835 L p F P
0 g
s
.65 .758 .928 r
.37377 .58667 m .38467 .58325 L .38786 .58641 L p F P
0 g
s
.65 .758 .928 r
.38467 .58325 m .37377 .58667 L .37057 .58352 L p F P
0 g
s
.652 .76 .928 r
.91626 .58243 m .90445 .58589 L .90209 .58275 L p F P
0 g
s
.651 .758 .928 r
.73228 .58629 m .7438 .58286 L .74641 .58601 L p F P
0 g
s
.651 .758 .928 r
.7438 .58286 m .73228 .58629 L .72964 .58314 L p F P
0 g
s
.65 .757 .928 r
.21564 .58638 m .22627 .58297 L .22971 .58612 L p F P
0 g
s
.65 .757 .928 r
.22627 .58297 m .21564 .58638 L .21218 .58322 L p F P
0 g
s
.651 .758 .928 r
.56007 .58639 m .57129 .58297 L .57418 .58612 L p F P
0 g
s
.651 .758 .928 r
.57129 .58297 m .56007 .58639 L .55716 .58323 L p F P
0 g
s
.65 .758 .928 r
.38786 .58641 m .39878 .58299 L .40194 .58615 L p F P
0 g
s
.65 .758 .928 r
.39878 .58299 m .38786 .58641 L .38467 .58325 L p F P
0 g
s
.651 .758 .928 r
.74641 .58601 m .75796 .58258 L .76055 .58573 L p F P
0 g
s
.651 .758 .928 r
.75796 .58258 m .74641 .58601 L .7438 .58286 L p F P
0 g
s
.65 .757 .928 r
.05748 .58601 m .06784 .5826 L .07153 .58577 L p F P
0 g
s
.651 .758 .928 r
.57418 .58612 m .58543 .5827 L .5883 .58586 L p F P
0 g
s
.651 .758 .928 r
.58543 .5827 m .57418 .58612 L .57129 .58297 L p F P
0 g
s
.65 .757 .928 r
.22971 .58612 m .24036 .58271 L .24378 .58587 L p F P
0 g
s
.65 .757 .928 r
.24036 .58271 m .22971 .58612 L .22627 .58297 L p F P
0 g
s
.65 .758 .928 r
.40194 .58615 m .4129 .58272 L .41604 .58588 L p F P
0 g
s
.65 .758 .928 r
.4129 .58272 m .40194 .58615 L .39878 .58299 L p F P
0 g
s
.651 .758 .928 r
.76055 .58573 m .77212 .58229 L .77469 .58545 L p F P
0 g
s
.651 .758 .928 r
.77212 .58229 m .76055 .58573 L .75796 .58258 L p F P
0 g
s
.65 .757 .928 r
.07153 .58577 m .08191 .58236 L .08557 .58552 L p F P
0 g
s
.65 .757 .928 r
.08191 .58236 m .07153 .58577 L .06784 .5826 L p F P
0 g
s
.651 .758 .928 r
.5883 .58586 m .59957 .58243 L .60242 .58559 L p F P
0 g
s
.651 .758 .928 r
.59957 .58243 m .5883 .58586 L .58543 .5827 L p F P
0 g
s
.65 .757 .928 r
.24378 .58587 m .25446 .58245 L .25785 .58561 L p F P
0 g
s
.65 .757 .928 r
.25446 .58245 m .24378 .58587 L .24036 .58271 L p F P
0 g
s
.65 .758 .928 r
.41604 .58588 m .42701 .58246 L .43013 .58562 L p F P
0 g
s
.65 .758 .928 r
.42701 .58246 m .41604 .58588 L .4129 .58272 L p F P
0 g
s
.651 .758 .928 r
.77469 .58545 m .78628 .58201 L .78883 .58516 L p F P
0 g
s
.651 .758 .928 r
.78628 .58201 m .77469 .58545 L .77212 .58229 L p F P
0 g
s
.65 .757 .928 r
.08557 .58552 m .09598 .5821 L .09963 .58527 L p F P
0 g
s
.65 .757 .928 r
.09598 .5821 m .08557 .58552 L .08191 .58236 L p F P
0 g
s
.651 .758 .928 r
.60242 .58559 m .61371 .58216 L .61654 .58532 L p F P
0 g
s
.651 .758 .928 r
.61371 .58216 m .60242 .58559 L .59957 .58243 L p F P
0 g
s
.65 .757 .928 r
.25785 .58561 m .26856 .58218 L .27193 .58535 L p F P
0 g
s
.65 .757 .928 r
.26856 .58218 m .25785 .58561 L .25446 .58245 L p F P
0 g
s
.65 .758 .928 r
.43013 .58562 m .44114 .5822 L .44423 .58536 L p F P
0 g
s
.65 .758 .928 r
.44114 .5822 m .43013 .58562 L .42701 .58246 L p F P
0 g
s
.651 .758 .928 r
.78883 .58516 m .80045 .58172 L .80298 .58487 L p F P
0 g
s
.651 .758 .928 r
.80045 .58172 m .78883 .58516 L .78628 .58201 L p F P
0 g
s
.65 .757 .928 r
.09963 .58527 m .11006 .58185 L .11368 .58502 L p F P
0 g
s
.65 .757 .928 r
.11006 .58185 m .09963 .58527 L .09598 .5821 L p F P
0 g
s
.651 .758 .928 r
.61654 .58532 m .62786 .58189 L .63066 .58505 L p F P
0 g
s
.651 .758 .928 r
.62786 .58189 m .61654 .58532 L .61371 .58216 L p F P
0 g
s
0 0 .272 r
.40137 .27711 m .40135 .27716 L .40148 .27238 L p F P
0 g
s
0 0 .272 r
.40148 .27238 m .4015 .27232 L .40137 .27711 L p F P
0 g
s
.764 .494 .526 r
.40126 .27715 m .40135 .27716 L .40148 .27238 L p F P
0 g
s
.764 .494 .526 r
.40148 .27238 m .40139 .27236 L .40126 .27715 L p F P
0 g
s
.65 .757 .928 r
.27193 .58535 m .28266 .58192 L .28601 .58509 L p F P
0 g
s
.65 .757 .928 r
.28266 .58192 m .27193 .58535 L .26856 .58218 L p F P
0 g
s
.65 .758 .928 r
.44423 .58536 m .45526 .58193 L .45833 .58509 L p F P
0 g
s
.65 .758 .928 r
.45526 .58193 m .44423 .58536 L .44114 .5822 L p F P
0 g
s
.651 .758 .928 r
.80298 .58487 m .81462 .58143 L .81713 .58458 L p F P
0 g
s
.651 .758 .928 r
.81462 .58143 m .80298 .58487 L .80045 .58172 L p F P
0 g
s
.65 .757 .928 r
.11368 .58502 m .12414 .5816 L .12774 .58476 L p F P
0 g
s
.65 .757 .928 r
.12414 .5816 m .11368 .58502 L .11006 .58185 L p F P
0 g
s
.651 .758 .928 r
.63066 .58505 m .64201 .58162 L .64479 .58478 L p F P
0 g
s
.651 .758 .928 r
.64201 .58162 m .63066 .58505 L .62786 .58189 L p F P
0 g
s
.65 .758 .928 r
.28601 .58509 m .29676 .58166 L .30009 .58483 L p F P
0 g
s
.65 .757 .928 r
.29676 .58166 m .28601 .58509 L .28266 .58192 L p F P
0 g
s
.65 .758 .928 r
.45833 .58509 m .46939 .58167 L .47244 .58483 L p F P
0 g
s
.65 .758 .928 r
.46939 .58167 m .45833 .58509 L .45526 .58193 L p F P
0 g
s
.651 .759 .928 r
.81713 .58458 m .8288 .58114 L .83128 .58429 L p F P
0 g
s
.651 .759 .928 r
.8288 .58114 m .81713 .58458 L .81462 .58143 L p F P
0 g
s
.65 .757 .928 r
.12774 .58476 m .13823 .58134 L .14181 .58451 L p F P
0 g
s
.65 .757 .928 r
.13823 .58134 m .12774 .58476 L .12414 .5816 L p F P
0 g
s
.651 .758 .928 r
.64479 .58478 m .65617 .58135 L .65892 .58451 L p F P
0 g
s
.651 .758 .928 r
.65617 .58135 m .64479 .58478 L .64201 .58162 L p F P
0 g
s
.65 .758 .928 r
.30009 .58483 m .31087 .5814 L .31418 .58456 L p F P
0 g
s
.65 .758 .928 r
.31087 .5814 m .30009 .58483 L .29676 .58166 L p F P
0 g
s
.65 .758 .928 r
.47244 .58483 m .48352 .5814 L .48655 .58456 L p F P
0 g
s
.65 .758 .928 r
.48352 .5814 m .47244 .58483 L .46939 .58167 L p F P
0 g
s
.651 .759 .928 r
.83128 .58429 m .84298 .58084 L .84543 .58399 L p F P
0 g
s
.651 .759 .928 r
.84298 .58084 m .83128 .58429 L .8288 .58114 L p F P
0 g
s
.65 .757 .928 r
.14181 .58451 m .15232 .58109 L .15587 .58425 L p F P
0 g
s
.65 .757 .928 r
.15232 .58109 m .14181 .58451 L .13823 .58134 L p F P
0 g
s
.651 .758 .928 r
.65892 .58451 m .67033 .58108 L .67306 .58424 L p F P
0 g
s
.651 .758 .928 r
.67033 .58108 m .65892 .58451 L .65617 .58135 L p F P
0 g
s
.65 .758 .928 r
.31418 .58456 m .32499 .58114 L .32827 .5843 L p F P
0 g
s
.65 .758 .928 r
.32499 .58114 m .31418 .58456 L .31087 .5814 L p F P
0 g
s
.65 .758 .928 r
.48655 .58456 m .49766 .58114 L .50067 .5843 L p F P
0 g
s
.65 .758 .928 r
.49766 .58114 m .48655 .58456 L .48352 .5814 L p F P
0 g
s
.651 .759 .928 r
.84543 .58399 m .85716 .58054 L .85959 .58369 L p F P
0 g
s
.651 .759 .928 r
.85716 .58054 m .84543 .58399 L .84298 .58084 L p F P
0 g
s
.651 .758 .928 r
.67306 .58424 m .68449 .5808 L .6872 .58396 L p F P
0 g
s
.651 .758 .928 r
.68449 .5808 m .67306 .58424 L .67033 .58108 L p F P
0 g
s
.65 .757 .928 r
.15587 .58425 m .16641 .58083 L .16995 .584 L p F P
0 g
s
.65 .757 .928 r
.16641 .58083 m .15587 .58425 L .15232 .58109 L p F P
0 g
s
.65 .758 .928 r
.50067 .5843 m .5118 .58087 L .51478 .58403 L p F P
0 g
s
.65 .758 .928 r
.5118 .58087 m .50067 .5843 L .49766 .58114 L p F P
0 g
s
.65 .758 .928 r
.32827 .5843 m .3391 .58087 L .34236 .58404 L p F P
0 g
s
.65 .758 .928 r
.3391 .58087 m .32827 .5843 L .32499 .58114 L p F P
0 g
s
.651 .759 .928 r
.85959 .58369 m .87134 .58023 L .87376 .58338 L p F P
0 g
s
.651 .759 .928 r
.87134 .58023 m .85959 .58369 L .85716 .58054 L p F P
0 g
s
.651 .758 .928 r
.6872 .58396 m .69866 .58053 L .70135 .58369 L p F P
0 g
s
.651 .758 .928 r
.69866 .58053 m .6872 .58396 L .68449 .5808 L p F P
0 g
s
.65 .757 .928 r
.16995 .584 m .18051 .58057 L .18402 .58374 L p F P
0 g
s
.65 .757 .928 r
.18051 .58057 m .16995 .584 L .16641 .58083 L p F P
0 g
s
.651 .758 .928 r
.51478 .58403 m .52594 .5806 L .52891 .58377 L p F P
0 g
s
.651 .758 .928 r
.52594 .5806 m .51478 .58403 L .5118 .58087 L p F P
0 g
s
.65 .758 .928 r
.34236 .58404 m .35322 .58061 L .35646 .58378 L p F P
0 g
s
.65 .758 .928 r
.35322 .58061 m .34236 .58404 L .3391 .58087 L p F P
0 g
s
.652 .759 .928 r
.87376 .58338 m .88553 .57992 L .88792 .58307 L p F P
0 g
s
.651 .759 .928 r
.88553 .57992 m .87376 .58338 L .87134 .58023 L p F P
0 g
s
.651 .758 .928 r
.70135 .58369 m .71283 .58025 L .71549 .58341 L p F P
0 g
s
.651 .758 .928 r
.71283 .58025 m .70135 .58369 L .69866 .58053 L p F P
0 g
s
.65 .757 .928 r
.18402 .58374 m .19461 .58032 L .1981 .58348 L p F P
0 g
s
.65 .757 .928 r
.19461 .58032 m .18402 .58374 L .18051 .58057 L p F P
0 g
s
.651 .758 .928 r
.52891 .58377 m .54009 .58034 L .54303 .5835 L p F P
0 g
s
.651 .758 .928 r
.54009 .58034 m .52891 .58377 L .52594 .5806 L p F P
0 g
s
.65 .758 .928 r
.35646 .58378 m .36735 .58035 L .37057 .58352 L p F P
0 g
s
.65 .758 .928 r
.36735 .58035 m .35646 .58378 L .35322 .58061 L p F P
0 g
s
.652 .759 .928 r
.88792 .58307 m .89972 .5796 L .90209 .58275 L p F P
0 g
s
.652 .759 .928 r
.89972 .5796 m .88792 .58307 L .88553 .57992 L p F P
0 g
s
.651 .758 .928 r
.71549 .58341 m .727 .57997 L .72964 .58314 L p F P
0 g
s
.651 .758 .928 r
.727 .57997 m .71549 .58341 L .71283 .58025 L p F P
0 g
s
.65 .757 .928 r
.1981 .58348 m .20872 .58006 L .21218 .58322 L p F P
0 g
s
.65 .757 .928 r
.20872 .58006 m .1981 .58348 L .19461 .58032 L p F P
0 g
s
.651 .758 .928 r
.54303 .5835 m .55424 .58007 L .55716 .58323 L p F P
0 g
s
.651 .758 .928 r
.55424 .58007 m .54303 .5835 L .54009 .58034 L p F P
0 g
s
.65 .758 .928 r
.37057 .58352 m .38148 .58008 L .38467 .58325 L p F P
0 g
s
.65 .758 .928 r
.38148 .58008 m .37057 .58352 L .36735 .58035 L p F P
0 g
s
.652 .76 .928 r
.90209 .58275 m .91391 .57928 L .91626 .58243 L p F P
0 g
s
.652 .759 .928 r
.91391 .57928 m .90209 .58275 L .89972 .5796 L p F P
0 g
s
.651 .758 .928 r
.74118 .57969 m .72964 .58314 L .727 .57997 L p F P
0 g
s
.651 .758 .928 r
.72964 .58314 m .74118 .57969 L .7438 .58286 L p F P
0 g
s
.652 .76 .928 r
.92811 .57895 m .91626 .58243 L .91391 .57928 L p F P
0 g
s
.65 .757 .928 r
.21218 .58322 m .22282 .5798 L .22627 .58297 L p F P
0 g
s
.65 .757 .928 r
.22282 .5798 m .21218 .58322 L .20872 .58006 L p F P
0 g
s
.651 .758 .928 r
.55716 .58323 m .5684 .5798 L .57129 .58297 L p F P
0 g
s
.651 .758 .928 r
.5684 .5798 m .55716 .58323 L .55424 .58007 L p F P
0 g
s
.65 .758 .928 r
.39561 .57982 m .38467 .58325 L .38148 .58008 L p F P
0 g
s
.65 .758 .928 r
.38467 .58325 m .39561 .57982 L .39878 .58299 L p F P
0 g
s
.651 .758 .928 r
.7438 .58286 m .75536 .57941 L .75796 .58258 L p F P
0 g
s
.651 .758 .928 r
.75536 .57941 m .7438 .58286 L .74118 .57969 L p F P
0 g
s
.65 .757 .928 r
.22627 .58297 m .23694 .57954 L .24036 .58271 L p F P
0 g
s
.65 .757 .928 r
.23694 .57954 m .22627 .58297 L .22282 .5798 L p F P
0 g
s
.651 .758 .928 r
.57129 .58297 m .58255 .57953 L .58543 .5827 L p F P
0 g
s
.651 .758 .928 r
.58255 .57953 m .57129 .58297 L .5684 .5798 L p F P
0 g
s
.65 .758 .928 r
.39878 .58299 m .40975 .57956 L .4129 .58272 L p F P
0 g
s
.65 .758 .928 r
.40975 .57956 m .39878 .58299 L .39561 .57982 L p F P
0 g
s
.651 .758 .928 r
.75796 .58258 m .76954 .57913 L .77212 .58229 L p F P
0 g
s
.651 .758 .928 r
.76954 .57913 m .75796 .58258 L .75536 .57941 L p F P
0 g
s
.65 .757 .928 r
.06784 .5826 m .07823 .57918 L .08191 .58236 L p F P
0 g
s
0 0 .272 r
.40124 .28191 m .40122 .28196 L .40135 .27716 L p F P
0 g
s
0 0 .272 r
.40135 .27716 m .40137 .27711 L .40124 .28191 L p F P
0 g
s
.764 .494 .526 r
.40114 .28195 m .40122 .28196 L .40135 .27716 L p F P
0 g
s
.764 .494 .526 r
.40135 .27716 m .40126 .27715 L .40114 .28195 L p F P
0 g
s
.651 .758 .928 r
.58543 .5827 m .59672 .57926 L .59957 .58243 L p F P
0 g
s
.651 .758 .928 r
.59672 .57926 m .58543 .5827 L .58255 .57953 L p F P
0 g
s
.65 .757 .928 r
.24036 .58271 m .25105 .57927 L .25446 .58245 L p F P
0 g
s
.65 .757 .928 r
.25105 .57927 m .24036 .58271 L .23694 .57954 L p F P
0 g
s
.65 .758 .928 r
.4129 .58272 m .42389 .57929 L .42701 .58246 L p F P
0 g
s
.65 .758 .928 r
.42389 .57929 m .4129 .58272 L .40975 .57956 L p F P
0 g
s
.651 .758 .928 r
.77212 .58229 m .78373 .57884 L .78628 .58201 L p F P
0 g
s
.651 .758 .928 r
.78373 .57884 m .77212 .58229 L .76954 .57913 L p F P
0 g
s
.65 .757 .928 r
.08191 .58236 m .09233 .57893 L .09598 .5821 L p F P
0 g
s
.65 .757 .928 r
.09233 .57893 m .08191 .58236 L .07823 .57918 L p F P
0 g
s
.651 .758 .928 r
.59957 .58243 m .61088 .57899 L .61371 .58216 L p F P
0 g
s
.651 .758 .928 r
.61088 .57899 m .59957 .58243 L .59672 .57926 L p F P
0 g
s
.65 .757 .928 r
.25446 .58245 m .26517 .57901 L .26856 .58218 L p F P
0 g
s
.65 .757 .928 r
.26517 .57901 m .25446 .58245 L .25105 .57927 L p F P
0 g
s
.65 .758 .928 r
.42701 .58246 m .43803 .57903 L .44114 .5822 L p F P
0 g
s
.65 .758 .928 r
.43803 .57903 m .42701 .58246 L .42389 .57929 L p F P
0 g
s
.651 .758 .928 r
.78628 .58201 m .79792 .57856 L .80045 .58172 L p F P
0 g
s
.651 .758 .928 r
.79792 .57856 m .78628 .58201 L .78373 .57884 L p F P
0 g
s
.65 .757 .928 r
.09598 .5821 m .10643 .57868 L .11006 .58185 L p F P
0 g
s
.65 .757 .928 r
.10643 .57868 m .09598 .5821 L .09233 .57893 L p F P
0 g
s
.651 .758 .928 r
.61371 .58216 m .62505 .57872 L .62786 .58189 L p F P
0 g
s
.651 .758 .928 r
.62505 .57872 m .61371 .58216 L .61088 .57899 L p F P
0 g
s
.65 .757 .928 r
.26856 .58218 m .2793 .57875 L .28266 .58192 L p F P
0 g
s
.65 .757 .928 r
.2793 .57875 m .26856 .58218 L .26517 .57901 L p F P
0 g
s
.65 .758 .928 r
.44114 .5822 m .45218 .57876 L .45526 .58193 L p F P
0 g
s
.65 .758 .928 r
.45218 .57876 m .44114 .5822 L .43803 .57903 L p F P
0 g
s
.651 .758 .928 r
.80045 .58172 m .81211 .57827 L .81462 .58143 L p F P
0 g
s
.651 .758 .928 r
.81211 .57827 m .80045 .58172 L .79792 .57856 L p F P
0 g
s
.65 .757 .928 r
.11006 .58185 m .12053 .57842 L .12414 .5816 L p F P
0 g
s
.65 .757 .928 r
.12053 .57842 m .11006 .58185 L .10643 .57868 L p F P
0 g
s
.651 .758 .928 r
.62786 .58189 m .63923 .57845 L .64201 .58162 L p F P
0 g
s
.651 .758 .928 r
.63923 .57845 m .62786 .58189 L .62505 .57872 L p F P
0 g
s
.65 .757 .928 r
.28266 .58192 m .29343 .57849 L .29676 .58166 L p F P
0 g
s
.65 .757 .928 r
.29343 .57849 m .28266 .58192 L .2793 .57875 L p F P
0 g
s
.65 .758 .928 r
.45526 .58193 m .46633 .57849 L .46939 .58167 L p F P
0 g
s
.65 .758 .928 r
.46633 .57849 m .45526 .58193 L .45218 .57876 L p F P
0 g
s
.651 .759 .928 r
.81462 .58143 m .82631 .57797 L .8288 .58114 L p F P
0 g
s
.651 .758 .928 r
.82631 .57797 m .81462 .58143 L .81211 .57827 L p F P
0 g
s
.65 .757 .928 r
.12414 .5816 m .13464 .57817 L .13823 .58134 L p F P
0 g
s
.65 .757 .928 r
.13464 .57817 m .12414 .5816 L .12053 .57842 L p F P
0 g
s
.651 .758 .928 r
.64201 .58162 m .6534 .57818 L .65617 .58135 L p F P
0 g
s
.651 .758 .928 r
.6534 .57818 m .64201 .58162 L .63923 .57845 L p F P
0 g
s
.65 .758 .928 r
.29676 .58166 m .30756 .57823 L .31087 .5814 L p F P
0 g
s
.65 .757 .928 r
.30756 .57823 m .29676 .58166 L .29343 .57849 L p F P
0 g
s
.65 .758 .928 r
.46939 .58167 m .48048 .57823 L .48352 .5814 L p F P
0 g
s
.65 .758 .928 r
.48048 .57823 m .46939 .58167 L .46633 .57849 L p F P
0 g
s
.651 .759 .928 r
.8288 .58114 m .84051 .57768 L .84298 .58084 L p F P
0 g
s
.651 .759 .928 r
.84051 .57768 m .8288 .58114 L .82631 .57797 L p F P
0 g
s
.65 .757 .928 r
.13823 .58134 m .14875 .57791 L .15232 .58109 L p F P
0 g
s
.65 .757 .928 r
.14875 .57791 m .13823 .58134 L .13464 .57817 L p F P
0 g
s
.651 .758 .928 r
.65617 .58135 m .66758 .5779 L .67033 .58108 L p F P
0 g
s
.651 .758 .928 r
.66758 .5779 m .65617 .58135 L .6534 .57818 L p F P
0 g
s
.65 .758 .928 r
.31087 .5814 m .32169 .57796 L .32499 .58114 L p F P
0 g
s
.65 .758 .928 r
.32169 .57796 m .31087 .5814 L .30756 .57823 L p F P
0 g
s
.65 .758 .928 r
.48352 .5814 m .49464 .57796 L .49766 .58114 L p F P
0 g
s
.65 .758 .928 r
.49464 .57796 m .48352 .5814 L .48048 .57823 L p F P
0 g
s
.651 .759 .928 r
.84298 .58084 m .85471 .57737 L .85716 .58054 L p F P
0 g
s
.651 .759 .928 r
.85471 .57737 m .84298 .58084 L .84051 .57768 L p F P
0 g
s
.651 .758 .928 r
.67033 .58108 m .68177 .57763 L .68449 .5808 L p F P
0 g
s
.651 .758 .928 r
.68177 .57763 m .67033 .58108 L .66758 .5779 L p F P
0 g
s
.65 .757 .928 r
.15232 .58109 m .16287 .57766 L .16641 .58083 L p F P
0 g
s
.65 .757 .928 r
.16287 .57766 m .15232 .58109 L .14875 .57791 L p F P
0 g
s
.65 .758 .928 r
.49766 .58114 m .5088 .57769 L .5118 .58087 L p F P
0 g
s
.65 .758 .928 r
.5088 .57769 m .49766 .58114 L .49464 .57796 L p F P
0 g
s
.65 .758 .928 r
.32499 .58114 m .33583 .5777 L .3391 .58087 L p F P
0 g
s
.65 .758 .928 r
.33583 .5777 m .32499 .58114 L .32169 .57796 L p F P
0 g
s
.651 .759 .928 r
.85716 .58054 m .86892 .57707 L .87134 .58023 L p F P
0 g
s
.651 .759 .928 r
.86892 .57707 m .85716 .58054 L .85471 .57737 L p F P
0 g
s
.651 .758 .928 r
.68449 .5808 m .69596 .57735 L .69866 .58053 L p F P
0 g
s
.651 .758 .928 r
.69596 .57735 m .68449 .5808 L .68177 .57763 L p F P
0 g
s
.65 .757 .928 r
.16641 .58083 m .17699 .5774 L .18051 .58057 L p F P
0 g
s
.65 .757 .928 r
.17699 .5774 m .16641 .58083 L .16287 .57766 L p F P
0 g
s
.651 .758 .928 r
.5118 .58087 m .52297 .57743 L .52594 .5806 L p F P
0 g
s
.651 .758 .928 r
.52297 .57743 m .5118 .58087 L .5088 .57769 L p F P
0 g
s
.65 .758 .928 r
.3391 .58087 m .34998 .57743 L .35322 .58061 L p F P
0 g
s
.65 .758 .928 r
.34998 .57743 m .3391 .58087 L .33583 .5777 L p F P
0 g
s
.651 .759 .928 r
.87134 .58023 m .88313 .57676 L .88553 .57992 L p F P
0 g
s
.651 .759 .928 r
.88313 .57676 m .87134 .58023 L .86892 .57707 L p F P
0 g
s
.651 .758 .928 r
.69866 .58053 m .71015 .57708 L .71283 .58025 L p F P
0 g
s
.651 .758 .928 r
.71015 .57708 m .69866 .58053 L .69596 .57735 L p F P
0 g
s
.65 .757 .928 r
.18051 .58057 m .19111 .57714 L .19461 .58032 L p F P
0 g
s
.65 .757 .928 r
.19111 .57714 m .18051 .58057 L .17699 .5774 L p F P
0 g
s
.651 .758 .928 r
.52594 .5806 m .53714 .57716 L .54009 .58034 L p F P
0 g
s
.651 .758 .928 r
.53714 .57716 m .52594 .5806 L .52297 .57743 L p F P
0 g
s
.65 .758 .928 r
.35322 .58061 m .36412 .57717 L .36735 .58035 L p F P
0 g
s
.65 .758 .928 r
.36412 .57717 m .35322 .58061 L .34998 .57743 L p F P
0 g
s
.652 .759 .928 r
.88553 .57992 m .89734 .57644 L .89972 .5796 L p F P
0 g
s
.652 .759 .928 r
.89734 .57644 m .88553 .57992 L .88313 .57676 L p F P
0 g
s
.651 .758 .928 r
.71283 .58025 m .72434 .5768 L .727 .57997 L p F P
0 g
s
.651 .758 .928 r
.72434 .5768 m .71283 .58025 L .71015 .57708 L p F P
0 g
s
.65 .757 .928 r
.19461 .58032 m .20524 .57688 L .20872 .58006 L p F P
0 g
s
.65 .757 .928 r
.20524 .57688 m .19461 .58032 L .19111 .57714 L p F P
0 g
s
.651 .758 .928 r
.54009 .58034 m .55131 .57689 L .55424 .58007 L p F P
0 g
s
.651 .758 .928 r
.55131 .57689 m .54009 .58034 L .53714 .57716 L p F P
0 g
s
.65 .758 .928 r
.36735 .58035 m .37827 .57691 L .38148 .58008 L p F P
0 g
s
.65 .758 .928 r
.37827 .57691 m .36735 .58035 L .36412 .57717 L p F P
0 g
s
.652 .759 .928 r
.89972 .5796 m .91156 .57612 L .91391 .57928 L p F P
0 g
s
.652 .759 .928 r
.91156 .57612 m .89972 .5796 L .89734 .57644 L p F P
0 g
s
.651 .758 .928 r
.727 .57997 m .73854 .57652 L .74118 .57969 L p F P
0 g
s
.651 .758 .928 r
.73854 .57652 m .727 .57997 L .72434 .5768 L p F P
0 g
s
0 0 .272 r
.40111 .28672 m .40109 .28677 L .40122 .28196 L p F P
0 g
s
0 0 .272 r
.40122 .28196 m .40124 .28191 L .40111 .28672 L p F P
0 g
s
.764 .494 .526 r
.40101 .28676 m .40109 .28677 L .40122 .28196 L p F P
0 g
s
.764 .494 .526 r
.40122 .28196 m .40114 .28195 L .40101 .28676 L p F P
0 g
s
.65 .757 .928 r
.20872 .58006 m .21937 .57662 L .22282 .5798 L p F P
0 g
s
.65 .757 .928 r
.21937 .57662 m .20872 .58006 L .20524 .57688 L p F P
0 g
s
.652 .76 .928 r
.91391 .57928 m .92578 .57579 L .92811 .57895 L p F P
0 g
s
.652 .76 .928 r
.92578 .57579 m .91391 .57928 L .91156 .57612 L p F P
0 g
s
.651 .758 .928 r
.55424 .58007 m .56549 .57662 L .5684 .5798 L p F P
0 g
s
.651 .758 .928 r
.56549 .57662 m .55424 .58007 L .55131 .57689 L p F P
0 g
s
.65 .758 .928 r
.38148 .58008 m .39243 .57664 L .39561 .57982 L p F P
0 g
s
.65 .758 .928 r
.39243 .57664 m .38148 .58008 L .37827 .57691 L p F P
0 g
s
.651 .758 .928 r
.74118 .57969 m .75275 .57624 L .75536 .57941 L p F P
0 g
s
.651 .758 .928 r
.75275 .57624 m .74118 .57969 L .73854 .57652 L p F P
0 g
s
.652 .76 .928 r
.94 .57546 m .92811 .57895 L .92578 .57579 L p F P
0 g
s
.65 .757 .928 r
.22282 .5798 m .2335 .57636 L .23694 .57954 L p F P
0 g
s
.65 .757 .928 r
.2335 .57636 m .22282 .5798 L .21937 .57662 L p F P
0 g
s
.651 .758 .928 r
.5684 .5798 m .57967 .57635 L .58255 .57953 L p F P
0 g
s
.651 .758 .928 r
.57967 .57635 m .5684 .5798 L .56549 .57662 L p F P
0 g
s
.65 .758 .928 r
.40659 .57638 m .39561 .57982 L .39243 .57664 L p F P
0 g
s
.65 .758 .928 r
.39561 .57982 m .40659 .57638 L .40975 .57956 L p F P
0 g
s
.651 .758 .928 r
.75536 .57941 m .76695 .57596 L .76954 .57913 L p F P
0 g
s
.651 .758 .928 r
.76695 .57596 m .75536 .57941 L .75275 .57624 L p F P
0 g
s
.651 .758 .928 r
.58255 .57953 m .59385 .57608 L .59672 .57926 L p F P
0 g
s
.651 .758 .928 r
.59385 .57608 m .58255 .57953 L .57967 .57635 L p F P
0 g
s
.65 .757 .928 r
.23694 .57954 m .24764 .57609 L .25105 .57927 L p F P
0 g
s
.65 .757 .928 r
.24764 .57609 m .23694 .57954 L .2335 .57636 L p F P
0 g
s
.65 .758 .928 r
.40975 .57956 m .42075 .57611 L .42389 .57929 L p F P
0 g
s
.65 .758 .928 r
.42075 .57611 m .40975 .57956 L .40659 .57638 L p F P
0 g
s
.651 .758 .928 r
.76954 .57913 m .78116 .57567 L .78373 .57884 L p F P
0 g
s
.651 .758 .928 r
.78116 .57567 m .76954 .57913 L .76695 .57596 L p F P
0 g
s
.65 .757 .928 r
.07823 .57918 m .08866 .57575 L .09233 .57893 L p F P
0 g
s
.651 .758 .928 r
.59672 .57926 m .60804 .57581 L .61088 .57899 L p F P
0 g
s
.651 .758 .928 r
.60804 .57581 m .59672 .57926 L .59385 .57608 L p F P
0 g
s
.65 .757 .928 r
.25105 .57927 m .26178 .57583 L .26517 .57901 L p F P
0 g
s
.65 .757 .928 r
.26178 .57583 m .25105 .57927 L .24764 .57609 L p F P
0 g
s
.65 .758 .928 r
.42389 .57929 m .43491 .57584 L .43803 .57903 L p F P
0 g
s
.65 .758 .928 r
.43491 .57584 m .42389 .57929 L .42075 .57611 L p F P
0 g
s
.651 .758 .928 r
.78373 .57884 m .79537 .57538 L .79792 .57856 L p F P
0 g
s
.651 .758 .928 r
.79537 .57538 m .78373 .57884 L .78116 .57567 L p F P
0 g
s
.65 .757 .928 r
.09233 .57893 m .10278 .5755 L .10643 .57868 L p F P
0 g
s
.65 .757 .928 r
.10278 .5755 m .09233 .57893 L .08866 .57575 L p F P
0 g
s
.651 .758 .928 r
.61088 .57899 m .62223 .57554 L .62505 .57872 L p F P
0 g
s
.651 .758 .928 r
.62223 .57554 m .61088 .57899 L .60804 .57581 L p F P
0 g
s
.65 .757 .928 r
.26517 .57901 m .27593 .57557 L .2793 .57875 L p F P
0 g
s
.65 .757 .928 r
.27593 .57557 m .26517 .57901 L .26178 .57583 L p F P
0 g
s
.65 .758 .928 r
.43803 .57903 m .44908 .57558 L .45218 .57876 L p F P
0 g
s
.65 .758 .928 r
.44908 .57558 m .43803 .57903 L .43491 .57584 L p F P
0 g
s
.651 .758 .928 r
.79792 .57856 m .80959 .57509 L .81211 .57827 L p F P
0 g
s
.651 .758 .928 r
.80959 .57509 m .79792 .57856 L .79537 .57538 L p F P
0 g
s
.65 .757 .928 r
.10643 .57868 m .11691 .57524 L .12053 .57842 L p F P
0 g
s
.65 .757 .928 r
.11691 .57524 m .10643 .57868 L .10278 .5755 L p F P
0 g
s
.651 .758 .928 r
.62505 .57872 m .63643 .57527 L .63923 .57845 L p F P
0 g
s
.651 .758 .928 r
.63643 .57527 m .62505 .57872 L .62223 .57554 L p F P
0 g
s
.65 .757 .928 r
.2793 .57875 m .29008 .57531 L .29343 .57849 L p F P
0 g
s
.65 .757 .928 r
.29008 .57531 m .2793 .57875 L .27593 .57557 L p F P
0 g
s
.65 .758 .928 r
.45218 .57876 m .46326 .57531 L .46633 .57849 L p F P
0 g
s
.65 .758 .928 r
.46326 .57531 m .45218 .57876 L .44908 .57558 L p F P
0 g
s
.651 .758 .928 r
.81211 .57827 m .82381 .5748 L .82631 .57797 L p F P
0 g
s
.651 .758 .928 r
.82381 .5748 m .81211 .57827 L .80959 .57509 L p F P
0 g
s
.65 .757 .928 r
.12053 .57842 m .13104 .57498 L .13464 .57817 L p F P
0 g
s
.65 .757 .928 r
.13104 .57498 m .12053 .57842 L .11691 .57524 L p F P
0 g
s
.651 .758 .928 r
.63923 .57845 m .65063 .575 L .6534 .57818 L p F P
0 g
s
.651 .758 .928 r
.65063 .575 m .63923 .57845 L .63643 .57527 L p F P
0 g
s
.65 .757 .928 r
.29343 .57849 m .30423 .57504 L .30756 .57823 L p F P
0 g
s
.65 .757 .928 r
.30423 .57504 m .29343 .57849 L .29008 .57531 L p F P
0 g
s
.65 .758 .928 r
.46633 .57849 m .47743 .57504 L .48048 .57823 L p F P
0 g
s
.65 .758 .928 r
.47743 .57504 m .46633 .57849 L .46326 .57531 L p F P
0 g
s
.651 .759 .928 r
.82631 .57797 m .83803 .5745 L .84051 .57768 L p F P
0 g
s
.651 .759 .928 r
.83803 .5745 m .82631 .57797 L .82381 .5748 L p F P
0 g
s
.65 .757 .928 r
.13464 .57817 m .14517 .57473 L .14875 .57791 L p F P
0 g
s
.65 .757 .928 r
.14517 .57473 m .13464 .57817 L .13104 .57498 L p F P
0 g
s
.651 .758 .928 r
.6534 .57818 m .66483 .57472 L .66758 .5779 L p F P
0 g
s
.651 .758 .928 r
.66483 .57472 m .6534 .57818 L .65063 .575 L p F P
0 g
s
.65 .758 .928 r
.30756 .57823 m .31839 .57478 L .32169 .57796 L p F P
0 g
s
.65 .758 .928 r
.31839 .57478 m .30756 .57823 L .30423 .57504 L p F P
0 g
s
.65 .758 .928 r
.48048 .57823 m .49161 .57478 L .49464 .57796 L p F P
0 g
s
.65 .758 .928 r
.49161 .57478 m .48048 .57823 L .47743 .57504 L p F P
0 g
s
.651 .759 .928 r
.84051 .57768 m .85226 .5742 L .85471 .57737 L p F P
0 g
s
.651 .759 .928 r
.85226 .5742 m .84051 .57768 L .83803 .5745 L p F P
0 g
s
.651 .758 .928 r
.66758 .5779 m .67904 .57445 L .68177 .57763 L p F P
0 g
s
.651 .758 .928 r
.67904 .57445 m .66758 .5779 L .66483 .57472 L p F P
0 g
s
.65 .757 .928 r
.14875 .57791 m .15931 .57447 L .16287 .57766 L p F P
0 g
s
.65 .757 .928 r
.15931 .57447 m .14875 .57791 L .14517 .57473 L p F P
0 g
s
.65 .758 .928 r
.49464 .57796 m .5058 .57451 L .5088 .57769 L p F P
0 g
s
.65 .758 .928 r
.5058 .57451 m .49464 .57796 L .49161 .57478 L p F P
0 g
s
.65 .758 .928 r
.32169 .57796 m .33255 .57451 L .33583 .5777 L p F P
0 g
s
.65 .758 .928 r
.33255 .57451 m .32169 .57796 L .31839 .57478 L p F P
0 g
s
.651 .759 .928 r
.85471 .57737 m .86649 .5739 L .86892 .57707 L p F P
0 g
s
.651 .759 .928 r
.86649 .5739 m .85471 .57737 L .85226 .5742 L p F P
0 g
s
.651 .758 .928 r
.68177 .57763 m .69325 .57417 L .69596 .57735 L p F P
0 g
s
.651 .758 .928 r
.69325 .57417 m .68177 .57763 L .67904 .57445 L p F P
0 g
s
.65 .757 .928 r
.16287 .57766 m .17345 .57421 L .17699 .5774 L p F P
0 g
s
.65 .757 .928 r
.17345 .57421 m .16287 .57766 L .15931 .57447 L p F P
0 g
s
.651 .758 .928 r
.5088 .57769 m .51999 .57424 L .52297 .57743 L p F P
0 g
s
.651 .758 .928 r
.51999 .57424 m .5088 .57769 L .5058 .57451 L p F P
0 g
s
.65 .758 .928 r
.33583 .5777 m .34672 .57425 L .34998 .57743 L p F P
0 g
s
.65 .758 .928 r
.34672 .57425 m .33583 .5777 L .33255 .57451 L p F P
0 g
s
.651 .759 .928 r
.86892 .57707 m .88072 .57359 L .88313 .57676 L p F P
0 g
s
.651 .759 .928 r
.88072 .57359 m .86892 .57707 L .86649 .5739 L p F P
0 g
s
.651 .758 .928 r
.69596 .57735 m .70746 .57389 L .71015 .57708 L p F P
0 g
s
.651 .758 .928 r
.70746 .57389 m .69596 .57735 L .69325 .57417 L p F P
0 g
s
.65 .757 .928 r
.17699 .5774 m .1876 .57395 L .19111 .57714 L p F P
0 g
s
.65 .757 .928 r
.1876 .57395 m .17699 .5774 L .17345 .57421 L p F P
0 g
s
0 0 .273 r
.40098 .29155 m .40096 .2916 L .40109 .28677 L p F P
0 g
s
0 0 .273 r
.40109 .28677 m .40111 .28672 L .40098 .29155 L p F P
0 g
s
.764 .494 .526 r
.40089 .29158 m .40096 .2916 L .40109 .28677 L p F P
0 g
s
.764 .494 .526 r
.40109 .28677 m .40101 .28676 L .40089 .29158 L p F P
0 g
s
.651 .758 .928 r
.52297 .57743 m .53418 .57397 L .53714 .57716 L p F P
0 g
s
.651 .758 .928 r
.53418 .57397 m .52297 .57743 L .51999 .57424 L p F P
0 g
s
.65 .758 .928 r
.34998 .57743 m .36089 .57398 L .36412 .57717 L p F P
0 g
s
.65 .758 .928 r
.36089 .57398 m .34998 .57743 L .34672 .57425 L p F P
0 g
s
.652 .759 .928 r
.88313 .57676 m .89496 .57327 L .89734 .57644 L p F P
0 g
s
.652 .759 .928 r
.89496 .57327 m .88313 .57676 L .88072 .57359 L p F P
0 g
s
.651 .758 .928 r
.71015 .57708 m .72168 .57362 L .72434 .5768 L p F P
0 g
s
.651 .758 .928 r
.72168 .57362 m .71015 .57708 L .70746 .57389 L p F P
0 g
s
.65 .757 .928 r
.19111 .57714 m .20175 .57369 L .20524 .57688 L p F P
0 g
s
.65 .757 .928 r
.20175 .57369 m .19111 .57714 L .1876 .57395 L p F P
0 g
s
.651 .758 .928 r
.53714 .57716 m .54837 .5737 L .55131 .57689 L p F P
0 g
s
.651 .758 .928 r
.54837 .5737 m .53714 .57716 L .53418 .57397 L p F P
0 g
s
.65 .758 .928 r
.36412 .57717 m .37506 .57372 L .37827 .57691 L p F P
0 g
s
.65 .758 .928 r
.37506 .57372 m .36412 .57717 L .36089 .57398 L p F P
0 g
s
.652 .759 .928 r
.89734 .57644 m .9092 .57295 L .91156 .57612 L p F P
0 g
s
.652 .759 .928 r
.9092 .57295 m .89734 .57644 L .89496 .57327 L p F P
0 g
s
.651 .758 .928 r
.7359 .57334 m .72434 .5768 L .72168 .57362 L p F P
0 g
s
.651 .758 .928 r
.72434 .5768 m .7359 .57334 L .73854 .57652 L p F P
0 g
s
.65 .757 .928 r
.20524 .57688 m .2159 .57343 L .21937 .57662 L p F P
0 g
s
.65 .757 .928 r
.2159 .57343 m .20524 .57688 L .20175 .57369 L p F P
0 g
s
.651 .758 .928 r
.55131 .57689 m .56257 .57343 L .56549 .57662 L p F P
0 g
s
.651 .758 .928 r
.56257 .57343 m .55131 .57689 L .54837 .5737 L p F P
0 g
s
.65 .758 .928 r
.37827 .57691 m .38923 .57345 L .39243 .57664 L p F P
0 g
s
.65 .758 .928 r
.38923 .57345 m .37827 .57691 L .37506 .57372 L p F P
0 g
s
.652 .76 .928 r
.91156 .57612 m .92344 .57262 L .92578 .57579 L p F P
0 g
s
.652 .76 .928 r
.92344 .57262 m .91156 .57612 L .9092 .57295 L p F P
0 g
s
.651 .758 .928 r
.73854 .57652 m .75013 .57305 L .75275 .57624 L p F P
0 g
s
.651 .758 .928 r
.75013 .57305 m .73854 .57652 L .7359 .57334 L p F P
0 g
s
.652 .76 .928 r
.92578 .57579 m .93768 .57229 L .94 .57546 L p F P
0 g
s
.652 .76 .928 r
.93768 .57229 m .92578 .57579 L .92344 .57262 L p F P
0 g
s
.65 .757 .928 r
.21937 .57662 m .23006 .57316 L .2335 .57636 L p F P
0 g
s
.65 .757 .928 r
.23006 .57316 m .21937 .57662 L .2159 .57343 L p F P
0 g
s
.651 .758 .928 r
.56549 .57662 m .57678 .57316 L .57967 .57635 L p F P
0 g
s
.651 .758 .928 r
.57678 .57316 m .56549 .57662 L .56257 .57343 L p F P
0 g
s
.65 .758 .928 r
.39243 .57664 m .40341 .57319 L .40659 .57638 L p F P
0 g
s
.65 .758 .928 r
.40341 .57319 m .39243 .57664 L .38923 .57345 L p F P
0 g
s
.651 .758 .928 r
.76436 .57277 m .75275 .57624 L .75013 .57305 L p F P
0 g
s
.651 .758 .928 r
.75275 .57624 m .76436 .57277 L .76695 .57596 L p F P
0 g
s
.652 .76 .929 r
.95193 .57194 m .94 .57546 L .93768 .57229 L p F P
0 g
s
.651 .758 .928 r
.57967 .57635 m .59098 .57289 L .59385 .57608 L p F P
0 g
s
.651 .758 .928 r
.59098 .57289 m .57967 .57635 L .57678 .57316 L p F P
0 g
s
.65 .757 .928 r
.2335 .57636 m .24422 .5729 L .24764 .57609 L p F P
0 g
s
.65 .757 .928 r
.24422 .5729 m .2335 .57636 L .23006 .57316 L p F P
0 g
s
.65 .758 .928 r
.40659 .57638 m .4176 .57292 L .42075 .57611 L p F P
0 g
s
.65 .758 .928 r
.4176 .57292 m .40659 .57638 L .40341 .57319 L p F P
0 g
s
.651 .758 .928 r
.76695 .57596 m .77859 .57249 L .78116 .57567 L p F P
0 g
s
.651 .758 .928 r
.77859 .57249 m .76695 .57596 L .76436 .57277 L p F P
0 g
s
.651 .758 .928 r
.59385 .57608 m .60519 .57262 L .60804 .57581 L p F P
0 g
s
.651 .758 .928 r
.60519 .57262 m .59385 .57608 L .59098 .57289 L p F P
0 g
s
.65 .757 .928 r
.24764 .57609 m .25838 .57264 L .26178 .57583 L p F P
0 g
s
.65 .757 .928 r
.25838 .57264 m .24764 .57609 L .24422 .5729 L p F P
0 g
s
.65 .758 .928 r
.42075 .57611 m .43179 .57265 L .43491 .57584 L p F P
0 g
s
.65 .758 .928 r
.43179 .57265 m .42075 .57611 L .4176 .57292 L p F P
0 g
s
.651 .758 .928 r
.78116 .57567 m .79282 .5722 L .79537 .57538 L p F P
0 g
s
.651 .758 .928 r
.79282 .5722 m .78116 .57567 L .77859 .57249 L p F P
0 g
s
.65 .757 .928 r
.08866 .57575 m .09913 .5723 L .10278 .5755 L p F P
0 g
s
.651 .758 .928 r
.60804 .57581 m .61941 .57235 L .62223 .57554 L p F P
0 g
s
.651 .758 .928 r
.61941 .57235 m .60804 .57581 L .60519 .57262 L p F P
0 g
s
.65 .757 .928 r
.26178 .57583 m .27255 .57238 L .27593 .57557 L p F P
0 g
s
.65 .757 .928 r
.27255 .57238 m .26178 .57583 L .25838 .57264 L p F P
0 g
s
.65 .758 .928 r
.43491 .57584 m .44598 .57238 L .44908 .57558 L p F P
0 g
s
.65 .758 .928 r
.44598 .57238 m .43491 .57584 L .43179 .57265 L p F P
0 g
s
.651 .758 .928 r
.79537 .57538 m .80706 .57191 L .80959 .57509 L p F P
0 g
s
.651 .758 .928 r
.80706 .57191 m .79537 .57538 L .79282 .5722 L p F P
0 g
s
.65 .757 .928 r
.10278 .5755 m .11327 .57205 L .11691 .57524 L p F P
0 g
s
.65 .757 .928 r
.11327 .57205 m .10278 .5755 L .09913 .5723 L p F P
0 g
s
.651 .758 .928 r
.62223 .57554 m .63363 .57208 L .63643 .57527 L p F P
0 g
s
.651 .758 .928 r
.63363 .57208 m .62223 .57554 L .61941 .57235 L p F P
0 g
s
.65 .757 .928 r
.27593 .57557 m .28672 .57211 L .29008 .57531 L p F P
0 g
s
.65 .757 .928 r
.28672 .57211 m .27593 .57557 L .27255 .57238 L p F P
0 g
s
.65 .758 .928 r
.44908 .57558 m .46017 .57212 L .46326 .57531 L p F P
0 g
s
.65 .758 .928 r
.46017 .57212 m .44908 .57558 L .44598 .57238 L p F P
0 g
s
.651 .758 .928 r
.80959 .57509 m .82131 .57161 L .82381 .5748 L p F P
0 g
s
.651 .758 .928 r
.82131 .57161 m .80959 .57509 L .80706 .57191 L p F P
0 g
s
.65 .757 .928 r
.11691 .57524 m .12743 .57179 L .13104 .57498 L p F P
0 g
s
.65 .757 .928 r
.12743 .57179 m .11691 .57524 L .11327 .57205 L p F P
0 g
s
.651 .758 .928 r
.63643 .57527 m .64785 .5718 L .65063 .575 L p F P
0 g
s
.651 .758 .928 r
.64785 .5718 m .63643 .57527 L .63363 .57208 L p F P
0 g
s
.65 .757 .928 r
.29008 .57531 m .3009 .57185 L .30423 .57504 L p F P
0 g
s
.65 .757 .928 r
.3009 .57185 m .29008 .57531 L .28672 .57211 L p F P
0 g
s
.65 .758 .928 r
.46326 .57531 m .47437 .57185 L .47743 .57504 L p F P
0 g
s
.65 .758 .928 r
.47437 .57185 m .46326 .57531 L .46017 .57212 L p F P
0 g
s
.651 .759 .928 r
.82381 .5748 m .83555 .57132 L .83803 .5745 L p F P
0 g
s
.651 .758 .928 r
.83555 .57132 m .82381 .5748 L .82131 .57161 L p F P
0 g
s
.65 .757 .928 r
.13104 .57498 m .14158 .57153 L .14517 .57473 L p F P
0 g
s
.65 .757 .928 r
.14158 .57153 m .13104 .57498 L .12743 .57179 L p F P
0 g
s
.651 .758 .928 r
.65063 .575 m .66207 .57153 L .66483 .57472 L p F P
0 g
s
.651 .758 .928 r
.66207 .57153 m .65063 .575 L .64785 .5718 L p F P
0 g
s
.65 .758 .928 r
.30423 .57504 m .31508 .57158 L .31839 .57478 L p F P
0 g
s
.65 .757 .928 r
.31508 .57158 m .30423 .57504 L .3009 .57185 L p F P
0 g
s
.65 .758 .928 r
.47743 .57504 m .48858 .57158 L .49161 .57478 L p F P
0 g
s
.65 .758 .928 r
.48858 .57158 m .47743 .57504 L .47437 .57185 L p F P
0 g
s
.651 .759 .928 r
.83803 .5745 m .8498 .57102 L .85226 .5742 L p F P
0 g
s
.651 .759 .928 r
.8498 .57102 m .83803 .5745 L .83555 .57132 L p F P
0 g
s
.651 .758 .928 r
.66483 .57472 m .6763 .57125 L .67904 .57445 L p F P
0 g
s
.651 .758 .928 r
.6763 .57125 m .66483 .57472 L .66207 .57153 L p F P
0 g
s
.65 .757 .928 r
.14517 .57473 m .15574 .57127 L .15931 .57447 L p F P
0 g
s
.65 .757 .928 r
.15574 .57127 m .14517 .57473 L .14158 .57153 L p F P
0 g
s
0 0 .273 r
.40085 .29639 m .40083 .29643 L .40096 .2916 L p F P
0 g
s
0 0 .273 r
.40096 .2916 m .40098 .29155 L .40085 .29639 L p F P
0 g
s
.764 .494 .526 r
.40076 .29642 m .40083 .29643 L .40096 .2916 L p F P
0 g
s
.764 .494 .526 r
.40096 .2916 m .40089 .29158 L .40076 .29642 L p F P
0 g
s
.65 .758 .928 r
.49161 .57478 m .50278 .57131 L .5058 .57451 L p F P
0 g
s
.65 .758 .928 r
.50278 .57131 m .49161 .57478 L .48858 .57158 L p F P
0 g
s
.65 .758 .928 r
.31839 .57478 m .32926 .57132 L .33255 .57451 L p F P
0 g
s
.65 .758 .928 r
.32926 .57132 m .31839 .57478 L .31508 .57158 L p F P
0 g
s
.651 .759 .928 r
.85226 .5742 m .86405 .57071 L .86649 .5739 L p F P
0 g
s
.651 .759 .928 r
.86405 .57071 m .85226 .5742 L .8498 .57102 L p F P
0 g
s
.651 .758 .928 r
.67904 .57445 m .69053 .57098 L .69325 .57417 L p F P
0 g
s
.651 .758 .928 r
.69053 .57098 m .67904 .57445 L .6763 .57125 L p F P
0 g
s
.65 .757 .928 r
.15931 .57447 m .1699 .57101 L .17345 .57421 L p F P
0 g
s
.65 .757 .928 r
.1699 .57101 m .15931 .57447 L .15574 .57127 L p F P
0 g
s
.651 .758 .928 r
.5058 .57451 m .51699 .57104 L .51999 .57424 L p F P
0 g
s
.651 .758 .928 r
.51699 .57104 m .5058 .57451 L .50278 .57131 L p F P
0 g
s
.65 .758 .928 r
.33255 .57451 m .34345 .57105 L .34672 .57425 L p F P
0 g
s
.65 .758 .928 r
.34345 .57105 m .33255 .57451 L .32926 .57132 L p F P
0 g
s
.651 .759 .928 r
.86649 .5739 m .87831 .5704 L .88072 .57359 L p F P
0 g
s
.651 .759 .928 r
.87831 .5704 m .86649 .5739 L .86405 .57071 L p F P
0 g
s
.651 .758 .928 r
.69325 .57417 m .70477 .5707 L .70746 .57389 L p F P
0 g
s
.651 .758 .928 r
.70477 .5707 m .69325 .57417 L .69053 .57098 L p F P
0 g
s
.65 .757 .928 r
.17345 .57421 m .18407 .57075 L .1876 .57395 L p F P
0 g
s
.65 .757 .928 r
.18407 .57075 m .17345 .57421 L .1699 .57101 L p F P
0 g
s
.651 .758 .928 r
.51999 .57424 m .53121 .57077 L .53418 .57397 L p F P
0 g
s
.651 .758 .928 r
.53121 .57077 m .51999 .57424 L .51699 .57104 L p F P
0 g
s
.65 .758 .928 r
.34672 .57425 m .35764 .57078 L .36089 .57398 L p F P
0 g
s
.65 .758 .928 r
.35764 .57078 m .34672 .57425 L .34345 .57105 L p F P
0 g
s
.652 .759 .928 r
.88072 .57359 m .89257 .57009 L .89496 .57327 L p F P
0 g
s
.652 .759 .928 r
.89257 .57009 m .88072 .57359 L .87831 .5704 L p F P
0 g
s
.651 .758 .928 r
.70746 .57389 m .71901 .57042 L .72168 .57362 L p F P
0 g
s
.651 .758 .928 r
.71901 .57042 m .70746 .57389 L .70477 .5707 L p F P
0 g
s
.65 .757 .928 r
.1876 .57395 m .19824 .57049 L .20175 .57369 L p F P
0 g
s
.65 .757 .928 r
.19824 .57049 m .1876 .57395 L .18407 .57075 L p F P
0 g
s
.651 .758 .928 r
.53418 .57397 m .54542 .57051 L .54837 .5737 L p F P
0 g
s
.651 .758 .928 r
.54542 .57051 m .53418 .57397 L .53121 .57077 L p F P
0 g
s
.65 .758 .928 r
.36089 .57398 m .37183 .57052 L .37506 .57372 L p F P
0 g
s
.65 .758 .928 r
.37183 .57052 m .36089 .57398 L .35764 .57078 L p F P
0 g
s
.652 .759 .928 r
.89496 .57327 m .90683 .56977 L .9092 .57295 L p F P
0 g
s
.652 .759 .928 r
.90683 .56977 m .89496 .57327 L .89257 .57009 L p F P
0 g
s
.651 .758 .928 r
.72168 .57362 m .73326 .57014 L .7359 .57334 L p F P
0 g
s
.651 .758 .928 r
.73326 .57014 m .72168 .57362 L .71901 .57042 L p F P
0 g
s
.65 .757 .928 r
.20175 .57369 m .21242 .57023 L .2159 .57343 L p F P
0 g
s
.65 .757 .928 r
.21242 .57023 m .20175 .57369 L .19824 .57049 L p F P
0 g
s
.651 .758 .928 r
.54837 .5737 m .55965 .57023 L .56257 .57343 L p F P
0 g
s
.651 .758 .928 r
.55965 .57023 m .54837 .5737 L .54542 .57051 L p F P
0 g
s
.65 .758 .928 r
.37506 .57372 m .38603 .57025 L .38923 .57345 L p F P
0 g
s
.65 .758 .928 r
.38603 .57025 m .37506 .57372 L .37183 .57052 L p F P
0 g
s
.652 .76 .928 r
.9092 .57295 m .92109 .56944 L .92344 .57262 L p F P
0 g
s
.652 .759 .928 r
.92109 .56944 m .9092 .57295 L .90683 .56977 L p F P
0 g
s
.651 .758 .928 r
.7475 .56986 m .7359 .57334 L .73326 .57014 L p F P
0 g
s
.651 .758 .928 r
.7359 .57334 m .7475 .56986 L .75013 .57305 L p F P
0 g
s
.652 .76 .928 r
.92344 .57262 m .93536 .56911 L .93768 .57229 L p F P
0 g
s
.652 .76 .928 r
.93536 .56911 m .92344 .57262 L .92109 .56944 L p F P
0 g
s
.65 .757 .928 r
.2159 .57343 m .2266 .56996 L .23006 .57316 L p F P
0 g
s
.65 .757 .928 r
.2266 .56996 m .2159 .57343 L .21242 .57023 L p F P
0 g
s
.651 .758 .928 r
.56257 .57343 m .57387 .56996 L .57678 .57316 L p F P
0 g
s
.651 .758 .928 r
.57387 .56996 m .56257 .57343 L .55965 .57023 L p F P
0 g
s
.65 .758 .928 r
.38923 .57345 m .40023 .56999 L .40341 .57319 L p F P
0 g
s
.65 .758 .928 r
.40023 .56999 m .38923 .57345 L .38603 .57025 L p F P
0 g
s
.651 .758 .928 r
.75013 .57305 m .76175 .56958 L .76436 .57277 L p F P
0 g
s
.651 .758 .928 r
.76175 .56958 m .75013 .57305 L .7475 .56986 L p F P
0 g
s
.652 .76 .929 r
.93768 .57229 m .94963 .56877 L .95193 .57194 L p F P
0 g
s
.652 .76 .928 r
.94963 .56877 m .93768 .57229 L .93536 .56911 L p F P
0 g
s
.651 .758 .928 r
.57678 .57316 m .5881 .56969 L .59098 .57289 L p F P
0 g
s
.651 .758 .928 r
.5881 .56969 m .57678 .57316 L .57387 .56996 L p F P
0 g
s
.65 .757 .928 r
.23006 .57316 m .24078 .5697 L .24422 .5729 L p F P
0 g
s
.65 .757 .928 r
.24078 .5697 m .23006 .57316 L .2266 .56996 L p F P
0 g
s
.65 .758 .928 r
.40341 .57319 m .41444 .56972 L .4176 .57292 L p F P
0 g
s
.65 .758 .928 r
.41444 .56972 m .40341 .57319 L .40023 .56999 L p F P
0 g
s
.651 .758 .928 r
.77601 .56929 m .76436 .57277 L .76175 .56958 L p F P
0 g
s
.651 .758 .928 r
.76436 .57277 m .77601 .56929 L .77859 .57249 L p F P
0 g
s
.651 .758 .928 r
.59098 .57289 m .60233 .56942 L .60519 .57262 L p F P
0 g
s
.651 .758 .928 r
.60233 .56942 m .59098 .57289 L .5881 .56969 L p F P
0 g
s
.65 .757 .928 r
.24422 .5729 m .25497 .56944 L .25838 .57264 L p F P
0 g
s
.65 .757 .928 r
.25497 .56944 m .24422 .5729 L .24078 .5697 L p F P
0 g
s
.65 .758 .928 r
.4176 .57292 m .42865 .56945 L .43179 .57265 L p F P
0 g
s
.65 .758 .928 r
.42865 .56945 m .4176 .57292 L .41444 .56972 L p F P
0 g
s
.651 .758 .928 r
.77859 .57249 m .79027 .569 L .79282 .5722 L p F P
0 g
s
.651 .758 .928 r
.79027 .569 m .77859 .57249 L .77601 .56929 L p F P
0 g
s
.651 .758 .928 r
.60519 .57262 m .61657 .56915 L .61941 .57235 L p F P
0 g
s
.651 .758 .928 r
.61657 .56915 m .60519 .57262 L .60233 .56942 L p F P
0 g
s
.65 .757 .928 r
.25838 .57264 m .26916 .56917 L .27255 .57238 L p F P
0 g
s
.65 .757 .928 r
.26916 .56917 m .25838 .57264 L .25497 .56944 L p F P
0 g
s
.65 .758 .928 r
.43179 .57265 m .44286 .56918 L .44598 .57238 L p F P
0 g
s
.65 .758 .928 r
.44286 .56918 m .43179 .57265 L .42865 .56945 L p F P
0 g
s
.651 .758 .928 r
.79282 .5722 m .80453 .56871 L .80706 .57191 L p F P
0 g
s
.651 .758 .928 r
.80453 .56871 m .79282 .5722 L .79027 .569 L p F P
0 g
s
.65 .757 .928 r
.09913 .5723 m .10963 .56884 L .11327 .57205 L p F P
0 g
s
.651 .758 .928 r
.61941 .57235 m .63081 .56888 L .63363 .57208 L p F P
0 g
s
.651 .758 .928 r
.63081 .56888 m .61941 .57235 L .61657 .56915 L p F P
0 g
s
.65 .757 .928 r
.27255 .57238 m .28335 .56891 L .28672 .57211 L p F P
0 g
s
.65 .757 .928 r
.28335 .56891 m .27255 .57238 L .26916 .56917 L p F P
0 g
s
.65 .758 .928 r
.44598 .57238 m .45708 .56891 L .46017 .57212 L p F P
0 g
s
.65 .758 .928 r
.45708 .56891 m .44598 .57238 L .44286 .56918 L p F P
0 g
s
.651 .758 .928 r
.80706 .57191 m .81879 .56842 L .82131 .57161 L p F P
0 g
s
.651 .758 .928 r
.81879 .56842 m .80706 .57191 L .80453 .56871 L p F P
0 g
s
.65 .757 .928 r
.11327 .57205 m .1238 .56858 L .12743 .57179 L p F P
0 g
s
.65 .757 .928 r
.1238 .56858 m .11327 .57205 L .10963 .56884 L p F P
0 g
s
.651 .758 .928 r
.63363 .57208 m .64506 .5686 L .64785 .5718 L p F P
0 g
s
.651 .758 .928 r
.64506 .5686 m .63363 .57208 L .63081 .56888 L p F P
0 g
s
0 0 .273 r
.40072 .30124 m .4007 .30128 L .40083 .29643 L p F P
0 g
s
0 0 .273 r
.40083 .29643 m .40085 .29639 L .40072 .30124 L p F P
0 g
s
.764 .494 .526 r
.40063 .30127 m .4007 .30128 L .40083 .29643 L p F P
0 g
s
.764 .494 .526 r
.40083 .29643 m .40076 .29642 L .40063 .30127 L p F P
0 g
s
.65 .757 .928 r
.28672 .57211 m .29755 .56864 L .3009 .57185 L p F P
0 g
s
.65 .757 .928 r
.29755 .56864 m .28672 .57211 L .28335 .56891 L p F P
0 g
s
.65 .758 .928 r
.46017 .57212 m .4713 .56865 L .47437 .57185 L p F P
0 g
s
.65 .758 .928 r
.4713 .56865 m .46017 .57212 L .45708 .56891 L p F P
0 g
s
.651 .758 .928 r
.82131 .57161 m .83306 .56812 L .83555 .57132 L p F P
0 g
s
.651 .758 .928 r
.83306 .56812 m .82131 .57161 L .81879 .56842 L p F P
0 g
s
.65 .757 .928 r
.12743 .57179 m .13798 .56832 L .14158 .57153 L p F P
0 g
s
.65 .757 .928 r
.13798 .56832 m .12743 .57179 L .1238 .56858 L p F P
0 g
s
.651 .758 .928 r
.64785 .5718 m .6593 .56833 L .66207 .57153 L p F P
0 g
s
.651 .758 .928 r
.6593 .56833 m .64785 .5718 L .64506 .5686 L p F P
0 g
s
.65 .757 .928 r
.3009 .57185 m .31175 .56838 L .31508 .57158 L p F P
0 g
s
.65 .757 .928 r
.31175 .56838 m .3009 .57185 L .29755 .56864 L p F P
0 g
s
.65 .758 .928 r
.47437 .57185 m .48553 .56838 L .48858 .57158 L p F P
0 g
s
.65 .758 .928 r
.48553 .56838 m .47437 .57185 L .4713 .56865 L p F P
0 g
s
.651 .759 .928 r
.83555 .57132 m .84733 .56782 L .8498 .57102 L p F P
0 g
s
.651 .759 .928 r
.84733 .56782 m .83555 .57132 L .83306 .56812 L p F P
0 g
s
.651 .758 .928 r
.66207 .57153 m .67356 .56805 L .6763 .57125 L p F P
0 g
s
.651 .758 .928 r
.67356 .56805 m .66207 .57153 L .6593 .56833 L p F P
0 g
s
.65 .757 .928 r
.14158 .57153 m .15216 .56806 L .15574 .57127 L p F P
0 g
s
.65 .757 .928 r
.15216 .56806 m .14158 .57153 L .13798 .56832 L p F P
0 g
s
.65 .758 .928 r
.48858 .57158 m .49976 .56811 L .50278 .57131 L p F P
0 g
s
.65 .758 .928 r
.49976 .56811 m .48858 .57158 L .48553 .56838 L p F P
0 g
s
.65 .758 .928 r
.31508 .57158 m .32596 .56811 L .32926 .57132 L p F P
0 g
s
.65 .757 .928 r
.32596 .56811 m .31508 .57158 L .31175 .56838 L p F P
0 g
s
.651 .759 .928 r
.8498 .57102 m .86161 .56752 L .86405 .57071 L p F P
0 g
s
.651 .759 .928 r
.86161 .56752 m .8498 .57102 L .84733 .56782 L p F P
0 g
s
.651 .758 .928 r
.6763 .57125 m .68781 .56777 L .69053 .57098 L p F P
0 g
s
.651 .758 .928 r
.68781 .56777 m .6763 .57125 L .67356 .56805 L p F P
0 g
s
.65 .757 .928 r
.15574 .57127 m .16635 .5678 L .1699 .57101 L p F P
0 g
s
.65 .757 .928 r
.16635 .5678 m .15574 .57127 L .15216 .56806 L p F P
0 g
s
.651 .758 .928 r
.50278 .57131 m .51399 .56784 L .51699 .57104 L p F P
0 g
s
.651 .758 .928 r
.51399 .56784 m .50278 .57131 L .49976 .56811 L p F P
0 g
s
.65 .758 .928 r
.32926 .57132 m .34017 .56784 L .34345 .57105 L p F P
0 g
s
.65 .758 .928 r
.34017 .56784 m .32926 .57132 L .32596 .56811 L p F P
0 g
s
.651 .759 .928 r
.86405 .57071 m .87588 .56721 L .87831 .5704 L p F P
0 g
s
.651 .759 .928 r
.87588 .56721 m .86405 .57071 L .86161 .56752 L p F P
0 g
s
.651 .758 .928 r
.69053 .57098 m .70207 .5675 L .70477 .5707 L p F P
0 g
s
.651 .758 .928 r
.70207 .5675 m .69053 .57098 L .68781 .56777 L p F P
0 g
s
.65 .757 .928 r
.1699 .57101 m .18054 .56754 L .18407 .57075 L p F P
0 g
s
.65 .757 .928 r
.18054 .56754 m .1699 .57101 L .16635 .5678 L p F P
0 g
s
.651 .758 .928 r
.51699 .57104 m .52823 .56757 L .53121 .57077 L p F P
0 g
s
.651 .758 .928 r
.52823 .56757 m .51699 .57104 L .51399 .56784 L p F P
0 g
s
.65 .758 .928 r
.34345 .57105 m .35438 .56758 L .35764 .57078 L p F P
0 g
s
.65 .758 .928 r
.35438 .56758 m .34345 .57105 L .34017 .56784 L p F P
0 g
s
.652 .759 .928 r
.87831 .5704 m .89017 .56689 L .89257 .57009 L p F P
0 g
s
.652 .759 .928 r
.89017 .56689 m .87831 .5704 L .87588 .56721 L p F P
0 g
s
.651 .758 .928 r
.70477 .5707 m .71633 .56722 L .71901 .57042 L p F P
0 g
s
.651 .758 .928 r
.71633 .56722 m .70477 .5707 L .70207 .5675 L p F P
0 g
s
.65 .757 .928 r
.18407 .57075 m .19473 .56728 L .19824 .57049 L p F P
0 g
s
.65 .757 .928 r
.19473 .56728 m .18407 .57075 L .18054 .56754 L p F P
0 g
s
.651 .758 .928 r
.53121 .57077 m .54247 .5673 L .54542 .57051 L p F P
0 g
s
.651 .758 .928 r
.54247 .5673 m .53121 .57077 L .52823 .56757 L p F P
0 g
s
.65 .758 .928 r
.35764 .57078 m .3686 .56731 L .37183 .57052 L p F P
0 g
s
.65 .758 .928 r
.3686 .56731 m .35764 .57078 L .35438 .56758 L p F P
0 g
s
.652 .759 .928 r
.89257 .57009 m .90445 .56658 L .90683 .56977 L p F P
0 g
s
.652 .759 .928 r
.90445 .56658 m .89257 .57009 L .89017 .56689 L p F P
0 g
s
.651 .758 .928 r
.71901 .57042 m .7306 .56694 L .73326 .57014 L p F P
0 g
s
.651 .758 .928 r
.7306 .56694 m .71901 .57042 L .71633 .56722 L p F P
0 g
s
.65 .757 .928 r
.19824 .57049 m .20893 .56702 L .21242 .57023 L p F P
0 g
s
.65 .757 .928 r
.20893 .56702 m .19824 .57049 L .19473 .56728 L p F P
0 g
s
.651 .758 .928 r
.54542 .57051 m .55671 .56703 L .55965 .57023 L p F P
0 g
s
.651 .758 .928 r
.55671 .56703 m .54542 .57051 L .54247 .5673 L p F P
0 g
s
.65 .758 .928 r
.37183 .57052 m .38282 .56704 L .38603 .57025 L p F P
0 g
s
.65 .758 .928 r
.38282 .56704 m .37183 .57052 L .3686 .56731 L p F P
0 g
s
.652 .759 .928 r
.90683 .56977 m .91874 .56625 L .92109 .56944 L p F P
0 g
s
.652 .759 .928 r
.91874 .56625 m .90683 .56977 L .90445 .56658 L p F P
0 g
s
.651 .758 .928 r
.73326 .57014 m .74487 .56665 L .7475 .56986 L p F P
0 g
s
.651 .758 .928 r
.74487 .56665 m .73326 .57014 L .7306 .56694 L p F P
0 g
s
.65 .757 .928 r
.21242 .57023 m .22313 .56675 L .2266 .56996 L p F P
0 g
s
.65 .757 .928 r
.22313 .56675 m .21242 .57023 L .20893 .56702 L p F P
0 g
s
.652 .76 .928 r
.92109 .56944 m .93302 .56592 L .93536 .56911 L p F P
0 g
s
.652 .76 .928 r
.93302 .56592 m .92109 .56944 L .91874 .56625 L p F P
0 g
s
.651 .758 .928 r
.55965 .57023 m .57096 .56675 L .57387 .56996 L p F P
0 g
s
.651 .758 .928 r
.57096 .56675 m .55965 .57023 L .55671 .56703 L p F P
0 g
s
.65 .758 .928 r
.38603 .57025 m .39704 .56677 L .40023 .56999 L p F P
0 g
s
.65 .758 .928 r
.39704 .56677 m .38603 .57025 L .38282 .56704 L p F P
0 g
s
.651 .758 .928 r
.75914 .56637 m .7475 .56986 L .74487 .56665 L p F P
0 g
s
.651 .758 .928 r
.7475 .56986 m .75914 .56637 L .76175 .56958 L p F P
0 g
s
.652 .76 .928 r
.93536 .56911 m .94732 .56558 L .94963 .56877 L p F P
0 g
s
.652 .76 .928 r
.94732 .56558 m .93536 .56911 L .93302 .56592 L p F P
0 g
s
.65 .757 .928 r
.2266 .56996 m .23733 .56649 L .24078 .5697 L p F P
0 g
s
.65 .757 .928 r
.23733 .56649 m .2266 .56996 L .22313 .56675 L p F P
0 g
s
.651 .758 .928 r
.57387 .56996 m .58521 .56648 L .5881 .56969 L p F P
0 g
s
.651 .758 .928 r
.58521 .56648 m .57387 .56996 L .57096 .56675 L p F P
0 g
s
.65 .758 .928 r
.40023 .56999 m .41127 .56651 L .41444 .56972 L p F P
0 g
s
.65 .758 .928 r
.41127 .56651 m .40023 .56999 L .39704 .56677 L p F P
0 g
s
.651 .758 .928 r
.76175 .56958 m .77342 .56608 L .77601 .56929 L p F P
0 g
s
.651 .758 .928 r
.77342 .56608 m .76175 .56958 L .75914 .56637 L p F P
0 g
s
.651 .758 .928 r
.5881 .56969 m .59947 .56621 L .60233 .56942 L p F P
0 g
s
.651 .758 .928 r
.59947 .56621 m .5881 .56969 L .58521 .56648 L p F P
0 g
s
.65 .757 .928 r
.24078 .5697 m .25154 .56622 L .25497 .56944 L p F P
0 g
s
.65 .757 .928 r
.25154 .56622 m .24078 .5697 L .23733 .56649 L p F P
0 g
s
.65 .758 .928 r
.41444 .56972 m .4255 .56624 L .42865 .56945 L p F P
0 g
s
.65 .758 .928 r
.4255 .56624 m .41444 .56972 L .41127 .56651 L p F P
0 g
s
.651 .758 .928 r
.7877 .5658 m .77601 .56929 L .77342 .56608 L p F P
0 g
s
.651 .758 .928 r
.77601 .56929 m .7877 .5658 L .79027 .569 L p F P
0 g
s
.651 .758 .928 r
.60233 .56942 m .61373 .56594 L .61657 .56915 L p F P
0 g
s
.651 .758 .928 r
.61373 .56594 m .60233 .56942 L .59947 .56621 L p F P
0 g
s
0 0 .273 r
.40058 .30611 m .40057 .30615 L .4007 .30128 L p F P
0 g
s
0 0 .273 r
.4007 .30128 m .40072 .30124 L .40058 .30611 L p F P
0 g
s
.764 .494 .526 r
.40051 .30613 m .40057 .30615 L .4007 .30128 L p F P
0 g
s
.764 .494 .526 r
.4007 .30128 m .40063 .30127 L .40051 .30613 L p F P
0 g
s
.65 .757 .928 r
.25497 .56944 m .26576 .56596 L .26916 .56917 L p F P
0 g
s
.65 .757 .928 r
.26576 .56596 m .25497 .56944 L .25154 .56622 L p F P
0 g
s
.65 .758 .928 r
.43974 .56597 m .42865 .56945 L .4255 .56624 L p F P
0 g
s
.65 .758 .928 r
.42865 .56945 m .43974 .56597 L .44286 .56918 L p F P
0 g
s
.651 .758 .928 r
.79027 .569 m .80198 .5655 L .80453 .56871 L p F P
0 g
s
.651 .758 .928 r
.80198 .5655 m .79027 .569 L .7877 .5658 L p F P
0 g
s
.651 .758 .928 r
.61657 .56915 m .62799 .56566 L .63081 .56888 L p F P
0 g
s
.651 .758 .928 r
.62799 .56566 m .61657 .56915 L .61373 .56594 L p F P
0 g
s
.65 .757 .928 r
.26916 .56917 m .27997 .56569 L .28335 .56891 L p F P
0 g
s
.65 .757 .928 r
.27997 .56569 m .26916 .56917 L .26576 .56596 L p F P
0 g
s
.65 .758 .928 r
.44286 .56918 m .45398 .5657 L .45708 .56891 L p F P
0 g
s
.65 .758 .928 r
.45398 .5657 m .44286 .56918 L .43974 .56597 L p F P
0 g
s
.651 .758 .928 r
.80453 .56871 m .81627 .56521 L .81879 .56842 L p F P
0 g
s
.651 .758 .928 r
.81627 .56521 m .80453 .56871 L .80198 .5655 L p F P
0 g
s
.65 .757 .928 r
.10963 .56884 m .12017 .56537 L .1238 .56858 L p F P
0 g
s
.651 .758 .928 r
.63081 .56888 m .64226 .56539 L .64506 .5686 L p F P
0 g
s
.651 .758 .928 r
.64226 .56539 m .63081 .56888 L .62799 .56566 L p F P
0 g
s
.65 .757 .928 r
.28335 .56891 m .29419 .56543 L .29755 .56864 L p F P
0 g
s
.65 .757 .928 r
.29419 .56543 m .28335 .56891 L .27997 .56569 L p F P
0 g
s
.65 .758 .928 r
.45708 .56891 m .46822 .56543 L .4713 .56865 L p F P
0 g
s
.65 .758 .928 r
.46822 .56543 m .45708 .56891 L .45398 .5657 L p F P
0 g
s
.651 .758 .928 r
.81879 .56842 m .83056 .56491 L .83306 .56812 L p F P
0 g
s
.651 .758 .928 r
.83056 .56491 m .81879 .56842 L .81627 .56521 L p F P
0 g
s
.65 .757 .928 r
.1238 .56858 m .13437 .56511 L .13798 .56832 L p F P
0 g
s
.65 .757 .928 r
.13437 .56511 m .1238 .56858 L .12017 .56537 L p F P
0 g
s
.651 .758 .928 r
.64506 .5686 m .65653 .56511 L .6593 .56833 L p F P
0 g
s
.651 .758 .928 r
.65653 .56511 m .64506 .5686 L .64226 .56539 L p F P
0 g
s
.65 .757 .928 r
.29755 .56864 m .30842 .56516 L .31175 .56838 L p F P
0 g
s
.65 .757 .928 r
.30842 .56516 m .29755 .56864 L .29419 .56543 L p F P
0 g
s
.65 .758 .928 r
.4713 .56865 m .48247 .56516 L .48553 .56838 L p F P
0 g
s
.65 .758 .928 r
.48247 .56516 m .4713 .56865 L .46822 .56543 L p F P
0 g
s
.651 .759 .928 r
.83306 .56812 m .84486 .56462 L .84733 .56782 L p F P
0 g
s
.651 .759 .928 r
.84486 .56462 m .83306 .56812 L .83056 .56491 L p F P
0 g
s
.65 .757 .928 r
.13798 .56832 m .14857 .56485 L .15216 .56806 L p F P
0 g
s
.65 .757 .928 r
.14857 .56485 m .13798 .56832 L .13437 .56511 L p F P
0 g
s
.651 .758 .928 r
.6593 .56833 m .6708 .56484 L .67356 .56805 L p F P
0 g
s
.651 .758 .928 r
.6708 .56484 m .6593 .56833 L .65653 .56511 L p F P
0 g
s
.65 .757 .928 r
.31175 .56838 m .32264 .56489 L .32596 .56811 L p F P
0 g
s
.65 .757 .928 r
.32264 .56489 m .31175 .56838 L .30842 .56516 L p F P
0 g
s
.65 .758 .928 r
.48553 .56838 m .49672 .56489 L .49976 .56811 L p F P
0 g
s
.65 .758 .928 r
.49672 .56489 m .48553 .56838 L .48247 .56516 L p F P
0 g
s
.651 .759 .928 r
.84733 .56782 m .85915 .56431 L .86161 .56752 L p F P
0 g
s
.651 .759 .928 r
.85915 .56431 m .84733 .56782 L .84486 .56462 L p F P
0 g
s
.651 .758 .928 r
.67356 .56805 m .68508 .56456 L .68781 .56777 L p F P
0 g
s
.651 .758 .928 r
.68508 .56456 m .67356 .56805 L .6708 .56484 L p F P
0 g
s
.65 .757 .928 r
.15216 .56806 m .16278 .56459 L .16635 .5678 L p F P
0 g
s
.65 .757 .928 r
.16278 .56459 m .15216 .56806 L .14857 .56485 L p F P
0 g
s
.651 .758 .928 r
.49976 .56811 m .51098 .56462 L .51399 .56784 L p F P
0 g
s
.651 .758 .928 r
.51098 .56462 m .49976 .56811 L .49672 .56489 L p F P
0 g
s
.65 .758 .928 r
.32596 .56811 m .33688 .56463 L .34017 .56784 L p F P
0 g
s
.65 .758 .928 r
.33688 .56463 m .32596 .56811 L .32264 .56489 L p F P
0 g
s
.651 .759 .928 r
.86161 .56752 m .87345 .564 L .87588 .56721 L p F P
0 g
s
.651 .759 .928 r
.87345 .564 m .86161 .56752 L .85915 .56431 L p F P
0 g
s
.651 .758 .928 r
.68781 .56777 m .69936 .56428 L .70207 .5675 L p F P
0 g
s
.651 .758 .928 r
.69936 .56428 m .68781 .56777 L .68508 .56456 L p F P
0 g
s
.65 .757 .928 r
.16635 .5678 m .17699 .56432 L .18054 .56754 L p F P
0 g
s
.65 .757 .928 r
.17699 .56432 m .16635 .5678 L .16278 .56459 L p F P
0 g
s
.651 .758 .928 r
.51399 .56784 m .52524 .56435 L .52823 .56757 L p F P
0 g
s
.651 .758 .928 r
.52524 .56435 m .51399 .56784 L .51098 .56462 L p F P
0 g
s
.65 .758 .928 r
.34017 .56784 m .35111 .56436 L .35438 .56758 L p F P
0 g
s
.65 .758 .928 r
.35111 .56436 m .34017 .56784 L .33688 .56463 L p F P
0 g
s
.652 .759 .928 r
.87588 .56721 m .88776 .56369 L .89017 .56689 L p F P
0 g
s
.651 .759 .928 r
.88776 .56369 m .87588 .56721 L .87345 .564 L p F P
0 g
s
.651 .758 .928 r
.70207 .5675 m .71364 .564 L .71633 .56722 L p F P
0 g
s
.651 .758 .928 r
.71364 .564 m .70207 .5675 L .69936 .56428 L p F P
0 g
s
.65 .757 .928 r
.18054 .56754 m .19121 .56406 L .19473 .56728 L p F P
0 g
s
.65 .757 .928 r
.19121 .56406 m .18054 .56754 L .17699 .56432 L p F P
0 g
s
.651 .758 .928 r
.52823 .56757 m .5395 .56408 L .54247 .5673 L p F P
0 g
s
.651 .758 .928 r
.5395 .56408 m .52823 .56757 L .52524 .56435 L p F P
0 g
s
.65 .758 .928 r
.35438 .56758 m .36535 .56409 L .3686 .56731 L p F P
0 g
s
.65 .758 .928 r
.36535 .56409 m .35438 .56758 L .35111 .56436 L p F P
0 g
s
.652 .759 .928 r
.89017 .56689 m .90206 .56337 L .90445 .56658 L p F P
0 g
s
.652 .759 .928 r
.90206 .56337 m .89017 .56689 L .88776 .56369 L p F P
0 g
s
.651 .758 .928 r
.71633 .56722 m .72793 .56372 L .7306 .56694 L p F P
0 g
s
.651 .758 .928 r
.72793 .56372 m .71633 .56722 L .71364 .564 L p F P
0 g
s
.65 .757 .928 r
.19473 .56728 m .20543 .5638 L .20893 .56702 L p F P
0 g
s
.65 .757 .928 r
.20543 .5638 m .19473 .56728 L .19121 .56406 L p F P
0 g
s
.651 .758 .928 r
.54247 .5673 m .55377 .56381 L .55671 .56703 L p F P
0 g
s
.651 .758 .928 r
.55377 .56381 m .54247 .5673 L .5395 .56408 L p F P
0 g
s
.65 .758 .928 r
.3686 .56731 m .3796 .56382 L .38282 .56704 L p F P
0 g
s
.65 .758 .928 r
.3796 .56382 m .3686 .56731 L .36535 .56409 L p F P
0 g
s
.652 .759 .928 r
.90445 .56658 m .91637 .56305 L .91874 .56625 L p F P
0 g
s
.652 .759 .928 r
.91637 .56305 m .90445 .56658 L .90206 .56337 L p F P
0 g
s
.651 .758 .928 r
.7306 .56694 m .74223 .56344 L .74487 .56665 L p F P
0 g
s
.651 .758 .928 r
.74223 .56344 m .7306 .56694 L .72793 .56372 L p F P
0 g
s
.65 .757 .928 r
.20893 .56702 m .21965 .56353 L .22313 .56675 L p F P
0 g
s
.65 .757 .928 r
.21965 .56353 m .20893 .56702 L .20543 .5638 L p F P
0 g
s
.651 .758 .928 r
.55671 .56703 m .56804 .56353 L .57096 .56675 L p F P
0 g
s
.651 .758 .928 r
.56804 .56353 m .55671 .56703 L .55377 .56381 L p F P
0 g
s
.652 .76 .928 r
.91874 .56625 m .93069 .56272 L .93302 .56592 L p F P
0 g
s
.652 .759 .928 r
.93069 .56272 m .91874 .56625 L .91637 .56305 L p F P
0 g
s
.65 .758 .928 r
.38282 .56704 m .39384 .56355 L .39704 .56677 L p F P
0 g
s
.65 .758 .928 r
.39384 .56355 m .38282 .56704 L .3796 .56382 L p F P
0 g
s
.651 .758 .928 r
.74487 .56665 m .75652 .56315 L .75914 .56637 L p F P
0 g
s
.651 .758 .928 r
.75652 .56315 m .74487 .56665 L .74223 .56344 L p F P
0 g
s
.652 .76 .928 r
.93302 .56592 m .945 .56238 L .94732 .56558 L p F P
0 g
s
.652 .76 .928 r
.945 .56238 m .93302 .56592 L .93069 .56272 L p F P
0 g
s
.65 .757 .928 r
.22313 .56675 m .23388 .56327 L .23733 .56649 L p F P
0 g
s
.65 .757 .928 r
.23388 .56327 m .22313 .56675 L .21965 .56353 L p F P
0 g
s
0 0 .273 r
.40045 .31098 m .40044 .31102 L .40057 .30615 L p F P
0 g
s
0 0 .273 r
.40057 .30615 m .40058 .30611 L .40045 .31098 L p F P
0 g
s
.764 .494 .526 r
.40038 .31101 m .40044 .31102 L .40057 .30615 L p F P
0 g
s
.764 .494 .526 r
.40057 .30615 m .40051 .30613 L .40038 .31101 L p F P
0 g
s
.651 .758 .928 r
.57096 .56675 m .58231 .56326 L .58521 .56648 L p F P
0 g
s
.651 .758 .928 r
.58231 .56326 m .57096 .56675 L .56804 .56353 L p F P
0 g
s
.65 .758 .928 r
.39704 .56677 m .40809 .56328 L .41127 .56651 L p F P
0 g
s
.65 .758 .928 r
.40809 .56328 m .39704 .56677 L .39384 .56355 L p F P
0 g
s
.651 .758 .928 r
.77082 .56287 m .75914 .56637 L .75652 .56315 L p F P
0 g
s
.651 .758 .928 r
.75914 .56637 m .77082 .56287 L .77342 .56608 L p F P
0 g
s
.651 .758 .928 r
.58521 .56648 m .59659 .56299 L .59947 .56621 L p F P
0 g
s
.651 .758 .928 r
.59659 .56299 m .58521 .56648 L .58231 .56326 L p F P
0 g
s
.65 .757 .928 r
.23733 .56649 m .24811 .563 L .25154 .56622 L p F P
0 g
s
.65 .757 .928 r
.24811 .563 m .23733 .56649 L .23388 .56327 L p F P
0 g
s
.65 .758 .928 r
.41127 .56651 m .42235 .56302 L .4255 .56624 L p F P
0 g
s
.65 .758 .928 r
.42235 .56302 m .41127 .56651 L .40809 .56328 L p F P
0 g
s
.651 .758 .928 r
.77342 .56608 m .78512 .56258 L .7877 .5658 L p F P
0 g
s
.651 .758 .928 r
.78512 .56258 m .77342 .56608 L .77082 .56287 L p F P
0 g
s
.651 .758 .928 r
.59947 .56621 m .61087 .56271 L .61373 .56594 L p F P
0 g
s
.651 .758 .928 r
.61087 .56271 m .59947 .56621 L .59659 .56299 L p F P
0 g
s
.65 .757 .928 r
.25154 .56622 m .26234 .56273 L .26576 .56596 L p F P
0 g
s
.65 .757 .928 r
.26234 .56273 m .25154 .56622 L .24811 .563 L p F P
0 g
s
.65 .758 .928 r
.4255 .56624 m .43661 .56275 L .43974 .56597 L p F P
0 g
s
.65 .758 .928 r
.43661 .56275 m .4255 .56624 L .42235 .56302 L p F P
0 g
s
.651 .758 .928 r
.79943 .56229 m .7877 .5658 L .78512 .56258 L p F P
0 g
s
.651 .758 .928 r
.7877 .5658 m .79943 .56229 L .80198 .5655 L p F P
0 g
s
.651 .758 .928 r
.61373 .56594 m .62516 .56244 L .62799 .56566 L p F P
0 g
s
.651 .758 .928 r
.62516 .56244 m .61373 .56594 L .61087 .56271 L p F P
0 g
s
.65 .757 .928 r
.26576 .56596 m .27658 .56247 L .27997 .56569 L p F P
0 g
s
.65 .757 .928 r
.27658 .56247 m .26576 .56596 L .26234 .56273 L p F P
0 g
s
.65 .758 .928 r
.45087 .56248 m .43974 .56597 L .43661 .56275 L p F P
0 g
s
.65 .758 .928 r
.43974 .56597 m .45087 .56248 L .45398 .5657 L p F P
0 g
s
.651 .758 .928 r
.80198 .5655 m .81374 .56199 L .81627 .56521 L p F P
0 g
s
.651 .758 .928 r
.81374 .56199 m .80198 .5655 L .79943 .56229 L p F P
0 g
s
.651 .758 .928 r
.62799 .56566 m .63945 .56217 L .64226 .56539 L p F P
0 g
s
.651 .758 .928 r
.63945 .56217 m .62799 .56566 L .62516 .56244 L p F P
0 g
s
.65 .757 .928 r
.27997 .56569 m .29082 .5622 L .29419 .56543 L p F P
0 g
s
.65 .757 .928 r
.29082 .5622 m .27997 .56569 L .27658 .56247 L p F P
0 g
s
.65 .758 .928 r
.45398 .5657 m .46514 .56221 L .46822 .56543 L p F P
0 g
s
.65 .758 .928 r
.46514 .56221 m .45398 .5657 L .45087 .56248 L p F P
0 g
s
.651 .758 .928 r
.81627 .56521 m .82805 .5617 L .83056 .56491 L p F P
0 g
s
.651 .758 .928 r
.82805 .5617 m .81627 .56521 L .81374 .56199 L p F P
0 g
s
.65 .757 .928 r
.12017 .56537 m .13074 .56188 L .13437 .56511 L p F P
0 g
s
.651 .758 .928 r
.64226 .56539 m .65374 .56189 L .65653 .56511 L p F P
0 g
s
.651 .758 .928 r
.65374 .56189 m .64226 .56539 L .63945 .56217 L p F P
0 g
s
.65 .757 .928 r
.29419 .56543 m .30507 .56193 L .30842 .56516 L p F P
0 g
s
.65 .757 .928 r
.30507 .56193 m .29419 .56543 L .29082 .5622 L p F P
0 g
s
.65 .758 .928 r
.46822 .56543 m .47941 .56194 L .48247 .56516 L p F P
0 g
s
.65 .758 .928 r
.47941 .56194 m .46822 .56543 L .46514 .56221 L p F P
0 g
s
.651 .759 .928 r
.83056 .56491 m .84237 .5614 L .84486 .56462 L p F P
0 g
s
.651 .758 .928 r
.84237 .5614 m .83056 .56491 L .82805 .5617 L p F P
0 g
s
.65 .757 .928 r
.13437 .56511 m .14497 .56162 L .14857 .56485 L p F P
0 g
s
.65 .757 .928 r
.14497 .56162 m .13437 .56511 L .13074 .56188 L p F P
0 g
s
.651 .758 .928 r
.65653 .56511 m .66804 .56161 L .6708 .56484 L p F P
0 g
s
.651 .758 .928 r
.66804 .56161 m .65653 .56511 L .65374 .56189 L p F P
0 g
s
.65 .757 .928 r
.30842 .56516 m .31932 .56167 L .32264 .56489 L p F P
0 g
s
.65 .757 .928 r
.31932 .56167 m .30842 .56516 L .30507 .56193 L p F P
0 g
s
.65 .758 .928 r
.48247 .56516 m .49368 .56166 L .49672 .56489 L p F P
0 g
s
.65 .758 .928 r
.49368 .56166 m .48247 .56516 L .47941 .56194 L p F P
0 g
s
.651 .759 .928 r
.84486 .56462 m .85669 .56109 L .85915 .56431 L p F P
0 g
s
.651 .759 .928 r
.85669 .56109 m .84486 .56462 L .84237 .5614 L p F P
0 g
s
.651 .758 .928 r
.6708 .56484 m .68234 .56133 L .68508 .56456 L p F P
0 g
s
.651 .758 .928 r
.68234 .56133 m .6708 .56484 L .66804 .56161 L p F P
0 g
s
.65 .757 .928 r
.14857 .56485 m .1592 .56136 L .16278 .56459 L p F P
0 g
s
.65 .757 .928 r
.1592 .56136 m .14857 .56485 L .14497 .56162 L p F P
0 g
s
.651 .758 .928 r
.49672 .56489 m .50796 .56139 L .51098 .56462 L p F P
0 g
s
.651 .758 .928 r
.50796 .56139 m .49672 .56489 L .49368 .56166 L p F P
0 g
s
.65 .758 .928 r
.32264 .56489 m .33358 .5614 L .33688 .56463 L p F P
0 g
s
.65 .757 .928 r
.33358 .5614 m .32264 .56489 L .31932 .56167 L p F P
0 g
s
.651 .759 .928 r
.85915 .56431 m .87102 .56079 L .87345 .564 L p F P
0 g
s
.651 .759 .928 r
.87102 .56079 m .85915 .56431 L .85669 .56109 L p F P
0 g
s
.651 .758 .928 r
.68508 .56456 m .69664 .56106 L .69936 .56428 L p F P
0 g
s
.651 .758 .928 r
.69664 .56106 m .68508 .56456 L .68234 .56133 L p F P
0 g
s
.65 .757 .928 r
.16278 .56459 m .17343 .56109 L .17699 .56432 L p F P
0 g
s
.65 .757 .928 r
.17343 .56109 m .16278 .56459 L .1592 .56136 L p F P
0 g
s
.651 .758 .928 r
.51098 .56462 m .52224 .56112 L .52524 .56435 L p F P
0 g
s
.651 .758 .928 r
.52224 .56112 m .51098 .56462 L .50796 .56139 L p F P
0 g
s
.65 .758 .928 r
.33688 .56463 m .34783 .56113 L .35111 .56436 L p F P
0 g
s
.65 .758 .928 r
.34783 .56113 m .33688 .56463 L .33358 .5614 L p F P
0 g
s
.651 .759 .928 r
.87345 .564 m .88534 .56047 L .88776 .56369 L p F P
0 g
s
.651 .759 .928 r
.88534 .56047 m .87345 .564 L .87102 .56079 L p F P
0 g
s
.651 .758 .928 r
.69936 .56428 m .71095 .56078 L .71364 .564 L p F P
0 g
s
.651 .758 .928 r
.71095 .56078 m .69936 .56428 L .69664 .56106 L p F P
0 g
s
.65 .757 .928 r
.17699 .56432 m .18767 .56083 L .19121 .56406 L p F P
0 g
s
.65 .757 .928 r
.18767 .56083 m .17699 .56432 L .17343 .56109 L p F P
0 g
s
.651 .758 .928 r
.52524 .56435 m .53652 .56085 L .5395 .56408 L p F P
0 g
s
.651 .758 .928 r
.53652 .56085 m .52524 .56435 L .52224 .56112 L p F P
0 g
s
.65 .758 .928 r
.35111 .56436 m .3621 .56086 L .36535 .56409 L p F P
0 g
s
.65 .758 .928 r
.3621 .56086 m .35111 .56436 L .34783 .56113 L p F P
0 g
s
.652 .759 .928 r
.88776 .56369 m .89967 .56016 L .90206 .56337 L p F P
0 g
s
.652 .759 .928 r
.89967 .56016 m .88776 .56369 L .88534 .56047 L p F P
0 g
s
.651 .758 .928 r
.71364 .564 m .72526 .56049 L .72793 .56372 L p F P
0 g
s
.651 .758 .928 r
.72526 .56049 m .71364 .564 L .71095 .56078 L p F P
0 g
s
.65 .757 .928 r
.19121 .56406 m .20191 .56056 L .20543 .5638 L p F P
0 g
s
.65 .757 .928 r
.20191 .56056 m .19121 .56406 L .18767 .56083 L p F P
0 g
s
0 0 .273 r
.40032 .31588 m .40031 .31591 L .40044 .31102 L p F P
0 g
s
0 0 .273 r
.40044 .31102 m .40045 .31098 L .40032 .31588 L p F P
0 g
s
.764 .494 .526 r
.40025 .3159 m .40031 .31591 L .40044 .31102 L p F P
0 g
s
.764 .494 .526 r
.40044 .31102 m .40038 .31101 L .40025 .3159 L p F P
0 g
s
.651 .758 .928 r
.5395 .56408 m .55081 .56058 L .55377 .56381 L p F P
0 g
s
.651 .758 .928 r
.55081 .56058 m .5395 .56408 L .53652 .56085 L p F P
0 g
s
.65 .758 .928 r
.36535 .56409 m .37636 .56059 L .3796 .56382 L p F P
0 g
s
.65 .758 .928 r
.37636 .56059 m .36535 .56409 L .3621 .56086 L p F P
0 g
s
.652 .759 .928 r
.90206 .56337 m .914 .55983 L .91637 .56305 L p F P
0 g
s
.652 .759 .928 r
.914 .55983 m .90206 .56337 L .89967 .56016 L p F P
0 g
s
.651 .758 .928 r
.72793 .56372 m .73957 .56021 L .74223 .56344 L p F P
0 g
s
.651 .758 .928 r
.73957 .56021 m .72793 .56372 L .72526 .56049 L p F P
0 g
s
.65 .757 .928 r
.20543 .5638 m .21616 .5603 L .21965 .56353 L p F P
0 g
s
.65 .757 .928 r
.21616 .5603 m .20543 .5638 L .20191 .56056 L p F P
0 g
s
.651 .758 .928 r
.55377 .56381 m .56511 .5603 L .56804 .56353 L p F P
0 g
s
.651 .758 .928 r
.56511 .5603 m .55377 .56381 L .55081 .56058 L p F P
0 g
s
.65 .758 .928 r
.3796 .56382 m .39063 .56032 L .39384 .56355 L p F P
0 g
s
.65 .758 .928 r
.39063 .56032 m .3796 .56382 L .37636 .56059 L p F P
0 g
s
.652 .759 .928 r
.91637 .56305 m .92834 .5595 L .93069 .56272 L p F P
0 g
s
.652 .759 .928 r
.92834 .5595 m .91637 .56305 L .914 .55983 L p F P
0 g
s
.651 .758 .928 r
.74223 .56344 m .75389 .55993 L .75652 .56315 L p F P
0 g
s
.651 .758 .928 r
.75389 .55993 m .74223 .56344 L .73957 .56021 L p F P
0 g
s
.652 .76 .928 r
.93069 .56272 m .94268 .55917 L .945 .56238 L p F P
0 g
s
.652 .76 .928 r
.94268 .55917 m .93069 .56272 L .92834 .5595 L p F P
0 g
s
.65 .757 .928 r
.21965 .56353 m .23041 .56003 L .23388 .56327 L p F P
0 g
s
.65 .757 .928 r
.23041 .56003 m .21965 .56353 L .21616 .5603 L p F P
0 g
s
.651 .758 .928 r
.56804 .56353 m .5794 .56003 L .58231 .56326 L p F P
0 g
s
.651 .758 .928 r
.5794 .56003 m .56804 .56353 L .56511 .5603 L p F P
0 g
s
.65 .758 .928 r
.39384 .56355 m .4049 .56005 L .40809 .56328 L p F P
0 g
s
.65 .758 .928 r
.4049 .56005 m .39384 .56355 L .39063 .56032 L p F P
0 g
s
.651 .758 .928 r
.75652 .56315 m .76822 .55964 L .77082 .56287 L p F P
0 g
s
.651 .758 .928 r
.76822 .55964 m .75652 .56315 L .75389 .55993 L p F P
0 g
s
.651 .758 .928 r
.58231 .56326 m .5937 .55976 L .59659 .56299 L p F P
0 g
s
.651 .758 .928 r
.5937 .55976 m .58231 .56326 L .5794 .56003 L p F P
0 g
s
.65 .757 .928 r
.23388 .56327 m .24466 .55977 L .24811 .563 L p F P
0 g
s
.65 .757 .928 r
.24466 .55977 m .23388 .56327 L .23041 .56003 L p F P
0 g
s
.65 .758 .928 r
.40809 .56328 m .41918 .55978 L .42235 .56302 L p F P
0 g
s
.65 .758 .928 r
.41918 .55978 m .40809 .56328 L .4049 .56005 L p F P
0 g
s
.651 .758 .928 r
.78254 .55935 m .77082 .56287 L .76822 .55964 L p F P
0 g
s
.651 .758 .928 r
.77082 .56287 m .78254 .55935 L .78512 .56258 L p F P
0 g
s
.651 .758 .928 r
.59659 .56299 m .60801 .55948 L .61087 .56271 L p F P
0 g
s
.651 .758 .928 r
.60801 .55948 m .59659 .56299 L .5937 .55976 L p F P
0 g
s
.65 .757 .928 r
.24811 .563 m .25892 .5595 L .26234 .56273 L p F P
0 g
s
.65 .757 .928 r
.25892 .5595 m .24811 .563 L .24466 .55977 L p F P
0 g
s
.65 .758 .928 r
.42235 .56302 m .43346 .55951 L .43661 .56275 L p F P
0 g
s
.65 .758 .928 r
.43346 .55951 m .42235 .56302 L .41918 .55978 L p F P
0 g
s
.651 .758 .928 r
.78512 .56258 m .79687 .55906 L .79943 .56229 L p F P
0 g
s
.651 .758 .928 r
.79687 .55906 m .78512 .56258 L .78254 .55935 L p F P
0 g
s
.651 .758 .928 r
.61087 .56271 m .62232 .55921 L .62516 .56244 L p F P
0 g
s
.651 .758 .928 r
.62232 .55921 m .61087 .56271 L .60801 .55948 L p F P
0 g
s
.65 .757 .928 r
.26234 .56273 m .27318 .55923 L .27658 .56247 L p F P
0 g
s
.65 .757 .928 r
.27318 .55923 m .26234 .56273 L .25892 .5595 L p F P
0 g
s
.65 .758 .928 r
.43661 .56275 m .44775 .55924 L .45087 .56248 L p F P
0 g
s
.65 .758 .928 r
.44775 .55924 m .43661 .56275 L .43346 .55951 L p F P
0 g
s
.651 .758 .928 r
.8112 .55877 m .79943 .56229 L .79687 .55906 L p F P
0 g
s
.651 .758 .928 r
.79943 .56229 m .8112 .55877 L .81374 .56199 L p F P
0 g
s
.651 .758 .928 r
.62516 .56244 m .63663 .55893 L .63945 .56217 L p F P
0 g
s
.651 .758 .928 r
.63663 .55893 m .62516 .56244 L .62232 .55921 L p F P
0 g
s
.65 .757 .928 r
.27658 .56247 m .28745 .55896 L .29082 .5622 L p F P
0 g
s
.65 .757 .928 r
.28745 .55896 m .27658 .56247 L .27318 .55923 L p F P
0 g
s
.65 .758 .928 r
.46204 .55897 m .45087 .56248 L .44775 .55924 L p F P
0 g
s
.65 .758 .928 r
.45087 .56248 m .46204 .55897 L .46514 .56221 L p F P
0 g
s
.651 .758 .928 r
.81374 .56199 m .82554 .55847 L .82805 .5617 L p F P
0 g
s
.651 .758 .928 r
.82554 .55847 m .81374 .56199 L .8112 .55877 L p F P
0 g
s
.651 .758 .928 r
.63945 .56217 m .65094 .55865 L .65374 .56189 L p F P
0 g
s
.651 .758 .928 r
.65094 .55865 m .63945 .56217 L .63663 .55893 L p F P
0 g
s
.65 .757 .928 r
.29082 .5622 m .30171 .5587 L .30507 .56193 L p F P
0 g
s
.65 .757 .928 r
.30171 .5587 m .29082 .5622 L .28745 .55896 L p F P
0 g
s
.65 .758 .928 r
.46514 .56221 m .47633 .5587 L .47941 .56194 L p F P
0 g
s
.65 .758 .928 r
.47633 .5587 m .46514 .56221 L .46204 .55897 L p F P
0 g
s
.651 .758 .928 r
.82805 .5617 m .83988 .55817 L .84237 .5614 L p F P
0 g
s
.651 .758 .928 r
.83988 .55817 m .82805 .5617 L .82554 .55847 L p F P
0 g
s
.65 .757 .928 r
.13074 .56188 m .14135 .55838 L .14497 .56162 L p F P
0 g
s
.651 .758 .928 r
.65374 .56189 m .66526 .55838 L .66804 .56161 L p F P
0 g
s
.651 .758 .928 r
.66526 .55838 m .65374 .56189 L .65094 .55865 L p F P
0 g
s
.65 .757 .928 r
.30507 .56193 m .31599 .55843 L .31932 .56167 L p F P
0 g
s
.65 .757 .928 r
.31599 .55843 m .30507 .56193 L .30171 .5587 L p F P
0 g
s
.65 .758 .928 r
.47941 .56194 m .49063 .55843 L .49368 .56166 L p F P
0 g
s
.65 .758 .928 r
.49063 .55843 m .47941 .56194 L .47633 .5587 L p F P
0 g
s
.651 .759 .928 r
.84237 .5614 m .85422 .55787 L .85669 .56109 L p F P
0 g
s
.651 .759 .928 r
.85422 .55787 m .84237 .5614 L .83988 .55817 L p F P
0 g
s
.651 .758 .928 r
.66804 .56161 m .67958 .5581 L .68234 .56133 L p F P
0 g
s
.651 .758 .928 r
.67958 .5581 m .66804 .56161 L .66526 .55838 L p F P
0 g
s
.65 .757 .928 r
.14497 .56162 m .15561 .55812 L .1592 .56136 L p F P
0 g
s
.65 .757 .928 r
.15561 .55812 m .14497 .56162 L .14135 .55838 L p F P
0 g
s
.651 .758 .928 r
.49368 .56166 m .50493 .55816 L .50796 .56139 L p F P
0 g
s
.651 .758 .928 r
.50493 .55816 m .49368 .56166 L .49063 .55843 L p F P
0 g
s
.65 .757 .928 r
.31932 .56167 m .33026 .55816 L .33358 .5614 L p F P
0 g
s
.65 .757 .928 r
.33026 .55816 m .31932 .56167 L .31599 .55843 L p F P
0 g
s
.651 .759 .928 r
.85669 .56109 m .86857 .55756 L .87102 .56079 L p F P
0 g
s
.651 .759 .928 r
.86857 .55756 m .85669 .56109 L .85422 .55787 L p F P
0 g
s
.651 .758 .928 r
.68234 .56133 m .69391 .55782 L .69664 .56106 L p F P
0 g
s
.651 .758 .928 r
.69391 .55782 m .68234 .56133 L .67958 .5581 L p F P
0 g
s
.65 .757 .928 r
.1592 .56136 m .16986 .55785 L .17343 .56109 L p F P
0 g
s
.65 .757 .928 r
.16986 .55785 m .1592 .56136 L .15561 .55812 L p F P
0 g
s
0 0 .273 r
.40019 .32078 m .40017 .32081 L .40031 .31591 L p F P
0 g
s
0 0 .273 r
.40031 .31591 m .40032 .31588 L .40019 .32078 L p F P
0 g
s
.764 .494 .526 r
.40012 .3208 m .40017 .32081 L .40031 .31591 L p F P
0 g
s
.764 .494 .526 r
.40031 .31591 m .40025 .3159 L .40012 .3208 L p F P
0 g
s
.651 .758 .928 r
.50796 .56139 m .51923 .55788 L .52224 .56112 L p F P
0 g
s
.651 .758 .928 r
.51923 .55788 m .50796 .56139 L .50493 .55816 L p F P
0 g
s
.65 .758 .928 r
.33358 .5614 m .34454 .55789 L .34783 .56113 L p F P
0 g
s
.65 .757 .928 r
.34454 .55789 m .33358 .5614 L .33026 .55816 L p F P
0 g
s
.651 .759 .928 r
.87102 .56079 m .88292 .55725 L .88534 .56047 L p F P
0 g
s
.651 .759 .928 r
.88292 .55725 m .87102 .56079 L .86857 .55756 L p F P
0 g
s
.651 .758 .928 r
.69664 .56106 m .70824 .55754 L .71095 .56078 L p F P
0 g
s
.651 .758 .928 r
.70824 .55754 m .69664 .56106 L .69391 .55782 L p F P
0 g
s
.65 .757 .928 r
.17343 .56109 m .18412 .55759 L .18767 .56083 L p F P
0 g
s
.65 .757 .928 r
.18412 .55759 m .17343 .56109 L .16986 .55785 L p F P
0 g
s
.651 .758 .928 r
.52224 .56112 m .53354 .55761 L .53652 .56085 L p F P
0 g
s
.651 .758 .928 r
.53354 .55761 m .52224 .56112 L .51923 .55788 L p F P
0 g
s
.65 .758 .928 r
.34783 .56113 m .35883 .55762 L .3621 .56086 L p F P
0 g
s
.65 .758 .928 r
.35883 .55762 m .34783 .56113 L .34454 .55789 L p F P
0 g
s
.652 .759 .928 r
.88534 .56047 m .89727 .55693 L .89967 .56016 L p F P
0 g
s
.652 .759 .928 r
.89727 .55693 m .88534 .56047 L .88292 .55725 L p F P
0 g
s
.651 .758 .928 r
.71095 .56078 m .72258 .55726 L .72526 .56049 L p F P
0 g
s
.651 .758 .928 r
.72258 .55726 m .71095 .56078 L .70824 .55754 L p F P
0 g
s
.65 .757 .928 r
.18767 .56083 m .19839 .55732 L .20191 .56056 L p F P
0 g
s
.65 .757 .928 r
.19839 .55732 m .18767 .56083 L .18412 .55759 L p F P
0 g
s
.651 .758 .928 r
.53652 .56085 m .54785 .55734 L .55081 .56058 L p F P
0 g
s
.651 .758 .928 r
.54785 .55734 m .53652 .56085 L .53354 .55761 L p F P
0 g
s
.65 .758 .928 r
.3621 .56086 m .37312 .55735 L .37636 .56059 L p F P
0 g
s
.65 .758 .928 r
.37312 .55735 m .3621 .56086 L .35883 .55762 L p F P
0 g
s
.652 .759 .928 r
.89967 .56016 m .91163 .55661 L .914 .55983 L p F P
0 g
s
.652 .759 .928 r
.91163 .55661 m .89967 .56016 L .89727 .55693 L p F P
0 g
s
.651 .758 .928 r
.72526 .56049 m .73691 .55697 L .73957 .56021 L p F P
0 g
s
.651 .758 .928 r
.73691 .55697 m .72526 .56049 L .72258 .55726 L p F P
0 g
s
.65 .757 .928 r
.20191 .56056 m .21266 .55706 L .21616 .5603 L p F P
0 g
s
.65 .757 .928 r
.21266 .55706 m .20191 .56056 L .19839 .55732 L p F P
0 g
s
.651 .758 .928 r
.55081 .56058 m .56216 .55706 L .56511 .5603 L p F P
0 g
s
.651 .758 .928 r
.56216 .55706 m .55081 .56058 L .54785 .55734 L p F P
0 g
s
.65 .758 .928 r
.37636 .56059 m .38741 .55708 L .39063 .56032 L p F P
0 g
s
.65 .758 .928 r
.38741 .55708 m .37636 .56059 L .37312 .55735 L p F P
0 g
s
.652 .759 .928 r
.914 .55983 m .92598 .55628 L .92834 .5595 L p F P
0 g
s
.652 .759 .928 r
.92598 .55628 m .914 .55983 L .91163 .55661 L p F P
0 g
s
.651 .758 .928 r
.73957 .56021 m .75126 .55669 L .75389 .55993 L p F P
0 g
s
.651 .758 .928 r
.75126 .55669 m .73957 .56021 L .73691 .55697 L p F P
0 g
s
.652 .76 .928 r
.92834 .5595 m .94035 .55594 L .94268 .55917 L p F P
0 g
s
.652 .76 .928 r
.94035 .55594 m .92834 .5595 L .92598 .55628 L p F P
0 g
s
.65 .757 .928 r
.21616 .5603 m .22693 .55679 L .23041 .56003 L p F P
0 g
s
.65 .757 .928 r
.22693 .55679 m .21616 .5603 L .21266 .55706 L p F P
0 g
s
.651 .758 .928 r
.56511 .5603 m .57648 .55679 L .5794 .56003 L p F P
0 g
s
.651 .758 .928 r
.57648 .55679 m .56511 .5603 L .56216 .55706 L p F P
0 g
s
.65 .758 .928 r
.39063 .56032 m .40171 .55681 L .4049 .56005 L p F P
0 g
s
.65 .758 .928 r
.40171 .55681 m .39063 .56032 L .38741 .55708 L p F P
0 g
s
.651 .758 .928 r
.75389 .55993 m .7656 .5564 L .76822 .55964 L p F P
0 g
s
.651 .758 .928 r
.7656 .5564 m .75389 .55993 L .75126 .55669 L p F P
0 g
s
.651 .758 .928 r
.5794 .56003 m .59081 .55651 L .5937 .55976 L p F P
0 g
s
.651 .758 .928 r
.59081 .55651 m .5794 .56003 L .57648 .55679 L p F P
0 g
s
.65 .757 .928 r
.23041 .56003 m .2412 .55652 L .24466 .55977 L p F P
0 g
s
.65 .757 .928 r
.2412 .55652 m .23041 .56003 L .22693 .55679 L p F P
0 g
s
.65 .758 .928 r
.4049 .56005 m .41601 .55654 L .41918 .55978 L p F P
0 g
s
.65 .758 .928 r
.41601 .55654 m .4049 .56005 L .40171 .55681 L p F P
0 g
s
.651 .758 .928 r
.76822 .55964 m .77995 .55611 L .78254 .55935 L p F P
0 g
s
.651 .758 .928 r
.77995 .55611 m .76822 .55964 L .7656 .5564 L p F P
0 g
s
.651 .758 .928 r
.5937 .55976 m .60513 .55624 L .60801 .55948 L p F P
0 g
s
.651 .758 .928 r
.60513 .55624 m .5937 .55976 L .59081 .55651 L p F P
0 g
s
.65 .757 .928 r
.24466 .55977 m .25548 .55626 L .25892 .5595 L p F P
0 g
s
.65 .757 .928 r
.25548 .55626 m .24466 .55977 L .2412 .55652 L p F P
0 g
s
.65 .758 .928 r
.41918 .55978 m .43031 .55627 L .43346 .55951 L p F P
0 g
s
.65 .758 .928 r
.43031 .55627 m .41918 .55978 L .41601 .55654 L p F P
0 g
s
.651 .758 .928 r
.7943 .55582 m .78254 .55935 L .77995 .55611 L p F P
0 g
s
.651 .758 .928 r
.78254 .55935 m .7943 .55582 L .79687 .55906 L p F P
0 g
s
.651 .758 .928 r
.60801 .55948 m .61946 .55596 L .62232 .55921 L p F P
0 g
s
.651 .758 .928 r
.61946 .55596 m .60801 .55948 L .60513 .55624 L p F P
0 g
s
.65 .757 .928 r
.25892 .5595 m .26977 .55599 L .27318 .55923 L p F P
0 g
s
.65 .757 .928 r
.26977 .55599 m .25892 .5595 L .25548 .55626 L p F P
0 g
s
.65 .758 .928 r
.43346 .55951 m .44462 .556 L .44775 .55924 L p F P
0 g
s
.65 .758 .928 r
.44462 .556 m .43346 .55951 L .43031 .55627 L p F P
0 g
s
.651 .758 .928 r
.79687 .55906 m .80866 .55553 L .8112 .55877 L p F P
0 g
s
.651 .758 .928 r
.80866 .55553 m .79687 .55906 L .7943 .55582 L p F P
0 g
s
.651 .758 .928 r
.62232 .55921 m .6338 .55569 L .63663 .55893 L p F P
0 g
s
.651 .758 .928 r
.6338 .55569 m .62232 .55921 L .61946 .55596 L p F P
0 g
s
.65 .757 .928 r
.27318 .55923 m .28406 .55572 L .28745 .55896 L p F P
0 g
s
.65 .757 .928 r
.28406 .55572 m .27318 .55923 L .26977 .55599 L p F P
0 g
s
.65 .758 .928 r
.44775 .55924 m .45893 .55572 L .46204 .55897 L p F P
0 g
s
.65 .758 .928 r
.45893 .55572 m .44775 .55924 L .44462 .556 L p F P
0 g
s
.651 .758 .928 r
.82302 .55523 m .8112 .55877 L .80866 .55553 L p F P
0 g
s
.651 .758 .928 r
.8112 .55877 m .82302 .55523 L .82554 .55847 L p F P
0 g
s
.651 .758 .928 r
.63663 .55893 m .64814 .55541 L .65094 .55865 L p F P
0 g
s
.651 .758 .928 r
.64814 .55541 m .63663 .55893 L .6338 .55569 L p F P
0 g
s
.65 .757 .928 r
.28745 .55896 m .29835 .55545 L .30171 .5587 L p F P
0 g
s
.65 .757 .928 r
.29835 .55545 m .28745 .55896 L .28406 .55572 L p F P
0 g
s
.65 .758 .928 r
.47324 .55545 m .46204 .55897 L .45893 .55572 L p F P
0 g
s
.65 .758 .928 r
.46204 .55897 m .47324 .55545 L .47633 .5587 L p F P
0 g
s
.651 .758 .928 r
.82554 .55847 m .83738 .55493 L .83988 .55817 L p F P
0 g
s
.651 .758 .928 r
.83738 .55493 m .82554 .55847 L .82302 .55523 L p F P
0 g
s
.651 .758 .928 r
.65094 .55865 m .66248 .55513 L .66526 .55838 L p F P
0 g
s
.651 .758 .928 r
.66248 .55513 m .65094 .55865 L .64814 .55541 L p F P
0 g
s
0 0 .273 r
.40006 .3257 m .40004 .32573 L .40017 .32081 L p F P
0 g
s
0 0 .273 r
.40017 .32081 m .40019 .32078 L .40006 .3257 L p F P
0 g
s
.764 .494 .526 r
.39999 .32572 m .40004 .32573 L .40017 .32081 L p F P
0 g
s
.764 .494 .526 r
.40017 .32081 m .40012 .3208 L .39999 .32572 L p F P
0 g
s
.65 .757 .928 r
.30171 .5587 m .31264 .55518 L .31599 .55843 L p F P
0 g
s
.65 .757 .928 r
.31264 .55518 m .30171 .5587 L .29835 .55545 L p F P
0 g
s
.65 .758 .928 r
.47633 .5587 m .48756 .55518 L .49063 .55843 L p F P
0 g
s
.651 .758 .928 r
.48756 .55518 m .47633 .5587 L .47324 .55545 L p F P
0 g
s
.651 .759 .928 r
.83988 .55817 m .85175 .55463 L .85422 .55787 L p F P
0 g
s
.651 .759 .928 r
.85175 .55463 m .83988 .55817 L .83738 .55493 L p F P
0 g
s
.651 .758 .928 r
.66526 .55838 m .67683 .55485 L .67958 .5581 L p F P
0 g
s
.651 .758 .928 r
.67683 .55485 m .66526 .55838 L .66248 .55513 L p F P
0 g
s
.65 .757 .928 r
.14135 .55838 m .152 .55487 L .15561 .55812 L p F P
0 g
s
.651 .758 .928 r
.49063 .55843 m .50188 .55491 L .50493 .55816 L p F P
0 g
s
.651 .758 .928 r
.50188 .55491 m .49063 .55843 L .48756 .55518 L p F P
0 g
s
.65 .757 .928 r
.31599 .55843 m .32694 .55491 L .33026 .55816 L p F P
0 g
s
.65 .757 .928 r
.32694 .55491 m .31599 .55843 L .31264 .55518 L p F P
0 g
s
.651 .759 .928 r
.85422 .55787 m .86611 .55432 L .86857 .55756 L p F P
0 g
s
.651 .759 .928 r
.86611 .55432 m .85422 .55787 L .85175 .55463 L p F P
0 g
s
.651 .758 .928 r
.67958 .5581 m .69117 .55457 L .69391 .55782 L p F P
0 g
s
.651 .758 .928 r
.69117 .55457 m .67958 .5581 L .67683 .55485 L p F P
0 g
s
.65 .757 .928 r
.15561 .55812 m .16628 .5546 L .16986 .55785 L p F P
0 g
s
.65 .757 .928 r
.16628 .5546 m .15561 .55812 L .152 .55487 L p F P
0 g
s
.651 .758 .928 r
.50493 .55816 m .51621 .55463 L .51923 .55788 L p F P
0 g
s
.651 .758 .928 r
.51621 .55463 m .50493 .55816 L .50188 .55491 L p F P
0 g
s
.65 .757 .928 r
.33026 .55816 m .34125 .55464 L .34454 .55789 L p F P
0 g
s
.65 .757 .928 r
.34125 .55464 m .33026 .55816 L .32694 .55491 L p F P
0 g
s
.651 .759 .928 r
.86857 .55756 m .88049 .55401 L .88292 .55725 L p F P
0 g
s
.651 .759 .928 r
.88049 .55401 m .86857 .55756 L .86611 .55432 L p F P
0 g
s
.651 .758 .928 r
.69391 .55782 m .70553 .55429 L .70824 .55754 L p F P
0 g
s
.651 .758 .928 r
.70553 .55429 m .69391 .55782 L .69117 .55457 L p F P
0 g
s
.65 .757 .928 r
.16986 .55785 m .18056 .55434 L .18412 .55759 L p F P
0 g
s
.65 .757 .928 r
.18056 .55434 m .16986 .55785 L .16628 .5546 L p F P
0 g
s
.651 .758 .928 r
.51923 .55788 m .53054 .55436 L .53354 .55761 L p F P
0 g
s
.651 .758 .928 r
.53054 .55436 m .51923 .55788 L .51621 .55463 L p F P
0 g
s
.65 .758 .928 r
.34454 .55789 m .35555 .55437 L .35883 .55762 L p F P
0 g
s
.65 .758 .928 r
.35555 .55437 m .34454 .55789 L .34125 .55464 L p F P
0 g
s
.652 .759 .928 r
.88292 .55725 m .89486 .55369 L .89727 .55693 L p F P
0 g
s
.652 .759 .928 r
.89486 .55369 m .88292 .55725 L .88049 .55401 L p F P
0 g
s
.651 .758 .928 r
.70824 .55754 m .71989 .55401 L .72258 .55726 L p F P
0 g
s
.651 .758 .928 r
.71989 .55401 m .70824 .55754 L .70553 .55429 L p F P
0 g
s
.65 .757 .928 r
.18412 .55759 m .19485 .55407 L .19839 .55732 L p F P
0 g
s
.65 .757 .928 r
.19485 .55407 m .18412 .55759 L .18056 .55434 L p F P
0 g
s
.651 .758 .928 r
.53354 .55761 m .54488 .55409 L .54785 .55734 L p F P
0 g
s
.651 .758 .928 r
.54488 .55409 m .53354 .55761 L .53054 .55436 L p F P
0 g
s
.65 .758 .928 r
.35883 .55762 m .36986 .5541 L .37312 .55735 L p F P
0 g
s
.65 .758 .928 r
.36986 .5541 m .35883 .55762 L .35555 .55437 L p F P
0 g
s
.652 .759 .928 r
.89727 .55693 m .90924 .55337 L .91163 .55661 L p F P
0 g
s
.652 .759 .928 r
.90924 .55337 m .89727 .55693 L .89486 .55369 L p F P
0 g
s
.651 .758 .928 r
.72258 .55726 m .73425 .55372 L .73691 .55697 L p F P
0 g
s
.651 .758 .928 r
.73425 .55372 m .72258 .55726 L .71989 .55401 L p F P
0 g
s
.65 .757 .928 r
.19839 .55732 m .20914 .5538 L .21266 .55706 L p F P
0 g
s
.65 .757 .928 r
.20914 .5538 m .19839 .55732 L .19485 .55407 L p F P
0 g
s
.651 .758 .928 r
.54785 .55734 m .55921 .55381 L .56216 .55706 L p F P
0 g
s
.651 .758 .928 r
.55921 .55381 m .54785 .55734 L .54488 .55409 L p F P
0 g
s
.65 .758 .928 r
.37312 .55735 m .38418 .55383 L .38741 .55708 L p F P
0 g
s
.65 .758 .928 r
.38418 .55383 m .37312 .55735 L .36986 .5541 L p F P
0 g
s
.652 .759 .928 r
.91163 .55661 m .92362 .55305 L .92598 .55628 L p F P
0 g
s
.652 .759 .928 r
.92362 .55305 m .91163 .55661 L .90924 .55337 L p F P
0 g
s
.651 .758 .928 r
.73691 .55697 m .74861 .55344 L .75126 .55669 L p F P
0 g
s
.651 .758 .928 r
.74861 .55344 m .73691 .55697 L .73425 .55372 L p F P
0 g
s
.65 .757 .928 r
.21266 .55706 m .22344 .55354 L .22693 .55679 L p F P
0 g
s
.65 .757 .928 r
.22344 .55354 m .21266 .55706 L .20914 .5538 L p F P
0 g
s
.651 .758 .928 r
.56216 .55706 m .57356 .55354 L .57648 .55679 L p F P
0 g
s
.651 .758 .928 r
.57356 .55354 m .56216 .55706 L .55921 .55381 L p F P
0 g
s
.652 .76 .928 r
.92598 .55628 m .93801 .55271 L .94035 .55594 L p F P
0 g
s
.652 .759 .928 r
.93801 .55271 m .92598 .55628 L .92362 .55305 L p F P
0 g
s
.65 .758 .928 r
.38741 .55708 m .3985 .55356 L .40171 .55681 L p F P
0 g
s
.65 .758 .928 r
.3985 .55356 m .38741 .55708 L .38418 .55383 L p F P
0 g
s
.651 .758 .928 r
.75126 .55669 m .76298 .55315 L .7656 .5564 L p F P
0 g
s
.651 .758 .928 r
.76298 .55315 m .75126 .55669 L .74861 .55344 L p F P
0 g
s
.651 .758 .928 r
.57648 .55679 m .5879 .55326 L .59081 .55651 L p F P
0 g
s
.651 .758 .928 r
.5879 .55326 m .57648 .55679 L .57356 .55354 L p F P
0 g
s
.65 .757 .928 r
.22693 .55679 m .23774 .55327 L .2412 .55652 L p F P
0 g
s
.65 .757 .928 r
.23774 .55327 m .22693 .55679 L .22344 .55354 L p F P
0 g
s
.65 .758 .928 r
.40171 .55681 m .41282 .55329 L .41601 .55654 L p F P
0 g
s
.65 .758 .928 r
.41282 .55329 m .40171 .55681 L .3985 .55356 L p F P
0 g
s
.651 .758 .928 r
.7656 .5564 m .77735 .55286 L .77995 .55611 L p F P
0 g
s
.651 .758 .928 r
.77735 .55286 m .7656 .5564 L .76298 .55315 L p F P
0 g
s
.651 .758 .928 r
.59081 .55651 m .60225 .55299 L .60513 .55624 L p F P
0 g
s
.651 .758 .928 r
.60225 .55299 m .59081 .55651 L .5879 .55326 L p F P
0 g
s
.65 .757 .928 r
.2412 .55652 m .25204 .553 L .25548 .55626 L p F P
0 g
s
.65 .757 .928 r
.25204 .553 m .2412 .55652 L .23774 .55327 L p F P
0 g
s
.65 .758 .928 r
.41601 .55654 m .42714 .55301 L .43031 .55627 L p F P
0 g
s
.65 .758 .928 r
.42714 .55301 m .41601 .55654 L .41282 .55329 L p F P
0 g
s
.651 .758 .928 r
.77995 .55611 m .79172 .55257 L .7943 .55582 L p F P
0 g
s
.651 .758 .928 r
.79172 .55257 m .77995 .55611 L .77735 .55286 L p F P
0 g
s
.651 .758 .928 r
.60513 .55624 m .61661 .55271 L .61946 .55596 L p F P
0 g
s
.651 .758 .928 r
.61661 .55271 m .60513 .55624 L .60225 .55299 L p F P
0 g
s
.65 .757 .928 r
.25548 .55626 m .26634 .55273 L .26977 .55599 L p F P
0 g
s
.65 .757 .928 r
.26634 .55273 m .25548 .55626 L .25204 .553 L p F P
0 g
s
.65 .758 .928 r
.43031 .55627 m .44148 .55274 L .44462 .556 L p F P
0 g
s
.65 .758 .928 r
.44148 .55274 m .43031 .55627 L .42714 .55301 L p F P
0 g
s
.651 .758 .928 r
.8061 .55228 m .7943 .55582 L .79172 .55257 L p F P
0 g
s
.651 .758 .928 r
.7943 .55582 m .8061 .55228 L .80866 .55553 L p F P
0 g
s
.651 .758 .928 r
.61946 .55596 m .63096 .55243 L .6338 .55569 L p F P
0 g
s
.651 .758 .928 r
.63096 .55243 m .61946 .55596 L .61661 .55271 L p F P
0 g
s
0 0 .273 r
.39992 .33063 m .39991 .33066 L .40004 .32573 L p F P
0 g
s
0 0 .273 r
.40004 .32573 m .40006 .3257 L .39992 .33063 L p F P
0 g
s
.764 .494 .526 r
.39986 .33065 m .39991 .33066 L .40004 .32573 L p F P
0 g
s
.764 .494 .526 r
.40004 .32573 m .39999 .32572 L .39986 .33065 L p F P
0 g
s
.65 .757 .928 r
.26977 .55599 m .28065 .55246 L .28406 .55572 L p F P
0 g
s
.65 .757 .928 r
.28065 .55246 m .26977 .55599 L .26634 .55273 L p F P
0 g
s
.65 .758 .928 r
.44462 .556 m .45581 .55247 L .45893 .55572 L p F P
0 g
s
.65 .758 .928 r
.45581 .55247 m .44462 .556 L .44148 .55274 L p F P
0 g
s
.651 .758 .928 r
.80866 .55553 m .82049 .55198 L .82302 .55523 L p F P
0 g
s
.651 .758 .928 r
.82049 .55198 m .80866 .55553 L .8061 .55228 L p F P
0 g
s
.651 .758 .928 r
.6338 .55569 m .64532 .55215 L .64814 .55541 L p F P
0 g
s
.651 .758 .928 r
.64532 .55215 m .6338 .55569 L .63096 .55243 L p F P
0 g
s
.65 .757 .928 r
.28406 .55572 m .29497 .55219 L .29835 .55545 L p F P
0 g
s
.65 .757 .928 r
.29497 .55219 m .28406 .55572 L .28065 .55246 L p F P
0 g
s
.65 .758 .928 r
.45893 .55572 m .47015 .5522 L .47324 .55545 L p F P
0 g
s
.65 .758 .928 r
.47015 .5522 m .45893 .55572 L .45581 .55247 L p F P
0 g
s
.651 .758 .928 r
.83487 .55168 m .82302 .55523 L .82049 .55198 L p F P
0 g
s
.651 .758 .928 r
.82302 .55523 m .83487 .55168 L .83738 .55493 L p F P
0 g
s
.651 .758 .928 r
.64814 .55541 m .65969 .55188 L .66248 .55513 L p F P
0 g
s
.651 .758 .928 r
.65969 .55188 m .64814 .55541 L .64532 .55215 L p F P
0 g
s
.65 .757 .928 r
.29835 .55545 m .30929 .55192 L .31264 .55518 L p F P
0 g
s
.65 .757 .928 r
.30929 .55192 m .29835 .55545 L .29497 .55219 L p F P
0 g
s
.651 .758 .928 r
.48449 .55192 m .47324 .55545 L .47015 .5522 L p F P
0 g
s
.651 .758 .928 r
.47324 .55545 m .48449 .55192 L .48756 .55518 L p F P
0 g
s
.651 .759 .928 r
.83738 .55493 m .84926 .55138 L .85175 .55463 L p F P
0 g
s
.651 .758 .928 r
.84926 .55138 m .83738 .55493 L .83487 .55168 L p F P
0 g
s
.651 .758 .928 r
.66248 .55513 m .67406 .5516 L .67683 .55485 L p F P
0 g
s
.651 .758 .928 r
.67406 .5516 m .66248 .55513 L .65969 .55188 L p F P
0 g
s
.651 .758 .928 r
.48756 .55518 m .49883 .55165 L .50188 .55491 L p F P
0 g
s
.651 .758 .928 r
.49883 .55165 m .48756 .55518 L .48449 .55192 L p F P
0 g
s
.65 .757 .928 r
.31264 .55518 m .32361 .55165 L .32694 .55491 L p F P
0 g
s
.65 .757 .928 r
.32361 .55165 m .31264 .55518 L .30929 .55192 L p F P
0 g
s
.651 .759 .928 r
.85175 .55463 m .86365 .55107 L .86611 .55432 L p F P
0 g
s
.651 .759 .928 r
.86365 .55107 m .85175 .55463 L .84926 .55138 L p F P
0 g
s
.651 .758 .928 r
.67683 .55485 m .68843 .55132 L .69117 .55457 L p F P
0 g
s
.651 .758 .928 r
.68843 .55132 m .67683 .55485 L .67406 .5516 L p F P
0 g
s
.65 .757 .928 r
.152 .55487 m .16269 .55134 L .16628 .5546 L p F P
0 g
s
.651 .758 .928 r
.50188 .55491 m .51318 .55137 L .51621 .55463 L p F P
0 g
s
.651 .758 .928 r
.51318 .55137 m .50188 .55491 L .49883 .55165 L p F P
0 g
s
.65 .757 .928 r
.32694 .55491 m .33793 .55138 L .34125 .55464 L p F P
0 g
s
.65 .757 .928 r
.33793 .55138 m .32694 .55491 L .32361 .55165 L p F P
0 g
s
.651 .759 .928 r
.86611 .55432 m .87805 .55076 L .88049 .55401 L p F P
0 g
s
.651 .759 .928 r
.87805 .55076 m .86611 .55432 L .86365 .55107 L p F P
0 g
s
.651 .758 .928 r
.69117 .55457 m .70281 .55103 L .70553 .55429 L p F P
0 g
s
.651 .758 .928 r
.70281 .55103 m .69117 .55457 L .68843 .55132 L p F P
0 g
s
.65 .757 .928 r
.16628 .5546 m .17699 .55108 L .18056 .55434 L p F P
0 g
s
.65 .757 .928 r
.17699 .55108 m .16628 .5546 L .16269 .55134 L p F P
0 g
s
.651 .758 .928 r
.51621 .55463 m .52754 .5511 L .53054 .55436 L p F P
0 g
s
.651 .758 .928 r
.52754 .5511 m .51621 .55463 L .51318 .55137 L p F P
0 g
s
.65 .758 .928 r
.34125 .55464 m .35226 .55111 L .35555 .55437 L p F P
0 g
s
.65 .757 .928 r
.35226 .55111 m .34125 .55464 L .33793 .55138 L p F P
0 g
s
.652 .759 .928 r
.88049 .55401 m .89245 .55045 L .89486 .55369 L p F P
0 g
s
.651 .759 .928 r
.89245 .55045 m .88049 .55401 L .87805 .55076 L p F P
0 g
s
.651 .758 .928 r
.70553 .55429 m .71719 .55075 L .71989 .55401 L p F P
0 g
s
.651 .758 .928 r
.71719 .55075 m .70553 .55429 L .70281 .55103 L p F P
0 g
s
.65 .757 .928 r
.18056 .55434 m .1913 .55081 L .19485 .55407 L p F P
0 g
s
.65 .757 .928 r
.1913 .55081 m .18056 .55434 L .17699 .55108 L p F P
0 g
s
.651 .758 .928 r
.53054 .55436 m .54189 .55083 L .54488 .55409 L p F P
0 g
s
.651 .758 .928 r
.54189 .55083 m .53054 .55436 L .52754 .5511 L p F P
0 g
s
.65 .758 .928 r
.35555 .55437 m .3666 .55084 L .36986 .5541 L p F P
0 g
s
.65 .758 .928 r
.3666 .55084 m .35555 .55437 L .35226 .55111 L p F P
0 g
s
.652 .759 .928 r
.89486 .55369 m .90685 .55013 L .90924 .55337 L p F P
0 g
s
.652 .759 .928 r
.90685 .55013 m .89486 .55369 L .89245 .55045 L p F P
0 g
s
.651 .758 .928 r
.71989 .55401 m .73157 .55047 L .73425 .55372 L p F P
0 g
s
.651 .758 .928 r
.73157 .55047 m .71989 .55401 L .71719 .55075 L p F P
0 g
s
.65 .757 .928 r
.19485 .55407 m .20562 .55054 L .20914 .5538 L p F P
0 g
s
.65 .757 .928 r
.20562 .55054 m .19485 .55407 L .1913 .55081 L p F P
0 g
s
.651 .758 .928 r
.54488 .55409 m .55625 .55055 L .55921 .55381 L p F P
0 g
s
.651 .758 .928 r
.55625 .55055 m .54488 .55409 L .54189 .55083 L p F P
0 g
s
.65 .758 .928 r
.36986 .5541 m .38094 .55057 L .38418 .55383 L p F P
0 g
s
.65 .758 .928 r
.38094 .55057 m .36986 .5541 L .3666 .55084 L p F P
0 g
s
.652 .759 .928 r
.90924 .55337 m .92125 .5498 L .92362 .55305 L p F P
0 g
s
.652 .759 .928 r
.92125 .5498 m .90924 .55337 L .90685 .55013 L p F P
0 g
s
.651 .758 .928 r
.73425 .55372 m .74596 .55018 L .74861 .55344 L p F P
0 g
s
.651 .758 .928 r
.74596 .55018 m .73425 .55372 L .73157 .55047 L p F P
0 g
s
.65 .757 .928 r
.20914 .5538 m .21993 .55027 L .22344 .55354 L p F P
0 g
s
.65 .757 .928 r
.21993 .55027 m .20914 .5538 L .20562 .55054 L p F P
0 g
s
.651 .758 .928 r
.55921 .55381 m .57062 .55027 L .57356 .55354 L p F P
0 g
s
.651 .758 .928 r
.57062 .55027 m .55921 .55381 L .55625 .55055 L p F P
0 g
s
.65 .758 .928 r
.38418 .55383 m .39528 .55029 L .3985 .55356 L p F P
0 g
s
.65 .758 .928 r
.39528 .55029 m .38418 .55383 L .38094 .55057 L p F P
0 g
s
.652 .759 .928 r
.92362 .55305 m .93566 .54946 L .93801 .55271 L p F P
0 g
s
.652 .759 .928 r
.93566 .54946 m .92362 .55305 L .92125 .5498 L p F P
0 g
s
.651 .758 .928 r
.74861 .55344 m .76035 .54989 L .76298 .55315 L p F P
0 g
s
.651 .758 .928 r
.76035 .54989 m .74861 .55344 L .74596 .55018 L p F P
0 g
s
.65 .757 .928 r
.22344 .55354 m .23426 .55 L .23774 .55327 L p F P
0 g
s
.65 .757 .928 r
.23426 .55 m .22344 .55354 L .21993 .55027 L p F P
0 g
s
.651 .758 .928 r
.57356 .55354 m .58499 .55 L .5879 .55326 L p F P
0 g
s
.651 .758 .928 r
.58499 .55 m .57356 .55354 L .57062 .55027 L p F P
0 g
s
.65 .758 .928 r
.3985 .55356 m .40962 .55002 L .41282 .55329 L p F P
0 g
s
.65 .758 .928 r
.40962 .55002 m .3985 .55356 L .39528 .55029 L p F P
0 g
s
.651 .758 .928 r
.76298 .55315 m .77474 .5496 L .77735 .55286 L p F P
0 g
s
.651 .758 .928 r
.77474 .5496 m .76298 .55315 L .76035 .54989 L p F P
0 g
s
.651 .758 .928 r
.5879 .55326 m .59936 .54972 L .60225 .55299 L p F P
0 g
s
.651 .758 .928 r
.59936 .54972 m .5879 .55326 L .58499 .55 L p F P
0 g
s
.65 .757 .928 r
.23774 .55327 m .24858 .54973 L .25204 .553 L p F P
0 g
s
.65 .757 .928 r
.24858 .54973 m .23774 .55327 L .23426 .55 L p F P
0 g
s
0 0 .273 r
.39979 .33557 m .39978 .3356 L .39991 .33066 L p F P
0 g
s
0 0 .273 r
.39991 .33066 m .39992 .33063 L .39979 .33557 L p F P
0 g
s
.764 .494 .526 r
.39973 .33559 m .39978 .3356 L .39991 .33066 L p F P
0 g
s
.764 .494 .526 r
.39991 .33066 m .39986 .33065 L .39973 .33559 L p F P
0 g
s
.65 .758 .928 r
.41282 .55329 m .42397 .54975 L .42714 .55301 L p F P
0 g
s
.65 .758 .928 r
.42397 .54975 m .41282 .55329 L .40962 .55002 L p F P
0 g
s
.651 .758 .928 r
.77735 .55286 m .78914 .54931 L .79172 .55257 L p F P
0 g
s
.651 .758 .928 r
.78914 .54931 m .77735 .55286 L .77474 .5496 L p F P
0 g
s
.651 .758 .928 r
.60225 .55299 m .61374 .54944 L .61661 .55271 L p F P
0 g
s
.651 .758 .928 r
.61374 .54944 m .60225 .55299 L .59936 .54972 L p F P
0 g
s
.65 .757 .928 r
.25204 .553 m .26291 .54946 L .26634 .55273 L p F P
0 g
s
.65 .757 .928 r
.26291 .54946 m .25204 .553 L .24858 .54973 L p F P
0 g
s
.65 .758 .928 r
.42714 .55301 m .43832 .54947 L .44148 .55274 L p F P
0 g
s
.65 .758 .928 r
.43832 .54947 m .42714 .55301 L .42397 .54975 L p F P
0 g
s
.651 .758 .928 r
.79172 .55257 m .80354 .54902 L .8061 .55228 L p F P
0 g
s
.651 .758 .928 r
.80354 .54902 m .79172 .55257 L .78914 .54931 L p F P
0 g
s
.651 .758 .928 r
.61661 .55271 m .62812 .54917 L .63096 .55243 L p F P
0 g
s
.651 .758 .928 r
.62812 .54917 m .61661 .55271 L .61374 .54944 L p F P
0 g
s
.65 .757 .928 r
.26634 .55273 m .27724 .54919 L .28065 .55246 L p F P
0 g
s
.65 .757 .928 r
.27724 .54919 m .26634 .55273 L .26291 .54946 L p F P
0 g
s
.65 .758 .928 r
.44148 .55274 m .45268 .5492 L .45581 .55247 L p F P
0 g
s
.65 .758 .928 r
.45268 .5492 m .44148 .55274 L .43832 .54947 L p F P
0 g
s
.651 .758 .928 r
.81795 .54872 m .8061 .55228 L .80354 .54902 L p F P
0 g
s
.651 .758 .928 r
.8061 .55228 m .81795 .54872 L .82049 .55198 L p F P
0 g
s
.651 .758 .928 r
.63096 .55243 m .6425 .54889 L .64532 .55215 L p F P
0 g
s
.651 .758 .928 r
.6425 .54889 m .63096 .55243 L .62812 .54917 L p F P
0 g
s
.65 .757 .928 r
.28065 .55246 m .29158 .54892 L .29497 .55219 L p F P
0 g
s
.65 .757 .928 r
.29158 .54892 m .28065 .55246 L .27724 .54919 L p F P
0 g
s
.65 .758 .928 r
.45581 .55247 m .46704 .54893 L .47015 .5522 L p F P
0 g
s
.65 .758 .928 r
.46704 .54893 m .45581 .55247 L .45268 .5492 L p F P
0 g
s
.651 .758 .928 r
.82049 .55198 m .83235 .54842 L .83487 .55168 L p F P
0 g
s
.651 .758 .928 r
.83235 .54842 m .82049 .55198 L .81795 .54872 L p F P
0 g
s
.651 .758 .928 r
.64532 .55215 m .65689 .54861 L .65969 .55188 L p F P
0 g
s
.651 .758 .928 r
.65689 .54861 m .64532 .55215 L .6425 .54889 L p F P
0 g
s
.65 .757 .928 r
.29497 .55219 m .30592 .54865 L .30929 .55192 L p F P
0 g
s
.65 .757 .928 r
.30592 .54865 m .29497 .55219 L .29158 .54892 L p F P
0 g
s
.651 .758 .928 r
.47015 .5522 m .48141 .54865 L .48449 .55192 L p F P
0 g
s
.651 .758 .928 r
.48141 .54865 m .47015 .5522 L .46704 .54893 L p F P
0 g
s
.651 .758 .928 r
.84677 .54812 m .83487 .55168 L .83235 .54842 L p F P
0 g
s
.651 .758 .928 r
.83487 .55168 m .84677 .54812 L .84926 .55138 L p F P
0 g
s
.651 .758 .928 r
.65969 .55188 m .67128 .54833 L .67406 .5516 L p F P
0 g
s
.651 .758 .928 r
.67128 .54833 m .65969 .55188 L .65689 .54861 L p F P
0 g
s
.65 .757 .928 r
.30929 .55192 m .32027 .54838 L .32361 .55165 L p F P
0 g
s
.65 .757 .928 r
.32027 .54838 m .30929 .55192 L .30592 .54865 L p F P
0 g
s
.651 .758 .928 r
.49577 .54838 m .48449 .55192 L .48141 .54865 L p F P
0 g
s
.651 .758 .928 r
.48449 .55192 m .49577 .54838 L .49883 .55165 L p F P
0 g
s
.651 .759 .928 r
.84926 .55138 m .86118 .54781 L .86365 .55107 L p F P
0 g
s
.651 .759 .928 r
.86118 .54781 m .84926 .55138 L .84677 .54812 L p F P
0 g
s
.651 .758 .928 r
.67406 .5516 m .68567 .54805 L .68843 .55132 L p F P
0 g
s
.651 .758 .928 r
.68567 .54805 m .67406 .5516 L .67128 .54833 L p F P
0 g
s
.651 .758 .928 r
.49883 .55165 m .51015 .5481 L .51318 .55137 L p F P
0 g
s
.651 .758 .928 r
.51015 .5481 m .49883 .55165 L .49577 .54838 L p F P
0 g
s
.65 .757 .928 r
.32361 .55165 m .33461 .54811 L .33793 .55138 L p F P
0 g
s
.65 .757 .928 r
.33461 .54811 m .32361 .55165 L .32027 .54838 L p F P
0 g
s
.651 .759 .928 r
.86365 .55107 m .8756 .5475 L .87805 .55076 L p F P
0 g
s
.651 .759 .928 r
.8756 .5475 m .86365 .55107 L .86118 .54781 L p F P
0 g
s
.651 .758 .928 r
.68843 .55132 m .70007 .54776 L .70281 .55103 L p F P
0 g
s
.651 .758 .928 r
.70007 .54776 m .68843 .55132 L .68567 .54805 L p F P
0 g
s
.65 .757 .928 r
.16269 .55134 m .17341 .5478 L .17699 .55108 L p F P
0 g
s
.651 .758 .928 r
.51318 .55137 m .52452 .54783 L .52754 .5511 L p F P
0 g
s
.651 .758 .928 r
.52452 .54783 m .51318 .55137 L .51015 .5481 L p F P
0 g
s
.65 .757 .928 r
.33793 .55138 m .34897 .54784 L .35226 .55111 L p F P
0 g
s
.65 .757 .928 r
.34897 .54784 m .33793 .55138 L .33461 .54811 L p F P
0 g
s
.651 .759 .928 r
.87805 .55076 m .89002 .54719 L .89245 .55045 L p F P
0 g
s
.651 .759 .928 r
.89002 .54719 m .87805 .55076 L .8756 .5475 L p F P
0 g
s
.651 .758 .928 r
.70281 .55103 m .71448 .54748 L .71719 .55075 L p F P
0 g
s
.651 .758 .928 r
.71448 .54748 m .70281 .55103 L .70007 .54776 L p F P
0 g
s
.65 .757 .928 r
.17699 .55108 m .18775 .54754 L .1913 .55081 L p F P
0 g
s
.65 .757 .928 r
.18775 .54754 m .17699 .55108 L .17341 .5478 L p F P
0 g
s
.651 .758 .928 r
.52754 .5511 m .5389 .54755 L .54189 .55083 L p F P
0 g
s
.651 .758 .928 r
.5389 .54755 m .52754 .5511 L .52452 .54783 L p F P
0 g
s
.65 .758 .928 r
.35226 .55111 m .36332 .54756 L .3666 .55084 L p F P
0 g
s
.65 .758 .928 r
.36332 .54756 m .35226 .55111 L .34897 .54784 L p F P
0 g
s
.652 .759 .928 r
.89245 .55045 m .90445 .54687 L .90685 .55013 L p F P
0 g
s
.652 .759 .928 r
.90445 .54687 m .89245 .55045 L .89002 .54719 L p F P
0 g
s
.651 .758 .928 r
.71719 .55075 m .72888 .5472 L .73157 .55047 L p F P
0 g
s
.651 .758 .928 r
.72888 .5472 m .71719 .55075 L .71448 .54748 L p F P
0 g
s
.65 .757 .928 r
.1913 .55081 m .20208 .54727 L .20562 .55054 L p F P
0 g
s
.65 .757 .928 r
.20208 .54727 m .1913 .55081 L .18775 .54754 L p F P
0 g
s
.651 .758 .928 r
.54189 .55083 m .55329 .54728 L .55625 .55055 L p F P
0 g
s
.651 .758 .928 r
.55329 .54728 m .54189 .55083 L .5389 .54755 L p F P
0 g
s
.65 .758 .928 r
.3666 .55084 m .37768 .54729 L .38094 .55057 L p F P
0 g
s
.65 .758 .928 r
.37768 .54729 m .3666 .55084 L .36332 .54756 L p F P
0 g
s
.652 .759 .928 r
.90685 .55013 m .91887 .54654 L .92125 .5498 L p F P
0 g
s
.652 .759 .928 r
.91887 .54654 m .90685 .55013 L .90445 .54687 L p F P
0 g
s
.651 .758 .928 r
.73157 .55047 m .74329 .54691 L .74596 .55018 L p F P
0 g
s
.651 .758 .928 r
.74329 .54691 m .73157 .55047 L .72888 .5472 L p F P
0 g
s
.65 .757 .928 r
.20562 .55054 m .21642 .547 L .21993 .55027 L p F P
0 g
s
.65 .757 .928 r
.21642 .547 m .20562 .55054 L .20208 .54727 L p F P
0 g
s
.651 .758 .928 r
.55625 .55055 m .56767 .547 L .57062 .55027 L p F P
0 g
s
.651 .758 .928 r
.56767 .547 m .55625 .55055 L .55329 .54728 L p F P
0 g
s
0 0 .273 r
.39966 .34053 m .39964 .34056 L .39978 .3356 L p F P
0 g
s
0 0 .273 r
.39978 .3356 m .39979 .33557 L .39966 .34053 L p F P
0 g
s
.764 .494 .526 r
.3996 .34055 m .39964 .34056 L .39978 .3356 L p F P
0 g
s
.764 .494 .526 r
.39978 .3356 m .39973 .33559 L .3996 .34055 L p F P
0 g
s
.65 .758 .928 r
.38094 .55057 m .39205 .54702 L .39528 .55029 L p F P
0 g
s
.65 .758 .928 r
.39205 .54702 m .38094 .55057 L .37768 .54729 L p F P
0 g
s
.652 .759 .928 r
.92125 .5498 m .93331 .54621 L .93566 .54946 L p F P
0 g
s
.652 .759 .928 r
.93331 .54621 m .92125 .5498 L .91887 .54654 L p F P
0 g
s
.651 .758 .928 r
.74596 .55018 m .75771 .54662 L .76035 .54989 L p F P
0 g
s
.651 .758 .928 r
.75771 .54662 m .74596 .55018 L .74329 .54691 L p F P
0 g
s
.65 .757 .928 r
.21993 .55027 m .23077 .54673 L .23426 .55 L p F P
0 g
s
.65 .757 .928 r
.23077 .54673 m .21993 .55027 L .21642 .547 L p F P
0 g
s
.651 .758 .928 r
.57062 .55027 m .58206 .54672 L .58499 .55 L p F P
0 g
s
.651 .758 .928 r
.58206 .54672 m .57062 .55027 L .56767 .547 L p F P
0 g
s
.65 .758 .928 r
.39528 .55029 m .40641 .54675 L .40962 .55002 L p F P
0 g
s
.65 .758 .928 r
.40641 .54675 m .39528 .55029 L .39205 .54702 L p F P
0 g
s
.651 .758 .928 r
.76035 .54989 m .77212 .54633 L .77474 .5496 L p F P
0 g
s
.651 .758 .928 r
.77212 .54633 m .76035 .54989 L .75771 .54662 L p F P
0 g
s
.651 .758 .928 r
.58499 .55 m .59646 .54645 L .59936 .54972 L p F P
0 g
s
.651 .758 .928 r
.59646 .54645 m .58499 .55 L .58206 .54672 L p F P
0 g
s
.65 .757 .928 r
.23426 .55 m .24511 .54646 L .24858 .54973 L p F P
0 g
s
.65 .757 .928 r
.24511 .54646 m .23426 .55 L .23077 .54673 L p F P
0 g
s
.65 .758 .928 r
.40962 .55002 m .42079 .54647 L .42397 .54975 L p F P
0 g
s
.65 .758 .928 r
.42079 .54647 m .40962 .55002 L .40641 .54675 L p F P
0 g
s
.651 .758 .928 r
.77474 .5496 m .78655 .54604 L .78914 .54931 L p F P
0 g
s
.651 .758 .928 r
.78655 .54604 m .77474 .5496 L .77212 .54633 L p F P
0 g
s
.651 .758 .928 r
.59936 .54972 m .61086 .54617 L .61374 .54944 L p F P
0 g
s
.651 .758 .928 r
.61086 .54617 m .59936 .54972 L .59646 .54645 L p F P
0 g
s
.65 .757 .928 r
.24858 .54973 m .25946 .54619 L .26291 .54946 L p F P
0 g
s
.65 .757 .928 r
.25946 .54619 m .24858 .54973 L .24511 .54646 L p F P
0 g
s
.65 .758 .928 r
.42397 .54975 m .43516 .5462 L .43832 .54947 L p F P
0 g
s
.65 .758 .928 r
.43516 .5462 m .42397 .54975 L .42079 .54647 L p F P
0 g
s
.651 .758 .928 r
.78914 .54931 m .80097 .54575 L .80354 .54902 L p F P
0 g
s
.651 .758 .928 r
.80097 .54575 m .78914 .54931 L .78655 .54604 L p F P
0 g
s
.651 .758 .928 r
.61374 .54944 m .62526 .54589 L .62812 .54917 L p F P
0 g
s
.651 .758 .928 r
.62526 .54589 m .61374 .54944 L .61086 .54617 L p F P
0 g
s
.65 .757 .928 r
.26291 .54946 m .27382 .54592 L .27724 .54919 L p F P
0 g
s
.65 .757 .928 r
.27382 .54592 m .26291 .54946 L .25946 .54619 L p F P
0 g
s
.65 .758 .928 r
.43832 .54947 m .44954 .54592 L .45268 .5492 L p F P
0 g
s
.65 .758 .928 r
.44954 .54592 m .43832 .54947 L .43516 .5462 L p F P
0 g
s
.651 .758 .928 r
.80354 .54902 m .8154 .54545 L .81795 .54872 L p F P
0 g
s
.651 .758 .928 r
.8154 .54545 m .80354 .54902 L .80097 .54575 L p F P
0 g
s
.651 .758 .928 r
.62812 .54917 m .63967 .54561 L .6425 .54889 L p F P
0 g
s
.651 .758 .928 r
.63967 .54561 m .62812 .54917 L .62526 .54589 L p F P
0 g
s
.65 .757 .928 r
.27724 .54919 m .28818 .54564 L .29158 .54892 L p F P
0 g
s
.65 .757 .928 r
.28818 .54564 m .27724 .54919 L .27382 .54592 L p F P
0 g
s
.65 .758 .928 r
.45268 .5492 m .46392 .54565 L .46704 .54893 L p F P
0 g
s
.65 .758 .928 r
.46392 .54565 m .45268 .5492 L .44954 .54592 L p F P
0 g
s
.651 .758 .928 r
.82983 .54515 m .81795 .54872 L .8154 .54545 L p F P
0 g
s
.651 .758 .928 r
.81795 .54872 m .82983 .54515 L .83235 .54842 L p F P
0 g
s
.651 .758 .928 r
.6425 .54889 m .65408 .54533 L .65689 .54861 L p F P
0 g
s
.651 .758 .928 r
.65408 .54533 m .6425 .54889 L .63967 .54561 L p F P
0 g
s
.65 .757 .928 r
.29158 .54892 m .30254 .54537 L .30592 .54865 L p F P
0 g
s
.65 .757 .928 r
.30254 .54537 m .29158 .54892 L .28818 .54564 L p F P
0 g
s
.651 .758 .928 r
.46704 .54893 m .47831 .54537 L .48141 .54865 L p F P
0 g
s
.651 .758 .928 r
.47831 .54537 m .46704 .54893 L .46392 .54565 L p F P
0 g
s
.651 .758 .928 r
.83235 .54842 m .84427 .54485 L .84677 .54812 L p F P
0 g
s
.651 .758 .928 r
.84427 .54485 m .83235 .54842 L .82983 .54515 L p F P
0 g
s
.651 .758 .928 r
.65689 .54861 m .66849 .54505 L .67128 .54833 L p F P
0 g
s
.651 .758 .928 r
.66849 .54505 m .65689 .54861 L .65408 .54533 L p F P
0 g
s
.65 .757 .928 r
.30592 .54865 m .31691 .5451 L .32027 .54838 L p F P
0 g
s
.65 .757 .928 r
.31691 .5451 m .30592 .54865 L .30254 .54537 L p F P
0 g
s
.651 .758 .928 r
.48141 .54865 m .4927 .5451 L .49577 .54838 L p F P
0 g
s
.651 .758 .928 r
.4927 .5451 m .48141 .54865 L .47831 .54537 L p F P
0 g
s
.651 .758 .928 r
.8587 .54454 m .84677 .54812 L .84427 .54485 L p F P
0 g
s
.651 .759 .928 r
.84677 .54812 m .8587 .54454 L .86118 .54781 L p F P
0 g
s
.651 .758 .928 r
.67128 .54833 m .68291 .54477 L .68567 .54805 L p F P
0 g
s
.651 .758 .928 r
.68291 .54477 m .67128 .54833 L .66849 .54505 L p F P
0 g
s
.651 .758 .928 r
.5071 .54482 m .49577 .54838 L .4927 .5451 L p F P
0 g
s
.651 .758 .928 r
.49577 .54838 m .5071 .54482 L .51015 .5481 L p F P
0 g
s
.65 .757 .928 r
.32027 .54838 m .33128 .54483 L .33461 .54811 L p F P
0 g
s
.65 .757 .928 r
.33128 .54483 m .32027 .54838 L .31691 .5451 L p F P
0 g
s
.651 .759 .928 r
.86118 .54781 m .87315 .54423 L .8756 .5475 L p F P
0 g
s
.651 .759 .928 r
.87315 .54423 m .86118 .54781 L .8587 .54454 L p F P
0 g
s
.651 .758 .928 r
.68567 .54805 m .69733 .54449 L .70007 .54776 L p F P
0 g
s
.651 .758 .928 r
.69733 .54449 m .68567 .54805 L .68291 .54477 L p F P
0 g
s
.651 .758 .928 r
.51015 .5481 m .5215 .54455 L .52452 .54783 L p F P
0 g
s
.651 .758 .928 r
.5215 .54455 m .51015 .5481 L .5071 .54482 L p F P
0 g
s
.65 .757 .928 r
.33461 .54811 m .34566 .54455 L .34897 .54784 L p F P
0 g
s
.65 .757 .928 r
.34566 .54455 m .33461 .54811 L .33128 .54483 L p F P
0 g
s
.651 .759 .928 r
.8756 .5475 m .88759 .54392 L .89002 .54719 L p F P
0 g
s
.651 .759 .928 r
.88759 .54392 m .8756 .5475 L .87315 .54423 L p F P
0 g
s
.651 .758 .928 r
.70007 .54776 m .71176 .5442 L .71448 .54748 L p F P
0 g
s
.651 .758 .928 r
.71176 .5442 m .70007 .54776 L .69733 .54449 L p F P
0 g
s
.65 .757 .928 r
.17341 .5478 m .18417 .54425 L .18775 .54754 L p F P
0 g
s
0 0 .274 r
.39952 .3455 m .39951 .34552 L .39964 .34056 L p F P
0 g
s
0 0 .274 r
.39964 .34056 m .39966 .34053 L .39952 .3455 L p F P
0 g
s
.764 .494 .526 r
.39947 .34552 m .39951 .34552 L .39964 .34056 L p F P
0 g
s
.764 .494 .526 r
.39964 .34056 m .3996 .34055 L .39947 .34552 L p F P
0 g
s
.651 .758 .928 r
.52452 .54783 m .5359 .54427 L .5389 .54755 L p F P
0 g
s
.651 .758 .928 r
.5359 .54427 m .52452 .54783 L .5215 .54455 L p F P
0 g
s
.65 .758 .928 r
.34897 .54784 m .36004 .54428 L .36332 .54756 L p F P
0 g
s
.65 .757 .928 r
.36004 .54428 m .34897 .54784 L .34566 .54455 L p F P
0 g
s
.652 .759 .928 r
.89002 .54719 m .90204 .5436 L .90445 .54687 L p F P
0 g
s
.652 .759 .928 r
.90204 .5436 m .89002 .54719 L .88759 .54392 L p F P
0 g
s
.651 .758 .928 r
.71448 .54748 m .72619 .54392 L .72888 .5472 L p F P
0 g
s
.651 .758 .928 r
.72619 .54392 m .71448 .54748 L .71176 .5442 L p F P
0 g
s
.65 .757 .928 r
.18775 .54754 m .19853 .54398 L .20208 .54727 L p F P
0 g
s
.65 .757 .928 r
.19853 .54398 m .18775 .54754 L .18417 .54425 L p F P
0 g
s
.651 .758 .928 r
.5389 .54755 m .55031 .54399 L .55329 .54728 L p F P
0 g
s
.651 .758 .928 r
.55031 .54399 m .5389 .54755 L .5359 .54427 L p F P
0 g
s
.65 .758 .928 r
.36332 .54756 m .37442 .54401 L .37768 .54729 L p F P
0 g
s
.65 .758 .928 r
.37442 .54401 m .36332 .54756 L .36004 .54428 L p F P
0 g
s
.652 .759 .928 r
.90445 .54687 m .91649 .54327 L .91887 .54654 L p F P
0 g
s
.652 .759 .928 r
.91649 .54327 m .90445 .54687 L .90204 .5436 L p F P
0 g
s
.651 .758 .928 r
.72888 .5472 m .74062 .54363 L .74329 .54691 L p F P
0 g
s
.651 .758 .928 r
.74062 .54363 m .72888 .5472 L .72619 .54392 L p F P
0 g
s
.65 .757 .928 r
.20208 .54727 m .2129 .54371 L .21642 .547 L p F P
0 g
s
.65 .757 .928 r
.2129 .54371 m .20208 .54727 L .19853 .54398 L p F P
0 g
s
.651 .758 .928 r
.55329 .54728 m .56472 .54372 L .56767 .547 L p F P
0 g
s
.651 .758 .928 r
.56472 .54372 m .55329 .54728 L .55031 .54399 L p F P
0 g
s
.65 .758 .928 r
.37768 .54729 m .38881 .54373 L .39205 .54702 L p F P
0 g
s
.65 .758 .928 r
.38881 .54373 m .37768 .54729 L .37442 .54401 L p F P
0 g
s
.652 .759 .928 r
.91887 .54654 m .93094 .54294 L .93331 .54621 L p F P
0 g
s
.652 .759 .928 r
.93094 .54294 m .91887 .54654 L .91649 .54327 L p F P
0 g
s
.651 .758 .928 r
.74329 .54691 m .75506 .54334 L .75771 .54662 L p F P
0 g
s
.651 .758 .928 r
.75506 .54334 m .74329 .54691 L .74062 .54363 L p F P
0 g
s
.65 .757 .928 r
.21642 .547 m .22726 .54344 L .23077 .54673 L p F P
0 g
s
.65 .757 .928 r
.22726 .54344 m .21642 .547 L .2129 .54371 L p F P
0 g
s
.651 .758 .928 r
.56767 .547 m .57913 .54344 L .58206 .54672 L p F P
0 g
s
.651 .758 .928 r
.57913 .54344 m .56767 .547 L .56472 .54372 L p F P
0 g
s
.65 .758 .928 r
.39205 .54702 m .4032 .54346 L .40641 .54675 L p F P
0 g
s
.65 .758 .928 r
.4032 .54346 m .39205 .54702 L .38881 .54373 L p F P
0 g
s
.651 .758 .928 r
.75771 .54662 m .7695 .54305 L .77212 .54633 L p F P
0 g
s
.651 .758 .928 r
.7695 .54305 m .75771 .54662 L .75506 .54334 L p F P
0 g
s
.651 .758 .928 r
.58206 .54672 m .59355 .54316 L .59646 .54645 L p F P
0 g
s
.651 .758 .928 r
.59355 .54316 m .58206 .54672 L .57913 .54344 L p F P
0 g
s
.65 .757 .928 r
.23077 .54673 m .24163 .54317 L .24511 .54646 L p F P
0 g
s
.65 .757 .928 r
.24163 .54317 m .23077 .54673 L .22726 .54344 L p F P
0 g
s
.65 .758 .928 r
.40641 .54675 m .41759 .54319 L .42079 .54647 L p F P
0 g
s
.65 .758 .928 r
.41759 .54319 m .40641 .54675 L .4032 .54346 L p F P
0 g
s
.651 .758 .928 r
.77212 .54633 m .78394 .54276 L .78655 .54604 L p F P
0 g
s
.651 .758 .928 r
.78394 .54276 m .77212 .54633 L .7695 .54305 L p F P
0 g
s
.651 .758 .928 r
.59646 .54645 m .60797 .54288 L .61086 .54617 L p F P
0 g
s
.651 .758 .928 r
.60797 .54288 m .59646 .54645 L .59355 .54316 L p F P
0 g
s
.65 .757 .928 r
.24511 .54646 m .25601 .5429 L .25946 .54619 L p F P
0 g
s
.65 .757 .928 r
.25601 .5429 m .24511 .54646 L .24163 .54317 L p F P
0 g
s
.65 .758 .928 r
.42079 .54647 m .43199 .54291 L .43516 .5462 L p F P
0 g
s
.65 .758 .928 r
.43199 .54291 m .42079 .54647 L .41759 .54319 L p F P
0 g
s
.651 .758 .928 r
.78655 .54604 m .79839 .54246 L .80097 .54575 L p F P
0 g
s
.651 .758 .928 r
.79839 .54246 m .78655 .54604 L .78394 .54276 L p F P
0 g
s
.651 .758 .928 r
.61086 .54617 m .6224 .5426 L .62526 .54589 L p F P
0 g
s
.651 .758 .928 r
.6224 .5426 m .61086 .54617 L .60797 .54288 L p F P
0 g
s
.65 .757 .928 r
.25946 .54619 m .27039 .54263 L .27382 .54592 L p F P
0 g
s
.65 .757 .928 r
.27039 .54263 m .25946 .54619 L .25601 .5429 L p F P
0 g
s
.65 .758 .928 r
.43516 .5462 m .44639 .54264 L .44954 .54592 L p F P
0 g
s
.65 .758 .928 r
.44639 .54264 m .43516 .5462 L .43199 .54291 L p F P
0 g
s
.651 .758 .928 r
.80097 .54575 m .81284 .54217 L .8154 .54545 L p F P
0 g
s
.651 .758 .928 r
.81284 .54217 m .80097 .54575 L .79839 .54246 L p F P
0 g
s
.651 .758 .928 r
.62526 .54589 m .63683 .54232 L .63967 .54561 L p F P
0 g
s
.651 .758 .928 r
.63683 .54232 m .62526 .54589 L .6224 .5426 L p F P
0 g
s
.65 .757 .928 r
.27382 .54592 m .28477 .54235 L .28818 .54564 L p F P
0 g
s
.65 .757 .928 r
.28477 .54235 m .27382 .54592 L .27039 .54263 L p F P
0 g
s
.65 .758 .928 r
.44954 .54592 m .4608 .54236 L .46392 .54565 L p F P
0 g
s
.65 .758 .928 r
.4608 .54236 m .44954 .54592 L .44639 .54264 L p F P
0 g
s
.651 .758 .928 r
.8154 .54545 m .8273 .54187 L .82983 .54515 L p F P
0 g
s
.651 .758 .928 r
.8273 .54187 m .8154 .54545 L .81284 .54217 L p F P
0 g
s
.651 .758 .928 r
.63967 .54561 m .65126 .54204 L .65408 .54533 L p F P
0 g
s
.651 .758 .928 r
.65126 .54204 m .63967 .54561 L .63683 .54232 L p F P
0 g
s
.65 .757 .928 r
.28818 .54564 m .29916 .54208 L .30254 .54537 L p F P
0 g
s
.65 .757 .928 r
.29916 .54208 m .28818 .54564 L .28477 .54235 L p F P
0 g
s
.651 .758 .928 r
.46392 .54565 m .47521 .54208 L .47831 .54537 L p F P
0 g
s
.651 .758 .928 r
.47521 .54208 m .46392 .54565 L .4608 .54236 L p F P
0 g
s
.651 .758 .928 r
.84176 .54156 m .82983 .54515 L .8273 .54187 L p F P
0 g
s
.651 .758 .928 r
.82983 .54515 m .84176 .54156 L .84427 .54485 L p F P
0 g
s
.651 .758 .928 r
.65408 .54533 m .6657 .54176 L .66849 .54505 L p F P
0 g
s
.651 .758 .928 r
.6657 .54176 m .65408 .54533 L .65126 .54204 L p F P
0 g
s
.65 .757 .928 r
.30254 .54537 m .31355 .54181 L .31691 .5451 L p F P
0 g
s
.65 .757 .928 r
.31355 .54181 m .30254 .54537 L .29916 .54208 L p F P
0 g
s
.651 .758 .928 r
.47831 .54537 m .48962 .54181 L .4927 .5451 L p F P
0 g
s
.651 .758 .928 r
.48962 .54181 m .47831 .54537 L .47521 .54208 L p F P
0 g
s
.651 .758 .928 r
.84427 .54485 m .85622 .54126 L .8587 .54454 L p F P
0 g
s
.651 .758 .928 r
.85622 .54126 m .84427 .54485 L .84176 .54156 L p F P
0 g
s
.651 .758 .928 r
.66849 .54505 m .68014 .54148 L .68291 .54477 L p F P
0 g
s
.651 .758 .928 r
.68014 .54148 m .66849 .54505 L .6657 .54176 L p F P
0 g
s
0 0 .274 r
.39939 .35048 m .39938 .35051 L .39951 .34552 L p F P
0 g
s
0 0 .274 r
.39951 .34552 m .39952 .3455 L .39939 .35048 L p F P
0 g
s
.763 .494 .526 r
.39934 .3505 m .39938 .35051 L .39951 .34552 L p F P
0 g
s
.763 .494 .526 r
.39951 .34552 m .39947 .34552 L .39934 .3505 L p F P
0 g
s
.651 .758 .928 r
.4927 .5451 m .50404 .54153 L .5071 .54482 L p F P
0 g
s
.651 .758 .928 r
.50404 .54153 m .4927 .5451 L .48962 .54181 L p F P
0 g
s
.65 .757 .928 r
.31691 .5451 m .32794 .54153 L .33128 .54483 L p F P
0 g
s
.65 .757 .928 r
.32794 .54153 m .31691 .5451 L .31355 .54181 L p F P
0 g
s
.651 .759 .928 r
.87068 .54095 m .8587 .54454 L .85622 .54126 L p F P
0 g
s
.651 .759 .928 r
.8587 .54454 m .87068 .54095 L .87315 .54423 L p F P
0 g
s
.651 .758 .928 r
.68291 .54477 m .69458 .54119 L .69733 .54449 L p F P
0 g
s
.651 .758 .928 r
.69458 .54119 m .68291 .54477 L .68014 .54148 L p F P
0 g
s
.651 .758 .928 r
.51846 .54125 m .5071 .54482 L .50404 .54153 L p F P
0 g
s
.651 .758 .928 r
.5071 .54482 m .51846 .54125 L .5215 .54455 L p F P
0 g
s
.65 .757 .928 r
.33128 .54483 m .34234 .54126 L .34566 .54455 L p F P
0 g
s
.65 .757 .928 r
.34234 .54126 m .33128 .54483 L .32794 .54153 L p F P
0 g
s
.651 .759 .928 r
.87315 .54423 m .88515 .54063 L .88759 .54392 L p F P
0 g
s
.651 .759 .928 r
.88515 .54063 m .87315 .54423 L .87068 .54095 L p F P
0 g
s
.651 .758 .928 r
.69733 .54449 m .70903 .54091 L .71176 .5442 L p F P
0 g
s
.651 .758 .928 r
.70903 .54091 m .69733 .54449 L .69458 .54119 L p F P
0 g
s
.651 .758 .928 r
.5215 .54455 m .53289 .54098 L .5359 .54427 L p F P
0 g
s
.651 .758 .928 r
.53289 .54098 m .5215 .54455 L .51846 .54125 L p F P
0 g
s
.65 .757 .928 r
.34566 .54455 m .35674 .54099 L .36004 .54428 L p F P
0 g
s
.65 .757 .928 r
.35674 .54099 m .34566 .54455 L .34234 .54126 L p F P
0 g
s
.652 .759 .928 r
.88759 .54392 m .89962 .54032 L .90204 .5436 L p F P
0 g
s
.652 .759 .928 r
.89962 .54032 m .88759 .54392 L .88515 .54063 L p F P
0 g
s
.651 .758 .928 r
.71176 .5442 m .72348 .54062 L .72619 .54392 L p F P
0 g
s
.651 .758 .928 r
.72348 .54062 m .71176 .5442 L .70903 .54091 L p F P
0 g
s
.65 .757 .928 r
.18417 .54425 m .19497 .54069 L .19853 .54398 L p F P
0 g
s
.651 .758 .928 r
.5359 .54427 m .54732 .5407 L .55031 .54399 L p F P
0 g
s
.651 .758 .928 r
.54732 .5407 m .5359 .54427 L .53289 .54098 L p F P
0 g
s
.65 .758 .928 r
.36004 .54428 m .37114 .54071 L .37442 .54401 L p F P
0 g
s
.65 .758 .928 r
.37114 .54071 m .36004 .54428 L .35674 .54099 L p F P
0 g
s
.652 .759 .928 r
.90204 .5436 m .9141 .53999 L .91649 .54327 L p F P
0 g
s
.652 .759 .928 r
.9141 .53999 m .90204 .5436 L .89962 .54032 L p F P
0 g
s
.651 .758 .928 r
.72619 .54392 m .73794 .54034 L .74062 .54363 L p F P
0 g
s
.651 .758 .928 r
.73794 .54034 m .72619 .54392 L .72348 .54062 L p F P
0 g
s
.65 .757 .928 r
.19853 .54398 m .20936 .54042 L .2129 .54371 L p F P
0 g
s
.65 .757 .928 r
.20936 .54042 m .19853 .54398 L .19497 .54069 L p F P
0 g
s
.651 .758 .928 r
.55031 .54399 m .56175 .54042 L .56472 .54372 L p F P
0 g
s
.651 .758 .928 r
.56175 .54042 m .55031 .54399 L .54732 .5407 L p F P
0 g
s
.65 .758 .928 r
.37442 .54401 m .38555 .54044 L .38881 .54373 L p F P
0 g
s
.65 .758 .928 r
.38555 .54044 m .37442 .54401 L .37114 .54071 L p F P
0 g
s
.652 .759 .928 r
.91649 .54327 m .92857 .53966 L .93094 .54294 L p F P
0 g
s
.652 .759 .928 r
.92857 .53966 m .91649 .54327 L .9141 .53999 L p F P
0 g
s
.651 .758 .928 r
.74062 .54363 m .7524 .54005 L .75506 .54334 L p F P
0 g
s
.651 .758 .928 r
.7524 .54005 m .74062 .54363 L .73794 .54034 L p F P
0 g
s
.65 .757 .928 r
.2129 .54371 m .22375 .54014 L .22726 .54344 L p F P
0 g
s
.65 .757 .928 r
.22375 .54014 m .2129 .54371 L .20936 .54042 L p F P
0 g
s
.651 .758 .928 r
.56472 .54372 m .57619 .54014 L .57913 .54344 L p F P
0 g
s
.651 .758 .928 r
.57619 .54014 m .56472 .54372 L .56175 .54042 L p F P
0 g
s
.65 .758 .928 r
.38881 .54373 m .39997 .54016 L .4032 .54346 L p F P
0 g
s
.65 .758 .928 r
.39997 .54016 m .38881 .54373 L .38555 .54044 L p F P
0 g
s
.651 .758 .928 r
.75506 .54334 m .76686 .53976 L .7695 .54305 L p F P
0 g
s
.651 .758 .928 r
.76686 .53976 m .75506 .54334 L .7524 .54005 L p F P
0 g
s
.651 .758 .928 r
.57913 .54344 m .59063 .53986 L .59355 .54316 L p F P
0 g
s
.651 .758 .928 r
.59063 .53986 m .57913 .54344 L .57619 .54014 L p F P
0 g
s
.65 .757 .928 r
.22726 .54344 m .23814 .53987 L .24163 .54317 L p F P
0 g
s
.65 .757 .928 r
.23814 .53987 m .22726 .54344 L .22375 .54014 L p F P
0 g
s
.65 .758 .928 r
.4032 .54346 m .41439 .53989 L .41759 .54319 L p F P
0 g
s
.65 .758 .928 r
.41439 .53989 m .4032 .54346 L .39997 .54016 L p F P
0 g
s
.651 .758 .928 r
.7695 .54305 m .78133 .53947 L .78394 .54276 L p F P
0 g
s
.651 .758 .928 r
.78133 .53947 m .7695 .54305 L .76686 .53976 L p F P
0 g
s
.651 .758 .928 r
.59355 .54316 m .60507 .53959 L .60797 .54288 L p F P
0 g
s
.651 .758 .928 r
.60507 .53959 m .59355 .54316 L .59063 .53986 L p F P
0 g
s
.65 .757 .928 r
.24163 .54317 m .25254 .5396 L .25601 .5429 L p F P
0 g
s
.65 .757 .928 r
.25254 .5396 m .24163 .54317 L .23814 .53987 L p F P
0 g
s
.65 .758 .928 r
.41759 .54319 m .42881 .53961 L .43199 .54291 L p F P
0 g
s
.65 .758 .928 r
.42881 .53961 m .41759 .54319 L .41439 .53989 L p F P
0 g
s
.651 .758 .928 r
.78394 .54276 m .7958 .53917 L .79839 .54246 L p F P
0 g
s
.651 .758 .928 r
.7958 .53917 m .78394 .54276 L .78133 .53947 L p F P
0 g
s
.651 .758 .928 r
.60797 .54288 m .61952 .53931 L .6224 .5426 L p F P
0 g
s
.651 .758 .928 r
.61952 .53931 m .60797 .54288 L .60507 .53959 L p F P
0 g
s
.65 .757 .928 r
.25601 .5429 m .26694 .53933 L .27039 .54263 L p F P
0 g
s
.65 .757 .928 r
.26694 .53933 m .25601 .5429 L .25254 .5396 L p F P
0 g
s
.65 .758 .928 r
.43199 .54291 m .44323 .53934 L .44639 .54264 L p F P
0 g
s
.65 .758 .928 r
.44323 .53934 m .43199 .54291 L .42881 .53961 L p F P
0 g
s
.651 .758 .928 r
.79839 .54246 m .81028 .53887 L .81284 .54217 L p F P
0 g
s
.651 .758 .928 r
.81028 .53887 m .79839 .54246 L .7958 .53917 L p F P
0 g
s
.651 .758 .928 r
.6224 .5426 m .63398 .53902 L .63683 .54232 L p F P
0 g
s
.651 .758 .928 r
.63398 .53902 m .6224 .5426 L .61952 .53931 L p F P
0 g
s
.65 .757 .928 r
.27039 .54263 m .28135 .53905 L .28477 .54235 L p F P
0 g
s
.65 .757 .928 r
.28135 .53905 m .27039 .54263 L .26694 .53933 L p F P
0 g
s
.65 .758 .928 r
.44639 .54264 m .45766 .53906 L .4608 .54236 L p F P
0 g
s
.65 .758 .928 r
.45766 .53906 m .44639 .54264 L .44323 .53934 L p F P
0 g
s
.651 .758 .928 r
.81284 .54217 m .82476 .53857 L .8273 .54187 L p F P
0 g
s
.651 .758 .928 r
.82476 .53857 m .81284 .54217 L .81028 .53887 L p F P
0 g
s
.651 .758 .928 r
.63683 .54232 m .64843 .53874 L .65126 .54204 L p F P
0 g
s
.651 .758 .928 r
.64843 .53874 m .63683 .54232 L .63398 .53902 L p F P
0 g
s
0 0 .274 r
.39926 .35548 m .39925 .3555 L .39938 .35051 L p F P
0 g
s
0 0 .274 r
.39938 .35051 m .39939 .35048 L .39926 .35548 L p F P
0 g
s
.763 .494 .526 r
.39921 .3555 m .39925 .3555 L .39938 .35051 L p F P
0 g
s
.763 .494 .526 r
.39938 .35051 m .39934 .3505 L .39921 .3555 L p F P
0 g
s
.65 .757 .928 r
.28477 .54235 m .29576 .53878 L .29916 .54208 L p F P
0 g
s
.65 .757 .928 r
.29576 .53878 m .28477 .54235 L .28135 .53905 L p F P
0 g
s
.651 .758 .928 r
.4608 .54236 m .47209 .53878 L .47521 .54208 L p F P
0 g
s
.651 .758 .928 r
.47209 .53878 m .4608 .54236 L .45766 .53906 L p F P
0 g
s
.651 .758 .928 r
.8273 .54187 m .83924 .53827 L .84176 .54156 L p F P
0 g
s
.651 .758 .928 r
.83924 .53827 m .8273 .54187 L .82476 .53857 L p F P
0 g
s
.651 .758 .928 r
.65126 .54204 m .66289 .53846 L .6657 .54176 L p F P
0 g
s
.651 .758 .928 r
.66289 .53846 m .65126 .54204 L .64843 .53874 L p F P
0 g
s
.65 .757 .928 r
.29916 .54208 m .31017 .53851 L .31355 .54181 L p F P
0 g
s
.65 .757 .928 r
.31017 .53851 m .29916 .54208 L .29576 .53878 L p F P
0 g
s
.651 .758 .928 r
.47521 .54208 m .48653 .53851 L .48962 .54181 L p F P
0 g
s
.651 .758 .928 r
.48653 .53851 m .47521 .54208 L .47209 .53878 L p F P
0 g
s
.651 .758 .928 r
.85372 .53797 m .84176 .54156 L .83924 .53827 L p F P
0 g
s
.651 .758 .928 r
.84176 .54156 m .85372 .53797 L .85622 .54126 L p F P
0 g
s
.651 .758 .928 r
.6657 .54176 m .67736 .53818 L .68014 .54148 L p F P
0 g
s
.651 .758 .928 r
.67736 .53818 m .6657 .54176 L .66289 .53846 L p F P
0 g
s
.651 .758 .928 r
.48962 .54181 m .50097 .53823 L .50404 .54153 L p F P
0 g
s
.651 .758 .928 r
.50097 .53823 m .48962 .54181 L .48653 .53851 L p F P
0 g
s
.65 .757 .928 r
.31355 .54181 m .32459 .53823 L .32794 .54153 L p F P
0 g
s
.65 .757 .928 r
.32459 .53823 m .31355 .54181 L .31017 .53851 L p F P
0 g
s
.651 .759 .928 r
.85622 .54126 m .86821 .53766 L .87068 .54095 L p F P
0 g
s
.651 .759 .928 r
.86821 .53766 m .85622 .54126 L .85372 .53797 L p F P
0 g
s
.651 .758 .928 r
.68014 .54148 m .69183 .53789 L .69458 .54119 L p F P
0 g
s
.651 .758 .928 r
.69183 .53789 m .68014 .54148 L .67736 .53818 L p F P
0 g
s
.651 .758 .928 r
.50404 .54153 m .51542 .53795 L .51846 .54125 L p F P
0 g
s
.651 .758 .928 r
.51542 .53795 m .50404 .54153 L .50097 .53823 L p F P
0 g
s
.65 .757 .928 r
.32794 .54153 m .33901 .53796 L .34234 .54126 L p F P
0 g
s
.65 .757 .928 r
.33901 .53796 m .32794 .54153 L .32459 .53823 L p F P
0 g
s
.651 .759 .928 r
.8827 .53734 m .87068 .54095 L .86821 .53766 L p F P
0 g
s
.651 .759 .928 r
.87068 .54095 m .8827 .53734 L .88515 .54063 L p F P
0 g
s
.651 .758 .928 r
.69458 .54119 m .7063 .53761 L .70903 .54091 L p F P
0 g
s
.651 .758 .928 r
.7063 .53761 m .69458 .54119 L .69183 .53789 L p F P
0 g
s
.651 .758 .928 r
.51846 .54125 m .52987 .53767 L .53289 .54098 L p F P
0 g
s
.651 .758 .928 r
.52987 .53767 m .51846 .54125 L .51542 .53795 L p F P
0 g
s
.65 .757 .928 r
.34234 .54126 m .35343 .53768 L .35674 .54099 L p F P
0 g
s
.65 .757 .928 r
.35343 .53768 m .34234 .54126 L .33901 .53796 L p F P
0 g
s
.652 .759 .928 r
.88515 .54063 m .8972 .53702 L .89962 .54032 L p F P
0 g
s
.652 .759 .928 r
.8972 .53702 m .88515 .54063 L .8827 .53734 L p F P
0 g
s
.651 .758 .928 r
.70903 .54091 m .72077 .53732 L .72348 .54062 L p F P
0 g
s
.651 .758 .928 r
.72077 .53732 m .70903 .54091 L .7063 .53761 L p F P
0 g
s
.651 .758 .928 r
.53289 .54098 m .54432 .5374 L .54732 .5407 L p F P
0 g
s
.651 .758 .928 r
.54432 .5374 m .53289 .54098 L .52987 .53767 L p F P
0 g
s
.65 .758 .928 r
.35674 .54099 m .36786 .53741 L .37114 .54071 L p F P
0 g
s
.65 .757 .928 r
.36786 .53741 m .35674 .54099 L .35343 .53768 L p F P
0 g
s
.652 .759 .928 r
.89962 .54032 m .91169 .5367 L .9141 .53999 L p F P
0 g
s
.652 .759 .928 r
.91169 .5367 m .89962 .54032 L .8972 .53702 L p F P
0 g
s
.651 .758 .928 r
.72348 .54062 m .73525 .53703 L .73794 .54034 L p F P
0 g
s
.651 .758 .928 r
.73525 .53703 m .72348 .54062 L .72077 .53732 L p F P
0 g
s
.65 .757 .928 r
.19497 .54069 m .20581 .53711 L .20936 .54042 L p F P
0 g
s
.651 .758 .928 r
.54732 .5407 m .55878 .53712 L .56175 .54042 L p F P
0 g
s
.651 .758 .928 r
.55878 .53712 m .54732 .5407 L .54432 .5374 L p F P
0 g
s
.65 .758 .928 r
.37114 .54071 m .38229 .53713 L .38555 .54044 L p F P
0 g
s
.65 .758 .928 r
.38229 .53713 m .37114 .54071 L .36786 .53741 L p F P
0 g
s
.652 .759 .928 r
.9141 .53999 m .9262 .53637 L .92857 .53966 L p F P
0 g
s
.652 .759 .928 r
.9262 .53637 m .9141 .53999 L .91169 .5367 L p F P
0 g
s
.651 .758 .928 r
.73794 .54034 m .74974 .53674 L .7524 .54005 L p F P
0 g
s
.651 .758 .928 r
.74974 .53674 m .73794 .54034 L .73525 .53703 L p F P
0 g
s
.65 .757 .928 r
.20936 .54042 m .22022 .53684 L .22375 .54014 L p F P
0 g
s
.65 .757 .928 r
.22022 .53684 m .20936 .54042 L .20581 .53711 L p F P
0 g
s
.651 .758 .928 r
.56175 .54042 m .57324 .53684 L .57619 .54014 L p F P
0 g
s
.651 .758 .928 r
.57324 .53684 m .56175 .54042 L .55878 .53712 L p F P
0 g
s
.65 .758 .928 r
.38555 .54044 m .39673 .53686 L .39997 .54016 L p F P
0 g
s
.65 .758 .928 r
.39673 .53686 m .38555 .54044 L .38229 .53713 L p F P
0 g
s
.651 .758 .928 r
.7524 .54005 m .76422 .53645 L .76686 .53976 L p F P
0 g
s
.651 .758 .928 r
.76422 .53645 m .7524 .54005 L .74974 .53674 L p F P
0 g
s
.651 .758 .928 r
.57619 .54014 m .5877 .53656 L .59063 .53986 L p F P
0 g
s
.651 .758 .928 r
.5877 .53656 m .57619 .54014 L .57324 .53684 L p F P
0 g
s
.65 .757 .928 r
.22375 .54014 m .23464 .53656 L .23814 .53987 L p F P
0 g
s
.65 .757 .928 r
.23464 .53656 m .22375 .54014 L .22022 .53684 L p F P
0 g
s
.65 .758 .928 r
.39997 .54016 m .41117 .53658 L .41439 .53989 L p F P
0 g
s
.65 .758 .928 r
.41117 .53658 m .39997 .54016 L .39673 .53686 L p F P
0 g
s
.651 .758 .928 r
.76686 .53976 m .77871 .53616 L .78133 .53947 L p F P
0 g
s
.651 .758 .928 r
.77871 .53616 m .76686 .53976 L .76422 .53645 L p F P
0 g
s
.651 .758 .928 r
.59063 .53986 m .60217 .53628 L .60507 .53959 L p F P
0 g
s
.651 .758 .928 r
.60217 .53628 m .59063 .53986 L .5877 .53656 L p F P
0 g
s
.65 .757 .928 r
.23814 .53987 m .24906 .53629 L .25254 .5396 L p F P
0 g
s
.65 .757 .928 r
.24906 .53629 m .23814 .53987 L .23464 .53656 L p F P
0 g
s
.65 .758 .928 r
.41439 .53989 m .42561 .5363 L .42881 .53961 L p F P
0 g
s
.65 .758 .928 r
.42561 .5363 m .41439 .53989 L .41117 .53658 L p F P
0 g
s
.651 .758 .928 r
.78133 .53947 m .79321 .53587 L .7958 .53917 L p F P
0 g
s
.651 .758 .928 r
.79321 .53587 m .78133 .53947 L .77871 .53616 L p F P
0 g
s
.651 .758 .928 r
.60507 .53959 m .61664 .536 L .61952 .53931 L p F P
0 g
s
.651 .758 .928 r
.61664 .536 m .60507 .53959 L .60217 .53628 L p F P
0 g
s
.65 .757 .928 r
.25254 .5396 m .26349 .53602 L .26694 .53933 L p F P
0 g
s
.65 .757 .928 r
.26349 .53602 m .25254 .5396 L .24906 .53629 L p F P
0 g
s
0 0 .274 r
.39912 .36049 m .39911 .36051 L .39925 .3555 L p F P
0 g
s
0 0 .274 r
.39925 .3555 m .39926 .35548 L .39912 .36049 L p F P
0 g
s
.763 .494 .526 r
.39908 .36051 m .39911 .36051 L .39925 .3555 L p F P
0 g
s
.763 .494 .526 r
.39925 .3555 m .39921 .3555 L .39908 .36051 L p F P
0 g
s
.65 .758 .928 r
.42881 .53961 m .44006 .53603 L .44323 .53934 L p F P
0 g
s
.65 .758 .928 r
.44006 .53603 m .42881 .53961 L .42561 .5363 L p F P
0 g
s
.651 .758 .928 r
.7958 .53917 m .8077 .53557 L .81028 .53887 L p F P
0 g
s
.651 .758 .928 r
.8077 .53557 m .7958 .53917 L .79321 .53587 L p F P
0 g
s
.651 .758 .928 r
.61952 .53931 m .63112 .53572 L .63398 .53902 L p F P
0 g
s
.651 .758 .928 r
.63112 .53572 m .61952 .53931 L .61664 .536 L p F P
0 g
s
.65 .757 .928 r
.26694 .53933 m .27791 .53574 L .28135 .53905 L p F P
0 g
s
.65 .757 .928 r
.27791 .53574 m .26694 .53933 L .26349 .53602 L p F P
0 g
s
.65 .758 .928 r
.44323 .53934 m .45452 .53575 L .45766 .53906 L p F P
0 g
s
.65 .758 .928 r
.45452 .53575 m .44323 .53934 L .44006 .53603 L p F P
0 g
s
.651 .758 .928 r
.81028 .53887 m .82221 .53527 L .82476 .53857 L p F P
0 g
s
.651 .758 .928 r
.82221 .53527 m .81028 .53887 L .8077 .53557 L p F P
0 g
s
.651 .758 .928 r
.63398 .53902 m .6456 .53543 L .64843 .53874 L p F P
0 g
s
.651 .758 .928 r
.6456 .53543 m .63398 .53902 L .63112 .53572 L p F P
0 g
s
.65 .757 .928 r
.28135 .53905 m .29235 .53547 L .29576 .53878 L p F P
0 g
s
.65 .757 .928 r
.29235 .53547 m .28135 .53905 L .27791 .53574 L p F P
0 g
s
.651 .758 .928 r
.45766 .53906 m .46897 .53547 L .47209 .53878 L p F P
0 g
s
.651 .758 .928 r
.46897 .53547 m .45766 .53906 L .45452 .53575 L p F P
0 g
s
.651 .758 .928 r
.82476 .53857 m .83671 .53497 L .83924 .53827 L p F P
0 g
s
.651 .758 .928 r
.83671 .53497 m .82476 .53857 L .82221 .53527 L p F P
0 g
s
.651 .758 .928 r
.64843 .53874 m .66008 .53515 L .66289 .53846 L p F P
0 g
s
.651 .758 .928 r
.66008 .53515 m .64843 .53874 L .6456 .53543 L p F P
0 g
s
.65 .757 .928 r
.29576 .53878 m .30678 .53519 L .31017 .53851 L p F P
0 g
s
.65 .757 .928 r
.30678 .53519 m .29576 .53878 L .29235 .53547 L p F P
0 g
s
.651 .758 .928 r
.47209 .53878 m .48343 .53519 L .48653 .53851 L p F P
0 g
s
.651 .758 .928 r
.48343 .53519 m .47209 .53878 L .46897 .53547 L p F P
0 g
s
.651 .758 .928 r
.83924 .53827 m .85122 .53466 L .85372 .53797 L p F P
0 g
s
.651 .758 .928 r
.85122 .53466 m .83924 .53827 L .83671 .53497 L p F P
0 g
s
.651 .758 .928 r
.66289 .53846 m .67457 .53487 L .67736 .53818 L p F P
0 g
s
.651 .758 .928 r
.67457 .53487 m .66289 .53846 L .66008 .53515 L p F P
0 g
s
.65 .757 .928 r
.31017 .53851 m .32122 .53492 L .32459 .53823 L p F P
0 g
s
.65 .757 .928 r
.32122 .53492 m .31017 .53851 L .30678 .53519 L p F P
0 g
s
.651 .758 .928 r
.48653 .53851 m .4979 .53492 L .50097 .53823 L p F P
0 g
s
.651 .758 .928 r
.4979 .53492 m .48653 .53851 L .48343 .53519 L p F P
0 g
s
.651 .758 .928 r
.86573 .53435 m .85372 .53797 L .85122 .53466 L p F P
0 g
s
.651 .759 .928 r
.85372 .53797 m .86573 .53435 L .86821 .53766 L p F P
0 g
s
.651 .758 .928 r
.67736 .53818 m .68906 .53458 L .69183 .53789 L p F P
0 g
s
.651 .758 .928 r
.68906 .53458 m .67736 .53818 L .67457 .53487 L p F P
0 g
s
.651 .758 .928 r
.50097 .53823 m .51236 .53464 L .51542 .53795 L p F P
0 g
s
.651 .758 .928 r
.51236 .53464 m .50097 .53823 L .4979 .53492 L p F P
0 g
s
.65 .757 .928 r
.32459 .53823 m .33567 .53464 L .33901 .53796 L p F P
0 g
s
.65 .757 .928 r
.33567 .53464 m .32459 .53823 L .32122 .53492 L p F P
0 g
s
.651 .759 .928 r
.86821 .53766 m .88025 .53404 L .8827 .53734 L p F P
0 g
s
.651 .759 .928 r
.88025 .53404 m .86821 .53766 L .86573 .53435 L p F P
0 g
s
.651 .758 .928 r
.69183 .53789 m .70355 .5343 L .7063 .53761 L p F P
0 g
s
.651 .758 .928 r
.70355 .5343 m .69183 .53789 L .68906 .53458 L p F P
0 g
s
.651 .758 .928 r
.51542 .53795 m .52683 .53436 L .52987 .53767 L p F P
0 g
s
.651 .758 .928 r
.52683 .53436 m .51542 .53795 L .51236 .53464 L p F P
0 g
s
.65 .757 .928 r
.33901 .53796 m .35011 .53437 L .35343 .53768 L p F P
0 g
s
.65 .757 .928 r
.35011 .53437 m .33901 .53796 L .33567 .53464 L p F P
0 g
s
.651 .759 .928 r
.89476 .53372 m .8827 .53734 L .88025 .53404 L p F P
0 g
s
.652 .759 .928 r
.8827 .53734 m .89476 .53372 L .8972 .53702 L p F P
0 g
s
.651 .758 .928 r
.7063 .53761 m .71805 .53401 L .72077 .53732 L p F P
0 g
s
.651 .758 .928 r
.71805 .53401 m .7063 .53761 L .70355 .5343 L p F P
0 g
s
.651 .758 .928 r
.54131 .53408 m .52987 .53767 L .52683 .53436 L p F P
0 g
s
.651 .758 .928 r
.52987 .53767 m .54131 .53408 L .54432 .5374 L p F P
0 g
s
.65 .757 .928 r
.35343 .53768 m .36456 .53409 L .36786 .53741 L p F P
0 g
s
.65 .757 .928 r
.36456 .53409 m .35343 .53768 L .35011 .53437 L p F P
0 g
s
.652 .759 .928 r
.8972 .53702 m .90929 .53339 L .91169 .5367 L p F P
0 g
s
.652 .759 .928 r
.90929 .53339 m .8972 .53702 L .89476 .53372 L p F P
0 g
s
.651 .758 .928 r
.72077 .53732 m .73255 .53372 L .73525 .53703 L p F P
0 g
s
.651 .758 .928 r
.73255 .53372 m .72077 .53732 L .71805 .53401 L p F P
0 g
s
.651 .758 .928 r
.54432 .5374 m .55579 .5338 L .55878 .53712 L p F P
0 g
s
.651 .758 .928 r
.55579 .5338 m .54432 .5374 L .54131 .53408 L p F P
0 g
s
.65 .758 .928 r
.36786 .53741 m .37902 .53381 L .38229 .53713 L p F P
0 g
s
.65 .758 .928 r
.37902 .53381 m .36786 .53741 L .36456 .53409 L p F P
0 g
s
.652 .759 .928 r
.91169 .5367 m .92381 .53307 L .9262 .53637 L p F P
0 g
s
.652 .759 .928 r
.92381 .53307 m .91169 .5367 L .90929 .53339 L p F P
0 g
s
.651 .758 .928 r
.73525 .53703 m .74706 .53343 L .74974 .53674 L p F P
0 g
s
.651 .758 .928 r
.74706 .53343 m .73525 .53703 L .73255 .53372 L p F P
0 g
s
.65 .757 .928 r
.20581 .53711 m .21669 .53352 L .22022 .53684 L p F P
0 g
s
.651 .758 .928 r
.55878 .53712 m .57027 .53352 L .57324 .53684 L p F P
0 g
s
.651 .758 .928 r
.57027 .53352 m .55878 .53712 L .55579 .5338 L p F P
0 g
s
.65 .758 .928 r
.38229 .53713 m .39348 .53354 L .39673 .53686 L p F P
0 g
s
.65 .758 .928 r
.39348 .53354 m .38229 .53713 L .37902 .53381 L p F P
0 g
s
.651 .758 .928 r
.74974 .53674 m .76157 .53314 L .76422 .53645 L p F P
0 g
s
.651 .758 .928 r
.76157 .53314 m .74974 .53674 L .74706 .53343 L p F P
0 g
s
.65 .757 .928 r
.22022 .53684 m .23113 .53324 L .23464 .53656 L p F P
0 g
s
.65 .757 .928 r
.23113 .53324 m .22022 .53684 L .21669 .53352 L p F P
0 g
s
.651 .758 .928 r
.57324 .53684 m .58476 .53324 L .5877 .53656 L p F P
0 g
s
.651 .758 .928 r
.58476 .53324 m .57324 .53684 L .57027 .53352 L p F P
0 g
s
0 0 .274 r
.39899 .36551 m .39898 .36554 L .39911 .36051 L p F P
0 g
s
0 0 .274 r
.39911 .36051 m .39912 .36049 L .39899 .36551 L p F P
0 g
s
.763 .494 .526 r
.39894 .36553 m .39898 .36554 L .39911 .36051 L p F P
0 g
s
.763 .494 .526 r
.39911 .36051 m .39908 .36051 L .39894 .36553 L p F P
0 g
s
.65 .758 .928 r
.39673 .53686 m .40794 .53326 L .41117 .53658 L p F P
0 g
s
.65 .758 .928 r
.40794 .53326 m .39673 .53686 L .39348 .53354 L p F P
0 g
s
.651 .758 .928 r
.76422 .53645 m .77609 .53285 L .77871 .53616 L p F P
0 g
s
.651 .758 .928 r
.77609 .53285 m .76422 .53645 L .76157 .53314 L p F P
0 g
s
.651 .758 .928 r
.5877 .53656 m .59925 .53296 L .60217 .53628 L p F P
0 g
s
.651 .758 .928 r
.59925 .53296 m .5877 .53656 L .58476 .53324 L p F P
0 g
s
.65 .757 .928 r
.23464 .53656 m .24557 .53297 L .24906 .53629 L p F P
0 g
s
.65 .757 .928 r
.24557 .53297 m .23464 .53656 L .23113 .53324 L p F P
0 g
s
.65 .758 .928 r
.41117 .53658 m .42241 .53298 L .42561 .5363 L p F P
0 g
s
.65 .758 .928 r
.42241 .53298 m .41117 .53658 L .40794 .53326 L p F P
0 g
s
.651 .758 .928 r
.77871 .53616 m .7906 .53255 L .79321 .53587 L p F P
0 g
s
.651 .758 .928 r
.7906 .53255 m .77871 .53616 L .77609 .53285 L p F P
0 g
s
.651 .758 .928 r
.60217 .53628 m .61375 .53268 L .61664 .536 L p F P
0 g
s
.651 .758 .928 r
.61375 .53268 m .60217 .53628 L .59925 .53296 L p F P
0 g
s
.65 .757 .928 r
.24906 .53629 m .26002 .5327 L .26349 .53602 L p F P
0 g
s
.65 .757 .928 r
.26002 .5327 m .24906 .53629 L .24557 .53297 L p F P
0 g
s
.65 .758 .928 r
.42561 .5363 m .43688 .53271 L .44006 .53603 L p F P
0 g
s
.65 .758 .928 r
.43688 .53271 m .42561 .5363 L .42241 .53298 L p F P
0 g
s
.651 .758 .928 r
.79321 .53587 m .80512 .53225 L .8077 .53557 L p F P
0 g
s
.651 .758 .928 r
.80512 .53225 m .79321 .53587 L .7906 .53255 L p F P
0 g
s
.651 .758 .928 r
.61664 .536 m .62825 .53239 L .63112 .53572 L p F P
0 g
s
.651 .758 .928 r
.62825 .53239 m .61664 .536 L .61375 .53268 L p F P
0 g
s
.65 .757 .928 r
.26349 .53602 m .27447 .53242 L .27791 .53574 L p F P
0 g
s
.65 .757 .928 r
.27447 .53242 m .26349 .53602 L .26002 .5327 L p F P
0 g
s
.65 .758 .928 r
.44006 .53603 m .45136 .53243 L .45452 .53575 L p F P
0 g
s
.65 .758 .928 r
.45136 .53243 m .44006 .53603 L .43688 .53271 L p F P
0 g
s
.651 .758 .928 r
.8077 .53557 m .81965 .53195 L .82221 .53527 L p F P
0 g
s
.651 .758 .928 r
.81965 .53195 m .8077 .53557 L .80512 .53225 L p F P
0 g
s
.651 .758 .928 r
.63112 .53572 m .64275 .53211 L .6456 .53543 L p F P
0 g
s
.651 .758 .928 r
.64275 .53211 m .63112 .53572 L .62825 .53239 L p F P
0 g
s
.65 .757 .928 r
.27791 .53574 m .28892 .53214 L .29235 .53547 L p F P
0 g
s
.65 .757 .928 r
.28892 .53214 m .27791 .53574 L .27447 .53242 L p F P
0 g
s
.651 .758 .928 r
.45452 .53575 m .46584 .53215 L .46897 .53547 L p F P
0 g
s
.651 .758 .928 r
.46584 .53215 m .45452 .53575 L .45136 .53243 L p F P
0 g
s
.651 .758 .928 r
.82221 .53527 m .83418 .53165 L .83671 .53497 L p F P
0 g
s
.651 .758 .928 r
.83418 .53165 m .82221 .53527 L .81965 .53195 L p F P
0 g
s
.651 .758 .928 r
.6456 .53543 m .65726 .53183 L .66008 .53515 L p F P
0 g
s
.651 .758 .928 r
.65726 .53183 m .6456 .53543 L .64275 .53211 L p F P
0 g
s
.65 .757 .928 r
.29235 .53547 m .30338 .53187 L .30678 .53519 L p F P
0 g
s
.65 .757 .928 r
.30338 .53187 m .29235 .53547 L .28892 .53214 L p F P
0 g
s
.651 .758 .928 r
.46897 .53547 m .48032 .53187 L .48343 .53519 L p F P
0 g
s
.651 .758 .928 r
.48032 .53187 m .46897 .53547 L .46584 .53215 L p F P
0 g
s
.651 .758 .928 r
.83671 .53497 m .84871 .53134 L .85122 .53466 L p F P
0 g
s
.651 .758 .928 r
.84871 .53134 m .83671 .53497 L .83418 .53165 L p F P
0 g
s
.651 .758 .928 r
.66008 .53515 m .67177 .53154 L .67457 .53487 L p F P
0 g
s
.651 .758 .928 r
.67177 .53154 m .66008 .53515 L .65726 .53183 L p F P
0 g
s
.65 .757 .928 r
.30678 .53519 m .31785 .53159 L .32122 .53492 L p F P
0 g
s
.65 .757 .928 r
.31785 .53159 m .30678 .53519 L .30338 .53187 L p F P
0 g
s
.651 .758 .928 r
.48343 .53519 m .49481 .53159 L .4979 .53492 L p F P
0 g
s
.651 .758 .928 r
.49481 .53159 m .48343 .53519 L .48032 .53187 L p F P
0 g
s
.651 .758 .928 r
.85122 .53466 m .86324 .53103 L .86573 .53435 L p F P
0 g
s
.651 .758 .928 r
.86324 .53103 m .85122 .53466 L .84871 .53134 L p F P
0 g
s
.651 .758 .928 r
.67457 .53487 m .68628 .53126 L .68906 .53458 L p F P
0 g
s
.651 .758 .928 r
.68628 .53126 m .67457 .53487 L .67177 .53154 L p F P
0 g
s
.651 .758 .928 r
.4979 .53492 m .5093 .53131 L .51236 .53464 L p F P
0 g
s
.651 .758 .928 r
.5093 .53131 m .4979 .53492 L .49481 .53159 L p F P
0 g
s
.65 .757 .928 r
.32122 .53492 m .33231 .53132 L .33567 .53464 L p F P
0 g
s
.65 .757 .928 r
.33231 .53132 m .32122 .53492 L .31785 .53159 L p F P
0 g
s
.651 .759 .928 r
.87778 .53072 m .86573 .53435 L .86324 .53103 L p F P
0 g
s
.651 .759 .928 r
.86573 .53435 m .87778 .53072 L .88025 .53404 L p F P
0 g
s
.651 .758 .928 r
.68906 .53458 m .7008 .53097 L .70355 .5343 L p F P
0 g
s
.651 .758 .928 r
.7008 .53097 m .68906 .53458 L .68628 .53126 L p F P
0 g
s
.651 .758 .928 r
.51236 .53464 m .52379 .53103 L .52683 .53436 L p F P
0 g
s
.651 .758 .928 r
.52379 .53103 m .51236 .53464 L .5093 .53131 L p F P
0 g
s
.65 .757 .928 r
.33567 .53464 m .34678 .53104 L .35011 .53437 L p F P
0 g
s
.65 .757 .928 r
.34678 .53104 m .33567 .53464 L .33231 .53132 L p F P
0 g
s
.651 .759 .928 r
.88025 .53404 m .89232 .5304 L .89476 .53372 L p F P
0 g
s
.651 .759 .928 r
.89232 .5304 m .88025 .53404 L .87778 .53072 L p F P
0 g
s
.651 .758 .928 r
.70355 .5343 m .71532 .53068 L .71805 .53401 L p F P
0 g
s
.651 .758 .928 r
.71532 .53068 m .70355 .5343 L .7008 .53097 L p F P
0 g
s
.651 .758 .928 r
.52683 .53436 m .53829 .53075 L .54131 .53408 L p F P
0 g
s
.651 .758 .928 r
.53829 .53075 m .52683 .53436 L .52379 .53103 L p F P
0 g
s
.65 .757 .928 r
.35011 .53437 m .36126 .53076 L .36456 .53409 L p F P
0 g
s
.65 .757 .928 r
.36126 .53076 m .35011 .53437 L .34678 .53104 L p F P
0 g
s
.652 .759 .928 r
.90687 .53008 m .89476 .53372 L .89232 .5304 L p F P
0 g
s
.652 .759 .928 r
.89476 .53372 m .90687 .53008 L .90929 .53339 L p F P
0 g
s
.651 .758 .928 r
.71805 .53401 m .72985 .5304 L .73255 .53372 L p F P
0 g
s
.651 .758 .928 r
.72985 .5304 m .71805 .53401 L .71532 .53068 L p F P
0 g
s
.651 .758 .928 r
.5528 .53047 m .54131 .53408 L .53829 .53075 L p F P
0 g
s
.651 .758 .928 r
.54131 .53408 m .5528 .53047 L .55579 .5338 L p F P
0 g
s
0 0 .275 r
.39885 .37055 m .39884 .37057 L .39898 .36554 L p F P
0 g
s
0 0 .275 r
.39898 .36554 m .39899 .36551 L .39885 .37055 L p F P
0 g
s
.763 .494 .526 r
.39881 .37057 m .39884 .37057 L .39898 .36554 L p F P
0 g
s
.763 .494 .526 r
.39898 .36554 m .39894 .36553 L .39881 .37057 L p F P
0 g
s
.65 .758 .928 r
.36456 .53409 m .37574 .53049 L .37902 .53381 L p F P
0 g
s
.65 .757 .928 r
.37574 .53049 m .36456 .53409 L .36126 .53076 L p F P
0 g
s
.652 .759 .928 r
.90929 .53339 m .92142 .52975 L .92381 .53307 L p F P
0 g
s
.652 .759 .928 r
.92142 .52975 m .90929 .53339 L .90687 .53008 L p F P
0 g
s
.651 .758 .928 r
.73255 .53372 m .74438 .53011 L .74706 .53343 L p F P
0 g
s
.651 .758 .928 r
.74438 .53011 m .73255 .53372 L .72985 .5304 L p F P
0 g
s
.651 .758 .928 r
.55579 .5338 m .5673 .53019 L .57027 .53352 L p F P
0 g
s
.651 .758 .928 r
.5673 .53019 m .55579 .5338 L .5528 .53047 L p F P
0 g
s
.65 .758 .928 r
.37902 .53381 m .39022 .53021 L .39348 .53354 L p F P
0 g
s
.65 .758 .928 r
.39022 .53021 m .37902 .53381 L .37574 .53049 L p F P
0 g
s
.651 .758 .928 r
.74706 .53343 m .75891 .52981 L .76157 .53314 L p F P
0 g
s
.651 .758 .928 r
.75891 .52981 m .74706 .53343 L .74438 .53011 L p F P
0 g
s
.65 .757 .928 r
.21669 .53352 m .2276 .52991 L .23113 .53324 L p F P
0 g
s
.651 .758 .928 r
.57027 .53352 m .58181 .52991 L .58476 .53324 L p F P
0 g
s
.651 .758 .928 r
.58181 .52991 m .57027 .53352 L .5673 .53019 L p F P
0 g
s
.65 .758 .928 r
.39348 .53354 m .40471 .52993 L .40794 .53326 L p F P
0 g
s
.65 .758 .928 r
.40471 .52993 m .39348 .53354 L .39022 .53021 L p F P
0 g
s
.651 .758 .928 r
.76157 .53314 m .77345 .52952 L .77609 .53285 L p F P
0 g
s
.651 .758 .928 r
.77345 .52952 m .76157 .53314 L .75891 .52981 L p F P
0 g
s
.651 .758 .928 r
.58476 .53324 m .59633 .52963 L .59925 .53296 L p F P
0 g
s
.651 .758 .928 r
.59633 .52963 m .58476 .53324 L .58181 .52991 L p F P
0 g
s
.65 .757 .928 r
.23113 .53324 m .24207 .52964 L .24557 .53297 L p F P
0 g
s
.65 .757 .928 r
.24207 .52964 m .23113 .53324 L .2276 .52991 L p F P
0 g
s
.65 .758 .928 r
.40794 .53326 m .4192 .52965 L .42241 .53298 L p F P
0 g
s
.65 .758 .928 r
.4192 .52965 m .40794 .53326 L .40471 .52993 L p F P
0 g
s
.651 .758 .928 r
.77609 .53285 m .78799 .52922 L .7906 .53255 L p F P
0 g
s
.651 .758 .928 r
.78799 .52922 m .77609 .53285 L .77345 .52952 L p F P
0 g
s
.651 .758 .928 r
.59925 .53296 m .61085 .52935 L .61375 .53268 L p F P
0 g
s
.651 .758 .928 r
.61085 .52935 m .59925 .53296 L .59633 .52963 L p F P
0 g
s
.65 .757 .928 r
.24557 .53297 m .25654 .52936 L .26002 .5327 L p F P
0 g
s
.65 .757 .928 r
.25654 .52936 m .24557 .53297 L .24207 .52964 L p F P
0 g
s
.65 .758 .928 r
.42241 .53298 m .43369 .52937 L .43688 .53271 L p F P
0 g
s
.65 .758 .928 r
.43369 .52937 m .42241 .53298 L .4192 .52965 L p F P
0 g
s
.651 .758 .928 r
.7906 .53255 m .80253 .52893 L .80512 .53225 L p F P
0 g
s
.651 .758 .928 r
.80253 .52893 m .7906 .53255 L .78799 .52922 L p F P
0 g
s
.651 .758 .928 r
.61375 .53268 m .62537 .52906 L .62825 .53239 L p F P
0 g
s
.651 .758 .928 r
.62537 .52906 m .61375 .53268 L .61085 .52935 L p F P
0 g
s
.65 .757 .928 r
.26002 .5327 m .27101 .52909 L .27447 .53242 L p F P
0 g
s
.65 .757 .928 r
.27101 .52909 m .26002 .5327 L .25654 .52936 L p F P
0 g
s
.65 .758 .928 r
.43688 .53271 m .44819 .5291 L .45136 .53243 L p F P
0 g
s
.65 .758 .928 r
.44819 .5291 m .43688 .53271 L .43369 .52937 L p F P
0 g
s
.651 .758 .928 r
.80512 .53225 m .81708 .52863 L .81965 .53195 L p F P
0 g
s
.651 .758 .928 r
.81708 .52863 m .80512 .53225 L .80253 .52893 L p F P
0 g
s
.651 .758 .928 r
.62825 .53239 m .63989 .52878 L .64275 .53211 L p F P
0 g
s
.651 .758 .928 r
.63989 .52878 m .62825 .53239 L .62537 .52906 L p F P
0 g
s
.65 .757 .928 r
.27447 .53242 m .28549 .52881 L .28892 .53214 L p F P
0 g
s
.65 .757 .928 r
.28549 .52881 m .27447 .53242 L .27101 .52909 L p F P
0 g
s
.651 .758 .928 r
.45136 .53243 m .46269 .52882 L .46584 .53215 L p F P
0 g
s
.651 .758 .928 r
.46269 .52882 m .45136 .53243 L .44819 .5291 L p F P
0 g
s
.651 .758 .928 r
.81965 .53195 m .83163 .52832 L .83418 .53165 L p F P
0 g
s
.651 .758 .928 r
.83163 .52832 m .81965 .53195 L .81708 .52863 L p F P
0 g
s
.651 .758 .928 r
.64275 .53211 m .65442 .5285 L .65726 .53183 L p F P
0 g
s
.651 .758 .928 r
.65442 .5285 m .64275 .53211 L .63989 .52878 L p F P
0 g
s
.65 .757 .928 r
.28892 .53214 m .29997 .52853 L .30338 .53187 L p F P
0 g
s
.65 .757 .928 r
.29997 .52853 m .28892 .53214 L .28549 .52881 L p F P
0 g
s
.651 .758 .928 r
.46584 .53215 m .4772 .52854 L .48032 .53187 L p F P
0 g
s
.651 .758 .928 r
.4772 .52854 m .46584 .53215 L .46269 .52882 L p F P
0 g
s
.651 .758 .928 r
.83418 .53165 m .84619 .52802 L .84871 .53134 L p F P
0 g
s
.651 .758 .928 r
.84619 .52802 m .83418 .53165 L .83163 .52832 L p F P
0 g
s
.651 .758 .928 r
.65726 .53183 m .66896 .52821 L .67177 .53154 L p F P
0 g
s
.651 .758 .928 r
.66896 .52821 m .65726 .53183 L .65442 .5285 L p F P
0 g
s
.65 .757 .928 r
.30338 .53187 m .31446 .52826 L .31785 .53159 L p F P
0 g
s
.65 .757 .928 r
.31446 .52826 m .30338 .53187 L .29997 .52853 L p F P
0 g
s
.651 .758 .928 r
.48032 .53187 m .49171 .52826 L .49481 .53159 L p F P
0 g
s
.651 .758 .928 r
.49171 .52826 m .48032 .53187 L .4772 .52854 L p F P
0 g
s
.651 .758 .928 r
.84871 .53134 m .86075 .52771 L .86324 .53103 L p F P
0 g
s
.651 .758 .928 r
.86075 .52771 m .84871 .53134 L .84619 .52802 L p F P
0 g
s
.651 .758 .928 r
.67177 .53154 m .6835 .52792 L .68628 .53126 L p F P
0 g
s
.651 .758 .928 r
.6835 .52792 m .67177 .53154 L .66896 .52821 L p F P
0 g
s
.651 .758 .928 r
.49481 .53159 m .50622 .52798 L .5093 .53131 L p F P
0 g
s
.651 .758 .928 r
.50622 .52798 m .49481 .53159 L .49171 .52826 L p F P
0 g
s
.65 .757 .928 r
.31785 .53159 m .32895 .52798 L .33231 .53132 L p F P
0 g
s
.65 .757 .928 r
.32895 .52798 m .31785 .53159 L .31446 .52826 L p F P
0 g
s
.651 .759 .928 r
.86324 .53103 m .87531 .52739 L .87778 .53072 L p F P
0 g
s
.651 .759 .928 r
.87531 .52739 m .86324 .53103 L .86075 .52771 L p F P
0 g
s
.651 .758 .928 r
.68628 .53126 m .69804 .52764 L .7008 .53097 L p F P
0 g
s
.651 .758 .928 r
.69804 .52764 m .68628 .53126 L .6835 .52792 L p F P
0 g
s
0 0 .275 r
.39872 .3756 m .39871 .37562 L .39884 .37057 L p F P
0 g
s
0 0 .275 r
.39884 .37057 m .39885 .37055 L .39872 .3756 L p F P
0 g
s
.763 .494 .526 r
.39868 .37562 m .39871 .37562 L .39884 .37057 L p F P
0 g
s
.763 .494 .526 r
.39884 .37057 m .39881 .37057 L .39868 .37562 L p F P
0 g
s
.651 .758 .928 r
.5093 .53131 m .52074 .5277 L .52379 .53103 L p F P
0 g
s
.651 .758 .928 r
.52074 .5277 m .5093 .53131 L .50622 .52798 L p F P
0 g
s
.65 .757 .928 r
.33231 .53132 m .34344 .5277 L .34678 .53104 L p F P
0 g
s
.65 .757 .928 r
.34344 .5277 m .33231 .53132 L .32895 .52798 L p F P
0 g
s
.651 .759 .928 r
.88988 .52708 m .87778 .53072 L .87531 .52739 L p F P
0 g
s
.651 .759 .928 r
.87778 .53072 m .88988 .52708 L .89232 .5304 L p F P
0 g
s
.651 .758 .928 r
.7008 .53097 m .71258 .52735 L .71532 .53068 L p F P
0 g
s
.651 .758 .928 r
.71258 .52735 m .7008 .53097 L .69804 .52764 L p F P
0 g
s
.651 .758 .928 r
.52379 .53103 m .53526 .52742 L .53829 .53075 L p F P
0 g
s
.651 .758 .928 r
.53526 .52742 m .52379 .53103 L .52074 .5277 L p F P
0 g
s
.65 .757 .928 r
.34678 .53104 m .35794 .52743 L .36126 .53076 L p F P
0 g
s
.65 .757 .928 r
.35794 .52743 m .34678 .53104 L .34344 .5277 L p F P
0 g
s
.652 .759 .928 r
.89232 .5304 m .90444 .52675 L .90687 .53008 L p F P
0 g
s
.652 .759 .928 r
.90444 .52675 m .89232 .5304 L .88988 .52708 L p F P
0 g
s
.651 .758 .928 r
.71532 .53068 m .72713 .52706 L .72985 .5304 L p F P
0 g
s
.651 .758 .928 r
.72713 .52706 m .71532 .53068 L .71258 .52735 L p F P
0 g
s
.651 .758 .928 r
.53829 .53075 m .54979 .52713 L .5528 .53047 L p F P
0 g
s
.651 .758 .928 r
.54979 .52713 m .53829 .53075 L .53526 .52742 L p F P
0 g
s
.65 .757 .928 r
.36126 .53076 m .37244 .52715 L .37574 .53049 L p F P
0 g
s
.65 .757 .928 r
.37244 .52715 m .36126 .53076 L .35794 .52743 L p F P
0 g
s
.652 .759 .928 r
.91902 .52643 m .90687 .53008 L .90444 .52675 L p F P
0 g
s
.652 .759 .928 r
.90687 .53008 m .91902 .52643 L .92142 .52975 L p F P
0 g
s
.651 .758 .928 r
.72985 .5304 m .74169 .52677 L .74438 .53011 L p F P
0 g
s
.651 .758 .928 r
.74169 .52677 m .72985 .5304 L .72713 .52706 L p F P
0 g
s
.651 .758 .928 r
.56432 .52685 m .5528 .53047 L .54979 .52713 L p F P
0 g
s
.651 .758 .928 r
.5528 .53047 m .56432 .52685 L .5673 .53019 L p F P
0 g
s
.65 .758 .928 r
.37574 .53049 m .38695 .52687 L .39022 .53021 L p F P
0 g
s
.65 .758 .928 r
.38695 .52687 m .37574 .53049 L .37244 .52715 L p F P
0 g
s
.651 .758 .928 r
.74438 .53011 m .75624 .52648 L .75891 .52981 L p F P
0 g
s
.651 .758 .928 r
.75624 .52648 m .74438 .53011 L .74169 .52677 L p F P
0 g
s
.651 .758 .928 r
.5673 .53019 m .57885 .52657 L .58181 .52991 L p F P
0 g
s
.651 .758 .928 r
.57885 .52657 m .5673 .53019 L .56432 .52685 L p F P
0 g
s
.65 .758 .928 r
.39022 .53021 m .40146 .52659 L .40471 .52993 L p F P
0 g
s
.65 .758 .928 r
.40146 .52659 m .39022 .53021 L .38695 .52687 L p F P
0 g
s
.651 .758 .928 r
.75891 .52981 m .7708 .52618 L .77345 .52952 L p F P
0 g
s
.651 .758 .928 r
.7708 .52618 m .75891 .52981 L .75624 .52648 L p F P
0 g
s
.651 .758 .928 r
.58181 .52991 m .59339 .52629 L .59633 .52963 L p F P
0 g
s
.651 .758 .928 r
.59339 .52629 m .58181 .52991 L .57885 .52657 L p F P
0 g
s
.65 .757 .928 r
.2276 .52991 m .23856 .5263 L .24207 .52964 L p F P
0 g
s
.65 .758 .928 r
.40471 .52993 m .41597 .52631 L .4192 .52965 L p F P
0 g
s
.65 .758 .928 r
.41597 .52631 m .40471 .52993 L .40146 .52659 L p F P
0 g
s
.651 .758 .928 r
.77345 .52952 m .78537 .52589 L .78799 .52922 L p F P
0 g
s
.651 .758 .928 r
.78537 .52589 m .77345 .52952 L .7708 .52618 L p F P
0 g
s
.651 .758 .928 r
.59633 .52963 m .60793 .526 L .61085 .52935 L p F P
0 g
s
.651 .758 .928 r
.60793 .526 m .59633 .52963 L .59339 .52629 L p F P
0 g
s
.65 .757 .928 r
.24207 .52964 m .25305 .52602 L .25654 .52936 L p F P
0 g
s
.65 .757 .928 r
.25305 .52602 m .24207 .52964 L .23856 .5263 L p F P
0 g
s
.65 .758 .928 r
.4192 .52965 m .43049 .52603 L .43369 .52937 L p F P
0 g
s
.65 .758 .928 r
.43049 .52603 m .4192 .52965 L .41597 .52631 L p F P
0 g
s
.651 .758 .928 r
.78799 .52922 m .79994 .52559 L .80253 .52893 L p F P
0 g
s
.651 .758 .928 r
.79994 .52559 m .78799 .52922 L .78537 .52589 L p F P
0 g
s
.651 .758 .928 r
.61085 .52935 m .62248 .52572 L .62537 .52906 L p F P
0 g
s
.651 .758 .928 r
.62248 .52572 m .61085 .52935 L .60793 .526 L p F P
0 g
s
.65 .757 .928 r
.25654 .52936 m .26755 .52574 L .27101 .52909 L p F P
0 g
s
.65 .757 .928 r
.26755 .52574 m .25654 .52936 L .25305 .52602 L p F P
0 g
s
.65 .758 .928 r
.43369 .52937 m .44501 .52575 L .44819 .5291 L p F P
0 g
s
.65 .758 .928 r
.44501 .52575 m .43369 .52937 L .43049 .52603 L p F P
0 g
s
.651 .758 .928 r
.80253 .52893 m .81451 .52529 L .81708 .52863 L p F P
0 g
s
.651 .758 .928 r
.81451 .52529 m .80253 .52893 L .79994 .52559 L p F P
0 g
s
.651 .758 .928 r
.62537 .52906 m .63703 .52544 L .63989 .52878 L p F P
0 g
s
.651 .758 .928 r
.63703 .52544 m .62537 .52906 L .62248 .52572 L p F P
0 g
s
.65 .757 .928 r
.27101 .52909 m .28205 .52547 L .28549 .52881 L p F P
0 g
s
.65 .757 .928 r
.28205 .52547 m .27101 .52909 L .26755 .52574 L p F P
0 g
s
.651 .758 .928 r
.44819 .5291 m .45954 .52547 L .46269 .52882 L p F P
0 g
s
.651 .758 .928 r
.45954 .52547 m .44819 .5291 L .44501 .52575 L p F P
0 g
s
.651 .758 .928 r
.81708 .52863 m .82908 .52498 L .83163 .52832 L p F P
0 g
s
.651 .758 .928 r
.82908 .52498 m .81708 .52863 L .81451 .52529 L p F P
0 g
s
.651 .758 .928 r
.63989 .52878 m .65158 .52515 L .65442 .5285 L p F P
0 g
s
.651 .758 .928 r
.65158 .52515 m .63989 .52878 L .63703 .52544 L p F P
0 g
s
.65 .757 .928 r
.28549 .52881 m .29655 .52519 L .29997 .52853 L p F P
0 g
s
.65 .757 .928 r
.29655 .52519 m .28549 .52881 L .28205 .52547 L p F P
0 g
s
.651 .758 .928 r
.46269 .52882 m .47407 .52519 L .4772 .52854 L p F P
0 g
s
.651 .758 .928 r
.47407 .52519 m .46269 .52882 L .45954 .52547 L p F P
0 g
s
.651 .758 .928 r
.83163 .52832 m .84366 .52468 L .84619 .52802 L p F P
0 g
s
.651 .758 .928 r
.84366 .52468 m .83163 .52832 L .82908 .52498 L p F P
0 g
s
.651 .758 .928 r
.65442 .5285 m .66614 .52487 L .66896 .52821 L p F P
0 g
s
.651 .758 .928 r
.66614 .52487 m .65442 .5285 L .65158 .52515 L p F P
0 g
s
0 0 .275 r
.39858 .38067 m .39857 .38069 L .39871 .37562 L p F P
0 g
s
0 0 .275 r
.39871 .37562 m .39872 .3756 L .39858 .38067 L p F P
0 g
s
.763 .494 .526 r
.39854 .38068 m .39857 .38069 L .39871 .37562 L p F P
0 g
s
.763 .494 .526 r
.39871 .37562 m .39868 .37562 L .39854 .38068 L p F P
0 g
s
.65 .757 .928 r
.29997 .52853 m .31106 .52491 L .31446 .52826 L p F P
0 g
s
.65 .757 .928 r
.31106 .52491 m .29997 .52853 L .29655 .52519 L p F P
0 g
s
.651 .758 .928 r
.4772 .52854 m .4886 .52491 L .49171 .52826 L p F P
0 g
s
.651 .758 .928 r
.4886 .52491 m .4772 .52854 L .47407 .52519 L p F P
0 g
s
.651 .758 .928 r
.84619 .52802 m .85824 .52437 L .86075 .52771 L p F P
0 g
s
.651 .758 .928 r
.85824 .52437 m .84619 .52802 L .84366 .52468 L p F P
0 g
s
.651 .758 .928 r
.66896 .52821 m .6807 .52458 L .6835 .52792 L p F P
0 g
s
.651 .758 .928 r
.6807 .52458 m .66896 .52821 L .66614 .52487 L p F P
0 g
s
.651 .758 .928 r
.49171 .52826 m .50314 .52463 L .50622 .52798 L p F P
0 g
s
.651 .758 .928 r
.50314 .52463 m .49171 .52826 L .4886 .52491 L p F P
0 g
s
.65 .757 .928 r
.31446 .52826 m .32558 .52463 L .32895 .52798 L p F P
0 g
s
.65 .757 .928 r
.32558 .52463 m .31446 .52826 L .31106 .52491 L p F P
0 g
s
.651 .759 .928 r
.86075 .52771 m .87283 .52406 L .87531 .52739 L p F P
0 g
s
.651 .758 .928 r
.87283 .52406 m .86075 .52771 L .85824 .52437 L p F P
0 g
s
.651 .758 .928 r
.6835 .52792 m .69527 .52429 L .69804 .52764 L p F P
0 g
s
.651 .758 .928 r
.69527 .52429 m .6835 .52792 L .6807 .52458 L p F P
0 g
s
.651 .758 .928 r
.50622 .52798 m .51768 .52435 L .52074 .5277 L p F P
0 g
s
.651 .758 .928 r
.51768 .52435 m .50622 .52798 L .50314 .52463 L p F P
0 g
s
.65 .757 .928 r
.32895 .52798 m .34009 .52435 L .34344 .5277 L p F P
0 g
s
.65 .757 .928 r
.34009 .52435 m .32895 .52798 L .32558 .52463 L p F P
0 g
s
.651 .759 .928 r
.87531 .52739 m .88742 .52374 L .88988 .52708 L p F P
0 g
s
.651 .759 .928 r
.88742 .52374 m .87531 .52739 L .87283 .52406 L p F P
0 g
s
.651 .758 .928 r
.69804 .52764 m .70984 .524 L .71258 .52735 L p F P
0 g
s
.651 .758 .928 r
.70984 .524 m .69804 .52764 L .69527 .52429 L p F P
0 g
s
.651 .758 .928 r
.52074 .5277 m .53223 .52407 L .53526 .52742 L p F P
0 g
s
.651 .758 .928 r
.53223 .52407 m .52074 .5277 L .51768 .52435 L p F P
0 g
s
.65 .757 .928 r
.34344 .5277 m .35461 .52408 L .35794 .52743 L p F P
0 g
s
.65 .757 .928 r
.35461 .52408 m .34344 .5277 L .34009 .52435 L p F P
0 g
s
.652 .759 .928 r
.90201 .52342 m .88988 .52708 L .88742 .52374 L p F P
0 g
s
.652 .759 .928 r
.88988 .52708 m .90201 .52342 L .90444 .52675 L p F P
0 g
s
.651 .758 .928 r
.71258 .52735 m .72441 .52371 L .72713 .52706 L p F P
0 g
s
.651 .758 .928 r
.72441 .52371 m .71258 .52735 L .70984 .524 L p F P
0 g
s
.651 .758 .928 r
.53526 .52742 m .54678 .52378 L .54979 .52713 L p F P
0 g
s
.651 .758 .928 r
.54678 .52378 m .53526 .52742 L .53223 .52407 L p F P
0 g
s
.65 .757 .928 r
.35794 .52743 m .36914 .5238 L .37244 .52715 L p F P
0 g
s
.65 .757 .928 r
.36914 .5238 m .35794 .52743 L .35461 .52408 L p F P
0 g
s
.652 .759 .928 r
.90444 .52675 m .91661 .52309 L .91902 .52643 L p F P
0 g
s
.652 .759 .928 r
.91661 .52309 m .90444 .52675 L .90201 .52342 L p F P
0 g
s
.651 .758 .928 r
.72713 .52706 m .73899 .52342 L .74169 .52677 L p F P
0 g
s
.651 .758 .928 r
.73899 .52342 m .72713 .52706 L .72441 .52371 L p F P
0 g
s
.651 .758 .928 r
.54979 .52713 m .56133 .5235 L .56432 .52685 L p F P
0 g
s
.651 .758 .928 r
.56133 .5235 m .54979 .52713 L .54678 .52378 L p F P
0 g
s
.65 .758 .928 r
.37244 .52715 m .38367 .52352 L .38695 .52687 L p F P
0 g
s
.65 .757 .928 r
.38367 .52352 m .37244 .52715 L .36914 .5238 L p F P
0 g
s
.651 .758 .928 r
.74169 .52677 m .75357 .52313 L .75624 .52648 L p F P
0 g
s
.651 .758 .928 r
.75357 .52313 m .74169 .52677 L .73899 .52342 L p F P
0 g
s
.651 .758 .928 r
.57589 .52322 m .56432 .52685 L .56133 .5235 L p F P
0 g
s
.651 .758 .928 r
.56432 .52685 m .57589 .52322 L .57885 .52657 L p F P
0 g
s
.65 .758 .928 r
.38695 .52687 m .3982 .52324 L .40146 .52659 L p F P
0 g
s
.65 .758 .928 r
.3982 .52324 m .38695 .52687 L .38367 .52352 L p F P
0 g
s
.651 .758 .928 r
.75624 .52648 m .76815 .52283 L .7708 .52618 L p F P
0 g
s
.651 .758 .928 r
.76815 .52283 m .75624 .52648 L .75357 .52313 L p F P
0 g
s
.651 .758 .928 r
.57885 .52657 m .59045 .52294 L .59339 .52629 L p F P
0 g
s
.651 .758 .928 r
.59045 .52294 m .57885 .52657 L .57589 .52322 L p F P
0 g
s
.65 .758 .928 r
.40146 .52659 m .41274 .52296 L .41597 .52631 L p F P
0 g
s
.65 .758 .928 r
.41274 .52296 m .40146 .52659 L .3982 .52324 L p F P
0 g
s
.651 .758 .928 r
.7708 .52618 m .78274 .52254 L .78537 .52589 L p F P
0 g
s
.651 .758 .928 r
.78274 .52254 m .7708 .52618 L .76815 .52283 L p F P
0 g
s
.651 .758 .928 r
.59339 .52629 m .60501 .52265 L .60793 .526 L p F P
0 g
s
.651 .758 .928 r
.60501 .52265 m .59339 .52629 L .59045 .52294 L p F P
0 g
s
.65 .757 .928 r
.23856 .5263 m .24955 .52267 L .25305 .52602 L p F P
0 g
s
.65 .758 .928 r
.41597 .52631 m .42728 .52268 L .43049 .52603 L p F P
0 g
s
.65 .758 .928 r
.42728 .52268 m .41597 .52631 L .41274 .52296 L p F P
0 g
s
.651 .758 .928 r
.78537 .52589 m .79733 .52224 L .79994 .52559 L p F P
0 g
s
.651 .758 .928 r
.79733 .52224 m .78537 .52589 L .78274 .52254 L p F P
0 g
s
.651 .758 .928 r
.60793 .526 m .61958 .52237 L .62248 .52572 L p F P
0 g
s
.651 .758 .928 r
.61958 .52237 m .60793 .526 L .60501 .52265 L p F P
0 g
s
.65 .757 .928 r
.25305 .52602 m .26407 .52239 L .26755 .52574 L p F P
0 g
s
.65 .757 .928 r
.26407 .52239 m .25305 .52602 L .24955 .52267 L p F P
0 g
s
.65 .758 .928 r
.43049 .52603 m .44183 .5224 L .44501 .52575 L p F P
0 g
s
.65 .758 .928 r
.44183 .5224 m .43049 .52603 L .42728 .52268 L p F P
0 g
s
.651 .758 .928 r
.79994 .52559 m .81192 .52194 L .81451 .52529 L p F P
0 g
s
.651 .758 .928 r
.81192 .52194 m .79994 .52559 L .79733 .52224 L p F P
0 g
s
.651 .758 .928 r
.62248 .52572 m .63416 .52208 L .63703 .52544 L p F P
0 g
s
.651 .758 .928 r
.63416 .52208 m .62248 .52572 L .61958 .52237 L p F P
0 g
s
.65 .757 .928 r
.26755 .52574 m .27859 .52211 L .28205 .52547 L p F P
0 g
s
.65 .757 .928 r
.27859 .52211 m .26755 .52574 L .26407 .52239 L p F P
0 g
s
0 0 .275 r
.39844 .38575 m .39844 .38577 L .39857 .38069 L p F P
0 g
s
0 0 .275 r
.39857 .38069 m .39858 .38067 L .39844 .38575 L p F P
0 g
s
.763 .494 .526 r
.39841 .38576 m .39844 .38577 L .39857 .38069 L p F P
0 g
s
.763 .494 .526 r
.39857 .38069 m .39854 .38068 L .39841 .38576 L p F P
0 g
s
.651 .758 .928 r
.44501 .52575 m .45637 .52212 L .45954 .52547 L p F P
0 g
s
.651 .758 .928 r
.45637 .52212 m .44501 .52575 L .44183 .5224 L p F P
0 g
s
.651 .758 .928 r
.81451 .52529 m .82652 .52163 L .82908 .52498 L p F P
0 g
s
.651 .758 .928 r
.82652 .52163 m .81451 .52529 L .81192 .52194 L p F P
0 g
s
.651 .758 .928 r
.63703 .52544 m .64873 .5218 L .65158 .52515 L p F P
0 g
s
.651 .758 .928 r
.64873 .5218 m .63703 .52544 L .63416 .52208 L p F P
0 g
s
.65 .757 .928 r
.28205 .52547 m .29312 .52183 L .29655 .52519 L p F P
0 g
s
.65 .757 .928 r
.29312 .52183 m .28205 .52547 L .27859 .52211 L p F P
0 g
s
.651 .758 .928 r
.45954 .52547 m .47093 .52184 L .47407 .52519 L p F P
0 g
s
.651 .758 .928 r
.47093 .52184 m .45954 .52547 L .45637 .52212 L p F P
0 g
s
.651 .758 .928 r
.82908 .52498 m .84113 .52133 L .84366 .52468 L p F P
0 g
s
.651 .758 .928 r
.84113 .52133 m .82908 .52498 L .82652 .52163 L p F P
0 g
s
.651 .758 .928 r
.65158 .52515 m .66331 .52151 L .66614 .52487 L p F P
0 g
s
.651 .758 .928 r
.66331 .52151 m .65158 .52515 L .64873 .5218 L p F P
0 g
s
.65 .757 .928 r
.29655 .52519 m .30765 .52155 L .31106 .52491 L p F P
0 g
s
.65 .757 .928 r
.30765 .52155 m .29655 .52519 L .29312 .52183 L p F P
0 g
s
.651 .758 .928 r
.47407 .52519 m .48548 .52155 L .4886 .52491 L p F P
0 g
s
.651 .758 .928 r
.48548 .52155 m .47407 .52519 L .47093 .52184 L p F P
0 g
s
.651 .758 .928 r
.84366 .52468 m .85573 .52102 L .85824 .52437 L p F P
0 g
s
.651 .758 .928 r
.85573 .52102 m .84366 .52468 L .84113 .52133 L p F P
0 g
s
.651 .758 .928 r
.66614 .52487 m .6779 .52122 L .6807 .52458 L p F P
0 g
s
.651 .758 .928 r
.6779 .52122 m .66614 .52487 L .66331 .52151 L p F P
0 g
s
.651 .758 .928 r
.4886 .52491 m .50005 .52127 L .50314 .52463 L p F P
0 g
s
.651 .758 .928 r
.50005 .52127 m .4886 .52491 L .48548 .52155 L p F P
0 g
s
.65 .757 .928 r
.31106 .52491 m .32219 .52127 L .32558 .52463 L p F P
0 g
s
.65 .757 .928 r
.32219 .52127 m .31106 .52491 L .30765 .52155 L p F P
0 g
s
.651 .758 .928 r
.85824 .52437 m .87034 .52071 L .87283 .52406 L p F P
0 g
s
.651 .758 .928 r
.87034 .52071 m .85824 .52437 L .85573 .52102 L p F P
0 g
s
.651 .758 .928 r
.6807 .52458 m .69249 .52093 L .69527 .52429 L p F P
0 g
s
.651 .758 .928 r
.69249 .52093 m .6807 .52458 L .6779 .52122 L p F P
0 g
s
.651 .758 .928 r
.50314 .52463 m .51461 .52099 L .51768 .52435 L p F P
0 g
s
.651 .758 .928 r
.51461 .52099 m .50314 .52463 L .50005 .52127 L p F P
0 g
s
.65 .757 .928 r
.32558 .52463 m .33673 .521 L .34009 .52435 L p F P
0 g
s
.65 .757 .928 r
.33673 .521 m .32558 .52463 L .32219 .52127 L p F P
0 g
s
.651 .759 .928 r
.87283 .52406 m .88495 .52039 L .88742 .52374 L p F P
0 g
s
.651 .759 .928 r
.88495 .52039 m .87283 .52406 L .87034 .52071 L p F P
0 g
s
.651 .758 .928 r
.69527 .52429 m .70708 .52065 L .70984 .524 L p F P
0 g
s
.651 .758 .928 r
.70708 .52065 m .69527 .52429 L .69249 .52093 L p F P
0 g
s
.651 .758 .928 r
.51768 .52435 m .52918 .52071 L .53223 .52407 L p F P
0 g
s
.651 .758 .928 r
.52918 .52071 m .51768 .52435 L .51461 .52099 L p F P
0 g
s
.65 .757 .928 r
.34009 .52435 m .35128 .52072 L .35461 .52408 L p F P
0 g
s
.65 .757 .928 r
.35128 .52072 m .34009 .52435 L .33673 .521 L p F P
0 g
s
.652 .759 .928 r
.88742 .52374 m .89957 .52007 L .90201 .52342 L p F P
0 g
s
.652 .759 .928 r
.89957 .52007 m .88742 .52374 L .88495 .52039 L p F P
0 g
s
.651 .758 .928 r
.70984 .524 m .72168 .52035 L .72441 .52371 L p F P
0 g
s
.651 .758 .928 r
.72168 .52035 m .70984 .524 L .70708 .52065 L p F P
0 g
s
.651 .758 .928 r
.53223 .52407 m .54375 .52042 L .54678 .52378 L p F P
0 g
s
.651 .758 .928 r
.54375 .52042 m .53223 .52407 L .52918 .52071 L p F P
0 g
s
.65 .757 .928 r
.35461 .52408 m .36582 .52044 L .36914 .5238 L p F P
0 g
s
.65 .757 .928 r
.36582 .52044 m .35461 .52408 L .35128 .52072 L p F P
0 g
s
.652 .759 .928 r
.91419 .51974 m .90201 .52342 L .89957 .52007 L p F P
0 g
s
.652 .759 .928 r
.90201 .52342 m .91419 .51974 L .91661 .52309 L p F P
0 g
s
.651 .758 .928 r
.72441 .52371 m .73628 .52006 L .73899 .52342 L p F P
0 g
s
.651 .758 .928 r
.73628 .52006 m .72441 .52371 L .72168 .52035 L p F P
0 g
s
.651 .758 .928 r
.54678 .52378 m .55833 .52014 L .56133 .5235 L p F P
0 g
s
.651 .758 .928 r
.55833 .52014 m .54678 .52378 L .54375 .52042 L p F P
0 g
s
.65 .757 .928 r
.36914 .5238 m .38038 .52016 L .38367 .52352 L p F P
0 g
s
.65 .757 .928 r
.38038 .52016 m .36914 .5238 L .36582 .52044 L p F P
0 g
s
.651 .758 .928 r
.73899 .52342 m .75088 .51977 L .75357 .52313 L p F P
0 g
s
.651 .758 .928 r
.75088 .51977 m .73899 .52342 L .73628 .52006 L p F P
0 g
s
.651 .758 .928 r
.56133 .5235 m .57291 .51986 L .57589 .52322 L p F P
0 g
s
.651 .758 .928 r
.57291 .51986 m .56133 .5235 L .55833 .52014 L p F P
0 g
s
.65 .758 .928 r
.38367 .52352 m .39493 .51988 L .3982 .52324 L p F P
0 g
s
.65 .758 .928 r
.39493 .51988 m .38367 .52352 L .38038 .52016 L p F P
0 g
s
.651 .758 .928 r
.75357 .52313 m .76549 .51947 L .76815 .52283 L p F P
0 g
s
.651 .758 .928 r
.76549 .51947 m .75357 .52313 L .75088 .51977 L p F P
0 g
s
.651 .758 .928 r
.57589 .52322 m .58749 .51957 L .59045 .52294 L p F P
0 g
s
.651 .758 .928 r
.58749 .51957 m .57589 .52322 L .57291 .51986 L p F P
0 g
s
.65 .758 .928 r
.3982 .52324 m .40949 .5196 L .41274 .52296 L p F P
0 g
s
.65 .758 .928 r
.40949 .5196 m .3982 .52324 L .39493 .51988 L p F P
0 g
s
.651 .758 .928 r
.76815 .52283 m .7801 .51918 L .78274 .52254 L p F P
0 g
s
.651 .758 .928 r
.7801 .51918 m .76815 .52283 L .76549 .51947 L p F P
0 g
s
.651 .758 .928 r
.59045 .52294 m .60208 .51929 L .60501 .52265 L p F P
0 g
s
.651 .758 .928 r
.60208 .51929 m .59045 .52294 L .58749 .51957 L p F P
0 g
s
0 0 .276 r
.39831 .39084 m .3983 .39086 L .39844 .38577 L p F P
0 g
s
0 0 .276 r
.39844 .38577 m .39844 .38575 L .39831 .39084 L p F P
0 g
s
.763 .494 .526 r
.39827 .39085 m .3983 .39086 L .39844 .38577 L p F P
0 g
s
.763 .494 .526 r
.39844 .38577 m .39841 .38576 L .39827 .39085 L p F P
0 g
s
.65 .758 .928 r
.41274 .52296 m .42406 .51931 L .42728 .52268 L p F P
0 g
s
.65 .758 .928 r
.42406 .51931 m .41274 .52296 L .40949 .5196 L p F P
0 g
s
.651 .758 .928 r
.78274 .52254 m .79471 .51888 L .79733 .52224 L p F P
0 g
s
.651 .758 .928 r
.79471 .51888 m .78274 .52254 L .7801 .51918 L p F P
0 g
s
.651 .758 .928 r
.60501 .52265 m .61668 .519 L .61958 .52237 L p F P
0 g
s
.651 .758 .928 r
.61668 .519 m .60501 .52265 L .60208 .51929 L p F P
0 g
s
.65 .757 .928 r
.24955 .52267 m .26058 .51902 L .26407 .52239 L p F P
0 g
s
.65 .758 .928 r
.42728 .52268 m .43863 .51903 L .44183 .5224 L p F P
0 g
s
.65 .758 .928 r
.43863 .51903 m .42728 .52268 L .42406 .51931 L p F P
0 g
s
.651 .758 .928 r
.79733 .52224 m .80933 .51858 L .81192 .52194 L p F P
0 g
s
.651 .758 .928 r
.80933 .51858 m .79733 .52224 L .79471 .51888 L p F P
0 g
s
.651 .758 .928 r
.61958 .52237 m .63127 .51872 L .63416 .52208 L p F P
0 g
s
.651 .758 .928 r
.63127 .51872 m .61958 .52237 L .61668 .519 L p F P
0 g
s
.65 .757 .928 r
.26407 .52239 m .27513 .51874 L .27859 .52211 L p F P
0 g
s
.65 .757 .928 r
.27513 .51874 m .26407 .52239 L .26058 .51902 L p F P
0 g
s
.651 .758 .928 r
.44183 .5224 m .4532 .51875 L .45637 .52212 L p F P
0 g
s
.651 .758 .928 r
.4532 .51875 m .44183 .5224 L .43863 .51903 L p F P
0 g
s
.651 .758 .928 r
.81192 .52194 m .82396 .51827 L .82652 .52163 L p F P
0 g
s
.651 .758 .928 r
.82396 .51827 m .81192 .52194 L .80933 .51858 L p F P
0 g
s
.651 .758 .928 r
.63416 .52208 m .64587 .51843 L .64873 .5218 L p F P
0 g
s
.651 .758 .928 r
.64587 .51843 m .63416 .52208 L .63127 .51872 L p F P
0 g
s
.65 .757 .928 r
.27859 .52211 m .28968 .51846 L .29312 .52183 L p F P
0 g
s
.65 .757 .928 r
.28968 .51846 m .27859 .52211 L .27513 .51874 L p F P
0 g
s
.651 .758 .928 r
.45637 .52212 m .46778 .51847 L .47093 .52184 L p F P
0 g
s
.651 .758 .928 r
.46778 .51847 m .45637 .52212 L .4532 .51875 L p F P
0 g
s
.651 .758 .928 r
.82652 .52163 m .83858 .51797 L .84113 .52133 L p F P
0 g
s
.651 .758 .928 r
.83858 .51797 m .82652 .52163 L .82396 .51827 L p F P
0 g
s
.651 .758 .928 r
.64873 .5218 m .66048 .51814 L .66331 .52151 L p F P
0 g
s
.651 .758 .928 r
.66048 .51814 m .64873 .5218 L .64587 .51843 L p F P
0 g
s
.65 .757 .928 r
.29312 .52183 m .30423 .51819 L .30765 .52155 L p F P
0 g
s
.65 .757 .928 r
.30423 .51819 m .29312 .52183 L .28968 .51846 L p F P
0 g
s
.651 .758 .928 r
.47093 .52184 m .48236 .51819 L .48548 .52155 L p F P
0 g
s
.651 .758 .928 r
.48236 .51819 m .47093 .52184 L .46778 .51847 L p F P
0 g
s
.651 .758 .928 r
.84113 .52133 m .85321 .51766 L .85573 .52102 L p F P
0 g
s
.651 .758 .928 r
.85321 .51766 m .84113 .52133 L .83858 .51797 L p F P
0 g
s
.651 .758 .928 r
.66331 .52151 m .67509 .51786 L .6779 .52122 L p F P
0 g
s
.651 .758 .928 r
.67509 .51786 m .66331 .52151 L .66048 .51814 L p F P
0 g
s
.65 .757 .928 r
.30765 .52155 m .31879 .51791 L .32219 .52127 L p F P
0 g
s
.65 .757 .928 r
.31879 .51791 m .30765 .52155 L .30423 .51819 L p F P
0 g
s
.651 .758 .928 r
.48548 .52155 m .49694 .5179 L .50005 .52127 L p F P
0 g
s
.651 .758 .928 r
.49694 .5179 m .48548 .52155 L .48236 .51819 L p F P
0 g
s
.651 .758 .928 r
.85573 .52102 m .86784 .51734 L .87034 .52071 L p F P
0 g
s
.651 .758 .928 r
.86784 .51734 m .85573 .52102 L .85321 .51766 L p F P
0 g
s
.651 .758 .928 r
.6779 .52122 m .6897 .51757 L .69249 .52093 L p F P
0 g
s
.651 .758 .928 r
.6897 .51757 m .6779 .52122 L .67509 .51786 L p F P
0 g
s
.651 .758 .928 r
.50005 .52127 m .51153 .51762 L .51461 .52099 L p F P
0 g
s
.651 .758 .928 r
.51153 .51762 m .50005 .52127 L .49694 .5179 L p F P
0 g
s
.65 .757 .928 r
.32219 .52127 m .33336 .51763 L .33673 .521 L p F P
0 g
s
.65 .757 .928 r
.33336 .51763 m .32219 .52127 L .31879 .51791 L p F P
0 g
s
.651 .759 .928 r
.87034 .52071 m .88248 .51703 L .88495 .52039 L p F P
0 g
s
.651 .759 .928 r
.88248 .51703 m .87034 .52071 L .86784 .51734 L p F P
0 g
s
.651 .758 .928 r
.69249 .52093 m .70431 .51728 L .70708 .52065 L p F P
0 g
s
.651 .758 .928 r
.70431 .51728 m .69249 .52093 L .6897 .51757 L p F P
0 g
s
.651 .758 .928 r
.51461 .52099 m .52612 .51734 L .52918 .52071 L p F P
0 g
s
.651 .758 .928 r
.52612 .51734 m .51461 .52099 L .51153 .51762 L p F P
0 g
s
.65 .757 .928 r
.34793 .51735 m .33673 .521 L .33336 .51763 L p F P
0 g
s
.65 .757 .928 r
.33673 .521 m .34793 .51735 L .35128 .52072 L p F P
0 g
s
.652 .759 .928 r
.88495 .52039 m .89712 .51671 L .89957 .52007 L p F P
0 g
s
.652 .759 .928 r
.89712 .51671 m .88495 .52039 L .88248 .51703 L p F P
0 g
s
.651 .758 .928 r
.70708 .52065 m .71893 .51699 L .72168 .52035 L p F P
0 g
s
.651 .758 .928 r
.71893 .51699 m .70708 .52065 L .70431 .51728 L p F P
0 g
s
.651 .758 .928 r
.52918 .52071 m .54072 .51705 L .54375 .52042 L p F P
0 g
s
.651 .758 .928 r
.54072 .51705 m .52918 .52071 L .52612 .51734 L p F P
0 g
s
.65 .757 .928 r
.35128 .52072 m .3625 .51706 L .36582 .52044 L p F P
0 g
s
.65 .757 .928 r
.3625 .51706 m .35128 .52072 L .34793 .51735 L p F P
0 g
s
.652 .759 .928 r
.89957 .52007 m .91176 .51638 L .91419 .51974 L p F P
0 g
s
.652 .759 .928 r
.91176 .51638 m .89957 .52007 L .89712 .51671 L p F P
0 g
s
.651 .758 .928 r
.72168 .52035 m .73356 .51669 L .73628 .52006 L p F P
0 g
s
.651 .758 .928 r
.73356 .51669 m .72168 .52035 L .71893 .51699 L p F P
0 g
s
.651 .758 .928 r
.54375 .52042 m .55532 .51677 L .55833 .52014 L p F P
0 g
s
.651 .758 .928 r
.55532 .51677 m .54375 .52042 L .54072 .51705 L p F P
0 g
s
.65 .757 .928 r
.36582 .52044 m .37707 .51678 L .38038 .52016 L p F P
0 g
s
.65 .757 .928 r
.37707 .51678 m .36582 .52044 L .3625 .51706 L p F P
0 g
s
.651 .758 .928 r
.73628 .52006 m .74818 .5164 L .75088 .51977 L p F P
0 g
s
.651 .758 .928 r
.74818 .5164 m .73628 .52006 L .73356 .51669 L p F P
0 g
s
.651 .758 .928 r
.55833 .52014 m .56992 .51648 L .57291 .51986 L p F P
0 g
s
.651 .758 .928 r
.56992 .51648 m .55833 .52014 L .55532 .51677 L p F P
0 g
s
0 0 .276 r
.39817 .39595 m .39816 .39596 L .3983 .39086 L p F P
0 g
s
0 0 .276 r
.3983 .39086 m .39831 .39084 L .39817 .39595 L p F P
0 g
s
.763 .493 .526 r
.39814 .39596 m .39816 .39596 L .3983 .39086 L p F P
0 g
s
.763 .493 .526 r
.3983 .39086 m .39827 .39085 L .39814 .39596 L p F P
0 g
s
.65 .758 .928 r
.38038 .52016 m .39165 .5165 L .39493 .51988 L p F P
0 g
s
.65 .757 .928 r
.39165 .5165 m .38038 .52016 L .37707 .51678 L p F P
0 g
s
.651 .758 .928 r
.75088 .51977 m .76282 .5161 L .76549 .51947 L p F P
0 g
s
.651 .758 .928 r
.76282 .5161 m .75088 .51977 L .74818 .5164 L p F P
0 g
s
.651 .758 .928 r
.57291 .51986 m .58453 .5162 L .58749 .51957 L p F P
0 g
s
.651 .758 .928 r
.58453 .5162 m .57291 .51986 L .56992 .51648 L p F P
0 g
s
.65 .758 .928 r
.39493 .51988 m .40624 .51622 L .40949 .5196 L p F P
0 g
s
.65 .758 .928 r
.40624 .51622 m .39493 .51988 L .39165 .5165 L p F P
0 g
s
.651 .758 .928 r
.76549 .51947 m .77745 .51581 L .7801 .51918 L p F P
0 g
s
.651 .758 .928 r
.77745 .51581 m .76549 .51947 L .76282 .5161 L p F P
0 g
s
.651 .758 .928 r
.58749 .51957 m .59914 .51591 L .60208 .51929 L p F P
0 g
s
.651 .758 .928 r
.59914 .51591 m .58749 .51957 L .58453 .5162 L p F P
0 g
s
.65 .758 .928 r
.40949 .5196 m .42083 .51594 L .42406 .51931 L p F P
0 g
s
.65 .758 .928 r
.42083 .51594 m .40949 .5196 L .40624 .51622 L p F P
0 g
s
.651 .758 .928 r
.7801 .51918 m .79209 .51551 L .79471 .51888 L p F P
0 g
s
.651 .758 .928 r
.79209 .51551 m .7801 .51918 L .77745 .51581 L p F P
0 g
s
.651 .758 .928 r
.60208 .51929 m .61376 .51563 L .61668 .519 L p F P
0 g
s
.651 .758 .928 r
.61376 .51563 m .60208 .51929 L .59914 .51591 L p F P
0 g
s
.65 .758 .928 r
.42406 .51931 m .43542 .51566 L .43863 .51903 L p F P
0 g
s
.65 .758 .928 r
.43542 .51566 m .42406 .51931 L .42083 .51594 L p F P
0 g
s
.651 .758 .928 r
.79471 .51888 m .80673 .51521 L .80933 .51858 L p F P
0 g
s
.651 .758 .928 r
.80673 .51521 m .79471 .51888 L .79209 .51551 L p F P
0 g
s
.651 .758 .928 r
.61668 .519 m .62838 .51534 L .63127 .51872 L p F P
0 g
s
.651 .758 .928 r
.62838 .51534 m .61668 .519 L .61376 .51563 L p F P
0 g
s
.65 .757 .928 r
.26058 .51902 m .27165 .51537 L .27513 .51874 L p F P
0 g
s
.651 .758 .928 r
.43863 .51903 m .45001 .51537 L .4532 .51875 L p F P
0 g
s
.651 .758 .928 r
.45001 .51537 m .43863 .51903 L .43542 .51566 L p F P
0 g
s
.651 .758 .928 r
.80933 .51858 m .82138 .5149 L .82396 .51827 L p F P
0 g
s
.651 .758 .928 r
.82138 .5149 m .80933 .51858 L .80673 .51521 L p F P
0 g
s
.651 .758 .928 r
.63127 .51872 m .643 .51505 L .64587 .51843 L p F P
0 g
s
.651 .758 .928 r
.643 .51505 m .63127 .51872 L .62838 .51534 L p F P
0 g
s
.65 .757 .928 r
.27513 .51874 m .28622 .51509 L .28968 .51846 L p F P
0 g
s
.65 .757 .928 r
.28622 .51509 m .27513 .51874 L .27165 .51537 L p F P
0 g
s
.651 .758 .928 r
.4532 .51875 m .46461 .51509 L .46778 .51847 L p F P
0 g
s
.651 .758 .928 r
.46461 .51509 m .4532 .51875 L .45001 .51537 L p F P
0 g
s
.651 .758 .928 r
.82396 .51827 m .83603 .51459 L .83858 .51797 L p F P
0 g
s
.651 .758 .928 r
.83603 .51459 m .82396 .51827 L .82138 .5149 L p F P
0 g
s
.651 .758 .928 r
.64587 .51843 m .65763 .51477 L .66048 .51814 L p F P
0 g
s
.651 .758 .928 r
.65763 .51477 m .64587 .51843 L .643 .51505 L p F P
0 g
s
.65 .757 .928 r
.28968 .51846 m .3008 .51481 L .30423 .51819 L p F P
0 g
s
.65 .757 .928 r
.3008 .51481 m .28968 .51846 L .28622 .51509 L p F P
0 g
s
.651 .758 .928 r
.46778 .51847 m .47922 .51481 L .48236 .51819 L p F P
0 g
s
.651 .758 .928 r
.47922 .51481 m .46778 .51847 L .46461 .51509 L p F P
0 g
s
.651 .758 .928 r
.83858 .51797 m .85068 .51428 L .85321 .51766 L p F P
0 g
s
.651 .758 .928 r
.85068 .51428 m .83858 .51797 L .83603 .51459 L p F P
0 g
s
.651 .758 .928 r
.66048 .51814 m .67226 .51448 L .67509 .51786 L p F P
0 g
s
.651 .758 .928 r
.67226 .51448 m .66048 .51814 L .65763 .51477 L p F P
0 g
s
.65 .757 .928 r
.30423 .51819 m .31539 .51452 L .31879 .51791 L p F P
0 g
s
.65 .757 .928 r
.31539 .51452 m .30423 .51819 L .3008 .51481 L p F P
0 g
s
.651 .758 .928 r
.48236 .51819 m .49383 .51452 L .49694 .5179 L p F P
0 g
s
.651 .758 .928 r
.49383 .51452 m .48236 .51819 L .47922 .51481 L p F P
0 g
s
.651 .758 .928 r
.85321 .51766 m .86534 .51397 L .86784 .51734 L p F P
0 g
s
.651 .758 .928 r
.86534 .51397 m .85321 .51766 L .85068 .51428 L p F P
0 g
s
.651 .758 .928 r
.67509 .51786 m .6869 .51419 L .6897 .51757 L p F P
0 g
s
.651 .758 .928 r
.6869 .51419 m .67509 .51786 L .67226 .51448 L p F P
0 g
s
.651 .758 .928 r
.49694 .5179 m .50844 .51424 L .51153 .51762 L p F P
0 g
s
.651 .758 .928 r
.50844 .51424 m .49694 .5179 L .49383 .51452 L p F P
0 g
s
.65 .757 .928 r
.31879 .51791 m .32997 .51424 L .33336 .51763 L p F P
0 g
s
.65 .757 .928 r
.32997 .51424 m .31879 .51791 L .31539 .51452 L p F P
0 g
s
.651 .759 .928 r
.86784 .51734 m .88 .51365 L .88248 .51703 L p F P
0 g
s
.651 .758 .928 r
.88 .51365 m .86784 .51734 L .86534 .51397 L p F P
0 g
s
.651 .758 .928 r
.6897 .51757 m .70154 .5139 L .70431 .51728 L p F P
0 g
s
.651 .758 .928 r
.70154 .5139 m .6897 .51757 L .6869 .51419 L p F P
0 g
s
.651 .758 .928 r
.51153 .51762 m .52305 .51396 L .52612 .51734 L p F P
0 g
s
.651 .758 .928 r
.52305 .51396 m .51153 .51762 L .50844 .51424 L p F P
0 g
s
.65 .757 .928 r
.33336 .51763 m .34457 .51396 L .34793 .51735 L p F P
0 g
s
.65 .757 .928 r
.34457 .51396 m .33336 .51763 L .32997 .51424 L p F P
0 g
s
.652 .759 .928 r
.88248 .51703 m .89466 .51333 L .89712 .51671 L p F P
0 g
s
.651 .759 .928 r
.89466 .51333 m .88248 .51703 L .88 .51365 L p F P
0 g
s
.651 .758 .928 r
.70431 .51728 m .71618 .5136 L .71893 .51699 L p F P
0 g
s
.651 .758 .928 r
.71618 .5136 m .70431 .51728 L .70154 .5139 L p F P
0 g
s
.651 .758 .928 r
.52612 .51734 m .53767 .51367 L .54072 .51705 L p F P
0 g
s
.651 .758 .928 r
.53767 .51367 m .52612 .51734 L .52305 .51396 L p F P
0 g
s
0 0 .277 r
.39803 .40107 m .39803 .40108 L .39816 .39596 L p F P
0 g
s
0 0 .277 r
.39816 .39596 m .39817 .39595 L .39803 .40107 L p F P
0 g
s
.763 .493 .526 r
.398 .40108 m .39803 .40108 L .39816 .39596 L p F P
0 g
s
.763 .493 .526 r
.39816 .39596 m .39814 .39596 L .398 .40108 L p F P
0 g
s
.65 .757 .928 r
.35916 .51368 m .34793 .51735 L .34457 .51396 L p F P
0 g
s
.65 .757 .928 r
.34793 .51735 m .35916 .51368 L .3625 .51706 L p F P
0 g
s
.652 .759 .928 r
.89712 .51671 m .90933 .51301 L .91176 .51638 L p F P
0 g
s
.652 .759 .928 r
.90933 .51301 m .89712 .51671 L .89466 .51333 L p F P
0 g
s
.651 .758 .928 r
.71893 .51699 m .73083 .51331 L .73356 .51669 L p F P
0 g
s
.651 .758 .928 r
.73083 .51331 m .71893 .51699 L .71618 .5136 L p F P
0 g
s
.651 .758 .928 r
.54072 .51705 m .5523 .51339 L .55532 .51677 L p F P
0 g
s
.651 .758 .928 r
.5523 .51339 m .54072 .51705 L .53767 .51367 L p F P
0 g
s
.65 .757 .928 r
.3625 .51706 m .37376 .5134 L .37707 .51678 L p F P
0 g
s
.65 .757 .928 r
.37376 .5134 m .3625 .51706 L .35916 .51368 L p F P
0 g
s
.651 .758 .928 r
.73356 .51669 m .74548 .51302 L .74818 .5164 L p F P
0 g
s
.651 .758 .928 r
.74548 .51302 m .73356 .51669 L .73083 .51331 L p F P
0 g
s
.651 .758 .928 r
.55532 .51677 m .56693 .5131 L .56992 .51648 L p F P
0 g
s
.651 .758 .928 r
.56693 .5131 m .55532 .51677 L .5523 .51339 L p F P
0 g
s
.65 .757 .928 r
.37707 .51678 m .38836 .51312 L .39165 .5165 L p F P
0 g
s
.65 .757 .928 r
.38836 .51312 m .37707 .51678 L .37376 .5134 L p F P
0 g
s
.651 .758 .928 r
.74818 .5164 m .76014 .51272 L .76282 .5161 L p F P
0 g
s
.651 .758 .928 r
.76014 .51272 m .74818 .5164 L .74548 .51302 L p F P
0 g
s
.651 .758 .928 r
.56992 .51648 m .58156 .51281 L .58453 .5162 L p F P
0 g
s
.651 .758 .928 r
.58156 .51281 m .56992 .51648 L .56693 .5131 L p F P
0 g
s
.65 .758 .928 r
.39165 .5165 m .40297 .51283 L .40624 .51622 L p F P
0 g
s
.65 .758 .928 r
.40297 .51283 m .39165 .5165 L .38836 .51312 L p F P
0 g
s
.651 .758 .928 r
.76282 .5161 m .77479 .51242 L .77745 .51581 L p F P
0 g
s
.651 .758 .928 r
.77479 .51242 m .76282 .5161 L .76014 .51272 L p F P
0 g
s
.651 .758 .928 r
.58453 .5162 m .59619 .51253 L .59914 .51591 L p F P
0 g
s
.651 .758 .928 r
.59619 .51253 m .58453 .5162 L .58156 .51281 L p F P
0 g
s
.65 .758 .928 r
.40624 .51622 m .41758 .51255 L .42083 .51594 L p F P
0 g
s
.65 .758 .928 r
.41758 .51255 m .40624 .51622 L .40297 .51283 L p F P
0 g
s
.651 .758 .928 r
.77745 .51581 m .78946 .51212 L .79209 .51551 L p F P
0 g
s
.651 .758 .928 r
.78946 .51212 m .77745 .51581 L .77479 .51242 L p F P
0 g
s
.651 .758 .928 r
.59914 .51591 m .61083 .51224 L .61376 .51563 L p F P
0 g
s
.651 .758 .928 r
.61083 .51224 m .59914 .51591 L .59619 .51253 L p F P
0 g
s
.65 .758 .928 r
.42083 .51594 m .4322 .51227 L .43542 .51566 L p F P
0 g
s
.65 .758 .928 r
.4322 .51227 m .42083 .51594 L .41758 .51255 L p F P
0 g
s
.651 .758 .928 r
.79209 .51551 m .80412 .51182 L .80673 .51521 L p F P
0 g
s
.651 .758 .928 r
.80412 .51182 m .79209 .51551 L .78946 .51212 L p F P
0 g
s
.651 .758 .928 r
.61376 .51563 m .62548 .51195 L .62838 .51534 L p F P
0 g
s
.651 .758 .928 r
.62548 .51195 m .61376 .51563 L .61083 .51224 L p F P
0 g
s
.651 .758 .928 r
.43542 .51566 m .44682 .51198 L .45001 .51537 L p F P
0 g
s
.651 .758 .928 r
.44682 .51198 m .43542 .51566 L .4322 .51227 L p F P
0 g
s
.651 .758 .928 r
.80673 .51521 m .81879 .51152 L .82138 .5149 L p F P
0 g
s
.651 .758 .928 r
.81879 .51152 m .80673 .51521 L .80412 .51182 L p F P
0 g
s
.651 .758 .928 r
.62838 .51534 m .64012 .51167 L .643 .51505 L p F P
0 g
s
.651 .758 .928 r
.64012 .51167 m .62838 .51534 L .62548 .51195 L p F P
0 g
s
.65 .757 .928 r
.27165 .51537 m .28276 .5117 L .28622 .51509 L p F P
0 g
s
.651 .758 .928 r
.45001 .51537 m .46144 .5117 L .46461 .51509 L p F P
0 g
s
.651 .758 .928 r
.46144 .5117 m .45001 .51537 L .44682 .51198 L p F P
0 g
s
.651 .758 .928 r
.82138 .5149 m .83347 .51121 L .83603 .51459 L p F P
0 g
s
.651 .758 .928 r
.83347 .51121 m .82138 .5149 L .81879 .51152 L p F P
0 g
s
.651 .758 .928 r
.643 .51505 m .65478 .51138 L .65763 .51477 L p F P
0 g
s
.651 .758 .928 r
.65478 .51138 m .643 .51505 L .64012 .51167 L p F P
0 g
s
.65 .757 .928 r
.28622 .51509 m .29736 .51141 L .3008 .51481 L p F P
0 g
s
.65 .757 .928 r
.29736 .51141 m .28622 .51509 L .28276 .5117 L p F P
0 g
s
.651 .758 .928 r
.46461 .51509 m .47607 .51142 L .47922 .51481 L p F P
0 g
s
.651 .758 .928 r
.47607 .51142 m .46461 .51509 L .46144 .5117 L p F P
0 g
s
.651 .758 .928 r
.83603 .51459 m .84815 .5109 L .85068 .51428 L p F P
0 g
s
.651 .758 .928 r
.84815 .5109 m .83603 .51459 L .83347 .51121 L p F P
0 g
s
.651 .758 .928 r
.65763 .51477 m .66943 .51109 L .67226 .51448 L p F P
0 g
s
.651 .758 .928 r
.66943 .51109 m .65763 .51477 L .65478 .51138 L p F P
0 g
s
.65 .757 .928 r
.3008 .51481 m .31197 .51113 L .31539 .51452 L p F P
0 g
s
.65 .757 .928 r
.31197 .51113 m .3008 .51481 L .29736 .51141 L p F P
0 g
s
.651 .758 .928 r
.47922 .51481 m .4907 .51113 L .49383 .51452 L p F P
0 g
s
.651 .758 .928 r
.4907 .51113 m .47922 .51481 L .47607 .51142 L p F P
0 g
s
.651 .758 .928 r
.85068 .51428 m .86283 .51059 L .86534 .51397 L p F P
0 g
s
.651 .758 .928 r
.86283 .51059 m .85068 .51428 L .84815 .5109 L p F P
0 g
s
.651 .758 .928 r
.67226 .51448 m .68409 .5108 L .6869 .51419 L p F P
0 g
s
.651 .758 .928 r
.68409 .5108 m .67226 .51448 L .66943 .51109 L p F P
0 g
s
.651 .758 .928 r
.49383 .51452 m .50534 .51085 L .50844 .51424 L p F P
0 g
s
.651 .758 .928 r
.50534 .51085 m .49383 .51452 L .4907 .51113 L p F P
0 g
s
0 0 .277 r
.3979 .4062 m .39789 .40622 L .39803 .40108 L p F P
0 g
s
0 0 .277 r
.39803 .40108 m .39803 .40107 L .3979 .4062 L p F P
0 g
s
.763 .493 .526 r
.39787 .40621 m .39789 .40622 L .39803 .40108 L p F P
0 g
s
.763 .493 .526 r
.39803 .40108 m .398 .40108 L .39787 .40621 L p F P
0 g
s
.65 .757 .928 r
.31539 .51452 m .32658 .51085 L .32997 .51424 L p F P
0 g
s
.65 .757 .928 r
.32658 .51085 m .31539 .51452 L .31197 .51113 L p F P
0 g
s
.651 .758 .928 r
.86534 .51397 m .87751 .51027 L .88 .51365 L p F P
0 g
s
.651 .758 .928 r
.87751 .51027 m .86534 .51397 L .86283 .51059 L p F P
0 g
s
.651 .758 .928 r
.6869 .51419 m .69875 .51051 L .70154 .5139 L p F P
0 g
s
.651 .758 .928 r
.69875 .51051 m .6869 .51419 L .68409 .5108 L p F P
0 g
s
.651 .758 .928 r
.50844 .51424 m .51998 .51056 L .52305 .51396 L p F P
0 g
s
.651 .758 .928 r
.51998 .51056 m .50844 .51424 L .50534 .51085 L p F P
0 g
s
.65 .757 .928 r
.32997 .51424 m .34119 .51057 L .34457 .51396 L p F P
0 g
s
.65 .757 .928 r
.34119 .51057 m .32997 .51424 L .32658 .51085 L p F P
0 g
s
.651 .759 .928 r
.88 .51365 m .8922 .50995 L .89466 .51333 L p F P
0 g
s
.651 .759 .928 r
.8922 .50995 m .88 .51365 L .87751 .51027 L p F P
0 g
s
.651 .758 .928 r
.70154 .5139 m .71342 .51021 L .71618 .5136 L p F P
0 g
s
.651 .758 .928 r
.71342 .51021 m .70154 .5139 L .69875 .51051 L p F P
0 g
s
.651 .758 .928 r
.52305 .51396 m .53462 .51028 L .53767 .51367 L p F P
0 g
s
.651 .758 .928 r
.53462 .51028 m .52305 .51396 L .51998 .51056 L p F P
0 g
s
.65 .757 .928 r
.34457 .51396 m .35581 .51029 L .35916 .51368 L p F P
0 g
s
.65 .757 .928 r
.35581 .51029 m .34457 .51396 L .34119 .51057 L p F P
0 g
s
.652 .759 .928 r
.89466 .51333 m .90689 .50962 L .90933 .51301 L p F P
0 g
s
.652 .759 .928 r
.90689 .50962 m .89466 .51333 L .8922 .50995 L p F P
0 g
s
.651 .758 .928 r
.71618 .5136 m .72809 .50992 L .73083 .51331 L p F P
0 g
s
.651 .758 .928 r
.72809 .50992 m .71618 .5136 L .71342 .51021 L p F P
0 g
s
.651 .758 .928 r
.53767 .51367 m .54927 .50999 L .5523 .51339 L p F P
0 g
s
.651 .758 .928 r
.54927 .50999 m .53767 .51367 L .53462 .51028 L p F P
0 g
s
.65 .757 .928 r
.35916 .51368 m .37044 .51 L .37376 .5134 L p F P
0 g
s
.65 .757 .928 r
.37044 .51 m .35916 .51368 L .35581 .51029 L p F P
0 g
s
.651 .758 .928 r
.73083 .51331 m .74277 .50962 L .74548 .51302 L p F P
0 g
s
.651 .758 .928 r
.74277 .50962 m .73083 .51331 L .72809 .50992 L p F P
0 g
s
.651 .758 .928 r
.5523 .51339 m .56392 .5097 L .56693 .5131 L p F P
0 g
s
.651 .758 .928 r
.56392 .5097 m .5523 .51339 L .54927 .50999 L p F P
0 g
s
.65 .757 .928 r
.37376 .5134 m .38506 .50972 L .38836 .51312 L p F P
0 g
s
.65 .757 .928 r
.38506 .50972 m .37376 .5134 L .37044 .51 L p F P
0 g
s
.651 .758 .928 r
.74548 .51302 m .75745 .50933 L .76014 .51272 L p F P
0 g
s
.651 .758 .928 r
.75745 .50933 m .74548 .51302 L .74277 .50962 L p F P
0 g
s
.651 .758 .928 r
.56693 .5131 m .57857 .50942 L .58156 .51281 L p F P
0 g
s
.651 .758 .928 r
.57857 .50942 m .56693 .5131 L .56392 .5097 L p F P
0 g
s
.65 .758 .928 r
.38836 .51312 m .39969 .50944 L .40297 .51283 L p F P
0 g
s
.65 .757 .928 r
.39969 .50944 m .38836 .51312 L .38506 .50972 L p F P
0 g
s
.651 .758 .928 r
.76014 .51272 m .77213 .50903 L .77479 .51242 L p F P
0 g
s
.651 .758 .928 r
.77213 .50903 m .76014 .51272 L .75745 .50933 L p F P
0 g
s
.651 .758 .928 r
.58156 .51281 m .59323 .50913 L .59619 .51253 L p F P
0 g
s
.651 .758 .928 r
.59323 .50913 m .58156 .51281 L .57857 .50942 L p F P
0 g
s
.65 .758 .928 r
.40297 .51283 m .41433 .50915 L .41758 .51255 L p F P
0 g
s
.65 .758 .928 r
.41433 .50915 m .40297 .51283 L .39969 .50944 L p F P
0 g
s
.651 .758 .928 r
.77479 .51242 m .78682 .50873 L .78946 .51212 L p F P
0 g
s
.651 .758 .928 r
.78682 .50873 m .77479 .51242 L .77213 .50903 L p F P
0 g
s
.651 .758 .928 r
.59619 .51253 m .6079 .50884 L .61083 .51224 L p F P
0 g
s
.651 .758 .928 r
.6079 .50884 m .59619 .51253 L .59323 .50913 L p F P
0 g
s
.65 .758 .928 r
.41758 .51255 m .42897 .50887 L .4322 .51227 L p F P
0 g
s
.65 .758 .928 r
.42897 .50887 m .41758 .51255 L .41433 .50915 L p F P
0 g
s
.651 .758 .928 r
.78946 .51212 m .80151 .50843 L .80412 .51182 L p F P
0 g
s
.651 .758 .928 r
.80151 .50843 m .78946 .51212 L .78682 .50873 L p F P
0 g
s
.651 .758 .928 r
.61083 .51224 m .62256 .50856 L .62548 .51195 L p F P
0 g
s
.651 .758 .928 r
.62256 .50856 m .61083 .51224 L .6079 .50884 L p F P
0 g
s
.651 .758 .928 r
.4322 .51227 m .44361 .50859 L .44682 .51198 L p F P
0 g
s
.651 .758 .928 r
.44361 .50859 m .4322 .51227 L .42897 .50887 L p F P
0 g
s
.651 .758 .928 r
.80412 .51182 m .8162 .50812 L .81879 .51152 L p F P
0 g
s
.651 .758 .928 r
.8162 .50812 m .80412 .51182 L .80151 .50843 L p F P
0 g
s
.651 .758 .928 r
.62548 .51195 m .63724 .50827 L .64012 .51167 L p F P
0 g
s
.651 .758 .928 r
.63724 .50827 m .62548 .51195 L .62256 .50856 L p F P
0 g
s
.651 .758 .928 r
.44682 .51198 m .45826 .5083 L .46144 .5117 L p F P
0 g
s
.651 .758 .928 r
.45826 .5083 m .44682 .51198 L .44361 .50859 L p F P
0 g
s
.651 .758 .928 r
.81879 .51152 m .8309 .50782 L .83347 .51121 L p F P
0 g
s
.651 .758 .928 r
.8309 .50782 m .81879 .51152 L .8162 .50812 L p F P
0 g
s
.651 .758 .928 r
.64012 .51167 m .65191 .50798 L .65478 .51138 L p F P
0 g
s
.651 .758 .928 r
.65191 .50798 m .64012 .51167 L .63724 .50827 L p F P
0 g
s
.65 .757 .928 r
.28276 .5117 m .29391 .50801 L .29736 .51141 L p F P
0 g
s
0 0 .278 r
.39776 .41135 m .39775 .41137 L .39789 .40622 L p F P
0 g
s
0 0 .278 r
.39789 .40622 m .3979 .4062 L .39776 .41135 L p F P
0 g
s
.762 .493 .526 r
.39773 .41136 m .39775 .41137 L .39789 .40622 L p F P
0 g
s
.762 .493 .526 r
.39789 .40622 m .39787 .40621 L .39773 .41136 L p F P
0 g
s
.651 .758 .928 r
.46144 .5117 m .47291 .50802 L .47607 .51142 L p F P
0 g
s
.651 .758 .928 r
.47291 .50802 m .46144 .5117 L .45826 .5083 L p F P
0 g
s
.651 .758 .928 r
.83347 .51121 m .8456 .5075 L .84815 .5109 L p F P
0 g
s
.651 .758 .928 r
.8456 .5075 m .83347 .51121 L .8309 .50782 L p F P
0 g
s
.651 .758 .928 r
.65478 .51138 m .66659 .50769 L .66943 .51109 L p F P
0 g
s
.651 .758 .928 r
.66659 .50769 m .65478 .51138 L .65191 .50798 L p F P
0 g
s
.65 .757 .928 r
.29736 .51141 m .30854 .50773 L .31197 .51113 L p F P
0 g
s
.65 .757 .928 r
.30854 .50773 m .29736 .51141 L .29391 .50801 L p F P
0 g
s
.651 .758 .928 r
.47607 .51142 m .48757 .50773 L .4907 .51113 L p F P
0 g
s
.651 .758 .928 r
.48757 .50773 m .47607 .51142 L .47291 .50802 L p F P
0 g
s
.651 .758 .928 r
.84815 .5109 m .8603 .50719 L .86283 .51059 L p F P
0 g
s
.651 .758 .928 r
.8603 .50719 m .84815 .5109 L .8456 .5075 L p F P
0 g
s
.651 .758 .928 r
.66943 .51109 m .68127 .5074 L .68409 .5108 L p F P
0 g
s
.651 .758 .928 r
.68127 .5074 m .66943 .51109 L .66659 .50769 L p F P
0 g
s
.651 .758 .928 r
.4907 .51113 m .50222 .50744 L .50534 .51085 L p F P
0 g
s
.651 .758 .928 r
.50222 .50744 m .4907 .51113 L .48757 .50773 L p F P
0 g
s
.65 .757 .928 r
.31197 .51113 m .32317 .50745 L .32658 .51085 L p F P
0 g
s
.65 .757 .928 r
.32317 .50745 m .31197 .51113 L .30854 .50773 L p F P
0 g
s
.651 .758 .928 r
.86283 .51059 m .87501 .50687 L .87751 .51027 L p F P
0 g
s
.651 .758 .928 r
.87501 .50687 m .86283 .51059 L .8603 .50719 L p F P
0 g
s
.651 .758 .928 r
.68409 .5108 m .69596 .5071 L .69875 .51051 L p F P
0 g
s
.651 .758 .928 r
.69596 .5071 m .68409 .5108 L .68127 .5074 L p F P
0 g
s
.651 .758 .928 r
.50534 .51085 m .51689 .50716 L .51998 .51056 L p F P
0 g
s
.651 .758 .928 r
.51689 .50716 m .50534 .51085 L .50222 .50744 L p F P
0 g
s
.65 .757 .928 r
.32658 .51085 m .33781 .50716 L .34119 .51057 L p F P
0 g
s
.65 .757 .928 r
.33781 .50716 m .32658 .51085 L .32317 .50745 L p F P
0 g
s
.651 .759 .928 r
.87751 .51027 m .88972 .50655 L .8922 .50995 L p F P
0 g
s
.651 .759 .928 r
.88972 .50655 m .87751 .51027 L .87501 .50687 L p F P
0 g
s
.651 .758 .928 r
.69875 .51051 m .71065 .50681 L .71342 .51021 L p F P
0 g
s
.651 .758 .928 r
.71065 .50681 m .69875 .51051 L .69596 .5071 L p F P
0 g
s
.651 .758 .928 r
.51998 .51056 m .53156 .50687 L .53462 .51028 L p F P
0 g
s
.651 .758 .928 r
.53156 .50687 m .51998 .51056 L .51689 .50716 L p F P
0 g
s
.65 .757 .928 r
.34119 .51057 m .35245 .50688 L .35581 .51029 L p F P
0 g
s
.65 .757 .928 r
.35245 .50688 m .34119 .51057 L .33781 .50716 L p F P
0 g
s
.652 .759 .928 r
.8922 .50995 m .90444 .50623 L .90689 .50962 L p F P
0 g
s
.652 .759 .928 r
.90444 .50623 m .8922 .50995 L .88972 .50655 L p F P
0 g
s
.651 .758 .928 r
.71342 .51021 m .72535 .50652 L .72809 .50992 L p F P
0 g
s
.651 .758 .928 r
.72535 .50652 m .71342 .51021 L .71065 .50681 L p F P
0 g
s
.651 .758 .928 r
.53462 .51028 m .54623 .50659 L .54927 .50999 L p F P
0 g
s
.651 .758 .928 r
.54623 .50659 m .53462 .51028 L .53156 .50687 L p F P
0 g
s
.65 .757 .928 r
.35581 .51029 m .3671 .5066 L .37044 .51 L p F P
0 g
s
.65 .757 .928 r
.3671 .5066 m .35581 .51029 L .35245 .50688 L p F P
0 g
s
.651 .758 .928 r
.72809 .50992 m .74005 .50622 L .74277 .50962 L p F P
0 g
s
.651 .758 .928 r
.74005 .50622 m .72809 .50992 L .72535 .50652 L p F P
0 g
s
.651 .758 .928 r
.54927 .50999 m .5609 .5063 L .56392 .5097 L p F P
0 g
s
.651 .758 .928 r
.5609 .5063 m .54927 .50999 L .54623 .50659 L p F P
0 g
s
.65 .757 .928 r
.37044 .51 m .38175 .50631 L .38506 .50972 L p F P
0 g
s
.65 .757 .928 r
.38175 .50631 m .37044 .51 L .3671 .5066 L p F P
0 g
s
.651 .758 .928 r
.74277 .50962 m .75475 .50592 L .75745 .50933 L p F P
0 g
s
.651 .758 .928 r
.75475 .50592 m .74277 .50962 L .74005 .50622 L p F P
0 g
s
.651 .758 .928 r
.56392 .5097 m .57558 .50601 L .57857 .50942 L p F P
0 g
s
.651 .758 .928 r
.57558 .50601 m .56392 .5097 L .5609 .5063 L p F P
0 g
s
.65 .757 .928 r
.38506 .50972 m .39641 .50603 L .39969 .50944 L p F P
0 g
s
.65 .757 .928 r
.39641 .50603 m .38506 .50972 L .38175 .50631 L p F P
0 g
s
.651 .758 .928 r
.75745 .50933 m .76946 .50562 L .77213 .50903 L p F P
0 g
s
.651 .758 .928 r
.76946 .50562 m .75745 .50933 L .75475 .50592 L p F P
0 g
s
.651 .758 .928 r
.57857 .50942 m .59026 .50572 L .59323 .50913 L p F P
0 g
s
.651 .758 .928 r
.59026 .50572 m .57857 .50942 L .57558 .50601 L p F P
0 g
s
.65 .758 .928 r
.39969 .50944 m .41106 .50574 L .41433 .50915 L p F P
0 g
s
.65 .758 .928 r
.41106 .50574 m .39969 .50944 L .39641 .50603 L p F P
0 g
s
.651 .758 .928 r
.77213 .50903 m .78417 .50532 L .78682 .50873 L p F P
0 g
s
.651 .758 .928 r
.78417 .50532 m .77213 .50903 L .76946 .50562 L p F P
0 g
s
.651 .758 .928 r
.59323 .50913 m .60495 .50543 L .6079 .50884 L p F P
0 g
s
.651 .758 .928 r
.60495 .50543 m .59323 .50913 L .59026 .50572 L p F P
0 g
s
.65 .758 .928 r
.41433 .50915 m .42573 .50546 L .42897 .50887 L p F P
0 g
s
.65 .758 .928 r
.42573 .50546 m .41433 .50915 L .41106 .50574 L p F P
0 g
s
.651 .758 .928 r
.78682 .50873 m .79888 .50502 L .80151 .50843 L p F P
0 g
s
.651 .758 .928 r
.79888 .50502 m .78682 .50873 L .78417 .50532 L p F P
0 g
s
.651 .758 .928 r
.6079 .50884 m .61964 .50515 L .62256 .50856 L p F P
0 g
s
.651 .758 .928 r
.61964 .50515 m .6079 .50884 L .60495 .50543 L p F P
0 g
s
0 0 .279 r
.39762 .41652 m .39762 .41653 L .39775 .41137 L p F P
0 g
s
0 0 .279 r
.39775 .41137 m .39776 .41135 L .39762 .41652 L p F P
0 g
s
.762 .493 .526 r
.3976 .41652 m .39762 .41653 L .39775 .41137 L p F P
0 g
s
.762 .493 .526 r
.39775 .41137 m .39773 .41136 L .3976 .41652 L p F P
0 g
s
.651 .758 .928 r
.42897 .50887 m .44039 .50517 L .44361 .50859 L p F P
0 g
s
.651 .758 .928 r
.44039 .50517 m .42897 .50887 L .42573 .50546 L p F P
0 g
s
.651 .758 .928 r
.80151 .50843 m .8136 .50472 L .8162 .50812 L p F P
0 g
s
.651 .758 .928 r
.8136 .50472 m .80151 .50843 L .79888 .50502 L p F P
0 g
s
.651 .758 .928 r
.63434 .50486 m .62256 .50856 L .61964 .50515 L p F P
0 g
s
.651 .758 .928 r
.62256 .50856 m .63434 .50486 L .63724 .50827 L p F P
0 g
s
.651 .758 .928 r
.44361 .50859 m .45507 .50489 L .45826 .5083 L p F P
0 g
s
.651 .758 .928 r
.45507 .50489 m .44361 .50859 L .44039 .50517 L p F P
0 g
s
.651 .758 .928 r
.8162 .50812 m .82832 .50441 L .8309 .50782 L p F P
0 g
s
.651 .758 .928 r
.82832 .50441 m .8162 .50812 L .8136 .50472 L p F P
0 g
s
.651 .758 .928 r
.63724 .50827 m .64904 .50457 L .65191 .50798 L p F P
0 g
s
.651 .758 .928 r
.64904 .50457 m .63724 .50827 L .63434 .50486 L p F P
0 g
s
.651 .758 .928 r
.45826 .5083 m .46974 .5046 L .47291 .50802 L p F P
0 g
s
.651 .758 .928 r
.46974 .5046 m .45826 .5083 L .45507 .50489 L p F P
0 g
s
.651 .758 .928 r
.8309 .50782 m .84305 .5041 L .8456 .5075 L p F P
0 g
s
.651 .758 .928 r
.84305 .5041 m .8309 .50782 L .82832 .50441 L p F P
0 g
s
.651 .758 .928 r
.65191 .50798 m .66374 .50427 L .66659 .50769 L p F P
0 g
s
.651 .758 .928 r
.66374 .50427 m .65191 .50798 L .64904 .50457 L p F P
0 g
s
.65 .757 .928 r
.29391 .50801 m .3051 .50432 L .30854 .50773 L p F P
0 g
s
.651 .758 .928 r
.47291 .50802 m .48442 .50432 L .48757 .50773 L p F P
0 g
s
.651 .758 .928 r
.48442 .50432 m .47291 .50802 L .46974 .5046 L p F P
0 g
s
.651 .758 .928 r
.8456 .5075 m .85777 .50378 L .8603 .50719 L p F P
0 g
s
.651 .758 .928 r
.85777 .50378 m .8456 .5075 L .84305 .5041 L p F P
0 g
s
.651 .758 .928 r
.66659 .50769 m .67845 .50398 L .68127 .5074 L p F P
0 g
s
.651 .758 .928 r
.67845 .50398 m .66659 .50769 L .66374 .50427 L p F P
0 g
s
.651 .758 .928 r
.48757 .50773 m .4991 .50403 L .50222 .50744 L p F P
0 g
s
.651 .758 .928 r
.4991 .50403 m .48757 .50773 L .48442 .50432 L p F P
0 g
s
.65 .757 .928 r
.30854 .50773 m .31976 .50403 L .32317 .50745 L p F P
0 g
s
.65 .757 .928 r
.31976 .50403 m .30854 .50773 L .3051 .50432 L p F P
0 g
s
.651 .758 .928 r
.8603 .50719 m .87251 .50347 L .87501 .50687 L p F P
0 g
s
.651 .758 .928 r
.87251 .50347 m .8603 .50719 L .85777 .50378 L p F P
0 g
s
.651 .758 .928 r
.68127 .5074 m .69316 .50369 L .69596 .5071 L p F P
0 g
s
.651 .758 .928 r
.69316 .50369 m .68127 .5074 L .67845 .50398 L p F P
0 g
s
.651 .758 .928 r
.50222 .50744 m .51379 .50374 L .51689 .50716 L p F P
0 g
s
.651 .758 .928 r
.51379 .50374 m .50222 .50744 L .4991 .50403 L p F P
0 g
s
.65 .757 .928 r
.32317 .50745 m .33442 .50375 L .33781 .50716 L p F P
0 g
s
.65 .757 .928 r
.33442 .50375 m .32317 .50745 L .31976 .50403 L p F P
0 g
s
.651 .759 .928 r
.87501 .50687 m .88724 .50315 L .88972 .50655 L p F P
0 g
s
.651 .758 .928 r
.88724 .50315 m .87501 .50687 L .87251 .50347 L p F P
0 g
s
.651 .758 .928 r
.69596 .5071 m .70787 .5034 L .71065 .50681 L p F P
0 g
s
.651 .758 .928 r
.70787 .5034 m .69596 .5071 L .69316 .50369 L p F P
0 g
s
.651 .758 .928 r
.51689 .50716 m .52848 .50346 L .53156 .50687 L p F P
0 g
s
.651 .758 .928 r
.52848 .50346 m .51689 .50716 L .51379 .50374 L p F P
0 g
s
.65 .757 .928 r
.33781 .50716 m .34908 .50346 L .35245 .50688 L p F P
0 g
s
.65 .757 .928 r
.34908 .50346 m .33781 .50716 L .33442 .50375 L p F P
0 g
s
.652 .759 .928 r
.88972 .50655 m .90198 .50282 L .90444 .50623 L p F P
0 g
s
.652 .759 .928 r
.90198 .50282 m .88972 .50655 L .88724 .50315 L p F P
0 g
s
.651 .758 .928 r
.71065 .50681 m .72259 .5031 L .72535 .50652 L p F P
0 g
s
.651 .758 .928 r
.72259 .5031 m .71065 .50681 L .70787 .5034 L p F P
0 g
s
.651 .758 .928 r
.53156 .50687 m .54318 .50317 L .54623 .50659 L p F P
0 g
s
.651 .758 .928 r
.54318 .50317 m .53156 .50687 L .52848 .50346 L p F P
0 g
s
.65 .757 .928 r
.35245 .50688 m .36375 .50318 L .3671 .5066 L p F P
0 g
s
.65 .757 .928 r
.36375 .50318 m .35245 .50688 L .34908 .50346 L p F P
0 g
s
.651 .758 .928 r
.72535 .50652 m .73732 .5028 L .74005 .50622 L p F P
0 g
s
.651 .758 .928 r
.73732 .5028 m .72535 .50652 L .72259 .5031 L p F P
0 g
s
.651 .758 .928 r
.54623 .50659 m .55787 .50288 L .5609 .5063 L p F P
0 g
s
.651 .758 .928 r
.55787 .50288 m .54623 .50659 L .54318 .50317 L p F P
0 g
s
.65 .757 .928 r
.3671 .5066 m .37843 .5029 L .38175 .50631 L p F P
0 g
s
.65 .757 .928 r
.37843 .5029 m .3671 .5066 L .36375 .50318 L p F P
0 g
s
.651 .758 .928 r
.74005 .50622 m .75204 .50251 L .75475 .50592 L p F P
0 g
s
.651 .758 .928 r
.75204 .50251 m .74005 .50622 L .73732 .5028 L p F P
0 g
s
.651 .758 .928 r
.5609 .5063 m .57258 .50259 L .57558 .50601 L p F P
0 g
s
.651 .758 .928 r
.57258 .50259 m .5609 .5063 L .55787 .50288 L p F P
0 g
s
.65 .757 .928 r
.38175 .50631 m .39311 .50261 L .39641 .50603 L p F P
0 g
s
.65 .757 .928 r
.39311 .50261 m .38175 .50631 L .37843 .5029 L p F P
0 g
s
.651 .758 .928 r
.75475 .50592 m .76677 .50221 L .76946 .50562 L p F P
0 g
s
.651 .758 .928 r
.76677 .50221 m .75475 .50592 L .75204 .50251 L p F P
0 g
s
.651 .758 .928 r
.57558 .50601 m .58729 .5023 L .59026 .50572 L p F P
0 g
s
.651 .758 .928 r
.58729 .5023 m .57558 .50601 L .57258 .50259 L p F P
0 g
s
0 0 .28 r
.39748 .42169 m .39748 .4217 L .39762 .41653 L p F P
0 g
s
0 0 .28 r
.39762 .41653 m .39762 .41652 L .39748 .42169 L p F P
0 g
s
.762 .492 .526 r
.39746 .4217 m .39748 .4217 L .39762 .41653 L p F P
0 g
s
.762 .492 .526 r
.39762 .41653 m .3976 .41652 L .39746 .4217 L p F P
0 g
s
.65 .758 .928 r
.39641 .50603 m .40779 .50232 L .41106 .50574 L p F P
0 g
s
.65 .758 .928 r
.40779 .50232 m .39641 .50603 L .39311 .50261 L p F P
0 g
s
.651 .758 .928 r
.76946 .50562 m .78151 .50191 L .78417 .50532 L p F P
0 g
s
.651 .758 .928 r
.78151 .50191 m .76946 .50562 L .76677 .50221 L p F P
0 g
s
.651 .758 .928 r
.59026 .50572 m .602 .50201 L .60495 .50543 L p F P
0 g
s
.651 .758 .928 r
.602 .50201 m .59026 .50572 L .58729 .5023 L p F P
0 g
s
.65 .758 .928 r
.41106 .50574 m .42248 .50204 L .42573 .50546 L p F P
0 g
s
.65 .758 .928 r
.42248 .50204 m .41106 .50574 L .40779 .50232 L p F P
0 g
s
.651 .758 .928 r
.78417 .50532 m .79625 .5016 L .79888 .50502 L p F P
0 g
s
.651 .758 .928 r
.79625 .5016 m .78417 .50532 L .78151 .50191 L p F P
0 g
s
.651 .758 .928 r
.60495 .50543 m .61671 .50172 L .61964 .50515 L p F P
0 g
s
.651 .758 .928 r
.61671 .50172 m .60495 .50543 L .602 .50201 L p F P
0 g
s
.651 .758 .928 r
.42573 .50546 m .43717 .50175 L .44039 .50517 L p F P
0 g
s
.651 .758 .928 r
.43717 .50175 m .42573 .50546 L .42248 .50204 L p F P
0 g
s
.651 .758 .928 r
.79888 .50502 m .81099 .5013 L .8136 .50472 L p F P
0 g
s
.651 .758 .928 r
.81099 .5013 m .79888 .50502 L .79625 .5016 L p F P
0 g
s
.651 .758 .928 r
.61964 .50515 m .63143 .50143 L .63434 .50486 L p F P
0 g
s
.651 .758 .928 r
.63143 .50143 m .61964 .50515 L .61671 .50172 L p F P
0 g
s
.651 .758 .928 r
.44039 .50517 m .45186 .50147 L .45507 .50489 L p F P
0 g
s
.651 .758 .928 r
.45186 .50147 m .44039 .50517 L .43717 .50175 L p F P
0 g
s
.651 .758 .928 r
.8136 .50472 m .82573 .50099 L .82832 .50441 L p F P
0 g
s
.651 .758 .928 r
.82573 .50099 m .8136 .50472 L .81099 .5013 L p F P
0 g
s
.651 .758 .928 r
.63434 .50486 m .64615 .50114 L .64904 .50457 L p F P
0 g
s
.651 .758 .928 r
.64615 .50114 m .63434 .50486 L .63143 .50143 L p F P
0 g
s
.651 .758 .928 r
.45507 .50489 m .46656 .50118 L .46974 .5046 L p F P
0 g
s
.651 .758 .928 r
.46656 .50118 m .45507 .50489 L .45186 .50147 L p F P
0 g
s
.651 .758 .928 r
.82832 .50441 m .84048 .50068 L .84305 .5041 L p F P
0 g
s
.651 .758 .928 r
.84048 .50068 m .82832 .50441 L .82573 .50099 L p F P
0 g
s
.651 .758 .928 r
.64904 .50457 m .66088 .50085 L .66374 .50427 L p F P
0 g
s
.651 .758 .928 r
.66088 .50085 m .64904 .50457 L .64615 .50114 L p F P
0 g
s
.651 .758 .928 r
.46974 .5046 m .48126 .50089 L .48442 .50432 L p F P
0 g
s
.651 .758 .928 r
.48126 .50089 m .46974 .5046 L .46656 .50118 L p F P
0 g
s
.651 .758 .928 r
.84305 .5041 m .85524 .50036 L .85777 .50378 L p F P
0 g
s
.651 .758 .928 r
.85524 .50036 m .84305 .5041 L .84048 .50068 L p F P
0 g
s
.651 .758 .928 r
.66374 .50427 m .67561 .50056 L .67845 .50398 L p F P
0 g
s
.651 .758 .928 r
.67561 .50056 m .66374 .50427 L .66088 .50085 L p F P
0 g
s
.65 .757 .928 r
.3051 .50432 m .31633 .50061 L .31976 .50403 L p F P
0 g
s
.651 .758 .928 r
.48442 .50432 m .49597 .5006 L .4991 .50403 L p F P
0 g
s
.651 .758 .928 r
.49597 .5006 m .48442 .50432 L .48126 .50089 L p F P
0 g
s
.651 .758 .928 r
.85777 .50378 m .86999 .50005 L .87251 .50347 L p F P
0 g
s
.651 .758 .928 r
.86999 .50005 m .85777 .50378 L .85524 .50036 L p F P
0 g
s
.651 .758 .928 r
.67845 .50398 m .69035 .50026 L .69316 .50369 L p F P
0 g
s
.651 .758 .928 r
.69035 .50026 m .67845 .50398 L .67561 .50056 L p F P
0 g
s
.651 .758 .928 r
.4991 .50403 m .51068 .50032 L .51379 .50374 L p F P
0 g
s
.651 .758 .928 r
.51068 .50032 m .4991 .50403 L .49597 .5006 L p F P
0 g
s
.65 .757 .928 r
.31976 .50403 m .33101 .50032 L .33442 .50375 L p F P
0 g
s
.65 .757 .928 r
.33101 .50032 m .31976 .50403 L .31633 .50061 L p F P
0 g
s
.651 .758 .928 r
.87251 .50347 m .88475 .49973 L .88724 .50315 L p F P
0 g
s
.651 .758 .928 r
.88475 .49973 m .87251 .50347 L .86999 .50005 L p F P
0 g
s
.651 .758 .928 r
.69316 .50369 m .70509 .49997 L .70787 .5034 L p F P
0 g
s
.651 .758 .928 r
.70509 .49997 m .69316 .50369 L .69035 .50026 L p F P
0 g
s
.651 .758 .928 r
.51379 .50374 m .5254 .50003 L .52848 .50346 L p F P
0 g
s
.651 .758 .928 r
.5254 .50003 m .51379 .50374 L .51068 .50032 L p F P
0 g
s
.65 .757 .928 r
.33442 .50375 m .3457 .50004 L .34908 .50346 L p F P
0 g
s
.65 .757 .928 r
.3457 .50004 m .33442 .50375 L .33101 .50032 L p F P
0 g
s
.652 .759 .928 r
.88724 .50315 m .89952 .4994 L .90198 .50282 L p F P
0 g
s
.652 .759 .928 r
.89952 .4994 m .88724 .50315 L .88475 .49973 L p F P
0 g
s
.651 .758 .928 r
.70787 .5034 m .71983 .49967 L .72259 .5031 L p F P
0 g
s
.651 .758 .928 r
.71983 .49967 m .70787 .5034 L .70509 .49997 L p F P
0 g
s
.651 .758 .928 r
.52848 .50346 m .54011 .49974 L .54318 .50317 L p F P
0 g
s
.651 .758 .928 r
.54011 .49974 m .52848 .50346 L .5254 .50003 L p F P
0 g
s
.65 .757 .928 r
.34908 .50346 m .3604 .49975 L .36375 .50318 L p F P
0 g
s
.65 .757 .928 r
.3604 .49975 m .34908 .50346 L .3457 .50004 L p F P
0 g
s
.651 .758 .928 r
.72259 .5031 m .73458 .49938 L .73732 .5028 L p F P
0 g
s
.651 .758 .928 r
.73458 .49938 m .72259 .5031 L .71983 .49967 L p F P
0 g
s
.651 .758 .928 r
.54318 .50317 m .55484 .49945 L .55787 .50288 L p F P
0 g
s
.651 .758 .928 r
.55484 .49945 m .54318 .50317 L .54011 .49974 L p F P
0 g
s
0 0 .281 r
.39734 .42688 m .39734 .4269 L .39748 .4217 L p F P
0 g
s
0 0 .281 r
.39748 .4217 m .39748 .42169 L .39734 .42688 L p F P
0 g
s
.761 .492 .526 r
.39732 .42689 m .39734 .4269 L .39748 .4217 L p F P
0 g
s
.761 .492 .526 r
.39748 .4217 m .39746 .4217 L .39732 .42689 L p F P
0 g
s
.65 .757 .928 r
.36375 .50318 m .37509 .49947 L .37843 .5029 L p F P
0 g
s
.65 .757 .928 r
.37509 .49947 m .36375 .50318 L .3604 .49975 L p F P
0 g
s
.651 .758 .928 r
.73732 .5028 m .74933 .49908 L .75204 .50251 L p F P
0 g
s
.651 .758 .928 r
.74933 .49908 m .73732 .5028 L .73458 .49938 L p F P
0 g
s
.651 .758 .928 r
.55787 .50288 m .56957 .49916 L .57258 .50259 L p F P
0 g
s
.651 .758 .928 r
.56957 .49916 m .55787 .50288 L .55484 .49945 L p F P
0 g
s
.65 .757 .928 r
.37843 .5029 m .3898 .49918 L .39311 .50261 L p F P
0 g
s
.65 .757 .928 r
.3898 .49918 m .37843 .5029 L .37509 .49947 L p F P
0 g
s
.651 .758 .928 r
.75204 .50251 m .76408 .49878 L .76677 .50221 L p F P
0 g
s
.651 .758 .928 r
.76408 .49878 m .75204 .50251 L .74933 .49908 L p F P
0 g
s
.651 .758 .928 r
.57258 .50259 m .5843 .49887 L .58729 .5023 L p F P
0 g
s
.651 .758 .928 r
.5843 .49887 m .57258 .50259 L .56957 .49916 L p F P
0 g
s
.65 .758 .928 r
.39311 .50261 m .4045 .49889 L .40779 .50232 L p F P
0 g
s
.65 .757 .928 r
.4045 .49889 m .39311 .50261 L .3898 .49918 L p F P
0 g
s
.651 .758 .928 r
.76677 .50221 m .77884 .49848 L .78151 .50191 L p F P
0 g
s
.651 .758 .928 r
.77884 .49848 m .76677 .50221 L .76408 .49878 L p F P
0 g
s
.651 .758 .928 r
.58729 .5023 m .59903 .49858 L .602 .50201 L p F P
0 g
s
.651 .758 .928 r
.59903 .49858 m .58729 .5023 L .5843 .49887 L p F P
0 g
s
.65 .758 .928 r
.40779 .50232 m .41921 .49861 L .42248 .50204 L p F P
0 g
s
.65 .758 .928 r
.41921 .49861 m .40779 .50232 L .4045 .49889 L p F P
0 g
s
.651 .758 .928 r
.78151 .50191 m .7936 .49817 L .79625 .5016 L p F P
0 g
s
.651 .758 .928 r
.7936 .49817 m .78151 .50191 L .77884 .49848 L p F P
0 g
s
.651 .758 .928 r
.602 .50201 m .61377 .49829 L .61671 .50172 L p F P
0 g
s
.651 .758 .928 r
.61377 .49829 m .602 .50201 L .59903 .49858 L p F P
0 g
s
.651 .758 .928 r
.42248 .50204 m .43393 .49832 L .43717 .50175 L p F P
0 g
s
.651 .758 .928 r
.43393 .49832 m .42248 .50204 L .41921 .49861 L p F P
0 g
s
.651 .758 .928 r
.79625 .5016 m .80837 .49787 L .81099 .5013 L p F P
0 g
s
.651 .758 .928 r
.80837 .49787 m .79625 .5016 L .7936 .49817 L p F P
0 g
s
.651 .758 .928 r
.61671 .50172 m .62851 .498 L .63143 .50143 L p F P
0 g
s
.651 .758 .928 r
.62851 .498 m .61671 .50172 L .61377 .49829 L p F P
0 g
s
.651 .758 .928 r
.43717 .50175 m .44865 .49803 L .45186 .50147 L p F P
0 g
s
.651 .758 .928 r
.44865 .49803 m .43717 .50175 L .43393 .49832 L p F P
0 g
s
.651 .758 .928 r
.81099 .5013 m .82314 .49756 L .82573 .50099 L p F P
0 g
s
.651 .758 .928 r
.82314 .49756 m .81099 .5013 L .80837 .49787 L p F P
0 g
s
.651 .758 .928 r
.63143 .50143 m .64326 .49771 L .64615 .50114 L p F P
0 g
s
.651 .758 .928 r
.64326 .49771 m .63143 .50143 L .62851 .498 L p F P
0 g
s
.651 .758 .928 r
.45186 .50147 m .46337 .49774 L .46656 .50118 L p F P
0 g
s
.651 .758 .928 r
.46337 .49774 m .45186 .50147 L .44865 .49803 L p F P
0 g
s
.651 .758 .928 r
.82573 .50099 m .83791 .49725 L .84048 .50068 L p F P
0 g
s
.651 .758 .928 r
.83791 .49725 m .82573 .50099 L .82314 .49756 L p F P
0 g
s
.651 .758 .928 r
.65801 .49742 m .64615 .50114 L .64326 .49771 L p F P
0 g
s
.651 .758 .928 r
.64615 .50114 m .65801 .49742 L .66088 .50085 L p F P
0 g
s
.651 .758 .928 r
.46656 .50118 m .4781 .49746 L .48126 .50089 L p F P
0 g
s
.651 .758 .928 r
.4781 .49746 m .46656 .50118 L .46337 .49774 L p F P
0 g
s
.651 .758 .928 r
.84048 .50068 m .85269 .49693 L .85524 .50036 L p F P
0 g
s
.651 .758 .928 r
.85269 .49693 m .84048 .50068 L .83791 .49725 L p F P
0 g
s
.651 .758 .928 r
.66088 .50085 m .67277 .49712 L .67561 .50056 L p F P
0 g
s
.651 .758 .928 r
.67277 .49712 m .66088 .50085 L .65801 .49742 L p F P
0 g
s
.651 .758 .928 r
.48126 .50089 m .49283 .49717 L .49597 .5006 L p F P
0 g
s
.651 .758 .928 r
.49283 .49717 m .48126 .50089 L .4781 .49746 L p F P
0 g
s
.651 .758 .928 r
.85524 .50036 m .86747 .49662 L .86999 .50005 L p F P
0 g
s
.651 .758 .928 r
.86747 .49662 m .85524 .50036 L .85269 .49693 L p F P
0 g
s
.651 .758 .928 r
.67561 .50056 m .68753 .49683 L .69035 .50026 L p F P
0 g
s
.651 .758 .928 r
.68753 .49683 m .67561 .50056 L .67277 .49712 L p F P
0 g
s
.651 .758 .928 r
.49597 .5006 m .50756 .49688 L .51068 .50032 L p F P
0 g
s
.651 .758 .928 r
.50756 .49688 m .49597 .5006 L .49283 .49717 L p F P
0 g
s
.65 .757 .928 r
.31633 .50061 m .3276 .49688 L .33101 .50032 L p F P
0 g
s
.651 .758 .928 r
.86999 .50005 m .88225 .4963 L .88475 .49973 L p F P
0 g
s
.651 .758 .928 r
.88225 .4963 m .86999 .50005 L .86747 .49662 L p F P
0 g
s
.651 .758 .928 r
.69035 .50026 m .70229 .49653 L .70509 .49997 L p F P
0 g
s
.651 .758 .928 r
.70229 .49653 m .69035 .50026 L .68753 .49683 L p F P
0 g
s
.651 .758 .928 r
.51068 .50032 m .5223 .49659 L .5254 .50003 L p F P
0 g
s
.651 .758 .928 r
.5223 .49659 m .51068 .50032 L .50756 .49688 L p F P
0 g
s
0 0 .283 r
.39721 .43209 m .3972 .4321 L .39734 .4269 L p F P
0 g
s
0 0 .283 r
.39734 .4269 m .39734 .42688 L .39721 .43209 L p F P
0 g
s
.761 .492 .526 r
.39718 .4321 m .3972 .4321 L .39734 .4269 L p F P
0 g
s
.761 .492 .526 r
.39734 .4269 m .39732 .42689 L .39718 .4321 L p F P
0 g
s
.65 .757 .928 r
.33101 .50032 m .34231 .4966 L .3457 .50004 L p F P
0 g
s
.65 .757 .928 r
.34231 .4966 m .33101 .50032 L .3276 .49688 L p F P
0 g
s
.652 .759 .928 r
.88475 .49973 m .89704 .49597 L .89952 .4994 L p F P
0 g
s
.652 .759 .928 r
.89704 .49597 m .88475 .49973 L .88225 .4963 L p F P
0 g
s
.651 .758 .928 r
.70509 .49997 m .71706 .49624 L .71983 .49967 L p F P
0 g
s
.651 .758 .928 r
.71706 .49624 m .70509 .49997 L .70229 .49653 L p F P
0 g
s
.651 .758 .928 r
.5254 .50003 m .53704 .4963 L .54011 .49974 L p F P
0 g
s
.651 .758 .928 r
.53704 .4963 m .5254 .50003 L .5223 .49659 L p F P
0 g
s
.65 .757 .928 r
.3457 .50004 m .35703 .49631 L .3604 .49975 L p F P
0 g
s
.65 .757 .928 r
.35703 .49631 m .3457 .50004 L .34231 .4966 L p F P
0 g
s
.651 .758 .928 r
.71983 .49967 m .73183 .49594 L .73458 .49938 L p F P
0 g
s
.651 .758 .928 r
.73183 .49594 m .71983 .49967 L .71706 .49624 L p F P
0 g
s
.651 .758 .928 r
.54011 .49974 m .55179 .49601 L .55484 .49945 L p F P
0 g
s
.651 .758 .928 r
.55179 .49601 m .54011 .49974 L .53704 .4963 L p F P
0 g
s
.65 .757 .928 r
.3604 .49975 m .37175 .49602 L .37509 .49947 L p F P
0 g
s
.65 .757 .928 r
.37175 .49602 m .3604 .49975 L .35703 .49631 L p F P
0 g
s
.651 .758 .928 r
.73458 .49938 m .7466 .49564 L .74933 .49908 L p F P
0 g
s
.651 .758 .928 r
.7466 .49564 m .73458 .49938 L .73183 .49594 L p F P
0 g
s
.651 .758 .928 r
.55484 .49945 m .56654 .49572 L .56957 .49916 L p F P
0 g
s
.651 .758 .928 r
.56654 .49572 m .55484 .49945 L .55179 .49601 L p F P
0 g
s
.65 .757 .928 r
.37509 .49947 m .38648 .49574 L .3898 .49918 L p F P
0 g
s
.65 .757 .928 r
.38648 .49574 m .37509 .49947 L .37175 .49602 L p F P
0 g
s
.651 .758 .928 r
.74933 .49908 m .76138 .49534 L .76408 .49878 L p F P
0 g
s
.651 .758 .928 r
.76138 .49534 m .74933 .49908 L .7466 .49564 L p F P
0 g
s
.651 .758 .928 r
.56957 .49916 m .5813 .49543 L .5843 .49887 L p F P
0 g
s
.651 .758 .928 r
.5813 .49543 m .56957 .49916 L .56654 .49572 L p F P
0 g
s
.65 .757 .928 r
.3898 .49918 m .40121 .49545 L .4045 .49889 L p F P
0 g
s
.65 .757 .928 r
.40121 .49545 m .3898 .49918 L .38648 .49574 L p F P
0 g
s
.651 .758 .928 r
.76408 .49878 m .77616 .49504 L .77884 .49848 L p F P
0 g
s
.651 .758 .928 r
.77616 .49504 m .76408 .49878 L .76138 .49534 L p F P
0 g
s
.651 .758 .928 r
.5843 .49887 m .59606 .49514 L .59903 .49858 L p F P
0 g
s
.651 .758 .928 r
.59606 .49514 m .5843 .49887 L .5813 .49543 L p F P
0 g
s
.65 .758 .928 r
.4045 .49889 m .41594 .49516 L .41921 .49861 L p F P
0 g
s
.65 .758 .928 r
.41594 .49516 m .4045 .49889 L .40121 .49545 L p F P
0 g
s
.651 .758 .928 r
.77884 .49848 m .79095 .49473 L .7936 .49817 L p F P
0 g
s
.651 .758 .928 r
.79095 .49473 m .77884 .49848 L .77616 .49504 L p F P
0 g
s
.651 .758 .928 r
.59903 .49858 m .61082 .49485 L .61377 .49829 L p F P
0 g
s
.651 .758 .928 r
.61082 .49485 m .59903 .49858 L .59606 .49514 L p F P
0 g
s
.651 .758 .928 r
.41921 .49861 m .43068 .49487 L .43393 .49832 L p F P
0 g
s
.651 .758 .928 r
.43068 .49487 m .41921 .49861 L .41594 .49516 L p F P
0 g
s
.651 .758 .928 r
.7936 .49817 m .80574 .49443 L .80837 .49787 L p F P
0 g
s
.651 .758 .928 r
.80574 .49443 m .7936 .49817 L .79095 .49473 L p F P
0 g
s
.651 .758 .928 r
.61377 .49829 m .62559 .49455 L .62851 .498 L p F P
0 g
s
.651 .758 .928 r
.62559 .49455 m .61377 .49829 L .61082 .49485 L p F P
0 g
s
.651 .758 .928 r
.43393 .49832 m .44542 .49459 L .44865 .49803 L p F P
0 g
s
.651 .758 .928 r
.44542 .49459 m .43393 .49832 L .43068 .49487 L p F P
0 g
s
.651 .758 .928 r
.80837 .49787 m .82053 .49412 L .82314 .49756 L p F P
0 g
s
.651 .758 .928 r
.82053 .49412 m .80837 .49787 L .80574 .49443 L p F P
0 g
s
.651 .758 .928 r
.62851 .498 m .64036 .49426 L .64326 .49771 L p F P
0 g
s
.651 .758 .928 r
.64036 .49426 m .62851 .498 L .62559 .49455 L p F P
0 g
s
.651 .758 .928 r
.44865 .49803 m .46017 .4943 L .46337 .49774 L p F P
0 g
s
.651 .758 .928 r
.46017 .4943 m .44865 .49803 L .44542 .49459 L p F P
0 g
s
.651 .758 .928 r
.82314 .49756 m .83533 .49381 L .83791 .49725 L p F P
0 g
s
.651 .758 .928 r
.83533 .49381 m .82314 .49756 L .82053 .49412 L p F P
0 g
s
.651 .758 .928 r
.64326 .49771 m .65513 .49397 L .65801 .49742 L p F P
0 g
s
.651 .758 .928 r
.65513 .49397 m .64326 .49771 L .64036 .49426 L p F P
0 g
s
.651 .758 .928 r
.46337 .49774 m .47492 .49401 L .4781 .49746 L p F P
0 g
s
.651 .758 .928 r
.47492 .49401 m .46337 .49774 L .46017 .4943 L p F P
0 g
s
.651 .758 .928 r
.83791 .49725 m .85013 .49349 L .85269 .49693 L p F P
0 g
s
.651 .758 .928 r
.85013 .49349 m .83791 .49725 L .83533 .49381 L p F P
0 g
s
.651 .758 .928 r
.66991 .49367 m .65801 .49742 L .65513 .49397 L p F P
0 g
s
.651 .758 .928 r
.65801 .49742 m .66991 .49367 L .67277 .49712 L p F P
0 g
s
.651 .758 .928 r
.4781 .49746 m .48967 .49372 L .49283 .49717 L p F P
0 g
s
.651 .758 .928 r
.48967 .49372 m .4781 .49746 L .47492 .49401 L p F P
0 g
s
0 0 .285 r
.39707 .43731 m .39706 .43732 L .3972 .4321 L p F P
0 g
s
0 0 .285 r
.3972 .4321 m .39721 .43209 L .39707 .43731 L p F P
0 g
s
.76 .491 .526 r
.39704 .43732 m .39706 .43732 L .3972 .4321 L p F P
0 g
s
.76 .491 .526 r
.3972 .4321 m .39718 .4321 L .39704 .43732 L p F P
0 g
s
.651 .758 .928 r
.85269 .49693 m .86494 .49317 L .86747 .49662 L p F P
0 g
s
.651 .758 .928 r
.86494 .49317 m .85269 .49693 L .85013 .49349 L p F P
0 g
s
.651 .758 .928 r
.67277 .49712 m .6847 .49338 L .68753 .49683 L p F P
0 g
s
.651 .758 .928 r
.6847 .49338 m .67277 .49712 L .66991 .49367 L p F P
0 g
s
.651 .758 .928 r
.49283 .49717 m .50443 .49343 L .50756 .49688 L p F P
0 g
s
.651 .758 .928 r
.50443 .49343 m .49283 .49717 L .48967 .49372 L p F P
0 g
s
.651 .758 .928 r
.86747 .49662 m .87975 .49285 L .88225 .4963 L p F P
0 g
s
.651 .758 .928 r
.87975 .49285 m .86747 .49662 L .86494 .49317 L p F P
0 g
s
.651 .758 .928 r
.68753 .49683 m .69948 .49308 L .70229 .49653 L p F P
0 g
s
.651 .758 .928 r
.69948 .49308 m .68753 .49683 L .6847 .49338 L p F P
0 g
s
.651 .758 .928 r
.50756 .49688 m .5192 .49314 L .5223 .49659 L p F P
0 g
s
.651 .758 .928 r
.5192 .49314 m .50756 .49688 L .50443 .49343 L p F P
0 g
s
.65 .757 .928 r
.3276 .49688 m .33891 .49315 L .34231 .4966 L p F P
0 g
s
.652 .759 .928 r
.88225 .4963 m .89456 .49253 L .89704 .49597 L p F P
0 g
s
.651 .758 .928 r
.89456 .49253 m .88225 .4963 L .87975 .49285 L p F P
0 g
s
.651 .758 .928 r
.70229 .49653 m .71427 .49279 L .71706 .49624 L p F P
0 g
s
.651 .758 .928 r
.71427 .49279 m .70229 .49653 L .69948 .49308 L p F P
0 g
s
.651 .758 .928 r
.5223 .49659 m .53396 .49285 L .53704 .4963 L p F P
0 g
s
.651 .758 .928 r
.53396 .49285 m .5223 .49659 L .5192 .49314 L p F P
0 g
s
.65 .757 .928 r
.34231 .4966 m .35365 .49286 L .35703 .49631 L p F P
0 g
s
.65 .757 .928 r
.35365 .49286 m .34231 .4966 L .33891 .49315 L p F P
0 g
s
.651 .758 .928 r
.71706 .49624 m .72907 .49249 L .73183 .49594 L p F P
0 g
s
.651 .758 .928 r
.72907 .49249 m .71706 .49624 L .71427 .49279 L p F P
0 g
s
.651 .758 .928 r
.53704 .4963 m .54873 .49256 L .55179 .49601 L p F P
0 g
s
.651 .758 .928 r
.54873 .49256 m .53704 .4963 L .53396 .49285 L p F P
0 g
s
.65 .757 .928 r
.35703 .49631 m .36839 .49257 L .37175 .49602 L p F P
0 g
s
.65 .757 .928 r
.36839 .49257 m .35703 .49631 L .35365 .49286 L p F P
0 g
s
.651 .758 .928 r
.73183 .49594 m .74387 .49219 L .7466 .49564 L p F P
0 g
s
.651 .758 .928 r
.74387 .49219 m .73183 .49594 L .72907 .49249 L p F P
0 g
s
.651 .758 .928 r
.55179 .49601 m .56351 .49227 L .56654 .49572 L p F P
0 g
s
.651 .758 .928 r
.56351 .49227 m .55179 .49601 L .54873 .49256 L p F P
0 g
s
.65 .757 .928 r
.37175 .49602 m .38314 .49228 L .38648 .49574 L p F P
0 g
s
.65 .757 .928 r
.38314 .49228 m .37175 .49602 L .36839 .49257 L p F P
0 g
s
.651 .758 .928 r
.7466 .49564 m .75867 .49189 L .76138 .49534 L p F P
0 g
s
.651 .758 .928 r
.75867 .49189 m .7466 .49564 L .74387 .49219 L p F P
0 g
s
.651 .758 .928 r
.56654 .49572 m .57829 .49198 L .5813 .49543 L p F P
0 g
s
.651 .758 .928 r
.57829 .49198 m .56654 .49572 L .56351 .49227 L p F P
0 g
s
.65 .757 .928 r
.38648 .49574 m .3979 .492 L .40121 .49545 L p F P
0 g
s
.65 .757 .928 r
.3979 .492 m .38648 .49574 L .38314 .49228 L p F P
0 g
s
.651 .758 .928 r
.76138 .49534 m .77348 .49158 L .77616 .49504 L p F P
0 g
s
.651 .758 .928 r
.77348 .49158 m .76138 .49534 L .75867 .49189 L p F P
0 g
s
.651 .758 .928 r
.5813 .49543 m .59307 .49168 L .59606 .49514 L p F P
0 g
s
.651 .758 .928 r
.59307 .49168 m .5813 .49543 L .57829 .49198 L p F P
0 g
s
.65 .758 .928 r
.40121 .49545 m .41266 .49171 L .41594 .49516 L p F P
0 g
s
.65 .757 .928 r
.41266 .49171 m .40121 .49545 L .3979 .492 L p F P
0 g
s
.651 .758 .928 r
.77616 .49504 m .78829 .49128 L .79095 .49473 L p F P
0 g
s
.651 .758 .928 r
.78829 .49128 m .77616 .49504 L .77348 .49158 L p F P
0 g
s
.651 .758 .928 r
.59606 .49514 m .60786 .49139 L .61082 .49485 L p F P
0 g
s
.651 .758 .928 r
.60786 .49139 m .59606 .49514 L .59307 .49168 L p F P
0 g
s
.651 .758 .928 r
.41594 .49516 m .42742 .49142 L .43068 .49487 L p F P
0 g
s
.651 .758 .928 r
.42742 .49142 m .41594 .49516 L .41266 .49171 L p F P
0 g
s
.651 .758 .928 r
.79095 .49473 m .8031 .49097 L .80574 .49443 L p F P
0 g
s
.651 .758 .928 r
.8031 .49097 m .79095 .49473 L .78829 .49128 L p F P
0 g
s
.651 .758 .928 r
.61082 .49485 m .62265 .4911 L .62559 .49455 L p F P
0 g
s
.651 .758 .928 r
.62265 .4911 m .61082 .49485 L .60786 .49139 L p F P
0 g
s
.651 .758 .928 r
.43068 .49487 m .44219 .49113 L .44542 .49459 L p F P
0 g
s
.651 .758 .928 r
.44219 .49113 m .43068 .49487 L .42742 .49142 L p F P
0 g
s
.651 .758 .928 r
.80574 .49443 m .81792 .49066 L .82053 .49412 L p F P
0 g
s
.651 .758 .928 r
.81792 .49066 m .80574 .49443 L .8031 .49097 L p F P
0 g
s
.651 .758 .928 r
.62559 .49455 m .63745 .4908 L .64036 .49426 L p F P
0 g
s
.651 .758 .928 r
.63745 .4908 m .62559 .49455 L .62265 .4911 L p F P
0 g
s
0 0 .289 r
.39693 .44255 m .39692 .44255 L .39706 .43732 L p F P
0 g
s
0 0 .289 r
.39706 .43732 m .39707 .43731 L .39693 .44255 L p F P
0 g
s
.759 .49 .526 r
.39691 .44255 m .39692 .44255 L .39706 .43732 L p F P
0 g
s
.759 .49 .526 r
.39706 .43732 m .39704 .43732 L .39691 .44255 L p F P
0 g
s
.651 .758 .928 r
.44542 .49459 m .45696 .49084 L .46017 .4943 L p F P
0 g
s
.651 .758 .928 r
.45696 .49084 m .44542 .49459 L .44219 .49113 L p F P
0 g
s
.651 .758 .928 r
.82053 .49412 m .83274 .49035 L .83533 .49381 L p F P
0 g
s
.651 .758 .928 r
.83274 .49035 m .82053 .49412 L .81792 .49066 L p F P
0 g
s
.651 .758 .928 r
.64036 .49426 m .65224 .49051 L .65513 .49397 L p F P
0 g
s
.651 .758 .928 r
.65224 .49051 m .64036 .49426 L .63745 .4908 L p F P
0 g
s
.651 .758 .928 r
.46017 .4943 m .47173 .49055 L .47492 .49401 L p F P
0 g
s
.651 .758 .928 r
.47173 .49055 m .46017 .4943 L .45696 .49084 L p F P
0 g
s
.651 .758 .928 r
.83533 .49381 m .84757 .49004 L .85013 .49349 L p F P
0 g
s
.651 .758 .928 r
.84757 .49004 m .83533 .49381 L .83274 .49035 L p F P
0 g
s
.651 .758 .928 r
.65513 .49397 m .66705 .49022 L .66991 .49367 L p F P
0 g
s
.651 .758 .928 r
.66705 .49022 m .65513 .49397 L .65224 .49051 L p F P
0 g
s
.651 .758 .928 r
.47492 .49401 m .48651 .49026 L .48967 .49372 L p F P
0 g
s
.651 .758 .928 r
.48651 .49026 m .47492 .49401 L .47173 .49055 L p F P
0 g
s
.651 .758 .928 r
.85013 .49349 m .8624 .48972 L .86494 .49317 L p F P
0 g
s
.651 .758 .928 r
.8624 .48972 m .85013 .49349 L .84757 .49004 L p F P
0 g
s
.651 .758 .928 r
.68186 .48992 m .66991 .49367 L .66705 .49022 L p F P
0 g
s
.651 .758 .928 r
.66991 .49367 m .68186 .48992 L .6847 .49338 L p F P
0 g
s
.651 .758 .928 r
.48967 .49372 m .50129 .48997 L .50443 .49343 L p F P
0 g
s
.651 .758 .928 r
.50129 .48997 m .48967 .49372 L .48651 .49026 L p F P
0 g
s
.651 .758 .928 r
.86494 .49317 m .87723 .4894 L .87975 .49285 L p F P
0 g
s
.651 .758 .928 r
.87723 .4894 m .86494 .49317 L .8624 .48972 L p F P
0 g
s
.651 .758 .928 r
.6847 .49338 m .69667 .48962 L .69948 .49308 L p F P
0 g
s
.651 .758 .928 r
.69667 .48962 m .6847 .49338 L .68186 .48992 L p F P
0 g
s
.651 .758 .928 r
.50443 .49343 m .51608 .48968 L .5192 .49314 L p F P
0 g
s
.651 .758 .928 r
.51608 .48968 m .50443 .49343 L .50129 .48997 L p F P
0 g
s
.651 .758 .928 r
.87975 .49285 m .89207 .48907 L .89456 .49253 L p F P
0 g
s
.651 .758 .928 r
.89207 .48907 m .87975 .49285 L .87723 .4894 L p F P
0 g
s
.651 .758 .928 r
.69948 .49308 m .71148 .48932 L .71427 .49279 L p F P
0 g
s
.651 .758 .928 r
.71148 .48932 m .69948 .49308 L .69667 .48962 L p F P
0 g
s
.651 .758 .928 r
.5192 .49314 m .53087 .48939 L .53396 .49285 L p F P
0 g
s
.651 .758 .928 r
.53087 .48939 m .5192 .49314 L .51608 .48968 L p F P
0 g
s
.65 .757 .928 r
.33891 .49315 m .35026 .48939 L .35365 .49286 L p F P
0 g
s
.651 .758 .928 r
.71427 .49279 m .7263 .48903 L .72907 .49249 L p F P
0 g
s
.651 .758 .928 r
.7263 .48903 m .71427 .49279 L .71148 .48932 L p F P
0 g
s
.651 .758 .928 r
.53396 .49285 m .54567 .48909 L .54873 .49256 L p F P
0 g
s
.651 .758 .928 r
.54567 .48909 m .53396 .49285 L .53087 .48939 L p F P
0 g
s
.65 .757 .928 r
.35365 .49286 m .36503 .48911 L .36839 .49257 L p F P
0 g
s
.65 .757 .928 r
.36503 .48911 m .35365 .49286 L .35026 .48939 L p F P
0 g
s
.651 .758 .928 r
.72907 .49249 m .74113 .48873 L .74387 .49219 L p F P
0 g
s
.651 .758 .928 r
.74113 .48873 m .72907 .49249 L .7263 .48903 L p F P
0 g
s
.651 .758 .928 r
.54873 .49256 m .56047 .4888 L .56351 .49227 L p F P
0 g
s
.651 .758 .928 r
.56047 .4888 m .54873 .49256 L .54567 .48909 L p F P
0 g
s
.65 .757 .928 r
.36839 .49257 m .3798 .48882 L .38314 .49228 L p F P
0 g
s
.65 .757 .928 r
.3798 .48882 m .36839 .49257 L .36503 .48911 L p F P
0 g
s
.651 .758 .928 r
.74387 .49219 m .75595 .48842 L .75867 .49189 L p F P
0 g
s
.651 .758 .928 r
.75595 .48842 m .74387 .49219 L .74113 .48873 L p F P
0 g
s
.651 .758 .928 r
.56351 .49227 m .57527 .48851 L .57829 .49198 L p F P
0 g
s
.651 .758 .928 r
.57527 .48851 m .56351 .49227 L .56047 .4888 L p F P
0 g
s
.65 .757 .928 r
.38314 .49228 m .39458 .48853 L .3979 .492 L p F P
0 g
s
.65 .757 .928 r
.39458 .48853 m .38314 .49228 L .3798 .48882 L p F P
0 g
s
.651 .758 .928 r
.75867 .49189 m .77078 .48812 L .77348 .49158 L p F P
0 g
s
.651 .758 .928 r
.77078 .48812 m .75867 .49189 L .75595 .48842 L p F P
0 g
s
.651 .758 .928 r
.57829 .49198 m .59008 .48822 L .59307 .49168 L p F P
0 g
s
.651 .758 .928 r
.59008 .48822 m .57829 .49198 L .57527 .48851 L p F P
0 g
s
.65 .757 .928 r
.3979 .492 m .40936 .48824 L .41266 .49171 L p F P
0 g
s
.65 .757 .928 r
.40936 .48824 m .3979 .492 L .39458 .48853 L p F P
0 g
s
.651 .758 .928 r
.77348 .49158 m .78562 .48781 L .78829 .49128 L p F P
0 g
s
.651 .758 .928 r
.78562 .48781 m .77348 .49158 L .77078 .48812 L p F P
0 g
s
.651 .758 .928 r
.59307 .49168 m .60489 .48792 L .60786 .49139 L p F P
0 g
s
.651 .758 .928 r
.60489 .48792 m .59307 .49168 L .59008 .48822 L p F P
0 g
s
0 0 .293 r
.39679 .44779 m .39678 .4478 L .39692 .44255 L p F P
0 g
s
0 0 .293 r
.39692 .44255 m .39693 .44255 L .39679 .44779 L p F P
0 g
s
.758 .489 .526 r
.39677 .4478 m .39678 .4478 L .39692 .44255 L p F P
0 g
s
.758 .489 .526 r
.39692 .44255 m .39691 .44255 L .39677 .4478 L p F P
0 g
s
.651 .758 .928 r
.41266 .49171 m .42415 .48795 L .42742 .49142 L p F P
0 g
s
.651 .758 .928 r
.42415 .48795 m .41266 .49171 L .40936 .48824 L p F P
0 g
s
.651 .758 .928 r
.78829 .49128 m .80046 .48751 L .8031 .49097 L p F P
0 g
s
.651 .758 .928 r
.80046 .48751 m .78829 .49128 L .78562 .48781 L p F P
0 g
s
.651 .758 .928 r
.60786 .49139 m .6197 .48763 L .62265 .4911 L p F P
0 g
s
.651 .758 .928 r
.6197 .48763 m .60786 .49139 L .60489 .48792 L p F P
0 g
s
.651 .758 .928 r
.43894 .48766 m .42742 .49142 L .42415 .48795 L p F P
0 g
s
.651 .758 .928 r
.42742 .49142 m .43894 .48766 L .44219 .49113 L p F P
0 g
s
.651 .758 .928 r
.8031 .49097 m .8153 .4872 L .81792 .49066 L p F P
0 g
s
.651 .758 .928 r
.8153 .4872 m .8031 .49097 L .80046 .48751 L p F P
0 g
s
.651 .758 .928 r
.62265 .4911 m .63452 .48734 L .63745 .4908 L p F P
0 g
s
.651 .758 .928 r
.63452 .48734 m .62265 .4911 L .6197 .48763 L p F P
0 g
s
.651 .758 .928 r
.44219 .49113 m .45373 .48737 L .45696 .49084 L p F P
0 g
s
.651 .758 .928 r
.45373 .48737 m .44219 .49113 L .43894 .48766 L p F P
0 g
s
.651 .758 .928 r
.81792 .49066 m .83015 .48689 L .83274 .49035 L p F P
0 g
s
.651 .758 .928 r
.83015 .48689 m .81792 .49066 L .8153 .4872 L p F P
0 g
s
.651 .758 .928 r
.63745 .4908 m .64935 .48704 L .65224 .49051 L p F P
0 g
s
.651 .758 .928 r
.64935 .48704 m .63745 .4908 L .63452 .48734 L p F P
0 g
s
.651 .758 .928 r
.45696 .49084 m .46853 .48708 L .47173 .49055 L p F P
0 g
s
.651 .758 .928 r
.46853 .48708 m .45696 .49084 L .45373 .48737 L p F P
0 g
s
.651 .758 .928 r
.83274 .49035 m .845 .48657 L .84757 .49004 L p F P
0 g
s
.651 .758 .928 r
.845 .48657 m .83274 .49035 L .83015 .48689 L p F P
0 g
s
.651 .758 .928 r
.65224 .49051 m .66417 .48674 L .66705 .49022 L p F P
0 g
s
.651 .758 .928 r
.66417 .48674 m .65224 .49051 L .64935 .48704 L p F P
0 g
s
.651 .758 .928 r
.47173 .49055 m .48334 .48679 L .48651 .49026 L p F P
0 g
s
.651 .758 .928 r
.48334 .48679 m .47173 .49055 L .46853 .48708 L p F P
0 g
s
.651 .758 .928 r
.84757 .49004 m .85985 .48625 L .8624 .48972 L p F P
0 g
s
.651 .758 .928 r
.85985 .48625 m .84757 .49004 L .845 .48657 L p F P
0 g
s
.651 .758 .928 r
.66705 .49022 m .67901 .48645 L .68186 .48992 L p F P
0 g
s
.651 .758 .928 r
.67901 .48645 m .66705 .49022 L .66417 .48674 L p F P
0 g
s
.651 .758 .928 r
.48651 .49026 m .49814 .48649 L .50129 .48997 L p F P
0 g
s
.651 .758 .928 r
.49814 .48649 m .48651 .49026 L .48334 .48679 L p F P
0 g
s
.651 .758 .928 r
.8624 .48972 m .87471 .48593 L .87723 .4894 L p F P
0 g
s
.651 .758 .928 r
.87471 .48593 m .8624 .48972 L .85985 .48625 L p F P
0 g
s
.651 .758 .928 r
.69384 .48615 m .68186 .48992 L .67901 .48645 L p F P
0 g
s
.651 .758 .928 r
.68186 .48992 m .69384 .48615 L .69667 .48962 L p F P
0 g
s
.651 .758 .928 r
.50129 .48997 m .51295 .4862 L .51608 .48968 L p F P
0 g
s
.651 .758 .928 r
.51295 .4862 m .50129 .48997 L .49814 .48649 L p F P
0 g
s
.651 .758 .928 r
.87723 .4894 m .88957 .48561 L .89207 .48907 L p F P
0 g
s
.651 .758 .928 r
.88957 .48561 m .87723 .4894 L .87471 .48593 L p F P
0 g
s
.651 .758 .928 r
.69667 .48962 m .70868 .48585 L .71148 .48932 L p F P
0 g
s
.651 .758 .928 r
.70868 .48585 m .69667 .48962 L .69384 .48615 L p F P
0 g
s
.651 .758 .928 r
.51608 .48968 m .52777 .48591 L .53087 .48939 L p F P
0 g
s
.651 .758 .928 r
.52777 .48591 m .51608 .48968 L .51295 .4862 L p F P
0 g
s
.651 .758 .928 r
.71148 .48932 m .72353 .48555 L .7263 .48903 L p F P
0 g
s
.651 .758 .928 r
.72353 .48555 m .71148 .48932 L .70868 .48585 L p F P
0 g
s
.651 .758 .928 r
.53087 .48939 m .54259 .48562 L .54567 .48909 L p F P
0 g
s
.651 .758 .928 r
.54259 .48562 m .53087 .48939 L .52777 .48591 L p F P
0 g
s
.65 .757 .928 r
.35026 .48939 m .36165 .48563 L .36503 .48911 L p F P
0 g
s
.651 .758 .928 r
.7263 .48903 m .73837 .48525 L .74113 .48873 L p F P
0 g
s
.651 .758 .928 r
.73837 .48525 m .7263 .48903 L .72353 .48555 L p F P
0 g
s
.651 .758 .928 r
.54567 .48909 m .55741 .48533 L .56047 .4888 L p F P
0 g
s
.651 .758 .928 r
.55741 .48533 m .54567 .48909 L .54259 .48562 L p F P
0 g
s
.65 .757 .928 r
.36503 .48911 m .37645 .48534 L .3798 .48882 L p F P
0 g
s
.65 .757 .928 r
.37645 .48534 m .36503 .48911 L .36165 .48563 L p F P
0 g
s
.651 .758 .928 r
.74113 .48873 m .75323 .48495 L .75595 .48842 L p F P
0 g
s
.651 .758 .928 r
.75323 .48495 m .74113 .48873 L .73837 .48525 L p F P
0 g
s
.651 .758 .928 r
.56047 .4888 m .57224 .48503 L .57527 .48851 L p F P
0 g
s
.651 .758 .928 r
.57224 .48503 m .56047 .4888 L .55741 .48533 L p F P
0 g
s
0 0 .301 r
.39665 .45306 m .39664 .45307 L .39678 .4478 L p F P
0 g
s
0 0 .301 r
.39678 .4478 m .39679 .44779 L .39665 .45306 L p F P
0 g
s
.755 .487 .527 r
.39663 .45306 m .39664 .45307 L .39678 .4478 L p F P
0 g
s
.755 .487 .527 r
.39678 .4478 m .39677 .4478 L .39663 .45306 L p F P
0 g
s
.65 .757 .928 r
.3798 .48882 m .39125 .48505 L .39458 .48853 L p F P
0 g
s
.65 .757 .928 r
.39125 .48505 m .3798 .48882 L .37645 .48534 L p F P
0 g
s
.651 .758 .928 r
.75595 .48842 m .76808 .48464 L .77078 .48812 L p F P
0 g
s
.651 .758 .928 r
.76808 .48464 m .75595 .48842 L .75323 .48495 L p F P
0 g
s
.651 .758 .928 r
.57527 .48851 m .58707 .48474 L .59008 .48822 L p F P
0 g
s
.651 .758 .928 r
.58707 .48474 m .57527 .48851 L .57224 .48503 L p F P
0 g
s
.65 .757 .928 r
.39458 .48853 m .40606 .48476 L .40936 .48824 L p F P
0 g
s
.651 .757 .928 r
.40606 .48476 m .39458 .48853 L .39125 .48505 L p F P
0 g
s
.651 .758 .928 r
.77078 .48812 m .78294 .48434 L .78562 .48781 L p F P
0 g
s
.651 .758 .928 r
.78294 .48434 m .77078 .48812 L .76808 .48464 L p F P
0 g
s
.651 .758 .928 r
.59008 .48822 m .60191 .48444 L .60489 .48792 L p F P
0 g
s
.651 .758 .928 r
.60191 .48444 m .59008 .48822 L .58707 .48474 L p F P
0 g
s
.651 .758 .928 r
.40936 .48824 m .42087 .48447 L .42415 .48795 L p F P
0 g
s
.651 .757 .928 r
.42087 .48447 m .40936 .48824 L .40606 .48476 L p F P
0 g
s
.651 .758 .928 r
.78562 .48781 m .7978 .48403 L .80046 .48751 L p F P
0 g
s
.651 .758 .928 r
.7978 .48403 m .78562 .48781 L .78294 .48434 L p F P
0 g
s
.703 .569 .701 r
.40277 .66038 m .40405 .66037 L .40649 .6684 L p F P
0 g
s
.703 .569 .701 r
.40649 .6684 m .39398 .66854 L .40277 .66038 L p F P
0 g
s
.703 .579 .713 r
.40405 .66037 m .40377 .65952 L .40277 .66038 L closepath p F P
0 g
s
.708 .576 .706 r
.38898 .66036 m .40277 .66038 L .39398 .66854 L p F P
0 g
s
.707 .587 .719 r
.40135 .65209 m .40377 .65952 L .40277 .66038 L p F P
0 g
s
.707 .587 .719 r
.39812 .65209 m .40135 .65209 L p .40277 .66038 L F P
0 g
s
.707 .587 .719 r
.38897 .66033 m .39812 .65209 L p .40277 .66038 L F P
0 g
s
.707 .587 .719 r
.40277 .66038 m .38898 .66036 L .38897 .66033 L p F P
0 g
s
.686 .559 .706 r
.40405 .66037 m .41818 .65946 L p .40887 .66825 L F P
0 g
s
.686 .559 .706 r
.40887 .66825 m .40649 .6684 L .40405 .66037 L p F P
0 g
s
.691 .572 .716 r
.41563 .65133 m .41818 .65946 L .40405 .66037 L p F P
0 g
s
.691 .572 .716 r
.41424 .65142 m .41563 .65133 L p .40405 .66037 L F P
0 g
s
.691 .572 .716 r
.40405 .66037 m .40377 .65952 L .41424 .65142 L p F P
0 g
s
.651 .758 .928 r
.60489 .48792 m .61675 .48415 L .6197 .48763 L p F P
0 g
s
.651 .758 .928 r
.61675 .48415 m .60489 .48792 L .60191 .48444 L p F P
0 g
s
.708 .576 .706 r
.39398 .66854 m .39158 .66854 L .38898 .66036 L p F P
0 g
s
.724 .586 .7 r
.38894 .66036 m .38898 .66036 L .39158 .66854 L p F P
0 g
s
.723 .595 .713 r
.38898 .66036 m .38897 .66033 L .38894 .66036 L closepath p F P
0 g
s
.712 .588 .715 r
.38897 .66033 m .39812 .65209 L .38608 .65189 L closepath p F P
0 g
s
.722 .594 .712 r
.38894 .66036 m .38897 .66033 L .38608 .65189 L p F P
0 g
s
.724 .586 .7 r
.39158 .66854 m .38175 .66804 L .38894 .66036 L p F P
0 g
s
.728 .596 .709 r
.37757 .6596 m .38894 .66036 L .38175 .66804 L p F P
0 g
s
.722 .594 .712 r
.38507 .65183 m .37757 .6596 L .38894 .66036 L p F P
0 g
s
.722 .594 .712 r
.38608 .65189 m .38507 .65183 L p .38894 .66036 L F P
0 g
s
.69 .57 .715 r
.40377 .65952 m .41424 .65142 L .40135 .65209 L closepath p F P
0 g
s
.651 .758 .928 r
.42415 .48795 m .43568 .48418 L .43894 .48766 L p F P
0 g
s
.651 .758 .928 r
.43568 .48418 m .42415 .48795 L .42087 .48447 L p F P
0 g
s
.703 .566 .697 r
.39398 .66854 m .40649 .6684 L p .40012 .67639 L F P
0 g
s
.703 .566 .697 r
.39212 .6704 m .39398 .66854 L p .40012 .67639 L F P
0 g
s
.707 .567 .694 r
.39212 .6704 m .39398 .66854 L .39158 .66854 L closepath p F P
0 g
s
.723 .585 .7 r
.39158 .66854 m .39212 .6704 L .38682 .67621 L p F P
0 g
s
.723 .585 .7 r
.38175 .66804 m .39158 .66854 L p .38682 .67621 L F P
0 g
s
.691 .579 .725 r
.41424 .65142 m .40135 .65209 L .40061 .64996 L p F P
0 g
s
.708 .588 .72 r
.40135 .65209 m .40061 .64996 L .39812 .65209 L closepath p F P
0 g
s
.712 .597 .727 r
.39841 .64358 m .40061 .64996 L .39812 .65209 L p F P
0 g
s
.712 .597 .727 r
.39438 .64351 m .39841 .64358 L p .39812 .65209 L F P
0 g
s
.712 .597 .727 r
.3858 .65112 m .39438 .64351 L p .39812 .65209 L F P
0 g
s
.712 .597 .727 r
.39812 .65209 m .38608 .65189 L .3858 .65112 L p F P
0 g
s
.703 .566 .697 r
.40012 .67639 m .39391 .67647 L .39212 .6704 L p F P
0 g
s
.719 .575 .692 r
.39391 .67647 m .39212 .6704 L .38682 .67621 L closepath p F P
0 g
s
.691 .579 .725 r
.40061 .64996 m .40952 .64313 L p .41424 .65142 L F P
0 g
s
.694 .58 .722 r
.40061 .64996 m .40952 .64313 L .39841 .64358 L closepath p F P
0 g
s
.685 .549 .694 r
.40691 .66991 m .40887 .66825 L .40649 .6684 L closepath p F P
0 g
s
.703 .566 .697 r
.40649 .6684 m .40691 .66991 L .40012 .67639 L p F P
0 g
s
.651 .758 .928 r
.80046 .48751 m .81267 .48372 L .8153 .4872 L p F P
0 g
s
.651 .758 .928 r
.81267 .48372 m .80046 .48751 L .7978 .48403 L p F P
0 g
s
.651 .758 .928 r
.6197 .48763 m .63159 .48385 L .63452 .48734 L p F P
0 g
s
.651 .758 .928 r
.63159 .48385 m .6197 .48763 L .61675 .48415 L p F P
0 g
s
.728 .605 .721 r
.38608 .65189 m .3858 .65112 L .38507 .65183 L closepath p F P
0 g
s
.682 .548 .696 r
.40691 .66991 m .40887 .66825 L p .41668 .6756 L F P
0 g
s
.682 .548 .696 r
.41668 .6756 m .40868 .67619 L .40691 .66991 L p F P
0 g
s
.699 .558 .692 r
.40868 .67619 m .40691 .66991 L .40012 .67639 L closepath p F P
0 g
s
.651 .758 .928 r
.43894 .48766 m .4505 .48389 L .45373 .48737 L p F P
0 g
s
.651 .758 .928 r
.4505 .48389 m .43894 .48766 L .43568 .48418 L p F P
0 g
s
.717 .599 .723 r
.3858 .65112 m .39438 .64351 L .38289 .64314 L closepath p F P
0 g
s
.727 .604 .719 r
.38507 .65183 m .3858 .65112 L .38289 .64314 L p F P
0 g
s
.703 .556 .685 r
.39524 .68141 m .40012 .67639 L .39391 .67647 L closepath p F P
0 g
s
.719 .574 .691 r
.39391 .67647 m .39524 .68141 L .39286 .6841 L p F P
0 g
s
.719 .574 .691 r
.38682 .67621 m .39391 .67647 L p .39286 .6841 L F P
0 g
s
.733 .608 .718 r
.37422 .6509 m .38507 .65183 L .37757 .6596 L p F P
0 g
s
.727 .604 .719 r
.38194 .64306 m .37422 .6509 L .38507 .65183 L p F P
0 g
s
.727 .604 .719 r
.38289 .64314 m .38194 .64306 L p .38507 .65183 L F P
0 g
s
.682 .548 .696 r
.40887 .66825 m .4205 .66738 L p .41668 .6756 L F P
0 g
s
.682 .553 .702 r
.4205 .66738 m .41853 .66067 L .40887 .66825 L closepath p F P
0 g
s
.686 .559 .706 r
.41818 .65946 m .41853 .66067 L .40887 .66825 L p F P
0 g
s
.695 .589 .733 r
.40952 .64313 m .39841 .64358 L .39743 .64093 L p F P
0 g
s
.712 .598 .727 r
.39841 .64358 m .39743 .64093 L .39438 .64351 L closepath p F P
0 g
s
.699 .555 .688 r
.40012 .67639 m .40868 .67619 L p .40745 .6839 L F P
0 g
s
.699 .555 .688 r
.39524 .68141 m .40012 .67639 L p .40745 .6839 L F P
0 g
s
.716 .607 .734 r
.3952 .63481 m .39743 .64093 L .39438 .64351 L p F P
0 g
s
.716 .607 .734 r
.39145 .63468 m .3952 .63481 L p .39438 .64351 L F P
0 g
s
.716 .607 .734 r
.38261 .64243 m .39145 .63468 L p .39438 .64351 L F P
0 g
s
.716 .607 .734 r
.39438 .64351 m .38289 .64314 L .38261 .64243 L p F P
0 g
s
.651 .758 .928 r
.8153 .4872 m .82754 .48341 L .83015 .48689 L p F P
0 g
s
.651 .758 .928 r
.82754 .48341 m .8153 .4872 L .81267 .48372 L p F P
0 g
s
.651 .758 .928 r
.63452 .48734 m .64644 .48356 L .64935 .48704 L p F P
0 g
s
.651 .758 .928 r
.64644 .48356 m .63452 .48734 L .63159 .48385 L p F P
0 g
s
.723 .585 .7 r
.37726 .67307 m .38175 .66804 L p .38682 .67621 L F P
0 g
s
.729 .587 .697 r
.37726 .67307 m .38175 .66804 L .37556 .66764 L closepath p F P
0 g
s
.728 .596 .709 r
.3741 .66337 m .37757 .6596 L p .38175 .66804 L F P
0 g
s
.728 .596 .709 r
.38175 .66804 m .37556 .66764 L .3741 .66337 L p F P
0 g
s
.651 .758 .928 r
.45373 .48737 m .46532 .48359 L .46853 .48708 L p F P
0 g
s
.651 .758 .928 r
.46532 .48359 m .45373 .48737 L .4505 .48389 L p F P
0 g
s
.695 .589 .733 r
.39743 .64093 m .40586 .63453 L p .40952 .64313 L F P
0 g
s
.699 .589 .73 r
.39743 .64093 m .40586 .63453 L .3952 .63481 L closepath p F P
0 g
s
.719 .574 .691 r
.3804 .68366 m .38682 .67621 L p .39286 .6841 L F P
0 g
s
.724 .575 .688 r
.3804 .68366 m .38682 .67621 L .37813 .67579 L closepath p F P
0 g
s
.723 .585 .7 r
.38682 .67621 m .37813 .67579 L .37726 .67307 L p F P
0 g
s
.681 .539 .686 r
.41003 .68137 m .41668 .6756 L .40868 .67619 L closepath p F P
0 g
s
.699 .555 .688 r
.40868 .67619 m .41003 .68137 L .40745 .6839 L p F P
0 g
s
.699 .555 .688 r
.40745 .6839 m .396 .68417 L .39524 .68141 L p F P
0 g
s
.714 .564 .683 r
.396 .68417 m .39524 .68141 L .39286 .6841 L closepath p F P
0 g
s
.651 .758 .928 r
.83015 .48689 m .84242 .48309 L .845 .48657 L p F P
0 g
s
.651 .758 .928 r
.84242 .48309 m .83015 .48689 L .82754 .48341 L p F P
0 g
s
.687 .573 .721 r
.41563 .65133 m .41538 .65059 L .41424 .65142 L closepath p F P
0 g
s
.691 .579 .725 r
.41284 .64296 m .41538 .65059 L .41424 .65142 L p F P
0 g
s
.691 .579 .725 r
.40952 .64313 m .41284 .64296 L p .41424 .65142 L F P
0 g
s
.734 .598 .706 r
.3741 .66337 m .37757 .6596 L .37269 .6592 L closepath p F P
0 g
s
.733 .608 .718 r
.37092 .65439 m .37422 .6509 L p .37757 .6596 L F P
0 g
s
.733 .608 .718 r
.37757 .6596 m .37269 .6592 L .37092 .65439 L p F P
0 g
s
.651 .758 .928 r
.64935 .48704 m .66129 .48326 L .66417 .48674 L p F P
0 g
s
.651 .758 .928 r
.66129 .48326 m .64935 .48704 L .64644 .48356 L p F P
0 g
s
.732 .615 .728 r
.38289 .64314 m .38261 .64243 L .38194 .64306 L closepath p F P
0 g
s
.651 .758 .928 r
.46853 .48708 m .48015 .4833 L .48334 .48679 L p F P
0 g
s
.651 .758 .928 r
.48015 .4833 m .46853 .48708 L .46532 .48359 L p F P
0 g
s
.69 .581 .728 r
.41284 .64296 m .41221 .64119 L .40952 .64313 L closepath p F P
0 g
s
.695 .589 .733 r
.40983 .63437 m .41221 .64119 L .40952 .64313 L p F P
0 g
s
.695 .589 .733 r
.40586 .63453 m .40983 .63437 L p .40952 .64313 L F P
0 g
s
.667 .552 .715 r
.41563 .65133 m .42902 .64968 L p .42078 .65915 L F P
0 g
s
.667 .552 .715 r
.42078 .65915 m .41818 .65946 L .41563 .65133 L p F P
0 g
s
.671 .564 .726 r
.42697 .64337 m .42902 .64968 L .41563 .65133 L p F P
0 g
s
.671 .564 .726 r
.41563 .65133 m .41538 .65059 L .42697 .64337 L p F P
0 g
s
.698 .544 .674 r
.396 .68417 m .40745 .6839 L .40034 .69156 L p F P
0 g
s
.698 .544 .674 r
.40034 .69156 m .39783 .69162 L .396 .68417 L p F P
0 g
s
.714 .554 .67 r
.39286 .6841 m .396 .68417 L .39783 .69162 L p F P
0 g
s
.671 .562 .724 r
.42634 .64142 m .42697 .64337 L .41538 .65059 L p F P
0 g
s
.671 .562 .724 r
.41538 .65059 m .41284 .64296 L .42634 .64142 L p F P
0 g
s
.722 .604 .724 r
.39145 .63468 m .38261 .64243 L .37941 .63416 L p F P
0 g
s
.731 .614 .727 r
.38194 .64306 m .38261 .64243 L .37941 .63416 L p F P
0 g
s
.737 .619 .728 r
.37161 .64197 m .38194 .64306 L .37422 .6509 L p F P
0 g
s
.731 .614 .727 r
.37941 .63416 m .37161 .64197 L .38194 .64306 L p F P
0 g
s
.666 .542 .704 r
.41853 .66067 m .42078 .65915 L .41818 .65946 L closepath p F P
0 g
s
.714 .554 .67 r
.39783 .69162 m .38703 .69138 L .39286 .6841 L p F P
0 g
s
.719 .56 .674 r
.3804 .68367 m .39286 .6841 L .38703 .69138 L p F P
0 g
s
.719 .574 .691 r
.39286 .6841 m .3804 .68367 L .3804 .68366 L p F P
0 g
s
.699 .598 .74 r
.40586 .63453 m .3952 .63481 L .39425 .63234 L p F P
0 g
s
.716 .607 .734 r
.3952 .63481 m .39425 .63234 L .39145 .63468 L closepath p F P
0 g
s
.738 .592 .693 r
.37556 .66764 m .3709 .66712 L p .37523 .67552 L F P
0 g
s
.738 .592 .693 r
.37523 .67552 m .37726 .67307 L .37556 .66764 L p F P
0 g
s
.743 .604 .703 r
.37556 .66764 m .3741 .66337 L .3709 .66712 L closepath p F P
0 g
s
.663 .542 .706 r
.41853 .66067 m .42078 .65915 L p .42961 .6662 L F P
0 g
s
.663 .542 .706 r
.42961 .6662 m .4205 .66738 L .41853 .66067 L p F P
0 g
s
.651 .758 .928 r
.845 .48657 m .85729 .48277 L .85985 .48625 L p F P
0 g
s
.651 .758 .928 r
.85729 .48277 m .845 .48657 L .84242 .48309 L p F P
0 g
s
.676 .573 .732 r
.4238 .63396 m .42634 .64142 L .41284 .64296 L p F P
0 g
s
.676 .573 .732 r
.41284 .64296 m .41221 .64119 L .4238 .63396 L p F P
0 g
s
.738 .593 .694 r
.37813 .67579 m .37726 .67307 L .37523 .67552 L closepath p F P
0 g
s
.733 .581 .685 r
.37813 .67579 m .37523 .67552 L p .38039 .68367 L F P
0 g
s
.733 .581 .685 r
.38039 .68367 m .3804 .68366 L .37813 .67579 L p F P
0 g
s
.682 .541 .687 r
.41067 .68379 m .41003 .68137 L .41668 .6756 L p F P
0 g
s
.694 .548 .684 r
.41067 .68379 m .41003 .68137 L .40745 .6839 L closepath p F P
0 g
s
.722 .604 .724 r
.37941 .63416 m .37949 .63408 L .39145 .63468 L p F P
0 g
s
.716 .606 .733 r
.38926 .62562 m .37949 .63408 L .39145 .63468 L p F P
0 g
s
.716 .606 .733 r
.39171 .62575 m .38926 .62562 L p .39145 .63468 L F P
0 g
s
.716 .606 .733 r
.39145 .63468 m .39425 .63234 L .39171 .62575 L p F P
0 g
s
.651 .758 .928 r
.66417 .48674 m .67615 .48296 L .67901 .48645 L p F P
0 g
s
.651 .758 .928 r
.67615 .48296 m .66417 .48674 L .66129 .48326 L p F P
0 g
s
.743 .603 .702 r
.3709 .66712 m .3741 .66337 L .37269 .6592 L p F P
0 g
s
.675 .571 .731 r
.42346 .63295 m .4238 .63396 L .41221 .64119 L p F P
0 g
s
.675 .571 .731 r
.41221 .64119 m .40983 .63437 L .42346 .63295 L p F P
0 g
s
.651 .758 .928 r
.48334 .48679 m .49498 .48301 L .49814 .48649 L p F P
0 g
s
.651 .758 .928 r
.49498 .48301 m .48334 .48679 L .48015 .4833 L p F P
0 g
s
.693 .537 .67 r
.40745 .6839 m .41067 .68379 L .4124 .69114 L p F P
0 g
s
.693 .537 .67 r
.4124 .69114 m .40034 .69156 L .40745 .6839 L p F P
0 g
s
.699 .598 .74 r
.39425 .63234 m .40314 .62563 L p .40586 .63453 L F P
0 g
s
.703 .599 .737 r
.39425 .63234 m .40314 .62563 L .39171 .62575 L closepath p F P
0 g
s
.743 .603 .702 r
.37269 .6592 m .36731 .65849 L p .3709 .66712 L F P
0 g
s
.748 .616 .712 r
.37269 .6592 m .37092 .65439 L .36731 .65849 L closepath p F P
0 g
s
.682 .541 .687 r
.41668 .6756 m .42263 .67511 L p .41067 .68379 L F P
0 g
s
.678 .544 .694 r
.42263 .67511 m .42166 .67164 L .41668 .6756 L closepath p F P
0 g
s
.682 .548 .696 r
.4205 .66738 m .42166 .67164 L .41668 .6756 L p F P
0 g
s
.694 .59 .735 r
.40983 .63437 m .40904 .63225 L .40586 .63453 L closepath p F P
0 g
s
.699 .598 .74 r
.40657 .62554 m .40904 .63225 L .40586 .63453 L p F P
0 g
s
.699 .598 .74 r
.40314 .62563 m .40657 .62554 L p .40586 .63453 L F P
0 g
s
.662 .533 .696 r
.42166 .67164 m .42961 .6662 L .4205 .66738 L closepath p F P
0 g
s
.651 .758 .928 r
.85985 .48625 m .87218 .48245 L .87471 .48593 L p F P
0 g
s
.651 .758 .928 r
.87218 .48245 m .85985 .48625 L .85729 .48277 L p F P
0 g
s
.663 .542 .706 r
.42078 .65915 m .43149 .65775 L p .42961 .6662 L F P
0 g
s
.664 .548 .713 r
.43149 .65775 m .43012 .65332 L .42078 .65915 L closepath p F P
0 g
s
.667 .552 .715 r
.42902 .64968 m .43012 .65332 L .42078 .65915 L p F P
0 g
s
.682 .541 .687 r
.42263 .67511 m .42454 .68264 L .41067 .68379 L p F P
0 g
s
.676 .526 .674 r
.41067 .68379 m .42454 .68264 L p .41693 .69077 L F P
0 g
s
.676 .526 .674 r
.41693 .69077 m .4124 .69114 L .41067 .68379 L p F P
0 g
s
.739 .61 .715 r
.37092 .65439 m .37422 .6509 L .36947 .65042 L closepath p F P
0 g
s
.737 .619 .728 r
.36772 .64599 m .37161 .64197 L p .37422 .6509 L F P
0 g
s
.737 .619 .728 r
.37422 .6509 m .36947 .65042 L .36772 .64599 L p F P
0 g
s
.733 .581 .685 r
.37523 .67552 m .36982 .68267 L .38039 .68367 L p F P
0 g
s
.743 .594 .69 r
.36507 .67439 m .37523 .67552 L .36982 .68267 L p F P
0 g
s
.738 .592 .693 r
.3709 .66712 m .36507 .67439 L .37523 .67552 L p F P
0 g
s
.651 .758 .928 r
.67901 .48645 m .69101 .48267 L .69384 .48615 L p F P
0 g
s
.651 .758 .928 r
.69101 .48267 m .67901 .48645 L .67615 .48296 L p F P
0 g
s
.651 .758 .928 r
.49814 .48649 m .50982 .48272 L .51295 .4862 L p F P
0 g
s
.651 .758 .928 r
.50982 .48272 m .49814 .48649 L .49498 .48301 L p F P
0 g
s
.734 .582 .686 r
.3804 .68367 m .3804 .68366 L .38039 .68367 L closepath p F P
0 g
s
.719 .56 .674 r
.38703 .69138 m .38233 .69122 L .3804 .68367 L p F P
0 g
s
.734 .57 .669 r
.38039 .68367 m .3804 .68367 L .38233 .69122 L p F P
0 g
s
.734 .57 .669 r
.38233 .69122 m .37546 .69069 L .38039 .68367 L p F P
0 g
s
.739 .582 .68 r
.36982 .68267 m .38039 .68367 L .37546 .69069 L p F P
0 g
s
.68 .582 .739 r
.42063 .62501 m .42346 .63295 L .40983 .63437 L p F P
0 g
s
.68 .582 .739 r
.40983 .63437 m .40904 .63225 L .42063 .62501 L p F P
0 g
s
.748 .607 .701 r
.36116 .66586 m .3709 .66712 L .36507 .67439 L p F P
0 g
s
.743 .603 .702 r
.36731 .65849 m .36116 .66586 L .3709 .66712 L p F P
0 g
s
.651 .758 .928 r
.87471 .48593 m .88706 .48213 L .88957 .48561 L p F P
0 g
s
.651 .758 .928 r
.88706 .48213 m .87471 .48593 L .87218 .48245 L p F P
0 g
s
.663 .535 .698 r
.42263 .67511 m .42166 .67164 L .42961 .6662 L p F P
0 g
s
.747 .615 .711 r
.36731 .65849 m .37092 .65439 L .36947 .65042 L p F P
0 g
s
.679 .58 .738 r
.42036 .62427 m .42063 .62501 L .40904 .63225 L p F P
0 g
s
.679 .58 .738 r
.40904 .63225 m .40657 .62554 L .42036 .62427 L p F P
0 g
s
.651 .758 .928 r
.69384 .48615 m .70587 .48237 L .70868 .48585 L p F P
0 g
s
.651 .758 .928 r
.70587 .48237 m .69384 .48615 L .69101 .48267 L p F P
0 g
s
.651 .758 .928 r
.51295 .4862 m .52466 .48242 L .52777 .48591 L p F P
0 g
s
.651 .758 .928 r
.52466 .48242 m .51295 .4862 L .50982 .48272 L p F P
0 g
s
.697 .531 .659 r
.39833 .694 m .40034 .69156 L .39783 .69162 L closepath p F P
0 g
s
.714 .548 .664 r
.39783 .69162 m .39833 .694 L .39478 .69877 L p F P
0 g
s
.714 .548 .664 r
.38703 .69138 m .39783 .69162 L p .39478 .69877 L F P
0 g
s
.727 .612 .729 r
.37941 .63416 m .37949 .63408 L .37938 .63408 L closepath p F P
0 g
s
.742 .631 .737 r
.37938 .63408 m .37941 .63416 L .37161 .64197 L p F P
0 g
s
.726 .621 .741 r
.37798 .62481 m .38926 .62562 L .37949 .63408 L p F P
0 g
s
.726 .621 .741 r
.37619 .62642 m .37798 .62481 L p .37949 .63408 L F P
0 g
s
.726 .621 .741 r
.37949 .63408 m .37938 .63408 L .37619 .62642 L p F P
0 g
s
.742 .631 .737 r
.36969 .63282 m .37938 .63408 L p .37161 .64197 L F P
0 g
s
.744 .63 .733 r
.37938 .63408 m .37619 .62642 L .36969 .63282 L closepath p F P
0 g
s
.693 .529 .661 r
.40034 .69156 m .4124 .69114 L p .40976 .69846 L F P
0 g
s
.693 .529 .661 r
.39833 .694 m .40034 .69156 L p .40976 .69846 L F P
0 g
s
.658 .522 .687 r
.42263 .67511 m .43584 .6733 L p .42652 .68237 L F P
0 g
s
.658 .522 .687 r
.42652 .68237 m .42454 .68264 L .42263 .67511 L p F P
0 g
s
.663 .535 .698 r
.43378 .66563 m .43584 .6733 L .42263 .67511 L p F P
0 g
s
.663 .535 .698 r
.42961 .6662 m .43378 .66563 L p .42263 .67511 L F P
0 g
s
.747 .615 .711 r
.36947 .65042 m .36442 .64965 L p .36731 .65849 L F P
0 g
s
.753 .627 .72 r
.36947 .65042 m .36772 .64599 L .36442 .64965 L closepath p F P
0 g
s
.703 .608 .748 r
.40314 .62563 m .39171 .62575 L .39105 .62413 L p F P
0 g
s
.721 .617 .741 r
.39171 .62575 m .39105 .62413 L .38926 .62562 L closepath p F P
0 g
s
.651 .758 .928 r
.70868 .48585 m .72074 .48207 L .72353 .48555 L p F P
0 g
s
.651 .758 .928 r
.72074 .48207 m .70868 .48585 L .70587 .48237 L p F P
0 g
s
.714 .548 .664 r
.38348 .69627 m .38703 .69138 L p .39478 .69877 L F P
0 g
s
.718 .551 .662 r
.38348 .69627 m .38703 .69138 L .38233 .69122 L closepath p F P
0 g
s
.699 .599 .741 r
.40657 .62554 m .40585 .62369 L .40314 .62563 L closepath p F P
0 g
s
.703 .608 .748 r
.40306 .61646 m .40585 .62369 L .40314 .62563 L p F P
0 g
s
.703 .608 .748 r
.40124 .61648 m .40306 .61646 L p .40314 .62563 L F P
0 g
s
.703 .608 .748 r
.39105 .62413 m .40124 .61648 L p .40314 .62563 L F P
0 g
s
.651 .758 .928 r
.52777 .48591 m .5395 .48213 L .54259 .48562 L p F P
0 g
s
.651 .758 .928 r
.5395 .48213 m .52777 .48591 L .52466 .48242 L p F P
0 g
s
0 0 .312 r
.39651 .45834 m .3965 .45834 L .39664 .45307 L p F P
0 g
s
0 0 .312 r
.39664 .45307 m .39665 .45306 L .39651 .45834 L p F P
0 g
s
.752 .484 .527 r
.39649 .45834 m .3965 .45834 L .39664 .45307 L p F P
0 g
s
.752 .484 .527 r
.39664 .45307 m .39663 .45306 L .39649 .45834 L p F P
0 g
s
.72 .616 .74 r
.38768 .61636 m .37798 .62481 L .38926 .62562 L p F P
0 g
s
.72 .616 .74 r
.3879 .61638 m .38768 .61636 L p .38926 .62562 L F P
0 g
s
.72 .616 .74 r
.38926 .62562 m .39105 .62413 L .3879 .61638 L p F P
0 g
s
.753 .62 .712 r
.358 .65709 m .36731 .65849 L .36116 .66586 L p F P
0 g
s
.747 .615 .711 r
.36442 .64965 m .358 .65709 L .36731 .65849 L p F P
0 g
s
.708 .61 .745 r
.39105 .62413 m .40124 .61648 L .3879 .61638 L closepath p F P
0 g
s
.683 .591 .746 r
.41744 .61648 m .42036 .62427 L .40657 .62554 L p F P
0 g
s
.683 .591 .746 r
.40657 .62554 m .40585 .62369 L .41744 .61648 L p F P
0 g
s
.693 .529 .661 r
.40976 .69846 m .39937 .69882 L .39833 .694 L p F P
0 g
s
.709 .54 .657 r
.39937 .69882 m .39833 .694 L .39478 .69877 L closepath p F P
0 g
s
.744 .622 .724 r
.36772 .64599 m .37161 .64197 L .36585 .64126 L closepath p F P
0 g
s
.742 .631 .737 r
.3645 .63806 m .36969 .63282 L p .37161 .64197 L F P
0 g
s
.742 .631 .737 r
.37161 .64197 m .36585 .64126 L .3645 .63806 L p F P
0 g
s
.728 .557 .659 r
.38233 .69122 m .37546 .69069 L p .38204 .69842 L F P
0 g
s
.728 .557 .659 r
.38204 .69842 m .38348 .69627 L .38233 .69122 L p F P
0 g
s
.674 .514 .66 r
.41312 .69461 m .41693 .69077 L .4124 .69114 L closepath p F P
0 g
s
.693 .529 .661 r
.4124 .69114 m .41312 .69461 L .40976 .69846 L p F P
0 g
s
.651 .758 .928 r
.72353 .48555 m .73561 .48176 L .73837 .48525 L p F P
0 g
s
.651 .758 .928 r
.73561 .48176 m .72353 .48555 L .72074 .48207 L p F P
0 g
s
.651 .758 .928 r
.54259 .48562 m .55435 .48184 L .55741 .48533 L p F P
0 g
s
.651 .758 .928 r
.55435 .48184 m .54259 .48562 L .5395 .48213 L p F P
0 g
s
.683 .59 .745 r
.41701 .61533 m .41744 .61648 L .40585 .62369 L p F P
0 g
s
.683 .59 .745 r
.40585 .62369 m .40306 .61646 L .41701 .61533 L p F P
0 g
s
.65 .757 .928 r
.36165 .48563 m .37308 .48185 L .37645 .48534 L p F P
0 g
s
.752 .626 .72 r
.36442 .64965 m .36772 .64599 L .36585 .64126 L p F P
0 g
s
.739 .582 .68 r
.36545 .68883 m .36982 .68267 L p .37546 .69069 L F P
0 g
s
.744 .584 .677 r
.36545 .68883 m .36982 .68267 L .36353 .68199 L closepath p F P
0 g
s
.743 .594 .69 r
.36232 .67809 m .36507 .67439 L p .36982 .68267 L F P
0 g
s
.743 .594 .69 r
.36982 .68267 m .36353 .68199 L .36232 .67809 L p F P
0 g
s
.651 .758 .928 r
.73837 .48525 m .75049 .48146 L .75323 .48495 L p F P
0 g
s
.651 .758 .928 r
.75049 .48146 m .73837 .48525 L .73561 .48176 L p F P
0 g
s
.66 .54 .706 r
.43378 .66563 m .43327 .6639 L .42961 .6662 L closepath p F P
0 g
s
.663 .542 .706 r
.43149 .65775 m .43327 .6639 L .42961 .6662 L p F P
0 g
s
.655 .508 .672 r
.42478 .68369 m .42652 .68237 L .42454 .68264 L closepath p F P
0 g
s
.676 .526 .674 r
.42454 .68264 m .42478 .68369 L .41693 .69077 L p F P
0 g
s
.651 .758 .928 r
.55741 .48533 m .5692 .48154 L .57224 .48503 L p F P
0 g
s
.651 .758 .928 r
.5692 .48154 m .55741 .48533 L .55435 .48184 L p F P
0 g
s
.65 .757 .928 r
.37645 .48534 m .38791 .48156 L .39125 .48505 L p F P
0 g
s
.65 .757 .928 r
.38791 .48156 m .37645 .48534 L .37308 .48185 L p F P
0 g
s
.749 .597 .687 r
.36232 .67809 m .36507 .67439 L .36101 .67388 L closepath p F P
0 g
s
.748 .607 .701 r
.35915 .66843 m .36116 .66586 L p .36507 .67439 L F P
0 g
s
.748 .607 .701 r
.36507 .67439 m .36101 .67388 L .35915 .66843 L p F P
0 g
s
.646 .536 .715 r
.43012 .65332 m .42902 .64968 L .4417 .64731 L p F P
0 g
s
.65 .547 .724 r
.43905 .63907 m .4417 .64731 L .42902 .64968 L p F P
0 g
s
.65 .547 .724 r
.43321 .64018 m .43905 .63907 L p .42902 .64968 L F P
0 g
s
.65 .547 .724 r
.42902 .64968 m .42697 .64337 L .43321 .64018 L p F P
0 g
s
.675 .515 .661 r
.41693 .69077 m .4262 .68992 L p .41388 .69828 L F P
0 g
s
.675 .515 .661 r
.41388 .69828 m .41312 .69461 L .41693 .69077 L p F P
0 g
s
.672 .52 .67 r
.4262 .68992 m .42478 .68369 L .41693 .69077 L closepath p F P
0 g
s
.757 .632 .722 r
.35556 .6481 m .36442 .64965 L .358 .65709 L p F P
0 g
s
.752 .626 .72 r
.36214 .64061 m .35556 .6481 L .36442 .64965 L p F P
0 g
s
.752 .626 .72 r
.36585 .64126 m .36214 .64061 L p .36442 .64965 L F P
0 g
s
.649 .545 .723 r
.42697 .64337 m .43321 .64018 L .42634 .64142 L closepath p F P
0 g
s
.651 .554 .732 r
.43321 .64018 m .42634 .64142 L .4238 .63396 L p F P
0 g
s
.656 .51 .673 r
.4262 .68992 m .42478 .68369 L .42652 .68237 L p F P
0 g
s
.647 .538 .717 r
.43149 .65775 m .43012 .65332 L .44172 .64738 L p F P
0 g
s
.646 .536 .715 r
.4417 .64731 m .44172 .64738 L .43012 .65332 L p F P
0 g
s
.728 .557 .659 r
.37546 .69069 m .371 .69757 L .38204 .69842 L p F P
0 g
s
.739 .568 .662 r
.36572 .6898 m .37546 .69069 L .371 .69757 L p F P
0 g
s
.739 .582 .68 r
.37546 .69069 m .36572 .6898 L .36545 .68883 L p F P
0 g
s
.651 .758 .928 r
.75323 .48495 m .76537 .48116 L .76808 .48464 L p F P
0 g
s
.651 .758 .928 r
.76537 .48116 m .75323 .48495 L .75049 .48146 L p F P
0 g
s
.642 .527 .708 r
.43327 .6639 m .43149 .65775 L .44411 .65532 L p F P
0 g
s
.647 .538 .717 r
.44172 .64738 m .44411 .65532 L .43149 .65775 L p F P
0 g
s
.688 .524 .658 r
.41388 .69828 m .41312 .69461 L .40976 .69846 L closepath p F P
0 g
s
.714 .548 .664 r
.39478 .69877 m .384 .69855 L .38348 .69627 L p F P
0 g
s
.729 .558 .659 r
.384 .69855 m .38348 .69627 L .38204 .69842 L closepath p F P
0 g
s
.691 .516 .646 r
.39937 .69882 m .40976 .69846 L .40431 .70565 L p F P
0 g
s
.691 .516 .646 r
.40431 .70565 m .40066 .70577 L .39937 .69882 L p F P
0 g
s
.708 .528 .643 r
.39478 .69877 m .39937 .69882 L .40066 .70577 L p F P
0 g
s
.732 .624 .738 r
.37619 .62642 m .37798 .62481 L .37543 .62458 L closepath p F P
0 g
s
.746 .643 .746 r
.37543 .62458 m .37619 .62642 L .36969 .63282 L p F P
0 g
s
.654 .517 .684 r
.43769 .68076 m .4364 .67558 L .42652 .68237 L closepath p F P
0 g
s
.658 .522 .687 r
.43584 .6733 m .4364 .67558 L .42652 .68237 L p F P
0 g
s
.656 .51 .673 r
.42652 .68237 m .43769 .68076 L p .4262 .68992 L F P
0 g
s
.651 .758 .928 r
.57224 .48503 m .58406 .48125 L .58707 .48474 L p F P
0 g
s
.651 .758 .928 r
.58406 .48125 m .57224 .48503 L .5692 .48154 L p F P
0 g
s
.758 .638 .729 r
.36585 .64126 m .3645 .63806 L .36214 .64061 L closepath p F P
0 g
s
.651 .757 .928 r
.39125 .48505 m .40274 .48127 L .40606 .48476 L p F P
0 g
s
.651 .757 .928 r
.40274 .48127 m .39125 .48505 L .38791 .48156 L p F P
0 g
s
.73 .633 .75 r
.37711 .61533 m .38768 .61636 L .37798 .62481 L p F P
0 g
s
.73 .633 .75 r
.37295 .61901 m .37711 .61533 L p .37798 .62481 L F P
0 g
s
.73 .633 .75 r
.37798 .62481 m .37543 .62458 L .37295 .61901 L p F P
0 g
s
.708 .528 .643 r
.40066 .70577 m .3903 .70567 L .39478 .69877 L p F P
0 g
s
.713 .534 .646 r
.384 .69855 m .39478 .69877 L .3903 .70567 L p F P
0 g
s
.651 .554 .732 r
.4238 .63396 m .42696 .63234 L p .43321 .64018 L F P
0 g
s
.653 .554 .73 r
.4238 .63396 m .42696 .63234 L .42346 .63295 L closepath p F P
0 g
s
.755 .61 .698 r
.35915 .66843 m .36116 .66586 L .35812 .66541 L closepath p F P
0 g
s
.753 .62 .712 r
.35596 .65961 m .358 .65709 L p .36116 .66586 L F P
0 g
s
.753 .62 .712 r
.36116 .66586 m .35812 .66541 L .35596 .65961 L p F P
0 g
s
.654 .563 .74 r
.42696 .63234 m .42346 .63295 L .42063 .62501 L p F P
0 g
s
.651 .758 .928 r
.76808 .48464 m .78025 .48085 L .78294 .48434 L p F P
0 g
s
.651 .758 .928 r
.78025 .48085 m .76808 .48464 L .76537 .48116 L p F P
0 g
s
.749 .634 .733 r
.3645 .63806 m .36969 .63282 L .36178 .63166 L closepath p F P
0 g
s
.746 .643 .746 r
.36835 .62349 m .37543 .62458 L p .36969 .63282 L F P
0 g
s
.746 .643 .746 r
.36126 .63051 m .36835 .62349 L p .36969 .63282 L F P
0 g
s
.746 .643 .746 r
.36969 .63282 m .36178 .63166 L .36126 .63051 L p F P
0 g
s
.642 .529 .71 r
.43378 .66563 m .43327 .6639 L .44487 .65801 L p F P
0 g
s
.642 .527 .708 r
.44411 .65532 m .44487 .65801 L .43327 .6639 L p F P
0 g
s
.749 .641 .741 r
.37543 .62458 m .37295 .61901 L .36835 .62349 L closepath p F P
0 g
s
.651 .758 .928 r
.58707 .48474 m .59892 .48095 L .60191 .48444 L p F P
0 g
s
.651 .758 .928 r
.59892 .48095 m .58707 .48474 L .58406 .48125 L p F P
0 g
s
.713 .534 .646 r
.3903 .70567 m .38535 .70557 L .384 .69855 L p F P
0 g
s
.729 .545 .642 r
.38204 .69842 m .384 .69855 L .38535 .70557 L p F P
0 g
s
.758 .601 .684 r
.36101 .67388 m .35581 .67299 L p .35996 .68145 L F P
0 g
s
.758 .601 .684 r
.35996 .68145 m .36232 .67809 L .36101 .67388 L p F P
0 g
s
.763 .614 .694 r
.36101 .67388 m .35915 .66843 L .35581 .67299 L closepath p F P
0 g
s
.651 .757 .928 r
.40606 .48476 m .41757 .48098 L .42087 .48447 L p F P
0 g
s
.65 .757 .928 r
.41757 .48098 m .40606 .48476 L .40274 .48127 L p F P
0 g
s
.639 .516 .698 r
.43378 .66563 m .44634 .66315 L p .44312 .67188 L F P
0 g
s
.639 .516 .698 r
.44312 .67188 m .43584 .6733 L .43378 .66563 L p F P
0 g
s
.642 .529 .71 r
.44487 .65801 m .44634 .66315 L .43378 .66563 L p F P
0 g
s
.758 .602 .684 r
.36353 .68199 m .36232 .67809 L .35996 .68145 L closepath p F P
0 g
s
.686 .51 .642 r
.40976 .69846 m .41388 .69828 L .41511 .70516 L p F P
0 g
s
.686 .51 .642 r
.41511 .70516 m .40431 .70565 L .40976 .69846 L p F P
0 g
s
.752 .589 .674 r
.36353 .68199 m .35996 .68145 L p .36488 .68969 L F P
0 g
s
.752 .589 .674 r
.36488 .68969 m .36545 .68883 L .36353 .68199 L p F P
0 g
s
.729 .545 .642 r
.38535 .70557 m .37824 .70512 L .38204 .69842 L p F P
0 g
s
.733 .554 .649 r
.371 .69757 m .38204 .69842 L .37824 .70512 L p F P
0 g
s
.763 .614 .694 r
.35581 .67299 m .35915 .66843 L .35812 .66541 L p F P
0 g
s
.757 .638 .729 r
.36214 .64061 m .3645 .63806 L .36178 .63166 L p F P
0 g
s
.651 .758 .928 r
.78294 .48434 m .79514 .48054 L .7978 .48403 L p F P
0 g
s
.651 .758 .928 r
.79514 .48054 m .78294 .48434 L .78025 .48085 L p F P
0 g
s
.654 .563 .74 r
.42063 .62501 m .42293 .62384 L p .42696 .63234 L F P
0 g
s
.657 .563 .738 r
.42063 .62501 m .42293 .62384 L .42036 .62427 L closepath p F P
0 g
s
.763 .614 .694 r
.35812 .66541 m .35237 .6643 L p .35581 .67299 L F P
0 g
s
.768 .627 .704 r
.35812 .66541 m .35596 .65961 L .35237 .6643 L closepath p F P
0 g
s
.651 .758 .928 r
.60191 .48444 m .61378 .48066 L .61675 .48415 L p F P
0 g
s
.651 .758 .928 r
.61378 .48066 m .60191 .48444 L .59892 .48095 L p F P
0 g
s
.651 .758 .928 r
.42087 .48447 m .43241 .48069 L .43568 .48418 L p F P
0 g
s
.651 .757 .928 r
.43241 .48069 m .42087 .48447 L .41757 .48098 L p F P
0 g
s
.668 .498 .645 r
.41388 .69828 m .42766 .69703 L p .42201 .70455 L F P
0 g
s
.668 .498 .645 r
.42201 .70455 m .41511 .70516 L .41388 .69828 L p F P
0 g
s
.675 .515 .661 r
.4262 .68992 m .42766 .69703 L .41388 .69828 L p F P
0 g
s
.658 .572 .747 r
.42293 .62384 m .42036 .62427 L .41744 .61648 L p F P
0 g
s
.76 .623 .708 r
.35596 .65961 m .358 .65709 L .35481 .65655 L closepath p F P
0 g
s
.757 .632 .722 r
.35273 .65145 m .35556 .6481 L p .358 .65709 L F P
0 g
s
.757 .632 .722 r
.358 .65709 m .35481 .65655 L .35273 .65145 L p F P
0 g
s
.762 .645 .733 r
.35374 .63891 m .36214 .64061 L .35556 .6481 L p F P
0 g
s
.757 .638 .729 r
.36042 .63139 m .35374 .63891 L .36214 .64061 L p F P
0 g
s
.757 .638 .729 r
.36178 .63166 m .36042 .63139 L p .36214 .64061 L F P
0 g
s
.651 .498 .662 r
.4262 .68992 m .43935 .68805 L p .42939 .69678 L F P
0 g
s
.651 .498 .662 r
.42939 .69678 m .42766 .69703 L .4262 .68992 L p F P
0 g
s
.656 .51 .673 r
.43769 .68076 m .43935 .68805 L .4262 .68992 L p F P
0 g
s
.651 .554 .732 r
.42696 .63234 m .43622 .63064 L p .43321 .64018 L F P
0 g
s
.651 .56 .739 r
.43622 .63064 m .43538 .62829 L .42696 .63234 L closepath p F P
0 g
s
.654 .563 .74 r
.43318 .62201 m .43538 .62829 L .42696 .63234 L p F P
0 g
s
.654 .563 .74 r
.42293 .62384 m .43318 .62201 L p .42696 .63234 L F P
0 g
s
.651 .758 .928 r
.7978 .48403 m .81003 .48023 L .81267 .48372 L p F P
0 g
s
.651 .758 .928 r
.81003 .48023 m .7978 .48403 L .79514 .48054 L p F P
0 g
s
.753 .59 .674 r
.36572 .6898 m .36545 .68883 L .36488 .68969 L closepath p F P
0 g
s
.651 .758 .928 r
.61675 .48415 m .62865 .48036 L .63159 .48385 L p F P
0 g
s
.651 .758 .928 r
.62865 .48036 m .61675 .48415 L .61378 .48066 L p F P
0 g
s
.739 .568 .662 r
.371 .69757 m .36753 .69726 L .36572 .6898 L p F P
0 g
s
.755 .578 .657 r
.36488 .68969 m .36572 .6898 L .36753 .69726 L p F P
0 g
s
.651 .758 .928 r
.43568 .48418 m .44726 .48039 L .4505 .48389 L p F P
0 g
s
.651 .758 .928 r
.44726 .48039 m .43568 .48418 L .43241 .48069 L p F P
0 g
s
.636 .504 .686 r
.4364 .67558 m .44312 .67188 L .43584 .6733 L closepath p F P
0 g
s
.755 .578 .657 r
.36753 .69726 m .36103 .69639 L .36488 .68969 L p F P
0 g
s
.759 .585 .661 r
.35564 .68829 m .36488 .68969 L .36103 .69639 L p F P
0 g
s
.752 .589 .674 r
.35996 .68145 m .35564 .68829 L .36488 .68969 L p F P
0 g
s
.758 .601 .684 r
.35581 .67299 m .35107 .67994 L .35996 .68145 L p F P
0 g
s
.763 .605 .682 r
.35107 .67994 m .35996 .68145 L .35564 .68829 L p F P
0 g
s
.768 .627 .704 r
.35237 .6643 m .35596 .65961 L .35481 .65655 L p F P
0 g
s
.654 .568 .746 r
.43318 .62201 m .43221 .61937 L .42293 .62384 L closepath p F P
0 g
s
.658 .572 .747 r
.42994 .61317 m .43221 .61937 L .42293 .62384 L p F P
0 g
s
.658 .572 .747 r
.42087 .61472 m .42994 .61317 L p .42293 .62384 L F P
0 g
s
.658 .572 .747 r
.41744 .61648 m .42087 .61472 L p .42293 .62384 L F P
0 g
s
.651 .758 .928 r
.81267 .48372 m .82493 .47992 L .82754 .48341 L p F P
0 g
s
.651 .758 .928 r
.82493 .47992 m .81267 .48372 L .81003 .48023 L p F P
0 g
s
.651 .758 .928 r
.63159 .48385 m .64352 .48007 L .64644 .48356 L p F P
0 g
s
.651 .758 .928 r
.64352 .48007 m .63159 .48385 L .62865 .48036 L p F P
0 g
s
.651 .758 .928 r
.4505 .48389 m .4621 .4801 L .46532 .48359 L p F P
0 g
s
.651 .758 .928 r
.4621 .4801 m .4505 .48389 L .44726 .48039 L p F P
0 g
s
.648 .553 .733 r
.43905 .63907 m .43856 .6376 L .43321 .64018 L closepath p F P
0 g
s
.651 .554 .732 r
.43622 .63064 m .43856 .6376 L .43321 .64018 L p F P
0 g
s
.637 .506 .687 r
.43769 .68076 m .4364 .67558 L .44312 .67188 L p F P
0 g
s
.768 .627 .704 r
.35481 .65655 m .34959 .65542 L p .35237 .6643 L F P
0 g
s
.772 .639 .714 r
.35481 .65655 m .35273 .65145 L .34959 .65542 L closepath p F P
0 g
s
.66 .573 .746 r
.41744 .61648 m .42087 .61472 L .41701 .61533 L closepath p F P
0 g
s
.768 .619 .694 r
.34729 .67135 m .35581 .67299 L .35107 .67994 L p F P
0 g
s
.763 .614 .694 r
.35237 .6643 m .34729 .67135 L .35581 .67299 L p F P
0 g
s
.737 .636 .747 r
.37295 .61901 m .37711 .61533 L .371 .61463 L closepath p F P
0 g
s
.749 .641 .741 r
.36835 .62349 m .37295 .61901 L .371 .61463 L p F P
0 g
s
.651 .758 .928 r
.82754 .48341 m .83983 .4796 L .84242 .48309 L p F P
0 g
s
.651 .758 .928 r
.83983 .4796 m .82754 .48341 L .82493 .47992 L p F P
0 g
s
.733 .554 .649 r
.3685 .70196 m .371 .69757 L p .37824 .70512 L F P
0 g
s
.739 .557 .647 r
.3685 .70196 m .371 .69757 L .36753 .69726 L closepath p F P
0 g
s
.689 .501 .628 r
.40134 .71033 m .40431 .70565 L .40066 .70577 L closepath p F P
0 g
s
.702 .51 .626 r
.40066 .70577 m .3903 .70567 L p .40012 .71247 L F P
0 g
s
.702 .51 .626 r
.40012 .71247 m .40134 .71033 L .40066 .70577 L p F P
0 g
s
.755 .644 .738 r
.36835 .62349 m .36126 .63051 L .358 .62344 L p F P
0 g
s
.755 .644 .738 r
.358 .62344 m .35948 .62192 L .36835 .62349 L p F P
0 g
s
.749 .641 .741 r
.36751 .61399 m .35948 .62192 L .36835 .62349 L p F P
0 g
s
.749 .641 .741 r
.371 .61463 m .36751 .61399 L p .36835 .62349 L F P
0 g
s
.651 .758 .928 r
.64644 .48356 m .6584 .47977 L .66129 .48326 L p F P
0 g
s
.651 .758 .928 r
.6584 .47977 m .64644 .48356 L .64352 .48007 L p F P
0 g
s
.651 .758 .928 r
.46532 .48359 m .47696 .47981 L .48015 .4833 L p F P
0 g
s
.651 .758 .928 r
.47696 .47981 m .46532 .48359 L .4621 .4801 L p F P
0 g
s
.762 .65 .737 r
.36178 .63166 m .36126 .63051 L .36042 .63139 L closepath p F P
0 g
s
.765 .636 .718 r
.35273 .65145 m .35556 .6481 L .35101 .64722 L closepath p F P
0 g
s
.762 .645 .733 r
.34949 .64379 m .35374 .63891 L p .35556 .6481 L F P
0 g
s
.762 .645 .733 r
.35556 .6481 m .35101 .64722 L .34949 .64379 L p F P
0 g
s
.702 .51 .626 r
.3903 .70567 m .38658 .71236 L .40012 .71247 L p F P
0 g
s
.712 .521 .63 r
.38535 .70557 m .3903 .70567 L .38658 .71236 L p F P
0 g
s
.69 .502 .629 r
.40431 .70565 m .41511 .70516 L p .40166 .71247 L F P
0 g
s
.69 .502 .629 r
.40166 .71247 m .40134 .71033 L .40431 .70565 L p F P
0 g
s
.712 .521 .63 r
.38658 .71236 m .38642 .71235 L .38535 .70557 L p F P
0 g
s
.729 .533 .626 r
.37824 .70512 m .38535 .70557 L .38642 .71235 L p F P
0 g
s
.651 .758 .928 r
.84242 .48309 m .85473 .47928 L .85729 .48277 L p F P
0 g
s
.651 .758 .928 r
.85473 .47928 m .84242 .48309 L .83983 .4796 L p F P
0 g
s
.764 .652 .739 r
.36042 .63139 m .36126 .63051 L .358 .62344 L p F P
0 g
s
.748 .563 .644 r
.36753 .69726 m .36103 .69639 L p .3673 .70423 L F P
0 g
s
.748 .563 .644 r
.3673 .70423 m .3685 .70196 L .36753 .69726 L p F P
0 g
s
.651 .758 .928 r
.66129 .48326 m .67328 .47947 L .67615 .48296 L p F P
0 g
s
.651 .758 .928 r
.67328 .47947 m .66129 .48326 L .6584 .47977 L p F P
0 g
s
.651 .758 .928 r
.48015 .4833 m .49181 .47951 L .49498 .48301 L p F P
0 g
s
.651 .758 .928 r
.49181 .47951 m .48015 .4833 L .47696 .47981 L p F P
0 g
s
.637 .506 .687 r
.4484 .67082 m .45022 .67826 L .43769 .68076 L p F P
0 g
s
.637 .506 .687 r
.44312 .67188 m .4484 .67082 L p .43769 .68076 L F P
0 g
s
.632 .495 .677 r
.43769 .68076 m .45022 .67826 L p .44154 .68762 L F P
0 g
s
.632 .495 .677 r
.44154 .68762 m .43935 .68805 L .43769 .68076 L p F P
0 g
s
.772 .633 .706 r
.34423 .66255 m .35237 .6643 L .34729 .67135 L p F P
0 g
s
.768 .627 .704 r
.34959 .65542 m .34423 .66255 L .35237 .6643 L p F P
0 g
s
.766 .658 .743 r
.35248 .62954 m .36042 .63139 L .35374 .63891 L p F P
0 g
s
.764 .652 .739 r
.358 .62344 m .35248 .62954 L .36042 .63139 L p F P
0 g
s
.773 .639 .714 r
.34959 .65542 m .35273 .65145 L .35101 .64722 L p F P
0 g
s
.651 .758 .928 r
.85729 .48277 m .86964 .47896 L .87218 .48245 L p F P
0 g
s
.651 .758 .928 r
.86964 .47896 m .85729 .48277 L .85473 .47928 L p F P
0 g
s
.647 .48 .643 r
.42786 .69817 m .42939 .69678 L .42766 .69703 L closepath p F P
0 g
s
.668 .498 .645 r
.42766 .69703 m .42786 .69817 L .42201 .70455 L p F P
0 g
s
.651 .758 .928 r
.67615 .48296 m .68816 .47917 L .69101 .48267 L p F P
0 g
s
.651 .758 .928 r
.68816 .47917 m .67615 .48296 L .67328 .47947 L p F P
0 g
s
.651 .758 .928 r
.49498 .48301 m .50667 .47922 L .50982 .48272 L p F P
0 g
s
.651 .758 .928 r
.50667 .47922 m .49498 .48301 L .49181 .47951 L p F P
0 g
s
0 0 .332 r
.39637 .46363 m .39636 .46364 L .3965 .45834 L p F P
0 g
s
0 0 .332 r
.3965 .45834 m .39651 .45834 L .39637 .46363 L p F P
0 g
s
.745 .478 .527 r
.39634 .46364 m .39636 .46364 L .3965 .45834 L p F P
0 g
s
.745 .478 .527 r
.3965 .45834 m .39649 .45834 L .39634 .46364 L p F P
0 g
s
.666 .484 .629 r
.41511 .70516 m .42201 .70455 L .41631 .71182 L p F P
0 g
s
.666 .484 .629 r
.41631 .71182 m .41609 .71184 L .41511 .70516 L p F P
0 g
s
.69 .502 .629 r
.41511 .70516 m .41609 .71184 L .40166 .71247 L p F P
0 g
s
.729 .533 .626 r
.38642 .71235 m .37511 .71163 L .37824 .70512 L p F P
0 g
s
.733 .538 .629 r
.36902 .70443 m .37824 .70512 L .37511 .71163 L p F P
0 g
s
.733 .554 .649 r
.37824 .70512 m .36902 .70443 L .3685 .70196 L p F P
0 g
s
.651 .758 .928 r
.87218 .48245 m .88455 .47864 L .88706 .48213 L p F P
0 g
s
.651 .758 .928 r
.88455 .47864 m .87218 .48245 L .86964 .47896 L p F P
0 g
s
.648 .481 .644 r
.42884 .70387 m .42786 .69817 L .42939 .69678 L p F P
0 g
s
.664 .492 .642 r
.42884 .70387 m .42786 .69817 L .42201 .70455 L closepath p F P
0 g
s
.648 .481 .644 r
.42939 .69678 m .44075 .69509 L p .42884 .70387 L F P
0 g
s
.647 .491 .658 r
.44075 .69509 m .43951 .68886 L .42939 .69678 L closepath p F P
0 g
s
.651 .498 .662 r
.43935 .68805 m .43951 .68886 L .42939 .69678 L p F P
0 g
s
.651 .758 .928 r
.69101 .48267 m .70305 .47887 L .70587 .48237 L p F P
0 g
s
.651 .758 .928 r
.70305 .47887 m .69101 .48267 L .68816 .47917 L p F P
0 g
s
.651 .758 .928 r
.50982 .48272 m .52154 .47893 L .52466 .48242 L p F P
0 g
s
.651 .758 .928 r
.52154 .47893 m .50982 .48272 L .50667 .47922 L p F P
0 g
s
.621 .518 .716 r
.44172 .64738 m .44236 .64713 L .4417 .64731 L closepath p F P
0 g
s
.624 .531 .728 r
.44236 .64713 m .4417 .64731 L .43905 .63907 L p F P
0 g
s
.622 .52 .718 r
.44411 .65532 m .44172 .64738 L .44236 .64713 L p F P
0 g
s
.624 .531 .728 r
.43905 .63907 m .45101 .63593 L p .44236 .64713 L F P
0 g
s
.627 .54 .737 r
.45015 .63339 m .45101 .63593 L .43905 .63907 L p F P
0 g
s
.627 .54 .737 r
.43905 .63907 m .43856 .6376 L .45015 .63339 L p F P
0 g
s
.627 .538 .735 r
.44819 .62751 m .45015 .63339 L .43856 .6376 L p F P
0 g
s
.627 .538 .735 r
.43856 .6376 m .43622 .63064 L .44819 .62751 L p F P
0 g
s
.773 .639 .714 r
.35101 .64722 m .34739 .64634 L p .34959 .65542 L F P
0 g
s
.777 .652 .724 r
.35101 .64722 m .34949 .64379 L .34739 .64634 L closepath p F P
0 g
s
.637 .516 .699 r
.4484 .67082 m .44801 .6694 L .44312 .67188 L closepath p F P
0 g
s
.639 .516 .698 r
.44634 .66315 m .44801 .6694 L .44312 .67188 L p F P
0 g
s
.777 .646 .718 r
.34182 .65353 m .34959 .65542 L .34423 .66255 L p F P
0 g
s
.773 .639 .714 r
.34739 .64634 m .34182 .65353 L .34959 .65542 L p F P
0 g
s
.749 .564 .645 r
.36902 .70443 m .3685 .70196 L .3673 .70423 L closepath p F P
0 g
s
.77 .649 .729 r
.34949 .64379 m .35374 .63891 L .34662 .63733 L closepath p F P
0 g
s
.766 .658 .743 r
.34623 .63651 m .35248 .62954 L p .35374 .63891 L F P
0 g
s
.766 .658 .743 r
.35374 .63891 m .34662 .63733 L .34623 .63651 L p F P
0 g
s
.759 .585 .661 r
.36103 .69639 m .3517 .69502 L .35564 .68829 L p F P
0 g
s
.764 .592 .665 r
.34755 .68695 m .35564 .68829 L .3517 .69502 L p F P
0 g
s
.763 .605 .682 r
.34723 .68594 m .35107 .67994 L p .35564 .68829 L F P
0 g
s
.763 .605 .682 r
.35564 .68829 m .34755 .68695 L .34723 .68594 L p F P
0 g
s
.622 .52 .718 r
.44236 .64713 m .45364 .64416 L p .44411 .65532 L F P
0 g
s
.624 .531 .729 r
.45364 .64416 m .45332 .64317 L .44236 .64713 L closepath p F P
0 g
s
.624 .531 .728 r
.45101 .63593 m .45332 .64317 L .44236 .64713 L p F P
0 g
s
.702 .511 .627 r
.40166 .71247 m .40134 .71033 L .40012 .71247 L closepath p F P
0 g
s
.629 .548 .744 r
.44698 .62405 m .44819 .62751 L .43622 .63064 L p F P
0 g
s
.629 .548 .744 r
.43622 .63064 m .43538 .62829 L .44698 .62405 L p F P
0 g
s
.651 .758 .928 r
.70587 .48237 m .71795 .47857 L .72074 .48207 L p F P
0 g
s
.651 .758 .928 r
.71795 .47857 m .70587 .48237 L .70305 .47887 L p F P
0 g
s
.618 .51 .708 r
.44487 .65801 m .44411 .65532 L .45606 .65219 L p F P
0 g
s
.622 .52 .718 r
.45364 .64416 m .45606 .65219 L .44411 .65532 L p F P
0 g
s
.651 .758 .928 r
.52466 .48242 m .5364 .47863 L .5395 .48213 L p F P
0 g
s
.651 .758 .928 r
.5364 .47863 m .52466 .48242 L .52154 .47893 L p F P
0 g
s
.77 .609 .679 r
.34723 .68594 m .35107 .67994 L .34501 .67881 L closepath p F P
0 g
s
.768 .619 .694 r
.34407 .6761 m .34729 .67135 L p .35107 .67994 L F P
0 g
s
.768 .619 .694 r
.35107 .67994 m .34501 .67881 L .34407 .6761 L p F P
0 g
s
.748 .563 .644 r
.36103 .69639 m .35767 .70295 L .3673 .70423 L p F P
0 g
s
.759 .576 .65 r
.3517 .69502 m .36103 .69639 L .35767 .70295 L p F P
0 g
s
.629 .546 .742 r
.44518 .61889 m .44698 .62405 L .43538 .62829 L p F P
0 g
s
.629 .546 .742 r
.43538 .62829 m .43318 .62201 L .44518 .61889 L p F P
0 g
s
.619 .512 .71 r
.44634 .66315 m .44487 .65801 L .45648 .65369 L p F P
0 g
s
.618 .51 .708 r
.45606 .65219 m .45648 .65369 L .44487 .65801 L p F P
0 g
s
.661 .477 .625 r
.42201 .70455 m .42884 .70387 L .42977 .71048 L p F P
0 g
s
.661 .477 .625 r
.42977 .71048 m .41631 .71182 L .42201 .70455 L p F P
0 g
s
.757 .661 .757 r
.35926 .61222 m .36751 .61399 L .35948 .62192 L p F P
0 g
s
.628 .478 .659 r
.43951 .68886 m .44154 .68762 L .43935 .68805 L closepath p F P
0 g
s
.651 .758 .928 r
.72074 .48207 m .73284 .47827 L .73561 .48176 L p F P
0 g
s
.651 .758 .928 r
.73284 .47827 m .72074 .48207 L .71795 .47857 L p F P
0 g
s
.733 .538 .629 r
.37511 .71163 m .37014 .71126 L .36902 .70443 L p F P
0 g
s
.749 .549 .624 r
.3673 .70423 m .36902 .70443 L .37014 .71126 L p F P
0 g
s
.651 .758 .928 r
.5395 .48213 m .55128 .47834 L .55435 .48184 L p F P
0 g
s
.651 .758 .928 r
.55128 .47834 m .5395 .48213 L .5364 .47863 L p F P
0 g
s
.629 .479 .66 r
.44075 .69509 m .43951 .68886 L .44154 .68762 L p F P
0 g
s
.632 .556 .751 r
.4438 .61511 m .44518 .61889 L .43318 .62201 L p F P
0 g
s
.632 .556 .751 r
.43318 .62201 m .43221 .61937 L .4438 .61511 L p F P
0 g
s
.615 .501 .7 r
.44801 .6694 m .44634 .66315 L .45828 .66002 L p F P
0 g
s
.619 .512 .71 r
.45648 .65369 m .45828 .66002 L .44634 .66315 L p F P
0 g
s
.775 .623 .691 r
.34407 .6761 m .34729 .67135 L .34203 .67025 L closepath p F P
0 g
s
.772 .633 .706 r
.34086 .66724 m .34423 .66255 L p .34729 .67135 L F P
0 g
s
.772 .633 .706 r
.34729 .67135 m .34203 .67025 L .34086 .66724 L p F P
0 g
s
.777 .652 .724 r
.34739 .64634 m .34949 .64379 L .34662 .63733 L p F P
0 g
s
.76 .652 .743 r
.358 .62344 m .35948 .62192 L .35707 .62144 L closepath p F P
0 g
s
.757 .661 .757 r
.35472 .61675 m .35926 .61222 L p .35948 .62192 L F P
0 g
s
.757 .661 .757 r
.35948 .62192 m .35707 .62144 L .35472 .61675 L p F P
0 g
s
.7 .491 .603 r
.40012 .71247 m .40166 .71247 L .40231 .71885 L p F P
0 g
s
.7 .491 .603 r
.40231 .71885 m .39746 .71886 L .40012 .71247 L p F P
0 g
s
.704 .497 .605 r
.38658 .71236 m .40012 .71247 L .39746 .71886 L p F P
0 g
s
.681 .478 .604 r
.40166 .71247 m .41609 .71184 L p .41305 .71838 L F P
0 g
s
.681 .478 .604 r
.41305 .71838 m .40231 .71885 L .40166 .71247 L p F P
0 g
s
.749 .549 .624 r
.37014 .71126 m .36459 .71062 L .3673 .70423 L p F P
0 g
s
.754 .556 .628 r
.35767 .70295 m .3673 .70423 L .36459 .71062 L p F P
0 g
s
.651 .758 .928 r
.73561 .48176 m .74774 .47796 L .75049 .48146 L p F P
0 g
s
.651 .758 .928 r
.74774 .47796 m .73561 .48176 L .73284 .47827 L p F P
0 g
s
.771 .657 .736 r
.35248 .62954 m .358 .62344 L .35707 .62144 L p F P
0 g
s
.651 .758 .928 r
.55435 .48184 m .56615 .47804 L .5692 .48154 L p F P
0 g
s
.651 .758 .928 r
.56615 .47804 m .55435 .48184 L .55128 .47834 L p F P
0 g
s
.65 .757 .928 r
.37308 .48185 m .38456 .47806 L .38791 .48156 L p F P
0 g
s
.632 .554 .749 r
.44196 .61006 m .4438 .61511 L .43221 .61937 L p F P
0 g
s
.632 .554 .749 r
.43221 .61937 m .42994 .61317 L .44196 .61006 L p F P
0 g
s
.704 .497 .605 r
.38646 .71267 m .38658 .71236 L p .39746 .71886 L F P
0 g
s
.709 .501 .604 r
.38646 .71267 m .38658 .71236 L .38642 .71235 L closepath p F P
0 g
s
.722 .51 .603 r
.38642 .71235 m .37511 .71163 L p .38428 .71863 L F P
0 g
s
.722 .51 .603 r
.38428 .71863 m .38646 .71267 L .38642 .71235 L p F P
0 g
s
.629 .479 .66 r
.44154 .68762 m .45186 .68552 L p .44075 .69509 L F P
0 g
s
.63 .492 .675 r
.45186 .68552 m .45114 .68237 L .44154 .68762 L closepath p F P
0 g
s
.632 .495 .677 r
.45022 .67826 m .45114 .68237 L .44154 .68762 L p F P
0 g
s
.704 .497 .605 r
.39746 .71886 m .3871 .71877 L .38646 .71267 L p F P
0 g
s
.722 .51 .603 r
.3871 .71877 m .38646 .71267 L .38428 .71863 L closepath p F P
0 g
s
.781 .66 .729 r
.34002 .64433 m .34739 .64634 L .34182 .65353 L p F P
0 g
s
.777 .652 .724 r
.34573 .63709 m .34002 .64433 L .34739 .64634 L p F P
0 g
s
.777 .652 .724 r
.34662 .63733 m .34573 .63709 L p .34739 .64634 L F P
0 g
s
.651 .758 .928 r
.75049 .48146 m .76265 .47766 L .76537 .48116 L p F P
0 g
s
.651 .758 .928 r
.76265 .47766 m .75049 .48146 L .74774 .47796 L p F P
0 g
s
.651 .758 .928 r
.5692 .48154 m .58103 .47775 L .58406 .48125 L p F P
0 g
s
.651 .758 .928 r
.58103 .47775 m .5692 .48154 L .56615 .47804 L p F P
0 g
s
.651 .757 .928 r
.38791 .48156 m .39941 .47777 L .40274 .48127 L p F P
0 g
s
.714 .614 .745 r
.38791 .48156 m .39941 .47777 L .39622 .46895 L p F P
0 g
s
.714 .614 .745 r
.38456 .47806 m .38791 .48156 L p .39622 .46895 L F P
0 g
s
.641 .463 .627 r
.42884 .70387 m .44194 .70193 L p .43992 .709 L F P
0 g
s
.641 .463 .627 r
.43992 .709 m .42977 .71048 L .42884 .70387 L p F P
0 g
s
.648 .481 .644 r
.44075 .69509 m .44194 .70193 L .42884 .70387 L p F P
0 g
s
.616 .503 .703 r
.4484 .67082 m .44801 .6694 L .45963 .66511 L p F P
0 g
s
.615 .501 .7 r
.45828 .66002 m .45963 .66511 L .44801 .6694 L p F P
0 g
s
.771 .657 .736 r
.35707 .62144 m .3517 .62001 L p .35248 .62954 L F P
0 g
s
.775 .669 .745 r
.35707 .62144 m .35472 .61675 L .3517 .62001 L closepath p F P
0 g
s
.611 .488 .688 r
.45022 .67826 m .4484 .67082 L .46033 .66768 L p F P
0 g
s
.616 .503 .703 r
.45963 .66511 m .46033 .66768 L .4484 .67082 L p F P
0 g
s
.78 .637 .703 r
.34086 .66724 m .34423 .66255 L .33852 .6612 L closepath p F P
0 g
s
.777 .646 .718 r
.33763 .65911 m .34182 .65353 L p .34423 .66255 L F P
0 g
s
.777 .646 .718 r
.34423 .66255 m .33852 .6612 L .33763 .65911 L p F P
0 g
s
.651 .758 .928 r
.76537 .48116 m .77756 .47735 L .78025 .48085 L p F P
0 g
s
.651 .758 .928 r
.77756 .47735 m .76537 .48116 L .76265 .47766 L p F P
0 g
s
.777 .661 .735 r
.35248 .62954 m .34623 .63651 L .34294 .6298 L p F P
0 g
s
.777 .661 .735 r
.34294 .6298 m .34488 .62758 L .35248 .62954 L p F P
0 g
s
.771 .657 .736 r
.3517 .62001 m .34488 .62758 L .35248 .62954 L p F P
0 g
s
.651 .758 .928 r
.58406 .48125 m .59592 .47745 L .59892 .48095 L p F P
0 g
s
.651 .758 .928 r
.59592 .47745 m .58406 .48125 L .58103 .47775 L p F P
0 g
s
.65 .757 .928 r
.40274 .48127 m .41427 .47748 L .41757 .48098 L p F P
0 g
s
.65 .757 .928 r
.41427 .47748 m .40274 .48127 L .39941 .47777 L p F P
0 g
s
.661 .461 .603 r
.41612 .71215 m .41631 .71182 L .41609 .71184 L closepath p F P
0 g
s
.681 .478 .604 r
.41609 .71184 m .41612 .71215 L .41305 .71838 L p F P
0 g
s
.661 .461 .603 r
.41631 .71182 m .42977 .71048 L p .41672 .71819 L F P
0 g
s
.661 .461 .603 r
.41672 .71819 m .41612 .71215 L .41631 .71182 L p F P
0 g
s
.782 .626 .687 r
.34501 .67881 m .34407 .6761 L .34267 .67827 L closepath p F P
0 g
s
.777 .612 .676 r
.34501 .67881 m .34267 .67827 L p .34672 .68678 L F P
0 g
s
.777 .612 .676 r
.34672 .68678 m .34723 .68594 L .34501 .67881 L p F P
0 g
s
.676 .473 .602 r
.41672 .71819 m .41612 .71215 L .41305 .71838 L closepath p F P
0 g
s
.651 .758 .928 r
.78025 .48085 m .79247 .47704 L .79514 .48054 L p F P
0 g
s
.651 .758 .928 r
.79247 .47704 m .78025 .48085 L .77756 .47735 L p F P
0 g
s
.777 .612 .676 r
.34755 .68695 m .34723 .68594 L .34672 .68678 L closepath p F P
0 g
s
.764 .592 .665 r
.3517 .69502 m .34963 .69468 L .34755 .68695 L p F P
0 g
s
.78 .601 .658 r
.34672 .68678 m .34755 .68695 L .34963 .69468 L p F P
0 g
s
.782 .626 .687 r
.34267 .67827 m .34407 .6761 L .34203 .67025 L p F P
0 g
s
.722 .51 .603 r
.37511 .71163 m .37275 .71792 L .38428 .71863 L p F P
0 g
s
.731 .522 .608 r
.37014 .71126 m .37511 .71163 L .37275 .71792 L p F P
0 g
s
.651 .758 .928 r
.59892 .48095 m .61081 .47716 L .61378 .48066 L p F P
0 g
s
.651 .758 .928 r
.61081 .47716 m .59892 .48095 L .59592 .47745 L p F P
0 g
s
.651 .757 .928 r
.41757 .48098 m .42913 .47718 L .43241 .48069 L p F P
0 g
s
.651 .757 .928 r
.42913 .47718 m .41757 .48098 L .41427 .47748 L p F P
0 g
s
.623 .464 .646 r
.44075 .69509 m .45326 .69256 L p .45127 .70007 L F P
0 g
s
.623 .464 .646 r
.45127 .70007 m .44194 .70193 L .44075 .69509 L p F P
0 g
s
.629 .479 .66 r
.45186 .68552 m .45326 .69256 L .44075 .69509 L p F P
0 g
s
.78 .601 .658 r
.34963 .69468 m .34329 .69336 L .34672 .68678 L p F P
0 g
s
.785 .609 .662 r
.33882 .68497 m .34672 .68678 L .34329 .69336 L p F P
0 g
s
.777 .612 .676 r
.34267 .67827 m .33882 .68497 L .34672 .68678 L p F P
0 g
s
.759 .576 .65 r
.35033 .69774 m .3517 .69502 L p .35767 .70295 L F P
0 g
s
.765 .58 .648 r
.35033 .69774 m .3517 .69502 L .34963 .69468 L closepath p F P
0 g
s
.781 .664 .734 r
.34662 .63733 m .34623 .63651 L .34573 .63709 L closepath p F P
0 g
s
.782 .626 .687 r
.34203 .67025 m .33929 .66956 L p .34267 .67827 L F P
0 g
s
.786 .639 .698 r
.34203 .67025 m .34086 .66724 L .33929 .66956 L closepath p F P
0 g
s
.651 .758 .928 r
.79514 .48054 m .80738 .47673 L .81003 .48023 L p F P
0 g
s
.651 .758 .928 r
.80738 .47673 m .79514 .48054 L .79247 .47704 L p F P
0 g
s
.651 .758 .928 r
.61378 .48066 m .6257 .47686 L .62865 .48036 L p F P
0 g
s
.651 .758 .928 r
.6257 .47686 m .61378 .48066 L .61081 .47716 L p F P
0 g
s
.651 .758 .928 r
.43241 .48069 m .444 .47689 L .44726 .48039 L p F P
0 g
s
.651 .758 .928 r
.444 .47689 m .43241 .48069 L .42913 .47718 L p F P
0 g
s
.784 .668 .736 r
.34573 .63709 m .34623 .63651 L .34294 .6298 L p F P
0 g
s
.731 .522 .608 r
.37275 .71792 m .37091 .71779 L .37014 .71126 L p F P
0 g
s
.75 .535 .604 r
.36459 .71062 m .37014 .71126 L .37091 .71779 L p F P
0 g
s
.79 .667 .728 r
.33874 .63495 m .34573 .63709 L .34002 .64433 L p F P
0 g
s
.784 .668 .736 r
.34294 .6298 m .33874 .63495 L .34573 .63709 L p F P
0 g
s
.79 .625 .677 r
.33509 .67635 m .34267 .67827 L .33882 .68497 L p F P
0 g
s
.782 .626 .687 r
.33929 .66956 m .33509 .67635 L .34267 .67827 L p F P
0 g
s
.608 .476 .676 r
.45114 .68237 m .45022 .67826 L .46216 .67513 L p F P
0 g
s
.611 .488 .688 r
.46033 .66768 m .46216 .67513 L .45022 .67826 L p F P
0 g
s
.785 .651 .714 r
.33763 .65911 m .34182 .65353 L .33439 .65157 L closepath p F P
0 g
s
.781 .66 .729 r
.33437 .65152 m .34002 .64433 L p .34182 .65353 L F P
0 g
s
.781 .66 .729 r
.34182 .65353 m .33439 .65157 L .33437 .65152 L p F P
0 g
s
.754 .556 .628 r
.36459 .71062 m .35488 .70936 L .35767 .70295 L p F P
0 g
s
.759 .562 .631 r
.35131 .70204 m .35767 .70295 L .35488 .70936 L p F P
0 g
s
.759 .576 .65 r
.35767 .70295 m .35131 .70204 L .35033 .69774 L p F P
0 g
s
.787 .64 .699 r
.33929 .66956 m .34086 .66724 L .33852 .6612 L p F P
0 g
s
.651 .758 .928 r
.81003 .48023 m .8223 .47642 L .82493 .47992 L p F P
0 g
s
.651 .758 .928 r
.8223 .47642 m .81003 .48023 L .80738 .47673 L p F P
0 g
s
.774 .586 .644 r
.34963 .69468 m .34329 .69336 L p .34855 .70152 L F P
0 g
s
.774 .586 .644 r
.34855 .70152 m .35033 .69774 L .34963 .69468 L p F P
0 g
s
.651 .758 .928 r
.62865 .48036 m .6406 .47656 L .64352 .48007 L p F P
0 g
s
.651 .758 .928 r
.6406 .47656 m .62865 .48036 L .6257 .47686 L p F P
0 g
s
.651 .758 .928 r
.44726 .48039 m .45887 .47659 L .4621 .4801 L p F P
0 g
s
.651 .758 .928 r
.45887 .47659 m .44726 .48039 L .444 .47689 L p F P
0 g
s
.766 .666 .752 r
.35472 .61675 m .35926 .61222 L .35152 .6104 L closepath p F P
0 g
s
.651 .758 .928 r
.82493 .47992 m .83723 .4761 L .83983 .4796 L p F P
0 g
s
.651 .758 .928 r
.83723 .4761 m .82493 .47992 L .8223 .47642 L p F P
0 g
s
.776 .67 .746 r
.3517 .62001 m .35472 .61675 L .35152 .6104 L p F P
0 g
s
.651 .758 .928 r
.64352 .48007 m .6555 .47626 L .6584 .47977 L p F P
0 g
s
.651 .758 .928 r
.6555 .47626 m .64352 .48007 L .6406 .47656 L p F P
0 g
s
.651 .758 .928 r
.4621 .4801 m .47375 .4763 L .47696 .47981 L p F P
0 g
s
.651 .758 .928 r
.47375 .4763 m .4621 .4801 L .45887 .47659 L p F P
0 g
s
.007 0 .367 r
.39623 .46893 m .39622 .46895 L .39636 .46364 L p F P
0 g
s
.007 0 .367 r
.39636 .46364 m .39637 .46363 L .39623 .46893 L p F P
0 g
s
.73 .466 .528 r
.3962 .46895 m .39622 .46895 L .39636 .46364 L p F P
0 g
s
.73 .466 .528 r
.39636 .46364 m .39634 .46364 L .3962 .46895 L p F P
0 g
s
.774 .586 .644 r
.35131 .70204 m .35033 .69774 L .34855 .70152 L closepath p F P
0 g
s
.794 .64 .69 r
.33203 .66753 m .33929 .66956 L .33509 .67635 L p F P
0 g
s
.787 .64 .699 r
.33653 .66065 m .33203 .66753 L .33929 .66956 L p F P
0 g
s
.787 .64 .699 r
.33852 .6612 m .33653 .66065 L p .33929 .66956 L F P
0 g
s
.651 .758 .928 r
.83983 .4796 m .85216 .47578 L .85473 .47928 L p F P
0 g
s
.651 .758 .928 r
.85216 .47578 m .83983 .4796 L .83723 .4761 L p F P
0 g
s
.777 .679 .755 r
.3446 .61789 m .3517 .62001 L .34488 .62758 L p F P
0 g
s
.776 .67 .746 r
.35132 .61034 m .3446 .61789 L .3517 .62001 L p F P
0 g
s
.776 .67 .746 r
.35152 .6104 m .35132 .61034 L p .3517 .62001 L F P
0 g
s
.608 .478 .678 r
.45186 .68552 m .45114 .68237 L .46278 .67791 L p F P
0 g
s
.608 .476 .676 r
.46216 .67513 m .46278 .67791 L .45114 .68237 L p F P
0 g
s
.791 .652 .71 r
.33852 .6612 m .33763 .65911 L .33653 .66065 L closepath p F P
0 g
s
.696 .47 .577 r
.39746 .71886 m .40231 .71885 L .40262 .72493 L p F P
0 g
s
.696 .47 .577 r
.40262 .72493 m .3959 .72494 L .39746 .71886 L p F P
0 g
s
.701 .475 .578 r
.3871 .71877 m .39746 .71886 L .3959 .72494 L p F P
0 g
s
.75 .535 .604 r
.37091 .71779 m .36257 .71681 L .36459 .71062 L p F P
0 g
s
.753 .542 .61 r
.35488 .70936 m .36459 .71062 L .36257 .71681 L p F P
0 g
s
.677 .456 .578 r
.40231 .71885 m .41305 .71838 L .41119 .72456 L p F P
0 g
s
.677 .456 .578 r
.41119 .72456 m .40262 .72493 L .40231 .71885 L p F P
0 g
s
.651 .758 .928 r
.6584 .47977 m .6704 .47596 L .67328 .47947 L p F P
0 g
s
.651 .758 .928 r
.6704 .47596 m .6584 .47977 L .6555 .47626 L p F P
0 g
s
.651 .758 .928 r
.47696 .47981 m .48863 .47601 L .49181 .47951 L p F P
0 g
s
.651 .758 .928 r
.48863 .47601 m .47696 .47981 L .47375 .4763 L p F P
0 g
s
.701 .475 .578 r
.3959 .72494 m .38741 .72487 L .3871 .71877 L p F P
0 g
s
.719 .49 .577 r
.38428 .71863 m .3871 .71877 L .38741 .72487 L p F P
0 g
s
.636 .444 .606 r
.42977 .71048 m .43992 .709 L .43416 .71631 L p F P
0 g
s
.636 .444 .606 r
.43416 .71631 m .43043 .71685 L .42977 .71048 L p F P
0 g
s
.661 .461 .603 r
.42977 .71048 m .43043 .71685 L .41672 .71819 L p F P
0 g
s
.651 .758 .928 r
.85473 .47928 m .86709 .47546 L .86964 .47896 L p F P
0 g
s
.651 .758 .928 r
.86709 .47546 m .85473 .47928 L .85216 .47578 L p F P
0 g
s
.719 .49 .577 r
.38741 .72487 m .38294 .72464 L .38428 .71863 L p F P
0 g
s
.724 .495 .58 r
.37275 .71792 m .38428 .71863 L .38294 .72464 L p F P
0 g
s
.791 .653 .71 r
.33653 .66065 m .33763 .65911 L .33439 .65157 L p F P
0 g
s
.651 .758 .928 r
.67328 .47947 m .68531 .47566 L .68816 .47917 L p F P
0 g
s
.651 .758 .928 r
.68531 .47566 m .67328 .47947 L .6704 .47596 L p F P
0 g
s
.651 .758 .928 r
.49181 .47951 m .50351 .47571 L .50667 .47922 L p F P
0 g
s
.651 .758 .928 r
.50351 .47571 m .49181 .47951 L .48863 .47601 L p F P
0 g
s
.759 .562 .631 r
.35488 .70936 m .35259 .70904 L .35131 .70204 L p F P
0 g
s
.776 .573 .625 r
.34855 .70152 m .35131 .70204 L .35259 .70904 L p F P
0 g
s
.792 .663 .721 r
.34002 .64433 m .33437 .65152 L .33107 .64468 L p F P
0 g
s
.792 .663 .721 r
.33107 .64468 m .33295 .64221 L .34002 .64433 L p F P
0 g
s
.79 .667 .728 r
.34002 .64433 m .33295 .64221 L .33874 .63495 L p F P
0 g
s
.603 .462 .662 r
.45326 .69256 m .45186 .68552 L .46378 .68238 L p F P
0 g
s
.608 .478 .678 r
.46278 .67791 m .46378 .68238 L .45186 .68552 L p F P
0 g
s
.651 .758 .928 r
.86964 .47896 m .88202 .47513 L .88455 .47864 L p F P
0 g
s
.651 .758 .928 r
.88202 .47513 m .86964 .47896 L .86709 .47546 L p F P
0 g
s
.618 .446 .628 r
.44257 .70643 m .45127 .70007 L .44194 .70193 L closepath p F P
0 g
s
.641 .463 .627 r
.44194 .70193 m .44257 .70643 L .43992 .709 L p F P
0 g
s
.672 .45 .576 r
.41305 .71838 m .41672 .71819 L .41702 .72424 L p F P
0 g
s
.672 .45 .576 r
.41702 .72424 m .41119 .72456 L .41305 .71838 L p F P
0 g
s
.6 .515 .73 r
.45101 .63593 m .46227 .63204 L p .4643 .64053 L F P
0 g
s
.6 .515 .73 r
.4643 .64053 m .45332 .64317 L .45101 .63593 L p F P
0 g
s
.602 .525 .74 r
.46177 .63057 m .46227 .63204 L .45101 .63593 L p F P
0 g
s
.602 .525 .74 r
.45101 .63593 m .45015 .63339 L .46177 .63057 L p F P
0 g
s
.596 .505 .721 r
.45606 .65219 m .45364 .64416 L .4643 .64053 L p F P
0 g
s
.601 .518 .733 r
.45364 .64416 m .45332 .64317 L .4643 .64053 L closepath p F P
0 g
s
.8 .654 .701 r
.3296 .6585 m .33653 .66065 L .33203 .66753 L p F P
0 g
s
.791 .653 .71 r
.33434 .65155 m .3296 .6585 L .33653 .66065 L p F P
0 g
s
.791 .653 .71 r
.33439 .65157 m .33434 .65155 L p .33653 .66065 L F P
0 g
s
.651 .758 .928 r
.68816 .47917 m .70022 .47536 L .70305 .47887 L p F P
0 g
s
.651 .758 .928 r
.70022 .47536 m .68816 .47917 L .68531 .47566 L p F P
0 g
s
.651 .758 .928 r
.50667 .47922 m .5184 .47542 L .52154 .47893 L p F P
0 g
s
.651 .758 .928 r
.5184 .47542 m .50667 .47922 L .50351 .47571 L p F P
0 g
s
.601 .522 .738 r
.45943 .62358 m .46177 .63057 L .45015 .63339 L p F P
0 g
s
.601 .522 .738 r
.45015 .63339 m .44819 .62751 L .45943 .62358 L p F P
0 g
s
.782 .67 .739 r
.34294 .6298 m .34488 .62758 L .34133 .62657 L closepath p F P
0 g
s
.777 .679 .755 r
.33963 .6234 m .3446 .61789 L p .34488 .62758 L F P
0 g
s
.777 .679 .755 r
.34488 .62758 m .34133 .62657 L .33963 .6234 L p F P
0 g
s
.604 .532 .747 r
.4586 .62123 m .45943 .62358 L .44819 .62751 L p F P
0 g
s
.604 .532 .747 r
.44819 .62751 m .44698 .62405 L .4586 .62123 L p F P
0 g
s
.651 .434 .576 r
.41702 .72424 m .41672 .71819 L .43043 .71685 L p F P
0 g
s
.592 .493 .71 r
.45648 .65369 m .45606 .65219 L .46735 .64835 L p F P
0 g
s
.596 .505 .721 r
.46495 .64038 m .46735 .64835 L .45606 .65219 L p F P
0 g
s
.596 .505 .721 r
.4643 .64053 m .46495 .64038 L p .45606 .65219 L F P
0 g
s
.774 .586 .644 r
.34329 .69336 m .3403 .69982 L .34855 .70152 L p F P
0 g
s
.785 .599 .65 r
.33534 .69156 m .34329 .69336 L .3403 .69982 L p F P
0 g
s
.785 .609 .662 r
.34329 .69336 m .33534 .69156 L .33882 .68497 L p F P
0 g
s
.651 .758 .928 r
.70305 .47887 m .71514 .47506 L .71795 .47857 L p F P
0 g
s
.651 .758 .928 r
.71514 .47506 m .70305 .47887 L .70022 .47536 L p F P
0 g
s
.593 .495 .712 r
.45828 .66002 m .45648 .65369 L .46812 .65105 L p F P
0 g
s
.592 .493 .71 r
.46735 .64835 m .46812 .65105 L .45648 .65369 L p F P
0 g
s
.791 .673 .733 r
.33874 .63495 m .34294 .6298 L .34133 .62657 L p F P
0 g
s
.651 .758 .928 r
.52154 .47893 m .5333 .47512 L .5364 .47863 L p F P
0 g
s
.651 .758 .928 r
.5333 .47512 m .52154 .47893 L .5184 .47542 L p F P
0 g
s
.602 .53 .746 r
.45639 .61492 m .4586 .62123 L .44698 .62405 L p F P
0 g
s
.602 .53 .746 r
.44698 .62405 m .44518 .61889 L .45639 .61492 L p F P
0 g
s
.776 .573 .625 r
.35259 .70904 m .34612 .70782 L .34855 .70152 L p F P
0 g
s
.781 .58 .629 r
.3403 .69982 m .34855 .70152 L .34612 .70782 L p F P
0 g
s
.789 .62 .671 r
.33118 .68307 m .33882 .68497 L .33534 .69156 L p F P
0 g
s
.79 .625 .677 r
.33882 .68497 m .33118 .68307 L .33509 .67635 L p F P
0 g
s
.724 .495 .58 r
.38294 .72464 m .37131 .72396 L .37275 .71792 L p F P
0 g
s
.729 .501 .581 r
.37091 .71779 m .37275 .71792 L .37131 .72396 L p F P
0 g
s
.605 .54 .755 r
.45541 .61227 m .45639 .61492 L .44518 .61889 L p F P
0 g
s
.605 .54 .755 r
.44518 .61889 m .4438 .61511 L .45541 .61227 L p F P
0 g
s
.651 .758 .928 r
.71795 .47857 m .73006 .47476 L .73284 .47827 L p F P
0 g
s
.651 .758 .928 r
.73006 .47476 m .71795 .47857 L .71514 .47506 L p F P
0 g
s
.651 .758 .928 r
.5364 .47863 m .54819 .47483 L .55128 .47834 L p F P
0 g
s
.651 .758 .928 r
.54819 .47483 m .5364 .47863 L .5333 .47512 L p F P
0 g
s
.729 .501 .581 r
.37131 .72396 m .37128 .72395 L .37091 .71779 L p F P
0 g
s
.749 .516 .578 r
.36257 .71681 m .37091 .71779 L .37128 .72395 L p F P
0 g
s
.59 .485 .702 r
.45963 .66511 m .45828 .66002 L .4696 .65621 L p F P
0 g
s
.593 .495 .712 r
.46812 .65105 m .4696 .65621 L .45828 .66002 L p F P
0 g
s
.753 .542 .61 r
.35326 .71417 m .35488 .70936 L p .36257 .71681 L F P
0 g
s
.759 .546 .609 r
.35326 .71417 m .35488 .70936 L .35259 .70904 L closepath p F P
0 g
s
.604 .538 .753 r
.45314 .60604 m .45541 .61227 L .4438 .61511 L p F P
0 g
s
.604 .538 .753 r
.4438 .61511 m .44196 .61006 L .45314 .60604 L p F P
0 g
s
.794 .64 .69 r
.33509 .67635 m .32777 .67434 L .33203 .66753 L p F P
0 g
s
.794 .636 .686 r
.32777 .67434 m .33509 .67635 L .33118 .68307 L p F P
0 g
s
.651 .758 .928 r
.73284 .47827 m .74499 .47445 L .74774 .47796 L p F P
0 g
s
.651 .758 .928 r
.74499 .47445 m .73284 .47827 L .73006 .47476 L p F P
0 g
s
.788 .686 .752 r
.3447 .60805 m .35132 .61034 L .3446 .61789 L p F P
0 g
s
.795 .665 .721 r
.33439 .65157 m .33437 .65152 L .33434 .65155 L closepath p F P
0 g
s
.798 .67 .723 r
.33434 .65155 m .33437 .65152 L .33107 .64468 L p F P
0 g
s
.651 .758 .928 r
.55128 .47834 m .56309 .47453 L .56615 .47804 L p F P
0 g
s
.651 .758 .928 r
.56309 .47453 m .55128 .47834 L .54819 .47483 L p F P
0 g
s
.805 .667 .711 r
.32774 .6493 m .33434 .65155 L .3296 .6585 L p F P
0 g
s
.798 .67 .723 r
.33107 .64468 m .32774 .6493 L .33434 .65155 L p F P
0 g
s
.792 .681 .742 r
.33209 .63269 m .33874 .63495 L .33295 .64221 L p F P
0 g
s
.791 .673 .733 r
.33794 .62541 m .33209 .63269 L .33874 .63495 L p F P
0 g
s
.791 .673 .733 r
.34133 .62657 m .33794 .62541 L p .33874 .63495 L F P
0 g
s
.592 .487 .704 r
.46033 .66768 m .45963 .66511 L .47128 .66248 L p F P
0 g
s
.59 .485 .702 r
.4696 .65621 m .47128 .66248 L .45963 .66511 L p F P
0 g
s
.651 .758 .928 r
.74774 .47796 m .75992 .47415 L .76265 .47766 L p F P
0 g
s
.651 .758 .928 r
.75992 .47415 m .74774 .47796 L .74499 .47445 L p F P
0 g
s
.618 .447 .628 r
.44287 .70855 m .44257 .70643 L .45127 .70007 L p F P
0 g
s
.637 .461 .627 r
.44287 .70855 m .44257 .70643 L .43992 .709 L closepath p F P
0 g
s
.598 .447 .647 r
.45424 .69823 m .45326 .69256 L .4652 .68944 L p F P
0 g
s
.603 .462 .662 r
.46378 .68238 m .4652 .68944 L .45326 .69256 L p F P
0 g
s
.623 .464 .646 r
.45326 .69256 m .45424 .69823 L .45127 .70007 L p F P
0 g
s
.794 .684 .743 r
.34133 .62657 m .33963 .6234 L .33794 .62541 L closepath p F P
0 g
s
.769 .554 .606 r
.35259 .70904 m .34612 .70782 L p .35283 .71556 L F P
0 g
s
.769 .554 .606 r
.35283 .71556 m .35326 .71417 L .35259 .70904 L p F P
0 g
s
.651 .758 .928 r
.56615 .47804 m .578 .47423 L .58103 .47775 L p F P
0 g
s
.651 .758 .928 r
.578 .47423 m .56615 .47804 L .56309 .47453 L p F P
0 g
s
.714 .614 .745 r
.39622 .46895 m .3962 .46895 L .38456 .47806 L p F P
0 g
s
.631 .437 .602 r
.43992 .709 m .44287 .70855 L .44349 .71487 L p F P
0 g
s
.631 .437 .602 r
.44349 .71487 m .43416 .71631 L .43992 .709 L p F P
0 g
s
.587 .473 .691 r
.46216 .67513 m .46033 .66768 L .47167 .6639 L p F P
0 g
s
.592 .487 .704 r
.47128 .66248 m .47167 .6639 L .46033 .66768 L p F P
0 g
s
.651 .758 .928 r
.76265 .47766 m .77485 .47384 L .77756 .47735 L p F P
0 g
s
.651 .758 .928 r
.77485 .47384 m .76265 .47766 L .75992 .47415 L p F P
0 g
s
.798 .652 .7 r
.32505 .6654 m .33203 .66753 L .32777 .67434 L p F P
0 g
s
.8 .654 .701 r
.33203 .66753 m .32505 .6654 L .3296 .6585 L p F P
0 g
s
.651 .758 .928 r
.58103 .47775 m .59291 .47394 L .59592 .47745 L p F P
0 g
s
.651 .758 .928 r
.59291 .47394 m .58103 .47775 L .578 .47423 L p F P
0 g
s
.65 .757 .928 r
.39941 .47777 m .41096 .47396 L .41427 .47748 L p F P
0 g
s
.618 .545 .75 r
.39622 .46895 m .39941 .47777 L .41096 .47396 L p F P
0 g
s
.79 .684 .748 r
.3446 .61789 m .33963 .6234 L .33631 .61737 L p F P
0 g
s
.79 .684 .748 r
.33631 .61737 m .33783 .61564 L .3446 .61789 L p F P
0 g
s
.788 .686 .752 r
.3446 .61789 m .33783 .61564 L .3447 .60805 L p F P
0 g
s
.63 .419 .578 r
.43043 .71685 m .43416 .71631 L .43084 .72291 L p F P
0 g
s
.63 .419 .578 r
.43084 .72291 m .43077 .72292 L .43043 .71685 L p F P
0 g
s
.651 .434 .576 r
.43043 .71685 m .43077 .72292 L .41702 .72424 L p F P
0 g
s
.651 .758 .928 r
.77756 .47735 m .78979 .47353 L .79247 .47704 L p F P
0 g
s
.651 .758 .928 r
.78979 .47353 m .77756 .47735 L .77485 .47384 L p F P
0 g
s
.749 .516 .578 r
.37128 .72395 m .36135 .72278 L .36257 .71681 L p F P
0 g
s
.751 .519 .579 r
.35346 .71567 m .36257 .71681 L .36135 .72278 L p F P
0 g
s
.753 .542 .61 r
.36257 .71681 m .35346 .71567 L .35326 .71417 L p F P
0 g
s
.608 .42 .602 r
.44349 .71487 m .44287 .70855 L .45535 .70598 L p F P
0 g
s
.618 .447 .628 r
.45445 .69941 m .45535 .70598 L .44287 .70855 L p F P
0 g
s
.618 .447 .628 r
.45127 .70007 m .45445 .69941 L p .44287 .70855 L F P
0 g
s
.651 .758 .928 r
.59592 .47745 m .60782 .47364 L .61081 .47716 L p F P
0 g
s
.651 .758 .928 r
.60782 .47364 m .59592 .47745 L .59291 .47394 L p F P
0 g
s
.651 .757 .928 r
.41427 .47748 m .42584 .47367 L .42913 .47718 L p F P
0 g
s
.651 .757 .928 r
.42584 .47367 m .41427 .47748 L .41096 .47396 L p F P
0 g
s
.69 .441 .541 r
.3959 .72494 m .40262 .72493 L .40251 .73063 L p F P
0 g
s
.69 .441 .541 r
.40251 .73063 m .39567 .73064 L .3959 .72494 L p F P
0 g
s
.695 .445 .542 r
.38741 .72487 m .3959 .72494 L .39567 .73064 L p F P
0 g
s
.67 .425 .541 r
.40262 .72493 m .41119 .72456 L .41095 .73027 L p F P
0 g
s
.67 .425 .541 r
.41095 .73027 m .40251 .73063 L .40262 .72493 L p F P
0 g
s
.695 .445 .542 r
.39567 .73064 m .38729 .73057 L .38741 .72487 L p F P
0 g
s
.715 .462 .542 r
.38294 .72464 m .38741 .72487 L .38729 .73057 L p F P
0 g
s
.621 .463 .647 r
.45445 .69941 m .45424 .69823 L .45127 .70007 L closepath p F P
0 g
s
.651 .758 .928 r
.79247 .47704 m .80473 .47322 L .80738 .47673 L p F P
0 g
s
.651 .758 .928 r
.80473 .47322 m .79247 .47704 L .78979 .47353 L p F P
0 g
s
.651 .758 .928 r
.61081 .47716 m .62274 .47334 L .6257 .47686 L p F P
0 g
s
.651 .758 .928 r
.62274 .47334 m .61081 .47716 L .60782 .47364 L p F P
0 g
s
.618 .545 .75 r
.40763 .47043 m .39623 .46893 L .39622 .46895 L p F P
0 g
s
.618 .545 .75 r
.41096 .47396 m .40763 .47043 L p .39622 .46895 L F P
0 g
s
.651 .758 .928 r
.42913 .47718 m .44074 .47337 L .444 .47689 L p F P
0 g
s
.651 .757 .928 r
.44074 .47337 m .42913 .47718 L .42584 .47367 L p F P
0 g
s
.798 .672 .725 r
.33107 .64468 m .33295 .64221 L .32927 .641 L closepath p F P
0 g
s
.792 .681 .742 r
.32776 .63814 m .33209 .63269 L p .33295 .64221 L F P
0 g
s
.792 .681 .742 r
.33295 .64221 m .32927 .641 L .32776 .63814 L p F P
0 g
s
.797 .689 .745 r
.33794 .62541 m .33963 .6234 L .33631 .61737 L p F P
0 g
s
.587 .473 .691 r
.47167 .6639 m .47351 .67137 L .46216 .67513 L p F P
0 g
s
.582 .458 .677 r
.46278 .67791 m .46216 .67513 L .47351 .67137 L p F P
0 g
s
.715 .462 .542 r
.38729 .73057 m .38271 .73034 L .38294 .72464 L p F P
0 g
s
.719 .466 .543 r
.37131 .72396 m .38294 .72464 L .38271 .73034 L p F P
0 g
s
.781 .58 .629 r
.34612 .70782 m .33781 .70614 L .3403 .69982 L p F P
0 g
s
.785 .587 .633 r
.33225 .69805 m .3403 .69982 L .33781 .70614 L p F P
0 g
s
.785 .599 .65 r
.3403 .69982 m .33225 .69805 L .33534 .69156 L p F P
0 g
s
.791 .607 .653 r
.32958 .69017 m .33534 .69156 L .33225 .69805 L p F P
0 g
s
.789 .62 .671 r
.32877 .68762 m .33118 .68307 L p .33534 .69156 L F P
0 g
s
.789 .62 .671 r
.33534 .69156 m .32958 .69017 L .32877 .68762 L p F P
0 g
s
.651 .758 .928 r
.80738 .47673 m .81967 .4729 L .8223 .47642 L p F P
0 g
s
.651 .758 .928 r
.81967 .4729 m .80738 .47673 L .80473 .47322 L p F P
0 g
s
.624 .412 .575 r
.43416 .71631 m .44349 .71487 L .44381 .72091 L p F P
0 g
s
.624 .412 .575 r
.44381 .72091 m .43084 .72291 L .43416 .71631 L p F P
0 g
s
.664 .42 .541 r
.41119 .72456 m .41702 .72424 L .41694 .72995 L p F P
0 g
s
.664 .42 .541 r
.41694 .72995 m .41095 .73027 L .41119 .72456 L p F P
0 g
s
.802 .667 .714 r
.32297 .65626 m .3296 .6585 L .32505 .6654 L p F P
0 g
s
.805 .667 .711 r
.3296 .6585 m .32297 .65626 L .32774 .6493 L p F P
0 g
s
.651 .758 .928 r
.6257 .47686 m .63766 .47304 L .6406 .47656 L p F P
0 g
s
.651 .758 .928 r
.63766 .47304 m .6257 .47686 L .62274 .47334 L p F P
0 g
s
.651 .758 .928 r
.444 .47689 m .45563 .47308 L .45887 .47659 L p F P
0 g
s
.651 .758 .928 r
.45563 .47308 m .444 .47689 L .44074 .47337 L p F P
0 g
s
.802 .69 .741 r
.33168 .62301 m .33794 .62541 L .33209 .63269 L p F P
0 g
s
.797 .689 .745 r
.33631 .61737 m .33168 .62301 L .33794 .62541 L p F P
0 g
s
.598 .448 .649 r
.45445 .69941 m .45424 .69823 L .4659 .69351 L p F P
0 g
s
.598 .447 .647 r
.4652 .68944 m .4659 .69351 L .45424 .69823 L p F P
0 g
s
.805 .674 .72 r
.32774 .6493 m .33107 .64468 L .32927 .641 L p F P
0 g
s
.797 .625 .668 r
.32877 .68762 m .33118 .68307 L .32696 .68194 L closepath p F P
0 g
s
.794 .636 .686 r
.32558 .67814 m .32777 .67434 L p .33118 .68307 L F P
0 g
s
.794 .636 .686 r
.33118 .68307 m .32696 .68194 L .32558 .67814 L p F P
0 g
s
.769 .554 .606 r
.34612 .70782 m .34429 .71396 L .35283 .71556 L p F P
0 g
s
.78 .565 .608 r
.33781 .70614 m .34612 .70782 L .34429 .71396 L p F P
0 g
s
.651 .758 .928 r
.8223 .47642 m .83462 .47259 L .83723 .4761 L p F P
0 g
s
.651 .758 .928 r
.83462 .47259 m .8223 .47642 L .81967 .4729 L p F P
0 g
s
.769 .554 .606 r
.35346 .71567 m .35326 .71417 L .35283 .71556 L closepath p F P
0 g
s
.583 .46 .678 r
.46378 .68238 m .46278 .67791 L .47444 .67549 L p F P
0 g
s
.582 .458 .677 r
.47351 .67137 m .47444 .67549 L .46278 .67791 L p F P
0 g
s
.651 .758 .928 r
.6406 .47656 m .65258 .47274 L .6555 .47626 L p F P
0 g
s
.651 .758 .928 r
.65258 .47274 m .6406 .47656 L .63766 .47304 L p F P
0 g
s
.643 .403 .539 r
.41702 .72424 m .43077 .72292 L p .43056 .72865 L F P
0 g
s
.643 .403 .539 r
.43056 .72865 m .41694 .72995 L .41702 .72424 L p F P
0 g
s
.651 .758 .928 r
.45887 .47659 m .47053 .47278 L .47375 .4763 L p F P
0 g
s
.651 .758 .928 r
.47053 .47278 m .45887 .47659 L .45563 .47308 L p F P
0 g
s
.59 .424 .625 r
.45535 .70598 m .45445 .69941 L .46639 .69628 L p F P
0 g
s
.598 .448 .649 r
.4659 .69351 m .46639 .69628 L .45445 .69941 L p F P
0 g
s
.651 .758 .928 r
.83723 .4761 m .84957 .47227 L .85216 .47578 L p F P
0 g
s
.651 .758 .928 r
.84957 .47227 m .83723 .4761 L .83462 .47259 L p F P
0 g
s
.651 .758 .928 r
.6555 .47626 m .66751 .47244 L .6704 .47596 L p F P
0 g
s
.651 .758 .928 r
.66751 .47244 m .6555 .47626 L .65258 .47274 L p F P
0 g
s
.651 .758 .928 r
.47375 .4763 m .48544 .47249 L .48863 .47601 L p F P
0 g
s
.651 .758 .928 r
.48544 .47249 m .47375 .4763 L .47053 .47278 L p F P
0 g
s
.719 .466 .543 r
.37124 .72563 m .37131 .72396 L p .38271 .73034 L F P
0 g
s
.725 .471 .543 r
.37124 .72563 m .37131 .72396 L .37128 .72395 L closepath p F P
0 g
s
.74 .484 .542 r
.37128 .72395 m .36135 .72278 L p .37106 .72966 L F P
0 g
s
.74 .484 .542 r
.37106 .72966 m .37124 .72563 L .37128 .72395 L p F P
0 g
s
.751 .519 .579 r
.36135 .72278 m .35382 .72185 L .35346 .71567 L p F P
0 g
s
.77 .533 .576 r
.35283 .71556 m .35346 .71567 L .35382 .72185 L p F P
0 g
s
.798 .652 .7 r
.32234 .66977 m .32505 .6654 L p .32777 .67434 L F P
0 g
s
.798 .652 .7 r
.32777 .67434 m .32374 .67314 L .32234 .66977 L p F P
0 g
s
.802 .641 .682 r
.32558 .67814 m .32777 .67434 L .32374 .67314 L closepath p F P
0 g
s
.651 .758 .928 r
.85216 .47578 m .86453 .47195 L .86709 .47546 L p F P
0 g
s
.651 .758 .928 r
.86453 .47195 m .85216 .47578 L .84957 .47227 L p F P
0 g
s
.77 .533 .576 r
.35382 .72185 m .35173 .7215 L .35283 .71556 L p F P
0 g
s
.777 .54 .577 r
.34429 .71396 m .35283 .71556 L .35173 .7215 L p F P
0 g
s
.651 .758 .928 r
.6704 .47596 m .68245 .47214 L .68531 .47566 L p F P
0 g
s
.651 .758 .928 r
.68245 .47214 m .6704 .47596 L .66751 .47244 L p F P
0 g
s
.651 .758 .928 r
.48863 .47601 m .50035 .47219 L .50351 .47571 L p F P
0 g
s
.651 .758 .928 r
.50035 .47219 m .48863 .47601 L .48544 .47249 L p F P
0 g
s
.578 .445 .664 r
.4652 .68944 m .46378 .68238 L .47516 .67865 L p F P
0 g
s
.583 .46 .678 r
.47444 .67549 m .47516 .67865 L .46378 .68238 L p F P
0 g
s
.788 .702 .769 r
.33846 .60563 m .3447 .60805 L .33783 .61564 L p F P
0 g
s
.81 .677 .717 r
.32146 .64693 m .32774 .6493 L .32297 .65626 L p F P
0 g
s
.805 .674 .72 r
.32641 .63992 m .32146 .64693 L .32774 .6493 L p F P
0 g
s
.805 .674 .72 r
.32927 .641 m .32641 .63992 L p .32774 .6493 L F P
0 g
s
.651 .758 .928 r
.86709 .47546 m .87949 .47162 L .88202 .47513 L p F P
0 g
s
.651 .758 .928 r
.87949 .47162 m .86709 .47546 L .86453 .47195 L p F P
0 g
s
.807 .686 .731 r
.32927 .641 m .32776 .63814 L .32641 .63992 L closepath p F P
0 g
s
.805 .686 .734 r
.33209 .63269 m .32776 .63814 L .32442 .63203 L p F P
0 g
s
.805 .686 .734 r
.32442 .63203 m .32575 .63032 L .33209 .63269 L p F P
0 g
s
.802 .69 .741 r
.33209 .63269 m .32575 .63032 L .33168 .62301 L p F P
0 g
s
.651 .758 .928 r
.68531 .47566 m .69739 .47184 L .70022 .47536 L p F P
0 g
s
.651 .758 .928 r
.69739 .47184 m .68531 .47566 L .68245 .47214 L p F P
0 g
s
.651 .758 .928 r
.50351 .47571 m .51526 .4719 L .5184 .47542 L p F P
0 g
s
.651 .758 .928 r
.51526 .4719 m .50351 .47571 L .50035 .47219 L p F P
0 g
s
.804 .628 .664 r
.32696 .68194 m .32401 .68102 L p .32776 .68965 L F P
0 g
s
.804 .628 .664 r
.32776 .68965 m .32877 .68762 L .32696 .68194 L p F P
0 g
s
.808 .642 .677 r
.32696 .68194 m .32558 .67814 L .32401 .68102 L closepath p F P
0 g
s
.651 .758 .928 r
.70022 .47536 m .71233 .47154 L .71514 .47506 L p F P
0 g
s
.651 .758 .928 r
.71233 .47154 m .70022 .47536 L .69739 .47184 L p F P
0 g
s
.803 .627 .664 r
.32958 .69017 m .32877 .68762 L .32776 .68965 L closepath p F P
0 g
s
.807 .657 .696 r
.32234 .66977 m .32505 .6654 L .31977 .66366 L closepath p F P
0 g
s
.802 .667 .714 r
.31906 .66215 m .32297 .65626 L p .32505 .6654 L F P
0 g
s
.802 .667 .714 r
.32505 .6654 m .31977 .66366 L .31906 .66215 L p F P
0 g
s
.719 .466 .543 r
.38271 .73034 m .37114 .72967 L .37124 .72563 L p F P
0 g
s
.739 .483 .542 r
.37114 .72967 m .37124 .72563 L .37106 .72966 L closepath p F P
0 g
s
.791 .607 .653 r
.33225 .69805 m .33165 .69791 L .32958 .69017 L p F P
0 g
s
.807 .616 .645 r
.32776 .68965 m .32958 .69017 L .33165 .69791 L p F P
0 g
s
.651 .758 .928 r
.5184 .47542 m .53018 .4716 L .5333 .47512 L p F P
0 g
s
.651 .758 .928 r
.53018 .4716 m .5184 .47542 L .51526 .4719 L p F P
0 g
s
.599 .393 .574 r
.44381 .72091 m .44349 .71487 L .456 .71232 L p F P
0 g
s
.608 .42 .602 r
.45535 .70598 m .456 .71232 L .44349 .71487 L p F P
0 g
s
.595 .503 .72 r
.46495 .64038 m .4643 .64053 L .46493 .64031 L closepath p F P
0 g
s
.6 .515 .73 r
.46227 .63204 m .46493 .64031 L .4643 .64053 L p F P
0 g
s
.795 .694 .753 r
.33631 .61737 m .33783 .61564 L .33466 .61449 L closepath p F P
0 g
s
.788 .702 .769 r
.33296 .61169 m .33846 .60563 L p .33783 .61564 L F P
0 g
s
.788 .702 .769 r
.33783 .61564 m .33466 .61449 L .33296 .61169 L p F P
0 g
s
.809 .644 .678 r
.32401 .68102 m .32558 .67814 L .32374 .67314 L p F P
0 g
s
.651 .758 .928 r
.71514 .47506 m .72727 .47124 L .73006 .47476 L p F P
0 g
s
.651 .758 .928 r
.72727 .47124 m .71514 .47506 L .71233 .47154 L p F P
0 g
s
.651 .758 .928 r
.5333 .47512 m .5451 .4713 L .54819 .47483 L p F P
0 g
s
.651 .758 .928 r
.5451 .4713 m .5333 .47512 L .53018 .4716 L p F P
0 g
s
.618 .383 .538 r
.43075 .7246 m .43084 .72291 L .43077 .72292 L closepath p F P
0 g
s
.643 .403 .539 r
.43077 .72292 m .43075 .7246 L .43056 .72865 L p F P
0 g
s
.618 .382 .538 r
.43084 .72291 m .44381 .72091 L p .4307 .72863 L F P
0 g
s
.618 .382 .538 r
.4307 .72863 m .43075 .7246 L .43084 .72291 L p F P
0 g
s
.566 .485 .723 r
.46495 .64038 m .46493 .64031 L .4755 .63567 L p F P
0 g
s
.572 .5 .735 r
.47343 .62931 m .4755 .63567 L .46493 .64031 L p F P
0 g
s
.572 .5 .735 r
.46715 .6299 m .47343 .62931 L p .46493 .64031 L F P
0 g
s
.572 .5 .735 r
.46493 .64031 m .46227 .63204 L .46715 .6299 L p F P
0 g
s
.567 .487 .724 r
.46735 .64835 m .46495 .64038 L .47661 .63934 L p F P
0 g
s
.566 .485 .723 r
.4755 .63567 m .47661 .63934 L .46495 .64038 L p F P
0 g
s
.577 .511 .745 r
.46227 .63204 m .46177 .63057 L .46715 .6299 L closepath p F P
0 g
s
.576 .509 .743 r
.46715 .6299 m .46177 .63057 L .45943 .62358 L p F P
0 g
s
.805 .697 .745 r
.33168 .62301 m .33631 .61737 L .33466 .61449 L p F P
0 g
s
.785 .587 .633 r
.33188 .69902 m .33225 .69805 L p .33781 .70614 L F P
0 g
s
.793 .593 .63 r
.33188 .69902 m .33225 .69805 L .33165 .69791 L closepath p F P
0 g
s
.81 .691 .733 r
.32641 .63992 m .32776 .63814 L .32442 .63203 L p F P
0 g
s
.74 .484 .542 r
.36135 .72278 m .36111 .72848 L .37106 .72966 L p F P
0 g
s
.748 .49 .542 r
.35382 .72185 m .36135 .72278 L .36111 .72848 L p F P
0 g
s
.651 .758 .928 r
.74222 .47093 m .73006 .47476 L .72727 .47124 L p F P
0 g
s
.651 .758 .928 r
.73006 .47476 m .74222 .47093 L .74499 .47445 L p F P
0 g
s
.576 .509 .743 r
.45943 .62358 m .46707 .62014 L p .46715 .6299 L F P
0 g
s
.577 .519 .753 r
.45943 .62358 m .4586 .62123 L .46707 .62014 L closepath p F P
0 g
s
.809 .644 .678 r
.32374 .67314 m .32091 .67218 L p .32401 .68102 L F P
0 g
s
.812 .657 .691 r
.32374 .67314 m .32234 .66977 L .32091 .67218 L closepath p F P
0 g
s
.565 .477 .714 r
.46812 .65105 m .46735 .64835 L .47799 .6438 L p F P
0 g
s
.567 .487 .724 r
.47661 .63934 m .47799 .6438 L .46735 .64835 L p F P
0 g
s
.807 .616 .645 r
.33165 .69791 m .32506 .69602 L .32776 .68965 L p F P
0 g
s
.813 .624 .648 r
.32089 .68751 m .32776 .68965 L .32506 .69602 L p F P
0 g
s
.804 .628 .664 r
.32401 .68102 m .32089 .68751 L .32776 .68965 L p F P
0 g
s
.802 .598 .626 r
.33165 .69791 m .32506 .69602 L p .32999 .7043 L F P
0 g
s
.802 .598 .626 r
.32999 .7043 m .33188 .69902 L .33165 .69791 L p F P
0 g
s
.651 .758 .928 r
.54819 .47483 m .56002 .47101 L .56309 .47453 L p F P
0 g
s
.651 .758 .928 r
.56002 .47101 m .54819 .47483 L .5451 .4713 L p F P
0 g
s
.78 .565 .608 r
.34429 .71396 m .3359 .7123 L .33781 .70614 L p F P
0 g
s
.786 .572 .61 r
.33315 .70513 m .33781 .70614 L .3359 .7123 L p F P
0 g
s
.785 .587 .633 r
.33781 .70614 m .33315 .70513 L .33188 .69902 L p F P
0 g
s
.577 .517 .75 r
.46707 .62014 m .4586 .62123 L .45639 .61492 L p F P
0 g
s
.568 .48 .716 r
.4696 .65621 m .46812 .65105 L .47979 .65 L p F P
0 g
s
.565 .477 .714 r
.47799 .6438 m .47979 .65 L .46812 .65105 L p F P
0 g
s
.817 .691 .725 r
.32045 .63744 m .32641 .63992 L .32146 .64693 L p F P
0 g
s
.81 .691 .733 r
.32442 .63203 m .32045 .63744 L .32641 .63992 L p F P
0 g
s
.801 .597 .626 r
.33315 .70513 m .33188 .69902 L .32999 .7043 L closepath p F P
0 g
s
.582 .402 .603 r
.456 .71232 m .45535 .70598 L .4673 .70286 L p F P
0 g
s
.59 .424 .625 r
.46639 .69628 m .4673 .70286 L .45535 .70598 L p F P
0 g
s
.571 .427 .647 r
.4659 .69351 m .4652 .68944 L .47658 .68571 L p F P
0 g
s
.578 .445 .664 r
.47516 .67865 m .47658 .68571 L .4652 .68944 L p F P
0 g
s
.651 .758 .928 r
.74499 .47445 m .75718 .47062 L .75992 .47415 L p F P
0 g
s
.651 .758 .928 r
.75718 .47062 m .74499 .47445 L .74222 .47093 L p F P
0 g
s
.651 .758 .928 r
.56309 .47453 m .57495 .47071 L .578 .47423 L p F P
0 g
s
.651 .758 .928 r
.57495 .47071 m .56309 .47453 L .56002 .47101 L p F P
0 g
s
.68 .399 .49 r
.39567 .73064 m .40251 .73063 L .40189 .73588 L p F P
0 g
s
.68 .399 .49 r
.40189 .73588 m .39709 .73589 L .39567 .73064 L p F P
0 g
s
.685 .402 .489 r
.38729 .73057 m .39567 .73064 L .39709 .73589 L p F P
0 g
s
.658 .379 .487 r
.40251 .73063 m .41095 .73027 L .41273 .73542 L p F P
0 g
s
.658 .379 .487 r
.41273 .73542 m .40189 .73588 L .40251 .73063 L p F P
0 g
s
.814 .671 .705 r
.32297 .65626 m .31906 .66215 L .31575 .65526 L p F P
0 g
s
.814 .671 .705 r
.31575 .65526 m .31661 .65392 L .32297 .65626 L p F P
0 g
s
.81 .677 .717 r
.32297 .65626 m .31661 .65392 L .32146 .64693 L p F P
0 g
s
.577 .517 .75 r
.45639 .61492 m .46474 .61105 L p .46707 .62014 L F P
0 g
s
.578 .526 .76 r
.45639 .61492 m .45541 .61227 L .46474 .61105 L closepath p F P
0 g
s
.817 .642 .665 r
.31743 .67878 m .32401 .68102 L .32089 .68751 L p F P
0 g
s
.809 .644 .678 r
.32091 .67218 m .31743 .67878 L .32401 .68102 L p F P
0 g
s
.685 .402 .489 r
.39709 .73589 m .38663 .7358 L .38729 .73057 L p F P
0 g
s
.707 .423 .491 r
.38271 .73034 m .38729 .73057 L .38663 .7358 L p F P
0 g
s
.567 .471 .705 r
.4696 .65621 m .4803 .65173 L p .47619 .66205 L F P
0 g
s
.567 .471 .705 r
.47619 .66205 m .47128 .66248 L .4696 .65621 L p F P
0 g
s
.568 .48 .716 r
.47979 .65 m .4803 .65173 L .4696 .65621 L p F P
0 g
s
.813 .659 .692 r
.32091 .67218 m .32234 .66977 L .31977 .66366 L p F P
0 g
s
.777 .54 .577 r
.35173 .7215 m .34317 .71989 L .34429 .71396 L p F P
0 g
s
.779 .544 .581 r
.3359 .7123 m .34429 .71396 L .34317 .71989 L p F P
0 g
s
.651 .758 .928 r
.75992 .47415 m .77213 .47032 L .77485 .47384 L p F P
0 g
s
.651 .758 .928 r
.77213 .47032 m .75992 .47415 L .75718 .47062 L p F P
0 g
s
.803 .705 .756 r
.32577 .6205 m .33168 .62301 L .32575 .63032 L p F P
0 g
s
.805 .697 .745 r
.33167 .6132 m .32577 .6205 L .33168 .62301 L p F P
0 g
s
.805 .697 .745 r
.33466 .61449 m .33167 .6132 L p .33168 .62301 L F P
0 g
s
.638 .398 .539 r
.4307 .72863 m .43075 .7246 L .43056 .72865 L closepath p F P
0 g
s
.651 .758 .928 r
.578 .47423 m .58989 .47041 L .59291 .47394 L p F P
0 g
s
.651 .758 .928 r
.58989 .47041 m .578 .47423 L .57495 .47071 L p F P
0 g
s
.578 .524 .758 r
.46474 .61105 m .45541 .61227 L .45314 .60604 L p F P
0 g
s
.707 .423 .491 r
.38663 .7358 m .38385 .73566 L .38271 .73034 L p F P
0 g
s
.711 .423 .486 r
.37114 .72967 m .38271 .73034 L .38385 .73566 L p F P
0 g
s
.652 .376 .489 r
.41095 .73027 m .41694 .72995 L .41637 .73522 L p F P
0 g
s
.652 .376 .489 r
.41637 .73522 m .41273 .73542 L .41095 .73027 L p F P
0 g
s
.651 .758 .928 r
.77485 .47384 m .7871 .47 L .78979 .47353 L p F P
0 g
s
.651 .758 .928 r
.7871 .47 m .77485 .47384 L .77213 .47032 L p F P
0 g
s
.807 .707 .755 r
.33466 .61449 m .33296 .61169 L .33167 .6132 L closepath p F P
0 g
s
.651 .758 .928 r
.59291 .47394 m .60482 .47011 L .60782 .47364 L p F P
0 g
s
.651 .758 .928 r
.60482 .47011 m .59291 .47394 L .58989 .47041 L p F P
0 g
s
.651 .757 .928 r
.41096 .47396 m .42254 .47014 L .42584 .47367 L p F P
0 g
s
.651 .757 .928 r
.42254 .47014 m .41096 .47396 L .40763 .47043 L p F P
0 g
s
.567 .473 .708 r
.47167 .6639 m .47128 .66248 L .47619 .66205 L closepath p F P
0 g
s
.748 .49 .542 r
.36111 .72848 m .35365 .72757 L .35382 .72185 L p F P
0 g
s
.769 .508 .541 r
.35173 .7215 m .35382 .72185 L .35365 .72757 L p F P
0 g
s
.822 .659 .68 r
.31462 .66984 m .32091 .67218 L .31743 .67878 L p F P
0 g
s
.813 .659 .692 r
.31842 .66316 m .31462 .66984 L .32091 .67218 L p F P
0 g
s
.813 .659 .692 r
.31977 .66366 m .31842 .66316 L p .32091 .67218 L F P
0 g
s
.56 .456 .692 r
.47351 .67137 m .47167 .6639 L .47619 .66205 L p F P
0 g
s
.578 .524 .758 r
.45314 .60604 m .46042 .60257 L p .46474 .61105 L F P
0 g
s
.651 .758 .928 r
.78979 .47353 m .80206 .46969 L .80473 .47322 L p F P
0 g
s
.651 .758 .928 r
.80206 .46969 m .78979 .47353 L .7871 .47 L p F P
0 g
s
.629 .356 .486 r
.41637 .73522 m .41694 .72995 L .43056 .72865 L p F P
0 g
s
.786 .572 .61 r
.3359 .7123 m .33418 .71193 L .33315 .70513 L p F P
0 g
s
.804 .584 .604 r
.32999 .7043 m .33315 .70513 L .33418 .71193 L p F P
0 g
s
.651 .758 .928 r
.60782 .47364 m .61977 .46981 L .62274 .47334 L p F P
0 g
s
.651 .758 .928 r
.61977 .46981 m .60782 .47364 L .60482 .47011 L p F P
0 g
s
.572 .429 .648 r
.46639 .69628 m .4659 .69351 L .47759 .6914 L p F P
0 g
s
.571 .427 .647 r
.47658 .68571 m .47759 .6914 L .4659 .69351 L p F P
0 g
s
.651 .757 .928 r
.42584 .47367 m .43746 .46984 L .44074 .47337 L p F P
0 g
s
.651 .757 .928 r
.43746 .46984 m .42584 .47367 L .42254 .47014 L p F P
0 g
s
.816 .672 .704 r
.31977 .66366 m .31906 .66215 L .31842 .66316 L closepath p F P
0 g
s
.769 .508 .541 r
.35365 .72757 m .35147 .7272 L .35173 .7215 L p F P
0 g
s
.776 .514 .539 r
.34317 .71989 m .35173 .7215 L .35147 .7272 L p F P
0 g
s
.651 .758 .928 r
.80473 .47322 m .81703 .46938 L .81967 .4729 L p F P
0 g
s
.651 .758 .928 r
.81703 .46938 m .80473 .47322 L .80206 .46969 L p F P
0 g
s
.711 .423 .486 r
.3711 .72997 m .37114 .72967 L p .38385 .73566 L F P
0 g
s
.733 .45 .499 r
.3711 .72997 m .37106 .72966 L .37114 .72967 L closepath p F P
0 g
s
.651 .758 .928 r
.62274 .47334 m .63471 .46951 L .63766 .47304 L p F P
0 g
s
.651 .758 .928 r
.63471 .46951 m .62274 .47334 L .61977 .46981 L p F P
0 g
s
.741 .448 .487 r
.37106 .72966 m .3711 .72997 L .37037 .73483 L p F P
0 g
s
.741 .448 .487 r
.36111 .72848 m .37106 .72966 L p .37037 .73483 L F P
0 g
s
.651 .758 .928 r
.44074 .47337 m .45238 .46955 L .45563 .47308 L p F P
0 g
s
.651 .757 .928 r
.45238 .46955 m .44074 .47337 L .43746 .46984 L p F P
0 g
s
.803 .711 .763 r
.33846 .60563 m .33296 .61169 L .32958 .60643 L p F P
0 g
s
.803 .711 .763 r
.32958 .60643 m .33259 .60308 L .33846 .60563 L p F P
0 g
s
.814 .691 .729 r
.31546 .64447 m .32146 .64693 L .31661 .65392 L p F P
0 g
s
.817 .691 .725 r
.32146 .64693 m .31546 .64447 L .32045 .63744 L p F P
0 g
s
.811 .696 .738 r
.32442 .63203 m .32575 .63032 L .32275 .6291 L closepath p F P
0 g
s
.803 .705 .756 r
.32105 .62632 m .32577 .6205 L p .32575 .63032 L F P
0 g
s
.803 .705 .756 r
.32575 .63032 m .32275 .6291 L .32105 .62632 L p F P
0 g
s
.819 .676 .706 r
.31842 .66316 m .31906 .66215 L .31575 .65526 L p F P
0 g
s
.711 .423 .486 r
.38385 .73566 m .37225 .73496 L .3711 .72997 L p F P
0 g
s
.715 .425 .484 r
.37225 .73496 m .37037 .73483 L .3711 .72997 L closepath p F P
0 g
s
.651 .758 .928 r
.81967 .4729 m .83201 .46906 L .83462 .47259 L p F P
0 g
s
.651 .758 .928 r
.83201 .46906 m .81967 .4729 L .81703 .46938 L p F P
0 g
s
.651 .758 .928 r
.63766 .47304 m .64966 .46921 L .65258 .47274 L p F P
0 g
s
.651 .758 .928 r
.64966 .46921 m .63766 .47304 L .63471 .46951 L p F P
0 g
s
.651 .758 .928 r
.45563 .47308 m .46731 .46925 L .47053 .47278 L p F P
0 g
s
.651 .758 .928 r
.46731 .46925 m .45563 .47308 L .45238 .46955 L p F P
0 g
s
.564 .405 .625 r
.4673 .70286 m .46639 .69628 L .4778 .69258 L p F P
0 g
s
.572 .429 .648 r
.47759 .6914 m .4778 .69258 L .46639 .69628 L p F P
0 g
s
.827 .674 .693 r
.31242 .66072 m .31842 .66316 L .31462 .66984 L p F P
0 g
s
.819 .676 .706 r
.31575 .65526 m .31242 .66072 L .31842 .66316 L p F P
0 g
s
.819 .698 .732 r
.32045 .63744 m .32442 .63203 L .32275 .6291 L p F P
0 g
s
.56 .456 .692 r
.48297 .66175 m .48428 .66697 L .47351 .67137 L p F P
0 g
s
.56 .456 .692 r
.47619 .66205 m .48297 .66175 L p .47351 .67137 L F P
0 g
s
.557 .443 .679 r
.47351 .67137 m .48428 .66697 L p .4841 .67507 L F P
0 g
s
.557 .443 .679 r
.4841 .67507 m .47444 .67549 L .47351 .67137 L p F P
0 g
s
.651 .758 .928 r
.83462 .47259 m .84698 .46874 L .84957 .47227 L p F P
0 g
s
.651 .758 .928 r
.84698 .46874 m .83462 .47259 L .83201 .46906 L p F P
0 g
s
.587 .357 .534 r
.44376 .72662 m .44381 .72091 L .45633 .71837 L p F P
0 g
s
.599 .393 .574 r
.456 .71232 m .45633 .71837 L .44381 .72091 L p F P
0 g
s
.618 .382 .538 r
.44381 .72091 m .44376 .72662 L .4307 .72863 L p F P
0 g
s
.651 .758 .928 r
.65258 .47274 m .66462 .46891 L .66751 .47244 L p F P
0 g
s
.651 .758 .928 r
.66462 .46891 m .65258 .47274 L .64966 .46921 L p F P
0 g
s
.812 .715 .758 r
.33167 .6132 m .33296 .61169 L .32958 .60643 L p F P
0 g
s
.651 .758 .928 r
.47053 .47278 m .48224 .46896 L .48544 .47249 L p F P
0 g
s
.651 .758 .928 r
.48224 .46896 m .47053 .47278 L .46731 .46925 L p F P
0 g
s
.569 .498 .735 r
.47343 .62931 m .46715 .6299 L .4728 .62735 L closepath p F P
0 g
s
.576 .509 .743 r
.47025 .61983 m .4728 .62735 L .46715 .6299 L p F P
0 g
s
.576 .509 .743 r
.46707 .62014 m .47025 .61983 L p .46715 .6299 L F P
0 g
s
.804 .584 .604 r
.33418 .71193 m .32833 .71039 L .32999 .7043 L p F P
0 g
s
.81 .591 .606 r
.32283 .70226 m .32999 .7043 L .32833 .71039 L p F P
0 g
s
.802 .598 .626 r
.32506 .69602 m .32283 .70226 L .32999 .7043 L p F P
0 g
s
.814 .613 .631 r
.31816 .69389 m .32506 .69602 L .32283 .70226 L p F P
0 g
s
.813 .624 .648 r
.32506 .69602 m .31816 .69389 L .32089 .68751 L p F P
0 g
s
.651 .758 .928 r
.84957 .47227 m .86196 .46842 L .86453 .47195 L p F P
0 g
s
.651 .758 .928 r
.86196 .46842 m .84957 .47227 L .84698 .46874 L p F P
0 g
s
.816 .714 .752 r
.32616 .61055 m .33167 .6132 L .32577 .6205 L p F P
0 g
s
.812 .715 .758 r
.32958 .60643 m .32616 .61055 L .33167 .6132 L p F P
0 g
s
.651 .758 .928 r
.66751 .47244 m .67957 .46861 L .68245 .47214 L p F P
0 g
s
.651 .758 .928 r
.67957 .46861 m .66751 .47244 L .66462 .46891 L p F P
0 g
s
.651 .758 .928 r
.48544 .47249 m .49717 .46866 L .50035 .47219 L p F P
0 g
s
.651 .758 .928 r
.49717 .46866 m .48544 .47249 L .48224 .46896 L p F P
0 g
s
.572 .373 .573 r
.45633 .71837 m .456 .71232 L .46796 .70921 L p F P
0 g
s
.582 .402 .603 r
.4673 .70286 m .46796 .70921 L .456 .71232 L p F P
0 g
s
.818 .633 .652 r
.31427 .68528 m .32089 .68751 L .31816 .69389 L p F P
0 g
s
.817 .642 .665 r
.32089 .68751 m .31427 .68528 L .31743 .67878 L p F P
0 g
s
.779 .544 .581 r
.34317 .71989 m .3347 .71826 L .3359 .7123 L p F P
0 g
s
.786 .551 .582 r
.33418 .71193 m .3359 .7123 L .3347 .71826 L p F P
0 g
s
.651 .758 .928 r
.86453 .47195 m .87695 .46809 L .87949 .47162 L p F P
0 g
s
.651 .758 .928 r
.87695 .46809 m .86453 .47195 L .86196 .46842 L p F P
0 g
s
.557 .445 .681 r
.47516 .67865 m .47444 .67549 L .4841 .67507 L closepath p F P
0 g
s
.625 .359 .494 r
.43068 .72894 m .43056 .72865 L .4307 .72863 L closepath p F P
0 g
s
.629 .356 .486 r
.43056 .72865 m .43068 .72894 L p .41637 .73522 L F P
0 g
s
.651 .758 .928 r
.68245 .47214 m .69454 .46831 L .69739 .47184 L p F P
0 g
s
.651 .758 .928 r
.69454 .46831 m .68245 .47214 L .67957 .46861 L p F P
0 g
s
.595 .328 .482 r
.4307 .72863 m .44376 .72662 L .44325 .73192 L p F P
0 g
s
.595 .328 .482 r
.43068 .72894 m .4307 .72863 L p .44325 .73192 L F P
0 g
s
.651 .758 .928 r
.50035 .47219 m .51211 .46836 L .51526 .4719 L p F P
0 g
s
.651 .758 .928 r
.51211 .46836 m .50035 .47219 L .49717 .46866 L p F P
0 g
s
.741 .448 .487 r
.37037 .73483 m .36209 .73383 L .36111 .72848 L p F P
0 g
s
.741 .449 .488 r
.35365 .72757 m .36111 .72848 L .36209 .73383 L p F P
0 g
s
.786 .551 .582 r
.3347 .71826 m .33467 .71825 L .33418 .71193 L p F P
0 g
s
.806 .566 .575 r
.32833 .71039 m .33418 .71193 L .33467 .71825 L p F P
0 g
s
.595 .328 .482 r
.44325 .73192 m .4339 .73336 L .43068 .72894 L p F P
0 g
s
.6 .329 .478 r
.4339 .73336 m .43014 .73389 L .43068 .72894 L closepath p F P
0 g
s
.629 .356 .486 r
.43068 .72894 m .43014 .73389 L .41637 .73522 L p F P
0 g
s
.823 .701 .731 r
.31481 .63485 m .32045 .63744 L .31546 .64447 L p F P
0 g
s
.819 .698 .732 r
.31992 .62779 m .31481 .63485 L .32045 .63744 L p F P
0 g
s
.819 .698 .732 r
.32275 .6291 m .31992 .62779 L p .32045 .63744 L F P
0 g
s
.823 .651 .67 r
.3111 .67645 m .31743 .67878 L .31427 .68528 L p F P
0 g
s
.822 .659 .68 r
.31743 .67878 m .3111 .67645 L .31462 .66984 L p F P
0 g
s
.651 .758 .928 r
.69739 .47184 m .7095 .46801 L .71233 .47154 L p F P
0 g
s
.651 .758 .928 r
.7095 .46801 m .69739 .47184 L .69454 .46831 L p F P
0 g
s
.821 .681 .709 r
.31575 .65526 m .31661 .65392 L .31471 .65316 L closepath p F P
0 g
s
.814 .691 .729 r
.3124 .64893 m .31546 .64447 L p .31661 .65392 L F P
0 g
s
.814 .691 .729 r
.31661 .65392 m .31471 .65316 L .3124 .64893 L p F P
0 g
s
.819 .709 .743 r
.32275 .6291 m .32105 .62632 L .31992 .62779 L closepath p F P
0 g
s
.651 .758 .928 r
.51526 .4719 m .52705 .46807 L .53018 .4716 L p F P
0 g
s
.651 .758 .928 r
.52705 .46807 m .51526 .4719 L .51211 .46836 L p F P
0 g
s
.55 .426 .664 r
.47658 .68571 m .47516 .67865 L .4841 .67507 L p F P
0 g
s
.558 .455 .693 r
.48297 .66175 m .47619 .66205 L .4824 .65946 L closepath p F P
0 g
s
.567 .471 .705 r
.4803 .65173 m .4824 .65946 L .47619 .66205 L p F P
0 g
s
.776 .514 .539 r
.35147 .7272 m .34292 .72559 L .34317 .71989 L p F P
0 g
s
.777 .516 .541 r
.3347 .71826 m .34317 .71989 L .34292 .72559 L p F P
0 g
s
.651 .758 .928 r
.71233 .47154 m .72447 .4677 L .72727 .47124 L p F P
0 g
s
.651 .758 .928 r
.72447 .4677 m .71233 .47154 L .7095 .46801 L p F P
0 g
s
.827 .683 .704 r
.31242 .66072 m .31575 .65526 L .31471 .65316 L p F P
0 g
s
.651 .758 .928 r
.53018 .4716 m .54199 .46777 L .5451 .4713 L p F P
0 g
s
.651 .758 .928 r
.54199 .46777 m .53018 .4716 L .52705 .46807 L p F P
0 g
s
.818 .713 .749 r
.32577 .6205 m .32105 .62632 L .31766 .62103 L p F P
0 g
s
.818 .713 .749 r
.31766 .62103 m .32019 .61787 L .32577 .6205 L p F P
0 g
s
.816 .714 .752 r
.32577 .6205 m .32019 .61787 L .32616 .61055 L p F P
0 g
s
.651 .758 .928 r
.72727 .47124 m .73945 .4674 L .74222 .47093 L p F P
0 g
s
.651 .758 .928 r
.73945 .4674 m .72727 .47124 L .72447 .4677 L p F P
0 g
s
.651 .758 .928 r
.5451 .4713 m .55694 .46747 L .56002 .47101 L p F P
0 g
s
.651 .758 .928 r
.55694 .46747 m .5451 .4713 L .54199 .46777 L p F P
0 g
s
.827 .674 .693 r
.31462 .66984 m .30859 .66741 L .31242 .66072 L p F P
0 g
s
.828 .668 .685 r
.30859 .66741 m .31462 .66984 L .3111 .67645 L p F P
0 g
s
.57 .506 .744 r
.47025 .61983 m .46707 .62014 L .46991 .61882 L closepath p F P
0 g
s
.577 .517 .75 r
.46706 .61082 m .46991 .61882 L .46707 .62014 L p F P
0 g
s
.577 .517 .75 r
.46474 .61105 m .46706 .61082 L p .46707 .62014 L F P
0 g
s
.554 .382 .602 r
.46796 .70921 m .4673 .70286 L .47872 .69917 L p F P
0 g
s
.564 .405 .625 r
.4778 .69258 m .47872 .69917 L .4673 .70286 L p F P
0 g
s
.827 .683 .704 r
.31471 .65316 m .31078 .65142 L p .31242 .66072 L F P
0 g
s
.828 .694 .717 r
.31471 .65316 m .3124 .64893 L .31078 .65142 L closepath p F P
0 g
s
.651 .758 .928 r
.74222 .47093 m .75443 .46709 L .75718 .47062 L p F P
0 g
s
.651 .758 .928 r
.75443 .46709 m .74222 .47093 L .73945 .4674 L p F P
0 g
s
.66 .335 .41 r
.39709 .73589 m .40189 .73588 L .40063 .74055 L p F P
0 g
s
.66 .335 .41 r
.40063 .74055 m .4006 .74055 L .39709 .73589 L p F P
0 g
s
.655 .304 .366 r
.38663 .7358 m .39709 .73589 L .4006 .74055 L p F P
0 g
s
.634 .309 .402 r
.40063 .74055 m .40189 .73588 L .41273 .73542 L p F P
0 g
s
.651 .758 .928 r
.56002 .47101 m .5719 .46717 L .57495 .47071 L p F P
0 g
s
.651 .758 .928 r
.5719 .46717 m .56002 .47101 L .55694 .46747 L p F P
0 g
s
.741 .449 .488 r
.36209 .73383 m .35285 .73272 L .35365 .72757 L p F P
0 g
s
.765 .473 .49 r
.35147 .7272 m .35365 .72757 L .35285 .73272 L p F P
0 g
s
.655 .304 .366 r
.38573 .73902 m .38663 .7358 L p .4006 .74055 L F P
0 g
s
.692 .367 .42 r
.38573 .73902 m .38385 .73566 L .38663 .7358 L closepath p F P
0 g
s
.694 .35 .39 r
.38385 .73566 m .38573 .73902 L .38521 .74036 L p F P
0 g
s
.694 .35 .39 r
.37225 .73496 m .38385 .73566 L p .38521 .74036 L F P
0 g
s
.651 .758 .928 r
.75718 .47062 m .76941 .46678 L .77213 .47032 L p F P
0 g
s
.651 .758 .928 r
.76941 .46678 m .75718 .47062 L .75443 .46709 L p F P
0 g
s
.651 .758 .928 r
.57495 .47071 m .58686 .46687 L .58989 .47041 L p F P
0 g
s
.651 .758 .928 r
.58686 .46687 m .57495 .47071 L .5719 .46717 L p F P
0 g
s
.824 .717 .747 r
.31992 .62779 m .32105 .62632 L .31766 .62103 L p F P
0 g
s
.827 .696 .72 r
.31546 .64447 m .3124 .64893 L .30903 .64297 L p F P
0 g
s
.827 .696 .72 r
.30903 .64297 m .30975 .64191 L .31546 .64447 L p F P
0 g
s
.823 .701 .731 r
.31546 .64447 m .30975 .64191 L .31481 .63485 L p F P
0 g
s
.81 .722 .768 r
.33259 .60308 m .32958 .60643 L .32619 .60139 L p F P
0 g
s
.81 .722 .768 r
.32619 .60139 m .32706 .60042 L .33259 .60308 L p F P
0 g
s
.765 .473 .49 r
.35285 .73272 m .35223 .73262 L .35147 .7272 L p F P
0 g
s
.773 .475 .483 r
.34292 .72559 m .35147 .7272 L .35223 .73262 L p F P
0 g
s
.631 .315 .416 r
.41559 .73851 m .41273 .73542 L .41637 .73522 L closepath p F P
0 g
s
.634 .309 .402 r
.41273 .73542 m .41559 .73851 L p .40063 .74055 L F P
0 g
s
.651 .758 .928 r
.77213 .47032 m .7844 .46647 L .7871 .47 L p F P
0 g
s
.651 .758 .928 r
.7844 .46647 m .77213 .47032 L .76941 .46678 L p F P
0 g
s
.83 .715 .738 r
.31461 .62508 m .31992 .62779 L .31481 .63485 L p F P
0 g
s
.824 .717 .747 r
.31766 .62103 m .31461 .62508 L .31992 .62779 L p F P
0 g
s
.546 .411 .649 r
.47658 .68571 m .48741 .68138 L p .48057 .6915 L F P
0 g
s
.546 .411 .649 r
.48057 .6915 m .47759 .6914 L .47658 .68571 L p F P
0 g
s
.55 .426 .664 r
.48614 .67512 m .48741 .68138 L .47658 .68571 L p F P
0 g
s
.55 .426 .664 r
.4841 .67507 m .48614 .67512 L p .47658 .68571 L F P
0 g
s
.81 .591 .606 r
.32833 .71039 m .32113 .70836 L .32283 .70226 L p F P
0 g
s
.815 .598 .609 r
.31587 .70015 m .32283 .70226 L .32113 .70836 L p F P
0 g
s
.814 .613 .631 r
.32283 .70226 m .31587 .70015 L .31816 .69389 L p F P
0 g
s
.651 .758 .928 r
.58989 .47041 m .60182 .46657 L .60482 .47011 L p F P
0 g
s
.651 .758 .928 r
.60182 .46657 m .58989 .47041 L .58686 .46687 L p F P
0 g
s
.651 .757 .928 r
.40763 .47043 m .41923 .4666 L .42254 .47014 L p F P
0 g
s
.819 .624 .639 r
.31147 .69169 m .31816 .69389 L .31587 .70015 L p F P
0 g
s
.818 .633 .652 r
.31816 .69389 m .31147 .69169 L .31427 .68528 L p F P
0 g
s
.82 .724 .759 r
.32616 .61055 m .32958 .60643 L .32619 .60139 L p F P
0 g
s
.57 .515 .754 r
.46706 .61082 m .46474 .61105 L .46679 .61007 L closepath p F P
0 g
s
.578 .524 .758 r
.46387 .60222 m .46679 .61007 L .46474 .61105 L p F P
0 g
s
.578 .524 .758 r
.46042 .60257 m .46387 .60222 L p .46474 .61105 L F P
0 g
s
.833 .684 .697 r
.30669 .65818 m .31242 .66072 L .30859 .66741 L p F P
0 g
s
.827 .683 .704 r
.31078 .65142 m .30669 .65818 L .31242 .66072 L p F P
0 g
s
.806 .566 .575 r
.33467 .71825 m .3273 .7163 L .32833 .71039 L p F P
0 g
s
.811 .572 .577 r
.32113 .70836 m .32833 .71039 L .3273 .7163 L p F P
0 g
s
.588 .255 .372 r
.41637 .73522 m .43014 .73389 L .42891 .73854 L p F P
0 g
s
.588 .255 .372 r
.41559 .73851 m .41637 .73522 L p .42891 .73854 L F P
0 g
s
.651 .758 .928 r
.7871 .47 m .79939 .46616 L .80206 .46969 L p F P
0 g
s
.651 .758 .928 r
.79939 .46616 m .7871 .47 L .7844 .46647 L p F P
0 g
s
.651 .758 .928 r
.60482 .47011 m .61678 .46627 L .61977 .46981 L p F P
0 g
s
.651 .758 .928 r
.61678 .46627 m .60482 .47011 L .60182 .46657 L p F P
0 g
s
.651 .757 .928 r
.42254 .47014 m .43417 .4663 L .43746 .46984 L p F P
0 g
s
.651 .757 .928 r
.43417 .4663 m .42254 .47014 L .41923 .4666 L p F P
0 g
s
.571 .523 .763 r
.46387 .60222 m .46042 .60257 L .46344 .60107 L closepath p F P
0 g
s
.543 .474 .728 r
.4755 .63567 m .4854 .63028 L p .48605 .63955 L F P
0 g
s
.543 .474 .728 r
.48605 .63955 m .47661 .63934 L .4755 .63567 L p F P
0 g
s
.542 .483 .739 r
.48514 .62953 m .4854 .63028 L .4755 .63567 L p F P
0 g
s
.542 .483 .739 r
.4755 .63567 m .47343 .62931 L .48514 .62953 L p F P
0 g
s
.537 .479 .738 r
.48258 .62181 m .48514 .62953 L .47343 .62931 L p F P
0 g
s
.537 .479 .738 r
.47343 .62931 m .4728 .62735 L .48258 .62181 L p F P
0 g
s
.542 .491 .748 r
.48195 .62003 m .48258 .62181 L .4728 .62735 L p F P
0 g
s
.542 .491 .748 r
.4728 .62735 m .47025 .61983 L .48195 .62003 L p F P
0 g
s
.824 .644 .659 r
.30787 .68298 m .31427 .68528 L .31147 .69169 L p F P
0 g
s
.823 .651 .67 r
.31427 .68528 m .30787 .68298 L .3111 .67645 L p F P
0 g
s
.694 .35 .39 r
.38521 .74036 m .37541 .7397 L .37225 .73496 L p F P
0 g
s
.694 .351 .39 r
.37037 .73483 m .37225 .73496 L .37541 .7397 L p F P
0 g
s
.543 .476 .731 r
.47799 .6438 m .47661 .63934 L .48605 .63955 L closepath p F P
0 g
s
.557 .333 .531 r
.4563 .72409 m .45633 .71837 L .46832 .71527 L p F P
0 g
s
.572 .373 .573 r
.46796 .70921 m .46832 .71527 L .45633 .71837 L p F P
0 g
s
.587 .357 .534 r
.45633 .71837 m .4563 .72409 L .44376 .72662 L p F P
0 g
s
.651 .758 .928 r
.80206 .46969 m .81438 .46584 L .81703 .46938 L p F P
0 g
s
.651 .758 .928 r
.81438 .46584 m .80206 .46969 L .79939 .46616 L p F P
0 g
s
.566 .303 .477 r
.44325 .73192 m .44376 .72662 L .4563 .72409 L p F P
0 g
s
.542 .466 .72 r
.47799 .6438 m .48605 .63955 L p .48348 .65011 L F P
0 g
s
.542 .466 .72 r
.48348 .65011 m .47979 .65 L .47799 .6438 L p F P
0 g
s
.651 .758 .928 r
.61977 .46981 m .63176 .46597 L .63471 .46951 L p F P
0 g
s
.651 .758 .928 r
.63176 .46597 m .61977 .46981 L .61678 .46627 L p F P
0 g
s
.651 .757 .928 r
.43746 .46984 m .44912 .46601 L .45238 .46955 L p F P
0 g
s
.651 .757 .928 r
.44912 .46601 m .43746 .46984 L .43417 .4663 L p F P
0 g
s
.694 .351 .39 r
.37541 .7397 m .36878 .73926 L .37037 .73483 L p F P
0 g
s
.726 .384 .4 r
.36209 .73383 m .37037 .73483 L .36878 .73926 L p F P
0 g
s
.777 .516 .541 r
.33462 .71994 m .3347 .71826 L p .34292 .72559 L F P
0 g
s
.785 .523 .541 r
.33462 .71994 m .3347 .71826 L .33467 .71825 L closepath p F P
0 g
s
.799 .535 .539 r
.33467 .71825 m .3273 .7163 L p .33441 .72397 L F P
0 g
s
.799 .535 .539 r
.33441 .72397 m .33462 .71994 L .33467 .71825 L p F P
0 g
s
.537 .486 .747 r
.47955 .61313 m .48195 .62003 L .47025 .61983 L p F P
0 g
s
.537 .486 .747 r
.47025 .61983 m .46991 .61882 L .47955 .61313 L p F P
0 g
s
.822 .726 .759 r
.32101 .60777 m .32616 .61055 L .32019 .61787 L p F P
0 g
s
.82 .724 .759 r
.32619 .60139 m .32101 .60777 L .32616 .61055 L p F P
0 g
s
.541 .498 .758 r
.47876 .61098 m .47955 .61313 L .46991 .61882 L p F P
0 g
s
.541 .498 .758 r
.46991 .61882 m .46706 .61082 L .47876 .61098 L p F P
0 g
s
.831 .7 .719 r
.31078 .65142 m .3124 .64893 L .30903 .64297 L p F P
0 g
s
.651 .758 .928 r
.81703 .46938 m .82938 .46552 L .83201 .46906 L p F P
0 g
s
.651 .758 .928 r
.82938 .46552 m .81703 .46938 L .81438 .46584 L p F P
0 g
s
.542 .468 .722 r
.4803 .65173 m .47979 .65 L .48348 .65011 L closepath p F P
0 g
s
.651 .758 .928 r
.63471 .46951 m .64673 .46567 L .64966 .46921 L p F P
0 g
s
.651 .758 .928 r
.64673 .46567 m .63471 .46951 L .63176 .46597 L p F P
0 g
s
.651 .758 .928 r
.45238 .46955 m .46407 .46571 L .46731 .46925 L p F P
0 g
s
.651 .757 .928 r
.46407 .46571 m .45238 .46955 L .44912 .46601 L p F P
0 g
s
.535 .452 .708 r
.4824 .65946 m .4803 .65173 L .48348 .65011 L p F P
0 g
s
.828 .663 .678 r
.30501 .67404 m .3111 .67645 L .30787 .68298 L p F P
0 g
s
.828 .668 .685 r
.3111 .67645 m .30501 .67404 L .30859 .66741 L p F P
0 g
s
.651 .758 .928 r
.83201 .46906 m .84438 .4652 L .84698 .46874 L p F P
0 g
s
.651 .758 .928 r
.84438 .4652 m .83201 .46906 L .82938 .46552 L p F P
0 g
s
.536 .495 .757 r
.47628 .6042 m .47876 .61098 L .46706 .61082 L p F P
0 g
s
.536 .495 .757 r
.46706 .61082 m .46679 .61007 L .47628 .6042 L p F P
0 g
s
.651 .758 .928 r
.64966 .46921 m .66171 .46537 L .66462 .46891 L p F P
0 g
s
.651 .758 .928 r
.66171 .46537 m .64966 .46921 L .64673 .46567 L p F P
0 g
s
.651 .758 .928 r
.46731 .46925 m .47902 .46541 L .48224 .46896 L p F P
0 g
s
.651 .758 .928 r
.47902 .46541 m .46731 .46925 L .46407 .46571 L p F P
0 g
s
.541 .506 .767 r
.47556 .60232 m .47628 .6042 L .46679 .61007 L p F P
0 g
s
.541 .506 .767 r
.46679 .61007 m .46387 .60222 L .47556 .60232 L p F P
0 g
s
.825 .717 .745 r
.30948 .63216 m .31481 .63485 L .30975 .64191 L p F P
0 g
s
.83 .715 .738 r
.31481 .63485 m .30948 .63216 L .31461 .62508 L p F P
0 g
s
.839 .699 .708 r
.30535 .64877 m .31078 .65142 L .30669 .65818 L p F P
0 g
s
.831 .7 .719 r
.30903 .64297 m .30535 .64877 L .31078 .65142 L p F P
0 g
s
.546 .412 .65 r
.4778 .69258 m .47759 .6914 L .48057 .6915 L closepath p F P
0 g
s
.651 .758 .928 r
.84698 .46874 m .85939 .46488 L .86196 .46842 L p F P
0 g
s
.651 .758 .928 r
.85939 .46488 m .84698 .46874 L .84438 .4652 L p F P
0 g
s
.651 .758 .928 r
.66462 .46891 m .67669 .46507 L .67957 .46861 L p F P
0 g
s
.651 .758 .928 r
.67669 .46507 m .66462 .46891 L .66171 .46537 L p F P
0 g
s
.777 .516 .541 r
.34292 .72559 m .33449 .72399 L .33462 .71994 L p F P
0 g
s
.798 .534 .539 r
.33449 .72399 m .33462 .71994 L .33441 .72397 L closepath p F P
0 g
s
.651 .758 .928 r
.48224 .46896 m .49398 .46511 L .49717 .46866 L p F P
0 g
s
.651 .758 .928 r
.49398 .46511 m .48224 .46896 L .47902 .46541 L p F P
0 g
s
.541 .35 .571 r
.46832 .71527 m .46796 .70921 L .47939 .70552 L p F P
0 g
s
.554 .382 .602 r
.47872 .69917 m .47939 .70552 L .46796 .70921 L p F P
0 g
s
.533 .439 .694 r
.4824 .65946 m .4925 .6543 L p .49295 .66268 L F P
0 g
s
.533 .439 .694 r
.49295 .66268 m .48297 .66175 L .4824 .65946 L p F P
0 g
s
.535 .452 .708 r
.49152 .6508 m .4925 .6543 L .4824 .65946 L p F P
0 g
s
.535 .452 .708 r
.48348 .65011 m .49152 .6508 L p .4824 .65946 L F P
0 g
s
.534 .385 .624 r
.47872 .69917 m .4778 .69258 L .48057 .6915 L p F P
0 g
s
.651 .758 .928 r
.86196 .46842 m .8744 .46455 L .87695 .46809 L p F P
0 g
s
.651 .758 .928 r
.8744 .46455 m .86196 .46842 L .85939 .46488 L p F P
0 g
s
.566 .242 .379 r
.43014 .73389 m .4339 .73336 L .44211 .73669 L p F P
0 g
s
.566 .242 .379 r
.44211 .73669 m .42891 .73854 L .43014 .73389 L p F P
0 g
s
.773 .475 .483 r
.35223 .73262 m .34375 .73099 L .34292 .72559 L p F P
0 g
s
.773 .473 .48 r
.33449 .72399 m .34292 .72559 L .34375 .73099 L p F P
0 g
s
.825 .724 .752 r
.32019 .61787 m .31766 .62103 L .31425 .616 L p F P
0 g
s
.825 .724 .752 r
.31425 .616 m .31494 .61513 L .32019 .61787 L p F P
0 g
s
.822 .726 .759 r
.32019 .61787 m .31494 .61513 L .32101 .60777 L p F P
0 g
s
.726 .384 .4 r
.36878 .73926 m .36464 .73875 L .36209 .73383 L p F P
0 g
s
.724 .368 .375 r
.35285 .73272 m .36209 .73383 L .36464 .73875 L p F P
0 g
s
.651 .758 .928 r
.67957 .46861 m .69168 .46477 L .69454 .46831 L p F P
0 g
s
.651 .758 .928 r
.69168 .46477 m .67957 .46861 L .67669 .46507 L p F P
0 g
s
.651 .758 .928 r
.50894 .46482 m .49717 .46866 L .49398 .46511 L p F P
0 g
s
.651 .758 .928 r
.49717 .46866 m .50894 .46482 L .51211 .46836 L p F P
0 g
s
.532 .44 .696 r
.48428 .66697 m .48297 .66175 L .49295 .66268 L closepath p F P
0 g
s
.536 .503 .767 r
.47276 .595 m .47556 .60232 L .46387 .60222 L p F P
0 g
s
.536 .503 .767 r
.46387 .60222 m .46344 .60107 L .47276 .595 L p F P
0 g
s
.832 .682 .696 r
.30282 .66489 m .30859 .66741 L .30501 .67404 L p F P
0 g
s
.833 .684 .697 r
.30859 .66741 m .30282 .66489 L .30669 .65818 L p F P
0 g
s
.651 .758 .928 r
.69454 .46831 m .70667 .46446 L .7095 .46801 L p F P
0 g
s
.651 .758 .928 r
.70667 .46446 m .69454 .46831 L .69168 .46477 L p F P
0 g
s
.651 .758 .928 r
.51211 .46836 m .52391 .46452 L .52705 .46807 L p F P
0 g
s
.651 .758 .928 r
.52391 .46452 m .51211 .46836 L .50894 .46482 L p F P
0 g
s
.832 .726 .747 r
.31461 .62508 m .31766 .62103 L .31425 .616 L p F P
0 g
s
.564 .251 .397 r
.4339 .73336 m .44325 .73192 L .44217 .73668 L p F P
0 g
s
.564 .251 .397 r
.44217 .73668 m .44211 .73669 L .4339 .73336 L p F P
0 g
s
.651 .758 .928 r
.7095 .46801 m .72167 .46416 L .72447 .4677 L p F P
0 g
s
.651 .758 .928 r
.72167 .46416 m .7095 .46801 L .70667 .46446 L p F P
0 g
s
.655 .304 .366 r
.4006 .74055 m .38707 .7404 L .38573 .73902 L p F P
0 g
s
.657 .303 .361 r
.38707 .7404 m .38521 .74036 L .38573 .73902 L closepath p F P
0 g
s
.815 .598 .609 r
.32113 .70836 m .31411 .70627 L .31587 .70015 L p F P
0 g
s
.821 .606 .612 r
.31057 .69844 m .31587 .70015 L .31411 .70627 L p F P
0 g
s
.819 .624 .639 r
.3099 .69596 m .31147 .69169 L p .31587 .70015 L F P
0 g
s
.819 .624 .639 r
.31587 .70015 m .31057 .69844 L .3099 .69596 L p F P
0 g
s
.651 .758 .928 r
.52705 .46807 m .53888 .46422 L .54199 .46777 L p F P
0 g
s
.651 .758 .928 r
.53888 .46422 m .52705 .46807 L .52391 .46452 L p F P
0 g
s
.526 .426 .684 r
.48598 .6743 m .48428 .66697 L .49295 .66268 L p F P
0 g
s
.557 .443 .679 r
.48428 .66697 m .48598 .6743 L .4841 .67507 L p F P
0 g
s
.811 .572 .577 r
.3273 .7163 m .32007 .71428 L .32113 .70836 L p F P
0 g
s
.815 .578 .58 r
.31411 .70627 m .32113 .70836 L .32007 .71428 L p F P
0 g
s
.828 .63 .635 r
.3099 .69596 m .31147 .69169 L .30843 .69061 L closepath p F P
0 g
s
.824 .644 .659 r
.30673 .68564 m .30787 .68298 L p .31147 .69169 L F P
0 g
s
.824 .644 .659 r
.31147 .69169 m .30843 .69061 L .30673 .68564 L p F P
0 g
s
.547 .423 .664 r
.48614 .67512 m .4841 .67507 L .48598 .6743 L closepath p F P
0 g
s
.834 .708 .724 r
.30903 .64297 m .30975 .64191 L .30784 .64097 L closepath p F P
0 g
s
.825 .717 .745 r
.30563 .63755 m .30948 .63216 L p .30975 .64191 L F P
0 g
s
.825 .717 .745 r
.30975 .64191 m .30784 .64097 L .30563 .63755 L p F P
0 g
s
.651 .758 .928 r
.72447 .4677 m .73667 .46385 L .73945 .4674 L p F P
0 g
s
.651 .758 .928 r
.73667 .46385 m .72447 .4677 L .72167 .46416 L p F P
0 g
s
.817 .735 .774 r
.32619 .60139 m .32706 .60042 L .32447 .59901 L closepath p F P
0 g
s
.651 .758 .928 r
.54199 .46777 m .55385 .46392 L .55694 .46747 L p F P
0 g
s
.651 .758 .928 r
.55385 .46392 m .54199 .46777 L .53888 .46422 L p F P
0 g
s
.531 .452 .711 r
.49152 .6508 m .48348 .65011 L .49034 .6465 L closepath p F P
0 g
s
.542 .466 .72 r
.48833 .63972 m .49034 .6465 L .48348 .65011 L p F P
0 g
s
.542 .466 .72 r
.48605 .63955 m .48833 .63972 L p .48348 .65011 L F P
0 g
s
.83 .736 .761 r
.32101 .60777 m .32619 .60139 L .32447 .59901 L p F P
0 g
s
.534 .385 .624 r
.48057 .6915 m .48931 .69279 L p .47872 .69917 L F P
0 g
s
.533 .387 .628 r
.48931 .69279 m .48057 .6915 L .48864 .68827 L closepath p F P
0 g
s
.546 .411 .649 r
.48741 .68138 m .48864 .68827 L .48057 .6915 L p F P
0 g
s
.84 .709 .718 r
.30535 .64877 m .30903 .64297 L .30784 .64097 L p F P
0 g
s
.799 .535 .539 r
.3273 .7163 m .32703 .722 L .33441 .72397 L p F P
0 g
s
.812 .545 .536 r
.32007 .71428 m .3273 .7163 L .32703 .722 L p F P
0 g
s
.837 .727 .743 r
.30962 .62226 m .31461 .62508 L .30948 .63216 L p F P
0 g
s
.832 .726 .747 r
.31425 .616 m .30962 .62226 L .31461 .62508 L p F P
0 g
s
.651 .758 .928 r
.73945 .4674 m .75167 .46354 L .75443 .46709 L p F P
0 g
s
.651 .758 .928 r
.75167 .46354 m .73945 .4674 L .73667 .46385 L p F P
0 g
s
.588 .255 .372 r
.42891 .73854 m .41767 .73967 L .41559 .73851 L p F P
0 g
s
.592 .248 .355 r
.41767 .73967 m .41513 .73989 L .41559 .73851 L closepath p F P
0 g
s
.634 .309 .402 r
.41559 .73851 m .41513 .73989 L .40063 .74055 L p F P
0 g
s
.84 .695 .702 r
.30124 .65555 m .30669 .65818 L .30282 .66489 L p F P
0 g
s
.839 .699 .708 r
.30669 .65818 m .30124 .65555 L .30535 .64877 L p F P
0 g
s
.651 .758 .928 r
.55694 .46747 m .56883 .46362 L .5719 .46717 L p F P
0 g
s
.651 .758 .928 r
.56883 .46362 m .55694 .46747 L .55385 .46392 L p F P
0 g
s
.724 .368 .375 r
.35257 .73359 m .35285 .73272 L p .36464 .73875 L F P
0 g
s
.756 .427 .427 r
.35257 .73359 m .35223 .73262 L .35285 .73272 L closepath p F P
0 g
s
.834 .65 .655 r
.30673 .68564 m .30787 .68298 L .30547 .68205 L closepath p F P
0 g
s
.828 .663 .678 r
.30347 .67721 m .30501 .67404 L p .30787 .68298 L F P
0 g
s
.828 .663 .678 r
.30787 .68298 m .30547 .68205 L .30347 .67721 L p F P
0 g
s
.761 .411 .391 r
.35223 .73262 m .35257 .73359 L .35104 .737 L p F P
0 g
s
.761 .411 .391 r
.34375 .73099 m .35223 .73262 L p .35104 .737 L F P
0 g
s
.651 .758 .928 r
.75443 .46709 m .76668 .46323 L .76941 .46678 L p F P
0 g
s
.651 .758 .928 r
.76668 .46323 m .75443 .46709 L .75167 .46354 L p F P
0 g
s
.651 .758 .928 r
.5719 .46717 m .58382 .46332 L .58686 .46687 L p F P
0 g
s
.651 .758 .928 r
.58382 .46332 m .5719 .46717 L .56883 .46362 L p F P
0 g
s
.532 .273 .468 r
.4558 .72937 m .4563 .72409 L .4683 .72099 L p F P
0 g
s
.557 .333 .531 r
.46832 .71527 m .4683 .72099 L .4563 .72409 L p F P
0 g
s
.566 .303 .477 r
.4563 .72409 m .4558 .72937 L .44325 .73192 L p F P
0 g
s
.52 .406 .664 r
.48598 .6743 m .49617 .66926 L p .49635 .6771 L F P
0 g
s
.52 .406 .664 r
.49635 .6771 m .48614 .67512 L .48598 .6743 L p F P
0 g
s
.526 .426 .684 r
.49471 .66298 m .49617 .66926 L .48598 .6743 L p F P
0 g
s
.526 .426 .684 r
.49295 .66268 m .49471 .66298 L p .48598 .6743 L F P
0 g
s
.523 .359 .6 r
.47939 .70552 m .47872 .69917 L .48963 .69492 L p F P
0 g
s
.534 .385 .624 r
.48931 .69279 m .48963 .69492 L .47872 .69917 L p F P
0 g
s
.651 .758 .928 r
.76941 .46678 m .78169 .46292 L .7844 .46647 L p F P
0 g
s
.651 .758 .928 r
.78169 .46292 m .76941 .46678 L .76668 .46323 L p F P
0 g
s
.773 .473 .48 r
.33444 .72428 m .33449 .72399 L p .34375 .73099 L F P
0 g
s
.795 .503 .493 r
.33444 .72428 m .33441 .72397 L .33449 .72399 L closepath p F P
0 g
s
.651 .758 .928 r
.58686 .46687 m .5988 .46302 L .60182 .46657 L p F P
0 g
s
.651 .758 .928 r
.5988 .46302 m .58686 .46687 L .58382 .46332 L p F P
0 g
s
.805 .504 .48 r
.33441 .72397 m .33444 .72428 L .33349 .729 L p F P
0 g
s
.805 .504 .48 r
.32703 .722 m .33441 .72397 L p .33349 .729 L F P
0 g
s
.633 .26 .319 r
.40062 .74056 m .4006 .74055 L .40063 .74055 L closepath p F P
0 g
s
.596 .167 .197 r
.4006 .74055 m .40062 .74056 L .39806 .74405 L p F P
0 g
s
.596 .167 .197 r
.38707 .7404 m .4006 .74055 L p .39806 .74405 L F P
0 g
s
.558 .137 .199 r
.40063 .74055 m .41513 .73989 L .41276 .74353 L p F P
0 g
s
.558 .137 .199 r
.40062 .74056 m .40063 .74055 L p .41276 .74353 L F P
0 g
s
.558 .137 .199 r
.41276 .74353 m .40949 .74368 L .40062 .74056 L p F P
0 g
s
.556 .122 .172 r
.40949 .74368 m .39806 .74405 L .40062 .74056 L closepath p F P
0 g
s
.52 .407 .665 r
.48741 .68138 m .48614 .67512 L .49635 .6771 L closepath p F P
0 g
s
.84 .709 .718 r
.30784 .64097 m .30451 .63919 L p .30535 .64877 L F P
0 g
s
.839 .719 .731 r
.30784 .64097 m .30563 .63755 L .30451 .63919 L closepath p F P
0 g
s
.821 .743 .778 r
.3162 .60487 m .32101 .60777 L .31494 .61513 L p F P
0 g
s
.83 .736 .761 r
.3221 .59756 m .3162 .60487 L .32101 .60777 L p F P
0 g
s
.83 .736 .761 r
.32447 .59901 m .3221 .59756 L p .32101 .60777 L F P
0 g
s
.596 .167 .197 r
.39806 .74405 m .39428 .744 L .38707 .7404 L p F P
0 g
s
.597 .163 .188 r
.38521 .74036 m .38707 .7404 L .39428 .744 L p F P
0 g
s
.773 .473 .48 r
.34375 .73099 m .33525 .72936 L .33444 .72428 L p F P
0 g
s
.778 .477 .478 r
.33525 .72936 m .33349 .729 L .33444 .72428 L closepath p F P
0 g
s
.839 .67 .673 r
.30347 .67721 m .30501 .67404 L .30147 .67253 L closepath p F P
0 g
s
.832 .682 .696 r
.30016 .66984 m .30282 .66489 L p .30501 .67404 L F P
0 g
s
.832 .682 .696 r
.30501 .67404 m .30147 .67253 L .30016 .66984 L p F P
0 g
s
.835 .634 .63 r
.30843 .69061 m .30524 .68934 L p .30921 .69794 L F P
0 g
s
.835 .634 .63 r
.30921 .69794 m .3099 .69596 L .30843 .69061 L p F P
0 g
s
.838 .65 .649 r
.30843 .69061 m .30673 .68564 L .30524 .68934 L closepath p F P
0 g
s
.597 .163 .188 r
.39428 .744 m .38254 .7438 L .38521 .74036 L p F P
0 g
s
.641 .213 .215 r
.37541 .7397 m .38521 .74036 L .38254 .7438 L p F P
0 g
s
.651 .758 .928 r
.7844 .46647 m .7967 .46261 L .79939 .46616 L p F P
0 g
s
.651 .758 .928 r
.7967 .46261 m .7844 .46647 L .78169 .46292 L p F P
0 g
s
.724 .368 .375 r
.36464 .73875 m .35489 .7375 L .35257 .73359 L p F P
0 g
s
.724 .368 .374 r
.35489 .7375 m .35104 .737 L .35257 .73359 L closepath p F P
0 g
s
.651 .758 .928 r
.60182 .46657 m .61379 .46272 L .61678 .46627 L p F P
0 g
s
.651 .758 .928 r
.61379 .46272 m .60182 .46657 L .5988 .46302 L p F P
0 g
s
.651 .757 .928 r
.41923 .4666 m .43087 .46275 L .43417 .4663 L p F P
0 g
s
.84 .653 .649 r
.30524 .68934 m .30673 .68564 L .30547 .68205 L p F P
0 g
s
.53 .22 .386 r
.44217 .73668 m .44325 .73192 L .4558 .72937 L p F P
0 g
s
.522 .306 .527 r
.4683 .72099 m .46832 .71527 L .47976 .71159 L p F P
0 g
s
.541 .35 .571 r
.47939 .70552 m .47976 .71159 L .46832 .71527 L p F P
0 g
s
.84 .653 .649 r
.30547 .68205 m .30195 .68052 L p .30524 .68934 L F P
0 g
s
.842 .668 .667 r
.30547 .68205 m .30347 .67721 L .30195 .68052 L closepath p F P
0 g
s
.651 .758 .928 r
.79939 .46616 m .81172 .46229 L .81438 .46584 L p F P
0 g
s
.651 .758 .928 r
.81172 .46229 m .79939 .46616 L .7967 .46261 L p F P
0 g
s
.833 .632 .63 r
.31057 .69844 m .3099 .69596 L .30921 .69794 L closepath p F P
0 g
s
.651 .758 .928 r
.61678 .46627 m .62879 .46242 L .63176 .46597 L p F P
0 g
s
.651 .758 .928 r
.62879 .46242 m .61678 .46627 L .61379 .46272 L p F P
0 g
s
.651 .757 .928 r
.43417 .4663 m .44584 .46245 L .44912 .46601 L p F P
0 g
s
.651 .757 .928 r
.44584 .46245 m .43417 .4663 L .43087 .46275 L p F P
0 g
s
.846 .71 .713 r
.30019 .64603 m .30535 .64877 L .30124 .65555 L p F P
0 g
s
.84 .709 .718 r
.30451 .63919 m .30019 .64603 L .30535 .64877 L p F P
0 g
s
.84 .725 .737 r
.30948 .63216 m .30563 .63755 L .3022 .63254 L p F P
0 g
s
.84 .725 .737 r
.3022 .63254 m .30444 .62936 L .30948 .63216 L p F P
0 g
s
.837 .727 .743 r
.30948 .63216 m .30444 .62936 L .30962 .62226 L p F P
0 g
s
.821 .606 .612 r
.31411 .70627 m .31194 .70558 L .31057 .69844 L p F P
0 g
s
.838 .617 .603 r
.30921 .69794 m .31057 .69844 L .31194 .70558 L p F P
0 g
s
.521 .097 .177 r
.41276 .74353 m .41513 .73989 L .41767 .73967 L p F P
0 g
s
.651 .758 .928 r
.81438 .46584 m .82675 .46197 L .82938 .46552 L p F P
0 g
s
.651 .758 .928 r
.82675 .46197 m .81438 .46584 L .81172 .46229 L p F P
0 g
s
.651 .758 .928 r
.63176 .46597 m .64379 .46212 L .64673 .46567 L p F P
0 g
s
.651 .758 .928 r
.64379 .46212 m .63176 .46597 L .62879 .46242 L p F P
0 g
s
.651 .757 .928 r
.44912 .46601 m .46082 .46215 L .46407 .46571 L p F P
0 g
s
.651 .757 .928 r
.46082 .46215 m .44912 .46601 L .44584 .46245 L p F P
0 g
s
.641 .213 .215 r
.38254 .7438 m .38121 .74371 L .37541 .7397 L p F P
0 g
s
.579 .084 .043 r
.36878 .73926 m .37541 .7397 L .38121 .74371 L p F P
0 g
s
.532 .131 .227 r
.4271 .74191 m .41767 .73967 L .42891 .73854 L closepath p F P
0 g
s
.521 .097 .177 r
.41767 .73967 m .4271 .74191 L p .41276 .74353 L F P
0 g
s
.651 .758 .928 r
.82938 .46552 m .84177 .46165 L .84438 .4652 L p F P
0 g
s
.651 .758 .928 r
.84177 .46165 m .82938 .46552 L .82675 .46197 L p F P
0 g
s
.833 .737 .758 r
.31425 .616 m .31494 .61513 L .31265 .6138 L closepath p F P
0 g
s
.821 .743 .778 r
.31081 .6114 m .3162 .60487 L p .31494 .61513 L F P
0 g
s
.821 .743 .778 r
.31494 .61513 m .31265 .6138 L .31081 .6114 L p F P
0 g
s
.845 .687 .687 r
.30282 .66489 m .30016 .66984 L .2968 .66325 L p F P
0 g
s
.845 .687 .687 r
.2968 .66325 m .2973 .66229 L .30282 .66489 L p F P
0 g
s
.84 .695 .702 r
.30282 .66489 m .2973 .66229 L .30124 .65555 L p F P
0 g
s
.845 .672 .668 r
.30195 .68052 m .30347 .67721 L .30147 .67253 L p F P
0 g
s
.651 .758 .928 r
.64673 .46567 m .65879 .46182 L .66171 .46537 L p F P
0 g
s
.651 .758 .928 r
.65879 .46182 m .64673 .46567 L .64379 .46212 L p F P
0 g
s
.651 .758 .928 r
.46407 .46571 m .4758 .46186 L .47902 .46541 L p F P
0 g
s
.651 .758 .928 r
.4758 .46186 m .46407 .46571 L .46082 .46215 L p F P
0 g
s
.842 .737 .749 r
.30962 .62226 m .31425 .616 L .31265 .6138 L p F P
0 g
s
.512 .388 .649 r
.48864 .68827 m .48741 .68138 L .49635 .6771 L p F P
0 g
s
.815 .578 .58 r
.32007 .71428 m .31298 .71222 L .31411 .70627 L p F P
0 g
s
.823 .586 .581 r
.31194 .70558 m .31411 .70627 L .31298 .71222 L p F P
0 g
s
.838 .617 .603 r
.31194 .70558 m .30766 .704 L .30921 .69794 L p F P
0 g
s
.846 .626 .604 r
.30318 .69554 m .30921 .69794 L .30766 .704 L p F P
0 g
s
.835 .634 .63 r
.30524 .68934 m .30318 .69554 L .30921 .69794 L p F P
0 g
s
.651 .758 .928 r
.84438 .4652 m .8568 .46133 L .85939 .46488 L p F P
0 g
s
.651 .758 .928 r
.8568 .46133 m .84438 .4652 L .84177 .46165 L p F P
0 g
s
.761 .411 .391 r
.35104 .737 m .34596 .736 L .34375 .73099 L p F P
0 g
s
.761 .401 .372 r
.33525 .72936 m .34375 .73099 L .34596 .736 L p F P
0 g
s
.651 .758 .928 r
.66171 .46537 m .6738 .46151 L .67669 .46507 L p F P
0 g
s
.651 .758 .928 r
.6738 .46151 m .66171 .46537 L .65879 .46182 L p F P
0 g
s
.651 .758 .928 r
.47902 .46541 m .49078 .46156 L .49398 .46511 L p F P
0 g
s
.651 .758 .928 r
.49078 .46156 m .47902 .46541 L .4758 .46186 L p F P
0 g
s
.579 .084 .043 r
.36724 .7414 m .36878 .73926 L p .38121 .74371 L F P
0 g
s
.692 .286 .272 r
.36724 .7414 m .36464 .73875 L .36878 .73926 L closepath p F P
0 g
s
.812 .545 .536 r
.32703 .722 m .3198 .71999 L .32007 .71428 L p F P
0 g
s
.815 .55 .538 r
.31298 .71222 m .32007 .71428 L .3198 .71999 L p F P
0 g
s
.532 .461 .721 r
.48833 .63972 m .48605 .63955 L .48798 .6385 L closepath p F P
0 g
s
.543 .474 .728 r
.4854 .63028 m .48798 .6385 L .48605 .63955 L p F P
0 g
s
.85 .648 .629 r
.29945 .68685 m .30524 .68934 L .30318 .69554 L p F P
0 g
s
.84 .653 .649 r
.30195 .68052 m .29945 .68685 L .30524 .68934 L p F P
0 g
s
.651 .758 .928 r
.85939 .46488 m .87184 .461 L .8744 .46455 L p F P
0 g
s
.651 .758 .928 r
.87184 .461 m .85939 .46488 L .8568 .46133 L p F P
0 g
s
.845 .728 .735 r
.30451 .63919 m .30563 .63755 L .3022 .63254 L p F P
0 g
s
.651 .758 .928 r
.67669 .46507 m .68881 .46121 L .69168 .46477 L p F P
0 g
s
.651 .758 .928 r
.68881 .46121 m .67669 .46507 L .6738 .46151 L p F P
0 g
s
.651 .758 .928 r
.49398 .46511 m .50577 .46126 L .50894 .46482 L p F P
0 g
s
.651 .758 .928 r
.50577 .46126 m .49398 .46511 L .49078 .46156 L p F P
0 g
s
.845 .672 .668 r
.30147 .67253 m .2993 .67151 L p .30195 .68052 L F P
0 g
s
.845 .686 .684 r
.30147 .67253 m .30016 .66984 L .2993 .67151 L closepath p F P
0 g
s
.852 .725 .723 r
.29965 .63634 m .30451 .63919 L .30019 .64603 L p F P
0 g
s
.845 .728 .735 r
.3022 .63254 m .29965 .63634 L .30451 .63919 L p F P
0 g
s
.823 .586 .581 r
.31298 .71222 m .31261 .7121 L .31194 .70558 L p F P
0 g
s
.842 .6 .573 r
.30766 .704 m .31194 .70558 L .31261 .7121 L p F P
0 g
s
.651 .758 .928 r
.69168 .46477 m .70383 .4609 L .70667 .46446 L p F P
0 g
s
.651 .758 .928 r
.70383 .4609 m .69168 .46477 L .68881 .46121 L p F P
0 g
s
.67 .215 .163 r
.36464 .73875 m .36724 .7414 L .36582 .74248 L p F P
0 g
s
.67 .215 .163 r
.35489 .7375 m .36464 .73875 L p .36582 .74248 L F P
0 g
s
.651 .758 .928 r
.50894 .46482 m .52076 .46096 L .52391 .46452 L p F P
0 g
s
.651 .758 .928 r
.52076 .46096 m .50894 .46482 L .50577 .46126 L p F P
0 g
s
.508 .325 .568 r
.47976 .71159 m .47939 .70552 L .4903 .70127 L p F P
0 g
s
.523 .359 .6 r
.48963 .69492 m .4903 .70127 L .47939 .70552 L p F P
0 g
s
.84 .754 .768 r
.31768 .59452 m .3221 .59756 L .3162 .60487 L p F P
0 g
s
.854 .668 .65 r
.29642 .67794 m .30195 .68052 L .29945 .68685 L p F P
0 g
s
.845 .672 .668 r
.2993 .67151 m .29642 .67794 L .30195 .68052 L p F P
0 g
s
.805 .504 .48 r
.33349 .729 m .3277 .72745 L .32703 .722 L p F P
0 g
s
.81 .506 .474 r
.3198 .71999 m .32703 .722 L .3277 .72745 L p F P
0 g
s
.844 .709 .714 r
.29605 .65283 m .30124 .65555 L .2973 .66229 L p F P
0 g
s
.846 .71 .713 r
.30124 .65555 m .29605 .65283 L .30019 .64603 L p F P
0 g
s
.42 0 .073 r
.42891 .73854 m .44211 .73669 L p .43991 .74037 L F P
0 g
s
.42 0 .073 r
.4271 .74191 m .42891 .73854 L p .43991 .74037 L F P
0 g
s
.651 .758 .928 r
.70667 .46446 m .71885 .4606 L .72167 .46416 L p F P
0 g
s
.651 .758 .928 r
.71885 .4606 m .70667 .46446 L .70383 .4609 L p F P
0 g
s
.651 .758 .928 r
.52391 .46452 m .53575 .46066 L .53888 .46422 L p F P
0 g
s
.651 .758 .928 r
.53575 .46066 m .52391 .46452 L .52076 .46096 L p F P
0 g
s
.844 .74 .749 r
.30495 .61933 m .30962 .62226 L .30444 .62936 L p F P
0 g
s
.842 .737 .749 r
.31016 .61223 m .30495 .61933 L .30962 .62226 L p F P
0 g
s
.842 .737 .749 r
.31265 .6138 m .31016 .61223 L p .30962 .62226 L F P
0 g
s
.849 .691 .686 r
.2993 .67151 m .30016 .66984 L .2968 .66325 L p F P
0 g
s
.839 .745 .76 r
.31265 .6138 m .31081 .6114 L .31016 .61223 L closepath p F P
0 g
s
.651 .758 .928 r
.72167 .46416 m .73387 .46029 L .73667 .46385 L p F P
0 g
s
.651 .758 .928 r
.73387 .46029 m .72167 .46416 L .71885 .4606 L p F P
0 g
s
.651 .758 .928 r
.53888 .46422 m .55075 .46036 L .55385 .46392 L p F P
0 g
s
.651 .758 .928 r
.55075 .46036 m .53888 .46422 L .53575 .46066 L p F P
0 g
s
.506 .456 .735 r
.48798 .6385 m .4854 .63028 L .4863 .62967 L p F P
0 g
s
.515 .473 .748 r
.4854 .63028 m .48514 .62953 L .4863 .62967 L closepath p F P
0 g
s
.516 .471 .746 r
.4863 .62967 m .48514 .62953 L .48258 .62181 L p F P
0 g
s
.506 .445 .722 r
.48798 .6385 m .4972 .63234 L p .49813 .64152 L F P
0 g
s
.506 .445 .722 r
.49813 .64152 m .48833 .63972 L .48798 .6385 L p F P
0 g
s
.506 .456 .735 r
.49692 .63148 m .4972 .63234 L .48798 .6385 L p F P
0 g
s
.506 .456 .735 r
.4863 .62967 m .49692 .63148 L p .48798 .6385 L F P
0 g
s
.506 .446 .724 r
.49034 .6465 m .48833 .63972 L .49813 .64152 L closepath p F P
0 g
s
.505 .367 .627 r
.48864 .68827 m .49894 .68333 L p .49197 .69382 L F P
0 g
s
.505 .367 .627 r
.49197 .69382 m .48931 .69279 L .48864 .68827 L p F P
0 g
s
.512 .388 .649 r
.4979 .67759 m .49894 .68333 L .48864 .68827 L p F P
0 g
s
.512 .388 .649 r
.49635 .6771 m .4979 .67759 L p .48864 .68827 L F P
0 g
s
.516 .471 .746 r
.48258 .62181 m .48468 .62034 L p .4863 .62967 L F P
0 g
s
.514 .481 .757 r
.48258 .62181 m .48195 .62003 L .48468 .62034 L closepath p F P
0 g
s
.651 .758 .928 r
.73667 .46385 m .7489 .45998 L .75167 .46354 L p F P
0 g
s
.651 .758 .928 r
.7489 .45998 m .73667 .46385 L .73387 .46029 L p F P
0 g
s
.515 .479 .755 r
.48468 .62034 m .48195 .62003 L .47955 .61313 L p F P
0 g
s
.651 .758 .928 r
.55385 .46392 m .56576 .46006 L .56883 .46362 L p F P
0 g
s
.651 .758 .928 r
.56576 .46006 m .55385 .46392 L .55075 .46036 L p F P
0 g
s
.859 .687 .668 r
.29403 .66883 m .2993 .67151 L .29642 .67794 L p F P
0 g
s
.849 .691 .686 r
.2968 .66325 m .29403 .66883 L .2993 .67151 L p F P
0 g
s
.506 .436 .712 r
.49034 .6465 m .49813 .64152 L p .49657 .6518 L F P
0 g
s
.506 .436 .712 r
.49657 .6518 m .49152 .6508 L .49034 .6465 L p F P
0 g
s
.651 .758 .928 r
.75167 .46354 m .76393 .45967 L .76668 .46323 L p F P
0 g
s
.651 .758 .928 r
.76393 .45967 m .75167 .46354 L .7489 .45998 L p F P
0 g
s
.839 .755 .771 r
.3162 .60487 m .31081 .6114 L .30734 .60722 L p F P
0 g
s
.839 .755 .771 r
.30734 .60722 m .31175 .60184 L .3162 .60487 L p F P
0 g
s
.84 .754 .768 r
.3162 .60487 m .31175 .60184 L .31768 .59452 L p F P
0 g
s
.651 .758 .928 r
.56883 .46362 m .58076 .45976 L .58382 .46332 L p F P
0 g
s
.651 .758 .928 r
.58076 .45976 m .56883 .46362 L .56576 .46006 L p F P
0 g
s
.515 .479 .755 r
.47955 .61313 m .48197 .61133 L p .48468 .62034 L F P
0 g
s
.513 .488 .767 r
.47955 .61313 m .47876 .61098 L .48197 .61133 L closepath p F P
0 g
s
.487 .178 .367 r
.4547 .73411 m .4558 .72937 L .46782 .72628 L p F P
0 g
s
.53 .22 .386 r
.4558 .72937 m .4547 .73411 L .44217 .73668 L p F P
0 g
s
.532 .273 .468 r
.4683 .72099 m .46782 .72628 L .4558 .72937 L p F P
0 g
s
.761 .401 .372 r
.34596 .736 m .33765 .73431 L .33525 .72936 L p F P
0 g
s
.76 .401 .375 r
.33349 .729 m .33525 .72936 L .33765 .73431 L p F P
0 g
s
.503 .46 .742 r
.49692 .63148 m .4863 .62967 L .49447 .62394 L closepath p F P
0 g
s
.516 .471 .746 r
.49372 .62178 m .49447 .62394 L .4863 .62967 L p F P
0 g
s
.516 .471 .746 r
.48468 .62034 m .49372 .62178 L p .4863 .62967 L F P
0 g
s
.492 .24 .46 r
.46782 .72628 m .4683 .72099 L .47976 .71732 L p F P
0 g
s
.522 .306 .527 r
.47976 .71159 m .47976 .71732 L .4683 .72099 L p F P
0 g
s
.506 .437 .714 r
.4925 .6543 m .49152 .6508 L .49657 .6518 L closepath p F P
0 g
s
.513 .487 .765 r
.48197 .61133 m .47876 .61098 L .47628 .6042 L p F P
0 g
s
.651 .758 .928 r
.76668 .46323 m .77897 .45936 L .78169 .46292 L p F P
0 g
s
.651 .758 .928 r
.77897 .45936 m .76668 .46323 L .76393 .45967 L p F P
0 g
s
.67 .215 .163 r
.36582 .74248 m .36014 .74165 L .35489 .7375 L p F P
0 g
s
.591 .073 0 r
.35104 .737 m .35489 .7375 L .36014 .74165 L p F P
0 g
s
.651 .758 .928 r
.58382 .46332 m .59578 .45946 L .5988 .46302 L p F P
0 g
s
.651 .758 .928 r
.59578 .45946 m .58382 .46332 L .58076 .45976 L p F P
0 g
s
.52 .421 .682 r
.49471 .66298 m .49295 .66268 L .49447 .66191 L closepath p F P
0 g
s
.533 .439 .694 r
.4925 .6543 m .49447 .66191 L .49295 .66268 L p F P
0 g
s
.853 .722 .718 r
.29532 .64319 m .30019 .64603 L .29605 .65283 L p F P
0 g
s
.852 .725 .723 r
.30019 .64603 m .29532 .64319 L .29965 .63634 L p F P
0 g
s
.497 .421 .7 r
.49447 .66191 m .4925 .6543 L .49657 .6518 L p F P
0 g
s
.848 .737 .74 r
.30444 .62936 m .3022 .63254 L .29874 .62784 L p F P
0 g
s
.848 .737 .74 r
.29874 .62784 m .29971 .62645 L .30444 .62936 L p F P
0 g
s
.844 .74 .749 r
.30444 .62936 m .29971 .62645 L .30495 .61933 L p F P
0 g
s
.76 .401 .375 r
.33765 .73431 m .33141 .73307 L .33349 .729 L p F P
0 g
s
.796 .444 .391 r
.3277 .72745 m .33349 .729 L .33141 .73307 L p F P
0 g
s
.651 .758 .928 r
.78169 .46292 m .79401 .45905 L .7967 .46261 L p F P
0 g
s
.651 .758 .928 r
.79401 .45905 m .78169 .46292 L .77897 .45936 L p F P
0 g
s
.842 .6 .573 r
.31261 .7121 m .30668 .7099 L .30766 .704 L p F P
0 g
s
.849 .608 .573 r
.30162 .7016 m .30766 .704 L .30668 .7099 L p F P
0 g
s
.846 .626 .604 r
.30766 .704 m .30162 .7016 L .30318 .69554 L p F P
0 g
s
.651 .758 .928 r
.5988 .46302 m .61079 .45916 L .61379 .46272 L p F P
0 g
s
.651 .758 .928 r
.61079 .45916 m .5988 .46302 L .59578 .45946 L p F P
0 g
s
.815 .55 .538 r
.3198 .71999 m .31265 .71794 L .31298 .71222 L p F P
0 g
s
.823 .557 .537 r
.31261 .7121 m .31298 .71222 L .31265 .71794 L p F P
0 g
s
.513 .487 .765 r
.47628 .6042 m .4783 .6026 L p .48197 .61133 L F P
0 g
s
.511 .496 .776 r
.47628 .6042 m .47556 .60232 L .4783 .6026 L closepath p F P
0 g
s
.853 .635 .605 r
.29738 .69305 m .30318 .69554 L .30162 .7016 L p F P
0 g
s
.85 .648 .629 r
.30318 .69554 m .29738 .69305 L .29945 .68685 L p F P
0 g
s
.853 .698 .69 r
.2968 .66325 m .2973 .66229 L .29589 .66156 L closepath p F P
0 g
s
.844 .709 .714 r
.2934 .65742 m .29605 .65283 L p .2973 .66229 L F P
0 g
s
.844 .709 .714 r
.2973 .66229 m .29589 .66156 L .2934 .65742 L p F P
0 g
s
.823 .557 .537 r
.31265 .71794 m .31242 .71786 L .31261 .7121 L p F P
0 g
s
.845 .576 .532 r
.30668 .7099 m .31261 .7121 L .31242 .71786 L p F P
0 g
s
.651 .758 .928 r
.7967 .46261 m .80906 .45873 L .81172 .46229 L p F P
0 g
s
.651 .758 .928 r
.80906 .45873 m .7967 .46261 L .79401 .45905 L p F P
0 g
s
.591 .073 0 r
.34881 .73936 m .35104 .737 L p .36014 .74165 L F P
0 g
s
.727 .306 .249 r
.34881 .73936 m .34596 .736 L .35104 .737 L closepath p F P
0 g
s
.505 .367 .628 r
.48963 .69492 m .48931 .69279 L .49197 .69382 L closepath p F P
0 g
s
.845 .757 .765 r
.31016 .61223 m .31081 .6114 L .30734 .60722 L p F P
0 g
s
.651 .758 .928 r
.61379 .46272 m .62581 .45886 L .62879 .46242 L p F P
0 g
s
.651 .758 .928 r
.62581 .45886 m .61379 .46272 L .61079 .45916 L p F P
0 g
s
.511 .494 .774 r
.4783 .6026 m .47556 .60232 L .47276 .595 L p F P
0 g
s
.651 .757 .928 r
.43087 .46275 m .44256 .45889 L .44584 .46245 L p F P
0 g
s
.852 .754 .754 r
.30582 .60917 m .31016 .61223 L .30495 .61933 L p F P
0 g
s
.845 .757 .765 r
.30734 .60722 m .30582 .60917 L .31016 .61223 L p F P
0 g
s
.859 .7 .684 r
.29403 .66883 m .2968 .66325 L .29589 .66156 L p F P
0 g
s
.853 .738 .735 r
.29965 .63634 m .3022 .63254 L .29874 .62784 L p F P
0 g
s
.651 .758 .928 r
.81172 .46229 m .8241 .45841 L .82675 .46197 L p F P
0 g
s
.651 .758 .928 r
.8241 .45841 m .81172 .46229 L .80906 .45873 L p F P
0 g
s
.858 .658 .632 r
.2939 .68427 m .29945 .68685 L .29738 .69305 L p F P
0 g
s
.854 .668 .65 r
.29945 .68685 m .2939 .68427 L .29642 .67794 L p F P
0 g
s
.651 .758 .928 r
.62879 .46242 m .64084 .45855 L .64379 .46212 L p F P
0 g
s
.651 .758 .928 r
.64084 .45855 m .62879 .46242 L .62581 .45886 L p F P
0 g
s
.497 .421 .7 r
.50332 .65364 m .50398 .65608 L .49447 .66191 L p F P
0 g
s
.497 .421 .7 r
.49657 .6518 m .50332 .65364 L p .49447 .66191 L F P
0 g
s
.494 .403 .682 r
.49447 .66191 m .50398 .65608 L p .50266 .66544 L F P
0 g
s
.494 .403 .682 r
.50266 .66544 m .49471 .66298 L .49447 .66191 L p F P
0 g
s
.524 .163 .296 r
.44216 .7367 m .44211 .73669 L .44217 .73668 L closepath p F P
0 g
s
.42 0 .073 r
.44211 .73669 m .44216 .7367 L .43991 .74037 L p F P
0 g
s
.481 .122 .279 r
.44216 .7367 m .44217 .73668 L .4547 .73411 L p F P
0 g
s
.651 .757 .928 r
.44584 .46245 m .45756 .45859 L .46082 .46215 L p F P
0 g
s
.651 .757 .928 r
.45756 .45859 m .44584 .46245 L .44256 .45889 L p F P
0 g
s
.502 .469 .753 r
.49372 .62178 m .48468 .62034 L .4915 .6153 L closepath p F P
0 g
s
.515 .479 .755 r
.49052 .61261 m .4915 .6153 L .48468 .62034 L p F P
0 g
s
.515 .479 .755 r
.48197 .61133 m .49052 .61261 L p .48468 .62034 L F P
0 g
s
.481 .122 .279 r
.4547 .73411 m .45384 .73613 L .44216 .7367 L p F P
0 g
s
.426 .004 .133 r
.43991 .74037 m .44216 .7367 L .45384 .73613 L p F P
0 g
s
.81 .506 .474 r
.3277 .72745 m .32051 .72542 L .3198 .71999 L p F P
0 g
s
.813 .507 .472 r
.31265 .71794 m .3198 .71999 L .32051 .72542 L p F P
0 g
s
.493 .404 .684 r
.49617 .66926 m .49471 .66298 L .50266 .66544 L closepath p F P
0 g
s
.485 .277 .521 r
.47976 .71732 m .47976 .71159 L .49068 .70734 L p F P
0 g
s
.508 .325 .568 r
.4903 .70127 m .49068 .70734 L .47976 .71159 L p F P
0 g
s
.651 .758 .928 r
.82675 .46197 m .83916 .45809 L .84177 .46165 L p F P
0 g
s
.651 .758 .928 r
.83916 .45809 m .82675 .46197 L .8241 .45841 L p F P
0 g
s
.489 .334 .597 r
.49197 .69382 m .48963 .69492 L .4903 .70127 L p F P
0 g
s
.651 .758 .928 r
.64379 .46212 m .65587 .45825 L .65879 .46182 L p F P
0 g
s
.651 .758 .928 r
.65587 .45825 m .64379 .46212 L .64084 .45855 L p F P
0 g
s
.651 .758 .928 r
.46082 .46215 m .47256 .45829 L .4758 .46186 L p F P
0 g
s
.651 .757 .928 r
.47256 .45829 m .46082 .46215 L .45756 .45859 L p F P
0 g
s
.579 .084 .043 r
.38121 .74371 m .37024 .74281 L .36724 .7414 L p F P
0 g
s
.581 .091 .056 r
.37024 .74281 m .36582 .74248 L .36724 .7414 L closepath p F P
0 g
s
.859 .7 .684 r
.29589 .66156 m .29223 .65953 L p .29403 .66883 L F P
0 g
s
.857 .711 .701 r
.29589 .66156 m .2934 .65742 L .29223 .65953 L closepath p F P
0 g
s
.511 .494 .774 r
.47276 .595 m .47379 .59414 L p .4783 .6026 L F P
0 g
s
.651 .758 .928 r
.84177 .46165 m .85421 .45777 L .8568 .46133 L p F P
0 g
s
.651 .758 .928 r
.85421 .45777 m .84177 .46165 L .83916 .45809 L p F P
0 g
s
.651 .758 .928 r
.65879 .46182 m .6709 .45795 L .6738 .46151 L p F P
0 g
s
.651 .758 .928 r
.6709 .45795 m .65879 .46182 L .65587 .45825 L p F P
0 g
s
.651 .758 .928 r
.4758 .46186 m .48757 .45799 L .49078 .46156 L p F P
0 g
s
.651 .758 .928 r
.48757 .45799 m .4758 .46186 L .47256 .45829 L p F P
0 g
s
.862 .679 .653 r
.29113 .67527 m .29642 .67794 L .2939 .68427 L p F P
0 g
s
.859 .687 .668 r
.29642 .67794 m .29113 .67527 L .29403 .66883 L p F P
0 g
s
.86 .737 .727 r
.29508 .63339 m .29965 .63634 L .29532 .64319 L p F P
0 g
s
.853 .738 .735 r
.29874 .62784 m .29508 .63339 L .29965 .63634 L p F P
0 g
s
.651 .758 .928 r
.8568 .46133 m .86927 .45744 L .87184 .461 L p F P
0 g
s
.651 .758 .928 r
.86927 .45744 m .8568 .46133 L .85421 .45777 L p F P
0 g
s
.501 .478 .763 r
.49052 .61261 m .48197 .61133 L .48827 .60639 L closepath p F P
0 g
s
.513 .487 .765 r
.48731 .60389 m .48827 .60639 L .48197 .61133 L p F P
0 g
s
.513 .487 .765 r
.4783 .6026 m .48731 .60389 L p .48197 .61133 L F P
0 g
s
.71 .246 .148 r
.34596 .736 m .34881 .73936 L .34771 .73992 L p F P
0 g
s
.71 .246 .148 r
.33765 .73431 m .34596 .736 L p .34771 .73992 L F P
0 g
s
.858 .717 .705 r
.29605 .65283 m .2934 .65742 L .28996 .65206 L p F P
0 g
s
.858 .717 .705 r
.28996 .65206 m .29113 .65001 L .29605 .65283 L p F P
0 g
s
.853 .722 .718 r
.29605 .65283 m .29113 .65001 L .29532 .64319 L p F P
0 g
s
.651 .758 .928 r
.6738 .46151 m .68594 .45764 L .68881 .46121 L p F P
0 g
s
.651 .758 .928 r
.68594 .45764 m .6738 .46151 L .6709 .45795 L p F P
0 g
s
.651 .758 .928 r
.49078 .46156 m .50258 .45769 L .50577 .46126 L p F P
0 g
s
.651 .758 .928 r
.50258 .45769 m .49078 .46156 L .48757 .45799 L p F P
0 g
s
.848 .769 .775 r
.31362 .59135 m .31768 .59452 L .31175 .60184 L p F P
0 g
s
.485 .388 .67 r
.4977 .67644 m .49617 .66926 L .50266 .66544 L p F P
0 g
s
.52 .406 .664 r
.49617 .66926 m .4977 .67644 L .49635 .6771 L p F P
0 g
s
.796 .444 .391 r
.33141 .73307 m .32954 .73256 L .3277 .72745 L p F P
0 g
s
.803 .439 .368 r
.32051 .72542 m .3277 .72745 L .32954 .73256 L p F P
0 g
s
.423 0 0 r
.39709 .74471 m .39806 .74405 L .40949 .74368 L p F P
0 g
s
.481 0 0 r
.39709 .74471 m .39428 .744 L .39806 .74405 L closepath p F P
0 g
s
.851 .753 .755 r
.30059 .61629 m .30495 .61933 L .29971 .62645 L p F P
0 g
s
.852 .754 .754 r
.30495 .61933 m .30059 .61629 L .30582 .60917 L p F P
0 g
s
.49 0 0 r
.39428 .744 m .39709 .74471 L p .38213 .74408 L F P
0 g
s
.49 0 0 r
.38213 .74408 m .38254 .7438 L .39428 .744 L p F P
0 g
s
.651 .758 .928 r
.68881 .46121 m .70098 .45734 L .70383 .4609 L p F P
0 g
s
.651 .758 .928 r
.70098 .45734 m .68881 .46121 L .68594 .45764 L p F P
0 g
s
.651 .758 .928 r
.50577 .46126 m .5176 .45739 L .52076 .46096 L p F P
0 g
s
.651 .758 .928 r
.5176 .45739 m .50577 .46126 L .50258 .45769 L p F P
0 g
s
.499 .486 .774 r
.48731 .60389 m .4783 .6026 L .48477 .59719 L closepath p F P
0 g
s
.511 .494 .774 r
.48411 .59555 m .48477 .59719 L .4783 .6026 L p F P
0 g
s
.511 .494 .774 r
.47379 .59414 m .48411 .59555 L p .4783 .6026 L F P
0 g
s
.497 .495 .785 r
.48411 .59555 m .47379 .59414 L .48095 .58766 L closepath p F P
0 g
s
.553 .047 .007 r
.38213 .74408 m .38121 .74371 L .38254 .7438 L closepath p F P
0 g
s
.651 .758 .928 r
.70383 .4609 m .71602 .45703 L .71885 .4606 L p F P
0 g
s
.651 .758 .928 r
.71602 .45703 m .70383 .4609 L .70098 .45734 L p F P
0 g
s
.489 .334 .597 r
.4903 .70127 m .49775 .69782 L .49197 .69382 L p F P
0 g
s
.485 .335 .601 r
.49994 .69 m .49197 .69382 L .49775 .69782 L p F P
0 g
s
.505 .367 .627 r
.49894 .68333 m .49994 .69 L .49197 .69382 L p F P
0 g
s
.361 0 0 r
.38121 .74371 m .38213 .74408 L .37862 .74466 L p F P
0 g
s
.361 0 0 r
.37024 .74281 m .38121 .74371 L p .37876 .74461 L F P
0 g
s
.361 0 0 r
.37807 .74454 m .37533 .74393 L p .37876 .74461 L F P
0 g
s
.361 0 0 r
.37533 .74393 m .37024 .74281 L p .37568 .74396 L F P
0 g
s
.361 0 0 r
.37533 .74393 m .37568 .74396 L .37876 .74461 L F
.145 .666 .885 r
.37024 .74281 m .37862 .74466 L .37607 .74382 L p F P
0 g
s
.145 .666 .885 r
.36367 .74316 m .36582 .74248 L p .37607 .74382 L F P
0 g
s
.53 0 0 r
.36367 .74316 m .36014 .74165 L .36582 .74248 L closepath p F P
0 g
s
.321 0 0 r
.36014 .74165 m .36367 .74316 L .36014 .74267 L p F P
0 g
s
.047 .61 .791 r
.37345 .7435 m .36515 .74321 L p .36014 .74267 L F P
0 g
s
.047 .61 .791 r
.36515 .74321 m .36367 .74316 L .36289 .74305 L p F P
0 g
s
.047 .61 .791 r
.36289 .74305 m .36014 .74267 L p .36515 .74321 L F P
0 g
s
.145 .666 .885 r
.37607 .74382 m .37345 .7435 L .36515 .74321 L p F P
0 g
s
.145 .666 .885 r
.36515 .74321 m .36367 .74316 L p .36571 .74327 L F P
0 g
s
.145 .666 .885 r
.37607 .74382 m .36515 .74321 L .36571 .74327 L F
.361 0 0 r
.37862 .74466 m .37807 .74454 L p .37876 .74461 L F P
0 g
s
.651 .758 .928 r
.52076 .46096 m .53262 .45709 L .53575 .46066 L p F P
0 g
s
.651 .758 .928 r
.53262 .45709 m .52076 .46096 L .5176 .45739 L p F P
0 g
s
.445 0 0 r
.41208 .74409 m .40949 .74368 L .41276 .74353 L closepath p F P
0 g
s
.423 0 0 r
.40949 .74368 m .41208 .74409 L p .39709 .74471 L F P
0 g
s
.866 .698 .671 r
.28901 .66606 m .29403 .66883 L .29113 .67527 L p F P
0 g
s
.859 .7 .684 r
.29223 .65953 m .28901 .66606 L .29403 .66883 L p F P
0 g
s
.506 .384 .648 r
.4979 .67759 m .49635 .6771 L .4977 .67644 L closepath p F P
0 g
s
.391 0 0 r
.41208 .74409 m .41276 .74353 L .4267 .7423 L p F P
0 g
s
.521 .097 .177 r
.4271 .74191 m .4267 .7423 L .41276 .74353 L p F P
0 g
s
.651 .758 .928 r
.71885 .4606 m .73107 .45672 L .73387 .46029 L p F P
0 g
s
.651 .758 .928 r
.73107 .45672 m .71885 .4606 L .71602 .45703 L p F P
0 g
s
.651 .758 .928 r
.53575 .46066 m .54764 .45679 L .55075 .46036 L p F P
0 g
s
.651 .758 .928 r
.54764 .45679 m .53575 .46066 L .53262 .45709 L p F P
0 g
s
.492 .421 .704 r
.50332 .65364 m .49657 .6518 L .50193 .64839 L closepath p F P
0 g
s
.506 .436 .712 r
.50012 .64202 m .50193 .64839 L .49657 .6518 L p F P
0 g
s
.506 .436 .712 r
.49813 .64152 m .50012 .64202 L p .49657 .6518 L F P
0 g
s
.847 .769 .776 r
.31175 .60184 m .30734 .60722 L .30384 .60335 L p F P
0 g
s
.847 .769 .776 r
.30384 .60335 m .30766 .59869 L .31175 .60184 L p F P
0 g
s
.848 .769 .775 r
.31175 .60184 m .30766 .59869 L .31362 .59135 L p F P
0 g
s
.651 .758 .928 r
.73387 .46029 m .74613 .45641 L .7489 .45998 L p F P
0 g
s
.651 .758 .928 r
.74613 .45641 m .73387 .46029 L .73107 .45672 L p F P
0 g
s
.862 .72 .703 r
.29223 .65953 m .2934 .65742 L .28996 .65206 L p F P
0 g
s
.651 .758 .928 r
.55075 .46036 m .56267 .45649 L .56576 .46006 L p F P
0 g
s
.651 .758 .928 r
.56267 .45649 m .55075 .46036 L .54764 .45679 L p F P
0 g
s
.849 .608 .573 r
.30668 .7099 m .30063 .70751 L .30162 .7016 L p F P
0 g
s
.857 .616 .574 r
.29579 .69912 m .30162 .7016 L .30063 .70751 L p F P
0 g
s
.853 .635 .605 r
.30162 .7016 m .29579 .69912 L .29738 .69305 L p F P
0 g
s
.845 .576 .532 r
.31242 .71786 m .30639 .71561 L .30668 .7099 L p F P
0 g
s
.852 .582 .529 r
.30063 .70751 m .30668 .7099 L .30639 .71561 L p F P
0 g
s
.49 0 0 r
.39709 .74471 m .39417 .745 L p .38213 .74408 L F P
0 g
s
.49 0 0 r
.39417 .745 m .39368 .74505 L p .39241 .74495 L F P
0 g
s
.49 0 0 r
.38213 .74408 m .39417 .745 L .39241 .74495 L F
.39348 .74505 m .38213 .74408 L p .39368 .74505 L F P
0 g
s
.49 0 0 r
.39368 .74505 m .39363 .74506 L .39348 .74505 L p F P
0 g
s
.358 .779 .976 r
.38213 .74408 m .39363 .74506 L .39204 .74441 L p F P
0 g
s
.358 .779 .976 r
.37862 .74466 m .38213 .74408 L p .39204 .74441 L F P
0 g
s
.327 .774 .96 r
.38562 .74407 m .37607 .74382 L .37807 .74448 L p F P
0 g
s
.327 .774 .96 r
.37807 .74448 m .37862 .74466 L .38003 .74454 L p F P
0 g
s
.327 .774 .96 r
.38003 .74454 m .38562 .74407 L p .37807 .74448 L F P
0 g
s
.358 .779 .976 r
.39204 .74441 m .38562 .74407 L .38003 .74454 L p F P
0 g
s
.358 .779 .976 r
.38003 .74454 m .37862 .74466 L p .38167 .7446 L F P
0 g
s
.358 .779 .976 r
.39204 .74441 m .38003 .74454 L .38167 .7446 L F
.855 .739 .734 r
.29073 .64025 m .29532 .64319 L .29113 .65001 L p F P
0 g
s
.86 .737 .727 r
.29532 .64319 m .29073 .64025 L .29508 .63339 L p F P
0 g
s
.42 0 .073 r
.43991 .74037 m .42974 .74191 L .4271 .74191 L p F P
0 g
s
.377 0 0 r
.42974 .74191 m .4267 .7423 L .4271 .74191 L closepath p F P
0 g
s
.478 .364 .646 r
.4977 .67644 m .50734 .67076 L p .50381 .68057 L F P
0 g
s
.478 .364 .646 r
.50381 .68057 m .4979 .67759 L .4977 .67644 L p F P
0 g
s
.485 .388 .67 r
.50653 .66705 m .50734 .67076 L .4977 .67644 L p F P
0 g
s
.485 .388 .67 r
.50266 .66544 m .50653 .66705 L p .4977 .67644 L F P
0 g
s
.651 .758 .928 r
.7489 .45998 m .76118 .4561 L .76393 .45967 L p F P
0 g
s
.651 .758 .928 r
.76118 .4561 m .7489 .45998 L .74613 .45641 L p F P
0 g
s
.861 .644 .608 r
.2918 .69049 m .29738 .69305 L .29579 .69912 L p F P
0 g
s
.858 .658 .632 r
.29738 .69305 m .2918 .69049 L .2939 .68427 L p F P
0 g
s
.651 .758 .928 r
.56576 .46006 m .5777 .45619 L .58076 .45976 L p F P
0 g
s
.651 .758 .928 r
.5777 .45619 m .56576 .46006 L .56267 .45649 L p F P
0 g
s
.439 .134 .349 r
.46673 .731 m .46782 .72628 L .4793 .72261 L p F P
0 g
s
.492 .24 .46 r
.47976 .71732 m .4793 .72261 L .46782 .72628 L p F P
0 g
s
.487 .178 .367 r
.46782 .72628 m .46673 .731 L .4547 .73411 L p F P
0 g
s
.857 .75 .744 r
.29971 .62645 m .29874 .62784 L .29526 .62349 L p F P
0 g
s
.857 .75 .744 r
.29526 .62349 m .2953 .62343 L .29971 .62645 L p F P
0 g
s
.851 .753 .755 r
.29971 .62645 m .2953 .62343 L .30059 .61629 L p F P
0 g
s
.813 .507 .472 r
.32051 .72542 m .31338 .72336 L .31265 .71794 L p F P
0 g
s
.819 .511 .469 r
.31242 .71786 m .31265 .71794 L .31338 .72336 L p F P
0 g
s
.471 .298 .563 r
.49775 .69782 m .4903 .70127 L .49068 .70734 L p F P
0 g
s
.819 .511 .469 r
.31338 .72336 m .31116 .72269 L .31242 .71786 L p F P
0 g
s
.845 .539 .472 r
.30639 .71561 m .31242 .71786 L .31116 .72269 L p F P
0 g
s
.145 .666 .885 r
.36582 .74248 m .37024 .74281 L p .37607 .74382 L F P
0 g
s
.477 .365 .647 r
.49894 .68333 m .4979 .67759 L .50381 .68057 L closepath p F P
0 g
s
.871 .715 .687 r
.28747 .65666 m .29223 .65953 L .28901 .66606 L p F P
0 g
s
.862 .72 .703 r
.28996 .65206 m .28747 .65666 L .29223 .65953 L p F P
0 g
s
.651 .758 .928 r
.76393 .45967 m .77624 .45579 L .77897 .45936 L p F P
0 g
s
.651 .758 .928 r
.77624 .45579 m .76393 .45967 L .76118 .4561 L p F P
0 g
s
.651 .758 .928 r
.58076 .45976 m .59274 .45589 L .59578 .45946 L p F P
0 g
s
.651 .758 .928 r
.59274 .45589 m .58076 .45976 L .5777 .45619 L p F P
0 g
s
.862 .75 .737 r
.29508 .63339 m .29874 .62784 L .29526 .62349 L p F P
0 g
s
.71 .246 .148 r
.34771 .73992 m .34217 .73867 L .33765 .73431 L p F P
0 g
s
.667 .162 .036 r
.33141 .73307 m .33765 .73431 L .34217 .73867 L p F P
0 g
s
.854 .77 .768 r
.30582 .60917 m .30734 .60722 L .30384 .60335 L p F P
0 g
s
.865 .669 .635 r
.28859 .68161 m .2939 .68427 L .2918 .69049 L p F P
0 g
s
.862 .679 .653 r
.2939 .68427 m .28859 .68161 L .29113 .67527 L p F P
0 g
s
.423 0 0 r
.41208 .74409 m .40865 .74473 L .39709 .74471 L p F P
0 g
s
.417 .812 .985 r
.39709 .74471 m .40865 .74473 L .40704 .74411 L p F P
0 g
s
.417 .812 .985 r
.39363 .74506 m .39709 .74471 L p .40704 .74411 L F P
0 g
s
.651 .758 .928 r
.79131 .45547 m .77897 .45936 L .77624 .45579 L p F P
0 g
s
.651 .758 .928 r
.77897 .45936 m .79131 .45547 L .79401 .45905 L p F P
0 g
s
.416 .043 .22 r
.45384 .73613 m .4547 .73411 L .46673 .731 L p F P
0 g
s
.651 .758 .928 r
.59578 .45946 m .60778 .45558 L .61079 .45916 L p F P
0 g
s
.651 .758 .928 r
.60778 .45558 m .59578 .45946 L .59274 .45589 L p F P
0 g
s
.391 0 0 r
.4267 .7423 m .4237 .74364 L .41208 .74409 L p F P
0 g
s
.377 .816 .956 r
.41208 .74409 m .4237 .74364 L .42126 .74309 L p F P
0 g
s
.377 .816 .956 r
.40865 .74473 m .41208 .74409 L p .42126 .74309 L F P
0 g
s
.86 .768 .759 r
.3018 .60601 m .30582 .60917 L .30059 .61629 L p F P
0 g
s
.854 .77 .768 r
.30384 .60335 m .3018 .60601 L .30582 .60917 L p F P
0 g
s
.153 0 0 r
.4237 .74364 m .4267 .7423 L .42974 .74191 L p F P
0 g
s
.45 .205 .451 r
.4793 .72261 m .47976 .71732 L .49069 .71307 L p F P
0 g
s
.485 .277 .521 r
.49068 .70734 m .49069 .71307 L .47976 .71732 L p F P
0 g
s
.651 .758 .928 r
.79401 .45905 m .80638 .45516 L .80906 .45873 L p F P
0 g
s
.651 .758 .928 r
.80638 .45516 m .79401 .45905 L .79131 .45547 L p F P
0 g
s
.651 .758 .928 r
.61079 .45916 m .62283 .45528 L .62581 .45886 L p F P
0 g
s
.651 .758 .928 r
.62283 .45528 m .61079 .45916 L .60778 .45558 L p F P
0 g
s
.803 .439 .368 r
.32954 .73256 m .3225 .73049 L .32051 .72542 L p F P
0 g
s
.802 .43 .352 r
.31338 .72336 m .32051 .72542 L .3225 .73049 L p F P
0 g
s
.651 .758 .928 r
.80906 .45873 m .82145 .45484 L .8241 .45841 L p F P
0 g
s
.651 .758 .928 r
.82145 .45484 m .80906 .45873 L .80638 .45516 L p F P
0 g
s
.651 .758 .928 r
.62581 .45886 m .63788 .45498 L .64084 .45855 L p F P
0 g
s
.651 .758 .928 r
.63788 .45498 m .62581 .45886 L .62283 .45528 L p F P
0 g
s
.3 0 0 r
.43876 .74132 m .42974 .74191 L .43991 .74037 L closepath p F P
0 g
s
.153 0 0 r
.42974 .74191 m .43876 .74132 L p .4237 .74364 L F P
0 g
s
.651 .757 .928 r
.44256 .45889 m .45429 .45501 L .45756 .45859 L p F P
0 g
s
.87 .69 .657 r
.28609 .67251 m .29113 .67527 L .28859 .68161 L p F P
0 g
s
.866 .698 .671 r
.29113 .67527 m .28609 .67251 L .28901 .66606 L p F P
0 g
s
.651 .758 .928 r
.8241 .45841 m .83653 .45451 L .83916 .45809 L p F P
0 g
s
.651 .758 .928 r
.83653 .45451 m .8241 .45841 L .82145 .45484 L p F P
0 g
s
.651 .758 .928 r
.64084 .45855 m .65293 .45467 L .65587 .45825 L p F P
0 g
s
.651 .758 .928 r
.65293 .45467 m .64084 .45855 L .63788 .45498 L p F P
0 g
s
.321 0 0 r
.35063 .74032 m .36014 .74165 L p .36014 .7421 L F P
0 g
s
.321 0 0 r
.36014 .74264 m .35558 .74153 L .36014 .7421 L F
.35558 .74153 m .35063 .74032 L .36014 .7421 L F
.35976 .74257 m .35063 .74032 L p .36014 .74264 L F P
0 g
s
.321 0 0 r
.36014 .74267 m .35976 .74257 L p .36014 .74264 L F P
0 g
s
.201 .675 .936 r
.35063 .74032 m .36014 .74267 L .35866 .74194 L p F P
0 g
s
.201 .675 .936 r
.34771 .73992 m .35063 .74032 L p .35593 .74139 L F P
0 g
s
.201 .675 .936 r
.35866 .74194 m .35506 .74128 L .35593 .74139 L F
.35506 .74128 m .34771 .73992 L .35593 .74139 L F
.3452 .74032 m .34771 .73992 L p .35866 .74194 L F P
0 g
s
.569 .008 0 r
.3452 .74032 m .34217 .73867 L .34771 .73992 L closepath p F P
0 g
s
.389 0 0 r
.34217 .73867 m .3452 .74032 L .34164 .73956 L p F P
0 g
s
.056 .61 .821 r
.34185 .73958 m .34696 .74043 L .34164 .73956 L F
.35414 .74089 m .34999 .74063 L p .34185 .73958 L F P
0 g
s
.056 .61 .821 r
.34999 .74063 m .34696 .74043 L p .34185 .73958 L F P
0 g
s
.056 .61 .821 r
.34696 .74043 m .3452 .74032 L .34394 .74005 L p F P
0 g
s
.056 .61 .821 r
.34394 .74005 m .34164 .73956 L p .34696 .74043 L F P
0 g
s
.201 .675 .936 r
.35866 .74194 m .35414 .74089 L .34696 .74043 L p F P
0 g
s
.201 .675 .936 r
.34696 .74043 m .3452 .74032 L p .34909 .74079 L F P
0 g
s
.201 .675 .936 r
.35866 .74194 m .34696 .74043 L .34909 .74079 L F
.591 .073 0 r
.36014 .74165 m .35063 .74032 L .34881 .73936 L p F P
0 g
s
.651 .757 .928 r
.45756 .45859 m .46931 .45471 L .47256 .45829 L p F P
0 g
s
.651 .757 .928 r
.46931 .45471 m .45756 .45859 L .45429 .45501 L p F P
0 g
s
.867 .75 .731 r
.29079 .63034 m .29508 .63339 L .29073 .64025 L p F P
0 g
s
.862 .75 .737 r
.29526 .62349 m .29079 .63034 L .29508 .63339 L p F P
0 g
s
.464 .339 .625 r
.50381 .68057 m .49894 .68333 L .49994 .69 L p F P
0 g
s
.866 .729 .709 r
.28996 .65206 m .29113 .65001 L .28653 .64711 L closepath p F P
0 g
s
.855 .739 .734 r
.2865 .64707 m .29073 .64025 L p .29113 .65001 L F P
0 g
s
.855 .739 .734 r
.29113 .65001 m .28653 .64711 L .2865 .64707 L p F P
0 g
s
.592 .077 0 r
.35063 .74032 m .34771 .73992 L .34881 .73936 L closepath p F P
0 g
s
.651 .758 .928 r
.83916 .45809 m .85161 .45419 L .85421 .45777 L p F P
0 g
s
.651 .758 .928 r
.85161 .45419 m .83916 .45809 L .83653 .45451 L p F P
0 g
s
.492 .43 .715 r
.50012 .64202 m .49813 .64152 L .49969 .64048 L closepath p F P
0 g
s
.506 .445 .722 r
.4972 .63234 m .49969 .64048 L .49813 .64152 L p F P
0 g
s
.651 .758 .928 r
.65587 .45825 m .66799 .45437 L .6709 .45795 L p F P
0 g
s
.651 .758 .928 r
.66799 .45437 m .65587 .45825 L .65293 .45467 L p F P
0 g
s
.667 .162 .036 r
.33045 .73399 m .33141 .73307 L p .34217 .73867 L F P
0 g
s
.772 .363 .276 r
.33045 .73399 m .32954 .73256 L .33141 .73307 L closepath p F P
0 g
s
.651 .758 .928 r
.47256 .45829 m .48435 .45441 L .48757 .45799 L p F P
0 g
s
.651 .757 .928 r
.48435 .45441 m .47256 .45829 L .46931 .45471 L p F P
0 g
s
.651 .758 .928 r
.85421 .45777 m .8667 .45386 L .86927 .45744 L p F P
0 g
s
.651 .758 .928 r
.8667 .45386 m .85421 .45777 L .85161 .45419 L p F P
0 g
s
.856 .784 .781 r
.30992 .58805 m .31362 .59135 L .30766 .59869 L p F P
0 g
s
.85 .77 .773 r
.29655 .61314 m .30059 .61629 L .2953 .62343 L p F P
0 g
s
.86 .768 .759 r
.30059 .61629 m .29655 .61314 L .3018 .60601 L p F P
0 g
s
.651 .758 .928 r
.6709 .45795 m .68305 .45406 L .68594 .45764 L p F P
0 g
s
.651 .758 .928 r
.68305 .45406 m .6709 .45795 L .66799 .45437 L p F P
0 g
s
.651 .758 .928 r
.48757 .45799 m .49938 .45411 L .50258 .45769 L p F P
0 g
s
.651 .758 .928 r
.49938 .45411 m .48757 .45799 L .48435 .45441 L p F P
0 g
s
.871 .729 .702 r
.28747 .65666 m .28996 .65206 L .28653 .64711 L p F P
0 g
s
.874 .71 .674 r
.28424 .6632 m .28901 .66606 L .28609 .67251 L p F P
0 g
s
.871 .715 .687 r
.28901 .66606 m .28424 .6632 L .28747 .65666 L p F P
0 g
s
.651 .758 .928 r
.68594 .45764 m .69812 .45375 L .70098 .45734 L p F P
0 g
s
.651 .758 .928 r
.69812 .45375 m .68594 .45764 L .68305 .45406 L p F P
0 g
s
.759 .306 .173 r
.32954 .73256 m .33045 .73399 L .32741 .73546 L p F P
0 g
s
.759 .306 .173 r
.3225 .73049 m .32954 .73256 L p .32741 .73546 L F P
0 g
s
.651 .758 .928 r
.50258 .45769 m .51442 .45381 L .5176 .45739 L p F P
0 g
s
.651 .758 .928 r
.51442 .45381 m .50258 .45769 L .49938 .45411 L p F P
0 g
s
.852 .582 .529 r
.30639 .71561 m .30034 .71322 L .30063 .70751 L p F P
0 g
s
.86 .589 .528 r
.29478 .70504 m .30063 .70751 L .30034 .71322 L p F P
0 g
s
.857 .616 .574 r
.30063 .70751 m .29478 .70504 L .29579 .69912 L p F P
0 g
s
.864 .625 .575 r
.29017 .69657 m .29579 .69912 L .29478 .70504 L p F P
0 g
s
.861 .644 .608 r
.29579 .69912 m .29017 .69657 L .2918 .69049 L p F P
0 g
s
.445 .246 .514 r
.49069 .71307 m .49068 .70734 L .50104 .70256 L p F P
0 g
s
.471 .298 .563 r
.49068 .70734 m .50104 .70256 L .49775 .69782 L p F P
0 g
s
.651 .758 .928 r
.70098 .45734 m .71319 .45345 L .71602 .45703 L p F P
0 g
s
.651 .758 .928 r
.71319 .45345 m .70098 .45734 L .69812 .45375 L p F P
0 g
s
.465 .426 .73 r
.49794 .63174 m .4972 .63234 L .49969 .64048 L p F P
0 g
s
.477 .446 .745 r
.4972 .63234 m .49692 .63148 L .49794 .63174 L closepath p F P
0 g
s
.651 .758 .928 r
.5176 .45739 m .52947 .45351 L .53262 .45709 L p F P
0 g
s
.651 .758 .928 r
.52947 .45351 m .5176 .45739 L .51442 .45381 L p F P
0 g
s
.478 .445 .742 r
.49794 .63174 m .49692 .63148 L .49447 .62394 L p F P
0 g
s
.845 .539 .472 r
.31116 .72269 m .30692 .7211 L .30639 .71561 L p F P
0 g
s
.853 .544 .464 r
.30034 .71322 m .30639 .71561 L .30692 .7211 L p F P
0 g
s
.478 .445 .742 r
.49447 .62394 m .49625 .6224 L p .49794 .63174 L F P
0 g
s
.475 .454 .755 r
.49447 .62394 m .49372 .62178 L .49625 .6224 L closepath p F P
0 g
s
.476 .453 .753 r
.49625 .6224 m .49372 .62178 L .4915 .6153 L p F P
0 g
s
.868 .654 .611 r
.28644 .68784 m .2918 .69049 L .29017 .69657 L p F P
0 g
s
.865 .669 .635 r
.2918 .69049 m .28644 .68784 L .28859 .68161 L p F P
0 g
s
.465 .413 .715 r
.49969 .64048 m .50688 .63466 L p .50702 .64448 L F P
0 g
s
.465 .413 .715 r
.50702 .64448 m .50012 .64202 L .49969 .64048 L p F P
0 g
s
.465 .426 .73 r
.49969 .64048 m .50688 .63466 L .49794 .63174 L p F P
0 g
s
.478 .384 .671 r
.50653 .66705 m .50266 .66544 L .50578 .66354 L closepath p F P
0 g
s
.494 .403 .682 r
.50398 .65608 m .50578 .66354 L .50266 .66544 L p F P
0 g
s
.651 .758 .928 r
.71602 .45703 m .72826 .45314 L .73107 .45672 L p F P
0 g
s
.651 .758 .928 r
.72826 .45314 m .71602 .45703 L .71319 .45345 L p F P
0 g
s
.416 .043 .22 r
.46673 .731 m .46559 .73359 L .45384 .73613 L p F P
0 g
s
.306 0 .005 r
.45255 .73786 m .45384 .73613 L .46559 .73359 L p F P
0 g
s
.426 .004 .133 r
.45384 .73613 m .45255 .73786 L .43991 .74037 L p F P
0 g
s
.235 0 0 r
.43876 .74132 m .43991 .74037 L .45255 .73786 L p F P
0 g
s
.464 .414 .717 r
.50193 .64839 m .50012 .64202 L .50702 .64448 L closepath p F P
0 g
s
.651 .758 .928 r
.53262 .45709 m .54452 .45321 L .54764 .45679 L p F P
0 g
s
.651 .758 .928 r
.54452 .45321 m .53262 .45709 L .52947 .45351 L p F P
0 g
s
.855 .784 .782 r
.30766 .59869 m .30384 .60335 L .30032 .59984 L p F P
0 g
s
.855 .784 .782 r
.30032 .59984 m .30394 .59541 L .30766 .59869 L p F P
0 g
s
.856 .784 .781 r
.30766 .59869 m .30394 .59541 L .30992 .58805 L p F P
0 g
s
.476 .453 .753 r
.4915 .6153 m .49362 .61334 L p .49625 .6224 L F P
0 g
s
.473 .463 .766 r
.4915 .6153 m .49052 .61261 L .49362 .61334 L closepath p F P
0 g
s
.87 .748 .726 r
.29073 .64025 m .2865 .64707 L .28299 .64278 L p F P
0 g
s
.87 .748 .726 r
.28299 .64278 m .28642 .63721 L .29073 .64025 L p F P
0 g
s
.867 .75 .731 r
.29073 .64025 m .28642 .63721 L .29079 .63034 L p F P
0 g
s
.651 .758 .928 r
.73107 .45672 m .74334 .45283 L .74613 .45641 L p F P
0 g
s
.651 .758 .928 r
.74334 .45283 m .73107 .45672 L .72826 .45314 L p F P
0 g
s
.651 .758 .928 r
.54764 .45679 m .55957 .4529 L .56267 .45649 L p F P
0 g
s
.651 .758 .928 r
.55957 .4529 m .54764 .45679 L .54452 .45321 L p F P
0 g
s
.474 .462 .764 r
.49362 .61334 m .49052 .61261 L .48827 .60639 L p F P
0 g
s
.865 .764 .749 r
.29526 .62349 m .2953 .62343 L .295 .6232 L closepath p F P
0 g
s
.85 .77 .773 r
.29174 .61965 m .29655 .61314 L p .2953 .62343 L F P
0 g
s
.85 .77 .773 r
.2953 .62343 m .295 .6232 L .29174 .61965 L p F P
0 g
s
.872 .763 .739 r
.29079 .63034 m .29526 .62349 L .295 .6232 L p F P
0 g
s
.461 .43 .737 r
.50558 .6252 m .49794 .63174 L .50688 .63466 L p F P
0 g
s
.478 .445 .742 r
.50556 .62516 m .50558 .6252 L .49794 .63174 L p F P
0 g
s
.478 .445 .742 r
.49625 .6224 m .50556 .62516 L p .49794 .63174 L F P
0 g
s
.466 .404 .704 r
.50193 .64839 m .50702 .64448 L p .50595 .65464 L F P
0 g
s
.466 .404 .704 r
.50595 .65464 m .50332 .65364 L .50193 .64839 L p F P
0 g
s
.802 .43 .352 r
.3225 .73049 m .3155 .72839 L .31338 .72336 L p F P
0 g
s
.802 .431 .354 r
.31116 .72269 m .31338 .72336 L .3155 .72839 L p F P
0 g
s
.448 .308 .598 r
.50068 .69642 m .49994 .69 L .50957 .68456 L p F P
0 g
s
.485 .335 .601 r
.49775 .69782 m .50068 .69642 L .49994 .69 L p F P
0 g
s
.464 .339 .625 r
.49994 .69 m .50957 .68456 L .50381 .68057 L p F P
0 g
s
.871 .729 .702 r
.28649 .64709 m .28297 .65371 L .28747 .65666 L p F P
0 g
s
.871 .729 .702 r
.28653 .64711 m .28649 .64709 L p .28747 .65666 L F P
0 g
s
.879 .727 .69 r
.28297 .65371 m .28747 .65666 L .28424 .6632 L p F P
0 g
s
.873 .68 .638 r
.28351 .67886 m .28859 .68161 L .28644 .68784 L p F P
0 g
s
.87 .69 .657 r
.28859 .68161 m .28351 .67886 L .28609 .67251 L p F P
0 g
s
.651 .758 .928 r
.74613 .45641 m .75842 .45252 L .76118 .4561 L p F P
0 g
s
.651 .758 .928 r
.75842 .45252 m .74613 .45641 L .74334 .45283 L p F P
0 g
s
.872 .763 .739 r
.295 .6232 m .2913 .62027 L p .29079 .63034 L F P
0 g
s
.865 .769 .754 r
.295 .6232 m .29174 .61965 L .2913 .62027 L closepath p F P
0 g
s
.651 .758 .928 r
.56267 .45649 m .57463 .4526 L .5777 .45619 L p F P
0 g
s
.651 .758 .928 r
.57463 .4526 m .56267 .45649 L .55957 .4529 L p F P
0 g
s
.667 .162 .036 r
.34217 .73867 m .33422 .73687 L .33045 .73399 L p F P
0 g
s
.667 .172 .063 r
.33422 .73687 m .32741 .73546 L .33045 .73399 L closepath p F P
0 g
s
.862 .784 .772 r
.3018 .60601 m .30384 .60335 L .30032 .59984 L p F P
0 g
s
.474 .462 .764 r
.48827 .60639 m .49015 .60453 L p .49362 .61334 L F P
0 g
s
.471 .471 .776 r
.48827 .60639 m .48731 .60389 L .49015 .60453 L closepath p F P
0 g
s
.651 .758 .928 r
.76118 .4561 m .77351 .4522 L .77624 .45579 L p F P
0 g
s
.651 .758 .928 r
.77351 .4522 m .76118 .4561 L .75842 .45252 L p F P
0 g
s
.465 .405 .706 r
.50398 .65608 m .50332 .65364 L .50595 .65464 L closepath p F P
0 g
s
.651 .758 .928 r
.5777 .45619 m .58969 .4523 L .59274 .45589 L p F P
0 g
s
.651 .758 .928 r
.58969 .4523 m .5777 .45619 L .57463 .4526 L p F P
0 g
s
.471 .47 .775 r
.49015 .60453 m .48731 .60389 L .48477 .59719 L p F P
0 g
s
.465 .296 .566 r
.50068 .69642 m .49775 .69782 L .50104 .70256 L p F P
0 g
s
.452 .382 .687 r
.50595 .65464 m .50398 .65608 L .50578 .66354 L p F P
0 g
s
.651 .758 .928 r
.77624 .45579 m .7886 .45189 L .79131 .45547 L p F P
0 g
s
.651 .758 .928 r
.7886 .45189 m .77624 .45579 L .77351 .4522 L p F P
0 g
s
.868 .782 .764 r
.29809 .60273 m .3018 .60601 L .29655 .61314 L p F P
0 g
s
.862 .784 .772 r
.30032 .59984 m .29809 .60273 L .3018 .60601 L p F P
0 g
s
.802 .431 .354 r
.3155 .72839 m .30851 .7263 L .31116 .72269 L p F P
0 g
s
.838 .481 .378 r
.30692 .7211 m .31116 .72269 L .30851 .7263 L p F P
0 g
s
.352 0 .179 r
.46559 .73359 m .46673 .731 L .47824 .72735 L p F P
0 g
s
.439 .134 .349 r
.4793 .72261 m .47824 .72735 L .46673 .731 L p F P
0 g
s
.651 .758 .928 r
.59274 .45589 m .60476 .45199 L .60778 .45558 L p F P
0 g
s
.651 .758 .928 r
.60476 .45199 m .59274 .45589 L .58969 .4523 L p F P
0 g
s
.39 .092 .335 r
.47824 .72735 m .4793 .72261 L .49026 .71838 L p F P
0 g
s
.45 .205 .451 r
.49069 .71307 m .49026 .71838 L .4793 .72261 L p F P
0 g
s
.878 .702 .66 r
.2813 .66966 m .28609 .67251 L .28351 .67886 L p F P
0 g
s
.874 .71 .674 r
.28609 .67251 m .2813 .66966 L .28424 .6632 L p F P
0 g
s
.651 .758 .928 r
.80369 .45157 m .79131 .45547 L .7886 .45189 L p F P
0 g
s
.651 .758 .928 r
.79131 .45547 m .80369 .45157 L .80638 .45516 L p F P
0 g
s
.461 .443 .752 r
.50556 .62516 m .49625 .6224 L .50264 .61657 L closepath p F P
0 g
s
.476 .453 .753 r
.50235 .61578 m .50264 .61657 L .49625 .6224 L p F P
0 g
s
.476 .453 .753 r
.49362 .61334 m .50235 .61578 L p .49625 .6224 L F P
0 g
s
.651 .758 .928 r
.60778 .45558 m .61983 .45169 L .62283 .45528 L p F P
0 g
s
.651 .758 .928 r
.61983 .45169 m .60778 .45558 L .60476 .45199 L p F P
0 g
s
.459 .34 .63 r
.50865 .67773 m .50381 .68057 L .50957 .68456 L p F P
0 g
s
.478 .364 .646 r
.50734 .67076 m .50865 .67773 L .50381 .68057 L p F P
0 g
s
.471 .47 .775 r
.48477 .59719 m .48592 .59594 L p .49015 .60453 L F P
0 g
s
.467 .479 .787 r
.48477 .59719 m .48411 .59555 L .48592 .59594 L closepath p F P
0 g
s
.651 .758 .928 r
.80638 .45516 m .81879 .45125 L .82145 .45484 L p F P
0 g
s
.651 .758 .928 r
.81879 .45125 m .80638 .45516 L .80369 .45157 L p F P
0 g
s
.759 .306 .173 r
.32741 .73546 m .32618 .73508 L .3225 .73049 L p F P
0 g
s
.744 .261 .092 r
.3155 .72839 m .3225 .73049 L .32618 .73508 L p F P
0 g
s
.867 .739 .719 r
.28653 .64711 m .2865 .64707 L .28649 .64709 L closepath p F P
0 g
s
.651 .758 .928 r
.62283 .45528 m .6349 .45139 L .63788 .45498 L p F P
0 g
s
.651 .758 .928 r
.6349 .45139 m .62283 .45528 L .61983 .45169 L p F P
0 g
s
.874 .75 .723 r
.28649 .64709 m .2865 .64707 L .28299 .64278 L p F P
0 g
s
.883 .744 .703 r
.28225 .64403 m .28649 .64709 L .28297 .65371 L p F P
0 g
s
.874 .75 .723 r
.28299 .64278 m .28225 .64403 L .28649 .64709 L p F P
0 g
s
.875 .763 .736 r
.28678 .62719 m .29079 .63034 L .28642 .63721 L p F P
0 g
s
.872 .763 .739 r
.2913 .62027 m .28678 .62719 L .29079 .63034 L p F P
0 g
s
.468 .478 .786 r
.48592 .59594 m .48411 .59555 L .48095 .58766 L p F P
0 g
s
.389 0 0 r
.33422 .73687 m .34217 .73867 L p .34169 .73948 L F P
0 g
s
.389 0 0 r
.34069 .73921 m .33422 .73687 L p .34169 .73948 L F P
0 g
s
.389 0 0 r
.34164 .73956 m .34069 .73921 L p .34169 .73948 L F P
0 g
s
.002 .538 .842 r
.33422 .73687 m .34164 .73956 L .33942 .73845 L p F P
0 g
s
.002 .538 .842 r
.33942 .73845 m .33118 .7364 L .33422 .73687 L F
.32741 .73546 m .33301 .73662 L p .33118 .7364 L F P
0 g
s
.002 .538 .842 r
.33301 .73662 m .33422 .73687 L p .33118 .7364 L F P
0 g
s
.186 0 0 r
.32676 .73555 m .32315 .73506 L p .32868 .7361 L F P
0 g
s
.002 .538 .842 r
.32676 .73555 m .32741 .73546 L p .33942 .73845 L F P
0 g
s
.002 .538 .842 r
.33942 .73845 m .33693 .73764 L .32869 .73595 L p F P
0 g
s
.002 .538 .842 r
.33942 .73845 m .32869 .73595 L .32974 .73623 L F
.186 0 0 r
.33693 .73764 m .33047 .73631 L p .32868 .7361 L F P
0 g
s
.002 .538 .842 r
.32869 .73595 m .32676 .73555 L p .32974 .73623 L F P
0 g
s
.186 0 0 r
.33047 .73631 m .32676 .73555 L p .32868 .7361 L F P
0 g
s
.651 .758 .928 r
.82145 .45484 m .83389 .45093 L .83653 .45451 L p F P
0 g
s
.651 .758 .928 r
.83389 .45093 m .82145 .45484 L .81879 .45125 L p F P
0 g
s
.45 .366 .669 r
.50578 .66354 m .51318 .65815 L p .50993 .66895 L F P
0 g
s
.45 .366 .669 r
.50993 .66895 m .50653 .66705 L .50578 .66354 L p F P
0 g
s
.452 .382 .687 r
.50578 .66354 m .51318 .65815 L .50595 .65464 L p F P
0 g
s
.651 .758 .928 r
.63788 .45498 m .64998 .45108 L .65293 .45467 L p F P
0 g
s
.651 .758 .928 r
.64998 .45108 m .63788 .45498 L .6349 .45139 L p F P
0 g
s
.651 .757 .928 r
.45429 .45501 m .46606 .45112 L .46931 .45471 L p F P
0 g
s
.459 .452 .763 r
.50235 .61578 m .49362 .61334 L .49942 .60765 L closepath p F P
0 g
s
.474 .462 .764 r
.49914 .60692 m .49942 .60765 L .49362 .61334 L p F P
0 g
s
.474 .462 .764 r
.49015 .60453 m .49914 .60692 L p .49362 .61334 L F P
0 g
s
.235 0 0 r
.45255 .73786 m .45049 .73922 L .43876 .74132 L p F P
0 g
s
.416 .849 .942 r
.43876 .74132 m .45049 .73922 L .44756 .73898 L p F P
0 g
s
.416 .849 .942 r
.4354 .74167 m .43876 .74132 L p .44756 .73898 L F P
0 g
s
.153 0 0 r
.43876 .74132 m .4354 .74167 L .4237 .74364 L p F P
0 g
s
.86 .589 .528 r
.30034 .71322 m .29447 .71076 L .29478 .70504 L p F P
0 g
s
.867 .597 .527 r
.28912 .7025 m .29478 .70504 L .29447 .71076 L p F P
0 g
s
.864 .625 .575 r
.29478 .70504 m .28912 .7025 L .29017 .69657 L p F P
0 g
s
.651 .758 .928 r
.83653 .45451 m .849 .4506 L .85161 .45419 L p F P
0 g
s
.651 .758 .928 r
.849 .4506 m .83653 .45451 L .83389 .45093 L p F P
0 g
s
.651 .758 .928 r
.65293 .45467 m .66507 .45078 L .66799 .45437 L p F P
0 g
s
.651 .758 .928 r
.66507 .45078 m .65293 .45467 L .64998 .45108 L p F P
0 g
s
.651 .757 .928 r
.46931 .45471 m .48111 .45082 L .48435 .45441 L p F P
0 g
s
.651 .757 .928 r
.48111 .45082 m .46931 .45471 L .46606 .45112 L p F P
0 g
s
.872 .635 .577 r
.28476 .69395 m .29017 .69657 L .28912 .7025 L p F P
0 g
s
.868 .654 .611 r
.29017 .69657 m .28476 .69395 L .28644 .68784 L p F P
0 g
s
.883 .722 .678 r
.27972 .66025 m .28424 .6632 L .2813 .66966 L p F P
0 g
s
.879 .727 .69 r
.28424 .6632 m .27972 .66025 L .28297 .65371 L p F P
0 g
s
.853 .544 .464 r
.30692 .7211 m .30091 .71869 L .30034 .71322 L p F P
0 g
s
.86 .548 .457 r
.29447 .71076 m .30034 .71322 L .30091 .71869 L p F P
0 g
s
.868 .782 .764 r
.29655 .61314 m .29174 .61965 L .28819 .61616 L p F P
0 g
s
.868 .782 .764 r
.28819 .61616 m .29283 .60987 L .29655 .61314 L p F P
0 g
s
.868 .782 .764 r
.29655 .61314 m .29283 .60987 L .29809 .60273 L p F P
0 g
s
.651 .758 .928 r
.85161 .45419 m .86411 .45027 L .8667 .45386 L p F P
0 g
s
.651 .758 .928 r
.86411 .45027 m .85161 .45419 L .849 .4506 L p F P
0 g
s
.424 .265 .56 r
.5011 .70253 m .50068 .69642 L .51046 .69089 L p F P
0 g
s
.448 .308 .598 r
.50976 .68479 m .51046 .69089 L .50068 .69642 L p F P
0 g
s
.448 .308 .598 r
.50957 .68456 m .50976 .68479 L p .50068 .69642 L F P
0 g
s
.465 .296 .566 r
.50104 .70256 m .5011 .70253 L .50068 .69642 L p F P
0 g
s
.407 .172 .443 r
.50114 .70828 m .49069 .71307 L .49026 .71838 L p F P
0 g
s
.445 .246 .514 r
.50111 .70422 m .50114 .70828 L .49069 .71307 L p F P
0 g
s
.445 .246 .514 r
.50104 .70256 m .50111 .70422 L p .49069 .71307 L F P
0 g
s
.449 .366 .671 r
.50734 .67076 m .50653 .66705 L .50993 .66895 L closepath p F P
0 g
s
.447 .384 .694 r
.51277 .64943 m .50595 .65464 L .51318 .65815 L p F P
0 g
s
.466 .404 .704 r
.51199 .64662 m .51277 .64943 L .50595 .65464 L p F P
0 g
s
.466 .404 .704 r
.50702 .64448 m .51199 .64662 L p .50595 .65464 L F P
0 g
s
.651 .758 .928 r
.66799 .45437 m .68015 .45047 L .68305 .45406 L p F P
0 g
s
.651 .758 .928 r
.68015 .45047 m .66799 .45437 L .66507 .45078 L p F P
0 g
s
.651 .758 .928 r
.48435 .45441 m .49618 .45052 L .49938 .45411 L p F P
0 g
s
.651 .758 .928 r
.49618 .45052 m .48435 .45441 L .48111 .45082 L p F P
0 g
s
.448 .449 .767 r
.49015 .60453 m .49914 .60692 L .49593 .59849 L p F P
0 g
s
.448 .449 .767 r
.49593 .59849 m .49584 .59846 L .49015 .60453 L p F P
0 g
s
.471 .47 .775 r
.48592 .59594 m .49584 .59846 L .49015 .60453 L p F P
0 g
s
.877 .668 .616 r
.28132 .68512 m .28644 .68784 L .28476 .69395 L p F P
0 g
s
.873 .68 .638 r
.28644 .68784 m .28132 .68512 L .28351 .67886 L p F P
0 g
s
.077 0 0 r
.45049 .73922 m .45255 .73786 L .46463 .73479 L p F P
0 g
s
.306 0 .005 r
.46559 .73359 m .46463 .73479 L .45255 .73786 L p F P
0 g
s
.417 .812 .985 r
.40704 .74411 m .39891 .74432 L .39363 .74506 L p F P
0 g
s
.429 .812 .99 r
.39891 .74432 m .39204 .74441 L .39363 .74506 L closepath p F P
0 g
s
.468 .478 .786 r
.48095 .58766 m .48105 .58755 L p .48592 .59594 L F P
0 g
s
.651 .758 .928 r
.68305 .45406 m .69524 .45016 L .69812 .45375 L p F P
0 g
s
.651 .758 .928 r
.69524 .45016 m .68305 .45406 L .68015 .45047 L p F P
0 g
s
.838 .481 .378 r
.30851 .7263 m .30848 .72629 L .30692 .7211 L p F P
0 g
s
.847 .479 .355 r
.30091 .71869 m .30692 .7211 L .30848 .72629 L p F P
0 g
s
.651 .758 .928 r
.49938 .45411 m .51124 .45021 L .51442 .45381 L p F P
0 g
s
.651 .758 .928 r
.51124 .45021 m .49938 .45411 L .49618 .45052 L p F P
0 g
s
.458 .476 .79 r
.49089 .59006 m .48592 .59594 L .49584 .59846 L p F P
0 g
s
.468 .478 .786 r
.48105 .58755 m .49089 .59006 L .48592 .59594 L p F P
0 g
s
.372 .817 .948 r
.42126 .74309 m .4237 .74364 L .4354 .74167 L p F P
0 g
s
.456 .488 .804 r
.48526 .58188 m .48105 .58755 L .49089 .59006 L p F P
0 g
s
.377 .816 .956 r
.42126 .74309 m .41538 .74365 L .40865 .74473 L p F P
0 g
s
.439 .823 .988 r
.41538 .74365 m .40704 .74411 L .40865 .74473 L closepath p F P
0 g
s
.651 .758 .928 r
.69812 .45375 m .71034 .44985 L .71319 .45345 L p F P
0 g
s
.651 .758 .928 r
.71034 .44985 m .69812 .45375 L .69524 .45016 L p F P
0 g
s
.651 .758 .928 r
.51442 .45381 m .52631 .44991 L .52947 .45351 L p F P
0 g
s
.651 .758 .928 r
.52631 .44991 m .51442 .45381 L .51124 .45021 L p F P
0 g
s
.433 .338 .648 r
.50993 .66895 m .50734 .67076 L .50865 .67773 L p F P
0 g
s
.879 .762 .729 r
.28642 .63721 m .28299 .64278 L .27944 .63888 L p F P
0 g
s
.879 .762 .729 r
.27944 .63888 m .28239 .63407 L .28642 .63721 L p F P
0 g
s
.875 .763 .736 r
.28642 .63721 m .28239 .63407 L .28678 .62719 L p F P
0 g
s
.651 .758 .928 r
.71319 .45345 m .72544 .44954 L .72826 .45314 L p F P
0 g
s
.651 .758 .928 r
.72544 .44954 m .71319 .45345 L .71034 .44985 L p F P
0 g
s
.88 .695 .647 r
.27868 .67603 m .28351 .67886 L .28132 .68512 L p F P
0 g
s
.878 .702 .66 r
.28351 .67886 m .27868 .67603 L .2813 .66966 L p F P
0 g
s
.651 .758 .928 r
.52947 .45351 m .54139 .44961 L .54452 .45321 L p F P
0 g
s
.651 .758 .928 r
.54139 .44961 m .52947 .45351 L .52631 .44991 L p F P
0 g
s
.872 .782 .758 r
.2913 .62027 m .29174 .61965 L .28819 .61616 L p F P
0 g
s
.887 .74 .693 r
.27872 .65066 m .28297 .65371 L .27972 .66025 L p F P
0 g
s
.883 .744 .703 r
.28297 .65371 m .27872 .65066 L .28225 .64403 L p F P
0 g
s
.881 .779 .744 r
.28759 .61701 m .2913 .62027 L .28678 .62719 L p F P
0 g
s
.872 .782 .758 r
.28819 .61616 m .28759 .61701 L .2913 .62027 L p F P
0 g
s
.651 .758 .928 r
.72826 .45314 m .74054 .44923 L .74334 .45283 L p F P
0 g
s
.651 .758 .928 r
.74054 .44923 m .72826 .45314 L .72544 .44954 L p F P
0 g
s
.651 .758 .928 r
.54452 .45321 m .55647 .44931 L .55957 .4529 L p F P
0 g
s
.651 .758 .928 r
.55647 .44931 m .54452 .45321 L .54139 .44961 L p F P
0 g
s
.651 .758 .928 r
.74334 .45283 m .75565 .44892 L .75842 .45252 L p F P
0 g
s
.651 .758 .928 r
.75565 .44892 m .74334 .45283 L .74054 .44923 L p F P
0 g
s
.744 .261 .092 r
.32618 .73508 m .31957 .73288 L .3155 .72839 L p F P
0 g
s
.718 .211 .024 r
.30851 .7263 m .3155 .72839 L .31957 .73288 L p F P
0 g
s
.651 .758 .928 r
.55957 .4529 m .57155 .449 L .57463 .4526 L p F P
0 g
s
.651 .758 .928 r
.57155 .449 m .55957 .4529 L .55647 .44931 L p F P
0 g
s
.352 0 .179 r
.47824 .72735 m .4774 .72938 L .46559 .73359 L p F P
0 g
s
.192 0 0 r
.46463 .73479 m .46559 .73359 L .4774 .72938 L p F P
0 g
s
.651 .758 .928 r
.75842 .45252 m .77076 .4486 L .77351 .4522 L p F P
0 g
s
.651 .758 .928 r
.77076 .4486 m .75842 .45252 L .75565 .44892 L p F P
0 g
s
.685 .474 .594 r
.40044 .58625 m .40293 .58617 L .40351 .59243 L p F P
0 g
s
.685 .474 .594 r
.40351 .59243 m .39767 .59262 L .40044 .58625 L p F P
0 g
s
.703 .494 .603 r
.38762 .58617 m .40044 .58625 L .39767 .59262 L p F P
0 g
s
.651 .758 .928 r
.57463 .4526 m .58664 .4487 L .58969 .4523 L p F P
0 g
s
.651 .758 .928 r
.58664 .4487 m .57463 .4526 L .57155 .449 L p F P
0 g
s
.886 .715 .663 r
.27675 .66673 m .2813 .66966 L .27868 .67603 L p F P
0 g
s
.883 .722 .678 r
.2813 .66966 m .27675 .66673 L .27972 .66025 L p F P
0 g
s
.703 .494 .603 r
.39767 .59262 m .38832 .59257 L .38762 .58617 L p F P
0 g
s
.74 .521 .597 r
.38681 .58609 m .38762 .58617 L .38832 .59257 L p F P
0 g
s
.614 .421 .597 r
.40351 .59243 m .40293 .58617 L .41576 .58366 L p F P
0 g
s
.74 .521 .597 r
.38832 .59257 m .38481 .59222 L .38681 .58609 L p F P
0 g
s
.771 .541 .586 r
.37727 .58465 m .38681 .58609 L .38481 .59222 L p F P
0 g
s
.449 .399 .71 r
.51199 .64662 m .50702 .64448 L .51061 .64159 L closepath p F P
0 g
s
.465 .413 .715 r
.50878 .63542 m .51061 .64159 L .50702 .64448 L p F P
0 g
s
.465 .413 .715 r
.50688 .63466 m .50878 .63542 L p .50702 .64448 L F P
0 g
s
.651 .758 .928 r
.77351 .4522 m .78588 .44829 L .7886 .45189 L p F P
0 g
s
.651 .758 .928 r
.78588 .44829 m .77351 .4522 L .77076 .4486 L p F P
0 g
s
.651 .758 .928 r
.58969 .4523 m .60173 .44839 L .60476 .45199 L p F P
0 g
s
.651 .758 .928 r
.60173 .44839 m .58969 .4523 L .58664 .4487 L p F P
0 g
s
.418 .312 .626 r
.50972 .68447 m .50865 .67773 L .51546 .673 L p F P
0 g
s
.433 .338 .648 r
.50865 .67773 m .51546 .673 L .50993 .66895 L p F P
0 g
s
.459 .34 .63 r
.50957 .68456 m .50972 .68447 L .50865 .67773 L p F P
0 g
s
.883 .762 .724 r
.28225 .64403 m .28299 .64278 L .27944 .63888 L p F P
0 g
s
.487 .819 .999 r
.3902 .7435 m .39204 .74441 L .39891 .74432 L p F P
0 g
s
.447 .801 .997 r
.3902 .7435 m .38562 .74407 L .39204 .74441 L closepath p F P
0 g
s
.651 .758 .928 r
.7886 .45189 m .801 .44797 L .80369 .45157 L p F P
0 g
s
.651 .758 .928 r
.801 .44797 m .7886 .45189 L .78588 .44829 L p F P
0 g
s
.48 .821 .999 r
.40525 .74326 m .39891 .74432 L .40704 .74411 L closepath p F P
0 g
s
.487 .819 .999 r
.39891 .74432 m .40525 .74326 L p .3902 .7435 L F P
0 g
s
.436 .24 .513 r
.50111 .70422 m .50104 .70256 L .5011 .70253 L closepath p F P
0 g
s
.651 .758 .928 r
.60476 .45199 m .61682 .44809 L .61983 .45169 L p F P
0 g
s
.651 .758 .928 r
.61682 .44809 m .60476 .45199 L .60173 .44839 L p F P
0 g
s
.399 .21 .506 r
.5011 .70253 m .51088 .697 L p .50124 .70822 L F P
0 g
s
.399 .21 .506 r
.50124 .70822 m .50111 .70422 L .5011 .70253 L p F P
0 g
s
.424 .265 .56 r
.51046 .69089 m .51088 .697 L .5011 .70253 L p F P
0 g
s
.867 .597 .527 r
.29447 .71076 m .28879 .70823 L .28912 .7025 L p F P
0 g
s
.875 .606 .528 r
.28366 .69989 m .28912 .7025 L .28879 .70823 L p F P
0 g
s
.872 .635 .577 r
.28912 .7025 m .28366 .69989 L .28476 .69395 L p F P
0 g
s
.892 .757 .706 r
.27826 .64088 m .28225 .64403 L .27872 .65066 L p F P
0 g
s
.883 .762 .724 r
.27944 .63888 m .27826 .64088 L .28225 .64403 L p F P
0 g
s
.86 .548 .457 r
.30091 .71869 m .29507 .71622 L .29447 .71076 L p F P
0 g
s
.868 .552 .452 r
.28879 .70823 m .29447 .71076 L .29507 .71622 L p F P
0 g
s
.651 .758 .928 r
.81612 .44765 m .80369 .45157 L .801 .44797 L p F P
0 g
s
.651 .758 .928 r
.80369 .45157 m .81612 .44765 L .81879 .45125 L p F P
0 g
s
.497 .829 .999 r
.40525 .74326 m .40704 .74411 L .41538 .74365 L p F P
0 g
s
.427 .339 .654 r
.51632 .66431 m .50993 .66895 L .51546 .673 L p F P
0 g
s
.45 .366 .669 r
.51522 .65941 m .51632 .66431 L .50993 .66895 L p F P
0 g
s
.45 .366 .669 r
.51318 .65815 m .51522 .65941 L p .50993 .66895 L F P
0 g
s
.883 .777 .74 r
.28306 .62393 m .28678 .62719 L .28239 .63407 L p F P
0 g
s
.881 .779 .744 r
.28678 .62719 m .28306 .62393 L .28759 .61701 L p F P
0 g
s
.418 .801 .991 r
.38562 .74407 m .3902 .7435 L p .37516 .74343 L F P
0 g
s
.418 .801 .991 r
.37516 .74343 m .37607 .74382 L .38562 .74407 L p F P
0 g
s
.651 .758 .928 r
.61983 .45169 m .63192 .44778 L .6349 .45139 L p F P
0 g
s
.651 .758 .928 r
.63192 .44778 m .61983 .45169 L .61682 .44809 L p F P
0 g
s
.882 .647 .578 r
.28211 .69256 m .28476 .69395 L .28366 .69989 L p F P
0 g
s
.877 .668 .616 r
.28053 .68801 m .28132 .68512 L p .28476 .69395 L F P
0 g
s
.877 .668 .616 r
.28476 .69395 m .28211 .69256 L .28053 .68801 L p F P
0 g
s
.3 0 .169 r
.4774 .72938 m .47824 .72735 L .48925 .72316 L p F P
0 g
s
.39 .092 .335 r
.49026 .71838 m .48925 .72316 L .47824 .72735 L p F P
0 g
s
.651 .758 .928 r
.81879 .45125 m .83125 .44733 L .83389 .45093 L p F P
0 g
s
.651 .758 .928 r
.83125 .44733 m .81879 .45125 L .81612 .44765 L p F P
0 g
s
.327 .754 .973 r
.37516 .74343 m .37345 .7435 L .37607 .74382 L closepath p F P
0 g
s
.67 .14 0 r
.32676 .73555 m .32618 .73508 L .32741 .73546 L closepath p F P
0 g
s
.651 .758 .928 r
.6349 .45139 m .64703 .44748 L .64998 .45108 L p F P
0 g
s
.651 .758 .928 r
.64703 .44748 m .6349 .45139 L .63192 .44778 L p F P
0 g
s
.891 .735 .681 r
.27546 .65721 m .27972 .66025 L .27675 .66673 L p F P
0 g
s
.887 .74 .693 r
.27972 .66025 m .27546 .65721 L .27872 .65066 L p F P
0 g
s
.847 .479 .355 r
.30848 .72629 m .30257 .72386 L .30091 .71869 L p F P
0 g
s
.851 .475 .336 r
.29507 .71622 m .30091 .71869 L .30257 .72386 L p F P
0 g
s
.451 .834 .987 r
.42032 .74275 m .41538 .74365 L .42126 .74309 L closepath p F P
0 g
s
.497 .829 .999 r
.41538 .74365 m .42032 .74275 L p .40525 .74326 L F P
0 g
s
.651 .758 .928 r
.83389 .45093 m .84638 .447 L .849 .4506 L p F P
0 g
s
.651 .758 .928 r
.84638 .447 m .83389 .45093 L .83125 .44733 L p F P
0 g
s
.889 .677 .61 r
.28053 .68801 m .28132 .68512 L .27891 .68373 L closepath p F P
0 g
s
.88 .695 .647 r
.2772 .68029 m .27868 .67603 L p .28132 .68512 L F P
0 g
s
.88 .695 .647 r
.28132 .68512 m .27891 .68373 L .2772 .68029 L p F P
0 g
s
.651 .758 .928 r
.64998 .45108 m .66213 .44717 L .66507 .45078 L p F P
0 g
s
.651 .758 .928 r
.66213 .44717 m .64998 .45108 L .64703 .44748 L p F P
0 g
s
.4 .212 .506 r
.50114 .70828 m .50111 .70422 L .50124 .70822 L closepath p F P
0 g
s
.047 .61 .791 r
.36014 .74267 m .36373 .74222 L .37345 .7435 L p F P
0 g
s
.447 .801 .997 r
.36373 .74222 m .35866 .74194 L .36014 .74267 L closepath p F P
0 g
s
.651 .757 .928 r
.46606 .45112 m .47787 .44721 L .48111 .45082 L p F P
0 g
s
.525 .793 .994 r
.37345 .7435 m .37516 .74343 L .37171 .74094 L p F P
0 g
s
.525 .793 .994 r
.37171 .74094 m .36373 .74222 L .37345 .7435 L p F P
0 g
s
.342 .056 .326 r
.49775 .71497 m .49026 .71838 L .48925 .72316 L p F P
0 g
s
.407 .172 .443 r
.50112 .70859 m .50114 .70828 L p .49026 .71838 L F P
0 g
s
.407 .172 .443 r
.49026 .71838 m .49775 .71497 L .50112 .70859 L p F P
0 g
s
.558 0 0 r
.32618 .73508 m .32676 .73555 L .32315 .73506 L p F P
0 g
s
.558 0 0 r
.32315 .73506 m .31957 .73288 L .32618 .73508 L p F P
0 g
s
.771 .541 .586 r
.38481 .59222 m .37581 .5906 L .37727 .58465 L p F P
0 g
s
.828 .593 .583 r
.37029 .58239 m .37727 .58465 L .37581 .5906 L p F P
0 g
s
.651 .758 .928 r
.849 .4506 m .86152 .44667 L .86411 .45027 L p F P
0 g
s
.651 .758 .928 r
.86152 .44667 m .849 .4506 L .84638 .447 L p F P
0 g
s
.651 .758 .928 r
.66507 .45078 m .67725 .44686 L .68015 .45047 L p F P
0 g
s
.651 .758 .928 r
.67725 .44686 m .66507 .45078 L .66213 .44717 L p F P
0 g
s
.449 .409 .722 r
.50878 .63542 m .50688 .63466 L .50822 .63353 L closepath p F P
0 g
s
.461 .43 .737 r
.50688 .63466 m .50822 .63353 L .50558 .6252 L p F P
0 g
s
.651 .758 .928 r
.48111 .45082 m .49296 .44691 L .49618 .45052 L p F P
0 g
s
.651 .757 .928 r
.49296 .44691 m .48111 .45082 L .47787 .44721 L p F P
0 g
s
0 0 0 r
.46227 .73621 m .46463 .73479 L .47613 .7311 L p F P
0 g
s
.192 0 0 r
.4774 .72938 m .47613 .7311 L .46463 .73479 L p F P
0 g
s
.077 0 0 r
.46463 .73479 m .46227 .73621 L .45049 .73922 L p F P
0 g
s
.473 .844 .989 r
.42032 .74275 m .42126 .74309 L .43473 .74135 L p F P
0 g
s
.372 .817 .948 r
.4354 .74167 m .43473 .74135 L .42126 .74309 L p F P
0 g
s
.437 .299 .595 r
.50976 .68479 m .50957 .68456 L .50972 .68447 L closepath p F P
0 g
s
.686 .477 .599 r
.39767 .59262 m .40351 .59243 L .40415 .59876 L p F P
0 g
s
.686 .477 .599 r
.40415 .59876 m .39466 .59908 L .39767 .59262 L p F P
0 g
s
.703 .498 .608 r
.38832 .59257 m .39767 .59262 L .39466 .59908 L p F P
0 g
s
.651 .758 .928 r
.68015 .45047 m .69236 .44656 L .69524 .45016 L p F P
0 g
s
.651 .758 .928 r
.69236 .44656 m .68015 .45047 L .67725 .44686 L p F P
0 g
s
.718 .211 .024 r
.30849 .72631 m .30851 .7263 L p .31957 .73288 L F P
0 g
s
.818 .408 .271 r
.30849 .72631 m .30848 .72629 L .30851 .7263 L closepath p F P
0 g
s
.651 .758 .928 r
.49618 .45052 m .50805 .44661 L .51124 .45021 L p F P
0 g
s
.651 .758 .928 r
.50805 .44661 m .49618 .45052 L .49296 .44691 L p F P
0 g
s
.809 .366 .189 r
.30848 .72629 m .30849 .72631 L .30475 .7274 L p F P
0 g
s
.809 .366 .189 r
.30475 .7274 m .30257 .72386 L .30848 .72629 L p F P
0 g
s
.718 .211 .024 r
.31957 .73288 m .31296 .73065 L .30849 .72631 L p F P
0 g
s
.717 .223 .065 r
.31296 .73065 m .30849 .72631 L .30475 .7274 L p F P
0 g
s
.703 .498 .608 r
.39466 .59908 m .38909 .59905 L .38832 .59257 L p F P
0 g
s
.742 .525 .6 r
.38481 .59222 m .38832 .59257 L .38909 .59905 L p F P
0 g
s
.403 .274 .59 r
.50972 .68447 m .51882 .67816 L p .51283 .68931 L F P
0 g
s
.403 .274 .59 r
.51283 .68931 m .50976 .68479 L .50972 .68447 L p F P
0 g
s
.418 .312 .626 r
.51847 .67599 m .51882 .67816 L .50972 .68447 L p F P
0 g
s
.418 .312 .626 r
.51546 .673 m .51847 .67599 L p .50972 .68447 L F P
0 g
s
.894 .703 .636 r
.27868 .67603 m .2772 .68029 L .27377 .67407 L p F P
0 g
s
.894 .703 .636 r
.27377 .67407 m .2741 .67311 L .27868 .67603 L p F P
0 g
s
.886 .715 .663 r
.27868 .67603 m .2741 .67311 L .27675 .66673 L p F P
0 g
s
.403 .274 .59 r
.51046 .69089 m .50976 .68479 L .51283 .68931 L closepath p F P
0 g
s
.612 .423 .602 r
.40415 .59876 m .40351 .59243 L .41625 .58982 L p F P
0 g
s
.614 .421 .597 r
.41576 .58366 m .41625 .58982 L .40351 .59243 L p F P
0 g
s
.394 .845 .912 r
.44756 .73898 m .45049 .73922 L .46227 .73621 L p F P
0 g
s
.418 .801 .991 r
.3902 .7435 m .38679 .74066 L .37516 .74343 L p F P
0 g
s
.662 .741 .909 r
.38679 .74066 m .37516 .74343 L .37171 .74094 L p F P
0 g
s
.651 .758 .928 r
.69524 .45016 m .70748 .44625 L .71034 .44985 L p F P
0 g
s
.651 .758 .928 r
.70748 .44625 m .69524 .45016 L .69236 .44656 L p F P
0 g
s
.651 .758 .928 r
.51124 .45021 m .52314 .4463 L .52631 .44991 L p F P
0 g
s
.651 .758 .928 r
.52314 .4463 m .51124 .45021 L .50805 .44661 L p F P
0 g
s
.887 .776 .732 r
.28239 .63407 m .27944 .63888 L .27587 .63538 L p F P
0 g
s
.887 .776 .732 r
.27587 .63538 m .27866 .63082 L .28239 .63407 L p F P
0 g
s
.883 .777 .74 r
.28239 .63407 m .27866 .63082 L .28306 .62393 L p F P
0 g
s
.882 .647 .578 r
.28366 .69989 m .28361 .69986 L .28211 .69256 L p F P
0 g
s
.896 .654 .566 r
.27973 .6912 m .28211 .69256 L .28361 .69986 L p F P
0 g
s
.889 .672 .603 r
.28211 .69256 m .28053 .68801 L .27973 .6912 L closepath p F P
0 g
s
.742 .525 .6 r
.38909 .59905 m .38269 .59839 L .38481 .59222 L p F P
0 g
s
.782 .556 .594 r
.37581 .5906 m .38481 .59222 L .38269 .59839 L p F P
0 g
s
.896 .753 .696 r
.27473 .64751 m .27872 .65066 L .27546 .65721 L p F P
0 g
s
.892 .757 .706 r
.27872 .65066 m .27473 .64751 L .27826 .64088 L p F P
0 g
s
.895 .679 .603 r
.27973 .6912 m .28053 .68801 L .27891 .68373 L p F P
0 g
s
.651 .758 .928 r
.71034 .44985 m .72261 .44593 L .72544 .44954 L p F P
0 g
s
.651 .758 .928 r
.72261 .44593 m .71034 .44985 L .70748 .44625 L p F P
0 g
s
.651 .758 .928 r
.52631 .44991 m .53824 .446 L .54139 .44961 L p F P
0 g
s
.651 .758 .928 r
.53824 .446 m .52631 .44991 L .52314 .4463 L p F P
0 g
s
.494 .326 .582 r
.41625 .58982 m .41576 .58366 L .42636 .57885 L p F P
0 g
s
.487 .819 .999 r
.40525 .74326 m .40187 .74038 L .3902 .7435 L p F P
0 g
s
.667 .733 .899 r
.40187 .74038 m .3902 .7435 L .38679 .74066 L p F P
0 g
s
.651 .758 .928 r
.72544 .44954 m .73774 .44562 L .74054 .44923 L p F P
0 g
s
.651 .758 .928 r
.73774 .44562 m .72544 .44954 L .72261 .44593 L p F P
0 g
s
.895 .679 .603 r
.27891 .68373 m .27654 .68227 L p .27973 .6912 L F P
0 g
s
.892 .697 .632 r
.27891 .68373 m .2772 .68029 L .27654 .68227 L closepath p F P
0 g
s
.417 .402 .735 r
.5056 .62518 m .50558 .6252 L .50822 .63353 L p F P
0 g
s
.434 .428 .753 r
.50558 .6252 m .50556 .62516 L .5056 .62518 L closepath p F P
0 g
s
.435 .427 .751 r
.5056 .62518 m .50556 .62516 L .50264 .61657 L p F P
0 g
s
.651 .758 .928 r
.54139 .44961 m .55335 .4457 L .55647 .44931 L p F P
0 g
s
.651 .758 .928 r
.55335 .4457 m .54139 .44961 L .53824 .446 L p F P
0 g
s
.493 .806 1 r
.36373 .74222 m .37171 .74094 L p .35665 .74083 L F P
0 g
s
.493 .806 1 r
.35665 .74083 m .35866 .74194 L .36373 .74222 L p F P
0 g
s
.417 .402 .735 r
.50822 .63353 m .51293 .62859 L .5056 .62518 L p F P
0 g
s
.417 .415 .749 r
.51074 .61934 m .5056 .62518 L .51293 .62859 L p F P
0 g
s
.435 .427 .751 r
.5031 .61605 m .51074 .61934 L .5056 .62518 L p F P
0 g
s
.435 .427 .751 r
.50264 .61657 m .5031 .61605 L p .5056 .62518 L F P
0 g
s
.42 .391 .721 r
.50822 .63353 m .51293 .62859 L p .51418 .63811 L F P
0 g
s
.42 .391 .721 r
.51418 .63811 m .50878 .63542 L .50822 .63353 L p F P
0 g
s
.497 .829 .999 r
.42032 .74275 m .41696 .74017 L .40525 .74326 L p F P
0 g
s
.661 .739 .908 r
.41696 .74017 m .40525 .74326 L .40187 .74038 L p F P
0 g
s
.418 .392 .722 r
.51061 .64159 m .50878 .63542 L .51418 .63811 L closepath p F P
0 g
s
.416 .849 .942 r
.44756 .73898 m .44106 .74034 L .4354 .74167 L p F P
0 g
s
.543 .847 .998 r
.44106 .74034 m .43473 .74135 L .4354 .74167 L closepath p F P
0 g
s
.651 .758 .928 r
.74054 .44923 m .75287 .44531 L .75565 .44892 L p F P
0 g
s
.651 .758 .928 r
.75287 .44531 m .74054 .44923 L .73774 .44562 L p F P
0 g
s
.473 .844 .989 r
.43473 .74135 m .43205 .73983 L .42032 .74275 L p F P
0 g
s
.646 .766 .936 r
.43205 .73983 m .42032 .74275 L .41696 .74017 L p F P
0 g
s
.3 0 .169 r
.48925 .72316 m .48925 .72318 L .4774 .72938 L p F P
0 g
s
.098 0 0 r
.47613 .7311 m .4774 .72938 L .48925 .72318 L p F P
0 g
s
.431 .437 .765 r
.50264 .61657 m .50235 .61578 L .5031 .61605 L closepath p F P
0 g
s
.651 .758 .928 r
.55647 .44931 m .56846 .44539 L .57155 .449 L p F P
0 g
s
.651 .758 .928 r
.56846 .44539 m .55647 .44931 L .55335 .4457 L p F P
0 g
s
.893 .732 .675 r
.27246 .6637 m .27675 .66673 L .2741 .67311 L p F P
0 g
s
.891 .735 .681 r
.27675 .66673 m .27246 .6637 L .27546 .65721 L p F P
0 g
s
.365 .745 .989 r
.35665 .74083 m .35414 .74089 L .35866 .74194 L closepath p F P
0 g
s
.433 .436 .763 r
.5031 .61605 m .50235 .61578 L .49942 .60765 L p F P
0 g
s
.421 .381 .708 r
.51061 .64159 m .51418 .63811 L p .51442 .64791 L F P
0 g
s
.421 .381 .708 r
.51442 .64791 m .51199 .64662 L .51061 .64159 L p F P
0 g
s
.432 .357 .673 r
.51522 .65941 m .51318 .65815 L .51468 .657 L closepath p F P
0 g
s
.447 .384 .694 r
.51318 .65815 m .51468 .657 L .51277 .64943 L p F P
0 g
s
.651 .758 .928 r
.75565 .44892 m .76801 .44499 L .77076 .4486 L p F P
0 g
s
.651 .758 .928 r
.76801 .44499 m .75565 .44892 L .75287 .44531 L p F P
0 g
s
.36 .14 .439 r
.50112 .70859 m .50124 .70822 L .50114 .70828 L closepath p F P
0 g
s
.651 .758 .928 r
.57155 .449 m .58357 .44509 L .58664 .4487 L p F P
0 g
s
.651 .758 .928 r
.58357 .44509 m .57155 .449 L .56846 .44539 L p F P
0 g
s
.875 .606 .528 r
.28356 .70158 m .28366 .69989 L p .28879 .70823 L F P
0 g
s
.887 .618 .524 r
.28356 .70158 m .28366 .69989 L .28361 .69986 L closepath p F P
0 g
s
.891 .775 .726 r
.27826 .64088 m .27944 .63888 L .27587 .63538 L p F P
0 g
s
.868 .552 .452 r
.29507 .71622 m .28939 .71369 L .28879 .70823 L p F P
0 g
s
.875 .558 .446 r
.28343 .70569 m .28879 .70823 L .28939 .71369 L p F P
0 g
s
.875 .606 .528 r
.28879 .70823 m .28343 .70569 L .28356 .70158 L p F P
0 g
s
.895 .625 .521 r
.28361 .69986 m .27877 .6971 L p .28331 .70563 L F P
0 g
s
.895 .625 .521 r
.28331 .70563 m .28356 .70158 L .28361 .69986 L p F P
0 g
s
.896 .654 .566 r
.28361 .69986 m .27877 .6971 L .27973 .6912 L p F P
0 g
s
.291 .075 .404 r
.50124 .70822 m .51092 .70275 L p .50068 .71356 L F P
0 g
s
.291 .075 .404 r
.50068 .71356 m .50112 .70859 L .50124 .70822 L p F P
0 g
s
.399 .21 .506 r
.51088 .697 m .51092 .70275 L .50124 .70822 L p F P
0 g
s
.42 .381 .71 r
.51277 .64943 m .51199 .64662 L .51442 .64791 L closepath p F P
0 g
s
.389 .153 .431 r
.49775 .71497 m .50068 .71356 L .50112 .70859 L closepath p F P
0 g
s
.651 .758 .928 r
.77076 .4486 m .78315 .44468 L .78588 .44829 L p F P
0 g
s
.651 .758 .928 r
.78315 .44468 m .77076 .4486 L .76801 .44499 L p F P
0 g
s
.898 .705 .633 r
.27654 .68227 m .2772 .68029 L .27377 .67407 L p F P
0 g
s
.416 .428 .764 r
.50769 .61035 m .5031 .61605 L .51074 .61934 L p F P
0 g
s
.433 .436 .763 r
.49982 .60715 m .50769 .61035 L .5031 .61605 L p F P
0 g
s
.433 .436 .763 r
.49942 .60765 m .49982 .60715 L p .5031 .61605 L F P
0 g
s
.651 .758 .928 r
.58664 .4487 m .59868 .44478 L .60173 .44839 L p F P
0 g
s
.651 .758 .928 r
.59868 .44478 m .58664 .4487 L .58357 .44509 L p F P
0 g
s
.428 .446 .776 r
.49942 .60765 m .49914 .60692 L .49982 .60715 L closepath p F P
0 g
s
.403 .355 .69 r
.51442 .64791 m .51277 .64943 L .51468 .657 L p F P
0 g
s
.429 .445 .775 r
.49982 .60715 m .49914 .60692 L .49593 .59849 L p F P
0 g
s
.905 .665 .564 r
.27506 .68832 m .27973 .6912 L .27877 .6971 L p F P
0 g
s
.895 .679 .603 r
.27654 .68227 m .27506 .68832 L .27973 .6912 L p F P
0 g
s
.569 .838 .996 r
.43205 .73983 m .43473 .74135 L .44106 .74034 L p F P
0 g
s
.851 .475 .336 r
.30257 .72386 m .29682 .72136 L .29507 .71622 L p F P
0 g
s
.856 .471 .316 r
.28939 .71369 m .29507 .71622 L .29682 .72136 L p F P
0 g
s
.828 .593 .583 r
.37581 .5906 m .36906 .58828 L .37029 .58239 L p F P
0 g
s
.864 .633 .587 r
.3667 .58065 m .37029 .58239 L .36906 .58828 L p F P
0 g
s
.686 .481 .603 r
.39466 .59908 m .40415 .59876 L .40484 .60516 L p F P
0 g
s
.686 .481 .603 r
.40484 .60516 m .39146 .60561 L .39466 .59908 L p F P
0 g
s
.703 .501 .612 r
.38909 .59905 m .39466 .59908 L .39146 .60561 L p F P
0 g
s
.651 .758 .928 r
.78588 .44829 m .79829 .44436 L .801 .44797 L p F P
0 g
s
.651 .758 .928 r
.79829 .44436 m .78588 .44829 L .78315 .44468 L p F P
0 g
s
.9 .77 .709 r
.27454 .63763 m .27826 .64088 L .27473 .64751 L p F P
0 g
s
.891 .775 .726 r
.27587 .63538 m .27454 .63763 L .27826 .64088 L p F P
0 g
s
.703 .501 .612 r
.39146 .60561 m .38993 .6056 L .38909 .59905 L p F P
0 g
s
.743 .528 .603 r
.38269 .59839 m .38909 .59905 L .38993 .6056 L p F P
0 g
s
.398 0 0 r
.31957 .73288 m .32315 .73506 L .31955 .73364 L p F P
0 g
s
.398 0 0 r
.31296 .73065 m .31957 .73288 L p .31955 .73356 L F P
0 g
s
.398 0 0 r
.31835 .73309 m .31296 .73065 L p .31955 .73356 L F P
0 g
s
.398 0 0 r
.31955 .73364 m .31835 .73309 L p .31955 .73356 L F P
0 g
s
0 .443 .797 r
.31296 .73065 m .31955 .73364 L .3169 .7321 L p F P
0 g
s
0 .443 .797 r
.30626 .72845 m .31296 .73065 L p .3169 .7321 L F P
0 g
s
0 .443 .797 r
.3169 .7321 m .31544 .73145 L .30671 .7286 L p F P
0 g
s
0 .443 .797 r
.30671 .7286 m .30626 .72845 L p .30689 .72867 L F P
0 g
s
0 .443 .797 r
.3169 .7321 m .30671 .7286 L .30689 .72867 L F
.651 .758 .928 r
.60173 .44839 m .61381 .44448 L .61682 .44809 L p F P
0 g
s
.651 .758 .928 r
.61381 .44448 m .60173 .44839 L .59868 .44478 L p F P
0 g
s
.782 .556 .594 r
.38269 .59839 m .37418 .59663 L .37581 .5906 L p F P
0 g
s
.826 .607 .605 r
.36906 .58828 m .37581 .5906 L .37418 .59663 L p F P
0 g
s
.376 .228 .55 r
.51283 .68931 m .51046 .69089 L .51088 .697 L p F P
0 g
s
.651 .758 .928 r
.801 .44797 m .81344 .44404 L .81612 .44765 L p F P
0 g
s
.651 .758 .928 r
.81344 .44404 m .801 .44797 L .79829 .44436 L p F P
0 g
s
.415 .44 .778 r
.50386 .60159 m .49982 .60715 L .50769 .61035 L p F P
0 g
s
.429 .445 .775 r
.49593 .59849 m .50386 .60159 L .49982 .60715 L p F P
0 g
s
.608 .423 .607 r
.40415 .59876 m .41682 .59608 L p .4122 .60358 L F P
0 g
s
.608 .423 .607 r
.4122 .60358 m .40484 .60516 L .40415 .59876 L p F P
0 g
s
.612 .423 .602 r
.41625 .58982 m .41682 .59608 L .40415 .59876 L p F P
0 g
s
.651 .758 .928 r
.61682 .44809 m .62893 .44417 L .63192 .44778 L p F P
0 g
s
.651 .758 .928 r
.62893 .44417 m .61682 .44809 L .61381 .44448 L p F P
0 g
s
.89 .62 .523 r
.28343 .70569 m .28356 .70158 L .28331 .70563 L closepath p F P
0 g
s
.519 .78 .992 r
.35414 .74089 m .35665 .74083 L .35318 .73809 L p F P
0 g
s
.519 .78 .992 r
.35318 .73809 m .34608 .73911 L .35414 .74089 L p F P
0 g
s
.056 .61 .821 r
.34164 .73956 m .34608 .73911 L .35414 .74089 L p F P
0 g
s
.9 .748 .684 r
.27145 .65408 m .27546 .65721 L .27246 .6637 L p F P
0 g
s
.896 .753 .696 r
.27546 .65721 m .27145 .65408 L .27473 .64751 L p F P
0 g
s
.456 .488 .804 r
.48949 .58302 m .48526 .58188 L p .49089 .59006 L F P
0 g
s
.436 .476 .803 r
.48949 .58302 m .48526 .58188 L .48755 .57853 L closepath p F P
0 g
s
.909 .693 .599 r
.2721 .67931 m .27654 .68227 L .27506 .68832 L p F P
0 g
s
.898 .705 .633 r
.27377 .67407 m .2721 .67931 L .27654 .68227 L p F P
0 g
s
.424 .787 .995 r
.34608 .73911 m .33942 .73845 L .34164 .73956 L closepath p F P
0 g
s
.651 .758 .928 r
.81612 .44765 m .8286 .44371 L .83125 .44733 L p F P
0 g
s
.651 .758 .928 r
.8286 .44371 m .81612 .44765 L .81344 .44404 L p F P
0 g
s
.442 .454 .776 r
.49593 .59849 m .49584 .59846 L .49589 .5984 L closepath p F P
0 g
s
.458 .476 .79 r
.49271 .59058 m .49089 .59006 L p .49584 .59846 L F P
0 g
s
.458 .476 .79 r
.49584 .59846 m .49589 .5984 L .49271 .59058 L p F P
0 g
s
.651 .758 .928 r
.63192 .44778 m .64406 .44386 L .64703 .44748 L p F P
0 g
s
.651 .758 .928 r
.64406 .44386 m .63192 .44778 L .62893 .44417 L p F P
0 g
s
.401 .337 .67 r
.51468 .657 m .52036 .65181 L p .51882 .66215 L F P
0 g
s
.401 .337 .67 r
.51882 .66215 m .51522 .65941 L .51468 .657 L p F P
0 g
s
.403 .355 .69 r
.51468 .657 m .52036 .65181 L .51442 .64791 L p F P
0 g
s
.439 .465 .79 r
.49271 .59058 m .49089 .59006 L .49195 .58871 L closepath p F P
0 g
s
.456 .488 .804 r
.49089 .59006 m .49195 .58871 L .48949 .58302 L p F P
0 g
s
.408 .433 .775 r
.50386 .60159 m .49593 .59849 L .49589 .5984 L p F P
0 g
s
.408 .433 .775 r
.49589 .5984 m .49932 .59304 L p .50386 .60159 L F P
0 g
s
.403 .444 .789 r
.49589 .5984 m .49271 .59058 L .49932 .59304 L closepath p F P
0 g
s
.743 .528 .603 r
.38993 .6056 m .38049 .60461 L .38269 .59839 L p F P
0 g
s
.791 .571 .602 r
.37418 .59663 m .38269 .59839 L .38049 .60461 L p F P
0 g
s
.798 .325 .104 r
.30257 .72386 m .30475 .7274 L .3029 .72733 L p F P
0 g
s
.798 .325 .104 r
.29682 .72136 m .30257 .72386 L p .3029 .72733 L F P
0 g
s
.651 .758 .928 r
.83125 .44733 m .84375 .44339 L .84638 .447 L p F P
0 g
s
.651 .758 .928 r
.84375 .44339 m .83125 .44733 L .8286 .44371 L p F P
0 g
s
.504 .338 .59 r
.41682 .59608 m .41625 .58982 L .42696 .58512 L p F P
0 g
s
.494 .326 .582 r
.42636 .57885 m .42696 .58512 L .41625 .58982 L p F P
0 g
s
.651 .758 .928 r
.64703 .44748 m .65919 .44356 L .66213 .44717 L p F P
0 g
s
.651 .758 .928 r
.65919 .44356 m .64703 .44748 L .64406 .44386 L p F P
0 g
s
.467 .862 .971 r
.44716 .73887 m .44106 .74034 L .44756 .73898 L closepath p F P
0 g
s
.569 .838 .996 r
.44106 .74034 m .44716 .73887 L p .43205 .73983 L F P
0 g
s
.4 .337 .671 r
.51632 .66431 m .51522 .65941 L .51882 .66215 L closepath p F P
0 g
s
.651 .758 .928 r
.84638 .447 m .85892 .44306 L .86152 .44667 L p F P
0 g
s
.651 .758 .928 r
.85892 .44306 m .84638 .447 L .84375 .44339 L p F P
0 g
s
.651 .758 .928 r
.66213 .44717 m .67433 .44325 L .67725 .44686 L p F P
0 g
s
.651 .758 .928 r
.67433 .44325 m .66213 .44717 L .65919 .44356 L p F P
0 g
s
.651 .757 .928 r
.47787 .44721 m .48973 .44329 L .49296 .44691 L p F P
0 g
s
.342 .056 .326 r
.48925 .72316 m .4893 .72314 L .49775 .71497 L p F P
0 g
s
.306 .012 .29 r
.50068 .71356 m .49775 .71497 L .4893 .72314 L p F P
0 g
s
.905 .716 .637 r
.27377 .67407 m .2741 .67311 L .27243 .67195 L closepath p F P
0 g
s
.893 .732 .675 r
.27027 .66899 m .27246 .6637 L p .2741 .67311 L F P
0 g
s
.893 .732 .675 r
.2741 .67311 m .27243 .67195 L .27027 .66899 L p F P
0 g
s
.397 .357 .697 r
.52074 .6418 m .51442 .64791 L .52036 .65181 L p F P
0 g
s
.421 .381 .708 r
.52074 .64179 m .52074 .6418 L .51442 .64791 L p F P
0 g
s
.421 .381 .708 r
.51418 .63811 m .52074 .64179 L p .51442 .64791 L F P
0 g
s
.409 .307 .628 r
.51847 .67599 m .51546 .673 L .51771 .67137 L closepath p F P
0 g
s
.427 .339 .654 r
.51546 .673 m .51771 .67137 L .51632 .66431 L p F P
0 g
s
.651 .758 .928 r
.67725 .44686 m .68947 .44294 L .69236 .44656 L p F P
0 g
s
.651 .758 .928 r
.68947 .44294 m .67725 .44686 L .67433 .44325 L p F P
0 g
s
.651 .758 .928 r
.49296 .44691 m .50485 .44299 L .50805 .44661 L p F P
0 g
s
.651 .758 .928 r
.50485 .44299 m .49296 .44691 L .48973 .44329 L p F P
0 g
s
.26 0 .186 r
.48925 .72318 m .4893 .72314 L .48925 .72316 L closepath p F P
0 g
s
.05 0 0 r
.4871 .72684 m .48925 .72318 L .4893 .72314 L p F P
0 g
s
.098 0 0 r
.48925 .72318 m .4871 .72684 L .47613 .7311 L p F P
0 g
s
.05 0 0 r
.4893 .72314 m .49958 .71822 L p .4871 .72684 L F P
0 g
s
.306 .012 .29 r
.4893 .72314 m .49958 .71822 L .50068 .71356 L p F P
0 g
s
.493 .806 1 r
.37171 .74094 m .36829 .73757 L .35665 .74083 L p F P
0 g
s
.677 .728 .888 r
.36829 .73757 m .35665 .74083 L .35318 .73809 L p F P
0 g
s
.909 .716 .629 r
.2721 .67931 m .27377 .67407 L .27243 .67195 L p F P
0 g
s
.864 .633 .587 r
.36906 .58828 m .3682 .58787 L .3667 .58065 L p F P
0 g
s
.838 .616 .602 r
.36438 .57979 m .3667 .58065 L .3682 .58787 L p F P
0 g
s
.651 .758 .928 r
.69236 .44656 m .70462 .44263 L .70748 .44625 L p F P
0 g
s
.651 .758 .928 r
.70462 .44263 m .69236 .44656 L .68947 .44294 L p F P
0 g
s
.381 .308 .648 r
.51882 .66215 m .51632 .66431 L .51771 .67137 L p F P
0 g
s
.403 .444 .788 r
.49932 .59304 m .49271 .59058 L .49195 .58871 L p F P
0 g
s
.651 .758 .928 r
.50805 .44661 m .51997 .44268 L .52314 .4463 L p F P
0 g
s
.651 .758 .928 r
.51997 .44268 m .50805 .44661 L .50485 .44299 L p F P
0 g
s
.905 .767 .698 r
.27099 .64428 m .27473 .64751 L .27145 .65408 L p F P
0 g
s
.9 .77 .709 r
.27473 .64751 m .27099 .64428 L .27454 .63763 L p F P
0 g
s
.687 .499 .627 r
.39146 .60561 m .40484 .60516 L p .40351 .61182 L F P
0 g
s
.687 .499 .627 r
.39025 .60794 m .39146 .60561 L p .40351 .61182 L F P
0 g
s
.704 .505 .616 r
.39025 .60794 m .39146 .60561 L .38993 .6056 L closepath p F P
0 g
s
.718 .515 .614 r
.38993 .6056 m .38049 .60461 L p .3883 .61213 L F P
0 g
s
.718 .515 .614 r
.3883 .61213 m .39025 .60794 L .38993 .6056 L p F P
0 g
s
.376 .228 .55 r
.51088 .697 m .51465 .6945 L .51283 .68931 L p F P
0 g
s
.365 .222 .55 r
.51961 .68463 m .51283 .68931 L .51465 .6945 L p F P
0 g
s
.403 .274 .59 r
.51882 .67816 m .51961 .68463 L .51283 .68931 L p F P
0 g
s
0 0 0 r
.47411 .73245 m .47613 .7311 L .4871 .72684 L p F P
0 g
s
0 0 0 r
.47613 .7311 m .47411 .73245 L .46227 .73621 L p F P
0 g
s
.662 .741 .909 r
.37171 .74094 m .3834 .73688 L .38679 .74066 L p F P
0 g
s
.692 .705 .858 r
.3834 .73688 m .37171 .74094 L .36829 .73757 L p F P
0 g
s
.403 .444 .788 r
.49195 .58871 m .49417 .58469 L p .49932 .59304 L F P
0 g
s
.398 .454 .802 r
.49195 .58871 m .48949 .58302 L .49417 .58469 L closepath p F P
0 g
s
.651 .758 .928 r
.70748 .44625 m .71977 .44232 L .72261 .44593 L p F P
0 g
s
.651 .758 .928 r
.71977 .44232 m .70748 .44625 L .70462 .44263 L p F P
0 g
s
.651 .758 .928 r
.52314 .4463 m .53509 .44238 L .53824 .446 L p F P
0 g
s
.651 .758 .928 r
.53509 .44238 m .52314 .4463 L .51997 .44268 L p F P
0 g
s
.494 .891 .948 r
.45963 .73584 m .46227 .73621 L .47411 .73245 L p F P
0 g
s
.394 .845 .912 r
.46227 .73621 m .45963 .73584 L .44756 .73898 L p F P
0 g
s
.875 .558 .446 r
.28333 .70595 m .28343 .70569 L p .28939 .71369 L F P
0 g
s
.891 .587 .464 r
.28333 .70595 m .28331 .70563 L .28343 .70569 L closepath p F P
0 g
s
.667 .733 .899 r
.38679 .74066 m .39851 .73643 L .40187 .74038 L p F P
0 g
s
.69 .692 .847 r
.39851 .73643 m .38679 .74066 L .3834 .73688 L p F P
0 g
s
.651 .758 .928 r
.72261 .44593 m .73492 .442 L .73774 .44562 L p F P
0 g
s
.651 .758 .928 r
.73492 .442 m .72261 .44593 L .71977 .44232 L p F P
0 g
s
.609 .428 .611 r
.4053 .60908 m .4122 .60358 L .40484 .60516 L closepath p F P
0 g
s
.687 .499 .627 r
.40484 .60516 m .4053 .60908 L .40351 .61182 L p F P
0 g
s
.651 .758 .928 r
.53824 .446 m .55022 .44207 L .55335 .4457 L p F P
0 g
s
.651 .758 .928 r
.55022 .44207 m .53824 .446 L .53509 .44238 L p F P
0 g
s
.903 .592 .448 r
.28331 .70563 m .28333 .70595 L .2812 .70973 L p F P
0 g
s
.903 .592 .448 r
.27842 .70284 m .28331 .70563 L p .2812 .70973 L F P
0 g
s
.895 .625 .521 r
.27877 .6971 m .27842 .70284 L .28331 .70563 L p F P
0 g
s
.474 .795 .999 r
.34608 .73911 m .35318 .73809 L p .33811 .73772 L F P
0 g
s
.474 .795 .999 r
.33811 .73772 m .33942 .73845 L .34608 .73911 L p F P
0 g
s
.907 .742 .665 r
.27246 .6637 m .27027 .66899 L .26672 .66476 L p F P
0 g
s
.907 .742 .665 r
.26672 .66476 m .26844 .66058 L .27246 .6637 L p F P
0 g
s
.9 .748 .684 r
.27246 .6637 m .26844 .66058 L .27145 .65408 L p F P
0 g
s
.717 .223 .065 r
.30475 .7274 m .30626 .72845 L .31296 .73065 L p F P
0 g
s
.826 .607 .605 r
.36867 .5899 m .36906 .58828 L p .37418 .59663 L F P
0 g
s
.863 .638 .596 r
.36867 .5899 m .36906 .58828 L .3682 .58787 L closepath p F P
0 g
s
.791 .571 .602 r
.38049 .60461 m .37241 .60271 L .37418 .59663 L p F P
0 g
s
.824 .609 .611 r
.36968 .59507 m .37418 .59663 L .37241 .60271 L p F P
0 g
s
.826 .607 .605 r
.37418 .59663 m .36968 .59507 L .36867 .5899 L p F P
0 g
s
.498 .876 .975 r
.44716 .73887 m .44756 .73898 L .45963 .73584 L p F P
0 g
s
.911 .639 .513 r
.27409 .69423 m .27877 .6971 L .27842 .70284 L p F P
0 g
s
.905 .665 .564 r
.27877 .6971 m .27409 .69423 L .27506 .68832 L p F P
0 g
s
.687 .499 .627 r
.40351 .61182 m .39091 .61231 L .39025 .60794 L p F P
0 g
s
.729 .528 .62 r
.39091 .61231 m .39025 .60794 L .3883 .61213 L closepath p F P
0 g
s
.875 .558 .446 r
.28939 .71369 m .2839 .7111 L .28333 .70595 L p F P
0 g
s
.885 .566 .439 r
.2839 .7111 m .2812 .70973 L .28333 .70595 L closepath p F P
0 g
s
.909 .716 .629 r
.27243 .67195 m .26984 .67008 L p .2721 .67931 L F P
0 g
s
.903 .73 .658 r
.27243 .67195 m .27027 .66899 L .26984 .67008 L closepath p F P
0 g
s
.661 .739 .908 r
.40187 .74038 m .41361 .73636 L .41696 .74017 L p F P
0 g
s
.68 .691 .854 r
.41361 .73636 m .40187 .74038 L .39851 .73643 L p F P
0 g
s
.838 .616 .602 r
.3682 .58787 m .36279 .58579 L .36438 .57979 L p F P
0 g
s
.886 .663 .594 r
.35915 .57695 m .36438 .57979 L .36279 .58579 L p F P
0 g
s
.651 .758 .928 r
.73774 .44562 m .75008 .44169 L .75287 .44531 L p F P
0 g
s
.651 .758 .928 r
.75008 .44169 m .73774 .44562 L .73492 .442 L p F P
0 g
s
.338 .164 .492 r
.51465 .6945 m .51088 .697 L .51092 .70275 L p F P
0 g
s
.651 .758 .928 r
.55335 .4457 m .56535 .44177 L .56846 .44539 L p F P
0 g
s
.651 .758 .928 r
.56535 .44177 m .55335 .4457 L .55022 .44207 L p F P
0 g
s
.856 .471 .316 r
.29682 .72136 m .29123 .71881 L .28939 .71369 L p F P
0 g
s
.86 .467 .296 r
.2839 .7111 m .28939 .71369 L .29123 .71881 L p F P
0 g
s
.233 0 .243 r
.5105 .70806 m .50068 .71356 L .49958 .71822 L p F P
0 g
s
.291 .075 .404 r
.51092 .70275 m .5105 .70806 L .50068 .71356 L p F P
0 g
s
.186 0 0 r
.32315 .73506 m .33063 .73533 L .33693 .73764 L p F P
0 g
s
.211 .69 .934 r
.33063 .73533 m .32315 .73506 L .31955 .73364 L p F P
0 g
s
.651 .758 .928 r
.75287 .44531 m .76524 .44137 L .76801 .44499 L p F P
0 g
s
.651 .758 .928 r
.76524 .44137 m .75287 .44531 L .75008 .44169 L p F P
0 g
s
.646 .766 .936 r
.41696 .74017 m .42872 .73653 L .43205 .73983 L p F P
0 g
s
.667 .707 .877 r
.42872 .73653 m .41696 .74017 L .41361 .73636 L p F P
0 g
s
.829 .618 .618 r
.3682 .58787 m .36279 .58579 L p .36725 .59435 L F P
0 g
s
.829 .618 .618 r
.36725 .59435 m .36867 .5899 L .3682 .58787 L p F P
0 g
s
.718 .515 .614 r
.38049 .60461 m .37819 .61087 L .3883 .61213 L p F P
0 g
s
.793 .588 .624 r
.37241 .60271 m .38049 .60461 L .37819 .61087 L p F P
0 g
s
.402 .378 .718 r
.52074 .64179 m .51418 .63811 L .51839 .63376 L closepath p F P
0 g
s
.42 .391 .721 r
.51751 .63097 m .51839 .63376 L .51418 .63811 L p F P
0 g
s
.42 .391 .721 r
.51293 .62859 m .51751 .63097 L p .51418 .63811 L F P
0 g
s
.651 .758 .928 r
.56846 .44539 m .58049 .44146 L .58357 .44509 L p F P
0 g
s
.651 .758 .928 r
.58049 .44146 m .56846 .44539 L .56535 .44177 L p F P
0 g
s
.915 .676 .561 r
.27061 .68537 m .27506 .68832 L .27409 .69423 L p F P
0 g
s
.909 .693 .599 r
.27506 .68832 m .27061 .68537 L .2721 .67931 L p F P
0 g
s
.398 .454 .802 r
.49417 .58469 m .48949 .58302 L .48755 .57853 L p F P
0 g
s
.519 .354 .597 r
.41682 .59608 m .42763 .59147 L p .42201 .60054 L F P
0 g
s
.519 .354 .597 r
.42201 .60054 m .41716 .59945 L .41682 .59608 L p F P
0 g
s
.504 .338 .59 r
.42696 .58512 m .42763 .59147 L .41682 .59608 L p F P
0 g
s
.608 .423 .607 r
.41682 .59608 m .41716 .59945 L .4122 .60358 L p F P
0 g
s
.498 .876 .975 r
.45963 .73584 m .45897 .73564 L .44716 .73887 L p F P
0 g
s
.622 .814 .974 r
.45897 .73564 m .44716 .73887 L .44384 .73653 L p F P
0 g
s
.569 .838 .996 r
.44716 .73887 m .44384 .73653 L .43205 .73983 L p F P
0 g
s
.262 .686 .966 r
.33811 .73772 m .33693 .73764 L .33942 .73845 L closepath p F P
0 g
s
.65 .742 .917 r
.44384 .73653 m .43205 .73983 L .42872 .73653 L p F P
0 g
s
.81 .596 .613 r
.36968 .59507 m .36867 .5899 L .36725 .59435 L closepath p F P
0 g
s
.651 .758 .928 r
.76801 .44499 m .78041 .44105 L .78315 .44468 L p F P
0 g
s
.651 .758 .928 r
.78041 .44105 m .76801 .44499 L .76524 .44137 L p F P
0 g
s
.375 .284 .623 r
.51771 .67137 m .52337 .6665 L p .51969 .67745 L F P
0 g
s
.375 .284 .623 r
.51969 .67745 m .51847 .67599 L .51771 .67137 L p F P
0 g
s
.381 .308 .648 r
.51771 .67137 m .52337 .6665 L .51882 .66215 L p F P
0 g
s
.651 .758 .928 r
.58357 .44509 m .59563 .44116 L .59868 .44478 L p F P
0 g
s
.651 .758 .928 r
.59563 .44116 m .58357 .44509 L .58049 .44146 L p F P
0 g
s
.651 .758 .928 r
.78315 .44468 m .79558 .44074 L .79829 .44436 L p F P
0 g
s
.651 .758 .928 r
.79558 .44074 m .78315 .44468 L .78041 .44105 L p F P
0 g
s
.798 .325 .104 r
.3029 .72733 m .30012 .72607 L .29682 .72136 L p F P
0 g
s
.784 .292 .038 r
.29123 .71881 m .29682 .72136 L .30012 .72607 L p F P
0 g
s
.651 .758 .928 r
.59868 .44478 m .61078 .44085 L .61381 .44448 L p F P
0 g
s
.651 .758 .928 r
.61078 .44085 m .59868 .44478 L .59563 .44116 L p F P
0 g
s
.62 .446 .625 r
.40566 .61169 m .4053 .60908 L .4122 .60358 L p F P
0 g
s
.678 .487 .62 r
.40566 .61169 m .4053 .60908 L .40351 .61182 L closepath p F P
0 g
s
.354 .232 .572 r
.4278 .57769 m .42636 .57885 L .42696 .58512 L p F P
0 g
s
.688 .501 .629 r
.39091 .61231 m .40351 .61182 L .3988 .61883 L p F P
0 g
s
.688 .501 .629 r
.3988 .61883 m .39197 .6191 L .39091 .61231 L p F P
0 g
s
.73 .53 .621 r
.3883 .61213 m .39091 .61231 L .39197 .6191 L p F P
0 g
s
.616 .054 0 r
.30626 .72845 m .3029 .72733 L .30475 .7274 L closepath p F P
0 g
s
.918 .705 .598 r
.26789 .67627 m .2721 .67931 L .27061 .68537 L p F P
0 g
s
.909 .716 .629 r
.26984 .67008 m .26789 .67627 L .2721 .67931 L p F P
0 g
s
.651 .758 .928 r
.79829 .44436 m .81076 .44041 L .81344 .44404 L p F P
0 g
s
.651 .758 .928 r
.81076 .44041 m .79829 .44436 L .79558 .44074 L p F P
0 g
s
.91 .763 .686 r
.2677 .65085 m .27145 .65408 L .26844 .66058 L p F P
0 g
s
.905 .767 .698 r
.27145 .65408 m .2677 .65085 L .27099 .64428 L p F P
0 g
s
.651 .758 .928 r
.61381 .44448 m .62593 .44054 L .62893 .44417 L p F P
0 g
s
.651 .758 .928 r
.62593 .44054 m .61381 .44448 L .61078 .44085 L p F P
0 g
s
.73 .53 .621 r
.39197 .6191 m .38525 .61863 L .3883 .61213 L p F P
0 g
s
.763 .555 .616 r
.37819 .61087 m .3883 .61213 L .38525 .61863 L p F P
0 g
s
.398 .454 .802 r
.48755 .57853 m .48849 .57649 L p .49417 .58469 L F P
0 g
s
.62 .446 .625 r
.4122 .60358 m .41753 .60249 L p .40566 .61169 L F P
0 g
s
.615 .435 .615 r
.41753 .60249 m .41716 .59945 L .4122 .60358 L closepath p F P
0 g
s
.437 .745 .993 r
.33693 .73764 m .33811 .73772 L .33459 .73514 L p F P
0 g
s
.437 .745 .993 r
.33459 .73514 m .33063 .73533 L .33693 .73764 L p F P
0 g
s
.651 .758 .928 r
.81344 .44404 m .82593 .44009 L .8286 .44371 L p F P
0 g
s
.651 .758 .928 r
.82593 .44009 m .81344 .44404 L .81076 .44041 L p F P
0 g
s
.374 .307 .653 r
.52454 .65698 m .51882 .66215 L .52337 .6665 L p F P
0 g
s
.401 .337 .67 r
.52398 .65466 m .52454 .65698 L .51882 .66215 L p F P
0 g
s
.401 .337 .67 r
.52036 .65181 m .52398 .65466 L p .51882 .66215 L F P
0 g
s
.651 .758 .928 r
.62893 .44417 m .64108 .44024 L .64406 .44386 L p F P
0 g
s
.651 .758 .928 r
.64108 .44024 m .62893 .44417 L .62593 .44054 L p F P
0 g
s
.824 .609 .611 r
.37241 .60271 m .37117 .60228 L .36968 .59507 L p F P
0 g
s
.812 .6 .616 r
.36725 .59435 m .36968 .59507 L .37117 .60228 L p F P
0 g
s
.4 .39 .732 r
.51751 .63097 m .51293 .62859 L .51576 .62543 L closepath p F P
0 g
s
.417 .415 .749 r
.51428 .62106 m .51074 .61934 L p .51293 .62859 L F P
0 g
s
.417 .415 .749 r
.51293 .62859 m .51576 .62543 L .51428 .62106 L p F P
0 g
s
.678 .489 .623 r
.40351 .61182 m .40566 .61169 L .40662 .61837 L p F P
0 g
s
.678 .489 .623 r
.40662 .61837 m .3988 .61883 L .40351 .61182 L p F P
0 g
s
.911 .742 .659 r
.26984 .67008 m .27027 .66899 L .26672 .66476 L p F P
0 g
s
.516 .364 .614 r
.41753 .60249 m .41716 .59945 L .42201 .60054 L closepath p F P
0 g
s
.617 .446 .628 r
.40662 .61837 m .40566 .61169 L .41839 .60905 L p F P
0 g
s
.62 .446 .625 r
.41753 .60249 m .41839 .60905 L .40566 .61169 L p F P
0 g
s
.651 .758 .928 r
.84112 .43976 m .8286 .44371 L .82593 .44009 L p F P
0 g
s
.651 .758 .928 r
.8286 .44371 m .84112 .43976 L .84375 .44339 L p F P
0 g
s
.374 .283 .624 r
.51882 .67816 m .51847 .67599 L .51969 .67745 L closepath p F P
0 g
s
.651 .758 .928 r
.64406 .44386 m .65624 .43993 L .65919 .44356 L p F P
0 g
s
.651 .758 .928 r
.65624 .43993 m .64406 .44386 L .64108 .44024 L p F P
0 g
s
.921 .73 .628 r
.26586 .66695 m .26984 .67008 L .26789 .67627 L p F P
0 g
s
.911 .742 .659 r
.26672 .66476 m .26586 .66695 L .26984 .67008 L p F P
0 g
s
.651 .758 .928 r
.84375 .44339 m .8563 .43943 L .85892 .44306 L p F P
0 g
s
.651 .758 .928 r
.8563 .43943 m .84375 .44339 L .84112 .43976 L p F P
0 g
s
.474 .795 .999 r
.35318 .73809 m .34971 .7347 L .33811 .73772 L p F P
0 g
s
.67 .739 .902 r
.34971 .7347 m .33811 .73772 L .33459 .73514 L p F P
0 g
s
.651 .758 .928 r
.65919 .44356 m .6714 .43962 L .67433 .44325 L p F P
0 g
s
.651 .758 .928 r
.6714 .43962 m .65919 .44356 L .65624 .43993 L p F P
0 g
s
.318 .218 .58 r
.43452 .57147 m .4278 .57769 L .43037 .58243 L p F P
0 g
s
.354 .232 .572 r
.42696 .58512 m .43037 .58243 L .4278 .57769 L p F P
0 g
s
.812 .6 .616 r
.37117 .60228 m .36526 .60051 L .36725 .59435 L p F P
0 g
s
.855 .639 .611 r
.36113 .59182 m .36725 .59435 L .36526 .60051 L p F P
0 g
s
.829 .618 .618 r
.36279 .58579 m .36113 .59182 L .36725 .59435 L p F P
0 g
s
.793 .588 .624 r
.37173 .60487 m .37241 .60271 L p .37819 .61087 L F P
0 g
s
.824 .611 .615 r
.37173 .60487 m .37241 .60271 L .37117 .60228 L closepath p F P
0 g
s
.344 .235 .584 r
.51969 .67745 m .51882 .67816 L .51961 .68463 L p F P
0 g
s
.136 .586 .926 r
.3029 .72733 m .30626 .72845 L .31544 .73145 L p F P
0 g
s
.651 .758 .928 r
.67433 .44325 m .68657 .43931 L .68947 .44294 L p F P
0 g
s
.651 .758 .928 r
.68657 .43931 m .67433 .44325 L .6714 .43962 L p F P
0 g
s
.651 .758 .928 r
.48973 .44329 m .50163 .43936 L .50485 .44299 L p F P
0 g
s
.399 .402 .747 r
.51428 .62106 m .51074 .61934 L .51284 .61679 L closepath p F P
0 g
s
.416 .428 .764 r
.51106 .61187 m .50769 .61035 L p .51074 .61934 L F P
0 g
s
.416 .428 .764 r
.51074 .61934 m .51284 .61679 L .51106 .61187 L p F P
0 g
s
.891 .673 .601 r
.35775 .5829 m .36279 .58579 L .36113 .59182 L p F P
0 g
s
.886 .663 .594 r
.36279 .58579 m .35775 .5829 L .35915 .57695 L p F P
0 g
s
.518 .369 .618 r
.41839 .60905 m .41753 .60249 L .42201 .60054 L p F P
0 g
s
.763 .555 .616 r
.38525 .61863 m .37579 .61716 L .37819 .61087 L p F P
0 g
s
.792 .589 .627 r
.37268 .60953 m .37819 .61087 L .37579 .61716 L p F P
0 g
s
.793 .588 .624 r
.37819 .61087 m .37268 .60953 L .37173 .60487 L p F P
0 g
s
.677 .728 .888 r
.36536 .73409 m .36829 .73757 L p .35318 .73809 L F P
0 g
s
.677 .728 .888 r
.35318 .73809 m .36348 .73405 L .36536 .73409 L p F P
0 g
s
.707 .713 .853 r
.36348 .73405 m .35318 .73809 L .34971 .7347 L p F P
0 g
s
.651 .758 .928 r
.68947 .44294 m .70174 .439 L .70462 .44263 L p F P
0 g
s
.651 .758 .928 r
.70174 .439 m .68947 .44294 L .68657 .43931 L p F P
0 g
s
.651 .758 .928 r
.50485 .44299 m .51678 .43905 L .51997 .44268 L p F P
0 g
s
.651 .758 .928 r
.51678 .43905 m .50485 .44299 L .50163 .43936 L p F P
0 g
s
.688 .502 .63 r
.39197 .6191 m .3988 .61883 L .39401 .62588 L p F P
0 g
s
.688 .502 .63 r
.39401 .62588 m .39305 .62592 L .39197 .6191 L p F P
0 g
s
.731 .531 .622 r
.38525 .61863 m .39197 .6191 L .39305 .62592 L p F P
0 g
s
.798 .595 .628 r
.37117 .60228 m .36526 .60051 L p .37018 .60894 L F P
0 g
s
.798 .595 .628 r
.37018 .60894 m .37173 .60487 L .37117 .60228 L p F P
0 g
s
.338 .164 .492 r
.51092 .70275 m .51479 .7002 L .51465 .6945 L p F P
0 g
s
.323 .153 .489 r
.52006 .69077 m .51465 .6945 L .51479 .7002 L p F P
0 g
s
.365 .222 .55 r
.51465 .6945 m .52006 .69077 L .51961 .68463 L p F P
0 g
s
.692 .705 .858 r
.38257 .73574 m .3834 .73688 L p .36829 .73757 L F P
0 g
s
.692 .705 .858 r
.36829 .73757 m .37305 .7354 L .38257 .73574 L p F P
0 g
s
.699 .737 .881 r
.36829 .73757 m .37305 .7354 L .36536 .73409 L closepath p F P
0 g
s
.903 .592 .448 r
.2812 .70973 m .27882 .70837 L .27842 .70284 L p F P
0 g
s
.913 .599 .438 r
.27375 .69997 m .27842 .70284 L .27882 .70837 L p F P
0 g
s
.911 .639 .513 r
.27842 .70284 m .27375 .69997 L .27409 .69423 L p F P
0 g
s
.69 .692 .847 r
.39818 .73594 m .39851 .73643 L p .3834 .73688 L F P
0 g
s
.69 .692 .847 r
.3834 .73688 m .38555 .73589 L .39818 .73594 L p F P
0 g
s
.694 .708 .859 r
.3834 .73688 m .38555 .73589 L .38257 .73574 L closepath p F P
0 g
s
.931 .713 .587 r
.35514 .57372 m .35915 .57695 L .35775 .5829 L p F P
0 g
s
.28 .07 .405 r
.51479 .7002 m .51092 .70275 L .5105 .70806 L p F P
0 g
s
.651 .758 .928 r
.70462 .44263 m .71692 .43868 L .71977 .44232 L p F P
0 g
s
.651 .758 .928 r
.71692 .43868 m .70462 .44263 L .70174 .439 L p F P
0 g
s
.651 .758 .928 r
.51997 .44268 m .53193 .43875 L .53509 .44238 L p F P
0 g
s
.651 .758 .928 r
.53193 .43875 m .51997 .44268 L .51678 .43905 L p F P
0 g
s
.86 .467 .296 r
.29123 .71881 m .2858 .71619 L .2839 .7111 L p F P
0 g
s
.86 .451 .254 r
.2812 .70973 m .2839 .7111 L .2858 .71619 L p F P
0 g
s
.678 .49 .624 r
.3988 .61883 m .40662 .61837 L .40759 .62508 L p F P
0 g
s
.678 .49 .624 r
.40759 .62508 m .39401 .62588 L .3988 .61883 L p F P
0 g
s
.921 .649 .508 r
.26964 .69129 m .27409 .69423 L .27375 .69997 L p F P
0 g
s
.915 .676 .561 r
.27409 .69423 m .26964 .69129 L .27061 .68537 L p F P
0 g
s
.68 .691 .854 r
.41293 .73535 m .41361 .73636 L p .39851 .73643 L F P
0 g
s
.68 .691 .854 r
.39851 .73643 m .39984 .73587 L .41293 .73535 L p F P
0 g
s
.68 .689 .852 r
.39851 .73643 m .39984 .73587 L .39818 .73594 L closepath p F P
0 g
s
.344 .235 .584 r
.51961 .68463 m .52235 .68239 L .51969 .67745 L p F P
0 g
s
.334 .232 .587 r
.52713 .6711 m .51969 .67745 L .52235 .68239 L p F P
0 g
s
.375 .284 .623 r
.52337 .6665 m .52713 .6711 L .51969 .67745 L p F P
0 g
s
.396 .414 .761 r
.51106 .61187 m .50769 .61035 L .50959 .60781 L closepath p F P
0 g
s
.415 .44 .778 r
.50784 .60327 m .50386 .60159 L p .50769 .61035 L F P
0 g
s
.415 .44 .778 r
.50769 .61035 m .50959 .60781 L .50784 .60327 L p F P
0 g
s
.79 .586 .625 r
.37268 .60953 m .37173 .60487 L .37018 .60894 L closepath p F P
0 g
s
.36 .241 .579 r
.43037 .58243 m .42696 .58512 L .42763 .59147 L p F P
0 g
s
0 0 0 r
.4871 .72684 m .48599 .72778 L .47411 .73245 L p F P
0 g
s
.544 .918 .938 r
.47123 .7322 m .47411 .73245 L .48599 .72778 L p F P
0 g
s
.494 .891 .948 r
.47411 .73245 m .47123 .7322 L .45963 .73584 L p F P
0 g
s
.918 .756 .666 r
.26844 .66058 m .26672 .66476 L .26311 .66117 L p F P
0 g
s
.918 .756 .666 r
.26311 .66117 m .26468 .65736 L .26844 .66058 L p F P
0 g
s
.91 .763 .686 r
.26844 .66058 m .26468 .65736 L .2677 .65085 L p F P
0 g
s
.731 .531 .622 r
.39305 .62592 m .38216 .62515 L .38525 .61863 L p F P
0 g
s
.766 .574 .639 r
.37579 .61716 m .38525 .61863 L .38216 .62515 L p F P
0 g
s
.651 .758 .928 r
.71977 .44232 m .7321 .43837 L .73492 .442 L p F P
0 g
s
.651 .758 .928 r
.7321 .43837 m .71977 .44232 L .71692 .43868 L p F P
0 g
s
.651 .758 .928 r
.53509 .44238 m .54708 .43844 L .55022 .44207 L p F P
0 g
s
.651 .758 .928 r
.54708 .43844 m .53509 .44238 L .53193 .43875 L p F P
0 g
s
.679 .691 .854 r
.39984 .73587 m .39818 .73594 L .39516 .73152 L p F P
0 g
s
.689 .694 .85 r
.39818 .73594 m .39516 .73152 L .38555 .73589 L closepath p F P
0 g
s
.693 .709 .86 r
.39182 .72582 m .39516 .73152 L .38555 .73589 L p F P
0 g
s
.693 .709 .86 r
.38002 .73227 m .39182 .72582 L p .38555 .73589 L F P
0 g
s
.693 .709 .86 r
.38555 .73589 m .38257 .73574 L .38002 .73227 L p F P
0 g
s
.398 .454 .802 r
.48849 .57649 m .49664 .57953 L .49417 .58469 L p F P
0 g
s
.392 .476 .827 r
.49031 .57151 m .48849 .57649 L .49664 .57953 L p F P
0 g
s
.68 .692 .855 r
.41293 .73535 m .41028 .73148 L .39984 .73587 L closepath p F P
0 g
s
.679 .691 .854 r
.40696 .72566 m .41028 .73148 L .39984 .73587 L p F P
0 g
s
.679 .691 .854 r
.39516 .73152 m .40696 .72566 L p .39984 .73587 L F P
0 g
s
.542 .887 .984 r
.45897 .73564 m .45963 .73584 L .47123 .7322 L p F P
0 g
s
.667 .707 .877 r
.42679 .73391 m .42872 .73653 L p .41361 .73636 L F P
0 g
s
.667 .707 .877 r
.41361 .73636 m .41831 .73464 L .42679 .73391 L p F P
0 g
s
.663 .684 .859 r
.41361 .73636 m .41831 .73464 L .41293 .73535 L closepath p F P
0 g
s
.61 .442 .629 r
.40662 .61837 m .41926 .61564 L p .41975 .62235 L F P
0 g
s
.61 .442 .629 r
.41975 .62235 m .40759 .62508 L .40662 .61837 L p F P
0 g
s
.617 .446 .628 r
.41839 .60905 m .41926 .61564 L .40662 .61837 L p F P
0 g
s
.393 .426 .776 r
.50784 .60327 m .50386 .60159 L .50597 .59843 L closepath p F P
0 g
s
.408 .433 .775 r
.50461 .59515 m .50597 .59843 L .50386 .60159 L p F P
0 g
s
.408 .433 .775 r
.49932 .59304 m .50461 .59515 L p .50386 .60159 L F P
0 g
s
.651 .758 .928 r
.73492 .442 m .74728 .43805 L .75008 .44169 L p F P
0 g
s
.651 .758 .928 r
.74728 .43805 m .73492 .442 L .7321 .43837 L p F P
0 g
s
.651 .758 .928 r
.55022 .44207 m .56224 .43813 L .56535 .44177 L p F P
0 g
s
.651 .758 .928 r
.56224 .43813 m .55022 .44207 L .54708 .43844 L p F P
0 g
s
.69 .708 .862 r
.38257 .73574 m .38002 .73227 L .37305 .7354 L closepath p F P
0 g
s
.136 .586 .926 r
.30107 .72693 m .3029 .72733 L p .31544 .73145 L F P
0 g
s
.677 .128 0 r
.30107 .72693 m .30012 .72607 L .3029 .72733 L closepath p F P
0 g
s
.925 .687 .559 r
.26638 .68234 m .27061 .68537 L .26964 .69129 L p F P
0 g
s
.918 .705 .598 r
.27061 .68537 m .26638 .68234 L .26789 .67627 L p F P
0 g
s
.381 .332 .678 r
.52398 .65466 m .52036 .65181 L .52276 .64951 L closepath p F P
0 g
s
.397 .357 .697 r
.52036 .65181 m .52276 .64951 L .52074 .6418 L p F P
0 g
s
.403 .444 .788 r
.49417 .58469 m .50139 .5874 L p .49932 .59304 L F P
0 g
s
.374 .44 .801 r
.49417 .58469 m .50139 .5874 L .49816 .58014 L p F P
0 g
s
.374 .44 .801 r
.49816 .58014 m .49664 .57953 L .49417 .58469 L p F P
0 g
s
.389 .438 .791 r
.50461 .59515 m .49932 .59304 L .50191 .58859 L closepath p F P
0 g
s
.403 .444 .788 r
.50139 .5874 m .50191 .58859 L .49932 .59304 L p F P
0 g
s
.784 .292 .038 r
.30012 .72607 m .29474 .72345 L .29123 .71881 L p F P
0 g
s
.765 .256 0 r
.2858 .71619 m .29123 .71881 L .29474 .72345 L p F P
0 g
s
.651 .758 .928 r
.75008 .44169 m .76247 .43774 L .76524 .44137 L p F P
0 g
s
.651 .758 .928 r
.76247 .43774 m .75008 .44169 L .74728 .43805 L p F P
0 g
s
.651 .758 .928 r
.56535 .44177 m .5774 .43783 L .58049 .44146 L p F P
0 g
s
.651 .758 .928 r
.5774 .43783 m .56535 .44177 L .56224 .43813 L p F P
0 g
s
.698 .738 .882 r
.37665 .72697 m .38002 .73227 L .37305 .7354 L p F P
0 g
s
.698 .738 .882 r
.36487 .73351 m .37665 .72697 L p .37305 .7354 L F P
0 g
s
.698 .738 .882 r
.37305 .7354 m .36536 .73409 L .36487 .73351 L p F P
0 g
s
.792 .589 .627 r
.37579 .61716 m .3742 .61678 L .37268 .60953 L p F P
0 g
s
.791 .588 .626 r
.37018 .60894 m .37268 .60953 L .3742 .61678 L p F P
0 g
s
.65 .742 .917 r
.42872 .73653 m .44052 .73281 L .44384 .73653 L p F P
0 g
s
.652 .699 .881 r
.43967 .73152 m .44052 .73281 L .42872 .73653 L p F P
0 g
s
.652 .699 .881 r
.42872 .73653 m .42679 .73391 L .43967 .73152 L p F P
0 g
s
.663 .686 .861 r
.41831 .73464 m .41293 .73535 L .41028 .73148 L p F P
0 g
s
.536 .772 .985 r
.33063 .73533 m .33459 .73514 L .33108 .73206 L p F P
0 g
s
.536 .772 .985 r
.33108 .73206 m .32378 .73318 L .33063 .73533 L p F P
0 g
s
.211 .69 .934 r
.31955 .73364 m .32378 .73318 L .33063 .73533 L p F P
0 g
s
.651 .758 .928 r
.76524 .44137 m .77766 .43742 L .78041 .44105 L p F P
0 g
s
.651 .758 .928 r
.77766 .43742 m .76524 .44137 L .76247 .43774 L p F P
0 g
s
0 0 0 r
.48599 .72778 m .4952 .72313 L .4871 .72684 L closepath p F P
0 g
s
.05 0 0 r
.49791 .72159 m .4952 .72313 L .4871 .72684 L p F P
0 g
s
.05 0 0 r
.49958 .71822 m .49791 .72159 L p .4871 .72684 L F P
0 g
s
.651 .758 .928 r
.58049 .44146 m .59257 .43752 L .59563 .44116 L p F P
0 g
s
.651 .758 .928 r
.59257 .43752 m .58049 .44146 L .5774 .43783 L p F P
0 g
s
.688 .505 .633 r
.39323 .627 m .39401 .62588 L .39305 .62592 L closepath p F P
0 g
s
.707 .517 .63 r
.39305 .62592 m .38216 .62515 L p .38982 .63275 L F P
0 g
s
.707 .517 .63 r
.38982 .63275 m .39323 .627 L .39305 .62592 L p F P
0 g
s
.928 .718 .597 r
.2639 .67314 m .26789 .67627 L .26638 .68234 L p F P
0 g
s
.921 .73 .628 r
.26789 .67627 m .2639 .67314 L .26586 .66695 L p F P
0 g
s
.542 .887 .984 r
.47123 .7322 m .47082 .73209 L .45897 .73564 L p F P
0 g
s
.617 .823 .979 r
.47082 .73209 m .45897 .73564 L .45566 .73313 L p F P
0 g
s
.622 .814 .974 r
.44384 .73653 m .45566 .73313 L .45897 .73564 L p F P
0 g
s
.651 .758 .928 r
.78041 .44105 m .79286 .4371 L .79558 .44074 L p F P
0 g
s
.651 .758 .928 r
.79286 .4371 m .78041 .44105 L .77766 .43742 L p F P
0 g
s
.085 0 .011 r
.49791 .72159 m .50767 .71377 L .49958 .71822 L closepath p F P
0 g
s
.233 0 .243 r
.50984 .71135 m .5105 .70806 L p .49958 .71822 L F P
0 g
s
.233 0 .243 r
.49958 .71822 m .50767 .71377 L .50984 .71135 L p F P
0 g
s
.644 .732 .913 r
.45566 .73313 m .44384 .73653 L .44052 .73281 L p F P
0 g
s
.677 .505 .646 r
.39401 .62588 m .40759 .62508 L p .40624 .63208 L F P
0 g
s
.677 .505 .646 r
.39323 .627 m .39401 .62588 L p .40624 .63208 L F P
0 g
s
.309 .181 .539 r
.52235 .68239 m .51961 .68463 L .52006 .69077 L p F P
0 g
s
.651 .758 .928 r
.59563 .44116 m .60774 .43721 L .61078 .44085 L p F P
0 g
s
.651 .758 .928 r
.60774 .43721 m .59563 .44116 L .59257 .43752 L p F P
0 g
s
.522 .372 .619 r
.41926 .61564 m .41839 .60905 L .42919 .60443 L p F P
0 g
s
.518 .369 .618 r
.42881 .60181 m .42919 .60443 L .41839 .60905 L p F P
0 g
s
.518 .369 .618 r
.42201 .60054 m .42881 .60181 L p .41839 .60905 L F P
0 g
s
.86 .451 .254 r
.27932 .71055 m .2812 .70973 L p .2858 .71619 L F P
0 g
s
.895 .537 .355 r
.27932 .71055 m .27882 .70837 L .2812 .70973 L closepath p F P
0 g
s
.791 .588 .626 r
.3742 .61678 m .36776 .61525 L .37018 .60894 L p F P
0 g
s
.83 .622 .622 r
.36324 .60668 m .37018 .60894 L .36776 .61525 L p F P
0 g
s
.798 .595 .628 r
.36526 .60051 m .36324 .60668 L .37018 .60894 L p F P
0 g
s
.521 .364 .609 r
.42881 .60181 m .42201 .60054 L .42835 .59789 L closepath p F P
0 g
s
.519 .354 .597 r
.42763 .59147 m .42835 .59789 L .42201 .60054 L p F P
0 g
s
.862 .65 .615 r
.35941 .59789 m .36526 .60051 L .36324 .60668 L p F P
0 g
s
.855 .639 .611 r
.36526 .60051 m .35941 .59789 L .36113 .59182 L p F P
0 g
s
.921 .754 .658 r
.26586 .66695 m .26672 .66476 L .26311 .66117 L p F P
0 g
s
.677 .505 .646 r
.40624 .63208 m .39431 .63293 L .39323 .627 L p F P
0 g
s
.719 .533 .637 r
.39431 .63293 m .39323 .627 L .38982 .63275 L closepath p F P
0 g
s
.46 .783 .998 r
.32378 .73318 m .3169 .7321 L .31955 .73364 L closepath p F P
0 g
s
.651 .758 .928 r
.79558 .44074 m .80806 .43678 L .81076 .44041 L p F P
0 g
s
.651 .758 .928 r
.80806 .43678 m .79558 .44074 L .79286 .4371 L p F P
0 g
s
.651 .758 .928 r
.61078 .44085 m .62292 .4369 L .62593 .44054 L p F P
0 g
s
.651 .758 .928 r
.62292 .4369 m .61078 .44085 L .60774 .43721 L p F P
0 g
s
.766 .574 .639 r
.37481 .61964 m .37579 .61716 L p .38216 .62515 L F P
0 g
s
.791 .591 .63 r
.37481 .61964 m .37579 .61716 L .3742 .61678 L closepath p F P
0 g
s
.667 .707 .877 r
.42679 .73391 m .4254 .73204 L .41831 .73464 L closepath p F P
0 g
s
.663 .686 .861 r
.42208 .72646 m .4254 .73204 L .41831 .73464 L p F P
0 g
s
.663 .686 .861 r
.41028 .73148 m .42208 .72646 L p .41831 .73464 L F P
0 g
s
.371 .371 .73 r
.51576 .62543 m .51756 .62292 L p .51958 .63223 L F P
0 g
s
.371 .371 .73 r
.51958 .63223 m .51751 .63097 L .51576 .62543 L p F P
0 g
s
.367 .383 .745 r
.51576 .62543 m .51428 .62106 L .51756 .62292 L closepath p F P
0 g
s
.895 .682 .606 r
.35624 .58889 m .36113 .59182 L .35941 .59789 L p F P
0 g
s
.891 .673 .601 r
.36113 .59182 m .35624 .58889 L .35775 .5829 L p F P
0 g
s
.369 .371 .731 r
.51839 .63376 m .51751 .63097 L .51958 .63223 L closepath p F P
0 g
s
.651 .758 .928 r
.81076 .44041 m .82326 .43645 L .82593 .44009 L p F P
0 g
s
.651 .758 .928 r
.82326 .43645 m .81076 .44041 L .80806 .43678 L p F P
0 g
s
.373 .359 .715 r
.51839 .63376 m .51958 .63223 L p .52074 .6418 L F P
0 g
s
.373 .359 .715 r
.52074 .6418 m .52074 .64179 L .51839 .63376 L p F P
0 g
s
.587 .015 0 r
.30012 .72607 m .30107 .72693 L .29742 .7255 L p F P
0 g
s
.587 .015 0 r
.29742 .7255 m .29474 .72345 L .30012 .72607 L p F P
0 g
s
.651 .758 .928 r
.62593 .44054 m .6381 .43659 L .64108 .44024 L p F P
0 g
s
.651 .758 .928 r
.6381 .43659 m .62593 .44054 L .62292 .4369 L p F P
0 g
s
.368 .383 .744 r
.51756 .62292 m .51428 .62106 L .51284 .61679 L p F P
0 g
s
.368 .383 .744 r
.51284 .61679 m .51474 .61383 L p .51756 .62292 L F P
0 g
s
.364 .395 .76 r
.51284 .61679 m .51106 .61187 L .51474 .61383 L closepath p F P
0 g
s
.774 .58 .636 r
.3742 .61678 m .36776 .61525 L p .37303 .62358 L F P
0 g
s
.774 .58 .636 r
.37303 .62358 m .37481 .61964 L .3742 .61678 L p F P
0 g
s
.707 .517 .63 r
.38216 .62515 m .37901 .63171 L .38982 .63275 L p F P
0 g
s
.765 .575 .64 r
.37576 .62409 m .38216 .62515 L .37901 .63171 L p F P
0 g
s
.766 .574 .639 r
.38216 .62515 m .37576 .62409 L .37481 .61964 L p F P
0 g
s
.651 .758 .928 r
.82593 .44009 m .83847 .43613 L .84112 .43976 L p F P
0 g
s
.651 .758 .928 r
.83847 .43613 m .82593 .44009 L .82326 .43645 L p F P
0 g
s
.61 .444 .631 r
.40828 .62969 m .41975 .62235 L .40759 .62508 L closepath p F P
0 g
s
.677 .505 .646 r
.40759 .62508 m .40828 .62969 L .40624 .63208 L p F P
0 g
s
.365 .249 .586 r
.43317 .5871 m .42763 .59147 L .42835 .59789 L p F P
0 g
s
.36 .241 .579 r
.42763 .59147 m .43317 .5871 L .43037 .58243 L p F P
0 g
s
.651 .758 .928 r
.64108 .44024 m .65328 .43629 L .65624 .43993 L p F P
0 g
s
.651 .758 .928 r
.65328 .43629 m .64108 .44024 L .6381 .43659 L p F P
0 g
s
.371 .36 .717 r
.52074 .6418 m .52074 .64179 L .52074 .6418 L closepath p F P
0 g
s
.344 .322 .691 r
.52074 .6418 m .52074 .6418 L .52276 .64951 L p F P
0 g
s
.344 .322 .691 r
.52276 .64951 m .52577 .64598 L .52074 .6418 L p F P
0 g
s
.348 .339 .708 r
.52511 .63624 m .52074 .6418 L .52577 .64598 L p F P
0 g
s
.373 .359 .715 r
.51958 .63223 m .52511 .63624 L .52074 .6418 L p F P
0 g
s
.931 .743 .627 r
.26212 .66373 m .26586 .66695 L .2639 .67314 L p F P
0 g
s
.921 .754 .658 r
.26311 .66117 m .26212 .66373 L .26586 .66695 L p F P
0 g
s
.675 .731 .892 r
.36536 .73409 m .36487 .73351 L .36348 .73405 L closepath p F P
0 g
s
.931 .719 .595 r
.35378 .57966 m .35775 .5829 L .35624 .58889 L p F P
0 g
s
.931 .713 .587 r
.35775 .5829 m .35378 .57966 L .35514 .57372 L p F P
0 g
s
.707 .713 .853 r
.34971 .7347 m .35335 .73285 L .36348 .73405 L p F P
0 g
s
.67 .698 .867 r
.36146 .72883 m .35335 .73285 L .36348 .73405 L p F P
0 g
s
.67 .698 .867 r
.36348 .73405 m .36487 .73351 L .36146 .72883 L p F P
0 g
s
.365 .394 .759 r
.51474 .61383 m .51106 .61187 L .50959 .60781 L p F P
0 g
s
.651 .758 .928 r
.84112 .43976 m .85368 .4358 L .8563 .43943 L p F P
0 g
s
.651 .758 .928 r
.85368 .4358 m .84112 .43976 L .83847 .43613 L p F P
0 g
s
.651 .758 .928 r
.65624 .43993 m .66847 .43597 L .6714 .43962 L p F P
0 g
s
.651 .758 .928 r
.66847 .43597 m .65624 .43993 L .65328 .43629 L p F P
0 g
s
.773 .579 .636 r
.37576 .62409 m .37481 .61964 L .37303 .62358 L closepath p F P
0 g
s
.662 .705 .879 r
.43722 .72787 m .43967 .73152 L .42679 .73391 L p F P
0 g
s
.662 .705 .879 r
.42679 .73391 m .4254 .73204 L .43722 .72787 L p F P
0 g
s
.711 .647 .783 r
.39182 .72582 m .38002 .73227 L .37665 .72697 L p F P
0 g
s
.696 .635 .784 r
.40696 .72566 m .39516 .73152 L .39182 .72582 L p F P
0 g
s
.28 .07 .405 r
.5105 .70806 m .51286 .70651 L .51479 .7002 L p F P
0 g
s
.258 .049 .394 r
.52012 .69654 m .51479 .7002 L .51286 .70651 L p F P
0 g
s
.323 .153 .489 r
.51479 .7002 m .52012 .69654 L .52006 .69077 L p F P
0 g
s
.365 .394 .759 r
.50959 .60781 m .51121 .60496 L p .51474 .61383 L F P
0 g
s
.36 .406 .774 r
.50959 .60781 m .50784 .60327 L .51121 .60496 L closepath p F P
0 g
s
.67 .739 .902 r
.33459 .73514 m .34626 .73082 L .34971 .7347 L p F P
0 g
s
.702 .721 .865 r
.34626 .73082 m .33459 .73514 L .33108 .73206 L p F P
0 g
s
.677 .505 .646 r
.39431 .63293 m .40624 .63208 L .39968 .63969 L p F P
0 g
s
.677 .505 .646 r
.39968 .63969 m .39561 .63998 L .39431 .63293 L p F P
0 g
s
.72 .533 .637 r
.38982 .63275 m .39431 .63293 L .39561 .63998 L p F P
0 g
s
.721 .667 .796 r
.37665 .72697 m .36487 .73351 L .36146 .72883 L p F P
0 g
s
.353 .275 .628 r
.526 .66413 m .52337 .6665 L .52713 .6711 L p F P
0 g
s
.374 .307 .653 r
.52337 .6665 m .526 .66413 L .52454 .65698 L p F P
0 g
s
.651 .758 .928 r
.6714 .43962 m .68366 .43566 L .68657 .43931 L p F P
0 g
s
.651 .758 .928 r
.68366 .43566 m .6714 .43962 L .66847 .43597 L p F P
0 g
s
.136 .586 .926 r
.31544 .73145 m .31021 .72879 L .30107 .72693 L p F P
0 g
s
0 .529 .825 r
.31021 .72879 m .30107 .72693 L .29742 .7255 L p F P
0 g
s
.326 .228 .589 r
.43528 .5779 m .43037 .58243 L .43317 .5871 L p F P
0 g
s
.318 .218 .58 r
.43037 .58243 m .43528 .5779 L .43452 .57147 L p F P
0 g
s
.913 .599 .438 r
.27882 .70837 m .27417 .7055 L .27375 .69997 L p F P
0 g
s
.922 .607 .428 r
.2693 .69702 m .27375 .69997 L .27417 .7055 L p F P
0 g
s
.921 .649 .508 r
.27375 .69997 m .2693 .69702 L .26964 .69129 L p F P
0 g
s
.902 .531 .32 r
.27882 .70837 m .27932 .71055 L .27556 .71079 L p F P
0 g
s
.902 .531 .32 r
.27417 .7055 m .27882 .70837 L p .27556 .71079 L F P
0 g
s
.72 .533 .637 r
.39561 .63998 m .38579 .63959 L .38982 .63275 L p F P
0 g
s
.745 .566 .652 r
.37901 .63171 m .38982 .63275 L .38579 .63959 L p F P
0 g
s
.741 .737 .848 r
.35335 .73285 m .34971 .7347 L .34626 .73082 L p F P
0 g
s
.348 .31 .674 r
.52276 .64951 m .52577 .64598 L p .52544 .65599 L F P
0 g
s
.348 .31 .674 r
.52544 .65599 m .52398 .65466 L .52276 .64951 L p F P
0 g
s
.679 .634 .798 r
.42208 .72646 m .41028 .73148 L .40696 .72566 L p F P
0 g
s
.651 .758 .928 r
.68657 .43931 m .69886 .43535 L .70174 .439 L p F P
0 g
s
.651 .758 .928 r
.69886 .43535 m .68657 .43931 L .68366 .43566 L p F P
0 g
s
.651 .758 .928 r
.50163 .43936 m .51358 .43541 L .51678 .43905 L p F P
0 g
s
.361 .406 .773 r
.51121 .60496 m .50784 .60327 L .50597 .59843 L p F P
0 g
s
.765 .575 .64 r
.37901 .63171 m .37735 .63143 L .37576 .62409 L p F P
0 g
s
.774 .58 .636 r
.37303 .62358 m .37576 .62409 L .37735 .63143 L p F P
0 g
s
.931 .66 .503 r
.26541 .68825 m .26964 .69129 L .2693 .69702 L p F P
0 g
s
.925 .687 .559 r
.26964 .69129 m .26541 .68825 L .26638 .68234 L p F P
0 g
s
.192 0 .273 r
.50984 .71135 m .51286 .70651 L .5105 .70806 L closepath p F P
0 g
s
0 0 0 r
.4952 .72313 m .48599 .72778 L .48272 .72811 L p F P
0 g
s
.544 .918 .938 r
.48599 .72778 m .48272 .72811 L p .47123 .7322 L F P
0 g
s
.536 .384 .622 r
.41926 .61564 m .43017 .61113 L p .4205 .62212 L F P
0 g
s
.536 .384 .622 r
.4205 .62212 m .42013 .62211 L .41926 .61564 L p F P
0 g
s
.522 .372 .619 r
.42919 .60443 m .43017 .61113 L .41926 .61564 L p F P
0 g
s
.61 .442 .629 r
.41926 .61564 m .42013 .62211 L .41975 .62235 L p F P
0 g
s
.495 .788 .997 r
.32378 .73318 m .33108 .73206 L p .31597 .73152 L F P
0 g
s
.495 .788 .997 r
.31597 .73152 m .3169 .7321 L .32378 .73318 L p F P
0 g
s
.621 .463 .647 r
.40866 .63189 m .40828 .62969 L .41975 .62235 L p F P
0 g
s
.672 .498 .641 r
.40866 .63189 m .40828 .62969 L .40624 .63208 L closepath p F P
0 g
s
.651 .758 .928 r
.70174 .439 m .71406 .43504 L .71692 .43868 L p F P
0 g
s
.651 .758 .928 r
.71406 .43504 m .70174 .439 L .69886 .43535 L p F P
0 g
s
.651 .758 .928 r
.51678 .43905 m .52875 .4351 L .53193 .43875 L p F P
0 g
s
.651 .758 .928 r
.52875 .4351 m .51678 .43905 L .51358 .43541 L p F P
0 g
s
.348 .355 .726 r
.52351 .62678 m .51958 .63223 L .52511 .63624 L p F P
0 g
s
.371 .371 .73 r
.51756 .62292 m .52351 .62678 L .51958 .63223 L p F P
0 g
s
.765 .256 0 r
.29474 .72345 m .28953 .72077 L .2858 .71619 L p F P
0 g
s
.741 .217 0 r
.28056 .71352 m .2858 .71619 L .28953 .72077 L p F P
0 g
s
.86 .451 .254 r
.2858 .71619 m .28056 .71352 L .27932 .71055 L p F P
0 g
s
.672 .499 .642 r
.40624 .63208 m .40866 .63189 L .4099 .63887 L p F P
0 g
s
.672 .499 .642 r
.4099 .63887 m .39968 .63969 L .40624 .63208 L p F P
0 g
s
.651 .758 .928 r
.71692 .43868 m .72926 .43472 L .7321 .43837 L p F P
0 g
s
.651 .758 .928 r
.72926 .43472 m .71692 .43868 L .71406 .43504 L p F P
0 g
s
.346 .31 .675 r
.52454 .65698 m .52398 .65466 L .52544 .65599 L closepath p F P
0 g
s
.774 .58 .636 r
.36776 .61525 m .36534 .62157 L .37303 .62358 L p F P
0 g
s
.839 .635 .626 r
.36118 .61287 m .36776 .61525 L .36534 .62157 L p F P
0 g
s
.83 .622 .622 r
.36776 .61525 m .36118 .61287 L .36324 .60668 L p F P
0 g
s
.651 .758 .928 r
.53193 .43875 m .54393 .43479 L .54708 .43844 L p F P
0 g
s
.651 .758 .928 r
.54393 .43479 m .53193 .43875 L .52875 .4351 L p F P
0 g
s
.361 .406 .773 r
.50597 .59843 m .50701 .59628 L p .51121 .60496 L F P
0 g
s
.356 .418 .788 r
.50597 .59843 m .50461 .59515 L .50701 .59628 L closepath p F P
0 g
s
.741 .737 .848 r
.34626 .73082 m .34642 .73072 L .35335 .73285 L p F P
0 g
s
.697 .689 .838 r
.35806 .7237 m .34642 .73072 L .35335 .73285 L p F P
0 g
s
.697 .689 .838 r
.35335 .73285 m .36146 .72883 L .35806 .7237 L p F P
0 g
s
.66 .642 .821 r
.43722 .72787 m .4254 .73204 L .42208 .72646 L p F P
0 g
s
.774 .58 .636 r
.37735 .63143 m .37012 .63007 L .37303 .62358 L p F P
0 g
s
.811 .611 .633 r
.36534 .62157 m .37303 .62358 L .37012 .63007 L p F P
0 g
s
.309 .181 .539 r
.52006 .69077 m .52386 .68769 L .52235 .68239 L p F P
0 g
s
.297 .174 .539 r
.52805 .67755 m .52235 .68239 L .52386 .68769 L p F P
0 g
s
.334 .232 .587 r
.52726 .67135 m .52713 .6711 L p .52235 .68239 L F P
0 g
s
.334 .232 .587 r
.52235 .68239 m .52805 .67755 L .52726 .67135 L p F P
0 g
s
.26 .106 .473 r
.52386 .68769 m .52006 .69077 L .52012 .69654 L p F P
0 g
s
.936 .699 .556 r
.26239 .67922 m .26638 .68234 L .26541 .68825 L p F P
0 g
s
.928 .718 .597 r
.26638 .68234 m .26239 .67922 L .2639 .67314 L p F P
0 g
s
.618 .462 .648 r
.4099 .63887 m .40866 .63189 L .4213 .62915 L p F P
0 g
s
.621 .463 .647 r
.42016 .62227 m .4213 .62915 L .40866 .63189 L p F P
0 g
s
.621 .463 .647 r
.41975 .62235 m .42016 .62227 L p .40866 .63189 L F P
0 g
s
.869 .661 .619 r
.35762 .60399 m .36324 .60668 L .36118 .61287 L p F P
0 g
s
.862 .65 .615 r
.36324 .60668 m .35762 .60399 L .35941 .59789 L p F P
0 g
s
.651 .758 .928 r
.7321 .43837 m .74447 .43441 L .74728 .43805 L p F P
0 g
s
.651 .758 .928 r
.74447 .43441 m .7321 .43837 L .72926 .43472 L p F P
0 g
s
.318 .269 .645 r
.52544 .65599 m .52454 .65698 L .526 .66413 L p F P
0 g
s
.651 .758 .928 r
.54708 .43844 m .55911 .43449 L .56224 .43813 L p F P
0 g
s
.651 .758 .928 r
.55911 .43449 m .54708 .43844 L .54393 .43479 L p F P
0 g
s
.745 .566 .652 r
.37791 .63395 m .37901 .63171 L p .38579 .63959 L F P
0 g
s
.765 .576 .642 r
.37791 .63395 m .37901 .63171 L .37735 .63143 L closepath p F P
0 g
s
.677 .506 .647 r
.39628 .6436 m .39968 .63969 L .39561 .63998 L closepath p F P
0 g
s
.698 .52 .643 r
.39561 .63998 m .38579 .63959 L p .39375 .64711 L F P
0 g
s
.698 .52 .643 r
.39375 .64711 m .39628 .6436 L .39561 .63998 L p F P
0 g
s
.356 .418 .788 r
.50701 .59628 m .50461 .59515 L .50191 .58859 L p F P
0 g
s
.651 .758 .928 r
.74728 .43805 m .75969 .43409 L .76247 .43774 L p F P
0 g
s
.651 .758 .928 r
.75969 .43409 m .74728 .43805 L .74447 .43441 L p F P
0 g
s
.899 .689 .611 r
.35465 .59492 m .35941 .59789 L .35762 .60399 L p F P
0 g
s
.895 .682 .606 r
.35941 .59789 m .35465 .59492 L .35624 .58889 L p F P
0 g
s
.432 .301 .601 r
.42835 .59789 m .43618 .59174 L p .43053 .60348 L F P
0 g
s
.432 .301 .601 r
.43053 .60348 m .42881 .60181 L .42835 .59789 L p F P
0 g
s
.365 .249 .586 r
.42835 .59789 m .43618 .59174 L .43317 .5871 L p F P
0 g
s
.651 .758 .928 r
.56224 .43813 m .5743 .43418 L .5774 .43783 L p F P
0 g
s
.651 .758 .928 r
.5743 .43418 m .56224 .43813 L .55911 .43449 L p F P
0 g
s
.867 .453 .238 r
.28056 .71352 m .27556 .71079 L .27932 .71055 L closepath p F P
0 g
s
.755 .57 .646 r
.37735 .63143 m .37012 .63007 L p .37558 .63836 L F P
0 g
s
.755 .57 .646 r
.37558 .63836 m .37791 .63395 L .37735 .63143 L p F P
0 g
s
.556 .9 .978 r
.47082 .73209 m .47698 .73005 L .47123 .7322 L closepath p F P
0 g
s
.544 .918 .938 r
.48272 .72811 m .47698 .73005 L .47123 .7322 L p F P
0 g
s
.348 .371 .743 r
.52104 .61757 m .51756 .62292 L .52351 .62678 L p F P
0 g
s
.368 .383 .744 r
.51474 .61383 m .52104 .61757 L .51756 .62292 L p F P
0 g
s
.689 .524 .658 r
.39968 .63969 m .4099 .63887 L p .39703 .64716 L F P
0 g
s
.689 .524 .658 r
.39703 .64716 m .39628 .6436 L .39968 .63969 L p F P
0 g
s
.651 .758 .928 r
.76247 .43774 m .77491 .43377 L .77766 .43742 L p F P
0 g
s
.651 .758 .928 r
.77491 .43377 m .76247 .43774 L .75969 .43409 L p F P
0 g
s
.644 .732 .913 r
.44052 .73281 m .45236 .72926 L .45566 .73313 L p F P
0 g
s
.642 .674 .865 r
.45181 .72839 m .45236 .72926 L .44052 .73281 L p F P
0 g
s
.642 .674 .865 r
.44052 .73281 m .43967 .73152 L .45181 .72839 L p F P
0 g
s
.188 .625 .944 r
.31597 .73152 m .31544 .73145 L .3169 .7321 L closepath p F P
0 g
s
.651 .758 .928 r
.5774 .43783 m .5895 .43387 L .59257 .43752 L p F P
0 g
s
.651 .758 .928 r
.5895 .43387 m .5774 .43783 L .5743 .43418 L p F P
0 g
s
.698 .52 .643 r
.38579 .63959 m .38173 .64644 L .39375 .64711 L p F P
0 g
s
.745 .566 .653 r
.37903 .63887 m .38579 .63959 L .38173 .64644 L p F P
0 g
s
.745 .566 .652 r
.38579 .63959 m .37903 .63887 L .37791 .63395 L p F P
0 g
s
.938 .73 .595 r
.26014 .66993 m .2639 .67314 L .26239 .67922 L p F P
0 g
s
.931 .743 .627 r
.2639 .67314 m .26014 .66993 L .26212 .66373 L p F P
0 g
s
.759 .575 .648 r
.37903 .63887 m .37791 .63395 L .37558 .63836 L closepath p F P
0 g
s
.651 .758 .928 r
.77766 .43742 m .79013 .43345 L .79286 .4371 L p F P
0 g
s
.651 .758 .928 r
.79013 .43345 m .77766 .43742 L .77491 .43377 L p F P
0 g
s
.696 .635 .784 r
.40536 .72241 m .40696 .72566 L p .39182 .72582 L F P
0 g
s
.696 .635 .784 r
.39182 .72582 m .39734 .72259 L .40536 .72241 L p F P
0 g
s
.7 .643 .79 r
.39182 .72582 m .39734 .72259 L .39019 .72265 L closepath p F P
0 g
s
.711 .647 .783 r
.39019 .72265 m .39182 .72582 L p .37665 .72697 L F P
0 g
s
.479 0 0 r
.29474 .72345 m .29742 .7255 L .29378 .72355 L p F P
0 g
s
.479 0 0 r
.29378 .72355 m .28953 .72077 L .29474 .72345 L p F P
0 g
s
.651 .758 .928 r
.59257 .43752 m .60469 .43356 L .60774 .43721 L p F P
0 g
s
.651 .758 .928 r
.60469 .43356 m .59257 .43752 L .5895 .43387 L p F P
0 g
s
.931 .724 .601 r
.35232 .58564 m .35624 .58889 L .35465 .59492 L p F P
0 g
s
.931 .719 .595 r
.35624 .58889 m .35232 .58564 L .35378 .57966 L p F P
0 g
s
.71 .537 .653 r
.39703 .64716 m .39628 .6436 L .39375 .64711 L closepath p F P
0 g
s
0 0 .119 r
.51286 .70651 m .51969 .70182 L p .50944 .71274 L F P
0 g
s
0 0 .119 r
.50944 .71274 m .50984 .71135 L .51286 .70651 L p F P
0 g
s
.258 .049 .394 r
.51286 .70651 m .51969 .70182 L .52012 .69654 L p F P
0 g
s
.711 .647 .783 r
.37665 .72697 m .38365 .72243 L .39019 .72265 L p F P
0 g
s
.721 .671 .8 r
.37665 .72697 m .38365 .72243 L .37354 .72153 L closepath p F P
0 g
s
.721 .667 .796 r
.37354 .72153 m .37665 .72697 L p .36146 .72883 L F P
0 g
s
.604 .85 .991 r
.47698 .73005 m .47082 .73209 L .46754 .72972 L p F P
0 g
s
.617 .823 .979 r
.45566 .73313 m .46754 .72972 L .47082 .73209 L p F P
0 g
s
.318 .269 .645 r
.526 .66413 m .52929 .66055 L .52544 .65599 L p F P
0 g
s
.316 .279 .657 r
.53031 .65032 m .52544 .65599 L .52929 .66055 L p F P
0 g
s
.348 .31 .674 r
.52577 .64598 m .53031 .65032 L .52544 .65599 L p F P
0 g
s
.617 .454 .639 r
.42016 .62227 m .42013 .62211 L .41975 .62235 L closepath p F P
0 g
s
.651 .758 .928 r
.79286 .4371 m .80535 .43313 L .80806 .43678 L p F P
0 g
s
.651 .758 .928 r
.80535 .43313 m .79286 .4371 L .79013 .43345 L p F P
0 g
s
.536 .398 .64 r
.42016 .62227 m .42013 .62211 L .4205 .62212 L closepath p F P
0 g
s
.633 .736 .922 r
.46754 .72972 m .45566 .73313 L .45236 .72926 L p F P
0 g
s
.537 .401 .643 r
.4213 .62915 m .42016 .62227 L .4205 .62212 L p F P
0 g
s
.651 .758 .928 r
.60774 .43721 m .61989 .43325 L .62292 .4369 L p F P
0 g
s
.651 .758 .928 r
.61989 .43325 m .60774 .43721 L .60469 .43356 L p F P
0 g
s
.679 .634 .798 r
.41937 .72106 m .42208 .72646 L p .40696 .72566 L F P
0 g
s
.679 .634 .798 r
.40696 .72566 m .41578 .72137 L .41937 .72106 L p F P
0 g
s
.676 .625 .791 r
.40696 .72566 m .41578 .72137 L .40536 .72241 L closepath p F P
0 g
s
.348 .388 .761 r
.51776 .60859 m .51474 .61383 L .52104 .61757 L p F P
0 g
s
.365 .394 .759 r
.51121 .60496 m .51776 .60859 L .51474 .61383 L p F P
0 g
s
0 0 0 r
.4952 .72313 m .49753 .72198 L .49791 .72159 L closepath p F P
0 g
s
0 0 0 r
.49753 .72198 m .4952 .72313 L p .48272 .72811 L F P
0 g
s
.356 .418 .788 r
.50191 .58859 m .50223 .58778 L p .50701 .59628 L F P
0 g
s
.351 .43 .803 r
.50191 .58859 m .50139 .5874 L .50223 .58778 L closepath p F P
0 g
s
.646 .678 .866 r
.44907 .72417 m .45181 .72839 L .43967 .73152 L p F P
0 g
s
.646 .678 .866 r
.43967 .73152 m .43722 .72787 L .44907 .72417 L p F P
0 g
s
.339 .689 .981 r
.31544 .73145 m .31597 .73152 L .3124 .72891 L p F P
0 g
s
.339 .689 .981 r
.3124 .72891 m .31021 .72879 L .31544 .73145 L p F P
0 g
s
.537 .401 .643 r
.4205 .62212 m .43187 .62249 L p .4213 .62915 L F P
0 g
s
.538 .393 .632 r
.43187 .62249 m .4205 .62212 L .43117 .61786 L closepath p F P
0 g
s
.536 .384 .622 r
.43017 .61113 m .43117 .61786 L .4205 .62212 L p F P
0 g
s
.292 .232 .617 r
.52929 .66055 m .526 .66413 L .52722 .67103 L p F P
0 g
s
.353 .275 .628 r
.52713 .6711 m .52722 .67103 L .526 .66413 L p F P
0 g
s
.612 .458 .648 r
.4099 .63887 m .42245 .63604 L p .41522 .64493 L F P
0 g
s
.612 .458 .648 r
.41522 .64493 m .41114 .64587 L .4099 .63887 L p F P
0 g
s
.689 .524 .658 r
.4099 .63887 m .41114 .64587 L .39703 .64716 L p F P
0 g
s
.618 .462 .648 r
.4213 .62915 m .42245 .63604 L .4099 .63887 L p F P
0 g
s
.651 .758 .928 r
.80806 .43678 m .82058 .4328 L .82326 .43645 L p F P
0 g
s
.651 .758 .928 r
.82058 .4328 m .80806 .43678 L .80535 .43313 L p F P
0 g
s
.745 .566 .653 r
.38173 .64644 m .38075 .64634 L .37903 .63887 L p F P
0 g
s
.76 .575 .647 r
.37558 .63836 m .37903 .63887 L .38075 .64634 L p F P
0 g
s
.348 .431 .805 r
.50223 .58778 m .50139 .5874 L .49816 .58014 L p F P
0 g
s
.651 .758 .928 r
.62292 .4369 m .6351 .43294 L .6381 .43659 L p F P
0 g
s
.651 .758 .928 r
.6351 .43294 m .62292 .4369 L .61989 .43325 L p F P
0 g
s
.392 .476 .827 r
.49492 .57327 m .49031 .57151 L p .49664 .57953 L F P
0 g
s
.358 .457 .825 r
.49492 .57327 m .49031 .57151 L .49177 .56675 L closepath p F P
0 g
s
.411 .299 .615 r
.42919 .60443 m .42881 .60181 L .43053 .60348 L closepath p F P
0 g
s
.162 .106 .541 r
.43484 .57104 m .43452 .57147 L .43528 .5779 L p F P
0 g
s
.669 .511 .661 r
.39703 .64716 m .41114 .64587 L p .4041 .65393 L F P
0 g
s
.669 .511 .661 r
.4041 .65393 m .39857 .65445 L .39703 .64716 L p F P
0 g
s
.711 .537 .653 r
.39375 .64711 m .39703 .64716 L .39857 .65445 L p F P
0 g
s
.721 .667 .796 r
.36146 .72883 m .37272 .72146 L .37354 .72153 L p F P
0 g
s
.734 .656 .773 r
.37272 .72146 m .36146 .72883 L .35806 .7237 L p F P
0 g
s
.711 .537 .653 r
.39857 .65445 m .38857 .65431 L .39375 .64711 L p F P
0 g
s
.728 .562 .666 r
.38173 .64644 m .39375 .64711 L .38857 .65431 L p F P
0 g
s
.495 .788 .997 r
.33108 .73206 m .32757 .72861 L .31597 .73152 L p F P
0 g
s
.659 .747 .915 r
.32757 .72861 m .31597 .73152 L .3124 .72891 L p F P
0 g
s
.651 .758 .928 r
.82326 .43645 m .83582 .43247 L .83847 .43613 L p F P
0 g
s
.651 .758 .928 r
.83582 .43247 m .82326 .43645 L .82058 .4328 L p F P
0 g
s
.348 .404 .778 r
.51373 .59984 m .51121 .60496 L .51776 .60859 L p F P
0 g
s
.361 .406 .773 r
.50701 .59628 m .51373 .59984 L .51121 .60496 L p F P
0 g
s
0 0 0 r
.49753 .72198 m .49791 .72159 L .50767 .71377 L p F P
0 g
s
.699 .645 .792 r
.39734 .72259 m .39019 .72265 L .38849 .71936 L p F P
0 g
s
.711 .65 .787 r
.39019 .72265 m .38849 .71936 L .38365 .72243 L closepath p F P
0 g
s
.651 .758 .928 r
.6381 .43659 m .65031 .43263 L .65328 .43629 L p F P
0 g
s
.651 .758 .928 r
.65031 .43263 m .6381 .43659 L .6351 .43294 L p F P
0 g
s
.696 .637 .786 r
.40536 .72241 m .40365 .71895 L .39734 .72259 L closepath p F P
0 g
s
.699 .645 .792 r
.40069 .71214 m .40365 .71895 L .39734 .72259 L p F P
0 g
s
.699 .645 .792 r
.3992 .71216 m .40069 .71214 L p .39734 .72259 L F P
0 g
s
.699 .645 .792 r
.38849 .71936 m .3992 .71216 L p .39734 .72259 L F P
0 g
s
.755 .57 .646 r
.37012 .63007 m .36721 .63656 L .37558 .63836 L p F P
0 g
s
.821 .625 .638 r
.36289 .62791 m .37012 .63007 L .36721 .63656 L p F P
0 g
s
.811 .611 .633 r
.37012 .63007 m .36289 .62791 L .36534 .62157 L p F P
0 g
s
.364 .444 .809 r
.49816 .58014 m .49664 .57953 L .49723 .57809 L closepath p F P
0 g
s
.392 .476 .827 r
.49664 .57953 m .49723 .57809 L .49492 .57327 L p F P
0 g
s
.848 .647 .631 r
.35908 .61909 m .36534 .62157 L .36289 .62791 L p F P
0 g
s
.839 .635 .626 r
.36534 .62157 m .35908 .61909 L .36118 .61287 L p F P
0 g
s
.76 .575 .647 r
.38075 .64634 m .37206 .64504 L .37558 .63836 L p F P
0 g
s
.796 .606 .645 r
.36721 .63656 m .37558 .63836 L .37206 .64504 L p F P
0 g
s
.651 .758 .928 r
.83847 .43613 m .85105 .43214 L .85368 .4358 L p F P
0 g
s
.651 .758 .928 r
.85105 .43214 m .83847 .43613 L .83582 .43247 L p F P
0 g
s
.346 .42 .795 r
.50905 .59129 m .50701 .59628 L .51373 .59984 L p F P
0 g
s
.356 .418 .788 r
.50223 .58778 m .50905 .59129 L .50701 .59628 L p F P
0 g
s
.162 .106 .541 r
.43528 .5779 m .43662 .57603 L .43484 .57104 L p F P
0 g
s
0 0 .464 r
.43773 .56566 m .43484 .57104 L .43662 .57603 L p F P
0 g
s
.721 .672 .801 r
.38518 .71221 m .38849 .71936 L .38365 .72243 L p F P
0 g
s
.721 .672 .801 r
.37329 .7211 m .38518 .71221 L p .38365 .72243 L F P
0 g
s
.721 .672 .801 r
.38365 .72243 m .37354 .72153 L .37329 .7211 L p F P
0 g
s
.676 .628 .794 r
.41578 .72137 m .40536 .72241 L .40365 .71895 L p F P
0 g
s
.66 .642 .821 r
.42208 .72646 m .43392 .72187 L .43722 .72787 L p F P
0 g
s
.66 .623 .802 r
.43256 .71893 m .43392 .72187 L .42208 .72646 L p F P
0 g
s
.66 .623 .802 r
.42208 .72646 m .41937 .72106 L .43256 .71893 L p F P
0 g
s
.184 0 .198 r
.50767 .71377 m .50944 .71274 L .50984 .71135 L closepath p F P
0 g
s
.651 .758 .928 r
.65328 .43629 m .66552 .43232 L .66847 .43597 L p F P
0 g
s
.651 .758 .928 r
.66552 .43232 m .65328 .43629 L .65031 .43263 L p F P
0 g
s
.344 .436 .812 r
.50377 .58291 m .50223 .58778 L .50905 .59129 L p F P
0 g
s
.348 .431 .805 r
.49816 .58014 m .50377 .58291 L .50223 .58778 L p F P
0 g
s
.741 .737 .848 r
.34626 .73082 m .34642 .73072 L .3461 .73062 L closepath p F P
0 g
s
.702 .721 .865 r
.3461 .73062 m .34626 .73082 L p .33108 .73206 L F P
0 g
s
.902 .531 .32 r
.27556 .71079 m .27552 .71076 L .27417 .7055 L p F P
0 g
s
.91 .533 .298 r
.26973 .70255 m .27417 .7055 L .27552 .71076 L p F P
0 g
s
.922 .607 .428 r
.27417 .7055 m .26973 .70255 L .2693 .69702 L p F P
0 g
s
.741 .737 .848 r
.35495 .71866 m .35806 .7237 L .34642 .73072 L p F P
0 g
s
.741 .737 .848 r
.35415 .71854 m .35495 .71866 L p .34642 .73072 L F P
0 g
s
.741 .737 .848 r
.34281 .7265 m .35415 .71854 L p .34642 .73072 L F P
0 g
s
.741 .737 .848 r
.34642 .73072 m .3461 .73062 L .34281 .7265 L p F P
0 g
s
.932 .615 .417 r
.26507 .694 m .2693 .69702 L .26973 .70255 L p F P
0 g
s
.931 .66 .503 r
.2693 .69702 m .26507 .694 L .26541 .68825 L p F P
0 g
s
.875 .67 .623 r
.35577 .61012 m .36118 .61287 L .35908 .61909 L p F P
0 g
s
.869 .661 .619 r
.36118 .61287 m .35577 .61012 L .35762 .60399 L p F P
0 g
s
.414 .304 .619 r
.43053 .60348 m .42919 .60443 L .43017 .61113 L p F P
0 g
s
.702 .721 .865 r
.33108 .73206 m .33647 .72946 L .3461 .73062 L p F P
0 g
s
.698 .726 .871 r
.3461 .73062 m .34281 .7265 L .33647 .72946 L closepath p F P
0 g
s
0 0 0 r
.50767 .71377 m .50944 .71274 L p .49753 .72198 L F P
0 g
s
.728 .562 .666 r
.38104 .64759 m .38173 .64644 L p .38857 .65431 L F P
0 g
s
.745 .567 .654 r
.38104 .64759 m .38173 .64644 L .38075 .64634 L closepath p F P
0 g
s
.736 .75 .863 r
.33647 .72946 m .33108 .73206 L .32757 .72861 L p F P
0 g
s
.651 .758 .928 r
.66847 .43597 m .68074 .43201 L .68366 .43566 L p F P
0 g
s
.651 .758 .928 r
.68074 .43201 m .66847 .43597 L .66552 .43232 L p F P
0 g
s
.741 .565 .656 r
.38075 .64634 m .37206 .64504 L p .37746 .65336 L F P
0 g
s
.741 .565 .656 r
.37746 .65336 m .38104 .64759 L .38075 .64634 L p F P
0 g
s
0 0 0 r
.50944 .71274 m .50727 .71636 L .49753 .72198 L p F P
0 g
s
0 0 0 r
.48272 .72811 m .49467 .72328 L .49753 .72198 L p F P
0 g
s
.405 .835 .686 r
.49467 .72328 m .49753 .72198 L .50727 .71636 L p F P
0 g
s
.741 .217 0 r
.28953 .72077 m .28448 .71803 L .28056 .71352 L p F P
0 g
s
.712 .177 0 r
.27556 .71079 m .28056 .71352 L .28448 .71803 L p F P
0 g
s
.942 .671 .496 r
.26141 .68514 m .26541 .68825 L .26507 .694 L p F P
0 g
s
.936 .699 .556 r
.26541 .68825 m .26141 .68514 L .26239 .67922 L p F P
0 g
s
.728 .562 .666 r
.38857 .65431 m .3826 .65395 L .38104 .64759 L p F P
0 g
s
.748 .574 .66 r
.3826 .65395 m .38104 .64759 L .37746 .65336 L closepath p F P
0 g
s
.651 .758 .928 r
.68366 .43566 m .69596 .43169 L .69886 .43535 L p F P
0 g
s
.651 .758 .928 r
.69596 .43169 m .68366 .43566 L .68074 .43201 L p F P
0 g
s
.71 .604 .737 r
.3992 .71216 m .38849 .71936 L .38518 .71221 L p F P
0 g
s
.902 .697 .615 r
.35297 .60099 m .35762 .60399 L .35577 .61012 L p F P
0 g
s
.899 .689 .611 r
.35762 .60399 m .35297 .60099 L .35465 .59492 L p F P
0 g
s
.185 0 .371 r
.52399 .6934 m .52012 .69654 L .51969 .70182 L p F P
0 g
s
.26 .106 .473 r
.52012 .69654 m .52399 .6934 L .52386 .68769 L p F P
0 g
s
.669 .511 .662 r
.3994 .65838 m .4041 .65393 L .39857 .65445 L closepath p F P
0 g
s
.716 .562 .679 r
.39857 .65445 m .3994 .65838 L .39635 .66191 L p F P
0 g
s
.716 .562 .679 r
.38857 .65431 m .39857 .65445 L p .39635 .66191 L F P
0 g
s
.332 .237 .595 r
.4361 .58442 m .43317 .5871 L .43618 .59174 L p F P
0 g
s
.326 .228 .589 r
.43317 .5871 m .4361 .58442 L .43528 .5779 L p F P
0 g
s
.539 .402 .643 r
.42245 .63604 m .4213 .62915 L .43226 .62469 L p F P
0 g
s
.537 .401 .643 r
.43187 .62249 m .43226 .62469 L .4213 .62915 L p F P
0 g
s
.32 .299 .679 r
.52986 .64088 m .52577 .64598 L .53031 .65032 L p F P
0 g
s
.348 .339 .708 r
.52957 .63989 m .52511 .63624 L p .52577 .64598 L F P
0 g
s
.348 .339 .708 r
.52577 .64598 m .52986 .64088 L .52957 .63989 L p F P
0 g
s
.716 .562 .679 r
.38419 .66041 m .38857 .65431 L p .39635 .66191 L F P
0 g
s
.728 .562 .666 r
.38419 .66041 m .38857 .65431 L .3826 .65395 L closepath p F P
0 g
s
.604 .85 .991 r
.48208 .72777 m .47698 .73005 L p .46754 .72972 L F P
0 g
s
.621 .874 .989 r
.47698 .73005 m .48208 .72777 L .48272 .72811 L closepath p F P
0 g
s
.612 .459 .65 r
.41135 .64704 m .41522 .64493 L .41114 .64587 L closepath p F P
0 g
s
.669 .511 .661 r
.41114 .64587 m .41135 .64704 L .4041 .65393 L p F P
0 g
s
.676 .628 .794 r
.40365 .71895 m .4155 .71238 L p .41578 .72137 L F P
0 g
s
.683 .608 .766 r
.41501 .71108 m .4155 .71238 L .40365 .71895 L p F P
0 g
s
.683 .608 .766 r
.40365 .71895 m .40069 .71214 L .41501 .71108 L p F P
0 g
s
.651 .758 .928 r
.69886 .43535 m .71119 .43138 L .71406 .43504 L p F P
0 g
s
.651 .758 .928 r
.71119 .43138 m .69886 .43535 L .69596 .43169 L p F P
0 g
s
.318 .22 .583 r
.52726 .67135 m .52713 .6711 L .52722 .67103 L closepath p F P
0 g
s
.318 .415 .804 r
.50377 .58291 m .49816 .58014 L .49723 .57809 L p F P
0 g
s
.651 .758 .928 r
.51358 .43541 m .52556 .43144 L .52875 .4351 L p F P
0 g
s
.719 .671 .802 r
.37354 .72153 m .37329 .7211 L .37272 .72146 L closepath p F P
0 g
s
.273 .188 .574 r
.52722 .67103 m .53245 .66535 L p .52941 .67616 L F P
0 g
s
.273 .188 .574 r
.52941 .67616 m .52726 .67135 L .52722 .67103 L p F P
0 g
s
.292 .232 .617 r
.52722 .67103 m .53245 .66535 L .52929 .66055 L p F P
0 g
s
.734 .656 .773 r
.35806 .7237 m .36244 .7203 L .37272 .72146 L p F P
0 g
s
.71 .65 .787 r
.36994 .71465 m .36244 .7203 L .37272 .72146 L p F P
0 g
s
.71 .65 .787 r
.37272 .72146 m .37329 .7211 L .36994 .71465 L p F P
0 g
s
.272 .188 .574 r
.52805 .67755 m .52726 .67135 L .52941 .67616 L closepath p F P
0 g
s
.728 .621 .738 r
.38518 .71221 m .37329 .7211 L .36994 .71465 L p F P
0 g
s
.622 .479 .666 r
.41261 .6531 m .41135 .64704 L .41522 .64493 L p F P
0 g
s
.668 .509 .66 r
.41261 .6531 m .41135 .64704 L .4041 .65393 L closepath p F P
0 g
s
.679 .635 .799 r
.41937 .72106 m .41878 .71992 L .41578 .72137 L closepath p F P
0 g
s
.676 .628 .794 r
.4155 .71238 m .41878 .71992 L .41578 .72137 L p F P
0 g
s
.642 .628 .821 r
.44907 .72417 m .43722 .72787 L .43392 .72187 L p F P
0 g
s
.245 .094 .469 r
.52854 .68373 m .52386 .68769 L .52399 .6934 L p F P
0 g
s
.297 .174 .539 r
.52386 .68769 m .52854 .68373 L .52805 .67755 L p F P
0 g
s
.651 .758 .928 r
.71406 .43504 m .72642 .43107 L .72926 .43472 L p F P
0 g
s
.651 .758 .928 r
.72642 .43107 m .71406 .43504 L .71119 .43138 L p F P
0 g
s
.414 .304 .619 r
.43017 .61113 m .43505 .60768 L .43053 .60348 L p F P
0 g
s
.401 .303 .628 r
.43801 .59775 m .43053 .60348 L .43505 .60768 L p F P
0 g
s
.432 .301 .601 r
.43732 .59336 m .43801 .59775 L .43053 .60348 L p F P
0 g
s
.432 .301 .601 r
.43618 .59174 m .43732 .59336 L p .43053 .60348 L F P
0 g
s
.651 .758 .928 r
.52875 .4351 m .54077 .43113 L .54393 .43479 L p F P
0 g
s
.651 .758 .928 r
.54077 .43113 m .52875 .4351 L .52556 .43144 L p F P
0 g
s
.946 .712 .552 r
.25863 .67601 m .26239 .67922 L .26141 .68514 L p F P
0 g
s
.938 .73 .595 r
.26239 .67922 m .25863 .67601 L .26014 .66993 L p F P
0 g
s
0 .529 .825 r
.29742 .7255 m .30508 .7261 L .31021 .72879 L p F P
0 g
s
.236 .674 .957 r
.30508 .7261 m .29742 .7255 L .29378 .72355 L p F P
0 g
s
.728 .562 .666 r
.3826 .65395 m .37746 .65336 L p .38339 .66152 L F P
0 g
s
.728 .562 .666 r
.38339 .66152 m .38419 .66041 L .3826 .65395 L p F P
0 g
s
.681 .53 .674 r
.4041 .65393 m .41261 .6531 L p .40024 .66188 L F P
0 g
s
.681 .53 .674 r
.40024 .66188 m .3994 .65838 L .4041 .65393 L p F P
0 g
s
.703 .544 .669 r
.40024 .66188 m .3994 .65838 L .39635 .66191 L closepath p F P
0 g
s
.318 .415 .804 r
.49723 .57809 m .49799 .5747 L p .50377 .58291 L F P
0 g
s
.313 .428 .819 r
.49723 .57809 m .49492 .57327 L .49799 .5747 L closepath p F P
0 g
s
.931 .728 .606 r
.35075 .59166 m .35465 .59492 L .35297 .60099 L p F P
0 g
s
.931 .724 .601 r
.35465 .59492 m .35075 .59166 L .35232 .58564 L p F P
0 g
s
0 0 0 r
.51863 .70651 m .50944 .71274 L .50727 .71636 L p F P
0 g
s
0 0 .119 r
.51969 .70182 m .51863 .70651 L .50944 .71274 L p F P
0 g
s
.651 .758 .928 r
.72926 .43472 m .74166 .43075 L .74447 .43441 L p F P
0 g
s
.651 .758 .928 r
.74166 .43075 m .72926 .43472 L .72642 .43107 L p F P
0 g
s
.666 .629 .803 r
.43063 .71481 m .43256 .71893 L .41937 .72106 L p F P
0 g
s
.666 .629 .803 r
.41937 .72106 m .41878 .71992 L .43063 .71481 L p F P
0 g
s
.651 .758 .928 r
.54393 .43479 m .55598 .43083 L .55911 .43449 L p F P
0 g
s
.651 .758 .928 r
.55598 .43083 m .54393 .43479 L .54077 .43113 L p F P
0 g
s
.736 .75 .863 r
.32757 .72861 m .33003 .72716 L .33647 .72946 L p F P
0 g
s
.695 .712 .861 r
.33936 .7219 m .33003 .72716 L .33647 .72946 L p F P
0 g
s
.695 .712 .861 r
.33647 .72946 m .34281 .7265 L .33936 .7219 L p F P
0 g
s
.164 .113 .548 r
.43662 .57603 m .43528 .5779 L .4361 .58442 L p F P
0 g
s
.703 .543 .668 r
.39635 .66191 m .40024 .66188 L .40204 .66944 L p F P
0 g
s
.703 .543 .668 r
.40204 .66944 m .3898 .66954 L .39635 .66191 L p F P
0 g
s
.715 .562 .679 r
.38451 .66162 m .39635 .66191 L .3898 .66954 L p F P
0 g
s
.716 .562 .679 r
.39635 .66191 m .38451 .66162 L .38419 .66041 L p F P
0 g
s
.651 .758 .928 r
.74447 .43441 m .7569 .43043 L .75969 .43409 L p F P
0 g
s
.651 .758 .928 r
.7569 .43043 m .74447 .43441 L .74166 .43075 L p F P
0 g
s
.664 .519 .677 r
.40024 .66188 m .41412 .66037 L p .40584 .66901 L F P
0 g
s
.664 .519 .677 r
.40584 .66901 m .40204 .66944 L .40024 .66188 L p F P
0 g
s
.681 .53 .674 r
.41261 .6531 m .41412 .66037 L .40024 .66188 L p F P
0 g
s
.741 .565 .656 r
.37206 .64504 m .36856 .65173 L .37746 .65336 L p F P
0 g
s
.801 .627 .666 r
.36427 .64307 m .37206 .64504 L .36856 .65173 L p F P
0 g
s
.796 .606 .645 r
.37206 .64504 m .36427 .64307 L .36721 .63656 L p F P
0 g
s
.651 .758 .928 r
.55911 .43449 m .57119 .43052 L .5743 .43418 L p F P
0 g
s
.651 .758 .928 r
.57119 .43052 m .55911 .43449 L .55598 .43083 L p F P
0 g
s
.661 .588 .763 r
.43063 .71481 m .41878 .71992 L .4155 .71238 L p F P
0 g
s
.36 0 0 r
.28953 .72077 m .29378 .72355 L .29014 .72121 L p F P
0 g
s
.36 0 0 r
.29014 .72121 m .28448 .71803 L .28953 .72077 L p F P
0 g
s
.823 .641 .656 r
.36039 .63427 m .36721 .63656 L .36427 .64307 L p F P
0 g
s
.821 .625 .638 r
.36721 .63656 m .36039 .63427 L .36289 .62791 L p F P
0 g
s
.728 .562 .666 r
.37746 .65336 m .37322 .66029 L .38339 .66152 L p F P
0 g
s
.781 .617 .677 r
.36856 .65173 m .37746 .65336 L .37322 .66029 L p F P
0 g
s
.622 .479 .666 r
.41522 .64493 m .42371 .64305 L p .41261 .6531 L F P
0 g
s
.619 .471 .66 r
.42371 .64305 m .4232 .64052 L .41522 .64493 L closepath p F P
0 g
s
.612 .458 .648 r
.42245 .63604 m .4232 .64052 L .41522 .64493 L p F P
0 g
s
.737 .575 .672 r
.38451 .66162 m .38419 .66041 L .38339 .66152 L closepath p F P
0 g
s
.416 .306 .621 r
.43505 .60768 m .43017 .61113 L .43117 .61786 L p F P
0 g
s
.752 .694 .796 r
.35806 .7237 m .36244 .7203 L .35495 .71866 L closepath p F P
0 g
s
.702 .619 .762 r
.40069 .71214 m .40035 .71139 L .3992 .71216 L closepath p F P
0 g
s
.71 .604 .737 r
.38518 .71221 m .38542 .71201 L .3992 .71216 L p F P
0 g
s
.69 .594 .744 r
.39708 .70295 m .38542 .71201 L .3992 .71216 L p F P
0 g
s
.69 .594 .744 r
.3992 .71216 m .40035 .71139 L .39708 .70295 L p F P
0 g
s
.651 .758 .928 r
.75969 .43409 m .77214 .43011 L .77491 .43377 L p F P
0 g
s
.651 .758 .928 r
.77214 .43011 m .75969 .43409 L .7569 .43043 L p F P
0 g
s
.715 .562 .679 r
.3898 .66954 m .3866 .66946 L .38451 .66162 L p F P
0 g
s
.737 .575 .672 r
.38339 .66152 m .38451 .66162 L .3866 .66946 L p F P
0 g
s
.697 .617 .764 r
.41223 .70383 m .41501 .71108 L .40069 .71214 L p F P
0 g
s
.697 .617 .764 r
.40069 .71214 m .40035 .71139 L .41223 .70383 L p F P
0 g
s
.848 .659 .647 r
.35691 .62535 m .36289 .62791 L .36039 .63427 L p F P
0 g
s
.848 .647 .631 r
.36289 .62791 m .35691 .62535 L .35908 .61909 L p F P
0 g
s
.651 .758 .928 r
.5743 .43418 m .58641 .43021 L .5895 .43387 L p F P
0 g
s
.651 .758 .928 r
.58641 .43021 m .5743 .43418 L .57119 .43052 L p F P
0 g
s
.737 .575 .672 r
.3866 .66946 m .37819 .66874 L .38339 .66152 L p F P
0 g
s
.765 .596 .668 r
.37322 .66029 m .38339 .66152 L .37819 .66874 L p F P
0 g
s
.614 .473 .666 r
.41261 .6531 m .42513 .65023 L p .42172 .65858 L F P
0 g
s
.614 .473 .666 r
.42172 .65858 m .41412 .66037 L .41261 .6531 L p F P
0 g
s
.622 .479 .666 r
.42371 .64305 m .42513 .65023 L .41261 .6531 L p F P
0 g
s
.325 .323 .704 r
.52957 .63989 m .52511 .63624 L .52758 .63288 L closepath p F P
0 g
s
.348 .355 .726 r
.52633 .62887 m .52351 .62678 L p .52511 .63624 L F P
0 g
s
.348 .355 .726 r
.52511 .63624 m .52758 .63288 L .52633 .62887 L p F P
0 g
s
.716 .617 .746 r
.38518 .71221 m .38542 .71201 L .38509 .712 L closepath p F P
0 g
s
.728 .621 .738 r
.38509 .712 m .38518 .71221 L p .36994 .71465 L F P
0 g
s
.688 .573 .721 r
.41223 .70383 m .40035 .71139 L .39708 .70295 L p F P
0 g
s
.716 .619 .747 r
.39703 .70282 m .39708 .70295 L .38542 .71201 L p F P
0 g
s
.716 .619 .747 r
.38386 .70255 m .39703 .70282 L p .38542 .71201 L F P
0 g
s
.716 .619 .747 r
.38188 .70436 m .38386 .70255 L p .38542 .71201 L F P
0 g
s
.716 .619 .747 r
.38542 .71201 m .38509 .712 L .38188 .70436 L p F P
0 g
s
.728 .621 .738 r
.36994 .71465 m .37386 .71122 L .38509 .712 L p F P
0 g
s
.727 .624 .743 r
.38509 .712 m .38188 .70436 L .37386 .71122 L closepath p F P
0 g
s
.435 .725 .987 r
.31021 .72879 m .3124 .72891 L .30883 .726 L p F P
0 g
s
.435 .725 .987 r
.30883 .726 m .30508 .7261 L .31021 .72879 L p F P
0 g
s
.633 .736 .922 r
.45236 .72926 m .46425 .72598 L .46754 .72972 L p F P
0 g
s
.632 .663 .862 r
.4634 .72469 m .46425 .72598 L .45236 .72926 L p F P
0 g
s
.632 .663 .862 r
.45236 .72926 m .45181 .72839 L .4634 .72469 L p F P
0 g
s
.651 .758 .928 r
.77491 .43377 m .78739 .42979 L .79013 .43345 L p F P
0 g
s
.651 .758 .928 r
.78739 .42979 m .77491 .43377 L .77214 .43011 L p F P
0 g
s
.751 .694 .797 r
.36787 .71037 m .36994 .71465 L .36244 .7203 L p F P
0 g
s
.751 .694 .797 r
.36411 .70989 m .36787 .71037 L p .36244 .7203 L F P
0 g
s
.751 .694 .797 r
.35466 .71819 m .36411 .70989 L p .36244 .7203 L F P
0 g
s
.751 .694 .797 r
.36244 .7203 m .35495 .71866 L .35466 .71819 L p F P
0 g
s
.549 .41 .644 r
.42245 .63604 m .43352 .63169 L p .43113 .64011 L F P
0 g
s
.549 .41 .644 r
.43113 .64011 m .4232 .64052 L .42245 .63604 L p F P
0 g
s
.539 .402 .643 r
.43226 .62469 m .43352 .63169 L .42245 .63604 L p F P
0 g
s
.651 .758 .928 r
.5895 .43387 m .60163 .4299 L .60469 .43356 L p F P
0 g
s
.651 .758 .928 r
.60163 .4299 m .5895 .43387 L .58641 .43021 L p F P
0 g
s
.876 .682 .636 r
.35385 .61629 m .35908 .61909 L .35691 .62535 L p F P
0 g
s
.875 .67 .623 r
.35908 .61909 m .35385 .61629 L .35577 .61012 L p F P
0 g
s
.664 .886 .979 r
.48208 .72777 m .48272 .72811 L .49467 .72328 L p F P
0 g
s
.705 .565 .694 r
.3898 .66954 m .40204 .66944 L p .39666 .67743 L F P
0 g
s
.705 .565 .694 r
.38738 .67237 m .3898 .66954 L p .39666 .67743 L F P
0 g
s
.715 .562 .679 r
.38738 .67237 m .3898 .66954 L .3866 .66946 L closepath p F P
0 g
s
.651 .758 .928 r
.79013 .43345 m .80264 .42947 L .80535 .43313 L p F P
0 g
s
.651 .758 .928 r
.80264 .42947 m .79013 .43345 L .78739 .42979 L p F P
0 g
s
.311 .429 .82 r
.49799 .5747 m .49492 .57327 L .49177 .56675 L p F P
0 g
s
.718 .563 .678 r
.3866 .66946 m .37819 .66874 L p .38337 .67714 L F P
0 g
s
.718 .563 .678 r
.38337 .67714 m .38738 .67237 L .3866 .66946 L p F P
0 g
s
.651 .758 .928 r
.60469 .43356 m .61686 .42959 L .61989 .43325 L p F P
0 g
s
.651 .758 .928 r
.61686 .42959 m .60469 .43356 L .60163 .4299 L p F P
0 g
s
.664 .519 .677 r
.40256 .67164 m .40584 .66901 L .40204 .66944 L closepath p F P
0 g
s
.705 .565 .694 r
.40204 .66944 m .40256 .67164 L .39666 .67743 L p F P
0 g
s
.629 .664 .865 r
.46096 .72102 m .4634 .72469 L .45181 .72839 L p F P
0 g
s
.629 .664 .865 r
.45181 .72839 m .44907 .72417 L .46096 .72102 L p F P
0 g
s
.651 .758 .928 r
.80535 .43313 m .81789 .42914 L .82058 .4328 L p F P
0 g
s
.651 .758 .928 r
.81789 .42914 m .80535 .43313 L .80264 .42947 L p F P
0 g
s
.705 .565 .694 r
.39666 .67743 m .38886 .67747 L .38738 .67237 L p F P
0 g
s
.728 .578 .687 r
.38886 .67747 m .38738 .67237 L .38337 .67714 L closepath p F P
0 g
s
.604 .85 .991 r
.46754 .72972 m .47945 .72622 L .48208 .72777 L p F P
0 g
s
.622 .758 .943 r
.47945 .72622 m .46754 .72972 L .46425 .72598 L p F P
0 g
s
.66 .53 .694 r
.40256 .67164 m .40584 .66901 L p .41745 .67549 L F P
0 g
s
.66 .53 .694 r
.41745 .67549 m .40407 .67723 L .40256 .67164 L p F P
0 g
s
.697 .552 .686 r
.40407 .67723 m .40256 .67164 L .39666 .67743 L closepath p F P
0 g
s
.651 .758 .928 r
.61989 .43325 m .63209 .42928 L .6351 .43294 L p F P
0 g
s
.651 .758 .928 r
.63209 .42928 m .61989 .43325 L .61686 .42959 L p F P
0 g
s
.745 .652 .758 r
.36994 .71465 m .37386 .71122 L .36787 .71037 L closepath p F P
0 g
s
.751 .68 .782 r
.35415 .71854 m .34281 .7265 L .33936 .7219 L p F P
0 g
s
.688 .573 .721 r
.41161 .70199 m .41223 .70383 L p .39708 .70295 L F P
0 g
s
.688 .573 .721 r
.39708 .70295 m .39727 .70281 L .41161 .70199 L p F P
0 g
s
.69 .578 .724 r
.39708 .70295 m .39727 .70281 L .39703 .70282 L closepath p F P
0 g
s
.228 .124 .522 r
.52941 .67616 m .52805 .67755 L .52854 .68373 L p F P
0 g
s
.69 .579 .726 r
.39727 .70281 m .39703 .70282 L .39396 .69405 L p F P
0 g
s
.714 .592 .718 r
.39338 .69403 m .39396 .69405 L .39703 .70282 L p F P
0 g
s
.714 .592 .718 r
.39703 .70282 m .38386 .70255 L .39338 .69403 L p F P
0 g
s
.688 .574 .722 r
.41161 .70199 m .40898 .69425 L .39727 .70281 L closepath p F P
0 g
s
.69 .579 .726 r
.40872 .69338 m .40898 .69425 L .39727 .70281 L p F P
0 g
s
.69 .579 .726 r
.39396 .69405 m .40872 .69338 L p .39727 .70281 L F P
0 g
s
.744 .653 .759 r
.38111 .70239 m .38188 .70436 L .37386 .71122 L p F P
0 g
s
.744 .653 .759 r
.37273 .70163 m .38111 .70239 L p .37386 .71122 L F P
0 g
s
.744 .653 .759 r
.3666 .70777 m .37273 .70163 L p .37386 .71122 L F P
0 g
s
.744 .653 .759 r
.37386 .71122 m .36787 .71037 L .3666 .70777 L p F P
0 g
s
.905 .704 .619 r
.35122 .60709 m .35577 .61012 L .35385 .61629 L p F P
0 g
s
.902 .697 .615 r
.35577 .61012 m .35122 .60709 L .35297 .60099 L p F P
0 g
s
.661 .588 .763 r
.4283 .70902 m .43063 .71481 L p .4155 .71238 L F P
0 g
s
.661 .588 .763 r
.4155 .71238 m .41991 .71027 L .4283 .70902 L p F P
0 g
s
.655 .572 .749 r
.4155 .71238 m .41991 .71027 L .41501 .71108 L closepath p F P
0 g
s
.705 .564 .693 r
.39059 .68345 m .39666 .67743 L .38886 .67747 L closepath p F P
0 g
s
.709 .567 .692 r
.38886 .67747 m .38337 .67714 L p .38855 .68554 L F P
0 g
s
.709 .567 .692 r
.38855 .68554 m .39059 .68345 L .38886 .67747 L p F P
0 g
s
.66 .53 .694 r
.40584 .66901 m .41588 .66789 L p .41745 .67549 L F P
0 g
s
.665 .52 .678 r
.41588 .66789 m .41448 .66209 L .40584 .66901 L closepath p F P
0 g
s
.664 .519 .677 r
.41412 .66037 m .41448 .66209 L .40584 .66901 L p F P
0 g
s
.697 .572 .71 r
.39666 .67743 m .40407 .67723 L p .4037 .68527 L F P
0 g
s
.697 .572 .71 r
.39059 .68345 m .39666 .67743 L p .4037 .68527 L F P
0 g
s
.651 .758 .928 r
.82058 .4328 m .83315 .42881 L .83582 .43247 L p F P
0 g
s
.651 .758 .928 r
.83315 .42881 m .82058 .4328 L .81789 .42914 L p F P
0 g
s
.282 .229 .62 r
.53341 .65584 m .52929 .66055 L .53245 .66535 L p F P
0 g
s
.316 .279 .657 r
.53284 .65331 m .53031 .65032 L p .52929 .66055 L F P
0 g
s
.316 .279 .657 r
.52929 .66055 m .53341 .65584 L .53284 .65331 L p F P
0 g
s
.655 .574 .752 r
.41991 .71027 m .41501 .71108 L .41223 .70383 L p F P
0 g
s
.642 .628 .821 r
.43392 .72187 m .44578 .71801 L .44907 .72417 L p F P
0 g
s
.636 .597 .793 r
.44482 .71588 m .44578 .71801 L .43392 .72187 L p F P
0 g
s
.636 .597 .793 r
.43392 .72187 m .43256 .71893 L .44482 .71588 L p F P
0 g
s
.651 .758 .928 r
.6351 .43294 m .64733 .42897 L .65031 .43263 L p F P
0 g
s
.651 .758 .928 r
.64733 .42897 m .6351 .43294 L .63209 .42928 L p F P
0 g
s
.323 .339 .722 r
.52633 .62887 m .52351 .62678 L .52498 .62456 L closepath p F P
0 g
s
.348 .371 .743 r
.52309 .61896 m .52104 .61757 L p .52351 .62678 L F P
0 g
s
.348 .371 .743 r
.52351 .62678 m .52498 .62456 L .52309 .61896 L p F P
0 g
s
.726 .611 .729 r
.38188 .70436 m .38386 .70255 L .38111 .70239 L closepath p F P
0 g
s
.726 .612 .731 r
.38087 .69351 m .39338 .69403 L .38386 .70255 L p F P
0 g
s
.726 .612 .731 r
.37859 .69591 m .38087 .69351 L p .38386 .70255 L F P
0 g
s
.726 .612 .731 r
.38386 .70255 m .38111 .70239 L .37859 .69591 L p F P
0 g
s
.91 .533 .298 r
.27552 .71076 m .27111 .70781 L .26973 .70255 L p F P
0 g
s
.916 .535 .277 r
.2655 .69952 m .26973 .70255 L .27111 .70781 L p F P
0 g
s
.932 .615 .417 r
.26973 .70255 m .2655 .69952 L .26507 .694 L p F P
0 g
s
.66 .528 .693 r
.40575 .68355 m .41745 .67549 L .40407 .67723 L closepath p F P
0 g
s
.697 .572 .71 r
.40407 .67723 m .40575 .68355 L .4037 .68527 L p F P
0 g
s
.659 .747 .915 r
.3124 .72891 m .32406 .72489 L .32757 .72861 L p F P
0 g
s
.691 .741 .89 r
.32406 .72489 m .3124 .72891 L .30883 .726 L p F P
0 g
s
.614 .473 .667 r
.41448 .66209 m .42172 .65858 L .41412 .66037 L closepath p F P
0 g
s
.635 .86 .984 r
.47945 .72622 m .48208 .72777 L .49232 .72269 L p F P
0 g
s
.664 .886 .979 r
.49467 .72328 m .49232 .72269 L .48208 .72777 L p F P
0 g
s
.697 .572 .71 r
.4037 .68527 m .39129 .68564 L .39059 .68345 L p F P
0 g
s
.72 .585 .703 r
.39129 .68564 m .39059 .68345 L .38855 .68554 L closepath p F P
0 g
s
.697 .57 .709 r
.39382 .69364 m .4037 .68527 L .39129 .68564 L closepath p F P
0 g
s
.702 .573 .707 r
.39129 .68564 m .38855 .68554 L p .39338 .69403 L F P
0 g
s
.702 .573 .707 r
.39338 .69403 m .39382 .69364 L .39129 .68564 L p F P
0 g
s
.551 .426 .663 r
.42371 .64305 m .4232 .64052 L .43113 .64011 L closepath p F P
0 g
s
.708 .591 .722 r
.40625 .68516 m .40872 .69338 L .39396 .69405 L p F P
0 g
s
.708 .591 .722 r
.4037 .68527 m .40625 .68516 L p .39396 .69405 L F P
0 g
s
.708 .591 .722 r
.39396 .69405 m .39382 .69364 L .4037 .68527 L p F P
0 g
s
.713 .593 .72 r
.39396 .69405 m .39382 .69364 L .39338 .69403 L closepath p F P
0 g
s
.702 .573 .707 r
.38855 .68554 m .38087 .69351 L .39338 .69403 L p F P
0 g
s
.718 .563 .678 r
.37819 .66874 m .37309 .67594 L .38337 .67714 L p F P
0 g
s
.763 .611 .689 r
.369 .66721 m .37819 .66874 L .37309 .67594 L p F P
0 g
s
.765 .596 .668 r
.37819 .66874 m .369 .66721 L .37322 .66029 L p F P
0 g
s
.651 .758 .928 r
.83582 .43247 m .84842 .42848 L .85105 .43214 L p F P
0 g
s
.651 .758 .928 r
.84842 .42848 m .83582 .43247 L .83315 .42881 L p F P
0 g
s
.941 .624 .405 r
.26106 .69089 m .26507 .694 L .2655 .69952 L p F P
0 g
s
.942 .671 .496 r
.26507 .694 m .26106 .69089 L .26141 .68514 L p F P
0 g
s
.78 .617 .678 r
.36599 .65871 m .37322 .66029 L .369 .66721 L p F P
0 g
s
.781 .617 .677 r
.36557 .65741 m .36856 .65173 L p .37322 .66029 L F P
0 g
s
.781 .617 .677 r
.37322 .66029 m .36599 .65871 L .36557 .65741 L p F P
0 g
s
.709 .567 .692 r
.38337 .67714 m .37713 .68468 L .38855 .68554 L p F P
0 g
s
.749 .608 .702 r
.37309 .67594 m .38337 .67714 L .37713 .68468 L p F P
0 g
s
.164 .113 .548 r
.4361 .58442 m .43852 .58099 L .43662 .57603 L p F P
0 g
s
0 0 .469 r
.43896 .57082 m .43662 .57603 L .43852 .58099 L p F P
0 g
s
0 0 .464 r
.43662 .57603 m .43896 .57082 L .43773 .56566 L p F P
0 g
s
.736 .617 .726 r
.38111 .70239 m .37859 .69591 L .37273 .70163 L closepath p F P
0 g
s
.736 .609 .715 r
.37713 .68468 m .38855 .68554 L .38087 .69351 L p F P
0 g
s
.167 .119 .555 r
.43852 .58099 m .4361 .58442 L .43698 .591 L p F P
0 g
s
.332 .237 .595 r
.43618 .59174 m .43698 .591 L .4361 .58442 L p F P
0 g
s
.712 .177 0 r
.27553 .71078 m .27556 .71079 L p .28448 .71803 L F P
0 g
s
.872 .443 .183 r
.27553 .71078 m .27552 .71076 L .27556 .71079 L closepath p F P
0 g
s
.651 .758 .928 r
.65031 .43263 m .66257 .42865 L .66552 .43232 L p F P
0 g
s
.651 .758 .928 r
.66257 .42865 m .65031 .43263 L .64733 .42897 L p F P
0 g
s
.867 .425 .131 r
.27552 .71076 m .27553 .71078 L .27181 .70929 L p F P
0 g
s
.867 .425 .131 r
.27181 .70929 m .27111 .70781 L .27552 .71076 L p F P
0 g
s
.712 .177 0 r
.28448 .71803 m .27962 .71522 L .27553 .71078 L p F P
0 g
s
.714 .18 0 r
.27962 .71522 m .27553 .71078 L .27181 .70929 L p F P
0 g
s
.8 .627 .667 r
.36557 .65741 m .36856 .65173 L .36327 .65026 L closepath p F P
0 g
s
.801 .627 .666 r
.36233 .64732 m .36427 .64307 L p .36856 .65173 L F P
0 g
s
.801 .627 .666 r
.36856 .65173 m .36327 .65026 L .36233 .64732 L p F P
0 g
s
.761 .759 .851 r
.33003 .72716 m .32757 .72861 L .32406 .72489 L p F P
0 g
s
.623 .494 .684 r
.41588 .66789 m .41448 .66209 L .42172 .65858 L p F P
0 g
s
.463 .341 .628 r
.43117 .61786 m .43967 .61187 L p .43385 .62366 L F P
0 g
s
.463 .341 .628 r
.43385 .62366 m .43187 .62249 L .43117 .61786 L p F P
0 g
s
.416 .306 .621 r
.43117 .61786 m .43967 .61187 L .43505 .60768 L p F P
0 g
s
.692 .563 .704 r
.40625 .68516 m .40575 .68355 L .4037 .68527 L closepath p F P
0 g
s
.931 .732 .612 r
.34911 .59772 m .35297 .60099 L .35122 .60709 L p F P
0 g
s
.931 .728 .606 r
.35297 .60099 m .34911 .59772 L .35075 .59166 L p F P
0 g
s
.651 .758 .928 r
.66552 .43232 m .67781 .42834 L .68074 .43201 L p F P
0 g
s
.651 .758 .928 r
.67781 .42834 m .66552 .43232 L .66257 .42865 L p F P
0 g
s
.639 .601 .795 r
.4425 .71076 m .44482 .71588 L .43256 .71893 L p F P
0 g
s
.639 .601 .795 r
.43256 .71893 m .43063 .71481 L .4425 .71076 L p F P
0 g
s
.823 .642 .658 r
.36233 .64732 m .36427 .64307 L .36046 .64172 L closepath p F P
0 g
s
.823 .641 .656 r
.35908 .63754 m .36039 .63427 L p .36427 .64307 L F P
0 g
s
.823 .641 .656 r
.36427 .64307 m .36046 .64172 L .35908 .63754 L p F P
0 g
s
.671 .551 .71 r
.40625 .68516 m .40575 .68355 L .41745 .67549 L p F P
0 g
s
.551 .427 .663 r
.42513 .65023 m .42371 .64305 L .43113 .64011 L p F P
0 g
s
.655 .574 .752 r
.41223 .70383 m .41732 .70111 L p .41991 .71027 L F P
0 g
s
.656 .555 .729 r
.41223 .70383 m .41732 .70111 L .41161 .70199 L closepath p F P
0 g
s
.657 .541 .711 r
.40625 .68516 m .41987 .6834 L p .41095 .69306 L F P
0 g
s
.657 .541 .711 r
.41095 .69306 m .40872 .69338 L .40625 .68516 L p F P
0 g
s
.671 .551 .71 r
.41768 .67546 m .41987 .6834 L .40625 .68516 L p F P
0 g
s
.671 .551 .71 r
.41745 .67549 m .41768 .67546 L p .40625 .68516 L F P
0 g
s
.952 .682 .489 r
.25764 .68194 m .26141 .68514 L .26106 .69089 L p F P
0 g
s
.946 .712 .552 r
.26141 .68514 m .25764 .68194 L .25863 .67601 L p F P
0 g
s
.656 .557 .731 r
.41732 .70111 m .41161 .70199 L .40898 .69425 L p F P
0 g
s
.741 .652 .761 r
.36787 .71037 m .3666 .70777 L .36411 .70989 L closepath p F P
0 g
s
.737 .608 .714 r
.37859 .69591 m .38087 .69351 L .37762 .69322 L closepath p F P
0 g
s
.736 .609 .715 r
.37532 .68689 m .37713 .68468 L p .38087 .69351 L F P
0 g
s
.736 .609 .715 r
.38087 .69351 m .37762 .69322 L .37532 .68689 L p F P
0 g
s
.761 .759 .851 r
.32406 .72489 m .32451 .72458 L .33003 .72716 L p F P
0 g
s
.719 .711 .842 r
.3359 .71711 m .32451 .72458 L .33003 .72716 L p F P
0 g
s
.719 .711 .842 r
.33003 .72716 m .33936 .7219 L .3359 .71711 L p F P
0 g
s
.322 .354 .739 r
.52309 .61896 m .52104 .61757 L .52204 .61587 L closepath p F P
0 g
s
.348 .388 .761 r
.51985 .6099 m .51776 .60859 L p .52104 .61757 L F P
0 g
s
.348 .388 .761 r
.52104 .61757 m .52204 .61587 L .51985 .6099 L p F P
0 g
s
.661 .588 .762 r
.4283 .70902 m .42736 .70671 L .41991 .71027 L closepath p F P
0 g
s
.655 .574 .752 r
.425 .70002 m .42736 .70671 L .41991 .71027 L p F P
0 g
s
.655 .574 .752 r
.41732 .70111 m .425 .70002 L p .41991 .71027 L F P
0 g
s
.185 0 .371 r
.51969 .70182 m .5224 .69963 L .52399 .6934 L p F P
0 g
s
.164 0 .36 r
.52861 .68951 m .52399 .6934 L .5224 .69963 L p F P
0 g
s
.245 .094 .469 r
.52399 .6934 m .52861 .68951 L .52854 .68373 L p F P
0 g
s
.651 .758 .928 r
.68074 .43201 m .69306 .42803 L .69596 .43169 L p F P
0 g
s
.651 .758 .928 r
.69306 .42803 m .68074 .43201 L .67781 .42834 L p F P
0 g
s
.063 0 .201 r
.5224 .69963 m .51969 .70182 L .51863 .70651 L p F P
0 g
s
.657 .54 .71 r
.40898 .69425 m .41095 .69306 L .40872 .69338 L closepath p F P
0 g
s
.733 .688 .808 r
.35495 .71866 m .35466 .71819 L .35415 .71854 L closepath p F P
0 g
s
.727 .603 .718 r
.37273 .70163 m .37859 .69591 L .37762 .69322 L p F P
0 g
s
.656 .557 .731 r
.40898 .69425 m .41095 .69306 L p .41732 .70111 L F P
0 g
s
.848 .66 .649 r
.35908 .63754 m .36039 .63427 L .35741 .63295 L closepath p F P
0 g
s
.848 .659 .647 r
.3558 .62847 m .35691 .62535 L p .36039 .63427 L F P
0 g
s
.848 .659 .647 r
.36039 .63427 m .35741 .63295 L .3558 .62847 L p F P
0 g
s
.751 .68 .782 r
.33936 .7219 m .34549 .71689 L .35415 .71854 L p F P
0 g
s
.727 .675 .799 r
.35127 .71236 m .34549 .71689 L .35415 .71854 L p F P
0 g
s
.727 .675 .799 r
.35415 .71854 m .35466 .71819 L .35127 .71236 L p F P
0 g
s
.727 .603 .718 r
.37762 .69322 m .37037 .69239 L p .37273 .70163 L F P
0 g
s
.745 .613 .712 r
.37762 .69322 m .37532 .68689 L .37037 .69239 L closepath p F P
0 g
s
.76 .633 .719 r
.37273 .70163 m .3666 .70777 L .36327 .70052 L p F P
0 g
s
.76 .633 .719 r
.36327 .70052 m .36364 .70009 L .37273 .70163 L p F P
0 g
s
.727 .603 .718 r
.37037 .69239 m .36364 .70009 L .37273 .70163 L p F P
0 g
s
.76 .653 .744 r
.36411 .70989 m .35466 .71819 L .35127 .71236 L p F P
0 g
s
.311 .429 .82 r
.49177 .56675 m .49179 .56662 L p .49799 .5747 L F P
0 g
s
.619 .49 .683 r
.41765 .67535 m .41588 .66789 L .42834 .66497 L p F P
0 g
s
.66 .53 .694 r
.41588 .66789 m .41765 .67535 L .41745 .67549 L p F P
0 g
s
.623 .494 .684 r
.42661 .65747 m .42834 .66497 L .41588 .66789 L p F P
0 g
s
.623 .494 .684 r
.42172 .65858 m .42661 .65747 L p .41588 .66789 L F P
0 g
s
.651 .758 .928 r
.69596 .43169 m .70831 .42771 L .71119 .43138 L p F P
0 g
s
.651 .758 .928 r
.70831 .42771 m .69596 .43169 L .69306 .42803 L p F P
0 g
s
.749 .608 .701 r
.37532 .68689 m .37713 .68468 L .37445 .68435 L closepath p F P
0 g
s
.749 .608 .702 r
.37206 .67739 m .37309 .67594 L p .37713 .68468 L F P
0 g
s
.749 .608 .702 r
.37713 .68468 m .37445 .68435 L .37206 .67739 L p F P
0 g
s
.311 .429 .82 r
.49179 .56662 m .49861 .57007 L .49799 .5747 L p F P
0 g
s
.27 .423 .831 r
.49189 .56213 m .49179 .56662 L .49861 .57007 L p F P
0 g
s
.656 .557 .731 r
.41095 .69306 m .42227 .69154 L p .41732 .70111 L F P
0 g
s
.661 .549 .716 r
.42227 .69154 m .42086 .68707 L .41095 .69306 L closepath p F P
0 g
s
.657 .541 .711 r
.41987 .6834 m .42086 .68707 L .41095 .69306 L p F P
0 g
s
.76 .653 .744 r
.35127 .71236 m .35532 .70826 L .36411 .70989 L p F P
0 g
s
.735 .64 .754 r
.36327 .70052 m .35532 .70826 L .36411 .70989 L p F P
0 g
s
.735 .64 .754 r
.36411 .70989 m .3666 .70777 L .36327 .70052 L p F P
0 g
s
.228 .124 .522 r
.52854 .68373 m .5307 .68153 L .52941 .67616 L p F P
0 g
s
.218 .121 .525 r
.5348 .67039 m .52941 .67616 L .5307 .68153 L p F P
0 g
s
.273 .188 .574 r
.53245 .66535 m .5348 .67039 L .52941 .67616 L p F P
0 g
s
.338 .247 .604 r
.43732 .59336 m .43618 .59174 L .43698 .591 L closepath p F P
0 g
s
.319 .369 .757 r
.51985 .6099 m .51776 .60859 L .5187 .60676 L closepath p F P
0 g
s
.348 .404 .778 r
.51662 .60151 m .51373 .59984 L p .51776 .60859 L F P
0 g
s
.348 .404 .778 r
.51776 .60859 m .5187 .60676 L .51662 .60151 L p F P
0 g
s
.651 .758 .928 r
.71119 .43138 m .72357 .42739 L .72642 .43107 L p F P
0 g
s
.651 .758 .928 r
.72357 .42739 m .71119 .43138 L .70831 .42771 L p F P
0 g
s
.738 .602 .706 r
.37037 .69239 m .37532 .68689 L .37445 .68435 L p F P
0 g
s
.651 .758 .928 r
.52556 .43144 m .5376 .42746 L .54077 .43113 L p F P
0 g
s
.763 .611 .689 r
.37206 .67739 m .37309 .67594 L .3715 .67568 L closepath p F P
0 g
s
.763 .611 .689 r
.36881 .66752 m .369 .66721 L p .37309 .67594 L F P
0 g
s
.763 .611 .689 r
.37309 .67594 m .3715 .67568 L .36881 .66752 L p F P
0 g
s
.633 .571 .766 r
.44065 .70603 m .4425 .71076 L .43063 .71481 L p F P
0 g
s
.633 .571 .766 r
.43063 .71481 m .4283 .70902 L .44065 .70603 L p F P
0 g
s
.875 .683 .64 r
.3558 .62847 m .35691 .62535 L .35375 .6236 L closepath p F P
0 g
s
.876 .682 .636 r
.35248 .62054 m .35385 .61629 L p .35691 .62535 L F P
0 g
s
.876 .682 .636 r
.35691 .62535 m .35375 .6236 L .35248 .62054 L p F P
0 g
s
.738 .602 .706 r
.37445 .68435 m .36735 .68334 L p .37037 .69239 L F P
0 g
s
.755 .611 .699 r
.37445 .68435 m .37206 .67739 L .36735 .68334 L closepath p F P
0 g
s
.621 .624 .832 r
.46096 .72102 m .44907 .72417 L .44578 .71801 L p F P
0 g
s
.318 .415 .804 r
.49799 .5747 m .50493 .57814 L .50377 .58291 L p F P
0 g
s
.319 .447 .833 r
.49861 .57007 m .49799 .5747 L .50493 .57814 L p F P
0 g
s
0 .305 .706 r
.28448 .71803 m .29014 .72121 L .2865 .71859 L p F P
0 g
s
0 .305 .706 r
.2865 .71859 m .27962 .71522 L .28448 .71803 L p F P
0 g
s
.661 .567 .738 r
.425 .70002 m .4241 .69748 L .41732 .70111 L closepath p F P
0 g
s
.656 .557 .731 r
.42227 .69154 m .4241 .69748 L .41732 .70111 L p F P
0 g
s
.651 .758 .928 r
.72642 .43107 m .73883 .42708 L .74166 .43075 L p F P
0 g
s
.651 .758 .928 r
.73883 .42708 m .72642 .43107 L .72357 .42739 L p F P
0 g
s
.45 .346 .645 r
.43226 .62469 m .43187 .62249 L .43385 .62366 L closepath p F P
0 g
s
.316 .385 .775 r
.51662 .60151 m .51373 .59984 L .51489 .59716 L closepath p F P
0 g
s
.346 .42 .795 r
.51338 .59362 m .50905 .59129 L p .51373 .59984 L F P
0 g
s
.346 .42 .795 r
.51373 .59984 m .51489 .59716 L .51338 .59362 L p F P
0 g
s
.651 .758 .928 r
.54077 .43113 m .55283 .42715 L .55598 .43083 L p F P
0 g
s
.651 .758 .928 r
.55283 .42715 m .54077 .43113 L .5376 .42746 L p F P
0 g
s
.75 .603 .695 r
.36735 .68334 m .37206 .67739 L .3715 .67568 L p F P
0 g
s
.75 .603 .695 r
.3715 .67568 m .36401 .67438 L p .36735 .68334 L F P
0 g
s
.766 .612 .688 r
.3715 .67568 m .36881 .66752 L .36401 .67438 L closepath p F P
0 g
s
.344 .436 .812 r
.51015 .58612 m .50377 .58291 L p .50905 .59129 L F P
0 g
s
.292 .402 .803 r
.50377 .58291 m .51015 .58612 L .50691 .5792 L p F P
0 g
s
.292 .402 .803 r
.50691 .5792 m .50493 .57814 L .50377 .58291 L p F P
0 g
s
.78 .617 .678 r
.36881 .66752 m .369 .66721 L .36869 .66715 L closepath p F P
0 g
s
.78 .617 .678 r
.369 .66721 m .36869 .66715 L .36599 .65871 L p F P
0 g
s
.293 .263 .653 r
.53284 .65331 m .53031 .65032 L .53178 .64851 L closepath p F P
0 g
s
.32 .299 .679 r
.53031 .65032 m .53178 .64851 L .52986 .64088 L p F P
0 g
s
.311 .4 .792 r
.51338 .59362 m .50905 .59129 L .51054 .58697 L closepath p F P
0 g
s
.344 .436 .812 r
.50905 .59129 m .51054 .58697 L .51015 .58612 L p F P
0 g
s
.763 .608 .686 r
.36401 .67438 m .36881 .66752 L .36869 .66715 L p F P
0 g
s
.763 .608 .686 r
.36869 .66715 m .36059 .66544 L p .36401 .67438 L F P
0 g
s
.779 .616 .678 r
.3649 .65848 m .36599 .65871 L .36869 .66715 L p F P
0 g
s
.779 .616 .678 r
.36869 .66715 m .36059 .66544 L .3649 .65848 L p F P
0 g
s
.778 .615 .679 r
.36599 .65871 m .36557 .65741 L .3649 .65848 L closepath p F P
0 g
s
.778 .616 .679 r
.3649 .65848 m .36557 .65741 L .36327 .65026 L p F P
0 g
s
.792 .623 .671 r
.36327 .65026 m .36233 .64732 L .36101 .64969 L closepath p F P
0 g
s
.797 .63 .674 r
.36101 .64969 m .36233 .64732 L .36046 .64172 L p F P
0 g
s
.778 .616 .679 r
.36327 .65026 m .36101 .64969 L p .3649 .65848 L F P
0 g
s
.56 .432 .663 r
.42513 .65023 m .43628 .64596 L p .43094 .65581 L F P
0 g
s
.56 .432 .663 r
.43094 .65581 m .42634 .65632 L .42513 .65023 L p F P
0 g
s
.551 .427 .663 r
.435 .63988 m .43628 .64596 L .42513 .65023 L p F P
0 g
s
.551 .427 .663 r
.43113 .64011 m .435 .63988 L p .42513 .65023 L F P
0 g
s
.614 .473 .666 r
.42513 .65023 m .42634 .65632 L .42172 .65858 L p F P
0 g
s
.77 .649 .728 r
.36164 .69073 m .37037 .69239 L .36364 .70009 L p F P
0 g
s
.738 .602 .706 r
.36735 .68334 m .36164 .69073 L .37037 .69239 L p F P
0 g
s
.501 .746 .983 r
.30508 .7261 m .30883 .726 L .30526 .72286 L p F P
0 g
s
.501 .746 .983 r
.30526 .72286 m .29998 .72338 L .30508 .7261 L p F P
0 g
s
.236 .674 .957 r
.29378 .72355 m .29998 .72338 L .30508 .7261 L p F P
0 g
s
.663 .534 .697 r
.41768 .67546 m .41765 .67535 L .41745 .67549 L closepath p F P
0 g
s
.651 .758 .928 r
.74166 .43075 m .75409 .42676 L .7569 .43043 L p F P
0 g
s
.651 .758 .928 r
.75409 .42676 m .74166 .43075 L .73883 .42708 L p F P
0 g
s
.626 .512 .703 r
.41768 .67546 m .41765 .67535 L .42952 .6701 L p F P
0 g
s
.619 .49 .683 r
.42834 .66497 m .42952 .6701 L .41765 .67535 L p F P
0 g
s
.625 .51 .703 r
.41987 .6834 m .41768 .67546 L .43018 .67257 L p F P
0 g
s
.626 .512 .703 r
.42952 .6701 m .43018 .67257 L .41768 .67546 L p F P
0 g
s
.797 .63 .674 r
.36046 .64172 m .35744 .64079 L p .36101 .64969 L F P
0 g
s
.809 .634 .665 r
.36046 .64172 m .35908 .63754 L .35744 .64079 L closepath p F P
0 g
s
.621 .488 .679 r
.42661 .65747 m .42634 .65632 L .42172 .65858 L closepath p F P
0 g
s
.651 .758 .928 r
.55598 .43083 m .56807 .42684 L .57119 .43052 L p F P
0 g
s
.651 .758 .928 r
.56807 .42684 m .55598 .43083 L .55283 .42715 L p F P
0 g
s
.399 .737 .992 r
.29998 .72338 m .29378 .72355 L .29014 .72121 L p F P
0 g
s
.82 .648 .67 r
.35744 .64079 m .35908 .63754 L .35741 .63295 L p F P
0 g
s
.809 .643 .676 r
.35725 .65647 m .3649 .65848 L .36059 .66544 L p F P
0 g
s
.778 .616 .679 r
.36101 .64969 m .35725 .65647 L .3649 .65848 L p F P
0 g
s
.291 .214 .594 r
.43698 .591 m .44052 .58595 L p .43914 .59641 L F P
0 g
s
.291 .214 .594 r
.43914 .59641 m .43732 .59336 L .43698 .591 L p F P
0 g
s
.167 .119 .555 r
.43698 .591 m .44052 .58595 L .43852 .58099 L p F P
0 g
s
.904 .706 .624 r
.35385 .61629 m .35248 .62054 L .34909 .61421 L p F P
0 g
s
.904 .706 .624 r
.34909 .61421 m .3494 .61323 L .35385 .61629 L p F P
0 g
s
.905 .704 .619 r
.35385 .61629 m .3494 .61323 L .35122 .60709 L p F P
0 g
s
0 0 .26 r
.43802 .56107 m .43773 .56566 L .43896 .57082 L p F P
0 g
s
.451 .348 .647 r
.43385 .62366 m .43226 .62469 L .43352 .63169 L p F P
0 g
s
.165 .035 .446 r
.5307 .68153 m .52854 .68373 L .52861 .68951 L p F P
0 g
s
.636 .575 .769 r
.43923 .70244 m .44065 .70603 L .4283 .70902 L p F P
0 g
s
.636 .575 .769 r
.4283 .70902 m .42736 .70671 L .43923 .70244 L p F P
0 g
s
.651 .758 .928 r
.7569 .43043 m .76936 .42644 L .77214 .43011 L p F P
0 g
s
.651 .758 .928 r
.76936 .42644 m .7569 .43043 L .75409 .42676 L p F P
0 g
s
.651 .758 .928 r
.57119 .43052 m .58332 .42653 L .58641 .43021 L p F P
0 g
s
.651 .758 .928 r
.58332 .42653 m .57119 .43052 L .56807 .42684 L p F P
0 g
s
.288 .316 .716 r
.52498 .62456 m .5265 .62158 L p .52873 .63088 L F P
0 g
s
.288 .316 .716 r
.52873 .63088 m .52633 .62887 L .52498 .62456 L p F P
0 g
s
.284 .33 .734 r
.52498 .62456 m .52309 .61896 L .5265 .62158 L closepath p F P
0 g
s
.403 .305 .63 r
.43912 .60458 m .43505 .60768 L .43967 .61187 L p F P
0 g
s
.401 .303 .628 r
.43505 .60768 m .43912 .60458 L .43801 .59775 L p F P
0 g
s
.405 .835 .686 r
.50727 .71636 m .50664 .71691 L .49467 .72328 L p F P
0 g
s
.698 .947 .957 r
.49232 .72269 m .49467 .72328 L .50664 .71691 L p F P
0 g
s
.82 .648 .67 r
.35741 .63295 m .35427 .63176 L p .35744 .64079 L F P
0 g
s
.829 .651 .662 r
.35741 .63295 m .3558 .62847 L .35427 .63176 L closepath p F P
0 g
s
.287 .315 .717 r
.52758 .63288 m .52633 .62887 L .52873 .63088 L closepath p F P
0 g
s
.291 .301 .699 r
.52758 .63288 m .52873 .63088 L p .53016 .64042 L F P
0 g
s
.291 .301 .699 r
.53016 .64042 m .52957 .63989 L .52758 .63288 L p F P
0 g
s
.285 .33 .734 r
.5265 .62158 m .52309 .61896 L .52204 .61587 L p F P
0 g
s
.63 .547 .743 r
.43738 .69704 m .43923 .70244 L .42736 .70671 L p F P
0 g
s
.63 .547 .743 r
.42736 .70671 m .425 .70002 L .43738 .69704 L p F P
0 g
s
.777 .702 .781 r
.34549 .71689 m .33936 .7219 L .3359 .71711 L p F P
0 g
s
.827 .655 .67 r
.35411 .64743 m .36101 .64969 L .35725 .65647 L p F P
0 g
s
.797 .63 .674 r
.35744 .64079 m .35411 .64743 L .36101 .64969 L p F P
0 g
s
.62 .506 .702 r
.42086 .68707 m .41987 .6834 L .43225 .68041 L p F P
0 g
s
.625 .51 .703 r
.43018 .67257 m .43225 .68041 L .41987 .6834 L p F P
0 g
s
.651 .758 .928 r
.77214 .43011 m .78464 .42612 L .78739 .42979 L p F P
0 g
s
.651 .758 .928 r
.78464 .42612 m .77214 .43011 L .76936 .42644 L p F P
0 g
s
.285 .33 .734 r
.52204 .61587 m .52351 .6125 L p .5265 .62158 L F P
0 g
s
.282 .346 .752 r
.52204 .61587 m .51985 .6099 L .52351 .6125 L closepath p F P
0 g
s
.651 .758 .928 r
.58641 .43021 m .59857 .42622 L .60163 .4299 L p F P
0 g
s
.651 .758 .928 r
.59857 .42622 m .58641 .43021 L .58332 .42653 L p F P
0 g
s
.784 .652 .717 r
.35913 .68152 m .36735 .68334 L .36164 .69073 L p F P
0 g
s
.75 .603 .695 r
.36401 .67438 m .35913 .68152 L .36735 .68334 L p F P
0 g
s
.846 .674 .668 r
.35427 .63176 m .3558 .62847 L .35375 .6236 L p F P
0 g
s
.77 .649 .728 r
.36327 .70052 m .36364 .70009 L .36303 .69996 L closepath p F P
0 g
s
.77 .649 .728 r
.35994 .69296 m .36164 .69073 L p .36364 .70009 L F P
0 g
s
.77 .649 .728 r
.36364 .70009 m .36303 .69996 L .35994 .69296 L p F P
0 g
s
.26 .202 .6 r
.43801 .59775 m .43732 .59336 L .43914 .59641 L closepath p F P
0 g
s
.748 .639 .739 r
.35532 .70826 m .36327 .70052 L .36303 .69996 L p F P
0 g
s
.628 .53 .723 r
.42227 .69154 m .42086 .68707 L .43273 .68224 L p F P
0 g
s
.62 .506 .702 r
.43225 .68041 m .43273 .68224 L .42086 .68707 L p F P
0 g
s
.632 .551 .745 r
.43597 .69296 m .43738 .69704 L .425 .70002 L p F P
0 g
s
.632 .551 .745 r
.425 .70002 m .4241 .69748 L .43597 .69296 L p F P
0 g
s
.777 .702 .781 r
.3359 .71711 m .33845 .71474 L .34549 .71689 L p F P
0 g
s
.745 .677 .785 r
.34788 .70636 m .33845 .71474 L .34549 .71689 L p F P
0 g
s
.745 .677 .785 r
.34549 .71689 m .35127 .71236 L .34788 .70636 L p F P
0 g
s
.651 .758 .928 r
.78739 .42979 m .79991 .42579 L .80264 .42947 L p F P
0 g
s
.651 .758 .928 r
.79991 .42579 m .78739 .42979 L .78464 .42612 L p F P
0 g
s
.289 .301 .699 r
.52986 .64088 m .52957 .63989 L .53016 .64042 L closepath p F P
0 g
s
.625 .526 .721 r
.4241 .69748 m .42227 .69154 L .43465 .68857 L p F P
0 g
s
.628 .53 .723 r
.43273 .68224 m .43465 .68857 L .42227 .69154 L p F P
0 g
s
.622 .758 .943 r
.46425 .72598 m .47617 .72287 L .47945 .72622 L p F P
0 g
s
.62 .665 .872 r
.47426 .72022 m .47617 .72287 L .46425 .72598 L p F P
0 g
s
.62 .665 .872 r
.46425 .72598 m .4634 .72469 L .47426 .72022 L p F P
0 g
s
.748 .639 .739 r
.36303 .69996 m .35489 .69844 L p .35532 .70826 L F P
0 g
s
.763 .646 .732 r
.36303 .69996 m .35994 .69296 L .35489 .69844 L closepath p F P
0 g
s
.651 .758 .928 r
.60163 .4299 m .61382 .42591 L .61686 .42959 L p F P
0 g
s
.651 .758 .928 r
.61382 .42591 m .60163 .4299 L .59857 .42622 L p F P
0 g
s
.252 .254 .667 r
.53016 .64042 m .52986 .64088 L .53178 .64851 L p F P
0 g
s
.931 .736 .618 r
.34739 .60382 m .35122 .60709 L .3494 .61323 L p F P
0 g
s
.931 .732 .612 r
.35122 .60709 m .34739 .60382 L .34911 .59772 L p F P
0 g
s
.625 .526 .721 r
.43465 .68857 m .43597 .69296 L .4241 .69748 L p F P
0 g
s
.845 .67 .665 r
.35125 .6383 m .35744 .64079 L .35411 .64743 L p F P
0 g
s
.82 .648 .67 r
.35427 .63176 m .35125 .6383 L .35744 .64079 L p F P
0 g
s
.786 .676 .743 r
.35532 .70826 m .35127 .71236 L .34788 .70636 L p F P
0 g
s
.786 .676 .743 r
.34788 .70636 m .34802 .70619 L .35532 .70826 L p F P
0 g
s
.748 .639 .739 r
.35489 .69844 m .34802 .70619 L .35532 .70826 L p F P
0 g
s
.282 .346 .751 r
.52351 .6125 m .51985 .6099 L .5187 .60676 L p F P
0 g
s
.563 .451 .684 r
.42661 .65747 m .42634 .65632 L .43094 .65581 L closepath p F P
0 g
s
.651 .758 .928 r
.80264 .42947 m .81519 .42546 L .81789 .42914 L p F P
0 g
s
.651 .758 .928 r
.81519 .42546 m .80264 .42947 L .79991 .42579 L p F P
0 g
s
.801 .659 .706 r
.35638 .67237 m .36401 .67438 L .35913 .68152 L p F P
0 g
s
.763 .608 .686 r
.36059 .66544 m .35638 .67237 L .36401 .67438 L p F P
0 g
s
.651 .758 .928 r
.61686 .42959 m .62907 .4256 L .63209 .42928 L p F P
0 g
s
.651 .758 .928 r
.62907 .4256 m .61686 .42959 L .61382 .42591 L p F P
0 g
s
.563 .451 .683 r
.42834 .66497 m .42661 .65747 L .43094 .65581 L p F P
0 g
s
.063 0 .201 r
.51863 .70651 m .51865 .70649 L .5224 .69963 L p F P
0 g
s
0 0 .084 r
.52817 .69478 m .5224 .69963 L .51865 .70649 L p F P
0 g
s
.164 0 .36 r
.5224 .69963 m .52817 .69478 L .52861 .68951 L p F P
0 g
s
.451 .348 .647 r
.43352 .63169 m .44026 .62734 L .43385 .62366 L p F P
0 g
s
.447 .35 .652 r
.44155 .61849 m .43385 .62366 L .44026 .62734 L p F P
0 g
s
.463 .341 .628 r
.44043 .61253 m .44155 .61849 L .43385 .62366 L p F P
0 g
s
.463 .341 .628 r
.43967 .61187 m .44043 .61253 L p .43385 .62366 L F P
0 g
s
.282 .346 .751 r
.5187 .60676 m .51983 .60362 L p .52351 .6125 L F P
0 g
s
.279 .361 .769 r
.5187 .60676 m .51662 .60151 L .51983 .60362 L closepath p F P
0 g
s
.846 .674 .668 r
.35375 .6236 m .35159 .62258 L p .35427 .63176 L F P
0 g
s
.852 .674 .661 r
.35375 .6236 m .35248 .62054 L .35159 .62258 L closepath p F P
0 g
s
.916 .535 .277 r
.27111 .70781 m .2669 .70478 L .2655 .69952 L p F P
0 g
s
.921 .537 .255 r
.2615 .69642 m .2655 .69952 L .2669 .70478 L p F P
0 g
s
.941 .624 .405 r
.2655 .69952 m .2615 .69642 L .26106 .69089 L p F P
0 g
s
.252 .254 .667 r
.53178 .64851 m .53407 .64496 L .53016 .64042 L p F P
0 g
s
.241 .255 .674 r
.53314 .63526 m .53016 .64042 L .53407 .64496 L p F P
0 g
s
.291 .301 .699 r
.52873 .63088 m .53314 .63526 L .53016 .64042 L p F P
0 g
s
0 0 0 r
.50664 .71691 m .50934 .71497 L .50727 .71636 L closepath p F P
0 g
s
0 0 0 r
.51862 .70652 m .51863 .70651 L p .50727 .71636 L F P
0 g
s
0 0 0 r
.50727 .71636 m .50934 .71497 L .51862 .70652 L p F P
0 g
s
.651 .758 .928 r
.81789 .42914 m .83048 .42514 L .83315 .42881 L p F P
0 g
s
.651 .758 .928 r
.83048 .42514 m .81789 .42914 L .81519 .42546 L p F P
0 g
s
.635 .86 .984 r
.49232 .72269 m .49141 .72233 L .47945 .72622 L p F P
0 g
s
.612 .803 .973 r
.49141 .72233 m .47945 .72622 L .47617 .72287 L p F P
0 g
s
.651 .758 .928 r
.63209 .42928 m .64434 .42529 L .64733 .42897 L p F P
0 g
s
.651 .758 .928 r
.64434 .42529 m .63209 .42928 L .62907 .4256 L p F P
0 g
s
.621 .624 .832 r
.44578 .71801 m .45767 .71499 L .46096 .72102 L p F P
0 g
s
.614 .58 .792 r
.45632 .71203 m .45767 .71499 L .44578 .71801 L p F P
0 g
s
.614 .58 .792 r
.44578 .71801 m .44482 .71588 L .45632 .71203 L p F P
0 g
s
.86 .408 .083 r
.27111 .70781 m .27181 .70929 L .26811 .70721 L p F P
0 g
s
.86 .408 .083 r
.26811 .70721 m .2669 .70478 L .27111 .70781 L p F P
0 g
s
.615 .665 .875 r
.47289 .71833 m .47426 .72022 L .4634 .72469 L p F P
0 g
s
.615 .665 .875 r
.4634 .72469 m .46096 .72102 L .47289 .71833 L p F P
0 g
s
.951 .632 .392 r
.25729 .68769 m .26106 .69089 L .2615 .69642 L p F P
0 g
s
.952 .682 .489 r
.26106 .69089 m .25729 .68769 L .25764 .68194 L p F P
0 g
s
.762 .763 .853 r
.32406 .72489 m .32451 .72458 L .32319 .72393 L closepath p F P
0 g
s
.691 .741 .89 r
.32319 .72393 m .32406 .72489 L p .30883 .726 L F P
0 g
s
.865 .69 .662 r
.34878 .62905 m .35427 .63176 L .35125 .6383 L p F P
0 g
s
.846 .674 .668 r
.35159 .62258 m .34878 .62905 L .35427 .63176 L p F P
0 g
s
.763 .762 .852 r
.33258 .71242 m .3359 .71711 L .32451 .72458 L p F P
0 g
s
.763 .762 .852 r
.33227 .71234 m .33258 .71242 L p .32451 .72458 L F P
0 g
s
.763 .762 .852 r
.32054 .72098 m .33227 .71234 L p .32451 .72458 L F P
0 g
s
.763 .762 .852 r
.32451 .72458 m .32319 .72393 L .32054 .72098 L p F P
0 g
s
.651 .758 .928 r
.83315 .42881 m .84577 .4248 L .84842 .42848 L p F P
0 g
s
.651 .758 .928 r
.84577 .4248 m .83315 .42881 L .83048 .42514 L p F P
0 g
s
.451 .348 .646 r
.43478 .63871 m .43352 .63169 L .44026 .62734 L p F P
0 g
s
.549 .41 .644 r
.43352 .63169 m .43478 .63871 L .43113 .64011 L p F P
0 g
s
.818 .668 .696 r
.35356 .66324 m .36059 .66544 L .35638 .67237 L p F P
0 g
s
.809 .643 .676 r
.36059 .66544 m .35356 .66324 L .35725 .65647 L p F P
0 g
s
.551 .418 .652 r
.435 .63988 m .43113 .64011 L .43478 .63871 L closepath p F P
0 g
s
.691 .741 .89 r
.30883 .726 m .3161 .72285 L .32319 .72393 L p F P
0 g
s
.719 .763 .887 r
.3161 .72285 m .30883 .726 L .30526 .72286 L p F P
0 g
s
.785 .652 .716 r
.35994 .69296 m .36164 .69073 L .35866 .68998 L closepath p F P
0 g
s
.784 .652 .717 r
.35661 .68524 m .35913 .68152 L p .36164 .69073 L F P
0 g
s
.784 .652 .717 r
.36164 .69073 m .35866 .68998 L .35661 .68524 L p F P
0 g
s
.876 .706 .668 r
.35159 .62258 m .35248 .62054 L .34909 .61421 L p F P
0 g
s
0 0 .47 r
.44037 .57595 m .43852 .58099 L .44052 .58595 L p F P
0 g
s
0 0 .469 r
.43852 .58099 m .44037 .57595 L .43896 .57082 L p F P
0 g
s
.252 .235 .645 r
.53178 .64851 m .53407 .64496 L p .53406 .65492 L F P
0 g
s
.252 .235 .645 r
.53406 .65492 m .53284 .65331 L .53178 .64851 L p F P
0 g
s
.651 .758 .928 r
.64733 .42897 m .6596 .42497 L .66257 .42865 L p F P
0 g
s
.651 .758 .928 r
.6596 .42497 m .64733 .42897 L .64434 .42529 L p F P
0 g
s
.247 .179 .58 r
.53468 .66281 m .53245 .66535 L .5348 .67039 L p F P
0 g
s
.282 .229 .62 r
.53245 .66535 m .53468 .66281 L .53341 .65584 L p F P
0 g
s
.26 .204 .602 r
.43914 .59641 m .43801 .59775 L .43912 .60458 L p F P
0 g
s
.612 .582 .796 r
.45439 .7079 m .45632 .71203 L .44482 .71588 L p F P
0 g
s
.612 .582 .796 r
.44482 .71588 m .4425 .71076 L .45439 .7079 L p F P
0 g
s
.278 .361 .769 r
.51983 .60362 m .51662 .60151 L .51489 .59716 L p F P
0 g
s
.651 .758 .928 r
.66257 .42865 m .67487 .42466 L .67781 .42834 L p F P
0 g
s
.651 .758 .928 r
.67487 .42466 m .66257 .42865 L .6596 .42497 L p F P
0 g
s
.76 .642 .73 r
.35489 .69844 m .35994 .69296 L .35866 .68998 L p F P
0 g
s
.567 .452 .682 r
.42952 .6701 m .42834 .66497 L .43958 .6608 L p F P
0 g
s
.563 .451 .683 r
.43817 .65498 m .43958 .6608 L .42834 .66497 L p F P
0 g
s
.563 .451 .683 r
.43094 .65581 m .43817 .65498 L p .42834 .66497 L F P
0 g
s
.838 .669 .674 r
.35082 .65407 m .35725 .65647 L .35356 .66324 L p F P
0 g
s
.827 .655 .67 r
.35725 .65647 m .35082 .65407 L .35411 .64743 L p F P
0 g
s
.651 .758 .928 r
.67781 .42834 m .69014 .42434 L .69306 .42803 L p F P
0 g
s
.651 .758 .928 r
.69014 .42434 m .67781 .42834 L .67487 .42466 L p F P
0 g
s
.686 .744 .895 r
.32319 .72393 m .32054 .72098 L .3161 .72285 L closepath p F P
0 g
s
.887 .715 .662 r
.34682 .61962 m .35159 .62258 L .34878 .62905 L p F P
0 g
s
.876 .706 .668 r
.34909 .61421 m .34682 .61962 L .35159 .62258 L p F P
0 g
s
.278 .361 .769 r
.51489 .59716 m .51553 .59492 L p .51983 .60362 L F P
0 g
s
.276 .376 .786 r
.51489 .59716 m .51338 .59362 L .51553 .59492 L closepath p F P
0 g
s
.793 .689 .75 r
.34751 .69638 m .35489 .69844 L .34802 .70619 L p F P
0 g
s
.76 .642 .73 r
.35359 .68887 m .34751 .69638 L .35489 .69844 L p F P
0 g
s
.76 .642 .73 r
.35866 .68998 m .35359 .68887 L p .35489 .69844 L F P
0 g
s
.251 .234 .645 r
.53341 .65584 m .53284 .65331 L .53406 .65492 L closepath p F P
0 g
s
.264 .301 .713 r
.53133 .62581 m .52873 .63088 L .53314 .63526 L p F P
0 g
s
.288 .316 .716 r
.5265 .62158 m .53133 .62581 L .52873 .63088 L p F P
0 g
s
.774 .648 .723 r
.35866 .68998 m .35661 .68524 L .35359 .68887 L closepath p F P
0 g
s
.165 .035 .446 r
.52861 .68951 m .53082 .68726 L .5307 .68153 L p F P
0 g
s
.151 .026 .443 r
.53618 .67575 m .5307 .68153 L .53082 .68726 L p F P
0 g
s
.218 .121 .525 r
.5307 .68153 m .53618 .67575 L .5348 .67039 L p F P
0 g
s
.801 .659 .706 r
.35661 .68524 m .35913 .68152 L .35439 .68008 L closepath p F P
0 g
s
.801 .659 .706 r
.35328 .6775 m .35638 .67237 L p .35913 .68152 L F P
0 g
s
.801 .659 .706 r
.35913 .68152 m .35439 .68008 L .35328 .6775 L p F P
0 g
s
.651 .758 .928 r
.69306 .42803 m .70542 .42403 L .70831 .42771 L p F P
0 g
s
.651 .758 .928 r
.70542 .42403 m .69306 .42803 L .69014 .42434 L p F P
0 g
s
0 .396 .815 r
.27962 .71522 m .2865 .71859 L .28362 .71636 L p F P
0 g
s
.714 .18 0 r
.27181 .70929 m .27497 .71234 L .27962 .71522 L p F P
0 g
s
0 .396 .815 r
.27497 .71234 m .27962 .71522 L p .28362 .71636 L F P
0 g
s
.636 .086 0 r
.27497 .71234 m .27181 .70929 L .26811 .70721 L p F P
0 g
s
0 0 0 r
.50934 .71497 m .50664 .71691 L .50341 .7175 L p F P
0 g
s
.698 .947 .957 r
.50664 .71691 m .50341 .7175 L p .49232 .72269 L F P
0 g
s
.854 .682 .668 r
.34827 .64484 m .35411 .64743 L .35082 .65407 L p F P
0 g
s
.845 .67 .665 r
.35411 .64743 m .34827 .64484 L .35125 .6383 L p F P
0 g
s
.574 .475 .704 r
.43018 .67257 m .42952 .6701 L .44137 .66829 L p F P
0 g
s
.567 .452 .682 r
.43958 .6608 m .44137 .66829 L .42952 .6701 L p F P
0 g
s
.651 .758 .928 r
.70831 .42771 m .7207 .42371 L .72357 .42739 L p F P
0 g
s
.651 .758 .928 r
.7207 .42371 m .70831 .42771 L .70542 .42403 L p F P
0 g
s
0 0 0 r
.50934 .71497 m .51633 .70998 L .51862 .70652 L closepath p F P
0 g
s
0 0 0 r
.51633 .70998 m .50934 .71497 L p .50341 .7175 L F P
0 g
s
.207 .177 .603 r
.53406 .65492 m .53341 .65584 L .53468 .66281 L p F P
0 g
s
0 0 .004 r
.51862 .70652 m .51865 .70649 L .51863 .70651 L closepath p F P
0 g
s
0 0 0 r
.51865 .70649 m .52602 .70023 L p .51633 .70998 L F P
0 g
s
0 0 0 r
.51633 .70998 m .51862 .70652 L .51865 .70649 L p F P
0 g
s
0 0 .084 r
.52745 .69801 m .52817 .69478 L p .51865 .70649 L F P
0 g
s
0 0 .084 r
.51865 .70649 m .52602 .70023 L .52745 .69801 L p F P
0 g
s
.548 .759 .975 r
.29998 .72338 m .30526 .72286 L .30168 .71959 L p F P
0 g
s
.548 .759 .975 r
.30168 .71959 m .29474 .72069 L .29998 .72338 L p F P
0 g
s
.399 .737 .992 r
.29014 .72121 m .29474 .72069 L .29998 .72338 L p F P
0 g
s
.562 .439 .67 r
.43817 .65498 m .43094 .65581 L .4378 .65326 L closepath p F P
0 g
s
.56 .432 .663 r
.43628 .64596 m .4378 .65326 L .43094 .65581 L p F P
0 g
s
.603 .55 .767 r
.45206 .70208 m .45439 .7079 L .4425 .71076 L p F P
0 g
s
.603 .55 .767 r
.4425 .71076 m .44065 .70603 L .45206 .70208 L p F P
0 g
s
.07 0 .327 r
.53082 .68726 m .52861 .68951 L .52817 .69478 L p F P
0 g
s
.274 .376 .786 r
.51553 .59492 m .51338 .59362 L .51054 .58697 L p F P
0 g
s
.574 .473 .702 r
.43225 .68041 m .43018 .67257 L .4414 .66839 L p F P
0 g
s
.574 .475 .704 r
.44137 .66829 m .4414 .66839 L .43018 .67257 L p F P
0 g
s
.789 .726 .794 r
.3359 .71711 m .33845 .71474 L .33258 .71242 L closepath p F P
0 g
s
.789 .726 .793 r
.34774 .7061 m .34788 .70636 L .33845 .71474 L p F P
0 g
s
.789 .726 .793 r
.34032 .70423 m .34774 .7061 L p .33845 .71474 L F P
0 g
s
.789 .726 .793 r
.33244 .71222 m .34032 .70423 L p .33845 .71474 L F P
0 g
s
.789 .726 .793 r
.33845 .71474 m .33258 .71242 L .33244 .71222 L p F P
0 g
s
.488 .375 .651 r
.43478 .63871 m .44436 .63281 L p .44214 .64245 L F P
0 g
s
.488 .375 .651 r
.44214 .64245 m .435 .63988 L .43478 .63871 L p F P
0 g
s
.451 .348 .646 r
.44359 .62922 m .44436 .63281 L .43478 .63871 L p F P
0 g
s
.451 .348 .646 r
.44026 .62734 m .44359 .62922 L p .43478 .63871 L F P
0 g
s
.651 .758 .928 r
.72357 .42739 m .73599 .42339 L .73883 .42708 L p F P
0 g
s
.651 .758 .928 r
.73599 .42339 m .72357 .42739 L .7207 .42371 L p F P
0 g
s
.651 .758 .928 r
.5376 .42746 m .54968 .42347 L .55283 .42715 L p F P
0 g
s
.26 .204 .602 r
.43912 .60458 m .44201 .60113 L .43914 .59641 L p F P
0 g
s
.099 .095 .564 r
.44261 .5909 m .43914 .59641 L .44201 .60113 L p F P
0 g
s
.291 .214 .594 r
.44052 .58595 m .44261 .5909 L .43914 .59641 L p F P
0 g
s
.793 .689 .75 r
.34788 .70636 m .34802 .70619 L .34774 .7061 L closepath p F P
0 g
s
.793 .689 .75 r
.34448 .70021 m .34751 .69638 L p .34802 .70619 L F P
0 g
s
.793 .689 .75 r
.34802 .70619 m .34774 .7061 L .34448 .70021 L p F P
0 g
s
.774 .648 .723 r
.35359 .68887 m .35661 .68524 L .35439 .68008 L p F P
0 g
s
.818 .668 .697 r
.35328 .6775 m .35638 .67237 L .35 .67006 L closepath p F P
0 g
s
.818 .668 .696 r
.34994 .66992 m .35356 .66324 L p .35638 .67237 L F P
0 g
s
.818 .668 .696 r
.35638 .67237 m .35 .67006 L .34994 .66992 L p F P
0 g
s
.929 .739 .624 r
.34909 .61421 m .3494 .61323 L .34605 .61037 L closepath p F P
0 g
s
.931 .736 .618 r
.34563 .60982 m .34739 .60382 L p .3494 .61323 L F P
0 g
s
.931 .736 .618 r
.3494 .61323 m .34605 .61037 L .34563 .60982 L p F P
0 g
s
.771 .682 .765 r
.34774 .7061 m .34448 .70021 L .34032 .70423 L closepath p F P
0 g
s
.266 .322 .734 r
.5287 .6166 m .5265 .62158 L .53133 .62581 L p F P
0 g
s
.285 .33 .734 r
.52351 .6125 m .5287 .6166 L .5265 .62158 L p F P
0 g
s
.48 .385 .67 r
.43628 .64596 m .435 .63988 L .44214 .64245 L closepath p F P
0 g
s
.602 .631 .852 r
.47289 .71833 m .46096 .72102 L .45767 .71499 L p F P
0 g
s
.603 .552 .77 r
.45112 .69976 m .45206 .70208 L .44065 .70603 L p F P
0 g
s
.603 .552 .77 r
.44065 .70603 m .43923 .70244 L .45112 .69976 L p F P
0 g
s
.651 .758 .928 r
.73883 .42708 m .75128 .42307 L .75409 .42676 L p F P
0 g
s
.651 .758 .928 r
.75128 .42307 m .73883 .42708 L .73599 .42339 L p F P
0 g
s
0 0 .36 r
.43901 .56632 m .43896 .57082 L .44037 .57595 L p F P
0 g
s
0 0 .26 r
.43896 .57082 m .43901 .56632 L .43802 .56107 L p F P
0 g
s
.651 .758 .928 r
.55283 .42715 m .56494 .42316 L .56807 .42684 L p F P
0 g
s
.651 .758 .928 r
.56494 .42316 m .55283 .42715 L .54968 .42347 L p F P
0 g
s
.26 .205 .604 r
.44201 .60113 m .43912 .60458 L .44025 .61144 L p F P
0 g
s
.403 .305 .63 r
.43967 .61187 m .44025 .61144 L .43912 .60458 L p F P
0 g
s
.719 .763 .887 r
.30526 .72286 m .31004 .72041 L .3161 .72285 L p F P
0 g
s
.686 .739 .892 r
.31702 .71697 m .31004 .72041 L .3161 .72285 L p F P
0 g
s
.686 .739 .892 r
.3161 .72285 m .32054 .72098 L .31702 .71697 L p F P
0 g
s
.873 .699 .664 r
.346 .63552 m .35125 .6383 L .34827 .64484 L p F P
0 g
s
.865 .69 .662 r
.35125 .6383 m .346 .63552 L .34878 .62905 L p F P
0 g
s
.909 .748 .669 r
.34682 .61962 m .34909 .61421 L .34605 .61037 L p F P
0 g
s
.634 .906 .983 r
.49141 .72233 m .49648 .72035 L .49232 .72269 L closepath p F P
0 g
s
.698 .947 .957 r
.50341 .7175 m .49648 .72035 L .49232 .72269 L p F P
0 g
s
.813 .687 .725 r
.34639 .68674 m .35359 .68887 L .34751 .69638 L p F P
0 g
s
.774 .648 .723 r
.35183 .67942 m .34639 .68674 L .35359 .68887 L p F P
0 g
s
.774 .648 .723 r
.35439 .68008 m .35183 .67942 L p .35359 .68887 L F P
0 g
s
.27 .423 .831 r
.49861 .57007 m .49887 .56554 L .49189 .56213 L p F P
0 g
s
.293 .463 .858 r
.49156 .55776 m .49189 .56213 L .49887 .56554 L p F P
0 g
s
.651 .758 .928 r
.75409 .42676 m .76658 .42275 L .76936 .42644 L p F P
0 g
s
.651 .758 .928 r
.76658 .42275 m .75409 .42676 L .75128 .42307 L p F P
0 g
s
.578 .476 .701 r
.43273 .68224 m .43225 .68041 L .4436 .67636 L p F P
0 g
s
.574 .473 .702 r
.4414 .66839 m .4436 .67636 L .43225 .68041 L p F P
0 g
s
.651 .758 .928 r
.56807 .42684 m .58021 .42284 L .58332 .42653 L p F P
0 g
s
.651 .758 .928 r
.58021 .42284 m .56807 .42684 L .56494 .42316 L p F P
0 g
s
.594 .522 .743 r
.44876 .69304 m .45112 .69976 L .43923 .70244 L p F P
0 g
s
.594 .522 .743 r
.43923 .70244 m .43738 .69704 L .44876 .69304 L p F P
0 g
s
.207 .177 .603 r
.53468 .66281 m .53678 .65985 L .53406 .65492 L p F P
0 g
s
.195 .176 .608 r
.53746 .64968 m .53406 .65492 L .53678 .65985 L p F P
0 g
s
.252 .235 .645 r
.53407 .64496 m .53746 .64968 L .53406 .65492 L p F P
0 g
s
.585 .499 .724 r
.43465 .68857 m .43273 .68224 L .4446 .68005 L p F P
0 g
s
.578 .476 .701 r
.4436 .67636 m .4446 .68005 L .43273 .68224 L p F P
0 g
s
.497 .763 .99 r
.29474 .72069 m .29014 .72121 L .2865 .71859 L p F P
0 g
s
.651 .758 .928 r
.76936 .42644 m .78188 .42243 L .78464 .42612 L p F P
0 g
s
.651 .758 .928 r
.78188 .42243 m .76936 .42644 L .76658 .42275 L p F P
0 g
s
.837 .67 .675 r
.35356 .66324 m .34994 .66992 L .34658 .66266 L p F P
0 g
s
.837 .67 .675 r
.34658 .66266 m .34754 .66072 L .35356 .66324 L p F P
0 g
s
.838 .669 .674 r
.35356 .66324 m .34754 .66072 L .35082 .65407 L p F P
0 g
s
.594 .525 .746 r
.44785 .6905 m .44876 .69304 L .43738 .69704 L p F P
0 g
s
.594 .525 .746 r
.43738 .69704 m .43597 .69296 L .44785 .6905 L p F P
0 g
s
.586 .498 .721 r
.43597 .69296 m .43465 .68857 L .44601 .68454 L p F P
0 g
s
.585 .499 .724 r
.4446 .68005 m .44601 .68454 L .43465 .68857 L p F P
0 g
s
.267 .342 .755 r
.52531 .60761 m .52351 .6125 L .5287 .6166 L p F P
0 g
s
.282 .346 .751 r
.51983 .60362 m .52531 .60761 L .52351 .6125 L p F P
0 g
s
.651 .758 .928 r
.58332 .42653 m .59549 .42253 L .59857 .42622 L p F P
0 g
s
.651 .758 .928 r
.59549 .42253 m .58332 .42653 L .58021 .42284 L p F P
0 g
s
.786 .653 .715 r
.35439 .68008 m .35328 .6775 L .35183 .67942 L closepath p F P
0 g
s
.586 .498 .721 r
.44601 .68454 m .44785 .6905 L .43597 .69296 L p F P
0 g
s
.319 .447 .833 r
.50366 .57259 m .49861 .57007 L p .50493 .57814 L F P
0 g
s
.257 .411 .825 r
.49861 .57007 m .50366 .57259 L .50041 .56634 L p F P
0 g
s
.257 .411 .825 r
.50041 .56634 m .49887 .56554 L .49861 .57007 L p F P
0 g
s
.274 .376 .786 r
.51054 .58697 m .51065 .5864 L p .51553 .59492 L F P
0 g
s
.272 .392 .802 r
.51054 .58697 m .51015 .58612 L .51065 .5864 L closepath p F P
0 g
s
.651 .758 .928 r
.78464 .42612 m .79718 .4221 L .79991 .42579 L p F P
0 g
s
.651 .758 .928 r
.79718 .4221 m .78464 .42612 L .78188 .42243 L p F P
0 g
s
.651 .758 .928 r
.59857 .42622 m .61076 .42222 L .61382 .42591 L p F P
0 g
s
.651 .758 .928 r
.61076 .42222 m .59857 .42622 L .59549 .42253 L p F P
0 g
s
.479 .383 .669 r
.4378 .65326 m .43628 .64596 L .44214 .64245 L p F P
0 g
s
.892 .721 .662 r
.34415 .62605 m .34878 .62905 L .346 .63552 L p F P
0 g
s
.887 .715 .662 r
.34878 .62905 m .34415 .62605 L .34682 .61962 L p F P
0 g
s
.264 .392 .806 r
.51065 .5864 m .51015 .58612 L .50691 .5792 L p F P
0 g
s
.161 .118 .557 r
.53678 .65985 m .53468 .66281 L .53563 .66946 L p F P
0 g
s
.247 .179 .58 r
.5348 .67039 m .53563 .66946 L .53468 .66281 L p F P
0 g
s
.789 .657 .717 r
.35183 .67942 m .35328 .6775 L .35 .67006 L p F P
0 g
s
.267 .362 .776 r
.52121 .59883 m .51983 .60362 L .52531 .60761 L p F P
0 g
s
.278 .361 .769 r
.51553 .59492 m .52121 .59883 L .51983 .60362 L p F P
0 g
s
.651 .758 .928 r
.79991 .42579 m .81249 .42178 L .81519 .42546 L p F P
0 g
s
.651 .758 .928 r
.81249 .42178 m .79991 .42579 L .79718 .4221 L p F P
0 g
s
.277 .404 .811 r
.50691 .5792 m .50493 .57814 L .50533 .57586 L closepath p F P
0 g
s
.319 .447 .833 r
.50493 .57814 m .50533 .57586 L .50366 .57259 L p F P
0 g
s
.651 .758 .928 r
.61382 .42591 m .62605 .42191 L .62907 .4256 L p F P
0 g
s
.651 .758 .928 r
.62605 .42191 m .61382 .42591 L .61076 .42222 L p F P
0 g
s
.768 .714 .802 r
.33227 .71234 m .32054 .72098 L .31702 .71697 L p F P
0 g
s
.921 .537 .255 r
.2669 .70478 m .26291 .70167 L .2615 .69642 L p F P
0 g
s
.925 .54 .233 r
.25772 .69323 m .2615 .69642 L .26291 .70167 L p F P
0 g
s
.951 .632 .392 r
.2615 .69642 m .25772 .69323 L .25729 .68769 L p F P
0 g
s
.406 .31 .634 r
.44043 .61253 m .43967 .61187 L .44025 .61144 L closepath p F P
0 g
s
.813 .687 .724 r
.34751 .69638 m .34448 .70021 L .34107 .69412 L p F P
0 g
s
.813 .687 .724 r
.34107 .69412 m .34115 .69401 L .34751 .69638 L p F P
0 g
s
.813 .687 .725 r
.34751 .69638 m .34115 .69401 L .34639 .68674 L p F P
0 g
s
.267 .382 .795 r
.51648 .59024 m .51553 .59492 L .52121 .59883 L p F P
0 g
s
.274 .376 .786 r
.51065 .5864 m .51648 .59024 L .51553 .59492 L p F P
0 g
s
.612 .803 .973 r
.47617 .72287 m .48815 .71968 L .49141 .72233 L p F P
0 g
s
.607 .681 .894 r
.48487 .7158 m .48815 .71968 L .47617 .72287 L p F P
0 g
s
.607 .681 .894 r
.48008 .71681 m .48487 .7158 L p .47617 .72287 L F P
0 g
s
.607 .681 .894 r
.47617 .72287 m .47426 .72022 L .48008 .71681 L p F P
0 g
s
.857 .695 .681 r
.34529 .65139 m .35082 .65407 L .34754 .66072 L p F P
0 g
s
.854 .682 .668 r
.35082 .65407 m .34529 .65139 L .34827 .64484 L p F P
0 g
s
.82 .686 .715 r
.34493 .67719 m .35183 .67942 L .34639 .68674 L p F P
0 g
s
.789 .657 .717 r
.34987 .67002 m .34493 .67719 L .35183 .67942 L p F P
0 g
s
.789 .657 .717 r
.35 .67006 m .34987 .67002 L p .35183 .67942 L F P
0 g
s
.749 .488 0 r
.43728 .5584 m .43802 .56107 L .43901 .56632 L p F P
0 g
s
.852 .393 .038 r
.2669 .70478 m .26811 .70721 L .26442 .70463 L p F P
0 g
s
.852 .393 .038 r
.26442 .70463 m .26291 .70167 L .2669 .70478 L p F P
0 g
s
.223 .361 .793 r
.51118 .58183 m .51065 .5864 L .51648 .59024 L p F P
0 g
s
.264 .392 .806 r
.50691 .5792 m .51118 .58183 L .51065 .5864 L p F P
0 g
s
.651 .758 .928 r
.81519 .42546 m .8278 .42145 L .83048 .42514 L p F P
0 g
s
.651 .758 .928 r
.8278 .42145 m .81519 .42546 L .81249 .42178 L p F P
0 g
s
.602 .868 .993 r
.49648 .72035 m .49141 .72233 L .48815 .71968 L p F P
0 g
s
.651 .758 .928 r
.62907 .4256 m .64133 .42159 L .64434 .42529 L p F P
0 g
s
.651 .758 .928 r
.64133 .42159 m .62907 .4256 L .62605 .42191 L p F P
0 g
s
.651 .758 .928 r
.83048 .42514 m .84311 .42111 L .84577 .4248 L p F P
0 g
s
.651 .758 .928 r
.84311 .42111 m .83048 .42514 L .8278 .42145 L p F P
0 g
s
.352 .273 .626 r
.44025 .61144 m .44491 .60586 L p .44369 .61627 L F P
0 g
s
.352 .273 .626 r
.44369 .61627 m .44043 .61253 L .44025 .61144 L p F P
0 g
s
.26 .205 .604 r
.44025 .61144 m .44491 .60586 L .44201 .60113 L p F P
0 g
s
.74 .774 .88 r
.31004 .72041 m .30526 .72286 L .30168 .71959 L p F P
0 g
s
.651 .758 .928 r
.64434 .42529 m .65662 .42128 L .6596 .42497 L p F P
0 g
s
.651 .758 .928 r
.65662 .42128 m .64434 .42529 L .64133 .42159 L p F P
0 g
s
.772 .684 .766 r
.34032 .70423 m .34448 .70021 L .34107 .69412 L p F P
0 g
s
0 .008 .538 r
.44192 .58106 m .44052 .58595 L .44261 .5909 L p F P
0 g
s
0 0 .47 r
.44052 .58595 m .44192 .58106 L .44037 .57595 L p F P
0 g
s
.797 .699 .757 r
.34032 .70423 m .33244 .71222 L .32898 .70726 L p F P
0 g
s
.797 .699 .757 r
.32898 .70726 m .33376 .70192 L .34032 .70423 L p F P
0 g
s
.772 .684 .766 r
.34107 .69412 m .33376 .70192 L .34032 .70423 L p F P
0 g
s
.198 .11 .523 r
.53563 .66946 m .5348 .67039 L .53618 .67575 L p F P
0 g
s
.328 .268 .636 r
.44155 .61849 m .44043 .61253 L .44369 .61627 L closepath p F P
0 g
s
.914 .751 .664 r
.34289 .61639 m .34682 .61962 L .34415 .62605 L p F P
0 g
s
.909 .748 .669 r
.34557 .60997 m .34289 .61639 L .34682 .61962 L p F P
0 g
s
.909 .748 .669 r
.34605 .61037 m .34557 .60997 L p .34682 .61962 L F P
0 g
s
.07 0 .327 r
.52817 .69478 m .52951 .69342 L .53082 .68726 L p F P
0 g
s
.034 0 .303 r
.53629 .68153 m .53082 .68726 L .52951 .69342 L p F P
0 g
s
.151 .026 .443 r
.53622 .67743 m .53618 .67575 L p .53082 .68726 L F P
0 g
s
.151 .026 .443 r
.53082 .68726 m .53629 .68153 L .53622 .67743 L p F P
0 g
s
.22 .225 .652 r
.53714 .63978 m .53407 .64496 L .53746 .64968 L p F P
0 g
s
.241 .255 .674 r
.53407 .64496 m .53714 .63978 L .53314 .63526 L p F P
0 g
s
.602 .631 .852 r
.45767 .71499 m .46961 .7127 L .47289 .71833 L p F P
0 g
s
.588 .572 .803 r
.46691 .70725 m .46961 .7127 L .45767 .71499 L p F P
0 g
s
.588 .572 .803 r
.45767 .71499 m .45632 .71203 L .46691 .70725 L p F P
0 g
s
.651 .758 .928 r
.6596 .42497 m .67192 .42097 L .67487 .42466 L p F P
0 g
s
.651 .758 .928 r
.67192 .42097 m .6596 .42497 L .65662 .42128 L p F P
0 g
s
.879 .708 .666 r
.34323 .64199 m .34827 .64484 L .34529 .65139 L p F P
0 g
s
.873 .699 .664 r
.34827 .64484 m .34323 .64199 L .346 .63552 L p F P
0 g
s
.509 .404 .67 r
.4378 .65326 m .44764 .64762 L p .44673 .65677 L F P
0 g
s
.509 .404 .67 r
.44673 .65677 m .43817 .65498 L .4378 .65326 L p F P
0 g
s
.479 .383 .669 r
.44678 .6441 m .44764 .64762 L .4378 .65326 L p F P
0 g
s
.479 .383 .669 r
.44214 .64245 m .44678 .6441 L p .4378 .65326 L F P
0 g
s
.748 .716 .822 r
.33258 .71242 m .33244 .71222 L .33227 .71234 L closepath p F P
0 g
s
.799 .661 .71 r
.35 .67006 m .34994 .66992 L .34987 .67002 L closepath p F P
0 g
s
0 .396 .815 r
.28362 .71636 m .28274 .71574 L .27497 .71234 L p F P
0 g
s
.636 .086 0 r
.26811 .70721 m .27056 .70937 L .27497 .71234 L p F P
0 g
s
0 .434 .849 r
.27056 .70937 m .27497 .71234 L .28274 .71574 L p F P
0 g
s
.768 .714 .802 r
.31702 .71697 m .32527 .71017 L .33227 .71234 L p F P
0 g
s
.747 .714 .821 r
.32898 .70726 m .32527 .71017 L .33227 .71234 L p F P
0 g
s
.747 .714 .821 r
.33227 .71234 m .33244 .71222 L .32898 .70726 L p F P
0 g
s
.805 .669 .713 r
.34987 .67002 m .34994 .66992 L .34658 .66266 L p F P
0 g
s
.651 .758 .928 r
.67487 .42466 m .68722 .42065 L .69014 .42434 L p F P
0 g
s
.651 .758 .928 r
.68722 .42065 m .67487 .42466 L .67192 .42097 L p F P
0 g
s
.83 .69 .709 r
.34337 .66765 m .34987 .67002 L .34493 .67719 L p F P
0 g
s
.805 .669 .713 r
.34658 .66266 m .34337 .66765 L .34987 .67002 L p F P
0 g
s
.582 .769 .968 r
.29474 .72069 m .30168 .71959 L .29809 .71624 L p F P
0 g
s
.582 .769 .968 r
.29809 .71624 m .289 .71814 L .29474 .72069 L p F P
0 g
s
.497 .763 .99 r
.2865 .71859 m .289 .71814 L .29474 .72069 L p F P
0 g
s
.503 .417 .691 r
.43958 .6608 m .43817 .65498 L .44673 .65677 L closepath p F P
0 g
s
.823 .702 .73 r
.34017 .68431 m .34639 .68674 L .34115 .69401 L p F P
0 g
s
.82 .686 .715 r
.34639 .68674 m .34017 .68431 L .34493 .67719 L p F P
0 g
s
.651 .758 .928 r
.69014 .42434 m .70252 .42033 L .70542 .42403 L p F P
0 g
s
.651 .758 .928 r
.70252 .42033 m .69014 .42434 L .68722 .42065 L p F P
0 g
s
.587 .574 .807 r
.46632 .70609 m .46691 .70725 L .45632 .71203 L p F P
0 g
s
.587 .574 .807 r
.45632 .71203 m .45439 .7079 L .46632 .70609 L p F P
0 g
s
.227 .372 .802 r
.51118 .58183 m .50691 .5792 L .50533 .57586 L p F P
0 g
s
.74 .774 .88 r
.30168 .71959 m .305 .71765 L .31004 .72041 L p F P
0 g
s
.709 .746 .88 r
.31349 .71294 m .305 .71765 L .31004 .72041 L p F P
0 g
s
.709 .746 .88 r
.31004 .72041 m .31702 .71697 L .31349 .71294 L p F P
0 g
s
.448 .352 .654 r
.44359 .62922 m .44026 .62734 L .44289 .62558 L closepath p F P
0 g
s
.447 .35 .652 r
.44026 .62734 m .44289 .62558 L .44155 .61849 L p F P
0 g
s
.602 .868 .993 r
.50187 .71684 m .49648 .72035 L p .48815 .71968 L F P
0 g
s
.653 .905 .981 r
.49648 .72035 m .50187 .71684 L .50341 .7175 L closepath p F P
0 g
s
.91 .746 .665 r
.34605 .61037 m .34563 .60982 L .34557 .60997 L closepath p F P
0 g
s
.651 .758 .928 r
.70542 .42403 m .71783 .42001 L .7207 .42371 L p F P
0 g
s
.651 .758 .928 r
.71783 .42001 m .70542 .42403 L .70252 .42033 L p F P
0 g
s
.097 .036 .492 r
.53878 .66502 m .53563 .66946 L .53619 .67573 L p F P
0 g
s
.161 .118 .557 r
.53563 .66946 m .53878 .66502 L .53678 .65985 L p F P
0 g
s
.198 .11 .523 r
.53618 .67575 m .53619 .67573 L .53563 .66946 L p F P
0 g
s
.608 .684 .896 r
.47426 .72022 m .47289 .71833 L .48008 .71681 L closepath p F P
0 g
s
0 0 .149 r
.52745 .69801 m .52951 .69342 L .52817 .69478 L closepath p F P
0 g
s
.896 .727 .663 r
.34151 .63248 m .346 .63552 L .34323 .64199 L p F P
0 g
s
.892 .721 .662 r
.346 .63552 m .34151 .63248 L .34415 .62605 L p F P
0 g
s
.526 .431 .689 r
.43958 .6608 m .44673 .65677 L p .44157 .6683 L F P
0 g
s
.526 .431 .689 r
.44157 .6683 m .44137 .66829 L .43958 .6608 L p F P
0 g
s
.327 .267 .636 r
.44369 .61627 m .44155 .61849 L .44289 .62558 L p F P
0 g
s
.651 .758 .928 r
.7207 .42371 m .73314 .4197 L .73599 .42339 L p F P
0 g
s
.651 .758 .928 r
.73314 .4197 m .7207 .42371 L .71783 .42001 L p F P
0 g
s
.546 0 0 r
.27056 .70937 m .26811 .70721 L .26442 .70463 L p F P
0 g
s
.856 .696 .682 r
.34658 .66266 m .34754 .66072 L .34492 .65938 L closepath p F P
0 g
s
.857 .695 .681 r
.3432 .65596 m .34529 .65139 L p .34754 .66072 L F P
0 g
s
.857 .695 .681 r
.34754 .66072 m .34492 .65938 L .3432 .65596 L p F P
0 g
s
.226 .253 .68 r
.53558 .63067 m .53314 .63526 L .53714 .63978 L p F P
0 g
s
.264 .301 .713 r
.53526 .62962 m .53133 .62581 L p .53314 .63526 L F P
0 g
s
.264 .301 .713 r
.53314 .63526 m .53558 .63067 L .53526 .62962 L p F P
0 g
s
0 0 .391 r
.44038 .57295 m .44037 .57595 L .44192 .58106 L p F P
0 g
s
0 0 .36 r
.43933 .56774 m .43901 .56632 L p .44037 .57595 L F P
0 g
s
0 0 .36 r
.44037 .57595 m .44038 .57295 L .43933 .56774 L p F P
0 g
s
.651 .758 .928 r
.73599 .42339 m .74846 .41937 L .75128 .42307 L p F P
0 g
s
.651 .758 .928 r
.74846 .41937 m .73599 .42339 L .73314 .4197 L p F P
0 g
s
.227 .372 .802 r
.50533 .57586 m .50539 .57357 L p .51118 .58183 L F P
0 g
s
.228 .39 .818 r
.50533 .57586 m .50366 .57259 L .50539 .57357 L closepath p F P
0 g
s
.651 .758 .928 r
.54968 .42347 m .5618 .41946 L .56494 .42316 L p F P
0 g
s
.571 .536 .778 r
.46304 .69848 m .46632 .70609 L .45439 .7079 L p F P
0 g
s
.571 .536 .778 r
.4586 .69896 m .46304 .69848 L p .45439 .7079 L F P
0 g
s
.571 .536 .778 r
.45439 .7079 m .45206 .70208 L .4586 .69896 L p F P
0 g
s
.14 .158 .617 r
.44481 .59584 m .44201 .60113 L .44491 .60586 L p F P
0 g
s
.099 .095 .564 r
.44201 .60113 m .44481 .59584 L .44261 .5909 L p F P
0 g
s
.842 .705 .712 r
.33897 .67466 m .34493 .67719 L .34017 .68431 L p F P
0 g
s
.83 .69 .709 r
.34493 .67719 m .33897 .67466 L .34337 .66765 L p F P
0 g
s
.651 .758 .928 r
.75128 .42307 m .76378 .41905 L .76658 .42275 L p F P
0 g
s
.651 .758 .928 r
.76378 .41905 m .75128 .42307 L .74846 .41937 L p F P
0 g
s
.826 .688 .711 r
.34337 .66765 m .34658 .66266 L .34492 .65938 L p F P
0 g
s
.651 .758 .928 r
.56494 .42316 m .5771 .41914 L .58021 .42284 L p F P
0 g
s
.651 .758 .928 r
.5771 .41914 m .56494 .42316 L .5618 .41946 L p F P
0 g
s
.823 .702 .731 r
.34107 .69412 m .34115 .69401 L .34097 .69393 L closepath p F P
0 g
s
.823 .702 .73 r
.33766 .68811 m .34017 .68431 L p .34115 .69401 L F P
0 g
s
.823 .702 .73 r
.34115 .69401 m .34097 .69393 L .33766 .68811 L p F P
0 g
s
.788 .692 .759 r
.33376 .70192 m .34107 .69412 L .34097 .69393 L p F P
0 g
s
.788 .692 .759 r
.34097 .69393 m .33448 .69171 L p .33376 .70192 L F P
0 g
s
.796 .694 .753 r
.34097 .69393 m .33766 .68811 L .33448 .69171 L closepath p F P
0 g
s
.749 .488 0 r
.43901 .56632 m .43884 .56568 L .43728 .5584 L p F P
0 g
s
0 0 .292 r
.4372 .55681 m .43728 .5584 L .43884 .56568 L p F P
0 g
s
.651 .758 .928 r
.76658 .42275 m .77911 .41873 L .78188 .42243 L p F P
0 g
s
.651 .758 .928 r
.77911 .41873 m .76658 .42275 L .76378 .41905 L p F P
0 g
s
.523 .448 .712 r
.4414 .66839 m .44137 .66829 L .44157 .6683 L closepath p F P
0 g
s
.523 .447 .712 r
.4436 .67636 m .4414 .66839 L .44157 .6683 L p F P
0 g
s
.651 .758 .928 r
.58021 .42284 m .5924 .41883 L .59549 .42253 L p F P
0 g
s
.651 .758 .928 r
.5924 .41883 m .58021 .42284 L .5771 .41914 L p F P
0 g
s
.916 .753 .664 r
.34027 .62281 m .34415 .62605 L .34151 .63248 L p F P
0 g
s
.914 .751 .664 r
.34415 .62605 m .34027 .62281 L .34289 .61639 L p F P
0 g
s
.609 .634 .85 r
.48008 .71681 m .47289 .71833 L .46961 .7127 L p F P
0 g
s
.878 .709 .668 r
.34529 .65139 m .3432 .65596 L .33978 .65003 L p F P
0 g
s
.878 .709 .668 r
.33978 .65003 m .34045 .64849 L .34529 .65139 L p F P
0 g
s
.879 .708 .666 r
.34529 .65139 m .34045 .64849 L .34323 .64199 L p F P
0 g
s
.16 .126 .568 r
.54027 .65459 m .53678 .65985 L .53878 .66502 L p F P
0 g
s
.195 .176 .608 r
.53678 .65985 m .54027 .65459 L .53746 .64968 L p F P
0 g
s
.523 .447 .712 r
.44157 .6683 m .45325 .66943 L p .4436 .67636 L F P
0 g
s
.524 .444 .707 r
.45325 .66943 m .44157 .6683 L .45154 .66308 L closepath p F P
0 g
s
.526 .431 .689 r
.45 .65744 m .45154 .66308 L .44157 .6683 L p F P
0 g
s
.526 .431 .689 r
.44673 .65677 m .45 .65744 L p .44157 .6683 L F P
0 g
s
.557 .773 .979 r
.289 .71814 m .28362 .71636 L .2865 .71859 L closepath p F P
0 g
s
.572 .54 .781 r
.45206 .70208 m .45112 .69976 L .4586 .69896 L closepath p F P
0 g
s
.789 .734 .802 r
.32527 .71017 m .31702 .71697 L .31349 .71294 L p F P
0 g
s
.651 .758 .928 r
.78188 .42243 m .79444 .4184 L .79718 .4221 L p F P
0 g
s
.651 .758 .928 r
.79444 .4184 m .78188 .42243 L .77911 .41873 L p F P
0 g
s
.229 .278 .706 r
.53526 .62962 m .53133 .62581 L .53296 .62228 L closepath p F P
0 g
s
.266 .322 .734 r
.532 .61949 m .5287 .6166 L p .53133 .62581 L F P
0 g
s
.266 .322 .734 r
.53133 .62581 m .53296 .62228 L .532 .61949 L p F P
0 g
s
.651 .758 .928 r
.59549 .42253 m .6077 .41852 L .61076 .42222 L p F P
0 g
s
.651 .758 .928 r
.6077 .41852 m .59549 .42253 L .5924 .41883 L p F P
0 g
s
.817 .718 .755 r
.33376 .70192 m .32898 .70726 L .3255 .70239 L p F P
0 g
s
.817 .718 .755 r
.3255 .70239 m .328 .69936 L .33376 .70192 L p F P
0 g
s
.788 .692 .759 r
.33448 .69171 m .328 .69936 L .33376 .70192 L p F P
0 g
s
0 0 0 r
.52951 .69342 m .53493 .68768 L p .52702 .69936 L F P
0 g
s
0 0 0 r
.52702 .69936 m .52745 .69801 L .52951 .69342 L p F P
0 g
s
.034 0 .303 r
.53626 .68184 m .53629 .68153 L p .52951 .69342 L F P
0 g
s
.034 0 .303 r
.52951 .69342 m .53493 .68768 L .53626 .68184 L p F P
0 g
s
.217 .39 .821 r
.50539 .57357 m .50366 .57259 L .50041 .56634 L p F P
0 g
s
0 0 0 r
.50341 .7175 m .51544 .71063 L .51633 .70998 L p F P
0 g
s
.741 .923 .952 r
.50187 .71684 m .50341 .7175 L .51544 .71063 L p F P
0 g
s
.571 .514 .752 r
.4586 .69896 m .45112 .69976 L .44876 .69304 L p F P
0 g
s
.719 .452 0 r
.43933 .56774 m .43901 .56632 L .43884 .56568 L closepath p F P
0 g
s
.398 .317 .649 r
.44289 .62558 m .44757 .62074 L p .44605 .63124 L F P
0 g
s
.398 .317 .649 r
.44605 .63124 m .44359 .62922 L .44289 .62558 L p F P
0 g
s
.327 .267 .636 r
.44289 .62558 m .44757 .62074 L .44369 .61627 L p F P
0 g
s
.651 .758 .928 r
.79718 .4221 m .80977 .41807 L .81249 .42178 L p F P
0 g
s
.651 .758 .928 r
.80977 .41807 m .79718 .4221 L .79444 .4184 L p F P
0 g
s
.542 .457 .709 r
.4436 .67636 m .45374 .67106 L p .45452 .68019 L F P
0 g
s
.542 .457 .709 r
.45452 .68019 m .4446 .68005 L .4436 .67636 L p F P
0 g
s
.523 .447 .712 r
.45325 .66943 m .45374 .67106 L .4436 .67636 L p F P
0 g
s
.826 .688 .711 r
.34492 .65938 m .34191 .65808 L p .34337 .66765 L F P
0 g
s
.832 .689 .705 r
.34492 .65938 m .3432 .65596 L .34191 .65808 L closepath p F P
0 g
s
.479 .386 .672 r
.44678 .6441 m .44214 .64245 L .44593 .64015 L closepath p F P
0 g
s
.488 .375 .651 r
.44436 .63281 m .44593 .64015 L .44214 .64245 L p F P
0 g
s
.651 .758 .928 r
.61076 .42222 m .62301 .41821 L .62605 .42191 L p F P
0 g
s
.651 .758 .928 r
.62301 .41821 m .61076 .42222 L .6077 .41852 L p F P
0 g
s
.293 .463 .858 r
.49716 .56046 m .49156 .55776 L p .49887 .56554 L F P
0 g
s
.213 .422 .849 r
.49156 .55776 m .49716 .56046 L .49389 .555 L p F P
0 g
s
.213 .422 .849 r
.49389 .555 m .49084 .55349 L .49156 .55776 L p F P
0 g
s
.789 .734 .802 r
.31349 .71294 m .31933 .70767 L .32527 .71017 L p F P
0 g
s
.765 .722 .813 r
.3255 .70239 m .31933 .70767 L .32527 .71017 L p F P
0 g
s
.765 .722 .813 r
.32527 .71017 m .32898 .70726 L .3255 .70239 L p F P
0 g
s
.925 .54 .233 r
.26291 .70167 m .25913 .69848 L .25772 .69323 L p F P
0 g
s
.843 .383 0 r
.26291 .70167 m .26442 .70463 L .26075 .70161 L p F P
0 g
s
.843 .383 0 r
.26075 .70161 m .25913 .69848 L .26291 .70167 L p F P
0 g
s
.852 .711 .707 r
.33776 .665 m .34337 .66765 L .33897 .67466 L p F P
0 g
s
.826 .688 .711 r
.34191 .65808 m .33776 .665 L .34337 .66765 L p F P
0 g
s
.541 .477 .733 r
.44601 .68454 m .4446 .68005 L .45452 .68019 L closepath p F P
0 g
s
0 0 0 r
.52602 .70023 m .51838 .70824 L .51633 .70998 L p F P
0 g
s
.495 .851 .598 r
.51544 .71063 m .51838 .70824 L .51633 .70998 L closepath p F P
0 g
s
.571 .514 .752 r
.44876 .69304 m .45464 .69014 L p .4586 .69896 L F P
0 g
s
.557 .508 .756 r
.44876 .69304 m .44785 .6905 L .45464 .69014 L closepath p F P
0 g
s
.651 .758 .928 r
.81249 .42178 m .82511 .41774 L .8278 .42145 L p F P
0 g
s
.651 .758 .928 r
.82511 .41774 m .81249 .42178 L .80977 .41807 L p F P
0 g
s
.557 .485 .73 r
.44601 .68454 m .45452 .68019 L p .45464 .69014 L F P
0 g
s
.557 .485 .73 r
.45464 .69014 m .44785 .6905 L .44601 .68454 L p F P
0 g
s
.651 .758 .928 r
.62605 .42191 m .63832 .41789 L .64133 .42159 L p F P
0 g
s
.651 .758 .928 r
.63832 .41789 m .62605 .42191 L .62301 .41821 L p F P
0 g
s
.228 .297 .727 r
.532 .61949 m .5287 .6166 L .52992 .61346 L closepath p F P
0 g
s
.267 .342 .755 r
.52875 .61035 m .52531 .60761 L p .5287 .6166 L F P
0 g
s
.267 .342 .755 r
.5287 .6166 m .52992 .61346 L .52875 .61035 L p F P
0 g
s
.898 .734 .67 r
.33885 .63893 m .34323 .64199 L .34045 .64849 L p F P
0 g
s
.896 .727 .663 r
.34323 .64199 m .33885 .63893 L .34151 .63248 L p F P
0 g
s
.651 .758 .928 r
.8278 .42145 m .84045 .41741 L .84311 .42111 L p F P
0 g
s
.651 .758 .928 r
.84045 .41741 m .8278 .42145 L .82511 .41774 L p F P
0 g
s
.842 .705 .712 r
.34017 .68431 m .33766 .68811 L .33422 .68239 L p F P
0 g
s
.842 .705 .712 r
.33422 .68239 m .33468 .68164 L .34017 .68431 L p F P
0 g
s
.842 .705 .712 r
.34017 .68431 m .33468 .68164 L .33897 .67466 L p F P
0 g
s
.757 .781 .873 r
.305 .71765 m .30168 .71959 L .29809 .71624 L p F P
0 g
s
.567 .773 .976 r
.289 .71814 m .29809 .71624 L p .28286 .71577 L F P
0 g
s
.567 .773 .976 r
.28286 .71577 m .28362 .71636 L .289 .71814 L p F P
0 g
s
.602 .868 .993 r
.48815 .71968 m .50017 .71594 L .50187 .71684 L p F P
0 g
s
.601 .778 .965 r
.50017 .71594 m .48815 .71968 L .48487 .7158 L p F P
0 g
s
0 0 .402 r
.43884 .56568 m .43854 .56195 L p .44059 .5714 L F P
0 g
s
0 0 .402 r
.44059 .5714 m .43933 .56774 L .43884 .56568 L p F P
0 g
s
0 0 .402 r
.43996 .56709 m .44059 .5714 L p .43864 .56238 L F P
0 g
s
0 0 .402 r
.43854 .56195 m .43996 .56709 L p .43864 .56238 L F P
0 g
s
0 0 .243 r
.44145 .57222 m .43996 .56709 L p .44009 .56757 L F P
0 g
s
0 0 .243 r
.44236 .57644 m .44145 .57222 L p .44009 .56757 L F P
0 g
s
0 0 .219 r
.443 .57735 m .44145 .57222 L p .44161 .57277 L F P
0 g
s
0 0 .219 r
.44416 .58149 m .443 .57735 L p .44161 .57277 L F P
0 g
s
.691 .386 0 r
.443 .57735 m .44416 .58149 L .44599 .58655 L p F P
0 g
s
.86 .495 0 r
.443 .57735 m .44462 .58248 L p .44439 .58195 L F P
0 g
s
0 0 .458 r
.44059 .5714 m .44038 .57295 L .44193 .58024 L p F P
0 g
s
0 .001 .54 r
.44193 .58024 m .44236 .57644 L p .44394 .58603 L F P
0 g
s
0 0 .458 r
.44193 .58024 m .44236 .57644 L .44059 .5714 L p F P
0 g
s
0 0 .243 r
.43996 .56709 m .44059 .5714 L .44236 .57644 L p F P
0 g
s
0 .001 .54 r
.44236 .57644 m .44416 .58149 L .44394 .58603 L p F P
0 g
s
0 0 .219 r
.44145 .57222 m .44236 .57644 L .44416 .58149 L p F P
0 g
s
.86 .495 0 r
.44083 .57351 m .443 .57735 L p .44439 .58195 L F P
0 g
s
.857 .502 0 r
.44145 .57222 m .443 .57735 L p .44281 .57689 L F P
0 g
s
0 0 .457 r
.44038 .57295 m .43933 .56774 L .44059 .5714 L closepath p F P
0 g
s
.857 .502 0 r
.4394 .56834 m .44145 .57222 L p .44281 .57689 L F P
0 g
s
.854 .509 0 r
.43996 .56709 m .44145 .57222 L p .44129 .5718 L F P
0 g
s
0 0 .292 r
.43884 .56568 m .43854 .56195 L p .43729 .5573 L F P
0 g
s
.854 .509 0 r
.43805 .56316 m .43996 .56709 L p .44129 .5718 L F P
0 g
s
.848 .517 0 r
.43854 .56195 m .43996 .56709 L p .43981 .56666 L F P
0 g
s
.848 .517 0 r
.4368 .55797 m .43854 .56195 L p .43981 .56666 L F P
0 g
s
0 0 .292 r
.43854 .56195 m .4372 .55681 L p .43729 .5573 L F P
0 g
s
.651 .758 .928 r
.64133 .42159 m .65364 .41758 L .65662 .42128 L p F P
0 g
s
.651 .758 .928 r
.65364 .41758 m .64133 .42159 L .63832 .41789 L p F P
0 g
s
.123 .005 .434 r
.53622 .67743 m .53618 .67575 L .53619 .67573 L closepath p F P
0 g
s
.047 0 .409 r
.53619 .67573 m .53993 .67045 L p .53632 .68148 L F P
0 g
s
.047 0 .409 r
.53632 .68148 m .53622 .67743 L .53619 .67573 L p F P
0 g
s
.097 .036 .492 r
.53619 .67573 m .53993 .67045 L .53878 .66502 L p F P
0 g
s
.378 .318 .663 r
.44436 .63281 m .44359 .62922 L .44605 .63124 L closepath p F P
0 g
s
.238 .412 .833 r
.50041 .56634 m .49887 .56554 L .49881 .56336 L closepath p F P
0 g
s
.293 .463 .858 r
.49887 .56554 m .49881 .56336 L .49716 .56046 L p F P
0 g
s
0 .024 .55 r
.4435 .58755 m .44261 .5909 L .44481 .59584 L p F P
0 g
s
0 .008 .538 r
.44252 .58285 m .44192 .58106 L p .44261 .5909 L F P
0 g
s
0 .008 .538 r
.44261 .5909 m .4435 .58755 L .44252 .58285 L p F P
0 g
s
.265 .252 .658 r
.44788 .61059 m .44369 .61627 L .44757 .62074 L p F P
0 g
s
.352 .273 .626 r
.44491 .60586 m .44788 .61059 L .44369 .61627 L p F P
0 g
s
.651 .758 .928 r
.65662 .42128 m .66896 .41726 L .67192 .42097 L p F P
0 g
s
.651 .758 .928 r
.66896 .41726 m .65662 .42128 L .65364 .41758 L p F P
0 g
s
0 .434 .849 r
.28274 .71574 m .27868 .71266 L .27056 .70937 L p F P
0 g
s
.546 0 0 r
.26442 .70463 m .26643 .70631 L .27056 .70937 L p F P
0 g
s
.011 .455 .869 r
.26643 .70631 m .27056 .70937 L .27868 .71266 L p F P
0 g
s
.846 .709 .712 r
.34191 .65808 m .3432 .65596 L .33978 .65003 L p F P
0 g
s
.842 .525 0 r
.43565 .55276 m .4372 .55681 L .43854 .56195 L p F P
0 g
s
.225 .316 .748 r
.52875 .61035 m .52531 .60761 L .52639 .60411 L closepath p F P
0 g
s
.267 .362 .776 r
.5255 .60195 m .52121 .59883 L p .52531 .60761 L F P
0 g
s
.267 .362 .776 r
.52531 .60761 m .52639 .60411 L .5255 .60195 L p F P
0 g
s
.757 .781 .873 r
.29809 .71624 m .3004 .71475 L .305 .71765 L p F P
0 g
s
.728 .753 .873 r
.30995 .70896 m .3004 .71475 L .305 .71765 L p F P
0 g
s
.728 .753 .873 r
.305 .71765 m .31349 .71294 L .30995 .70896 L p F P
0 g
s
.227 .372 .802 r
.50539 .57357 m .51134 .57735 L .51118 .58183 L p F P
0 g
s
.183 .367 .812 r
.50511 .56921 m .50539 .57357 L .51134 .57735 L p F P
0 g
s
.217 .39 .821 r
.50041 .56634 m .50511 .56921 L .50539 .57357 L p F P
0 g
s
.651 .758 .928 r
.67192 .42097 m .68428 .41694 L .68722 .42065 L p F P
0 g
s
.651 .758 .928 r
.68428 .41694 m .67192 .42097 L .66896 .41726 L p F P
0 g
s
0 0 .062 r
.52602 .70023 m .52702 .69936 L .52745 .69801 L closepath p F P
0 g
s
.378 .317 .663 r
.44605 .63124 m .44436 .63281 L .44593 .64015 L p F P
0 g
s
.801 .704 .757 r
.33448 .69171 m .33766 .68811 L .33422 .68239 L p F P
0 g
s
.178 .17 .611 r
.5396 .64615 m .53746 .64968 L .54027 .65459 L p F P
0 g
s
.22 .225 .652 r
.53854 .64175 m .53714 .63978 L p .53746 .64968 L F P
0 g
s
.22 .225 .652 r
.53746 .64968 m .5396 .64615 L .53854 .64175 L p F P
0 g
s
.222 .335 .768 r
.5255 .60195 m .52121 .59883 L .52228 .59415 L closepath p F P
0 g
s
.267 .382 .795 r
.52226 .5941 m .51648 .59024 L p .52121 .59883 L F P
0 g
s
.267 .382 .795 r
.52121 .59883 m .52228 .59415 L .52226 .5941 L p F P
0 g
s
.223 .361 .793 r
.51648 .59024 m .51709 .58565 L .51118 .58183 L p F P
0 g
s
.235 .391 .816 r
.51134 .57735 m .51118 .58183 L .51709 .58565 L p F P
0 g
s
.863 .723 .707 r
.33673 .65528 m .34191 .65808 L .33776 .665 L p F P
0 g
s
.846 .709 .712 r
.33978 .65003 m .33673 .65528 L .34191 .65808 L p F P
0 g
s
.2 .338 .78 r
.51648 .59024 m .52226 .5941 L .51901 .58701 L p F P
0 g
s
.2 .338 .78 r
.51901 .58701 m .51709 .58565 L .51648 .59024 L p F P
0 g
s
.651 .758 .928 r
.68722 .42065 m .69961 .41662 L .70252 .42033 L p F P
0 g
s
.651 .758 .928 r
.69961 .41662 m .68722 .42065 L .68428 .41694 L p F P
0 g
s
.051 0 .41 r
.53629 .68153 m .53622 .67743 L .53632 .68148 L closepath p F P
0 g
s
.918 .755 .664 r
.33766 .62924 m .34151 .63248 L .33885 .63893 L p F P
0 g
s
.916 .753 .664 r
.34151 .63248 m .33766 .62924 L .34027 .62281 L p F P
0 g
s
0 0 0 r
.52702 .69936 m .52602 .70023 L .51838 .70824 L p F P
0 g
s
.833 .734 .756 r
.32867 .68915 m .33448 .69171 L .328 .69936 L p F P
0 g
s
.801 .704 .757 r
.33422 .68239 m .32867 .68915 L .33448 .69171 L p F P
0 g
s
.609 .634 .85 r
.46961 .7127 m .48159 .71084 L p .48008 .71681 L F P
0 g
s
.567 .578 .824 r
.47831 .70493 m .48159 .71084 L .46961 .7127 L p F P
0 g
s
.567 .578 .824 r
.46936 .7058 m .47831 .70493 L p .46961 .7127 L F P
0 g
s
.567 .578 .824 r
.46961 .7127 m .46691 .70725 L .46936 .7058 L p F P
0 g
s
.651 .758 .928 r
.70252 .42033 m .71495 .41631 L .71783 .42001 L p F P
0 g
s
.651 .758 .928 r
.71495 .41631 m .70252 .42033 L .69961 .41662 L p F P
0 g
s
.855 .724 .717 r
.33373 .67191 m .33897 .67466 L .33468 .68164 L p F P
0 g
s
.852 .711 .707 r
.33897 .67466 m .33373 .67191 L .33776 .665 L p F P
0 g
s
0 0 .391 r
.44192 .58106 m .44193 .58024 L .44038 .57295 L p F P
0 g
s
.172 .37 .818 r
.50511 .56921 m .50041 .56634 L .49881 .56336 L p F P
0 g
s
0 0 0 r
.51838 .70824 m .51544 .71063 L .51222 .7109 L p F P
0 g
s
.741 .923 .952 r
.51544 .71063 m .51222 .7109 L p .50187 .71684 L F P
0 g
s
.665 .887 .979 r
.50017 .71594 m .50673 .71327 L .50187 .71684 L closepath p F P
0 g
s
.741 .923 .952 r
.51222 .7109 m .50673 .71327 L .50187 .71684 L p F P
0 g
s
.609 .662 .876 r
.48487 .7158 m .48008 .71681 L .4842 .71477 L closepath p F P
0 g
s
.609 .634 .85 r
.48159 .71084 m .4842 .71477 L .48008 .71681 L p F P
0 g
s
.651 .758 .928 r
.71783 .42001 m .73029 .41599 L .73314 .4197 L p F P
0 g
s
.651 .758 .928 r
.73029 .41599 m .71783 .42001 L .71495 .41631 L p F P
0 g
s
0 0 0 r
.51838 .70824 m .52467 .70276 L .52702 .69936 L p F P
0 g
s
0 0 0 r
.52467 .70276 m .51838 .70824 L p .51222 .7109 L F P
0 g
s
0 0 .412 r
.44252 .58285 m .44192 .58106 L .44193 .58024 L closepath p F P
0 g
s
.651 .758 .928 r
.73314 .4197 m .74563 .41566 L .74846 .41937 L p F P
0 g
s
.651 .758 .928 r
.74563 .41566 m .73314 .4197 L .73029 .41599 L p F P
0 g
s
.46 0 0 r
.26643 .70631 m .26442 .70463 L .26075 .70161 L p F P
0 g
s
.434 .356 .669 r
.44593 .64015 m .4511 .6354 L p .44978 .64583 L F P
0 g
s
.434 .356 .669 r
.44978 .64583 m .44678 .6441 L .44593 .64015 L p F P
0 g
s
.378 .317 .663 r
.44593 .64015 m .4511 .6354 L .44605 .63124 L p F P
0 g
s
.162 .568 .932 r
.28286 .71577 m .28274 .71574 L .28362 .71636 L closepath p F P
0 g
s
.834 .733 .753 r
.328 .69936 m .3255 .70239 L .322 .69768 L p F P
0 g
s
.834 .733 .753 r
.322 .69768 m .32282 .69662 L .328 .69936 L p F P
0 g
s
.833 .734 .756 r
.328 .69936 m .32282 .69662 L .32867 .68915 L p F P
0 g
s
0 0 0 r
.53148 .69449 m .52702 .69936 L .52467 .70276 L p F P
0 g
s
0 0 0 r
.53493 .68768 m .53148 .69449 L .52702 .69936 L p F P
0 g
s
.897 .735 .673 r
.33978 .65003 m .34045 .64849 L .33693 .64596 L closepath p F P
0 g
s
.898 .734 .67 r
.33631 .64506 m .33885 .63893 L p .34045 .64849 L F P
0 g
s
.898 .734 .67 r
.34045 .64849 m .33693 .64596 L .33631 .64506 L p F P
0 g
s
.651 .758 .928 r
.74846 .41937 m .76098 .41534 L .76378 .41905 L p F P
0 g
s
.651 .758 .928 r
.76098 .41534 m .74846 .41937 L .74563 .41566 L p F P
0 g
s
.651 .758 .928 r
.5618 .41946 m .57397 .41543 L .5771 .41914 L p F P
0 g
s
.805 .749 .8 r
.31933 .70767 m .31349 .71294 L .30995 .70896 L p F P
0 g
s
.805 .749 .8 r
.30995 .70896 m .31408 .70495 L .31933 .70767 L p F P
0 g
s
.781 .733 .808 r
.322 .69768 m .31408 .70495 L .31933 .70767 L p F P
0 g
s
.781 .733 .808 r
.31933 .70767 m .3255 .70239 L .322 .69768 L p F P
0 g
s
.504 .416 .69 r
.45 .65744 m .44673 .65677 L .44947 .65523 L closepath p F P
0 g
s
.509 .404 .67 r
.44764 .64762 m .44947 .65523 L .44673 .65677 L p F P
0 g
s
.148 .165 .621 r
.4467 .60225 m .44491 .60586 L .44788 .61059 L p F P
0 g
s
.14 .158 .617 r
.44571 .59776 m .44481 .59584 L p .44491 .60586 L F P
0 g
s
.14 .158 .617 r
.44491 .60586 m .4467 .60225 L .44571 .59776 L p F P
0 g
s
.185 .201 .643 r
.53854 .64175 m .53714 .63978 L .53778 .6386 L closepath p F P
0 g
s
.226 .253 .68 r
.53714 .63978 m .53778 .6386 L .53558 .63067 L p F P
0 g
s
.345 .317 .684 r
.45148 .62523 m .44605 .63124 L .4511 .6354 L p F P
0 g
s
.398 .317 .649 r
.44757 .62074 m .45148 .62523 L .44605 .63124 L p F P
0 g
s
.651 .758 .928 r
.76378 .41905 m .77633 .41502 L .77911 .41873 L p F P
0 g
s
.651 .758 .928 r
.77633 .41502 m .76378 .41905 L .76098 .41534 L p F P
0 g
s
.172 .37 .818 r
.49881 .56336 m .49846 .56119 L p .50511 .56921 L F P
0 g
s
.179 .392 .834 r
.49881 .56336 m .49716 .56046 L .49846 .56119 L closepath p F P
0 g
s
.651 .758 .928 r
.5771 .41914 m .5893 .41512 L .5924 .41883 L p F P
0 g
s
.651 .758 .928 r
.5893 .41512 m .5771 .41914 L .57397 .41543 L p F P
0 g
s
.572 .526 .765 r
.46304 .69848 m .4586 .69896 L .46255 .69717 L closepath p F P
0 g
s
.571 .514 .752 r
.45977 .68987 m .46255 .69717 L .4586 .69896 L p F P
0 g
s
.571 .514 .752 r
.45464 .69014 m .45977 .68987 L p .4586 .69896 L F P
0 g
s
0 .001 .54 r
.44394 .58603 m .44252 .58285 L .44193 .58024 L p F P
0 g
s
.088 .032 .492 r
.54211 .6601 m .53878 .66502 L .53993 .67045 L p F P
0 g
s
.16 .126 .568 r
.54187 .65858 m .54027 .65459 L p .53878 .66502 L F P
0 g
s
.16 .126 .568 r
.53878 .66502 m .54211 .6601 L .54187 .65858 L p F P
0 g
s
.871 .732 .707 r
.33285 .66213 m .33776 .665 L .33373 .67191 L p F P
0 g
s
.863 .723 .707 r
.33776 .665 m .33285 .66213 L .33673 .65528 L p F P
0 g
s
.869 .737 .714 r
.33673 .65528 m .33978 .65003 L .33693 .64596 L p F P
0 g
s
.418 .361 .686 r
.44764 .64762 m .44678 .6441 L .44978 .64583 L closepath p F P
0 g
s
.651 .758 .928 r
.77911 .41873 m .79168 .41469 L .79444 .4184 L p F P
0 g
s
.651 .758 .928 r
.79168 .41469 m .77911 .41873 L .77633 .41502 L p F P
0 g
s
.213 .591 .946 r
.28274 .71574 m .28286 .71577 L .27922 .71277 L p F P
0 g
s
.213 .591 .946 r
.27922 .71277 m .27868 .71266 L .28274 .71574 L p F P
0 g
s
.569 .582 .827 r
.46691 .70725 m .46632 .70609 L .46936 .7058 L closepath p F P
0 g
s
.651 .758 .928 r
.5924 .41883 m .60462 .4148 L .6077 .41852 L p F P
0 g
s
.651 .758 .928 r
.60462 .4148 m .5924 .41883 L .5893 .41512 L p F P
0 g
s
.567 .773 .976 r
.29809 .71624 m .29449 .71286 L .28286 .71577 L p F P
0 g
s
.627 .761 .943 r
.29449 .71286 m .28286 .71577 L .27922 .71277 L p F P
0 g
s
.558 .498 .744 r
.45977 .68987 m .45464 .69014 L .45915 .68801 L closepath p F P
0 g
s
.557 .485 .73 r
.4565 .68021 m .45915 .68801 L .45464 .69014 L p F P
0 g
s
.557 .485 .73 r
.45452 .68019 m .4565 .68021 L p .45464 .69014 L F P
0 g
s
.188 .271 .718 r
.53296 .62228 m .532 .61949 L .53343 .62086 L closepath p F P
0 g
s
.189 .251 .697 r
.53296 .62228 m .53343 .62086 L p .53578 .63018 L F P
0 g
s
.189 .251 .697 r
.53578 .63018 m .53526 .62962 L .53296 .62228 L p F P
0 g
s
.855 .724 .719 r
.33422 .68239 m .33468 .68164 L .33321 .68082 L closepath p F P
0 g
s
.855 .724 .717 r
.33076 .67702 m .33373 .67191 L p .33468 .68164 L F P
0 g
s
.855 .724 .717 r
.33468 .68164 m .33321 .68082 L .33076 .67702 L p F P
0 g
s
0 .026 .549 r
.4435 .58755 m .44252 .58285 L .44394 .58603 L closepath p F P
0 g
s
.651 .758 .928 r
.79444 .4184 m .80704 .41436 L .80977 .41807 L p F P
0 g
s
.651 .758 .928 r
.80704 .41436 m .79444 .4184 L .79168 .41469 L p F P
0 g
s
.189 .251 .697 r
.53558 .63067 m .53526 .62962 L .53578 .63018 L closepath p F P
0 g
s
.136 .191 .657 r
.53578 .63018 m .53558 .63067 L .53778 .6386 L p F P
0 g
s
.418 .36 .686 r
.44978 .64583 m .44764 .64762 L .44947 .65523 L p F P
0 g
s
.187 .27 .718 r
.53343 .62086 m .532 .61949 L .52992 .61346 L p F P
0 g
s
0 0 .29 r
.53626 .68184 m .53632 .68148 L .53629 .68153 L closepath p F P
0 g
s
.651 .758 .928 r
.6077 .41852 m .61996 .41449 L .62301 .41821 L p F P
0 g
s
.651 .758 .928 r
.61996 .41449 m .6077 .41852 L .60462 .4148 L p F P
0 g
s
.57 .551 .793 r
.46936 .7058 m .46632 .70609 L .46304 .69848 L p F P
0 g
s
.818 .719 .755 r
.32867 .68915 m .33422 .68239 L .33321 .68082 L p F P
0 g
s
0 0 .168 r
.53632 .68148 m .54004 .6762 L p .53579 .68674 L F P
0 g
s
0 0 .168 r
.53579 .68674 m .53626 .68184 L .53632 .68148 L p F P
0 g
s
.047 0 .409 r
.53993 .67045 m .54004 .6762 L .53632 .68148 L p F P
0 g
s
.917 .755 .666 r
.33885 .63893 m .33631 .64506 L .33278 .64115 L p F P
0 g
s
.917 .755 .666 r
.33278 .64115 m .33504 .63568 L .33885 .63893 L p F P
0 g
s
.918 .755 .664 r
.33885 .63893 m .33504 .63568 L .33766 .62924 L p F P
0 g
s
.01 0 .29 r
.53493 .68768 m .53579 .68674 L .53626 .68184 L closepath p F P
0 g
s
.601 .778 .965 r
.48487 .7158 m .4969 .71297 L .50017 .71594 L p F P
0 g
s
.586 .652 .881 r
.49363 .70892 m .4969 .71297 L .48487 .7158 L p F P
0 g
s
.586 .652 .881 r
.49227 .70914 m .49363 .70892 L p .48487 .7158 L F P
0 g
s
.586 .652 .881 r
.48487 .7158 m .4842 .71477 L .49227 .70914 L p F P
0 g
s
.187 .27 .718 r
.52992 .61346 m .53036 .61176 L p .53343 .62086 L F P
0 g
s
.187 .29 .739 r
.52992 .61346 m .52875 .61035 L .53036 .61176 L closepath p F P
0 g
s
.651 .758 .928 r
.80977 .41807 m .8224 .41403 L .82511 .41774 L p F P
0 g
s
.651 .758 .928 r
.8224 .41403 m .80977 .41807 L .80704 .41436 L p F P
0 g
s
.651 .758 .928 r
.62301 .41821 m .6353 .41417 L .63832 .41789 L p F P
0 g
s
.651 .758 .928 r
.6353 .41417 m .62301 .41821 L .61996 .41449 L p F P
0 g
s
.769 .787 .867 r
.3004 .71475 m .29809 .71624 L .29449 .71286 L p F P
0 g
s
.136 .191 .657 r
.53778 .6386 m .53925 .63486 L .53578 .63018 L p F P
0 g
s
.115 .187 .661 r
.53734 .6254 m .53578 .63018 L .53925 .63486 L p F P
0 g
s
.189 .251 .697 r
.53343 .62086 m .53734 .6254 L .53578 .63018 L p F P
0 g
s
.651 .758 .928 r
.82511 .41774 m .83777 .4137 L .84045 .41741 L p F P
0 g
s
.651 .758 .928 r
.83777 .4137 m .82511 .41774 L .8224 .41403 L p F P
0 g
s
.186 .29 .739 r
.53036 .61176 m .52875 .61035 L .52639 .60411 L p F P
0 g
s
.133 .165 .629 r
.53778 .6386 m .53925 .63486 L p .54033 .64456 L F P
0 g
s
.133 .165 .629 r
.54033 .64456 m .53854 .64175 L .53778 .6386 L p F P
0 g
s
.651 .758 .928 r
.63832 .41789 m .65064 .41386 L .65364 .41758 L p F P
0 g
s
.651 .758 .928 r
.65064 .41386 m .63832 .41789 L .6353 .41417 L p F P
0 g
s
.158 .391 .838 r
.49846 .56119 m .49716 .56046 L .49389 .555 L p F P
0 g
s
0 .023 .548 r
.44394 .58603 m .4435 .58755 L .44507 .59487 L p F P
0 g
s
0 .024 .55 r
.44481 .59584 m .44507 .59487 L .4435 .58755 L p F P
0 g
s
.605 .864 .992 r
.50673 .71327 m .50017 .71594 L .4969 .71297 L p F P
0 g
s
.011 .455 .869 r
.27868 .71266 m .27477 .70952 L .26643 .70631 L p F P
0 g
s
.036 .465 .879 r
.2626 .70313 m .26643 .70631 L .27477 .70952 L p F P
0 g
s
.46 0 0 r
.26075 .70161 m .2626 .70313 L .26643 .70631 L p F P
0 g
s
.588 .655 .883 r
.4842 .71477 m .48159 .71084 L .49227 .70914 L closepath p F P
0 g
s
.818 .719 .755 r
.33321 .68082 m .32923 .67895 L p .32867 .68915 L F P
0 g
s
.823 .719 .75 r
.33321 .68082 m .33076 .67702 L .32923 .67895 L closepath p F P
0 g
s
.769 .787 .867 r
.29449 .71286 m .29609 .71176 L .3004 .71475 L p F P
0 g
s
.744 .762 .868 r
.30639 .70507 m .29609 .71176 L .3004 .71475 L p F P
0 g
s
.744 .762 .868 r
.3004 .71475 m .30995 .70896 L .30639 .70507 L p F P
0 g
s
.184 .419 .854 r
.49084 .55349 m .49389 .555 L .49062 .54976 L p F P
0 g
s
.184 .419 .854 r
.49062 .54976 m .48974 .54932 L .49084 .55349 L p F P
0 g
s
.842 .525 0 r
.43854 .56195 m .4368 .55797 L .43565 .55276 L p F P
0 g
s
.882 .747 .708 r
.33225 .65226 m .33673 .65528 L .33285 .66213 L p F P
0 g
s
.869 .737 .714 r
.3361 .64542 m .33225 .65226 L .33673 .65528 L p F P
0 g
s
.869 .737 .714 r
.33693 .64596 m .3361 .64542 L p .33673 .65528 L F P
0 g
s
.651 .758 .928 r
.65364 .41758 m .66599 .41354 L .66896 .41726 L p F P
0 g
s
.651 .758 .928 r
.66599 .41354 m .65364 .41758 L .65064 .41386 L p F P
0 g
s
0 .035 .558 r
.44571 .59776 m .44481 .59584 L .44507 .59487 L closepath p F P
0 g
s
.463 .39 .689 r
.44947 .65523 m .45624 .6496 L p .45586 .65976 L F P
0 g
s
.463 .39 .689 r
.45586 .65976 m .45 .65744 L .44947 .65523 L p F P
0 g
s
.418 .36 .686 r
.44947 .65523 m .45624 .6496 L .44978 .64583 L p F P
0 g
s
.844 .749 .758 r
.32352 .68638 m .32867 .68915 L .32282 .69662 L p F P
0 g
s
.818 .719 .755 r
.32923 .67895 m .32352 .68638 L .32867 .68915 L p F P
0 g
s
.132 .165 .629 r
.5396 .64615 m .53854 .64175 L .54033 .64456 L closepath p F P
0 g
s
.186 .29 .739 r
.52639 .60411 m .52662 .60285 L p .53036 .61176 L F P
0 g
s
.187 .311 .759 r
.52639 .60411 m .5255 .60195 L .52662 .60285 L closepath p F P
0 g
s
.651 .758 .928 r
.66896 .41726 m .68134 .41322 L .68428 .41694 L p F P
0 g
s
.651 .758 .928 r
.68134 .41322 m .66896 .41726 L .66599 .41354 L p F P
0 g
s
.452 .399 .708 r
.45154 .66308 m .45 .65744 L .45586 .65976 L closepath p F P
0 g
s
.871 .732 .706 r
.33373 .67191 m .33076 .67702 L .32728 .67215 L p F P
0 g
s
.871 .732 .706 r
.32728 .67215 m .32904 .66897 L .33373 .67191 L p F P
0 g
s
.871 .732 .707 r
.33373 .67191 m .32904 .66897 L .33285 .66213 L p F P
0 g
s
.569 .573 .817 r
.47831 .70493 m .46936 .7058 L .47673 .70164 L closepath p F P
0 g
s
.57 .551 .793 r
.47502 .69813 m .47673 .70164 L .46936 .7058 L p F P
0 g
s
.57 .551 .793 r
.46304 .69848 m .47502 .69813 L p .46936 .7058 L F P
0 g
s
.528 .501 .769 r
.47207 .69123 m .47502 .69813 L .46304 .69848 L p F P
0 g
s
.528 .501 .769 r
.46304 .69848 m .46255 .69717 L .47207 .69123 L p F P
0 g
s
.124 .219 .692 r
.53464 .61616 m .53343 .62086 L .53734 .6254 L p F P
0 g
s
.187 .27 .718 r
.53036 .61176 m .53464 .61616 L .53343 .62086 L p F P
0 g
s
.527 .503 .772 r
.47174 .69047 m .47207 .69123 L .46255 .69717 L p F P
0 g
s
.527 .503 .772 r
.46255 .69717 m .45977 .68987 L .47174 .69047 L p F P
0 g
s
.184 .31 .759 r
.52662 .60285 m .5255 .60195 L .52228 .59415 L p F P
0 g
s
.542 .471 .725 r
.4565 .68021 m .45452 .68019 L .45624 .67934 L closepath p F P
0 g
s
.542 .457 .709 r
.45374 .67106 m .45624 .67934 L .45452 .68019 L p F P
0 g
s
.651 .758 .928 r
.68428 .41694 m .6967 .4129 L .69961 .41662 L p F P
0 g
s
.651 .758 .928 r
.6967 .4129 m .68428 .41694 L .68134 .41322 L p F P
0 g
s
.267 .254 .659 r
.45008 .61716 m .44757 .62074 L .45148 .62523 L p F P
0 g
s
.265 .252 .658 r
.44892 .6122 m .44788 .61059 L p .44757 .62074 L F P
0 g
s
.265 .252 .658 r
.44757 .62074 m .45008 .61716 L .44892 .6122 L p F P
0 g
s
.074 .098 .58 r
.54033 .64456 m .5396 .64615 L .54105 .65332 L p F P
0 g
s
.178 .17 .611 r
.54027 .65459 m .54105 .65332 L .5396 .64615 L p F P
0 g
s
.94 .581 .184 r
.43284 .5491 m .43565 .55276 L .4368 .55797 L p F P
0 g
s
.489 .422 .708 r
.45154 .66308 m .45586 .65976 L p .45529 .66995 L F P
0 g
s
.489 .422 .708 r
.45529 .66995 m .45325 .66943 L .45154 .66308 L p F P
0 g
s
.124 .101 .558 r
.54187 .65858 m .54027 .65459 L .54105 .65332 L closepath p F P
0 g
s
.172 .37 .818 r
.49846 .56119 m .50444 .56494 L .50511 .56921 L p F P
0 g
s
.121 .363 .824 r
.49735 .55705 m .49846 .56119 L .50444 .56494 L p F P
0 g
s
.158 .391 .838 r
.49389 .555 m .49735 .55705 L .49846 .56119 L p F P
0 g
s
.871 .736 .71 r
.33693 .64596 m .33631 .64506 L .3361 .64542 L closepath p F P
0 g
s
.651 .758 .928 r
.69961 .41662 m .71206 .41258 L .71495 .41631 L p F P
0 g
s
.651 .758 .928 r
.71206 .41258 m .69961 .41662 L .6967 .4129 L p F P
0 g
s
.401 .365 .703 r
.45571 .64014 m .44978 .64583 L .45624 .6496 L p F P
0 g
s
.434 .356 .669 r
.45539 .63893 m .45571 .64014 L .44978 .64583 L p F P
0 g
s
.434 .356 .669 r
.4511 .6354 m .45539 .63893 L p .44978 .64583 L F P
0 g
s
.091 .125 .604 r
.44507 .59487 m .44615 .59097 L p .44738 .60068 L F P
0 g
s
.091 .125 .604 r
.44738 .60068 m .44571 .59776 L .44507 .59487 L p F P
0 g
s
0 .023 .548 r
.44507 .59487 m .44615 .59097 L .44394 .58603 L p F P
0 g
s
.126 .244 .717 r
.53121 .60714 m .53036 .61176 L .53464 .61616 L p F P
0 g
s
.186 .29 .739 r
.52662 .60285 m .53121 .60714 L .53036 .61176 L p F P
0 g
s
.651 .758 .928 r
.71495 .41631 m .72742 .41226 L .73029 .41599 L p F P
0 g
s
.651 .758 .928 r
.72742 .41226 m .71495 .41631 L .71206 .41258 L p F P
0 g
s
.843 .749 .76 r
.322 .69768 m .32282 .69662 L .31969 .69472 L closepath p F P
0 g
s
.844 .749 .758 r
.31849 .69318 m .32352 .68638 L p .32282 .69662 L F P
0 g
s
.844 .749 .758 r
.32282 .69662 m .31969 .69472 L .31849 .69318 L p F P
0 g
s
.48 .435 .73 r
.45374 .67106 m .45325 .66943 L .45529 .66995 L closepath p F P
0 g
s
.183 .367 .812 r
.51134 .57735 m .51115 .57296 L .50511 .56921 L p F P
0 g
s
.202 .405 .838 r
.50444 .56494 m .50511 .56921 L .51115 .57296 L p F P
0 g
s
.503 .465 .748 r
.46845 .68193 m .47174 .69047 L .45977 .68987 L p F P
0 g
s
.503 .465 .748 r
.46826 .6819 m .46845 .68193 L p .45977 .68987 L F P
0 g
s
.503 .465 .748 r
.45977 .68987 m .45915 .68801 L .46826 .6819 L p F P
0 g
s
.479 .433 .728 r
.45624 .67934 m .45374 .67106 L .45529 .66995 L p F P
0 g
s
.505 .468 .75 r
.45915 .68801 m .4565 .68021 L .46826 .6819 L closepath p F P
0 g
s
.796 .745 .805 r
.31408 .70495 m .322 .69768 L .31969 .69472 L p F P
0 g
s
.819 .762 .799 r
.31408 .70495 m .30995 .70896 L .30639 .70507 L p F P
0 g
s
.819 .762 .799 r
.30639 .70507 m .30931 .70208 L .31408 .70495 L p F P
0 g
s
.796 .745 .805 r
.31781 .69381 m .30931 .70208 L .31408 .70495 L p F P
0 g
s
.796 .745 .805 r
.31969 .69472 m .31781 .69381 L p .31408 .70495 L F P
0 g
s
.892 .768 .719 r
.3361 .64542 m .33631 .64506 L .33278 .64115 L p F P
0 g
s
0 0 .414 r
.44416 .58149 m .44394 .58603 L .44615 .59097 L p F P
0 g
s
.895 .77 .716 r
.33219 .6422 m .3361 .64542 L .33225 .65226 L p F P
0 g
s
.892 .768 .719 r
.33278 .64115 m .33219 .6422 L .3361 .64542 L p F P
0 g
s
.651 .758 .928 r
.73029 .41599 m .74279 .41194 L .74563 .41566 L p F P
0 g
s
.651 .758 .928 r
.74279 .41194 m .73029 .41599 L .72742 .41226 L p F P
0 g
s
.095 .127 .604 r
.4467 .60225 m .44571 .59776 L .44738 .60068 L closepath p F P
0 g
s
.511 .452 .726 r
.45624 .67934 m .46532 .67292 L p .46826 .6819 L F P
0 g
s
.511 .452 .726 r
.46826 .6819 m .4565 .68021 L .45624 .67934 L p F P
0 g
s
.479 .433 .728 r
.46518 .67251 m .46532 .67292 L .45624 .67934 L p F P
0 g
s
.479 .433 .728 r
.45529 .66995 m .46518 .67251 L p .45624 .67934 L F P
0 g
s
.605 .864 .992 r
.51072 .7102 m .50673 .71327 L p .4969 .71297 L F P
0 g
s
.671 .904 .977 r
.50673 .71327 m .51072 .7102 L .51222 .7109 L closepath p F P
0 g
s
.12 .263 .737 r
.52711 .59832 m .52662 .60285 L .53121 .60714 L p F P
0 g
s
.184 .31 .759 r
.52228 .59412 m .52711 .59832 L .52662 .60285 L p F P
0 g
s
.184 .31 .759 r
.52228 .59415 m .52228 .59412 L p .52662 .60285 L F P
0 g
s
.235 .391 .816 r
.51576 .58022 m .51134 .57735 L p .51709 .58565 L F P
0 g
s
.157 .343 .799 r
.51134 .57735 m .51576 .58022 L .51251 .57388 L p F P
0 g
s
.157 .343 .799 r
.51251 .57388 m .51115 .57296 L .51134 .57735 L p F P
0 g
s
.833 .737 .758 r
.32923 .67895 m .33076 .67702 L .32728 .67215 L p F P
0 g
s
0 0 .043 r
.53579 .68674 m .53493 .68768 L .53148 .69449 L p F P
0 g
s
.887 .752 .707 r
.32851 .65907 m .33285 .66213 L .32904 .66897 L p F P
0 g
s
.882 .747 .708 r
.33285 .66213 m .32851 .65907 L .33225 .65226 L p F P
0 g
s
.651 .758 .928 r
.74563 .41566 m .75816 .41162 L .76098 .41534 L p F P
0 g
s
.651 .758 .928 r
.75816 .41162 m .74563 .41566 L .74279 .41194 L p F P
0 g
s
.187 .331 .778 r
.52228 .59415 m .52226 .5941 L .52228 .59412 L closepath p F P
0 g
s
.178 .336 .786 r
.51901 .58701 m .51709 .58565 L .51724 .5832 L closepath p F P
0 g
s
.235 .391 .816 r
.51709 .58565 m .51724 .5832 L .51576 .58022 L p F P
0 g
s
.174 .33 .781 r
.52228 .59412 m .52226 .5941 L .51901 .58701 L p F P
0 g
s
.109 .277 .754 r
.5224 .58968 m .52228 .59412 L .52711 .59832 L p F P
0 g
s
.174 .33 .781 r
.51901 .58701 m .5224 .58968 L .52228 .59412 L p F P
0 g
s
.851 .752 .753 r
.32427 .67611 m .32923 .67895 L .32352 .68638 L p F P
0 g
s
.833 .737 .758 r
.32728 .67215 m .32427 .67611 L .32923 .67895 L p F P
0 g
s
0 0 .392 r
.5427 .6664 m .53993 .67045 L .54004 .6762 L p F P
0 g
s
.088 .032 .492 r
.53993 .67045 m .5427 .6664 L .54211 .6601 L p F P
0 g
s
.59 .616 .846 r
.49227 .70914 m .48159 .71084 L .47831 .70493 L p F P
0 g
s
.651 .758 .928 r
.76098 .41534 m .77354 .41129 L .77633 .41502 L p F P
0 g
s
.651 .758 .928 r
.77354 .41129 m .76098 .41534 L .75816 .41162 L p F P
0 g
s
.06 .056 .538 r
.54105 .65332 m .54275 .64959 L p .54229 .65975 L F P
0 g
s
.06 .056 .538 r
.54229 .65975 m .54187 .65858 L .54105 .65332 L p F P
0 g
s
.074 .098 .58 r
.54105 .65332 m .54275 .64959 L .54033 .64456 L p F P
0 g
s
.651 .758 .928 r
.57397 .41543 m .58618 .41139 L .5893 .41512 L p F P
0 g
s
.089 .124 .603 r
.44738 .60068 m .4467 .60225 L .44835 .60966 L p F P
0 g
s
.148 .165 .621 r
.44788 .61059 m .44835 .60966 L .4467 .60225 L p F P
0 g
s
.245 .603 .952 r
.27868 .71266 m .27922 .71277 L .27557 .70967 L p F P
0 g
s
.245 .603 .952 r
.27557 .70967 m .27477 .70952 L .27868 .71266 L p F P
0 g
s
.109 .371 .833 r
.49735 .55705 m .49389 .555 L .49062 .54976 L p F P
0 g
s
.651 .758 .928 r
.77633 .41502 m .78892 .41096 L .79168 .41469 L p F P
0 g
s
.651 .758 .928 r
.78892 .41096 m .77633 .41502 L .77354 .41129 L p F P
0 g
s
.153 .171 .626 r
.44892 .6122 m .44788 .61059 L .44835 .60966 L closepath p F P
0 g
s
.054 .092 .583 r
.54226 .6397 m .54033 .64456 L .54275 .64959 L p F P
0 g
s
.133 .165 .629 r
.53925 .63486 m .54226 .6397 L .54033 .64456 L p F P
0 g
s
.651 .758 .928 r
.5893 .41512 m .60154 .41108 L .60462 .4148 L p F P
0 g
s
.651 .758 .928 r
.60154 .41108 m .5893 .41512 L .58618 .41139 L p F P
0 g
s
.476 .439 .737 r
.46518 .67251 m .45529 .66995 L .46261 .66442 L closepath p F P
0 g
s
.489 .422 .708 r
.4619 .6622 m .46261 .66442 L .45529 .66995 L p F P
0 g
s
.489 .422 .708 r
.45586 .65976 m .4619 .6622 L p .45529 .66995 L F P
0 g
s
.627 .761 .943 r
.27922 .71277 m .29087 .70949 L .29449 .71286 L p F P
0 g
s
.636 .767 .942 r
.29087 .70949 m .27922 .71277 L .27557 .70967 L p F P
0 g
s
.651 .758 .928 r
.79168 .41469 m .80431 .41063 L .80704 .41436 L p F P
0 g
s
.651 .758 .928 r
.80431 .41063 m .79168 .41469 L .78892 .41096 L p F P
0 g
s
.651 .758 .928 r
.60462 .4148 m .6169 .41076 L .61996 .41449 L p F P
0 g
s
.651 .758 .928 r
.6169 .41076 m .60462 .4148 L .60154 .41108 L p F P
0 g
s
0 0 0 r
.53886 .68235 m .53579 .68674 L .53451 .69118 L p F P
0 g
s
0 0 .043 r
.53148 .69449 m .53451 .69118 L .53579 .68674 L p F P
0 g
s
0 0 .168 r
.54004 .6762 m .53886 .68235 L .53579 .68674 L p F P
0 g
s
0 0 0 r
.51222 .7109 m .5243 .70303 L .52467 .70276 L p F P
0 g
s
.776 .92 .933 r
.51072 .7102 m .51222 .7109 L .5243 .70303 L p F P
0 g
s
.651 .758 .928 r
.80704 .41436 m .81969 .4103 L .8224 .41403 L p F P
0 g
s
.651 .758 .928 r
.81969 .4103 m .80704 .41436 L .80431 .41063 L p F P
0 g
s
.651 .758 .928 r
.61996 .41449 m .63226 .41044 L .6353 .41417 L p F P
0 g
s
.651 .758 .928 r
.63226 .41044 m .61996 .41449 L .6169 .41076 L p F P
0 g
s
.778 .792 .864 r
.29609 .71176 m .29449 .71286 L .29087 .70949 L p F P
0 g
s
.345 .316 .683 r
.45539 .63893 m .4511 .6354 L .45375 .6324 L closepath p F P
0 g
s
.345 .317 .684 r
.45215 .62597 m .45148 .62523 L p .4511 .6354 L F P
0 g
s
.345 .317 .684 r
.4511 .6354 m .45375 .6324 L .45215 .62597 L p F P
0 g
s
.854 .75 .748 r
.32352 .68638 m .31849 .69318 L .31495 .68896 L p F P
0 g
s
.854 .75 .748 r
.31495 .68896 m .31889 .68344 L .32352 .68638 L p F P
0 g
s
.851 .752 .753 r
.32352 .68638 m .31889 .68344 L .32427 .67611 L p F P
0 g
s
.651 .758 .928 r
.8224 .41403 m .83509 .40997 L .83777 .4137 L p F P
0 g
s
.651 .758 .928 r
.83509 .40997 m .8224 .41403 L .81969 .4103 L p F P
0 g
s
.778 .792 .864 r
.29087 .70949 m .29199 .70869 L .29609 .71176 L p F P
0 g
s
.757 .773 .866 r
.30281 .70133 m .29199 .70869 L .29609 .71176 L p F P
0 g
s
.757 .773 .866 r
.29609 .71176 m .30639 .70507 L .30281 .70133 L p F P
0 g
s
.899 .771 .712 r
.32839 .64903 m .33225 .65226 L .32851 .65907 L p F P
0 g
s
.895 .77 .716 r
.33225 .65226 m .32839 .64903 L .33219 .6422 L p F P
0 g
s
.798 .744 .803 r
.31969 .69472 m .31849 .69318 L .31781 .69381 L closepath p F P
0 g
s
.651 .758 .928 r
.6353 .41417 m .64763 .41013 L .65064 .41386 L p F P
0 g
s
.651 .758 .928 r
.64763 .41013 m .6353 .41417 L .63226 .41044 L p F P
0 g
s
.207 .208 .64 r
.44835 .60966 m .45011 .60549 L p .45115 .61525 L F P
0 g
s
.207 .208 .64 r
.45115 .61525 m .44892 .6122 L .44835 .60966 L p F P
0 g
s
.089 .124 .603 r
.44835 .60966 m .45011 .60549 L .44738 .60068 L p F P
0 g
s
.036 .465 .879 r
.27477 .70952 m .27103 .70632 L .2626 .70313 L p F P
0 g
s
.848 .517 0 r
.43996 .56709 m .43805 .56316 L .4368 .55797 L p F P
0 g
s
.128 .303 .772 r
.5224 .58968 m .51901 .58701 L .51724 .5832 L p F P
0 g
s
.605 .864 .992 r
.4969 .71297 m .50898 .70923 L .51072 .7102 L p F P
0 g
s
.59 .777 .969 r
.50898 .70923 m .4969 .71297 L .49363 .70892 L p F P
0 g
s
.06 .056 .538 r
.54211 .6601 m .54187 .65858 L .54229 .65975 L closepath p F P
0 g
s
0 0 0 r
.52467 .70276 m .52527 .7021 L .53148 .69449 L p F P
0 g
s
.624 .907 .613 r
.53451 .69118 m .53148 .69449 L .52527 .7021 L p F P
0 g
s
.887 .752 .708 r
.32904 .66897 m .32728 .67215 L .32375 .66787 L p F P
0 g
s
.887 .752 .708 r
.32375 .66787 m .32483 .66587 L .32904 .66897 L p F P
0 g
s
.887 .752 .707 r
.32904 .66897 m .32483 .66587 L .32851 .65907 L p F P
0 g
s
.651 .758 .928 r
.65064 .41386 m .66301 .40981 L .66599 .41354 L p F P
0 g
s
.651 .758 .928 r
.66301 .40981 m .65064 .41386 L .64763 .41013 L p F P
0 g
s
.085 .147 .631 r
.54087 .63007 m .53925 .63486 L .54226 .6397 L p F P
0 g
s
.115 .187 .661 r
.53925 .63486 m .54087 .63007 L .53734 .6254 L p F P
0 g
s
.193 .204 .642 r
.45008 .61716 m .44892 .6122 L .45115 .61525 L closepath p F P
0 g
s
.609 .907 .629 r
.5243 .70303 m .52527 .7021 L .52467 .70276 L closepath p F P
0 g
s
0 0 .524 r
.44838 .59592 m .44738 .60068 L .45011 .60549 L p F P
0 g
s
.091 .125 .604 r
.44615 .59097 m .44838 .59592 L .44738 .60068 L p F P
0 g
s
.651 .758 .928 r
.66599 .41354 m .67838 .40949 L .68134 .41322 L p F P
0 g
s
.651 .758 .928 r
.67838 .40949 m .66599 .41354 L .66301 .40981 L p F P
0 g
s
0 0 .45 r
.54229 .65975 m .54211 .6601 L .5427 .6664 L p F P
0 g
s
.932 .565 .164 r
.43393 .55433 m .4368 .55797 L .43805 .56316 L p F P
0 g
s
.94 .581 .184 r
.4368 .55797 m .43393 .55433 L .43284 .5491 L p F P
0 g
s
.651 .758 .928 r
.68134 .41322 m .69377 .40917 L .6967 .4129 L p F P
0 g
s
.651 .758 .928 r
.69377 .40917 m .68134 .41322 L .67838 .40949 L p F P
0 g
s
.59 .616 .846 r
.47831 .70493 m .49035 .70391 L p .49227 .70914 L F P
0 g
s
.535 .555 .822 r
.48707 .69809 m .49035 .70391 L .47831 .70493 L p F P
0 g
s
.535 .555 .822 r
.48143 .69809 m .48707 .69809 L p .47831 .70493 L F P
0 g
s
.535 .555 .822 r
.47831 .70493 m .47673 .70164 L .48143 .69809 L p F P
0 g
s
.152 .418 .859 r
.49062 .54976 m .48974 .54932 L .48896 .54728 L closepath p F P
0 g
s
.804 .758 .81 r
.31781 .69381 m .31849 .69318 L .31495 .68896 L p F P
0 g
s
.825 .775 .806 r
.31289 .69096 m .31781 .69381 L .30931 .70208 L p F P
0 g
s
.804 .758 .81 r
.31495 .68896 m .31289 .69096 L .31781 .69381 L p F P
0 g
s
.442 .403 .72 r
.4619 .6622 m .45586 .65976 L .46015 .65616 L closepath p F P
0 g
s
.463 .39 .689 r
.45864 .65101 m .46015 .65616 L .45586 .65976 L p F P
0 g
s
.463 .39 .689 r
.45624 .6496 m .45864 .65101 L p .45586 .65976 L F P
0 g
s
0 0 .45 r
.5427 .6664 m .54331 .66523 L .54229 .65975 L p F P
0 g
s
0 0 .438 r
.54454 .65484 m .54229 .65975 L .54331 .66523 L p F P
0 g
s
.06 .056 .538 r
.54275 .64959 m .54454 .65484 L .54229 .65975 L p F P
0 g
s
.128 .303 .772 r
.51724 .5832 m .51714 .58121 L p .5224 .58968 L F P
0 g
s
.137 .328 .792 r
.51724 .5832 m .51576 .58022 L .51714 .58121 L closepath p F P
0 g
s
.851 .759 .761 r
.32427 .67611 m .32728 .67215 L .32375 .66787 L p F P
0 g
s
.189 .2 .64 r
.45115 .61525 m .45008 .61716 L .45185 .62471 L p F P
0 g
s
.267 .254 .659 r
.45148 .62523 m .45185 .62471 L .45008 .61716 L p F P
0 g
s
.651 .758 .928 r
.6967 .4129 m .70915 .40885 L .71206 .41258 L p F P
0 g
s
.651 .758 .928 r
.70915 .40885 m .6967 .4129 L .69377 .40917 L p F P
0 g
s
.722 .989 .84 r
.52527 .7021 m .5243 .70303 L .52109 .70352 L p F P
0 g
s
.624 .907 .613 r
.5332 .69331 m .53451 .69118 L p .52527 .7021 L F P
0 g
s
.722 .989 .84 r
.52109 .70352 m .52999 .69657 L .52527 .7021 L p F P
0 g
s
.624 .907 .613 r
.52527 .7021 m .52999 .69657 L .5332 .69331 L p F P
0 g
s
.776 .92 .933 r
.5243 .70303 m .52109 .70352 L p .51072 .7102 L F P
0 g
s
.83 .774 .799 r
.30931 .70208 m .30639 .70507 L .30281 .70133 L p F P
0 g
s
.83 .774 .799 r
.30281 .70133 m .30493 .69908 L .30931 .70208 L p F P
0 g
s
.825 .775 .806 r
.30931 .70208 m .30493 .69908 L .31289 .69096 L p F P
0 g
s
.115 .204 .68 r
.53861 .62068 m .53734 .6254 L .54087 .63007 L p F P
0 g
s
.124 .219 .692 r
.53734 .6254 m .53861 .62068 L .53464 .61616 L p F P
0 g
s
.651 .758 .928 r
.71206 .41258 m .72454 .40853 L .72742 .41226 L p F P
0 g
s
.651 .758 .928 r
.72454 .40853 m .71206 .41258 L .70915 .40885 L p F P
0 g
s
.27 .258 .661 r
.45215 .62597 m .45148 .62523 L .45185 .62471 L closepath p F P
0 g
s
.109 .371 .833 r
.49062 .54976 m .49585 .553 L .49735 .55705 L p F P
0 g
s
.049 .349 .825 r
.49585 .553 m .49062 .54976 L .48896 .54728 L p F P
0 g
s
0 0 .233 r
.5428 .67222 m .54004 .6762 L .53886 .68235 L p F P
0 g
s
0 0 .392 r
.54004 .6762 m .5428 .67222 L .5427 .6664 L p F P
0 g
s
.69 .888 .97 r
.50898 .70923 m .51375 .7071 L .51072 .7102 L closepath p F P
0 g
s
.776 .92 .933 r
.52109 .70352 m .51375 .7071 L .51072 .7102 L p F P
0 g
s
.121 .363 .824 r
.50444 .56494 m .50341 .56077 L .49735 .55705 L p F P
0 g
s
.097 .366 .831 r
.49585 .553 m .49735 .55705 L .50341 .56077 L p F P
0 g
s
.537 .558 .824 r
.47673 .70164 m .47502 .69813 L .48143 .69809 L closepath p F P
0 g
s
.864 .769 .755 r
.3199 .67307 m .32427 .67611 L .31889 .68344 L p F P
0 g
s
.851 .759 .761 r
.32375 .66787 m .3199 .67307 L .32427 .67611 L p F P
0 g
s
.651 .758 .928 r
.72742 .41226 m .73994 .4082 L .74279 .41194 L p F P
0 g
s
.651 .758 .928 r
.73994 .4082 m .72742 .41226 L .72454 .40853 L p F P
0 g
s
.901 .773 .71 r
.32469 .65584 m .32851 .65907 L .32483 .66587 L p F P
0 g
s
.899 .771 .712 r
.32851 .65907 m .32469 .65584 L .32839 .64903 L p F P
0 g
s
0 0 .389 r
.44599 .58655 m .44615 .59097 L .44838 .59592 L p F P
0 g
s
0 0 .414 r
.44615 .59097 m .44599 .58655 L .44416 .58149 L p F P
0 g
s
.122 .326 .794 r
.51714 .58121 m .51576 .58022 L .51251 .57388 L p F P
0 g
s
.651 .758 .928 r
.74279 .41194 m .75534 .40788 L .75816 .41162 L p F P
0 g
s
.651 .758 .928 r
.75534 .40788 m .74279 .41194 L .73994 .4082 L p F P
0 g
s
.287 .269 .665 r
.45185 .62471 m .45451 .61991 L p .45562 .62966 L F P
0 g
s
.287 .269 .665 r
.45562 .62966 m .45215 .62597 L .45185 .62471 L p F P
0 g
s
.189 .2 .64 r
.45185 .62471 m .45451 .61991 L .45115 .61525 L p F P
0 g
s
.121 .234 .709 r
.53555 .61153 m .53464 .61616 L .53861 .62068 L p F P
0 g
s
.126 .244 .717 r
.53464 .61616 m .53555 .61153 L .53121 .60714 L p F P
0 g
s
.269 .266 .671 r
.45375 .6324 m .45215 .62597 L .45562 .62966 L closepath p F P
0 g
s
.651 .758 .928 r
.75816 .41162 m .77074 .40755 L .77354 .41129 L p F P
0 g
s
.651 .758 .928 r
.77074 .40755 m .75816 .41162 L .75534 .40788 L p F P
0 g
s
.202 .405 .838 r
.50925 .56793 m .50444 .56494 L p .51115 .57296 L F P
0 g
s
.106 .35 .818 r
.50444 .56494 m .50925 .56793 L .50598 .56242 L p F P
0 g
s
.106 .35 .818 r
.50598 .56242 m .50341 .56077 L .50444 .56494 L p F P
0 g
s
.26 .606 .954 r
.27477 .70952 m .27557 .70967 L .27191 .70648 L p F P
0 g
s
.26 .606 .954 r
.27191 .70648 m .27103 .70632 L .27477 .70952 L p F P
0 g
s
.651 .758 .928 r
.77354 .41129 m .78615 .40722 L .78892 .41096 L p F P
0 g
s
.651 .758 .928 r
.78615 .40722 m .77354 .41129 L .77074 .40755 L p F P
0 g
s
.542 .534 .796 r
.48143 .69809 m .47502 .69813 L .47207 .69123 L p F P
0 g
s
.651 .758 .928 r
.58618 .41139 m .59844 .40733 L .60154 .41108 L p F P
0 g
s
.127 .264 .736 r
.53175 .6026 m .53121 .60714 L .53555 .61153 L p F P
0 g
s
.12 .263 .737 r
.53121 .60714 m .53175 .6026 L .52711 .59832 L p F P
0 g
s
.401 .364 .703 r
.45864 .65101 m .45624 .6496 L .45785 .64807 L closepath p F P
0 g
s
.401 .365 .703 r
.45624 .6496 m .45785 .64807 L .45571 .64014 L p F P
0 g
s
0 .021 .526 r
.54475 .64472 m .54275 .64959 L .54454 .65484 L p F P
0 g
s
.054 .092 .583 r
.54275 .64959 m .54475 .64472 L .54226 .6397 L p F P
0 g
s
.587 .651 .88 r
.49363 .70892 m .49227 .70914 L .49331 .70842 L closepath p F P
0 g
s
.59 .616 .846 r
.49035 .70391 m .49331 .70842 L .49227 .70914 L p F P
0 g
s
.129 .339 .804 r
.51251 .57388 m .51115 .57296 L .51089 .57082 L closepath p F P
0 g
s
.202 .405 .838 r
.51115 .57296 m .51089 .57082 L .50925 .56793 L p F P
0 g
s
.636 .767 .942 r
.27557 .70967 m .28725 .70616 L .29087 .70949 L p F P
0 g
s
.638 .772 .944 r
.28725 .70616 m .27557 .70967 L .27191 .70648 L p F P
0 g
s
.651 .758 .928 r
.78892 .41096 m .80156 .40689 L .80431 .41063 L p F P
0 g
s
.651 .758 .928 r
.80156 .40689 m .78892 .41096 L .78615 .40722 L p F P
0 g
s
.651 .758 .928 r
.60154 .41108 m .61383 .40702 L .6169 .41076 L p F P
0 g
s
.651 .758 .928 r
.61383 .40702 m .60154 .41108 L .59844 .40733 L p F P
0 g
s
.347 .318 .684 r
.45375 .6324 m .45562 .62966 L p .45617 .63957 L F P
0 g
s
.347 .318 .684 r
.45617 .63957 m .45539 .63893 L .45375 .6324 L p F P
0 g
s
.049 .349 .825 r
.48896 .54728 m .48802 .54533 L p .49585 .553 L F P
0 g
s
.867 .767 .751 r
.31889 .68344 m .31495 .68896 L .31139 .6851 L p F P
0 g
s
.867 .767 .751 r
.31139 .6851 m .3147 .68035 L .31889 .68344 L p F P
0 g
s
.864 .769 .755 r
.31889 .68344 m .3147 .68035 L .3199 .67307 L p F P
0 g
s
.131 .293 .762 r
.52727 .59387 m .52711 .59832 L .53175 .6026 L p F P
0 g
s
.109 .277 .754 r
.52711 .59832 m .52727 .59387 L .5224 .58968 L p F P
0 g
s
0 0 .335 r
.54331 .66523 m .5427 .6664 L .5428 .67222 L p F P
0 g
s
0 .076 .596 r
.45284 .61032 m .45115 .61525 L .45451 .61991 L p F P
0 g
s
.207 .208 .64 r
.45011 .60549 m .45284 .61032 L .45115 .61525 L p F P
0 g
s
.128 .303 .772 r
.51714 .58121 m .52217 .58532 L .5224 .58968 L p F P
0 g
s
.063 .282 .771 r
.51653 .57694 m .51714 .58121 L .52217 .58532 L p F P
0 g
s
.122 .326 .794 r
.51251 .57388 m .51653 .57694 L .51714 .58121 L p F P
0 g
s
.087 .277 .761 r
.52217 .58532 m .5224 .58968 L .52727 .59387 L p F P
0 g
s
.651 .758 .928 r
.80431 .41063 m .81698 .40656 L .81969 .4103 L p F P
0 g
s
.651 .758 .928 r
.81698 .40656 m .80431 .41063 L .80156 .40689 L p F P
0 g
s
.784 .797 .863 r
.29199 .70869 m .29087 .70949 L .28725 .70616 L p F P
0 g
s
.651 .758 .928 r
.6169 .41076 m .62922 .4067 L .63226 .41044 L p F P
0 g
s
.651 .758 .928 r
.62922 .4067 m .6169 .41076 L .61383 .40702 L p F P
0 g
s
.784 .797 .863 r
.28725 .70616 m .28808 .70554 L .29199 .70869 L p F P
0 g
s
.767 .784 .867 r
.29921 .69777 m .28808 .70554 L .29199 .70869 L p F P
0 g
s
.767 .784 .867 r
.29199 .70869 m .30281 .70133 L .29921 .69777 L p F P
0 g
s
.59 .777 .969 r
.49363 .70892 m .50573 .70629 L .50898 .70923 L p F P
0 g
s
.572 .644 .883 r
.50246 .70238 m .50573 .70629 L .49363 .70892 L p F P
0 g
s
.572 .644 .883 r
.50024 .70265 m .50246 .70238 L p .49363 .70892 L F P
0 g
s
.572 .644 .883 r
.49363 .70892 m .49331 .70842 L .50024 .70265 L p F P
0 g
s
.651 .758 .928 r
.81969 .4103 m .83239 .40623 L .83509 .40997 L p F P
0 g
s
.651 .758 .928 r
.83239 .40623 m .81969 .4103 L .81698 .40656 L p F P
0 g
s
.651 .758 .928 r
.63226 .41044 m .64462 .40638 L .64763 .41013 L p F P
0 g
s
.651 .758 .928 r
.64462 .40638 m .63226 .41044 L .62922 .4067 L p F P
0 g
s
.901 .773 .711 r
.32483 .66587 m .32375 .66787 L .32019 .66423 L p F P
0 g
s
.901 .773 .711 r
.32019 .66423 m .32105 .66264 L .32483 .66587 L p F P
0 g
s
.901 .773 .71 r
.32483 .66587 m .32105 .66264 L .32469 .65584 L p F P
0 g
s
.854 .509 0 r
.44145 .57222 m .4394 .56834 L .43805 .56316 L p F P
0 g
s
.574 .647 .884 r
.49331 .70842 m .49035 .70391 L .50024 .70265 L closepath p F P
0 g
s
.329 .317 .694 r
.45571 .64014 m .45539 .63893 L .45617 .63957 L closepath p F P
0 g
s
.327 .316 .694 r
.45617 .63957 m .45571 .64014 L .45785 .64807 L p F P
0 g
s
.542 .534 .796 r
.47207 .69123 m .47291 .69056 L p .48143 .69809 L F P
0 g
s
.512 .52 .801 r
.47207 .69123 m .47174 .69047 L .47291 .69056 L closepath p F P
0 g
s
.651 .758 .928 r
.64763 .41013 m .66002 .40606 L .66301 .40981 L p F P
0 g
s
.651 .758 .928 r
.66002 .40606 m .64763 .41013 L .64462 .40638 L p F P
0 g
s
0 0 0 r
.5332 .69331 m .53603 .68899 L .53451 .69118 L closepath p F P
0 g
s
0 0 0 r
.53451 .69118 m .53603 .68899 L .53886 .68235 L p F P
0 g
s
.518 .5 .775 r
.47291 .69056 m .47174 .69047 L .46845 .68193 L p F P
0 g
s
.614 .881 .99 r
.51375 .7071 m .50898 .70923 L .50573 .70629 L p F P
0 g
s
.068 .299 .784 r
.51653 .57694 m .51251 .57388 L .51089 .57082 L p F P
0 g
s
.818 .775 .812 r
.31289 .69096 m .31495 .68896 L .31139 .6851 L p F P
0 g
s
.834 .786 .806 r
.30854 .68793 m .31289 .69096 L .30493 .69908 L p F P
0 g
s
.818 .775 .812 r
.31139 .6851 m .30854 .68793 L .31289 .69096 L p F P
0 g
s
.651 .758 .928 r
.66301 .40981 m .67542 .40574 L .67838 .40949 L p F P
0 g
s
.651 .758 .928 r
.67542 .40574 m .66301 .40981 L .66002 .40606 L p F P
0 g
s
.867 .783 .766 r
.3199 .67307 m .32375 .66787 L .32019 .66423 L p F P
0 g
s
.927 .553 .149 r
.43513 .55953 m .43805 .56316 L .4394 .56834 L p F P
0 g
s
.932 .565 .164 r
.43805 .56316 m .43513 .55953 L .43393 .55433 L p F P
0 g
s
0 0 0 r
.5423 .67743 m .53886 .68235 L .53603 .68899 L p F P
0 g
s
0 0 .233 r
.53886 .68235 m .5423 .67743 L .5428 .67222 L p F P
0 g
s
.037 .088 .587 r
.54398 .63489 m .54226 .6397 L .54475 .64472 L p F P
0 g
s
.085 .147 .631 r
.54226 .6397 m .54398 .63489 L .54087 .63007 L p F P
0 g
s
0 0 .335 r
.5428 .67222 m .54343 .67099 L .54331 .66523 L p F P
0 g
s
0 0 .309 r
.54557 .66032 m .54331 .66523 L .54343 .67099 L p F P
0 g
s
0 0 .438 r
.54331 .66523 m .54557 .66032 L .54454 .65484 L p F P
0 g
s
.327 .316 .694 r
.45785 .64807 m .46127 .64375 L .45617 .63957 L p F P
0 g
s
.21 .247 .682 r
.45973 .63413 m .45617 .63957 L .46127 .64375 L p F P
0 g
s
.347 .318 .684 r
.45562 .62966 m .45973 .63413 L .45617 .63957 L p F P
0 g
s
.651 .758 .928 r
.67838 .40949 m .69083 .40542 L .69377 .40917 L p F P
0 g
s
.651 .758 .928 r
.69083 .40542 m .67838 .40949 L .67542 .40574 L p F P
0 g
s
0 0 .509 r
.45063 .60089 m .45011 .60549 L .45284 .61032 L p F P
0 g
s
0 0 .524 r
.45011 .60549 m .45063 .60089 L .44838 .59592 L p F P
0 g
s
.393 .359 .702 r
.45785 .64807 m .46127 .64375 L p .4626 .65343 L F P
0 g
s
.393 .359 .702 r
.4626 .65343 m .45864 .65101 L .45785 .64807 L p F P
0 g
s
.838 .785 .801 r
.30493 .69908 m .30281 .70133 L .29921 .69777 L p F P
0 g
s
.838 .785 .801 r
.29921 .69777 m .30087 .69597 L .30493 .69908 L p F P
0 g
s
.834 .786 .806 r
.30493 .69908 m .30087 .69597 L .30854 .68793 L p F P
0 g
s
.542 .534 .796 r
.47291 .69056 m .48378 .6915 L p .48143 .69809 L F P
0 g
s
.477 .476 .777 r
.47291 .69056 m .48378 .6915 L .48048 .68422 L p F P
0 g
s
.477 .476 .777 r
.48048 .68422 m .48024 .68417 L .47291 .69056 L p F P
0 g
s
.518 .5 .775 r
.46845 .68193 m .48024 .68417 L .47291 .69056 L p F P
0 g
s
.377 .362 .716 r
.46015 .65616 m .45864 .65101 L .4626 .65343 L closepath p F P
0 g
s
.502 .47 .754 r
.46845 .68193 m .46826 .6819 L .46841 .6818 L closepath p F P
0 g
s
.511 .452 .726 r
.46532 .67292 m .46841 .6818 L .46826 .6819 L p F P
0 g
s
.651 .758 .928 r
.69377 .40917 m .70624 .4051 L .70915 .40885 L p F P
0 g
s
.651 .758 .928 r
.70624 .4051 m .69377 .40917 L .69083 .40542 L p F P
0 g
s
.49 .462 .754 r
.48024 .68417 m .46845 .68193 L .46841 .6818 L p F P
0 g
s
.49 .462 .754 r
.46841 .6818 m .47518 .6756 L p .48024 .68417 L F P
0 g
s
.45 .44 .756 r
.46562 .67264 m .46532 .67292 L .46841 .6818 L p F P
0 g
s
.45 .44 .756 r
.46841 .6818 m .47518 .6756 L .46562 .67264 L p F P
0 g
s
.432 .397 .719 r
.46015 .65616 m .4626 .65343 L p .46393 .6631 L F P
0 g
s
.432 .397 .719 r
.46393 .6631 m .4619 .6622 L .46015 .65616 L p F P
0 g
s
.049 .349 .825 r
.48802 .54533 m .49396 .54907 L .49585 .553 L p F P
0 g
s
0 .333 .816 r
.4857 .54151 m .48802 .54533 L .49396 .54907 L p F P
0 g
s
.651 .758 .928 r
.70915 .40885 m .72166 .40478 L .72454 .40853 L p F P
0 g
s
.651 .758 .928 r
.72166 .40478 m .70915 .40885 L .70624 .4051 L p F P
0 g
s
.875 .786 .759 r
.31605 .66986 m .3199 .67307 L .3147 .68035 L p F P
0 g
s
.867 .783 .766 r
.32019 .66423 m .31605 .66986 L .3199 .67307 L p F P
0 g
s
.068 .299 .784 r
.51089 .57082 m .5104 .56872 L p .51653 .57694 L F P
0 g
s
.086 .329 .805 r
.51089 .57082 m .50925 .56793 L .5104 .56872 L closepath p F P
0 g
s
.614 .881 .99 r
.51872 .70259 m .51375 .7071 L p .50573 .70629 L F P
0 g
s
.692 .925 .969 r
.51375 .7071 m .51872 .70259 L .52109 .70352 L closepath p F P
0 g
s
.418 .404 .737 r
.46261 .66442 m .4619 .6622 L .46393 .6631 L closepath p F P
0 g
s
.464 .432 .737 r
.46261 .66442 m .46393 .6631 L p .46562 .67264 L F P
0 g
s
.464 .432 .737 r
.46562 .67264 m .46518 .67251 L .46261 .66442 L p F P
0 g
s
.453 .444 .758 r
.46532 .67292 m .46518 .67251 L .46562 .67264 L closepath p F P
0 g
s
.651 .758 .928 r
.72454 .40853 m .73708 .40445 L .73994 .4082 L p F P
0 g
s
.651 .758 .928 r
.73708 .40445 m .72454 .40853 L .72166 .40478 L p F P
0 g
s
.058 .138 .633 r
.54189 .62654 m .54087 .63007 L .54398 .63489 L p F P
0 g
s
.115 .204 .68 r
.54105 .6239 m .53861 .62068 L p .54087 .63007 L F P
0 g
s
.115 .204 .68 r
.54087 .63007 m .54189 .62654 L .54105 .6239 L p F P
0 g
s
.435 .45 .777 r
.47161 .66659 m .46562 .67264 L .47518 .6756 L p F P
0 g
s
.464 .432 .737 r
.46393 .6631 m .47161 .66659 L .46562 .67264 L p F P
0 g
s
0 0 .366 r
.44788 .59161 m .44838 .59592 L .45063 .60089 L p F P
0 g
s
0 0 .366 r
.44983 .59667 m .44788 .59161 L p .44809 .5923 L F P
0 g
s
0 0 .366 r
.45063 .60089 m .44983 .59667 L p .44809 .5923 L F P
0 g
s
.674 .33 0 r
.44983 .59667 m .44879 .59422 L .45072 .59887 L p F P
0 g
s
0 0 .427 r
.45084 .59917 m .44983 .59667 L p .45293 .60585 L F P
0 g
s
.674 .33 0 r
.45072 .59887 m .45084 .59917 L .44983 .59667 L p F P
0 g
s
.687 .345 0 r
.44788 .59161 m .44983 .59667 L p .44966 .59621 L F P
0 g
s
0 0 .389 r
.44838 .59592 m .44788 .59161 L p .44611 .58702 L F P
0 g
s
.687 .345 0 r
.44631 .58761 m .44788 .59161 L p .44966 .59621 L F P
0 g
s
0 0 .389 r
.44788 .59161 m .44599 .58655 L p .44611 .58702 L F P
0 g
s
.651 .758 .928 r
.73994 .4082 m .7525 .40413 L .75534 .40788 L p F P
0 g
s
.651 .758 .928 r
.7525 .40413 m .73994 .4082 L .73708 .40445 L p F P
0 g
s
.533 .562 .83 r
.48707 .69809 m .48143 .69809 L .48546 .69486 L closepath p F P
0 g
s
.542 .534 .796 r
.48378 .6915 m .48546 .69486 L .48143 .69809 L p F P
0 g
s
.097 .366 .831 r
.50341 .56077 m .50202 .5567 L .49585 .553 L p F P
0 g
s
.132 .418 .862 r
.49396 .54907 m .49585 .553 L .50202 .5567 L p F P
0 g
s
.651 .758 .928 r
.75534 .40788 m .76793 .4038 L .77074 .40755 L p F P
0 g
s
.651 .758 .928 r
.76793 .4038 m .75534 .40788 L .7525 .40413 L p F P
0 g
s
.152 .231 .692 r
.45786 .62459 m .45562 .62966 L .45973 .63413 L p F P
0 g
s
.287 .269 .665 r
.45451 .61991 m .45786 .62459 L .45562 .62966 L p F P
0 g
s
0 0 .161 r
.54343 .67099 m .5428 .67222 L .5423 .67743 L p F P
0 g
s
.578 .614 .852 r
.50024 .70265 m .49035 .70391 L .48707 .69809 L p F P
0 g
s
.651 .758 .928 r
.77074 .40755 m .78337 .40347 L .78615 .40722 L p F P
0 g
s
.651 .758 .928 r
.78337 .40347 m .77074 .40755 L .76793 .4038 L p F P
0 g
s
.061 .325 .806 r
.5104 .56872 m .50925 .56793 L .50598 .56242 L p F P
0 g
s
0 0 0 r
.54209 .6783 m .5423 .67743 L p .53603 .68899 L F P
0 g
s
0 0 0 r
.53603 .68899 m .5395 .68378 L .54209 .6783 L p F P
0 g
s
.843 .961 .627 r
.53603 .68899 m .5395 .68378 L p .53194 .69435 L F P
0 g
s
.843 .961 .627 r
.53194 .69435 m .5332 .69331 L .53603 .68899 L p F P
0 g
s
0 0 .443 r
.54662 .64995 m .54454 .65484 L .54557 .66032 L p F P
0 g
s
0 .021 .526 r
.54454 .65484 m .54662 .64995 L .54475 .64472 L p F P
0 g
s
.058 .166 .663 r
.54105 .6239 m .53861 .62068 L .53918 .61803 L closepath p F P
0 g
s
.121 .234 .709 r
.53778 .6141 m .53555 .61153 L p .53861 .62068 L F P
0 g
s
.121 .234 .709 r
.53861 .62068 m .53918 .61803 L .53778 .6141 L p F P
0 g
s
.877 .785 .755 r
.3147 .68035 m .31139 .6851 L .30779 .68162 L p F P
0 g
s
.877 .785 .755 r
.30779 .68162 m .3109 .67713 L .3147 .68035 L p F P
0 g
s
.875 .786 .759 r
.3147 .68035 m .3109 .67713 L .31605 .66986 L p F P
0 g
s
.718 .393 0 r
.44462 .58248 m .44599 .58655 L .44788 .59161 L p F P
0 g
s
.691 .386 0 r
.44599 .58655 m .44462 .58248 L .443 .57735 L p F P
0 g
s
.651 .758 .928 r
.78615 .40722 m .7988 .40314 L .80156 .40689 L p F P
0 g
s
.651 .758 .928 r
.7988 .40314 m .78615 .40722 L .78337 .40347 L p F P
0 g
s
.638 .772 .944 r
.27191 .70648 m .2836 .70288 L .28725 .70616 L p F P
0 g
s
.651 .758 .928 r
.59844 .40733 m .61075 .40326 L .61383 .40702 L p F P
0 g
s
.39 .41 .76 r
.46879 .65734 m .46393 .6631 L .47161 .66659 L p F P
0 g
s
.432 .397 .719 r
.4626 .65343 m .46879 .65734 L .46393 .6631 L p F P
0 g
s
.062 .337 .815 r
.50341 .56077 m .50598 .56242 L .50271 .55715 L p F P
0 g
s
.062 .337 .815 r
.50271 .55715 m .50202 .5567 L .50341 .56077 L p F P
0 g
s
.818 .936 .907 r
.51872 .70259 m .52109 .70352 L .52999 .69657 L p F P
0 g
s
.787 .801 .864 r
.28808 .70554 m .28725 .70616 L .2836 .70288 L p F P
0 g
s
.651 .758 .928 r
.80156 .40689 m .81425 .40281 L .81698 .40656 L p F P
0 g
s
.651 .758 .928 r
.81425 .40281 m .80156 .40689 L .7988 .40314 L p F P
0 g
s
.787 .801 .864 r
.2836 .70288 m .28435 .70233 L .28808 .70554 L p F P
0 g
s
.775 .797 .871 r
.29559 .6944 m .28435 .70233 L .28808 .70554 L p F P
0 g
s
.775 .797 .871 r
.28808 .70554 m .29921 .69777 L .29559 .6944 L p F P
0 g
s
.651 .758 .928 r
.61383 .40702 m .62617 .40294 L .62922 .4067 L p F P
0 g
s
.651 .758 .928 r
.62617 .40294 m .61383 .40702 L .61075 .40326 L p F P
0 g
s
.651 .758 .928 r
.81698 .40656 m .82969 .40247 L .83239 .40623 L p F P
0 g
s
.651 .758 .928 r
.82969 .40247 m .81698 .40656 L .81425 .40281 L p F P
0 g
s
.06 .195 .692 r
.53778 .6141 m .53555 .61153 L .53591 .60892 L closepath p F P
0 g
s
.127 .264 .736 r
.53451 .60542 m .53175 .6026 L p .53555 .61153 L F P
0 g
s
.127 .264 .736 r
.53555 .61153 m .53591 .60892 L .53451 .60542 L p F P
0 g
s
.857 .502 0 r
.443 .57735 m .44083 .57351 L .4394 .56834 L p F P
0 g
s
.651 .758 .928 r
.62922 .4067 m .64159 .40263 L .64462 .40638 L p F P
0 g
s
.651 .758 .928 r
.64159 .40263 m .62922 .4067 L .62617 .40294 L p F P
0 g
s
.6 .89 .589 r
.52999 .69657 m .53194 .69435 L .5332 .69331 L closepath p F P
0 g
s
.007 .132 .646 r
.4556 .61516 m .45451 .61991 L .45786 .62459 L p F P
0 g
s
0 .076 .596 r
.45451 .61991 m .4556 .61516 L .45284 .61032 L p F P
0 g
s
.068 .299 .784 r
.5104 .56872 m .51558 .57277 L .51653 .57694 L p F P
0 g
s
0 .276 .778 r
.50908 .56464 m .5104 .56872 L .51558 .57277 L p F P
0 g
s
.061 .325 .806 r
.50598 .56242 m .50908 .56464 L .5104 .56872 L p F P
0 g
s
0 0 .161 r
.5423 .67743 m .54248 .67708 L .54343 .67099 L p F P
0 g
s
0 0 .098 r
.54567 .66609 m .54343 .67099 L .54248 .67708 L p F P
0 g
s
0 0 .309 r
.54343 .67099 m .54567 .66609 L .54557 .66032 L p F P
0 g
s
.818 .936 .907 r
.52999 .69657 m .53194 .69435 L p .51872 .70259 L F P
0 g
s
.83 .793 .817 r
.30854 .68793 m .31139 .6851 L .30779 .68162 L p F P
0 g
s
.651 .758 .928 r
.64462 .40638 m .65701 .40231 L .66002 .40606 L p F P
0 g
s
.651 .758 .928 r
.65701 .40231 m .64462 .40638 L .64159 .40263 L p F P
0 g
s
.84 .797 .81 r
.30469 .68473 m .30854 .68793 L .30087 .69597 L p F P
0 g
s
.83 .793 .817 r
.30779 .68162 m .30469 .68473 L .30854 .68793 L p F P
0 g
s
.061 .223 .719 r
.53451 .60542 m .53175 .6026 L .53194 .59908 L closepath p F P
0 g
s
.131 .293 .762 r
.53125 .59751 m .52727 .59387 L p .53175 .6026 L F P
0 g
s
.131 .293 .762 r
.53175 .6026 m .53194 .59908 L .53125 .59751 L p F P
0 g
s
.063 .282 .771 r
.52217 .58532 m .52162 .58105 L .51653 .57694 L p F P
0 g
s
.037 .281 .776 r
.51558 .57277 m .51653 .57694 L .52162 .58105 L p F P
0 g
s
.921 .541 .135 r
.43643 .56473 m .4394 .56834 L .44083 .57351 L p F P
0 g
s
.927 .553 .149 r
.4394 .56834 m .43643 .56473 L .43513 .55953 L p F P
0 g
s
.614 .881 .99 r
.50573 .70629 m .51786 .70217 L .51872 .70259 L p F P
0 g
s
.588 .801 .981 r
.51786 .70217 m .50573 .70629 L .50246 .70238 L p F P
0 g
s
.039 .23 .732 r
.52727 .59387 m .53125 .59751 L .52799 .59033 L p F P
0 g
s
.039 .23 .732 r
.52799 .59033 m .52712 .58949 L .52727 .59387 L p F P
0 g
s
.087 .277 .761 r
.52727 .59387 m .52712 .58949 L .52217 .58532 L p F P
0 g
s
.091 .303 .782 r
.52162 .58105 m .52217 .58532 L .52712 .58949 L p F P
0 g
s
.651 .758 .928 r
.66002 .40606 m .67244 .40198 L .67542 .40574 L p F P
0 g
s
.651 .758 .928 r
.67244 .40198 m .66002 .40606 L .65701 .40231 L p F P
0 g
s
.333 .363 .743 r
.46629 .64799 m .4626 .65343 L .46879 .65734 L p F P
0 g
s
.393 .359 .702 r
.46127 .64375 m .46629 .64799 L .4626 .65343 L p F P
0 g
s
.845 .796 .804 r
.30087 .69597 m .29921 .69777 L .29559 .6944 L p F P
0 g
s
.845 .796 .804 r
.29559 .6944 m .2971 .69276 L .30087 .69597 L p F P
0 g
s
.84 .797 .81 r
.30087 .69597 m .2971 .69276 L .30469 .68473 L p F P
0 g
s
.651 .758 .928 r
.67542 .40574 m .68788 .40166 L .69083 .40542 L p F P
0 g
s
.651 .758 .928 r
.68788 .40166 m .67542 .40574 L .67244 .40198 L p F P
0 g
s
0 .006 .522 r
.54577 .64195 m .54475 .64472 L .54662 .64995 L p F P
0 g
s
.037 .088 .587 r
.54435 .63566 m .54398 .63489 L p .54475 .64472 L F P
0 g
s
.037 .088 .587 r
.54475 .64472 m .54577 .64195 L .54435 .63566 L p F P
0 g
s
.578 .614 .852 r
.48707 .69809 m .49918 .69763 L p .50024 .70265 L F P
0 g
s
.51 .55 .832 r
.49589 .6922 m .49918 .69763 L .48707 .69809 L p F P
0 g
s
.51 .55 .832 r
.48871 .69175 m .49589 .6922 L p .48707 .69809 L F P
0 g
s
.51 .55 .832 r
.48707 .69809 m .48546 .69486 L .48871 .69175 L p F P
0 g
s
.651 .758 .928 r
.69083 .40542 m .70332 .40134 L .70624 .4051 L p F P
0 g
s
.651 .758 .928 r
.70332 .40134 m .69083 .40542 L .68788 .40166 L p F P
0 g
s
0 0 .565 r
.45293 .60585 m .45284 .61032 L .4556 .61516 L p F P
0 g
s
0 0 .509 r
.45284 .61032 m .45293 .60585 L .45063 .60089 L p F P
0 g
s
.651 .758 .928 r
.70624 .4051 m .71876 .40102 L .72166 .40478 L p F P
0 g
s
.651 .758 .928 r
.71876 .40102 m .70624 .4051 L .70332 .40134 L p F P
0 g
s
.003 .299 .793 r
.50908 .56464 m .50598 .56242 L .50271 .55715 L p F P
0 g
s
0 .333 .816 r
.49396 .54907 m .49167 .54523 L .4857 .54151 L p F P
0 g
s
0 .323 .806 r
.48298 .5378 m .4857 .54151 L .49167 .54523 L p F P
0 g
s
.651 .758 .928 r
.72166 .40478 m .73421 .40069 L .73708 .40445 L p F P
0 g
s
.651 .758 .928 r
.73421 .40069 m .72166 .40478 L .71876 .40102 L p F P
0 g
s
.259 .307 .722 r
.46383 .63862 m .46127 .64375 L .46629 .64799 L p F P
0 g
s
.21 .247 .682 r
.46127 .64375 m .46383 .63862 L .45973 .63413 L p F P
0 g
s
.651 .758 .928 r
.73708 .40445 m .74966 .40036 L .7525 .40413 L p F P
0 g
s
.651 .758 .928 r
.74966 .40036 m .73708 .40445 L .73421 .40069 L p F P
0 g
s
.002 .128 .643 r
.53918 .61803 m .53937 .6161 L p .54208 .62538 L F P
0 g
s
.002 .128 .643 r
.54208 .62538 m .54105 .6239 L .53918 .61803 L p F P
0 g
s
.012 .16 .673 r
.53918 .61803 m .53778 .6141 L .53937 .6161 L closepath p F P
0 g
s
.512 .553 .835 r
.48546 .69486 m .48378 .6915 L .48871 .69175 L closepath p F P
0 g
s
.006 .129 .644 r
.54189 .62654 m .54105 .6239 L .54208 .62538 L closepath p F P
0 g
s
0 .046 .583 r
.54208 .62538 m .54189 .62654 L .54409 .63452 L p F P
0 g
s
.058 .138 .633 r
.54398 .63489 m .54409 .63452 L .54189 .62654 L p F P
0 g
s
0 0 .427 r
.44983 .59667 m .45063 .60089 L .45293 .60585 L p F P
0 g
s
0 .049 .567 r
.54435 .63566 m .54398 .63489 L .54409 .63452 L closepath p F P
0 g
s
.006 .158 .673 r
.53937 .6161 m .53778 .6141 L .53591 .60892 L p F P
0 g
s
.651 .758 .928 r
.7525 .40413 m .76511 .40004 L .76793 .4038 L p F P
0 g
s
.651 .758 .928 r
.76511 .40004 m .7525 .40413 L .74966 .40036 L p F P
0 g
s
0 0 0 r
.54209 .6783 m .54248 .67708 L .5423 .67743 L closepath p F P
0 g
s
0 0 .312 r
.54773 .65542 m .54557 .66032 L .54567 .66609 L p F P
0 g
s
0 0 .443 r
.54557 .66032 m .54773 .65542 L .54662 .64995 L p F P
0 g
s
.786 .996 .791 r
.53001 .69497 m .5338 .69127 L .53194 .69435 L closepath p F P
0 g
s
.843 .961 .627 r
.5395 .68378 m .5338 .69127 L .53194 .69435 L p F P
0 g
s
.818 .936 .907 r
.53194 .69435 m .53001 .69497 L p .51872 .70259 L F P
0 g
s
.651 .758 .928 r
.76793 .4038 m .78057 .39971 L .78337 .40347 L p F P
0 g
s
.651 .758 .928 r
.78057 .39971 m .76793 .4038 L .76511 .40004 L p F P
0 g
s
.006 .158 .673 r
.53591 .60892 m .53596 .60703 L p .53937 .6161 L F P
0 g
s
.019 .191 .701 r
.53591 .60892 m .53451 .60542 L .53596 .60703 L closepath p F P
0 g
s
0 0 .536 r
.54409 .63452 m .54477 .63033 L p .54622 .63999 L F P
0 g
s
0 0 .536 r
.54622 .63999 m .54435 .63566 L .54409 .63452 L p F P
0 g
s
0 .046 .583 r
.54409 .63452 m .54477 .63033 L .54208 .62538 L p F P
0 g
s
.132 .418 .862 r
.49943 .55233 m .49396 .54907 L p .50202 .5567 L F P
0 g
s
0 .345 .823 r
.49396 .54907 m .49943 .55233 L .49614 .54793 L p F P
0 g
s
0 .345 .823 r
.49614 .54793 m .49167 .54523 L .49396 .54907 L p F P
0 g
s
0 0 0 r
.5395 .68378 m .54087 .68171 L .54209 .6783 L closepath p F P
0 g
s
.74 .773 .274 r
.54087 .68171 m .54209 .6783 L .54248 .67708 L p F P
0 g
s
.74 .773 .274 r
.54248 .67708 m .54463 .67222 L p .54087 .68171 L F P
0 g
s
0 0 .098 r
.54248 .67708 m .54463 .67222 L .54567 .66609 L p F P
0 g
s
0 0 .537 r
.54577 .64195 m .54435 .63566 L .54622 .63999 L closepath p F P
0 g
s
.569 .658 .897 r
.50246 .70238 m .50024 .70265 L .50165 .70121 L closepath p F P
0 g
s
.578 .614 .852 r
.49918 .69763 m .50165 .70121 L .50024 .70265 L p F P
0 g
s
.718 .393 0 r
.44788 .59161 m .44631 .58761 L .44462 .58248 L p F P
0 g
s
.651 .758 .928 r
.78337 .40347 m .79604 .39937 L .7988 .40314 L p F P
0 g
s
.651 .758 .928 r
.79604 .39937 m .78337 .40347 L .78057 .39971 L p F P
0 g
s
.726 .909 .958 r
.51786 .70217 m .51965 .70122 L .51872 .70259 L closepath p F P
0 g
s
.818 .936 .907 r
.53001 .69497 m .51965 .70122 L .51872 .70259 L p F P
0 g
s
.519 .534 .811 r
.48871 .69175 m .48378 .6915 L .48048 .68422 L p F P
0 g
s
.157 .235 .694 r
.46115 .62988 m .45973 .63413 L .46383 .63862 L p F P
0 g
s
.152 .231 .692 r
.46073 .62856 m .45786 .62459 L p .45973 .63413 L F P
0 g
s
.152 .231 .692 r
.45973 .63413 m .46115 .62988 L .46073 .62856 L p F P
0 g
s
.01 .188 .701 r
.53596 .60703 m .53451 .60542 L .53194 .59908 L p F P
0 g
s
.651 .758 .928 r
.7988 .40314 m .81151 .39904 L .81425 .40281 L p F P
0 g
s
.651 .758 .928 r
.81151 .39904 m .7988 .40314 L .79604 .39937 L p F P
0 g
s
.651 .758 .928 r
.61075 .40326 m .6231 .39918 L .62617 .40294 L p F P
0 g
s
0 .03 .578 r
.54251 .6209 m .54208 .62538 L .54477 .63033 L p F P
0 g
s
.002 .128 .643 r
.53937 .6161 m .54251 .6209 L .54208 .62538 L p F P
0 g
s
.651 .758 .928 r
.81425 .40281 m .82698 .3987 L .82969 .40247 L p F P
0 g
s
.651 .758 .928 r
.82698 .3987 m .81425 .40281 L .81151 .39904 L p F P
0 g
s
.86 .487 0 r
.44233 .57868 m .44462 .58248 L .44631 .58761 L p F P
0 g
s
.86 .495 0 r
.44462 .58248 m .44233 .57868 L .44083 .57351 L p F P
0 g
s
.651 .758 .928 r
.62617 .40294 m .63855 .39886 L .64159 .40263 L p F P
0 g
s
.651 .758 .928 r
.63855 .39886 m .62617 .40294 L .6231 .39918 L p F P
0 g
s
.02 .329 .813 r
.50271 .55715 m .50202 .5567 L .50118 .55485 L closepath p F P
0 g
s
.132 .418 .862 r
.50202 .5567 m .50118 .55485 L .49943 .55233 L p F P
0 g
s
.588 .801 .981 r
.50246 .70238 m .51461 .69954 L .51786 .70217 L p F P
0 g
s
.573 .66 .896 r
.51134 .69603 m .51461 .69954 L .50246 .70238 L p F P
0 g
s
.573 .66 .896 r
.50639 .69666 m .51134 .69603 L p .50246 .70238 L F P
0 g
s
.573 .66 .896 r
.50246 .70238 m .50165 .70121 L .50639 .69666 L p F P
0 g
s
.651 .758 .928 r
.64159 .40263 m .654 .39853 L .65701 .40231 L p F P
0 g
s
.651 .758 .928 r
.654 .39853 m .64159 .40263 L .63855 .39886 L p F P
0 g
s
0 0 .455 r
.54622 .63999 m .54577 .64195 L .547 .64893 L p F P
0 g
s
0 .006 .522 r
.54662 .64995 m .547 .64893 L .54577 .64195 L p F P
0 g
s
.916 .53 .122 r
.43782 .56992 m .44083 .57351 L .44233 .57868 L p F P
0 g
s
.921 .541 .135 r
.44083 .57351 m .43782 .56992 L .43643 .56473 L p F P
0 g
s
.01 .188 .701 r
.53194 .59908 m .5319 .59815 L p .53596 .60703 L F P
0 g
s
.026 .222 .728 r
.53194 .59908 m .53125 .59751 L .5319 .59815 L closepath p F P
0 g
s
0 .077 .62 r
.53949 .61169 m .53937 .6161 L .54251 .6209 L p F P
0 g
s
.006 .158 .673 r
.53596 .60703 m .53949 .61169 L .53937 .6161 L p F P
0 g
s
.685 .846 .96 r
.51965 .70122 m .51786 .70217 L .51461 .69954 L p F P
0 g
s
.009 .135 .648 r
.46073 .62856 m .45786 .62459 L .45839 .62131 L closepath p F P
0 g
s
.007 .132 .646 r
.45744 .61832 m .4556 .61516 L p .45786 .62459 L F P
0 g
s
.007 .132 .646 r
.45786 .62459 m .45839 .62131 L .45744 .61832 L p F P
0 g
s
.651 .758 .928 r
.65701 .40231 m .66946 .39821 L .67244 .40198 L p F P
0 g
s
.651 .758 .928 r
.66946 .39821 m .65701 .40231 L .654 .39853 L p F P
0 g
s
.003 .299 .793 r
.50271 .55715 m .50739 .56066 L .50908 .56464 L p F P
0 g
s
0 .269 .776 r
.50739 .56066 m .50271 .55715 L .50118 .55485 L p F P
0 g
s
0 .276 .778 r
.51558 .57277 m .51429 .56869 L .50908 .56464 L p F P
0 g
s
0 .27 .776 r
.50739 .56066 m .50908 .56464 L .51429 .56869 L p F P
0 g
s
.009 .217 .727 r
.5319 .59815 m .53125 .59751 L .52799 .59033 L p F P
0 g
s
.471 .485 .791 r
.48048 .68422 m .48024 .68417 L .4804 .68402 L closepath p F P
0 g
s
.49 .462 .754 r
.47719 .67625 m .4804 .68402 L .48024 .68417 L p F P
0 g
s
.49 .462 .754 r
.47518 .6756 m .47719 .67625 L p .48024 .68417 L F P
0 g
s
.434 .448 .775 r
.47719 .67625 m .47518 .6756 L .47642 .67424 L closepath p F P
0 g
s
.435 .45 .777 r
.47389 .66765 m .47161 .66659 L p .47518 .6756 L F P
0 g
s
.435 .45 .777 r
.47518 .6756 m .47642 .67424 L .47389 .66765 L p F P
0 g
s
0 0 .431 r
.547 .64893 m .54662 .64995 L .54773 .65542 L p F P
0 g
s
.651 .758 .928 r
.67244 .40198 m .68492 .39789 L .68788 .40166 L p F P
0 g
s
.651 .758 .928 r
.68492 .39789 m .67244 .40198 L .66946 .39821 L p F P
0 g
s
.685 .846 .96 r
.51461 .69954 m .52301 .69605 L .51965 .70122 L p F P
0 g
s
.723 .965 .939 r
.5268 .69435 m .52301 .69605 L .51965 .70122 L p F P
0 g
s
.723 .965 .939 r
.51965 .70122 m .53001 .69497 L .5268 .69435 L p F P
0 g
s
.574 .662 .897 r
.50165 .70121 m .49918 .69763 L .50639 .69666 L closepath p F P
0 g
s
.519 .534 .811 r
.48048 .68422 m .49259 .68618 L p .48871 .69175 L F P
0 g
s
.441 .467 .791 r
.48929 .67958 m .49259 .68618 L .48048 .68422 L p F P
0 g
s
.441 .467 .791 r
.4853 .67842 m .48929 .67958 L p .48048 .68422 L F P
0 g
s
.441 .467 .791 r
.48048 .68422 m .4804 .68402 L .4853 .67842 L p F P
0 g
s
.443 .47 .793 r
.4804 .68402 m .47719 .67625 L .4853 .67842 L closepath p F P
0 g
s
0 .112 .653 r
.53575 .6027 m .53596 .60703 L .53949 .61169 L p F P
0 g
s
.01 .188 .701 r
.5319 .59815 m .53575 .6027 L .53596 .60703 L p F P
0 g
s
.037 .281 .776 r
.52162 .58105 m .52074 .57685 L .51558 .57277 L p F P
0 g
s
.05 .317 .801 r
.51429 .56869 m .51558 .57277 L .52074 .57685 L p F P
0 g
s
.651 .758 .928 r
.68788 .40166 m .70038 .39757 L .70332 .40134 L p F P
0 g
s
.651 .758 .928 r
.70038 .39757 m .68788 .40166 L .68492 .39789 L p F P
0 g
s
.762 .979 .723 r
.54087 .68171 m .5395 .68378 L .5338 .69127 L p F P
0 g
s
.389 .407 .759 r
.47389 .66765 m .47161 .66659 L .47291 .66492 L closepath p F P
0 g
s
.39 .41 .76 r
.4706 .65849 m .46879 .65734 L p .47161 .66659 L F P
0 g
s
.39 .41 .76 r
.47161 .66659 m .47291 .66492 L .4706 .65849 L p F P
0 g
s
0 .138 .677 r
.53137 .59389 m .5319 .59815 L .53575 .6027 L p F P
0 g
s
.009 .217 .727 r
.52799 .59033 m .53137 .59389 L .5319 .59815 L p F P
0 g
s
.091 .303 .782 r
.52473 .58373 m .52162 .58105 L p .52712 .58949 L F P
0 g
s
0 .233 .746 r
.52162 .58105 m .52473 .58373 L .52146 .5775 L p F P
0 g
s
0 .233 .746 r
.52146 .5775 m .52074 .57685 L .52162 .58105 L p F P
0 g
s
.651 .758 .928 r
.70332 .40134 m .71585 .39724 L .71876 .40102 L p F P
0 g
s
.651 .758 .928 r
.71585 .39724 m .70332 .40134 L .70038 .39757 L p F P
0 g
s
0 .004 .57 r
.45744 .61832 m .4556 .61516 L .45554 .61264 L closepath p F P
0 g
s
0 0 .565 r
.45414 .60839 m .45293 .60585 L p .4556 .61516 L F P
0 g
s
0 0 .565 r
.4556 .61516 m .45554 .61264 L .45414 .60839 L p F P
0 g
s
.002 .22 .731 r
.52799 .59033 m .52712 .58949 L .52697 .58815 L closepath p F P
0 g
s
.091 .303 .782 r
.52712 .58949 m .52697 .58815 L .52473 .58373 L p F P
0 g
s
.651 .758 .928 r
.71876 .40102 m .73133 .39691 L .73421 .40069 L p F P
0 g
s
.651 .758 .928 r
.73133 .39691 m .71876 .40102 L .71585 .39724 L p F P
0 g
s
.499 .567 .856 r
.49589 .6922 m .48871 .69175 L .49283 .68661 L closepath p F P
0 g
s
.519 .534 .811 r
.49259 .68618 m .49283 .68661 L .48871 .69175 L p F P
0 g
s
0 0 .088 r
.54785 .66124 m .54567 .66609 L .54463 .67222 L p F P
0 g
s
0 0 .312 r
.54777 .65711 m .54773 .65542 L p .54567 .66609 L F P
0 g
s
0 0 .312 r
.54567 .66609 m .54785 .66124 L .54777 .65711 L p F P
0 g
s
0 .323 .806 r
.49167 .54523 m .48898 .54152 L .48298 .5378 L p F P
0 g
s
0 .307 .788 r
.47985 .5342 m .48298 .5378 L .48898 .54152 L p F P
0 g
s
0 0 .343 r
.54782 .6453 m .547 .64893 L .54774 .6554 L p F P
0 g
s
0 0 .455 r
.547 .64893 m .54782 .6453 L .54622 .63999 L p F P
0 g
s
0 0 .431 r
.54773 .65542 m .54774 .6554 L .547 .64893 L p F P
0 g
s
0 .269 .776 r
.50118 .55485 m .50009 .55277 L p .50739 .56066 L F P
0 g
s
0 .315 .805 r
.50118 .55485 m .49943 .55233 L .50009 .55277 L closepath p F P
0 g
s
.651 .758 .928 r
.73421 .40069 m .7468 .39659 L .74966 .40036 L p F P
0 g
s
.651 .758 .928 r
.7468 .39659 m .73421 .40069 L .73133 .39691 L p F P
0 g
s
.332 .361 .742 r
.4706 .65849 m .46879 .65734 L .46972 .65591 L closepath p F P
0 g
s
.333 .363 .743 r
.4673 .64884 m .46629 .64799 L p .46879 .65734 L F P
0 g
s
.333 .363 .743 r
.46879 .65734 m .46972 .65591 L .4673 .64884 L p F P
0 g
s
.454 .46 .775 r
.4853 .67842 m .47719 .67625 L .47642 .67424 L p F P
0 g
s
0 0 .437 r
.45414 .60839 m .45293 .60585 L .45246 .60373 L closepath p F P
0 g
s
0 0 .427 r
.45293 .60585 m .45246 .60373 L .45084 .59917 L p F P
0 g
s
.651 .758 .928 r
.74966 .40036 m .76229 .39626 L .76511 .40004 L p F P
0 g
s
.651 .758 .928 r
.76229 .39626 m .74966 .40036 L .7468 .39659 L p F P
0 g
s
.454 .46 .775 r
.47642 .67424 m .47979 .66995 L p .4853 .67842 L F P
0 g
s
.405 .432 .775 r
.47642 .67424 m .47389 .66765 L .47979 .66995 L closepath p F P
0 g
s
0 0 .444 r
.54697 .63545 m .54622 .63999 L .54782 .6453 L p F P
0 g
s
0 0 .536 r
.54477 .63033 m .54697 .63545 L .54622 .63999 L p F P
0 g
s
0 .177 .706 r
.53137 .59389 m .52799 .59033 L .52697 .58815 L p F P
0 g
s
.785 .992 .88 r
.5338 .69127 m .53001 .69497 L .5268 .69435 L p F P
0 g
s
.785 .992 .88 r
.5268 .69435 m .537 .68613 L .5338 .69127 L p F P
0 g
s
.762 .979 .723 r
.53897 .68402 m .54087 .68171 L p .5338 .69127 L F P
0 g
s
.762 .979 .723 r
.5338 .69127 m .537 .68613 L .53897 .68402 L p F P
0 g
s
.651 .758 .928 r
.76511 .40004 m .77777 .39593 L .78057 .39971 L p F P
0 g
s
.651 .758 .928 r
.77777 .39593 m .76511 .40004 L .76229 .39626 L p F P
0 g
s
.651 .758 .928 r
.78057 .39971 m .79326 .39559 L .79604 .39937 L p F P
0 g
s
.651 .758 .928 r
.79326 .39559 m .78057 .39971 L .77777 .39593 L p F P
0 g
s
0 .177 .706 r
.52697 .58815 m .52638 .58527 L p .53137 .59389 L F P
0 g
s
0 .219 .736 r
.52697 .58815 m .52473 .58373 L .52638 .58527 L closepath p F P
0 g
s
.849 .471 0 r
.44631 .58761 m .44752 .59111 L .44418 .58466 L p F P
0 g
s
0 0 .353 r
.44752 .59111 m .44418 .58466 L p .44714 .59033 L F P
0 g
s
.687 .345 0 r
.44752 .59111 m .44631 .58761 L p .44824 .59257 L F P
0 g
s
0 0 .353 r
.44835 .59264 m .44752 .59111 L p .44714 .59033 L F P
0 g
s
.687 .345 0 r
.44983 .59667 m .44752 .59111 L .44824 .59257 L F
.44983 .59667 m .44879 .59422 L .44752 .59111 L p F P
0 g
s
.258 .306 .722 r
.4673 .64884 m .46629 .64799 L .46674 .64711 L closepath p F P
0 g
s
.259 .307 .722 r
.46401 .63882 m .46383 .63862 L p .46629 .64799 L F P
0 g
s
.259 .307 .722 r
.46629 .64799 m .46674 .64711 L .46401 .63882 L p F P
0 g
s
.417 .425 .761 r
.47979 .66995 m .47389 .66765 L .47291 .66492 L p F P
0 g
s
.579 .632 .868 r
.50639 .69666 m .49918 .69763 L .49589 .6922 L p F P
0 g
s
0 .33 .811 r
.49167 .54523 m .49614 .54793 L .49284 .54386 L p F P
0 g
s
0 .33 .811 r
.49284 .54386 m .48898 .54152 L .49167 .54523 L p F P
0 g
s
.417 .425 .761 r
.47291 .66492 m .47554 .66111 L p .47979 .66995 L F P
0 g
s
.361 .392 .758 r
.47291 .66492 m .4706 .65849 L .47554 .66111 L closepath p F P
0 g
s
.651 .758 .928 r
.79604 .39937 m .80876 .39526 L .81151 .39904 L p F P
0 g
s
.651 .758 .928 r
.80876 .39526 m .79604 .39937 L .79326 .39559 L p F P
0 g
s
.849 .471 0 r
.44418 .58466 m .44392 .58384 L .44631 .58761 L p F P
0 g
s
.86 .487 0 r
.44631 .58761 m .44392 .58384 L .44233 .57868 L p F P
0 g
s
.651 .758 .928 r
.81151 .39904 m .82426 .39492 L .82698 .3987 L p F P
0 g
s
.651 .758 .928 r
.82426 .39492 m .81151 .39904 L .80876 .39526 L p F P
0 g
s
.74 .773 .274 r
.54463 .67222 m .54212 .67879 L .54087 .68171 L p F P
0 g
s
.768 .905 .514 r
.53897 .68402 m .54212 .67879 L .54087 .68171 L closepath p F P
0 g
s
0 .304 .797 r
.50009 .55277 m .49943 .55233 L .49614 .54793 L p F P
0 g
s
0 0 .52 r
.54524 .62585 m .54477 .63033 L .54697 .63545 L p F P
0 g
s
0 .03 .578 r
.54477 .63033 m .54524 .62585 L .54251 .6209 L p F P
0 g
s
.651 .758 .928 r
.6231 .39918 m .6355 .39507 L .63855 .39886 L p F P
0 g
s
.374 .388 .747 r
.47554 .66111 m .4706 .65849 L .46972 .65591 L p F P
0 g
s
.374 .388 .747 r
.46972 .65591 m .47198 .65206 L p .47554 .66111 L F P
0 g
s
.309 .348 .74 r
.46972 .65591 m .4673 .64884 L .47198 .65206 L closepath p F P
0 g
s
.158 .236 .695 r
.46401 .63882 m .46383 .63862 L .46389 .63845 L closepath p F P
0 g
s
.157 .235 .694 r
.46383 .63862 m .46389 .63845 L .46115 .62988 L p F P
0 g
s
.651 .758 .928 r
.63855 .39886 m .65098 .39475 L .654 .39853 L p F P
0 g
s
.651 .758 .928 r
.65098 .39475 m .63855 .39886 L .6355 .39507 L p F P
0 g
s
.908 .515 .104 r
.43929 .5751 m .44233 .57868 L .44392 .58384 L p F P
0 g
s
.916 .53 .122 r
.44233 .57868 m .43929 .5751 L .43782 .56992 L p F P
0 g
s
.321 .347 .732 r
.47198 .65206 m .4673 .64884 L .46674 .64711 L p F P
0 g
s
.321 .347 .732 r
.46674 .64711 m .46874 .6429 L p .47198 .65206 L F P
0 g
s
.246 .299 .72 r
.46674 .64711 m .46401 .63882 L .46874 .6429 L closepath p F P
0 g
s
.254 .3 .717 r
.46874 .6429 m .46401 .63882 L .46389 .63845 L p F P
0 g
s
.254 .3 .717 r
.46389 .63845 m .46558 .63372 L p .46874 .6429 L F P
0 g
s
.166 .241 .696 r
.46137 .62925 m .46115 .62988 L .46389 .63845 L p F P
0 g
s
.166 .241 .696 r
.46389 .63845 m .46558 .63372 L .46137 .62925 L p F P
0 g
s
.172 .244 .698 r
.46115 .62988 m .46073 .62856 L .46137 .62925 L closepath p F P
0 g
s
.17 .244 .698 r
.46137 .62925 m .46073 .62856 L .45839 .62131 L p F P
0 g
s
.072 .177 .669 r
.45839 .62131 m .45744 .61832 L .45871 .61993 L closepath p F P
0 g
s
.048 .169 .669 r
.45871 .61993 m .45744 .61832 L .45554 .61264 L p F P
0 g
s
.17 .244 .698 r
.45839 .62131 m .45871 .61993 L p .46137 .62925 L F P
0 g
s
0 .269 .776 r
.50009 .55277 m .50535 .55677 L .50739 .56066 L p F P
0 g
s
0 .242 .754 r
.49768 .54898 m .50009 .55277 L .50535 .55677 L p F P
0 g
s
0 .304 .797 r
.49614 .54793 m .49768 .54898 L .50009 .55277 L p F P
0 g
s
.651 .758 .928 r
.654 .39853 m .66646 .39443 L .66946 .39821 L p F P
0 g
s
.651 .758 .928 r
.66646 .39443 m .654 .39853 L .65098 .39475 L p F P
0 g
s
.048 .169 .669 r
.45554 .61264 m .45571 .6107 L p .45871 .61993 L F P
0 g
s
0 .095 .628 r
.45554 .61264 m .45414 .60839 L .45571 .6107 L closepath p F P
0 g
s
0 0 .283 r
.54777 .65711 m .54773 .65542 L .54774 .6554 L closepath p F P
0 g
s
0 0 .224 r
.54774 .6554 m .54874 .65083 L p .54787 .66119 L F P
0 g
s
0 0 .224 r
.54787 .66119 m .54777 .65711 L .54774 .6554 L p F P
0 g
s
0 0 .343 r
.54774 .6554 m .54874 .65083 L .54782 .6453 L p F P
0 g
s
0 .067 .618 r
.45571 .6107 m .45414 .60839 L .45246 .60373 L p F P
0 g
s
0 .212 .734 r
.52638 .58527 m .52473 .58373 L .52146 .5775 L p F P
0 g
s
.61 .848 .989 r
.52301 .69605 m .51461 .69954 L .51134 .69603 L p F P
0 g
s
.651 .758 .928 r
.66946 .39821 m .68195 .3941 L .68492 .39789 L p F P
0 g
s
.651 .758 .928 r
.68195 .3941 m .66946 .39821 L .66646 .39443 L p F P
0 g
s
0 .022 .578 r
.54266 .61649 m .54251 .6209 L .54524 .62585 L p F P
0 g
s
0 .077 .62 r
.54251 .6209 m .54266 .61649 L .53949 .61169 L p F P
0 g
s
0 .067 .618 r
.45246 .60373 m .45229 .60159 L p .45571 .6107 L F P
0 g
s
0 0 .565 r
.45246 .60373 m .45084 .59917 L .45229 .60159 L closepath p F P
0 g
s
.662 .76 .276 r
.5468 .66733 m .54463 .67222 L .54212 .67879 L p F P
0 g
s
0 0 .088 r
.54783 .66154 m .54785 .66124 L p .54463 .67222 L F P
0 g
s
0 0 .088 r
.54463 .67222 m .5468 .66733 L .54783 .66154 L p F P
0 g
s
0 .133 .657 r
.46233 .62455 m .46137 .62925 L .46558 .63372 L p F P
0 g
s
.17 .244 .698 r
.45871 .61993 m .46233 .62455 L .46137 .62925 L p F P
0 g
s
.651 .758 .928 r
.68492 .39789 m .69744 .39378 L .70038 .39757 L p F P
0 g
s
.651 .758 .928 r
.69744 .39378 m .68492 .39789 L .68195 .3941 L p F P
0 g
s
0 0 .52 r
.45229 .60159 m .45084 .59917 L .44879 .59422 L p F P
0 g
s
0 .27 .776 r
.51429 .56869 m .51265 .56469 L .50739 .56066 L p F P
0 g
s
0 .262 .771 r
.50535 .55677 m .50739 .56066 L .51265 .56469 L p F P
0 g
s
.651 .758 .928 r
.70038 .39757 m .71294 .39345 L .71585 .39724 L p F P
0 g
s
.651 .758 .928 r
.71294 .39345 m .70038 .39757 L .69744 .39378 L p F P
0 g
s
0 0 .229 r
.54785 .66124 m .54777 .65711 L .54787 .66119 L closepath p F P
0 g
s
0 .069 .62 r
.53931 .60736 m .53949 .61169 L .54266 .61649 L p F P
0 g
s
0 .112 .653 r
.53949 .61169 m .53931 .60736 L .53575 .6027 L p F P
0 g
s
.651 .758 .928 r
.71585 .39724 m .72844 .39313 L .73133 .39691 L p F P
0 g
s
.651 .758 .928 r
.72844 .39313 m .71585 .39724 L .71294 .39345 L p F P
0 g
s
.05 .317 .801 r
.5182 .57182 m .51429 .56869 L p .52074 .57685 L F P
0 g
s
0 .24 .756 r
.51429 .56869 m .5182 .57182 L .51492 .56655 L p F P
0 g
s
0 .24 .756 r
.51492 .56655 m .51265 .56469 L .51429 .56869 L p F P
0 g
s
.579 .632 .868 r
.49589 .6922 m .50806 .69181 L p .50639 .69666 L F P
0 g
s
.503 .569 .855 r
.50477 .68697 m .50806 .69181 L .49589 .6922 L p F P
0 g
s
.503 .569 .855 r
.49317 .6862 m .50477 .68697 L p .49589 .6922 L F P
0 g
s
.503 .569 .855 r
.49589 .6922 m .49283 .68661 L .49317 .6862 L p F P
0 g
s
0 .034 .598 r
.45888 .61545 m .45871 .61993 L .46233 .62455 L p F P
0 g
s
.048 .169 .669 r
.45571 .6107 m .45888 .61545 L .45871 .61993 L p F P
0 g
s
0 0 .52 r
.44879 .59422 m .44835 .59264 L p .45229 .60159 L F P
0 g
s
0 0 .463 r
.44879 .59422 m .44752 .59111 L .44835 .59264 L closepath p F P
0 g
s
0 .307 .788 r
.48898 .54152 m .48587 .53791 L .47985 .5342 L p F P
0 g
s
0 .103 .651 r
.53524 .59844 m .53575 .6027 L .53931 .60736 L p F P
0 g
s
0 .138 .677 r
.53575 .6027 m .53524 .59844 L .53137 .59389 L p F P
0 g
s
.651 .758 .928 r
.73133 .39691 m .74394 .3928 L .7468 .39659 L p F P
0 g
s
.651 .758 .928 r
.74394 .3928 m .73133 .39691 L .72844 .39313 L p F P
0 g
s
0 .22 .741 r
.52146 .5775 m .52074 .57685 L .52031 .57541 L closepath p F P
0 g
s
.05 .317 .801 r
.52074 .57685 m .52031 .57541 L .5182 .57182 L p F P
0 g
s
0 0 .328 r
.5486 .64075 m .54782 .6453 L .54874 .65083 L p F P
0 g
s
0 0 .444 r
.54782 .6453 m .5486 .64075 L .54697 .63545 L p F P
0 g
s
0 .127 .673 r
.53052 .58971 m .53137 .59389 L .53524 .59844 L p F P
0 g
s
0 .177 .706 r
.52638 .58527 m .53052 .58971 L .53137 .59389 L p F P
0 g
s
.564 .687 .923 r
.51134 .69603 m .50639 .69666 L .50854 .69242 L closepath p F P
0 g
s
.579 .632 .868 r
.50806 .69181 m .50854 .69242 L .50639 .69666 L p F P
0 g
s
0 .143 .688 r
.5252 .58117 m .52638 .58527 L .53052 .58971 L p F P
0 g
s
0 .212 .734 r
.52146 .5775 m .5252 .58117 L .52638 .58527 L p F P
0 g
s
.651 .758 .928 r
.7468 .39659 m .75945 .39247 L .76229 .39626 L p F P
0 g
s
.651 .758 .928 r
.75945 .39247 m .7468 .39659 L .74394 .3928 L p F P
0 g
s
0 0 .511 r
.45512 .60642 m .45571 .6107 L .45888 .61545 L p F P
0 g
s
0 .067 .618 r
.45229 .60159 m .45512 .60642 L .45571 .6107 L p F P
0 g
s
.651 .758 .928 r
.76229 .39626 m .77496 .39214 L .77777 .39593 L p F P
0 g
s
.651 .758 .928 r
.77496 .39214 m .76229 .39626 L .75945 .39247 L p F P
0 g
s
0 .172 .709 r
.5252 .58117 m .52146 .5775 L .52031 .57541 L p F P
0 g
s
.651 .758 .928 r
.77777 .39593 m .79048 .3918 L .79326 .39559 L p F P
0 g
s
.651 .758 .928 r
.79048 .3918 m .77777 .39593 L .77496 .39214 L p F P
0 g
s
.61 .848 .989 r
.52542 .69356 m .52301 .69605 L p .51134 .69603 L F P
0 g
s
.69 .888 .97 r
.52301 .69605 m .52542 .69356 L .5268 .69435 L closepath p F P
0 g
s
0 .279 .775 r
.49768 .54898 m .49614 .54793 L .49284 .54386 L p F P
0 g
s
.924 .969 .679 r
.54212 .67879 m .54406 .67398 L p .538 .68455 L F P
0 g
s
.924 .969 .679 r
.538 .68455 m .53897 .68402 L .54212 .67879 L p F P
0 g
s
.867 .991 .736 r
.54406 .67398 m .53907 .68129 L p .54542 .67061 L F P
0 g
s
.867 .991 .736 r
.54557 .67036 m .54406 .67398 L p .54542 .67061 L F P
0 g
s
.662 .76 .276 r
.54406 .67398 m .5468 .66733 L p .54226 .67844 L F P
0 g
s
.662 .76 .276 r
.54212 .67879 m .54406 .67398 L p .54226 .67844 L F P
0 g
s
0 0 .397 r
.45097 .59752 m .45229 .60159 L .45512 .60642 L p F P
0 g
s
0 0 .52 r
.44835 .59264 m .45097 .59752 L .45229 .60159 L p F P
0 g
s
.651 .758 .928 r
.79326 .39559 m .806 .39147 L .80876 .39526 L p F P
0 g
s
.651 .758 .928 r
.806 .39147 m .79326 .39559 L .79048 .3918 L p F P
0 g
s
0 .313 .793 r
.48898 .54152 m .49284 .54386 L .48953 .54014 L p F P
0 g
s
0 .313 .793 r
.48953 .54014 m .48587 .53791 L .48898 .54152 L p F P
0 g
s
.454 .46 .775 r
.47979 .66995 m .48598 .67253 L p .4853 .67842 L F P
0 g
s
.318 .385 .773 r
.47979 .66995 m .48598 .67253 L .48267 .66512 L p F P
0 g
s
.318 .385 .773 r
.48267 .66512 m .4823 .6649 L .47979 .66995 L p F P
0 g
s
.417 .425 .761 r
.47554 .66111 m .4823 .6649 L .47979 .66995 L p F P
0 g
s
.651 .758 .928 r
.80876 .39526 m .82153 .39113 L .82426 .39492 L p F P
0 g
s
.651 .758 .928 r
.82153 .39113 m .80876 .39526 L .806 .39147 L p F P
0 g
s
.413 .482 .821 r
.48929 .67958 m .4853 .67842 L .48724 .6752 L closepath p F P
0 g
s
.454 .46 .775 r
.48598 .67253 m .48724 .6752 L .4853 .67842 L p F P
0 g
s
0 0 .047 r
.54783 .66154 m .54787 .66119 L .54785 .66124 L closepath p F P
0 g
s
.688 .291 0 r
.44628 .58878 m .44835 .59264 L .45097 .59752 L p F P
0 g
s
0 0 .353 r
.44418 .58466 m .44628 .58878 L .44835 .59264 L p F P
0 g
s
0 0 .06 r
.5468 .66733 m .54721 .6663 L .54783 .66154 L closepath p F P
0 g
s
.74 .668 .116 r
.54721 .6663 m .54783 .66154 L .54787 .66119 L p F P
0 g
s
.74 .668 .116 r
.54787 .66119 m .54884 .65662 L p .54721 .6663 L F P
0 g
s
0 0 .224 r
.54874 .65083 m .54884 .65662 L .54787 .66119 L p F P
0 g
s
0 0 .441 r
.54749 .63095 m .54697 .63545 L .5486 .64075 L p F P
0 g
s
0 0 .52 r
.54697 .63545 m .54749 .63095 L .54524 .62585 L p F P
0 g
s
0 .172 .709 r
.52031 .57541 m .51934 .5728 L p .5252 .58117 L F P
0 g
s
0 .223 .745 r
.52031 .57541 m .5182 .57182 L .51934 .5728 L closepath p F P
0 g
s
.295 .389 .789 r
.47766 .65615 m .47554 .66111 L .4823 .6649 L p F P
0 g
s
.374 .388 .747 r
.47198 .65206 m .47766 .65615 L .47554 .66111 L p F P
0 g
s
.899 .5 .081 r
.44418 .58466 m .44392 .58384 L .44122 .58072 L closepath p F P
0 g
s
.908 .515 .104 r
.4408 .58016 m .43929 .5751 L p .44392 .58384 L F P
0 g
s
.908 .515 .104 r
.44392 .58384 m .44122 .58072 L .4408 .58016 L p F P
0 g
s
.651 .758 .928 r
.6355 .39507 m .64794 .39095 L .65098 .39475 L p F P
0 g
s
.824 .901 .894 r
.52542 .69356 m .5268 .69435 L .537 .68613 L p F P
0 g
s
.505 .572 .857 r
.49283 .68661 m .49259 .68618 L .49317 .6862 L closepath p F P
0 g
s
.513 .553 .834 r
.49317 .6862 m .49259 .68618 L .48929 .67958 L p F P
0 g
s
.651 .758 .928 r
.65098 .39475 m .66345 .39063 L .66646 .39443 L p F P
0 g
s
.651 .758 .928 r
.66345 .39063 m .65098 .39475 L .64794 .39095 L p F P
0 g
s
.212 .332 .769 r
.47355 .64723 m .47198 .65206 L .47766 .65615 L p F P
0 g
s
.321 .347 .732 r
.46874 .6429 m .47355 .64723 L .47198 .65206 L p F P
0 g
s
.754 .976 .714 r
.537 .68613 m .538 .68455 L .53897 .68402 L closepath p F P
0 g
s
.61 .848 .989 r
.51134 .69603 m .52356 .69236 L .52542 .69356 L p F P
0 g
s
.598 .701 .916 r
.5203 .68946 m .52356 .69236 L .51134 .69603 L p F P
0 g
s
.598 .701 .916 r
.50951 .69153 m .5203 .68946 L p .51134 .69603 L F P
0 g
s
.598 .701 .916 r
.51134 .69603 m .50854 .69242 L .50951 .69153 L p F P
0 g
s
.779 .339 0 r
.44628 .58878 m .44418 .58466 L .44122 .58072 L p F P
0 g
s
.453 .517 .833 r
.49317 .6862 m .50477 .68697 L .50148 .68167 L p F P
0 g
s
.453 .517 .833 r
.50148 .68167 m .49698 .68083 L .49317 .6862 L p F P
0 g
s
.513 .553 .834 r
.48929 .67958 m .49698 .68083 L .49317 .6862 L p F P
0 g
s
0 .242 .754 r
.50535 .55677 m .50295 .55298 L .49768 .54898 L p F P
0 g
s
0 .224 .734 r
.4949 .54528 m .49768 .54898 L .50295 .55298 L p F P
0 g
s
0 .279 .775 r
.49284 .54386 m .4949 .54528 L .49768 .54898 L p F P
0 g
s
.651 .758 .928 r
.66646 .39443 m .67897 .3903 L .68195 .3941 L p F P
0 g
s
.651 .758 .928 r
.67897 .3903 m .66646 .39443 L .66345 .39063 L p F P
0 g
s
.824 .901 .894 r
.537 .68613 m .538 .68455 L p .52542 .69356 L F P
0 g
s
0 0 .534 r
.54546 .62142 m .54524 .62585 L .54749 .63095 L p F P
0 g
s
0 .022 .578 r
.54524 .62585 m .54546 .62142 L .54266 .61649 L p F P
0 g
s
.651 .758 .928 r
.68195 .3941 m .69449 .38998 L .69744 .39378 L p F P
0 g
s
.651 .758 .928 r
.69449 .38998 m .68195 .3941 L .67897 .3903 L p F P
0 g
s
.103 .26 .74 r
.46969 .63824 m .46874 .6429 L .47355 .64723 L p F P
0 g
s
.254 .3 .717 r
.46558 .63372 m .46969 .63824 L .46874 .6429 L p F P
0 g
s
.651 .758 .928 r
.69744 .39378 m .71001 .38965 L .71294 .39345 L p F P
0 g
s
.651 .758 .928 r
.71001 .38965 m .69744 .39378 L .69449 .38998 L p F P
0 g
s
0 .262 .771 r
.51265 .56469 m .51066 .56078 L .50535 .55677 L p F P
0 g
s
0 .252 .761 r
.50295 .55298 m .50535 .55677 L .51066 .56078 L p F P
0 g
s
0 .211 .737 r
.51934 .5728 m .5182 .57182 L .51492 .56655 L p F P
0 g
s
.651 .758 .928 r
.71294 .39345 m .72554 .38932 L .72844 .39313 L p F P
0 g
s
.651 .758 .928 r
.72554 .38932 m .71294 .39345 L .71001 .38965 L p F P
0 g
s
0 .168 .694 r
.46589 .62922 m .46558 .63372 L .46969 .63824 L p F P
0 g
s
0 .133 .657 r
.46558 .63372 m .46589 .62922 L .46233 .62455 L p F P
0 g
s
0 0 .155 r
.54955 .64629 m .54874 .65083 L .54884 .65662 L p F P
0 g
s
0 0 .328 r
.54874 .65083 m .54955 .64629 L .5486 .64075 L p F P
0 g
s
0 .024 .585 r
.54256 .61213 m .54266 .61649 L .54546 .62142 L p F P
0 g
s
0 .069 .62 r
.54266 .61649 m .54256 .61213 L .53931 .60736 L p F P
0 g
s
.651 .758 .928 r
.72844 .39313 m .74107 .38899 L .74394 .3928 L p F P
0 g
s
.651 .758 .928 r
.74107 .38899 m .72844 .39313 L .72554 .38932 L p F P
0 g
s
.74 .882 .945 r
.52356 .69236 m .52623 .6909 L .52542 .69356 L closepath p F P
0 g
s
.824 .901 .894 r
.53578 .68486 m .52623 .6909 L .52542 .69356 L p F P
0 g
s
.824 .901 .894 r
.538 .68455 m .53578 .68486 L p .52542 .69356 L F P
0 g
s
0 .214 .738 r
.51265 .56469 m .51492 .56655 L .51164 .5616 L p F P
0 g
s
0 .214 .738 r
.51164 .5616 m .51066 .56078 L .51265 .56469 L p F P
0 g
s
.651 .758 .928 r
.74394 .3928 m .7566 .38866 L .75945 .39247 L p F P
0 g
s
.651 .758 .928 r
.7566 .38866 m .74394 .3928 L .74107 .38899 L p F P
0 g
s
.47 .515 .822 r
.49698 .68083 m .48929 .67958 L .48724 .6752 L p F P
0 g
s
0 0 .574 r
.46201 .62023 m .46233 .62455 L .46589 .62922 L p F P
0 g
s
0 .034 .598 r
.46233 .62455 m .46201 .62023 L .45888 .61545 L p F P
0 g
s
0 .078 .632 r
.53886 .60308 m .53931 .60736 L .54256 .61213 L p F P
0 g
s
0 .103 .651 r
.53931 .60736 m .53886 .60308 L .53524 .59844 L p F P
0 g
s
.861 .995 .814 r
.53578 .68486 m .53907 .68129 L .538 .68455 L closepath p F P
0 g
s
.924 .969 .679 r
.54406 .67398 m .53907 .68129 L .538 .68455 L p F P
0 g
s
.651 .758 .928 r
.75945 .39247 m .77214 .38833 L .77496 .39214 L p F P
0 g
s
.651 .758 .928 r
.77214 .38833 m .75945 .39247 L .7566 .38866 L p F P
0 g
s
0 0 0 r
.54721 .6663 m .5468 .66733 L .54406 .67398 L p F P
0 g
s
0 .172 .709 r
.51934 .5728 m .5237 .57716 L .5252 .58117 L p F P
0 g
s
0 .136 .681 r
.5175 .56887 m .51934 .5728 L .5237 .57716 L p F P
0 g
s
0 .211 .737 r
.51492 .56655 m .5175 .56887 L .51934 .5728 L p F P
0 g
s
0 .253 .747 r
.4949 .54528 m .49284 .54386 L .48953 .54014 L p F P
0 g
s
0 .129 .674 r
.53444 .59425 m .53524 .59844 L .53886 .60308 L p F P
0 g
s
0 .127 .673 r
.53524 .59844 m .53444 .59425 L .53052 .58971 L p F P
0 g
s
.651 .758 .928 r
.77496 .39214 m .78769 .38799 L .79048 .3918 L p F P
0 g
s
.651 .758 .928 r
.78769 .38799 m .77496 .39214 L .77214 .38833 L p F P
0 g
s
0 .143 .688 r
.53052 .58971 m .52936 .58561 L .5252 .58117 L p F P
0 g
s
0 .129 .678 r
.5237 .57716 m .5252 .58117 L .52936 .58561 L p F P
0 g
s
0 .118 .669 r
.52936 .58561 m .53052 .58971 L .53444 .59425 L p F P
0 g
s
0 0 .478 r
.45793 .61129 m .45888 .61545 L .46201 .62023 L p F P
0 g
s
0 0 .511 r
.45888 .61545 m .45793 .61129 L .45512 .60642 L p F P
0 g
s
.651 .758 .928 r
.79048 .3918 m .80323 .38766 L .806 .39147 L p F P
0 g
s
.651 .758 .928 r
.80323 .38766 m .79048 .3918 L .78769 .38799 L p F P
0 g
s
.598 .702 .916 r
.50854 .69242 m .50806 .69181 L .50951 .69153 L closepath p F P
0 g
s
.47 .515 .822 r
.48724 .6752 m .48852 .67319 L p .49698 .68083 L F P
0 g
s
.426 .491 .823 r
.48724 .6752 m .48598 .67253 L .48852 .67319 L closepath p F P
0 g
s
.779 .339 0 r
.44122 .58072 m .44086 .58027 L p .44628 .58878 L F P
0 g
s
.791 .355 0 r
.44122 .58072 m .4408 .58016 L .44086 .58027 L closepath p F P
0 g
s
.651 .758 .928 r
.806 .39147 m .81879 .38732 L .82153 .39113 L p F P
0 g
s
.651 .758 .928 r
.81879 .38732 m .806 .39147 L .80323 .38766 L p F P
0 g
s
0 0 .36 r
.45355 .60244 m .45512 .60642 L .45793 .61129 L p F P
0 g
s
0 0 .397 r
.45512 .60642 m .45355 .60244 L .45097 .59752 L p F P
0 g
s
0 0 .325 r
.54919 .63625 m .5486 .64075 L .54955 .64629 L p F P
0 g
s
0 0 .441 r
.5486 .64075 m .54919 .63625 L .54749 .63095 L p F P
0 g
s
0 0 0 r
.54406 .67398 m .54557 .67036 L .54721 .6663 L p F P
0 g
s
.74 .668 .116 r
.54884 .65662 m .54795 .66272 L .54721 .6663 L p F P
0 g
s
.804 .818 .338 r
.54795 .66272 m .54721 .6663 L .54557 .67036 L p F P
0 g
s
.602 .671 .889 r
.50951 .69153 m .50806 .69181 L .50477 .68697 L p F P
0 g
s
.718 .31 0 r
.44873 .59372 m .45097 .59752 L .45355 .60244 L p F P
0 g
s
.688 .291 0 r
.45097 .59752 m .44873 .59372 L .44628 .58878 L p F P
0 g
s
.779 .339 0 r
.44086 .58027 m .44331 .58519 L .44628 .58878 L p F P
0 g
s
.805 .367 0 r
.44331 .58519 m .44628 .58878 L .44873 .59372 L p F P
0 g
s
.435 .483 .811 r
.48852 .67319 m .48598 .67253 L .48267 .66512 L p F P
0 g
s
.651 .758 .928 r
.64794 .39095 m .66044 .38682 L .66345 .39063 L p F P
0 g
s
0 .176 .709 r
.5175 .56887 m .51492 .56655 L .51164 .5616 L p F P
0 g
s
.546 .648 .901 r
.50951 .69153 m .5203 .68946 L .51702 .6859 L p F P
0 g
s
.546 .648 .901 r
.51702 .6859 m .51323 .6862 L .50951 .69153 L p F P
0 g
s
.602 .671 .889 r
.50477 .68697 m .51323 .6862 L .50951 .69153 L p F P
0 g
s
.651 .758 .928 r
.66345 .39063 m .67598 .38649 L .67897 .3903 L p F P
0 g
s
.651 .758 .928 r
.67598 .38649 m .66345 .39063 L .66044 .38682 L p F P
0 g
s
.695 .838 .952 r
.52623 .6909 m .52356 .69236 L .5203 .68946 L p F P
0 g
s
0 .224 .734 r
.50295 .55298 m .50019 .54928 L .4949 .54528 L p F P
0 g
s
0 .202 .706 r
.49177 .54169 m .4949 .54528 L .50019 .54928 L p F P
0 g
s
0 .253 .747 r
.48953 .54014 m .49177 .54169 L .4949 .54528 L p F P
0 g
s
.651 .758 .928 r
.67897 .3903 m .69152 .38616 L .69449 .38998 L p F P
0 g
s
.651 .758 .928 r
.69152 .38616 m .67897 .3903 L .67598 .38649 L p F P
0 g
s
0 0 .426 r
.54772 .62747 m .54749 .63095 L .54919 .63625 L p F P
0 g
s
0 0 .534 r
.54701 .62489 m .54546 .62142 L p .54749 .63095 L F P
0 g
s
0 0 .534 r
.54749 .63095 m .54772 .62747 L .54701 .62489 L p F P
0 g
s
0 0 0 r
.54965 .65208 m .54884 .65662 L .54795 .66272 L p F P
0 g
s
0 0 .155 r
.54884 .65662 m .54965 .65208 L .54955 .64629 L p F P
0 g
s
.695 .838 .952 r
.5203 .68946 m .52783 .68619 L .52623 .6909 L p F P
0 g
s
.751 .956 .94 r
.53256 .68394 m .52783 .68619 L .52623 .6909 L p F P
0 g
s
.751 .956 .94 r
.52623 .6909 m .53578 .68486 L .53256 .68394 L p F P
0 g
s
.651 .758 .928 r
.69449 .38998 m .70707 .38584 L .71001 .38965 L p F P
0 g
s
.651 .758 .928 r
.70707 .38584 m .69449 .38998 L .69152 .38616 L p F P
0 g
s
.293 .387 .788 r
.48267 .66512 m .4823 .6649 L .48243 .66455 L closepath p F P
0 g
s
.295 .389 .789 r
.47936 .65739 m .47766 .65615 L p .4823 .6649 L F P
0 g
s
.295 .389 .789 r
.4823 .6649 m .48243 .66455 L .47936 .65739 L p F P
0 g
s
.651 .758 .928 r
.71001 .38965 m .72262 .38551 L .72554 .38932 L p F P
0 g
s
.651 .758 .928 r
.72262 .38551 m .71001 .38965 L .70707 .38584 L p F P
0 g
s
.211 .331 .769 r
.47936 .65739 m .47766 .65615 L .47808 .65435 L closepath p F P
0 g
s
.212 .332 .769 r
.47604 .64951 m .47355 .64723 L p .47766 .65615 L F P
0 g
s
.212 .332 .769 r
.47766 .65615 m .47808 .65435 L .47604 .64951 L p F P
0 g
s
0 .252 .761 r
.51066 .56078 m .50831 .55697 L .50295 .55298 L p F P
0 g
s
0 .306 .795 r
.50019 .54928 m .50295 .55298 L .50831 .55697 L p F P
0 g
s
.435 .483 .811 r
.48267 .66512 m .49073 .66823 L .48852 .67319 L p F P
0 g
s
.384 .443 .799 r
.49073 .66823 m .48267 .66512 L .48243 .66455 L p F P
0 g
s
.47 .515 .822 r
.48852 .67319 m .49817 .67599 L p .49698 .68083 L F P
0 g
s
.352 .438 .81 r
.48852 .67319 m .49817 .67599 L .49485 .66998 L p F P
0 g
s
.352 .438 .81 r
.49485 .66998 m .49073 .66823 L .48852 .67319 L p F P
0 g
s
.651 .758 .928 r
.72554 .38932 m .73818 .38518 L .74107 .38899 L p F P
0 g
s
.651 .758 .928 r
.73818 .38518 m .72554 .38932 L .72262 .38551 L p F P
0 g
s
.384 .443 .799 r
.48243 .66455 m .48445 .65994 L p .49073 .66823 L F P
0 g
s
.328 .409 .794 r
.48243 .66455 m .47936 .65739 L .48445 .65994 L closepath p F P
0 g
s
.104 .26 .74 r
.47604 .64951 m .47355 .64723 L .47382 .64424 L closepath p F P
0 g
s
.103 .26 .74 r
.47272 .6416 m .46969 .63824 L p .47355 .64723 L F P
0 g
s
.103 .26 .74 r
.47355 .64723 m .47382 .64424 L .47272 .6416 L p F P
0 g
s
0 0 .49 r
.54701 .62489 m .54546 .62142 L .54544 .61936 L closepath p F P
0 g
s
0 .024 .585 r
.5437 .61419 m .54256 .61213 L p .54546 .62142 L F P
0 g
s
0 .024 .585 r
.54546 .62142 m .54544 .61936 L .5437 .61419 L p F P
0 g
s
.651 .758 .928 r
.74107 .38899 m .75375 .38484 L .7566 .38866 L p F P
0 g
s
.651 .758 .928 r
.75375 .38484 m .74107 .38899 L .73818 .38518 L p F P
0 g
s
.841 .98 .873 r
.53907 .68129 m .53578 .68486 L .53256 .68394 L p F P
0 g
s
.841 .98 .873 r
.53256 .68394 m .54061 .67659 L .53907 .68129 L p F P
0 g
s
.867 .991 .736 r
.54477 .67126 m .54557 .67036 L p .53907 .68129 L F P
0 g
s
.867 .991 .736 r
.53907 .68129 m .54061 .67659 L .54477 .67126 L p F P
0 g
s
0 .17 .695 r
.47272 .6416 m .46969 .63824 L .46945 .63399 L closepath p F P
0 g
s
0 .168 .694 r
.46939 .63385 m .46589 .62922 L p .46969 .63824 L F P
0 g
s
0 .168 .694 r
.46969 .63824 m .46945 .63399 L .46939 .63385 L p F P
0 g
s
.651 .758 .928 r
.7566 .38866 m .76931 .38451 L .77214 .38833 L p F P
0 g
s
.651 .758 .928 r
.76931 .38451 m .7566 .38866 L .75375 .38484 L p F P
0 g
s
0 .187 .714 r
.51066 .56078 m .51164 .5616 L .50835 .55701 L p F P
0 g
s
0 .187 .714 r
.50835 .55701 m .50831 .55697 L .51066 .56078 L p F P
0 g
s
.651 .758 .928 r
.77214 .38833 m .78488 .38418 L .78769 .38799 L p F P
0 g
s
.651 .758 .928 r
.78488 .38418 m .77214 .38833 L .76931 .38451 L p F P
0 g
s
0 0 .538 r
.5437 .61419 m .54256 .61213 L .54241 .61046 L closepath p F P
0 g
s
0 .078 .632 r
.54041 .60542 m .53886 .60308 L p .54256 .61213 L F P
0 g
s
0 .078 .632 r
.54256 .61213 m .54241 .61046 L .54041 .60542 L p F P
0 g
s
.559 .63 .879 r
.51323 .6862 m .50477 .68697 L .50148 .68167 L p F P
0 g
s
.425 .544 .873 r
.50148 .68167 m .49698 .68083 L .49845 .67647 L closepath p F P
0 g
s
.47 .515 .822 r
.49817 .67599 m .49845 .67647 L .49698 .68083 L p F P
0 g
s
0 .003 .579 r
.46589 .62922 m .46939 .63385 L .46606 .62642 L p F P
0 g
s
0 .003 .579 r
.46606 .62642 m .46514 .62503 L .46589 .62922 L p F P
0 g
s
0 0 .574 r
.46589 .62922 m .46514 .62503 L .46201 .62023 L p F P
0 g
s
.651 .758 .928 r
.78769 .38799 m .80046 .38384 L .80323 .38766 L p F P
0 g
s
.651 .758 .928 r
.80046 .38384 m .78769 .38799 L .78488 .38418 L p F P
0 g
s
0 0 .148 r
.55021 .64176 m .54955 .64629 L .54965 .65208 L p F P
0 g
s
0 0 .325 r
.54955 .64629 m .55021 .64176 L .54919 .63625 L p F P
0 g
s
0 .136 .681 r
.5237 .57716 m .52188 .57322 L .5175 .56887 L p F P
0 g
s
0 .116 .661 r
.51534 .56502 m .5175 .56887 L .52188 .57322 L p F P
0 g
s
0 .176 .709 r
.51164 .5616 m .51534 .56502 L .5175 .56887 L p F P
0 g
s
.333 .408 .79 r
.48445 .65994 m .47936 .65739 L .47808 .65435 L p F P
0 g
s
0 .009 .583 r
.54041 .60542 m .53886 .60308 L .53841 .60053 L closepath p F P
0 g
s
0 .129 .674 r
.53712 .59771 m .53444 .59425 L p .53886 .60308 L F P
0 g
s
0 .129 .674 r
.53886 .60308 m .53841 .60053 L .53712 .59771 L p F P
0 g
s
0 0 .514 r
.46074 .61617 m .46201 .62023 L .46514 .62503 L p F P
0 g
s
0 0 .478 r
.46201 .62023 m .46074 .61617 L .45793 .61129 L p F P
0 g
s
.651 .758 .928 r
.80323 .38766 m .81604 .3835 L .81879 .38732 L p F P
0 g
s
.651 .758 .928 r
.81604 .3835 m .80323 .38766 L .80046 .38384 L p F P
0 g
s
0 .129 .678 r
.52936 .58561 m .52789 .58159 L .5237 .57716 L p F P
0 g
s
0 .115 .665 r
.52188 .57322 m .5237 .57716 L .52789 .58159 L p F P
0 g
s
0 .138 .673 r
.51534 .56502 m .51164 .5616 L .50835 .55701 L p F P
0 g
s
0 .033 .604 r
.53444 .59425 m .53712 .59771 L .53385 .59081 L p F P
0 g
s
0 .033 .604 r
.53385 .59081 m .53334 .59013 L .53444 .59425 L p F P
0 g
s
0 .118 .669 r
.53444 .59425 m .53334 .59013 L .52936 .58561 L p F P
0 g
s
0 .143 .688 r
.52789 .58159 m .52936 .58561 L .53334 .59013 L p F P
0 g
s
.333 .408 .79 r
.47808 .65435 m .47906 .65138 L p .48445 .65994 L F P
0 g
s
.27 .369 .781 r
.47808 .65435 m .47604 .64951 L .47906 .65138 L closepath p F P
0 g
s
0 0 .331 r
.45612 .60737 m .45793 .61129 L .46074 .61617 L p F P
0 g
s
0 0 .331 r
.46074 .61617 m .45873 .61232 L .45612 .60737 L p F P
0 g
s
.729 .302 0 r
.45612 .60737 m .45873 .61232 L p .45861 .61212 L F P
0 g
s
0 0 .36 r
.45793 .61129 m .45612 .60737 L p .45365 .60264 L F P
0 g
s
.729 .302 0 r
.45362 .60365 m .45612 .60737 L p .45861 .61212 L F P
0 g
s
0 0 .36 r
.45612 .60737 m .45355 .60244 L p .45365 .60264 L F P
0 g
s
.804 .818 .338 r
.54557 .67036 m .54579 .66921 L .54795 .66272 L p F P
0 g
s
0 0 0 r
.54795 .66272 m .5487 .65821 L .54965 .65208 L p F P
0 g
s
.867 .866 .418 r
.5487 .65821 m .54795 .66272 L .54579 .66921 L p F P
0 g
s
.736 .321 0 r
.45117 .59868 m .45355 .60244 L .45612 .60737 L p F P
0 g
s
.718 .31 0 r
.45355 .60244 m .45117 .59868 L .44873 .59372 L p F P
0 g
s
.805 .367 0 r
.44873 .59372 m .44571 .59014 L .44331 .58519 L p F P
0 g
s
.812 .373 0 r
.44571 .59014 m .44873 .59372 L .45117 .59868 L p F P
0 g
s
0 0 .442 r
.54544 .61936 m .54518 .61712 L p .54768 .62654 L F P
0 g
s
0 0 .442 r
.54768 .62654 m .54701 .62489 L .54544 .61936 L p F P
0 g
s
0 0 .5 r
.54544 .61936 m .5437 .61419 L .54518 .61712 L closepath p F P
0 g
s
.651 .758 .928 r
.66044 .38682 m .67298 .38266 L .67598 .38649 L p F P
0 g
s
0 0 .493 r
.54518 .61712 m .5437 .61419 L .54241 .61046 L p F P
0 g
s
.271 .369 .781 r
.47906 .65138 m .47604 .64951 L .47382 .64424 L p F P
0 g
s
0 .202 .706 r
.50019 .54928 m .49706 .54568 L .49177 .54169 L p F P
0 g
s
0 0 .493 r
.54241 .61046 m .54193 .60791 L p .54518 .61712 L F P
0 g
s
0 0 .55 r
.54241 .61046 m .54041 .60542 L .54193 .60791 L closepath p F P
0 g
s
0 0 .297 r
.5493 .63483 m .54919 .63625 L .55021 .64176 L p F P
0 g
s
0 0 .426 r
.54919 .63625 m .5493 .63483 L .54772 .62747 L p F P
0 g
s
0 0 .448 r
.54772 .62747 m .54701 .62489 L .54768 .62654 L closepath p F P
0 g
s
.624 .851 .986 r
.52783 .68619 m .5203 .68946 L .51702 .6859 L p F P
0 g
s
.651 .758 .928 r
.67598 .38649 m .68855 .38234 L .69152 .38616 L p F P
0 g
s
.651 .758 .928 r
.68855 .38234 m .67598 .38649 L .67298 .38266 L p F P
0 g
s
0 0 .317 r
.54768 .62654 m .54772 .62747 L .5493 .63483 L p F P
0 g
s
.651 .758 .928 r
.69152 .38616 m .70412 .38201 L .70707 .38584 L p F P
0 g
s
.651 .758 .928 r
.70412 .38201 m .69152 .38616 L .68855 .38234 L p F P
0 g
s
.882 .931 .551 r
.54477 .67126 m .54579 .66921 L .54557 .67036 L closepath p F P
0 g
s
.651 .758 .928 r
.70707 .38584 m .7197 .38168 L .72262 .38551 L p F P
0 g
s
.651 .758 .928 r
.7197 .38168 m .70707 .38584 L .70412 .38201 L p F P
0 g
s
0 0 .541 r
.54193 .60791 m .54041 .60542 L .53841 .60053 L p F P
0 g
s
.271 .369 .781 r
.47382 .64424 m .47416 .64268 L p .47906 .65138 L F P
0 g
s
.202 .325 .767 r
.47382 .64424 m .47272 .6416 L .47416 .64268 L closepath p F P
0 g
s
.559 .63 .879 r
.50148 .68167 m .51357 .68183 L .51323 .6862 L p F P
0 g
s
.515 .592 .87 r
.51357 .68183 m .50148 .68167 L .49845 .67647 L p F P
0 g
s
.651 .758 .928 r
.72262 .38551 m .73529 .38135 L .73818 .38518 L p F P
0 g
s
.651 .758 .928 r
.73529 .38135 m .72262 .38551 L .7197 .38168 L p F P
0 g
s
0 .306 .795 r
.50505 .55293 m .50019 .54928 L p .50831 .55697 L F P
0 g
s
0 .203 .707 r
.50019 .54928 m .50505 .55293 L .50175 .5492 L p F P
0 g
s
0 .203 .707 r
.50175 .5492 m .49706 .54568 L .50019 .54928 L p F P
0 g
s
.192 .324 .769 r
.47416 .64268 m .47272 .6416 L .46945 .63399 L p F P
0 g
s
0 0 .317 r
.5493 .63483 m .54914 .63191 L .54768 .62654 L p F P
0 g
s
0 0 .281 r
.54717 .62231 m .54768 .62654 L .54914 .63191 L p F P
0 g
s
0 0 .442 r
.54518 .61712 m .54717 .62231 L .54768 .62654 L p F P
0 g
s
.651 .758 .928 r
.73818 .38518 m .75088 .38101 L .75375 .38484 L p F P
0 g
s
.651 .758 .928 r
.75088 .38101 m .73818 .38518 L .73529 .38135 L p F P
0 g
s
0 0 .541 r
.53841 .60053 m .53799 .59891 L p .54193 .60791 L F P
0 g
s
0 .023 .596 r
.53841 .60053 m .53712 .59771 L .53799 .59891 L closepath p F P
0 g
s
.709 .668 .12 r
.55035 .64756 m .54965 .65208 L .5487 .65821 L p F P
0 g
s
0 0 .148 r
.54965 .65208 m .55035 .64756 L .55021 .64176 L p F P
0 g
s
.651 .758 .928 r
.75375 .38484 m .76647 .38068 L .76931 .38451 L p F P
0 g
s
.651 .758 .928 r
.76647 .38068 m .75375 .38484 L .75088 .38101 L p F P
0 g
s
0 0 .168 r
.54914 .63191 m .5493 .63483 L .55023 .64152 L p F P
0 g
s
0 0 .297 r
.55021 .64176 m .55023 .64152 L .5493 .63483 L p F P
0 g
s
.96 .943 .652 r
.54579 .66921 m .54637 .66475 L p .54215 .67262 L F P
0 g
s
.96 .943 .652 r
.54215 .67262 m .54477 .67126 L .54579 .66921 L p F P
0 g
s
.867 .866 .418 r
.54579 .66921 m .54637 .66475 L .5487 .65821 L p F P
0 g
s
.651 .758 .928 r
.76931 .38451 m .78207 .38034 L .78488 .38418 L p F P
0 g
s
.651 .758 .928 r
.78207 .38034 m .76931 .38451 L .76647 .38068 L p F P
0 g
s
0 .163 .686 r
.50835 .55701 m .50831 .55697 L .50811 .5567 L closepath p F P
0 g
s
0 .306 .795 r
.50831 .55697 m .50811 .5567 L .50505 .55293 L p F P
0 g
s
.477 .632 .921 r
.51323 .6862 m .51702 .6859 L .51374 .68183 L p F P
0 g
s
.477 .632 .921 r
.51374 .68183 m .51357 .68183 L .51323 .6862 L p F P
0 g
s
.624 .851 .986 r
.53051 .68273 m .52783 .68619 L p .51702 .6859 L F P
0 g
s
.705 .888 .964 r
.52783 .68619 m .53051 .68273 L .53256 .68394 L closepath p F P
0 g
s
0 .138 .673 r
.50835 .55701 m .51285 .56125 L .51534 .56502 L p F P
0 g
s
0 .099 .63 r
.51285 .56125 m .50835 .55701 L .50811 .5567 L p F P
0 g
s
0 .009 .585 r
.53799 .59891 m .53712 .59771 L .53385 .59081 L p F P
0 g
s
0 0 .367 r
.54439 .61295 m .54518 .61712 L .54717 .62231 L p F P
0 g
s
0 0 .493 r
.54193 .60791 m .54439 .61295 L .54518 .61712 L p F P
0 g
s
.651 .758 .928 r
.78488 .38418 m .79767 .38 L .80046 .38384 L p F P
0 g
s
.651 .758 .928 r
.79767 .38 m .78488 .38418 L .78207 .38034 L p F P
0 g
s
0 .099 .63 r
.50811 .5567 m .5055 .55329 L p .51285 .56125 L F P
0 g
s
0 .184 .701 r
.50811 .5567 m .50505 .55293 L .5055 .55329 L closepath p F P
0 g
s
.844 .987 .712 r
.54061 .67659 m .54215 .67262 L .54477 .67126 L closepath p F P
0 g
s
.333 .408 .79 r
.47906 .65138 m .48515 .65538 L .48445 .65994 L p F P
0 g
s
.064 .278 .768 r
.47957 .64686 m .47906 .65138 L .48515 .65538 L p F P
0 g
s
.271 .369 .781 r
.47416 .64268 m .47957 .64686 L .47906 .65138 L p F P
0 g
s
.384 .443 .799 r
.48445 .65994 m .49139 .66371 L .49073 .66823 L p F P
0 g
s
.222 .396 .825 r
.48515 .65538 m .48445 .65994 L .49139 .66371 L p F P
0 g
s
0 .224 .736 r
.47434 .63823 m .47416 .64268 L .47957 .64686 L p F P
0 g
s
.192 .324 .769 r
.46946 .63391 m .47434 .63823 L .47416 .64268 L p F P
0 g
s
.192 .324 .769 r
.46945 .63399 m .46946 .63391 L p .47416 .64268 L F P
0 g
s
.651 .758 .928 r
.80046 .38384 m .81328 .37966 L .81604 .3835 L p F P
0 g
s
.651 .758 .928 r
.81328 .37966 m .80046 .38384 L .79767 .38 L p F P
0 g
s
.119 .275 .749 r
.46945 .63399 m .46939 .63385 L .46946 .63391 L closepath p F P
0 g
s
.092 .269 .752 r
.46946 .63391 m .46939 .63385 L .46606 .62642 L p F P
0 g
s
0 .116 .661 r
.52188 .57322 m .51973 .56937 L .51534 .56502 L p F P
0 g
s
0 .094 .636 r
.51285 .56125 m .51534 .56502 L .51973 .56937 L p F P
0 g
s
0 .167 .702 r
.46921 .62957 m .46946 .63391 L .47434 .63823 L p F P
0 g
s
.092 .269 .752 r
.46606 .62642 m .46921 .62957 L .46946 .63391 L p F P
0 g
s
0 0 .431 r
.54086 .60381 m .54193 .60791 L .54439 .61295 L p F P
0 g
s
0 0 .541 r
.53799 .59891 m .54086 .60381 L .54193 .60791 L p F P
0 g
s
.248 .395 .814 r
.49073 .66823 m .49485 .66998 L .49153 .6638 L p F P
0 g
s
.248 .395 .814 r
.49153 .6638 m .49139 .66371 L .49073 .66823 L p F P
0 g
s
0 0 .521 r
.46606 .62642 m .46514 .62503 L .46442 .62307 L closepath p F P
0 g
s
0 0 .514 r
.46271 .61957 m .46074 .61617 L p .46514 .62503 L F P
0 g
s
0 0 .514 r
.46514 .62503 m .46442 .62307 L .46271 .61957 L p F P
0 g
s
0 .115 .665 r
.52789 .58159 m .52611 .57764 L .52188 .57322 L p F P
0 g
s
0 .165 .7 r
.51973 .56937 m .52188 .57322 L .52611 .57764 L p F P
0 g
s
.849 .896 .871 r
.53051 .68273 m .53256 .68394 L .54061 .67659 L p F P
0 g
s
.849 .896 .871 r
.54061 .67659 m .54215 .67262 L p .53051 .68273 L F P
0 g
s
0 0 .343 r
.46074 .61617 m .46271 .61957 L .45935 .61349 L p F P
0 g
s
0 0 .343 r
.45935 .61349 m .45873 .61232 L .46074 .61617 L p F P
0 g
s
0 0 .477 r
.53662 .59488 m .53799 .59891 L .54086 .60381 L p F P
0 g
s
0 .009 .585 r
.53385 .59081 m .53662 .59488 L .53799 .59891 L p F P
0 g
s
.515 .592 .87 r
.49845 .67647 m .4987 .67604 L p .51357 .68183 L F P
0 g
s
.48 .575 .873 r
.49845 .67647 m .49817 .67599 L .4987 .67604 L closepath p F P
0 g
s
0 .143 .688 r
.53057 .58468 m .52789 .58159 L p .53334 .59013 L F P
0 g
s
0 .042 .607 r
.52789 .58159 m .53057 .58468 L .52729 .57904 L p F P
0 g
s
0 .042 .607 r
.52729 .57904 m .52611 .57764 L .52789 .58159 L p F P
0 g
s
.812 .373 0 r
.45117 .59868 m .4481 .59511 L .44571 .59014 L p F P
0 g
s
.736 .321 0 r
.45612 .60737 m .45362 .60365 L .45117 .59868 L p F P
0 g
s
0 .006 .581 r
.53385 .59081 m .53334 .59013 L .53296 .58904 L closepath p F P
0 g
s
0 .143 .688 r
.53334 .59013 m .53296 .58904 L .53057 .58468 L p F P
0 g
s
.487 .564 .859 r
.4987 .67604 m .49817 .67599 L .49485 .66998 L p F P
0 g
s
.815 .373 0 r
.4481 .59511 m .45117 .59868 L .45362 .60365 L p F P
0 g
s
0 0 .107 r
.55023 .64152 m .55021 .64176 L .55035 .64756 L p F P
0 g
s
.624 .851 .986 r
.51702 .6859 m .52931 .68194 L .53051 .68273 L p F P
0 g
s
.578 .791 .98 r
.52931 .68194 m .51702 .6859 L .51374 .68183 L p F P
0 g
s
.515 .592 .87 r
.4987 .67604 m .51044 .67733 L p .51357 .68183 L F P
0 g
s
.417 .519 .855 r
.4987 .67604 m .51044 .67733 L .50713 .67254 L p F P
0 g
s
.417 .519 .855 r
.50713 .67254 m .5008 .67111 L .4987 .67604 L p F P
0 g
s
.487 .564 .859 r
.49485 .66998 m .5008 .67111 L .4987 .67604 L p F P
0 g
s
0 0 .168 r
.55023 .64152 m .54998 .63748 L .54914 .63191 L p F P
0 g
s
0 0 .107 r
.55035 .64756 m .55037 .64741 L .55023 .64152 L p F P
0 g
s
.753 .595 .024 r
.54998 .63748 m .55023 .64152 L .55037 .64741 L p F P
0 g
s
.651 .758 .928 r
.67298 .38266 m .68556 .3785 L .68855 .38234 L p F P
0 g
s
0 0 .533 r
.53662 .59488 m .53385 .59081 L .53296 .58904 L p F P
0 g
s
.651 .758 .928 r
.68855 .38234 m .70117 .37817 L .70412 .38201 L p F P
0 g
s
.651 .758 .928 r
.70117 .37817 m .68855 .38234 L .68556 .3785 L p F P
0 g
s
0 .191 .717 r
.46921 .62957 m .46606 .62642 L .46442 .62307 L p F P
0 g
s
.886 .885 .455 r
.54937 .6537 m .5487 .65821 L .54637 .66475 L p F P
0 g
s
.709 .668 .12 r
.5487 .65821 m .54937 .6537 L .55035 .64756 L p F P
0 g
s
.651 .758 .928 r
.70412 .38201 m .71677 .37783 L .7197 .38168 L p F P
0 g
s
.651 .758 .928 r
.71677 .37783 m .70412 .38201 L .70117 .37817 L p F P
0 g
s
0 0 .533 r
.53296 .58904 m .53175 .58614 L p .53662 .59488 L F P
0 g
s
0 .03 .598 r
.53296 .58904 m .53057 .58468 L .53175 .58614 L closepath p F P
0 g
s
.651 .758 .928 r
.7197 .38168 m .73238 .3775 L .73529 .38135 L p F P
0 g
s
.651 .758 .928 r
.73238 .3775 m .7197 .38168 L .71677 .37783 L p F P
0 g
s
0 0 .128 r
.54864 .62769 m .54914 .63191 L .54998 .63748 L p F P
0 g
s
0 0 .281 r
.54914 .63191 m .54864 .62769 L .54717 .62231 L p F P
0 g
s
.651 .758 .928 r
.73529 .38135 m .748 .37717 L .75088 .38101 L p F P
0 g
s
.651 .758 .928 r
.748 .37717 m .73529 .38135 L .73238 .3775 L p F P
0 g
s
0 .191 .717 r
.46442 .62307 m .46397 .62095 L p .46921 .62957 L F P
0 g
s
0 .141 .684 r
.46442 .62307 m .46271 .61957 L .46397 .62095 L closepath p F P
0 g
s
.651 .758 .928 r
.75088 .38101 m .76362 .37683 L .76647 .38068 L p F P
0 g
s
.651 .758 .928 r
.76362 .37683 m .75088 .38101 L .748 .37717 L p F P
0 g
s
0 .162 .671 r
.5055 .55329 m .50505 .55293 L .50175 .5492 L p F P
0 g
s
.651 .758 .928 r
.76647 .38068 m .77925 .3765 L .78207 .38034 L p F P
0 g
s
.651 .758 .928 r
.77925 .3765 m .76647 .38068 L .76362 .37683 L p F P
0 g
s
.436 .529 .854 r
.5008 .67111 m .49485 .66998 L .49153 .6638 L p F P
0 g
s
0 .099 .63 r
.5055 .55329 m .51004 .55757 L .51285 .56125 L p F P
0 g
s
0 .068 .586 r
.50235 .5497 m .5055 .55329 L .51004 .55757 L p F P
0 g
s
0 .162 .671 r
.50175 .5492 m .50235 .5497 L .5055 .55329 L p F P
0 g
s
0 0 .249 r
.5464 .61815 m .54717 .62231 L .54864 .62769 L p F P
0 g
s
0 0 .367 r
.54717 .62231 m .5464 .61815 L .54439 .61295 L p F P
0 g
s
.772 .884 .926 r
.52931 .68194 m .53058 .68113 L .53051 .68273 L closepath p F P
0 g
s
.849 .896 .871 r
.54159 .67269 m .53058 .68113 L .53051 .68273 L p F P
0 g
s
.849 .896 .871 r
.54215 .67262 m .54159 .67269 L p .53051 .68273 L F P
0 g
s
.651 .758 .928 r
.78207 .38034 m .79487 .37616 L .79767 .38 L p F P
0 g
s
.651 .758 .928 r
.79487 .37616 m .78207 .38034 L .77925 .3765 L p F P
0 g
s
0 .105 .66 r
.46397 .62095 m .46271 .61957 L .45935 .61349 L p F P
0 g
s
.651 .758 .928 r
.79767 .38 m .81051 .37581 L .81328 .37966 L p F P
0 g
s
.651 .758 .928 r
.81051 .37581 m .79767 .38 L .79487 .37616 L p F P
0 g
s
0 .011 .579 r
.53175 .58614 m .53057 .58468 L .52729 .57904 L p F P
0 g
s
0 .094 .636 r
.51973 .56937 m .51726 .56559 L .51285 .56125 L p F P
0 g
s
0 .07 .603 r
.51004 .55757 m .51285 .56125 L .51726 .56559 L p F P
0 g
s
.753 .697 .155 r
.55037 .64741 m .55035 .64756 L .54937 .6537 L p F P
0 g
s
0 0 .338 r
.54333 .60885 m .54439 .61295 L .5464 .61815 L p F P
0 g
s
0 0 .431 r
.54439 .61295 m .54333 .60885 L .54086 .60381 L p F P
0 g
s
.96 .943 .652 r
.54637 .66475 m .54223 .67184 L .54215 .67262 L p F P
0 g
s
.938 .966 .722 r
.54688 .6603 m .54637 .66475 L .54223 .67184 L p F P
0 g
s
.886 .885 .455 r
.54637 .66475 m .54688 .6603 L .54937 .6537 L p F P
0 g
s
.877 .754 .247 r
.55009 .64329 m .55037 .64741 L .54952 .65227 L p F P
0 g
s
.753 .595 .024 r
.55037 .64741 m .55009 .64329 L .54998 .63748 L p F P
0 g
s
.753 .697 .155 r
.54937 .6537 m .54952 .65227 L .55037 .64741 L p F P
0 g
s
.477 .632 .922 r
.51374 .68183 m .51357 .68183 L .51358 .68163 L closepath p F P
0 g
s
.515 .592 .87 r
.51044 .67733 m .51358 .68163 L .51357 .68183 L p F P
0 g
s
.578 .791 .98 r
.51374 .68183 m .52605 .67917 L .52931 .68194 L p F P
0 g
s
.563 .673 .913 r
.52277 .6759 m .52605 .67917 L .51374 .68183 L p F P
0 g
s
.563 .673 .913 r
.51709 .67651 m .52277 .6759 L p .51374 .68183 L F P
0 g
s
.563 .673 .913 r
.51374 .68183 m .51358 .68163 L .51709 .67651 L p F P
0 g
s
0 .165 .7 r
.524 .57376 m .51973 .56937 L p .52611 .57764 L F P
0 g
s
0 .06 .606 r
.51973 .56937 m .524 .57376 L .52071 .5692 L p F P
0 g
s
0 .06 .606 r
.52071 .5692 m .51726 .56559 L .51973 .56937 L p F P
0 g
s
.563 .674 .913 r
.51358 .68163 m .51044 .67733 L .51709 .67651 L closepath p F P
0 g
s
0 0 .402 r
.53949 .59978 m .54086 .60381 L .54333 .60885 L p F P
0 g
s
0 0 .477 r
.54086 .60381 m .53949 .59978 L .53662 .59488 L p F P
0 g
s
.815 .373 0 r
.45362 .60365 m .45051 .60011 L .4481 .59511 L p F P
0 g
s
.717 .289 0 r
.45935 .61349 m .45873 .61232 L .45659 .6093 L closepath p F P
0 g
s
.729 .302 0 r
.45598 .60837 m .45362 .60365 L p .45873 .61232 L F P
0 g
s
.729 .302 0 r
.45873 .61232 m .45659 .6093 L .45598 .60837 L p F P
0 g
s
0 .224 .736 r
.47957 .64686 m .47904 .64263 L .47434 .63823 L p F P
0 g
s
0 .124 .674 r
.47351 .63407 m .47434 .63823 L .47904 .64263 L p F P
0 g
s
0 .167 .702 r
.47434 .63823 m .47351 .63407 L .46921 .62957 L p F P
0 g
s
.064 .278 .768 r
.48515 .65538 m .48479 .65112 L .47957 .64686 L p F P
0 g
s
.008 .262 .765 r
.47904 .64263 m .47957 .64686 L .48479 .65112 L p F P
0 g
s
0 .191 .717 r
.46397 .62095 m .468 .6255 L .46921 .62957 L p F P
0 g
s
0 .002 .569 r
.4623 .61699 m .46397 .62095 L .468 .6255 L p F P
0 g
s
0 .105 .66 r
.45935 .61349 m .4623 .61699 L .46397 .62095 L p F P
0 g
s
0 .061 .624 r
.468 .6255 m .46921 .62957 L .47351 .63407 L p F P
0 g
s
.81 .367 0 r
.45362 .60365 m .45598 .60837 L .45258 .60434 L p F P
0 g
s
.81 .367 0 r
.45258 .60434 m .45051 .60011 L .45362 .60365 L p F P
0 g
s
.733 .847 .934 r
.53058 .68113 m .52931 .68194 L .52605 .67917 L p F P
0 g
s
.222 .396 .825 r
.4882 .65747 m .48515 .65538 L p .49139 .66371 L F P
0 g
s
.062 .276 .766 r
.48515 .65538 m .4882 .65747 L .48487 .65119 L p F P
0 g
s
.062 .276 .766 r
.48487 .65119 m .48479 .65112 L .48515 .65538 L p F P
0 g
s
0 .015 .577 r
.52729 .57904 m .52611 .57764 L .52403 .57381 L closepath p F P
0 g
s
0 .165 .7 r
.52611 .57764 m .52403 .57381 L .524 .57376 L p F P
0 g
s
.913 .977 .779 r
.54159 .67269 m .54223 .67184 L .54215 .67262 L closepath p F P
0 g
s
0 0 .446 r
.53496 .59092 m .53662 .59488 L .53949 .59978 L p F P
0 g
s
0 0 .533 r
.53175 .58614 m .53496 .59092 L .53662 .59488 L p F P
0 g
s
0 0 .477 r
.52978 .58225 m .53175 .58614 L .53496 .59092 L p F P
0 g
s
0 .011 .579 r
.52729 .57904 m .52978 .58225 L .53175 .58614 L p F P
0 g
s
.733 .847 .934 r
.52605 .67917 m .53029 .67694 L .53058 .68113 L p F P
0 g
s
.799 .973 .908 r
.53836 .67203 m .53029 .67694 L .53058 .68113 L p F P
0 g
s
.799 .973 .908 r
.53058 .68113 m .54159 .67269 L .53836 .67203 L p F P
0 g
s
.651 .758 .928 r
.68556 .3785 m .6982 .37431 L .70117 .37817 L p F P
0 g
s
.221 .395 .824 r
.49153 .6638 m .49139 .66371 L .49139 .66353 L closepath p F P
0 g
s
.222 .396 .825 r
.49139 .66371 m .49139 .66353 L .4882 .65747 L p F P
0 g
s
.436 .529 .854 r
.49153 .6638 m .50119 .66667 L .5008 .67111 L p F P
0 g
s
.382 .493 .847 r
.50119 .66667 m .49153 .6638 L .49139 .66353 L p F P
0 g
s
.382 .493 .847 r
.49139 .66353 m .49244 .65906 L p .50119 .66667 L F P
0 g
s
.337 .466 .843 r
.49139 .66353 m .4882 .65747 L .49244 .65906 L closepath p F P
0 g
s
.651 .758 .928 r
.70117 .37817 m .71383 .37398 L .71677 .37783 L p F P
0 g
s
.651 .758 .928 r
.71383 .37398 m .70117 .37817 L .6982 .37431 L p F P
0 g
s
0 0 .128 r
.54998 .63748 m .54948 .63327 L .54864 .62769 L p F P
0 g
s
.802 .626 .068 r
.54948 .63327 m .54998 .63748 L .55009 .64329 L p F P
0 g
s
0 0 .556 r
.4623 .61699 m .45935 .61349 L .45659 .6093 L p F P
0 g
s
.896 .959 .829 r
.54223 .67184 m .54159 .67269 L .53836 .67203 L p F P
0 g
s
.896 .959 .829 r
.53836 .67203 m .54231 .66752 L .54223 .67184 L p F P
0 g
s
.938 .966 .722 r
.54223 .67184 m .54231 .66752 L .54688 .6603 L p F P
0 g
s
.651 .758 .928 r
.71677 .37783 m .72947 .37364 L .73238 .3775 L p F P
0 g
s
.651 .758 .928 r
.72947 .37364 m .71677 .37783 L .71383 .37398 L p F P
0 g
s
.651 .758 .928 r
.73238 .3775 m .74511 .37331 L .748 .37717 L p F P
0 g
s
.651 .758 .928 r
.74511 .37331 m .73238 .3775 L .72947 .37364 L p F P
0 g
s
0 0 .528 r
.52978 .58225 m .52729 .57904 L .52403 .57381 L p F P
0 g
s
.651 .758 .928 r
.748 .37717 m .76076 .37297 L .76362 .37683 L p F P
0 g
s
.651 .758 .928 r
.76076 .37297 m .748 .37717 L .74511 .37331 L p F P
0 g
s
.33 .49 .867 r
.5008 .67111 m .50713 .67254 L .50381 .66756 L p F P
0 g
s
.33 .49 .867 r
.50381 .66756 m .50119 .66667 L .5008 .67111 L p F P
0 g
s
.651 .758 .928 r
.76362 .37683 m .77641 .37263 L .77925 .3765 L p F P
0 g
s
.651 .758 .928 r
.77641 .37263 m .76362 .37683 L .76076 .37297 L p F P
0 g
s
.883 .882 .45 r
.54952 .65227 m .54937 .6537 L .54688 .6603 L p F P
0 g
s
0 0 .249 r
.54864 .62769 m .54789 .62352 L .5464 .61815 L p F P
0 g
s
.718 .494 0 r
.54789 .62352 m .54864 .62769 L .54948 .63327 L p F P
0 g
s
0 .068 .586 r
.51004 .55757 m .50689 .55397 L .50235 .5497 L p F P
0 g
s
.651 .758 .928 r
.77925 .3765 m .79207 .37229 L .79487 .37616 L p F P
0 g
s
.651 .758 .928 r
.79207 .37229 m .77925 .3765 L .77641 .37263 L p F P
0 g
s
.651 .758 .928 r
.79487 .37616 m .80773 .37195 L .81051 .37581 L p F P
0 g
s
.651 .758 .928 r
.80773 .37195 m .79487 .37616 L .79207 .37229 L p F P
0 g
s
.567 .661 .9 r
.51709 .67651 m .51044 .67733 L .50713 .67254 L p F P
0 g
s
.334 .467 .845 r
.49244 .65906 m .4882 .65747 L .48487 .65119 L p F P
0 g
s
0 0 .218 r
.54536 .61405 m .5464 .61815 L .54789 .62352 L p F P
0 g
s
0 0 .338 r
.5464 .61815 m .54536 .61405 L .54333 .60885 L p F P
0 g
s
0 .07 .603 r
.51726 .56559 m .51445 .56191 L .51004 .55757 L p F P
0 g
s
0 .042 .562 r
.50689 .55397 m .51004 .55757 L .51445 .56191 L p F P
0 g
s
0 0 .556 r
.45659 .6093 m .45618 .60862 L p .4623 .61699 L F P
0 g
s
0 0 .534 r
.45659 .6093 m .45598 .60837 L .45618 .60862 L closepath p F P
0 g
s
.952 .875 .468 r
.5493 .64939 m .54952 .65227 L .54741 .65584 L p F P
0 g
s
.883 .882 .45 r
.54688 .6603 m .54741 .65584 L .54952 .65227 L p F P
0 g
s
.877 .754 .247 r
.54952 .65227 m .5493 .64939 L .55009 .64329 L p F P
0 g
s
0 .027 .563 r
.51726 .56559 m .52071 .5692 L .51741 .56503 L p F P
0 g
s
0 .027 .563 r
.51741 .56503 m .51445 .56191 L .51726 .56559 L p F P
0 g
s
0 0 .308 r
.54199 .60482 m .54333 .60885 L .54536 .61405 L p F P
0 g
s
0 0 .402 r
.54333 .60885 m .54199 .60482 L .53949 .59978 L p F P
0 g
s
.568 .096 0 r
.45618 .60862 m .45598 .60837 L .45258 .60434 L p F P
0 g
s
.916 .778 .297 r
.54958 .63909 m .55009 .64329 L .5493 .64939 L p F P
0 g
s
.802 .626 .068 r
.55009 .64329 m .54958 .63909 L .54948 .63327 L p F P
0 g
s
0 0 .556 r
.45618 .60862 m .45988 .61325 L .4623 .61699 L p F P
0 g
s
.598 .122 0 r
.45315 .60505 m .45618 .60862 L .45988 .61325 L p F P
0 g
s
.568 .096 0 r
.45258 .60434 m .45315 .60505 L .45618 .60862 L p F P
0 g
s
.693 .823 .945 r
.53029 .67694 m .52605 .67917 L .52277 .6759 L p F P
0 g
s
0 0 .37 r
.53785 .59582 m .53949 .59978 L .54199 .60482 L p F P
0 g
s
0 0 .446 r
.53949 .59978 m .53785 .59582 L .53496 .59092 L p F P
0 g
s
0 0 .528 r
.52403 .57381 m .52401 .57377 L p .52978 .58225 L F P
0 g
s
0 .052 .605 r
.52403 .57381 m .524 .57376 L .52401 .57377 L closepath p F P
0 g
s
0 .028 .574 r
.52401 .57377 m .524 .57376 L .52071 .5692 L p F P
0 g
s
0 0 .528 r
.52401 .57377 m .52752 .57844 L .52978 .58225 L p F P
0 g
s
0 0 .458 r
.52145 .57003 m .52401 .57377 L .52752 .57844 L p F P
0 g
s
0 .028 .574 r
.52071 .5692 m .52145 .57003 L .52401 .57377 L p F P
0 g
s
.932 .967 .752 r
.54741 .65584 m .54688 .6603 L .54231 .66752 L p F P
0 g
s
0 .002 .569 r
.468 .6255 m .46605 .62164 L .4623 .61699 L p F P
0 g
s
0 0 .46 r
.45988 .61325 m .4623 .61699 L .46605 .62164 L p F P
0 g
s
0 0 .411 r
.533 .58703 m .53496 .59092 L .53785 .59582 L p F P
0 g
s
0 0 .477 r
.53496 .59092 m .533 .58703 L .52978 .58225 L p F P
0 g
s
0 0 .438 r
.52752 .57844 m .52978 .58225 L .533 .58703 L p F P
0 g
s
0 .061 .624 r
.47351 .63407 m .47192 .63011 L .468 .6255 L p F P
0 g
s
0 0 .526 r
.46605 .62164 m .468 .6255 L .47192 .63011 L p F P
0 g
s
.651 .758 .928 r
.6982 .37431 m .71088 .37011 L .71383 .37398 L p F P
0 g
s
0 .124 .674 r
.47904 .64263 m .47772 .63861 L .47351 .63407 L p F P
0 g
s
0 .081 .637 r
.47192 .63011 m .47351 .63407 L .47772 .63861 L p F P
0 g
s
.008 .262 .765 r
.48152 .645 m .47904 .64263 L p .48479 .65112 L F P
0 g
s
0 .124 .674 r
.47904 .64263 m .48152 .645 L .47817 .6391 L p F P
0 g
s
0 .124 .674 r
.47817 .6391 m .47772 .63861 L .47904 .64263 L p F P
0 g
s
.651 .758 .928 r
.71383 .37398 m .72655 .36977 L .72947 .37364 L p F P
0 g
s
.651 .758 .928 r
.72655 .36977 m .71383 .37398 L .71088 .37011 L p F P
0 g
s
.01 .264 .766 r
.48487 .65119 m .48479 .65112 L .48476 .65099 L closepath p F P
0 g
s
.008 .262 .765 r
.48479 .65112 m .48476 .65099 L .48152 .645 L p F P
0 g
s
.334 .467 .845 r
.48487 .65119 m .49229 .65474 L .49244 .65906 L p F P
0 g
s
.261 .428 .839 r
.49229 .65474 m .48487 .65119 L .48476 .65099 L p F P
0 g
s
.261 .428 .839 r
.48476 .65099 m .48472 .64676 L p .49229 .65474 L F P
0 g
s
.213 .397 .829 r
.48476 .65099 m .48152 .645 L .48472 .64676 L closepath p F P
0 g
s
.693 .823 .945 r
.52277 .6759 m .53057 .67256 L .53029 .67694 L p F P
0 g
s
.758 .92 .944 r
.53512 .67042 m .53057 .67256 L .53029 .67694 L p F P
0 g
s
.758 .92 .944 r
.53029 .67694 m .53836 .67203 L .53512 .67042 L p F P
0 g
s
.651 .758 .928 r
.72947 .37364 m .74222 .36944 L .74511 .37331 L p F P
0 g
s
.651 .758 .928 r
.74222 .36944 m .72947 .37364 L .72655 .36977 L p F P
0 g
s
.651 .758 .928 r
.74511 .37331 m .75789 .3691 L .76076 .37297 L p F P
0 g
s
.651 .758 .928 r
.75789 .3691 m .74511 .37331 L .74222 .36944 L p F P
0 g
s
.842 .649 .106 r
.54875 .6291 m .54948 .63327 L .54958 .63909 L p F P
0 g
s
.718 .494 0 r
.54948 .63327 m .54875 .6291 L .54789 .62352 L p F P
0 g
s
.49 .656 .933 r
.51709 .67651 m .52277 .6759 L .51947 .67225 L p F P
0 g
s
.49 .656 .933 r
.51947 .67225 m .51689 .67226 L .51709 .67651 L p F P
0 g
s
.567 .661 .9 r
.50713 .67254 m .51689 .67226 L .51709 .67651 L p F P
0 g
s
.382 .493 .847 r
.49244 .65906 m .50048 .66247 L p .50119 .66667 L F P
0 g
s
.214 .405 .835 r
.49244 .65906 m .50048 .66247 L .49714 .65732 L p F P
0 g
s
.214 .405 .835 r
.49714 .65732 m .49229 .65474 L .49244 .65906 L p F P
0 g
s
.522 .63 .899 r
.51689 .67226 m .50713 .67254 L .50381 .66756 L p F P
0 g
s
.651 .758 .928 r
.76076 .37297 m .77357 .36876 L .77641 .37263 L p F P
0 g
s
.651 .758 .928 r
.77357 .36876 m .76076 .37297 L .75789 .3691 L p F P
0 g
s
.871 .945 .861 r
.54231 .66752 m .53836 .67203 L .53512 .67042 L p F P
0 g
s
.871 .945 .861 r
.53512 .67042 m .54237 .66319 L .54231 .66752 L p F P
0 g
s
.932 .967 .752 r
.54739 .65585 m .54741 .65584 L p .54231 .66752 L F P
0 g
s
.932 .967 .752 r
.54231 .66752 m .54237 .66319 L .54739 .65585 L p F P
0 g
s
.651 .758 .928 r
.77641 .37263 m .78925 .36842 L .79207 .37229 L p F P
0 g
s
.651 .758 .928 r
.78925 .36842 m .77641 .37263 L .77357 .36876 L p F P
0 g
s
.651 .758 .928 r
.79207 .37229 m .80494 .36808 L .80773 .37195 L p F P
0 g
s
.651 .758 .928 r
.80494 .36808 m .79207 .37229 L .78925 .36842 L p F P
0 g
s
0 0 .218 r
.54789 .62352 m .54688 .61941 L .54536 .61405 L p F P
0 g
s
.761 .515 0 r
.54688 .61941 m .54789 .62352 L .54875 .6291 L p F P
0 g
s
.952 .875 .468 r
.54741 .65584 m .5474 .65582 L .5493 .64939 L p F P
0 g
s
.976 .885 .519 r
.54874 .6452 m .5493 .64939 L .5474 .65582 L p F P
0 g
s
.916 .778 .297 r
.5493 .64939 m .54874 .6452 L .54958 .63909 L p F P
0 g
s
.294 .5 .887 r
.50381 .66756 m .50119 .66667 L .50062 .66268 L closepath p F P
0 g
s
.382 .493 .847 r
.50048 .66247 m .50062 .66268 L .50119 .66667 L p F P
0 g
s
0 .042 .562 r
.51445 .56191 m .51131 .55831 L .50689 .55397 L p F P
0 g
s
.192 .397 .835 r
.48472 .64676 m .48152 .645 L .47817 .6391 L p F P
0 g
s
0 0 .525 r
.52145 .57003 m .52071 .5692 L .51741 .56503 L p F P
0 g
s
0 0 .308 r
.54536 .61405 m .54406 .61 L .54199 .60482 L p F P
0 g
s
.692 .4 0 r
.54406 .61 m .54536 .61405 L .54688 .61941 L p F P
0 g
s
0 0 .516 r
.51445 .56191 m .51741 .56503 L .51411 .56127 L p F P
0 g
s
0 0 .516 r
.51411 .56127 m .51131 .55831 L .51445 .56191 L p F P
0 g
s
.598 .122 0 r
.45988 .61325 m .45679 .6097 L .45315 .60505 L p F P
0 g
s
.639 .839 .977 r
.53057 .67256 m .52277 .6759 L .51947 .67225 L p F P
0 g
s
0 0 .276 r
.54038 .60085 m .54199 .60482 L .54406 .61 L p F P
0 g
s
0 0 .37 r
.54199 .60482 m .54038 .60085 L .53785 .59582 L p F P
0 g
s
0 0 .458 r
.52752 .57844 m .52497 .5747 L .52145 .57003 L p F P
0 g
s
.579 .122 0 r
.51859 .56636 m .52145 .57003 L .52497 .5747 L p F P
0 g
s
0 0 .525 r
.51741 .56503 m .51859 .56636 L .52145 .57003 L p F P
0 g
s
0 0 .46 r
.46605 .62164 m .46347 .61795 L .45988 .61325 L p F P
0 g
s
.628 .151 0 r
.45679 .6097 m .45988 .61325 L .46347 .61795 L p F P
0 g
s
0 0 .334 r
.53591 .59193 m .53785 .59582 L .54038 .60085 L p F P
0 g
s
0 0 .411 r
.53785 .59582 m .53591 .59193 L .533 .58703 L p F P
0 g
s
0 0 .438 r
.533 .58703 m .53075 .58322 L .52752 .57844 L p F P
0 g
s
.587 .155 0 r
.52497 .5747 m .52752 .57844 L .53075 .58322 L p F P
0 g
s
.651 .758 .928 r
.71088 .37011 m .72361 .36589 L .72655 .36977 L p F P
0 g
s
.522 .63 .899 r
.50381 .66756 m .51569 .66828 L .51689 .67226 L p F P
0 g
s
.475 .602 .899 r
.51569 .66828 m .50381 .66756 L .50062 .66268 L p F P
0 g
s
.942 .793 .334 r
.54884 .63493 m .54958 .63909 L .54874 .6452 L p F P
0 g
s
.842 .649 .106 r
.54958 .63909 m .54884 .63493 L .54875 .6291 L p F P
0 g
s
0 0 .371 r
.53075 .58322 m .533 .58703 L .53591 .59193 L p F P
0 g
s
0 0 .526 r
.47192 .63011 m .46973 .62633 L .46605 .62164 L p F P
0 g
s
0 0 .425 r
.46347 .61795 m .46605 .62164 L .46973 .62633 L p F P
0 g
s
.651 .758 .928 r
.72655 .36977 m .73931 .36555 L .74222 .36944 L p F P
0 g
s
.651 .758 .928 r
.73931 .36555 m .72655 .36977 L .72361 .36589 L p F P
0 g
s
0 .081 .637 r
.47481 .63356 m .47192 .63011 L p .47772 .63861 L F P
0 g
s
0 0 .524 r
.47192 .63011 m .47481 .63356 L .47144 .62851 L p F P
0 g
s
0 0 .524 r
.47144 .62851 m .46973 .62633 L .47192 .63011 L p F P
0 g
s
0 .088 .643 r
.47817 .6391 m .47772 .63861 L .47719 .63748 L closepath p F P
0 g
s
0 .081 .637 r
.47772 .63861 m .47719 .63748 L .47481 .63356 L p F P
0 g
s
.651 .758 .928 r
.74222 .36944 m .75501 .36521 L .75789 .3691 L p F P
0 g
s
.651 .758 .928 r
.75501 .36521 m .74222 .36944 L .73931 .36555 L p F P
0 g
s
.967 .927 .605 r
.54739 .65585 m .5474 .65582 L .54741 .65584 L closepath p F P
0 g
s
.971 .93 .67 r
.5474 .65582 m .54739 .65585 L .54419 .65678 L p F P
0 g
s
.971 .93 .67 r
.54419 .65678 m .54672 .65168 L .5474 .65582 L p F P
0 g
s
.976 .885 .519 r
.5474 .65582 m .54672 .65168 L .54874 .6452 L p F P
0 g
s
.92 .977 .734 r
.54237 .66319 m .54739 .65585 L .54419 .65678 L p F P
0 g
s
.651 .758 .928 r
.75789 .3691 m .77072 .36487 L .77357 .36876 L p F P
0 g
s
.651 .758 .928 r
.77072 .36487 m .75789 .3691 L .75501 .36521 L p F P
0 g
s
.192 .397 .835 r
.47817 .6391 m .48375 .64264 L .48472 .64676 L p F P
0 g
s
.088 .349 .82 r
.48375 .64264 m .47817 .6391 L .47719 .63748 L p F P
0 g
s
.261 .428 .839 r
.48472 .64676 m .49127 .65066 L .49229 .65474 L p F P
0 g
s
0 .303 .798 r
.48375 .64264 m .48472 .64676 L .49127 .65066 L p F P
0 g
s
.651 .758 .928 r
.77357 .36876 m .78643 .36453 L .78925 .36842 L p F P
0 g
s
.651 .758 .928 r
.78643 .36453 m .77357 .36876 L .77072 .36487 L p F P
0 g
s
.639 .839 .977 r
.5327 .66874 m .53057 .67256 L p .51947 .67225 L F P
0 g
s
.707 .868 .958 r
.53057 .67256 m .5327 .66874 L .53512 .67042 L closepath p F P
0 g
s
.875 .665 .138 r
.54778 .62499 m .54875 .6291 L .54884 .63493 L p F P
0 g
s
.761 .515 0 r
.54875 .6291 m .54778 .62499 L .54688 .61941 L p F P
0 g
s
.651 .758 .928 r
.78925 .36842 m .80214 .36419 L .80494 .36808 L p F P
0 g
s
.651 .758 .928 r
.80214 .36419 m .78925 .36842 L .78643 .36453 L p F P
0 g
s
.421 .626 .938 r
.51689 .67226 m .51947 .67225 L .51617 .66833 L p F P
0 g
s
.421 .626 .938 r
.51617 .66833 m .51569 .66828 L .51689 .67226 L p F P
0 g
s
.088 .349 .82 r
.47719 .63748 m .47634 .6346 L p .48375 .64264 L F P
0 g
s
.05 .322 .805 r
.47719 .63748 m .47481 .63356 L .47634 .6346 L closepath p F P
0 g
s
.098 .353 .821 r
.49229 .65474 m .49714 .65732 L .4938 .65225 L p F P
0 g
s
.098 .353 .821 r
.4938 .65225 m .49127 .65066 L .49229 .65474 L p F P
0 g
s
.86 .876 .849 r
.54237 .66319 m .54251 .65882 L p .5327 .66874 L F P
0 g
s
.86 .876 .849 r
.5327 .66874 m .53512 .67042 L .54237 .66319 L p F P
0 g
s
.92 .977 .734 r
.54419 .65678 m .54251 .65882 L .54237 .66319 L p F P
0 g
s
0 0 .473 r
.51859 .56636 m .51741 .56503 L .51411 .56127 L p F P
0 g
s
.798 .532 0 r
.54563 .61536 m .54688 .61941 L .54778 .62499 L p F P
0 g
s
.692 .4 0 r
.54688 .61941 m .54563 .61536 L .54406 .61 L p F P
0 g
s
.475 .602 .899 r
.50062 .66268 m .50066 .66249 L p .51569 .66828 L F P
0 g
s
.45 .588 .899 r
.50062 .66268 m .50048 .66247 L .50066 .66249 L closepath p F P
0 g
s
.452 .587 .897 r
.50066 .66249 m .50048 .66247 L .49714 .65732 L p F P
0 g
s
.985 .888 .55 r
.54796 .64106 m .54874 .6452 L .54672 .65168 L p F P
0 g
s
.942 .793 .334 r
.54874 .6452 m .54796 .64106 L .54884 .63493 L p F P
0 g
s
.475 .602 .899 r
.50066 .66249 m .51285 .66421 L p .51569 .66828 L F P
0 g
s
.378 .539 .889 r
.50066 .66249 m .51285 .66421 L .50952 .65998 L p F P
0 g
s
.378 .539 .889 r
.50952 .65998 m .50098 .65803 L .50066 .66249 L p F P
0 g
s
.452 .587 .897 r
.49714 .65732 m .50098 .65803 L .50066 .66249 L p F P
0 g
s
.639 .839 .977 r
.51947 .67225 m .53185 .66811 L .5327 .66874 L p F P
0 g
s
.596 .797 .976 r
.53185 .66811 m .51947 .67225 L .51617 .66833 L p F P
0 g
s
0 0 .276 r
.54406 .61 m .54249 .60602 L .54038 .60085 L p F P
0 g
s
.729 .409 0 r
.54249 .60602 m .54406 .61 L .54563 .61536 L p F P
0 g
s
.579 .122 0 r
.52497 .5747 m .52211 .57103 L .51859 .56636 L p F P
0 g
s
0 0 .473 r
.51411 .56127 m .51543 .56277 L .51859 .56636 L p F P
0 g
s
.625 .149 0 r
.51543 .56277 m .51859 .56636 L .52211 .57103 L p F P
0 g
s
0 .309 .801 r
.47634 .6346 m .47481 .63356 L .47144 .62851 L p F P
0 g
s
.628 .151 0 r
.46347 .61795 m .46033 .61441 L .45679 .6097 L p F P
0 g
s
0 0 .334 r
.54038 .60085 m .53848 .59695 L .53591 .59193 L p F P
0 g
s
.667 .304 0 r
.53848 .59695 m .54038 .60085 L .54249 .60602 L p F P
0 g
s
.587 .155 0 r
.53075 .58322 m .5282 .57947 L .52497 .5747 L p F P
0 g
s
.636 .182 0 r
.52211 .57103 m .52497 .5747 L .5282 .57947 L p F P
0 g
s
.651 .758 .928 r
.72361 .36589 m .73639 .36165 L .73931 .36555 L p F P
0 g
s
.663 .267 0 r
.53368 .58811 m .53591 .59193 L .53848 .59695 L p F P
0 g
s
0 0 .371 r
.53591 .59193 m .53368 .58811 L .53075 .58322 L p F P
0 g
s
.647 .219 0 r
.5282 .57947 m .53075 .58322 L .53368 .58811 L p F P
0 g
s
0 0 .425 r
.46973 .62633 m .46701 .62268 L .46347 .61795 L p F P
0 g
s
.646 .167 0 r
.46033 .61441 m .46347 .61795 L .46701 .62268 L p F P
0 g
s
.651 .758 .928 r
.73931 .36555 m .75212 .36131 L .75501 .36521 L p F P
0 g
s
.651 .758 .928 r
.75212 .36131 m .73931 .36555 L .73639 .36165 L p F P
0 g
s
0 0 .427 r
.46973 .62633 m .47144 .62851 L .46805 .62407 L p F P
0 g
s
0 0 .427 r
.46805 .62407 m .46701 .62268 L .46973 .62633 L p F P
0 g
s
.961 .802 .364 r
.54789 .63082 m .54884 .63493 L .54796 .64106 L p F P
0 g
s
.875 .665 .138 r
.54884 .63493 m .54789 .63082 L .54778 .62499 L p F P
0 g
s
.651 .758 .928 r
.75501 .36521 m .76785 .36097 L .77072 .36487 L p F P
0 g
s
.651 .758 .928 r
.76785 .36097 m .75501 .36521 L .75212 .36131 L p F P
0 g
s
.088 .349 .82 r
.47634 .6346 m .48205 .63873 L .48375 .64264 L p F P
0 g
s
0 .223 .741 r
.47443 .63073 m .47634 .6346 L .48205 .63873 L p F P
0 g
s
0 .309 .801 r
.47144 .62851 m .47443 .63073 L .47634 .6346 L p F P
0 g
s
.651 .758 .928 r
.77072 .36487 m .78359 .36063 L .78643 .36453 L p F P
0 g
s
.651 .758 .928 r
.78359 .36063 m .77072 .36487 L .76785 .36097 L p F P
0 g
s
.651 .758 .928 r
.78643 .36453 m .79933 .36028 L .80214 .36419 L p F P
0 g
s
.651 .758 .928 r
.79933 .36028 m .78643 .36453 L .78359 .36063 L p F P
0 g
s
.97 .897 .694 r
.54672 .65168 m .54583 .64758 L p .54257 .65662 L F P
0 g
s
.97 .897 .694 r
.54257 .65662 m .54419 .65678 L .54672 .65168 L p F P
0 g
s
.985 .888 .55 r
.54672 .65168 m .54583 .64758 L .54796 .64106 L p F P
0 g
s
.397 .562 .9 r
.50098 .65803 m .49714 .65732 L .4938 .65225 L p F P
0 g
s
.797 .871 .902 r
.53185 .66811 m .53243 .6677 L .5327 .66874 L closepath p F P
0 g
s
.86 .876 .849 r
.54251 .65882 m .53243 .6677 L .5327 .66874 L p F P
0 g
s
0 .303 .798 r
.49127 .65066 m .48962 .64674 L .48375 .64264 L p F P
0 g
s
0 .267 .773 r
.48205 .63873 m .48375 .64264 L .48962 .64674 L p F P
0 g
s
.902 .676 .168 r
.54657 .62093 m .54778 .62499 L .54789 .63082 L p F P
0 g
s
.798 .532 0 r
.54778 .62499 m .54657 .62093 L .54563 .61536 L p F P
0 g
s
.418 .628 .941 r
.51617 .66833 m .51569 .66828 L .51535 .66732 L closepath p F P
0 g
s
.475 .602 .899 r
.51285 .66421 m .51535 .66732 L .51569 .66828 L p F P
0 g
s
.596 .797 .976 r
.51617 .66833 m .52857 .66529 L .53185 .66811 L p F P
0 g
s
.582 .707 .928 r
.52527 .66215 m .52857 .66529 L .51617 .66833 L p F P
0 g
s
.582 .707 .928 r
.51755 .66339 m .52527 .66215 L p .51617 .66833 L F P
0 g
s
.582 .707 .928 r
.51617 .66833 m .51535 .66732 L .51755 .66339 L p F P
0 g
s
0 .293 .791 r
.49127 .65066 m .4938 .65225 L .49044 .64733 L p F P
0 g
s
0 .293 .791 r
.49044 .64733 m .48962 .64674 L .49127 .65066 L p F P
0 g
s
0 .248 .756 r
.47443 .63073 m .47144 .62851 L .46805 .62407 L p F P
0 g
s
.907 .964 .81 r
.54251 .65882 m .54257 .65662 L .54419 .65678 L closepath p F P
0 g
s
.768 .847 .911 r
.53243 .6677 m .53185 .66811 L .52857 .66529 L p F P
0 g
s
.768 .847 .911 r
.52857 .66529 m .53094 .66379 L .53243 .6677 L p F P
0 g
s
.809 .865 .89 r
.54257 .65662 m .54251 .65882 L .53243 .6677 L p F P
0 g
s
.809 .865 .89 r
.54095 .65612 m .54257 .65662 L p .53243 .6677 L F P
0 g
s
.809 .865 .89 r
.53243 .6677 m .53094 .66379 L .54095 .65612 L p F P
0 g
s
.846 .557 .019 r
.54484 .61332 m .54563 .61536 L .54657 .62093 L p F P
0 g
s
.729 .409 0 r
.54322 .60858 m .54249 .60602 L p .54563 .61536 L F P
0 g
s
.729 .409 0 r
.54563 .61536 m .54484 .61332 L .54322 .60858 L p F P
0 g
s
.582 .706 .928 r
.51535 .66732 m .51285 .66421 L .51755 .66339 L closepath p F P
0 g
s
.625 .149 0 r
.52211 .57103 m .51895 .56744 L .51543 .56277 L p F P
0 g
s
.99 .888 .575 r
.54699 .63696 m .54796 .64106 L .54583 .64758 L p F P
0 g
s
.961 .802 .364 r
.54796 .64106 m .54699 .63696 L .54789 .63082 L p F P
0 g
s
.809 .471 0 r
.54322 .60858 m .54249 .60602 L .54157 .60409 L closepath p F P
0 g
s
.667 .304 0 r
.5399 .60048 m .53848 .59695 L p .54249 .60602 L F P
0 g
s
.667 .304 0 r
.54249 .60602 m .54157 .60409 L .5399 .60048 L p F P
0 g
s
.636 .182 0 r
.5282 .57947 m .52535 .57581 L .52211 .57103 L p F P
0 g
s
.679 .208 0 r
.51895 .56744 m .52211 .57103 L .52535 .57581 L p F P
0 g
s
.3 .515 .897 r
.50098 .65803 m .50952 .65998 L .50618 .65574 L p F P
0 g
s
.3 .515 .897 r
.50618 .65574 m .50016 .65389 L .50098 .65803 L p F P
0 g
s
.397 .562 .9 r
.4938 .65225 m .50016 .65389 L .50098 .65803 L p F P
0 g
s
.646 .167 0 r
.46701 .62268 m .46383 .61916 L .46033 .61441 L p F P
0 g
s
.776 .397 0 r
.53848 .59695 m .5399 .60048 L .53659 .59392 L p F P
0 g
s
.776 .397 0 r
.53659 .59392 m .53628 .59312 L .53848 .59695 L p F P
0 g
s
.663 .267 0 r
.53848 .59695 m .53628 .59312 L .53368 .58811 L p F P
0 g
s
.651 .758 .928 r
.73639 .36165 m .74922 .3574 L .75212 .36131 L p F P
0 g
s
.647 .219 0 r
.53368 .58811 m .53115 .58436 L .5282 .57947 L p F P
0 g
s
.692 .245 0 r
.52535 .57581 m .5282 .57947 L .53115 .58436 L p F P
0 g
s
.668 .245 0 r
.53115 .58436 m .53368 .58811 L .53628 .59312 L p F P
0 g
s
.651 .758 .928 r
.75212 .36131 m .76498 .35705 L .76785 .36097 L p F P
0 g
s
.651 .758 .928 r
.76498 .35705 m .75212 .36131 L .74922 .3574 L p F P
0 g
s
.643 .164 0 r
.46701 .62268 m .46805 .62407 L .46465 .62027 L p F P
0 g
s
.643 .164 0 r
.46465 .62027 m .46383 .61916 L .46701 .62268 L p F P
0 g
s
.336 .537 .902 r
.50016 .65389 m .4938 .65225 L .49044 .64733 L p F P
0 g
s
.651 .758 .928 r
.76785 .36097 m .78074 .35671 L .78359 .36063 L p F P
0 g
s
.651 .758 .928 r
.78074 .35671 m .76785 .36097 L .76498 .35705 L p F P
0 g
s
.651 .758 .928 r
.78359 .36063 m .79651 .35636 L .79933 .36028 L p F P
0 g
s
.651 .758 .928 r
.79651 .35636 m .78359 .36063 L .78074 .35671 L p F P
0 g
s
.976 .806 .392 r
.54674 .62685 m .54789 .63082 L .54699 .63696 L p F P
0 g
s
.902 .676 .168 r
.54661 .62264 m .54657 .62093 L p .54789 .63082 L F P
0 g
s
.902 .676 .168 r
.54789 .63082 m .54674 .62685 L .54661 .62264 L p F P
0 g
s
.909 .61 .119 r
.54395 .61142 m .54484 .61332 L .54655 .62089 L p F P
0 g
s
.825 .494 0 r
.54484 .61332 m .54322 .60858 L .54395 .61142 L closepath p F P
0 g
s
.846 .557 .019 r
.54657 .62093 m .54655 .62089 L .54484 .61332 L p F P
0 g
s
0 .223 .741 r
.48205 .63873 m .47978 .63496 L .47443 .63073 L p F P
0 g
s
0 .167 .686 r
.47187 .62704 m .47443 .63073 L .47978 .63496 L p F P
0 g
s
0 .248 .756 r
.46805 .62407 m .47187 .62704 L .47443 .63073 L p F P
0 g
s
.846 .507 0 r
.54395 .61142 m .54322 .60858 L .54157 .60409 L p F P
0 g
s
.929 .919 .784 r
.54095 .65612 m .54203 .65461 L .54257 .65662 L closepath p F P
0 g
s
.97 .897 .694 r
.54583 .64758 m .54203 .65461 L .54257 .65662 L p F P
0 g
s
0 .184 .69 r
.47187 .62704 m .46805 .62407 L .46465 .62027 L p F P
0 g
s
.846 .507 0 r
.54157 .60409 m .54052 .60215 L p .54395 .61142 L F P
0 g
s
.773 .403 0 r
.54157 .60409 m .5399 .60048 L .54052 .60215 L closepath p F P
0 g
s
.583 .702 .924 r
.51755 .66339 m .51285 .66421 L .50952 .65998 L p F P
0 g
s
.957 .907 .728 r
.54475 .64352 m .54583 .64758 L .54203 .65461 L p F P
0 g
s
.99 .888 .575 r
.54583 .64758 m .54475 .64352 L .54699 .63696 L p F P
0 g
s
0 .267 .773 r
.48708 .64264 m .48205 .63873 L p .48962 .64674 L F P
0 g
s
0 .195 .72 r
.48205 .63873 m .48708 .64264 L .4837 .63824 L p F P
0 g
s
0 .195 .72 r
.4837 .63824 m .47978 .63496 L .48205 .63873 L p F P
0 g
s
.939 .694 .221 r
.54661 .62264 m .54657 .62093 L .54655 .62089 L closepath p F P
0 g
s
.956 .702 .252 r
.54655 .62089 m .54473 .61704 L p .5467 .62676 L F P
0 g
s
.956 .702 .252 r
.5467 .62676 m .54661 .62264 L .54655 .62089 L p F P
0 g
s
.909 .61 .119 r
.54655 .62089 m .54473 .61704 L .54395 .61142 L p F P
0 g
s
.801 .42 0 r
.54052 .60215 m .5399 .60048 L .53659 .59392 L p F P
0 g
s
0 .276 .779 r
.49044 .64733 m .48962 .64674 L .48823 .64425 L closepath p F P
0 g
s
0 .267 .773 r
.48962 .64674 m .48823 .64425 L .48708 .64264 L p F P
0 g
s
.741 .831 .92 r
.53094 .66379 m .52857 .66529 L .52527 .66215 L p F P
0 g
s
.741 .831 .92 r
.52527 .66215 m .52933 .65991 L .53094 .66379 L p F P
0 g
s
.814 .922 .908 r
.53769 .65448 m .52933 .65991 L .53094 .66379 L p F P
0 g
s
.814 .922 .908 r
.53094 .66379 m .54095 .65612 L .53769 .65448 L p F P
0 g
s
.932 .622 .16 r
.54186 .60759 m .54395 .61142 L .54473 .61704 L p F P
0 g
s
.846 .507 0 r
.54052 .60215 m .54186 .60759 L .54395 .61142 L p F P
0 g
s
.947 .698 .234 r
.54674 .62685 m .54661 .62264 L .5467 .62676 L closepath p F P
0 g
s
.336 .537 .902 r
.49044 .64733 m .49858 .64995 L .50016 .65389 L p F P
0 g
s
.27 .512 .902 r
.49858 .64995 m .49044 .64733 L .48823 .64425 L p F P
0 g
s
.527 .693 .944 r
.51755 .66339 m .52527 .66215 L .52196 .65879 L p F P
0 g
s
.527 .693 .944 r
.52196 .65879 m .5169 .65921 L .51755 .66339 L p F P
0 g
s
.583 .702 .924 r
.50952 .65998 m .5169 .65921 L .51755 .66339 L p F P
0 g
s
.679 .208 0 r
.52535 .57581 m .52219 .57222 L .51895 .56744 L p F P
0 g
s
.911 .905 .805 r
.54203 .65461 m .54095 .65612 L .53769 .65448 L p F P
0 g
s
.911 .905 .805 r
.53769 .65448 m .54071 .65063 L .54203 .65461 L p F P
0 g
s
.957 .907 .728 r
.54203 .65461 m .54071 .65063 L .54475 .64352 L p F P
0 g
s
.894 .539 .062 r
.53816 .59838 m .54052 .60215 L .54186 .60759 L p F P
0 g
s
.801 .42 0 r
.53659 .59392 m .53816 .59838 L .54052 .60215 L p F P
0 g
s
.991 .884 .595 r
.5458 .63291 m .54699 .63696 L .54475 .64352 L p F P
0 g
s
.976 .806 .392 r
.54666 .62711 m .54674 .62685 L p .54699 .63696 L F P
0 g
s
.976 .806 .392 r
.54699 .63696 m .5458 .63291 L .54666 .62711 L p F P
0 g
s
.692 .245 0 r
.53115 .58436 m .52831 .58069 L .52535 .57581 L p F P
0 g
s
.732 .269 0 r
.52219 .57222 m .52535 .57581 L .52831 .58069 L p F P
0 g
s
.817 .421 0 r
.53659 .59392 m .53628 .59312 L .53531 .59168 L closepath p F P
0 g
s
.668 .245 0 r
.53328 .58852 m .53115 .58436 L p .53628 .59312 L F P
0 g
s
.668 .245 0 r
.53628 .59312 m .53531 .59168 L .53328 .58852 L p F P
0 g
s
.651 .758 .928 r
.74922 .3574 m .7621 .35312 L .76498 .35705 L p F P
0 g
s
.768 .334 0 r
.53115 .58436 m .53328 .58852 L .52998 .58399 L p F P
0 g
s
.768 .334 0 r
.52998 .58399 m .52831 .58069 L .53115 .58436 L p F P
0 g
s
.22 .486 .894 r
.50016 .65389 m .50618 .65574 L .50283 .65155 L p F P
0 g
s
.22 .486 .894 r
.50283 .65155 m .49858 .64995 L .50016 .65389 L p F P
0 g
s
.651 .758 .928 r
.76498 .35705 m .77789 .35278 L .78074 .35671 L p F P
0 g
s
.651 .758 .928 r
.77789 .35278 m .76498 .35705 L .7621 .35312 L p F P
0 g
s
.847 .455 0 r
.53816 .59838 m .53659 .59392 L .53531 .59168 L p F P
0 g
s
.651 .758 .928 r
.78074 .35671 m .79368 .35243 L .79651 .35636 L p F P
0 g
s
.651 .758 .928 r
.79368 .35243 m .78074 .35671 L .77789 .35278 L p F P
0 g
s
.546 .685 .93 r
.5169 .65921 m .50952 .65998 L .50618 .65574 L p F P
0 g
s
0 .167 .686 r
.47978 .63496 m .47703 .63133 L .47187 .62704 L p F P
0 g
s
0 .125 .634 r
.46874 .6235 m .47187 .62704 L .47703 .63133 L p F P
0 g
s
0 .184 .69 r
.46465 .62027 m .46874 .6235 L .47187 .62704 L p F P
0 g
s
.986 .779 .38 r
.54666 .62711 m .5467 .62676 L .54674 .62685 L closepath p F P
0 g
s
.27 .512 .902 r
.48823 .64425 m .48777 .64288 L p .49858 .64995 L F P
0 g
s
.259 .504 .899 r
.48823 .64425 m .48708 .64264 L .48777 .64288 L closepath p F P
0 g
s
.996 .773 .423 r
.5467 .62676 m .54484 .62288 L p .54506 .63087 L F P
0 g
s
.996 .773 .423 r
.54506 .63087 m .54666 .62711 L .5467 .62676 L p F P
0 g
s
.956 .702 .252 r
.54473 .61704 m .54484 .62288 L .5467 .62676 L p F P
0 g
s
.989 .807 .42 r
.5458 .63291 m .54506 .63087 L .54666 .62711 L closepath p F P
0 g
s
.847 .455 0 r
.53531 .59168 m .5337 .58939 L p .53816 .59838 L F P
0 g
s
.764 .346 0 r
.53531 .59168 m .53328 .58852 L .5337 .58939 L closepath p F P
0 g
s
0 .142 .665 r
.47978 .63496 m .4837 .63824 L .48032 .63419 L p F P
0 g
s
0 .142 .665 r
.48032 .63419 m .47703 .63133 L .47978 .63496 L p F P
0 g
s
.949 .899 .742 r
.54348 .6395 m .54475 .64352 L .54071 .65063 L p F P
0 g
s
.991 .884 .595 r
.54475 .64352 m .54348 .6395 L .5458 .63291 L p F P
0 g
s
.233 .507 .906 r
.48777 .64288 m .48708 .64264 L .4837 .63824 L p F P
0 g
s
.977 .709 .308 r
.54263 .61321 m .54473 .61704 L .54484 .62288 L p F P
0 g
s
.932 .622 .16 r
.54473 .61704 m .54263 .61321 L .54186 .60759 L p F P
0 g
s
.716 .818 .929 r
.52933 .65991 m .52527 .66215 L .52196 .65879 L p F P
0 g
s
.27 .512 .902 r
.48777 .64288 m .49647 .64616 L .49858 .64995 L p F P
0 g
s
.111 .453 .885 r
.4858 .63902 m .48777 .64288 L .49647 .64616 L p F P
0 g
s
.233 .507 .906 r
.4837 .63824 m .4858 .63902 L .48777 .64288 L p F P
0 g
s
.948 .628 .198 r
.5395 .60382 m .54186 .60759 L .54263 .61321 L p F P
0 g
s
.894 .539 .062 r
.54186 .60759 m .5395 .60382 L .53816 .59838 L p F P
0 g
s
.716 .818 .929 r
.52196 .65879 m .52767 .65603 L .52933 .65991 L p F P
0 g
s
.777 .888 .924 r
.53441 .6523 m .52767 .65603 L .52933 .65991 L p F P
0 g
s
.777 .888 .924 r
.52933 .65991 m .53769 .65448 L .53441 .6523 L p F P
0 g
s
.795 .365 0 r
.5337 .58939 m .53328 .58852 L .52998 .58399 L p F P
0 g
s
.732 .269 0 r
.52831 .58069 m .52515 .57711 L .52219 .57222 L p F P
0 g
s
.913 .549 .103 r
.53553 .59467 m .53816 .59838 L .5395 .60382 L p F P
0 g
s
.847 .455 0 r
.5337 .58939 m .53553 .59467 L .53816 .59838 L p F P
0 g
s
.894 .893 .821 r
.54071 .65063 m .53769 .65448 L .53441 .6523 L p F P
0 g
s
.894 .893 .821 r
.53441 .6523 m .53918 .64669 L .54071 .65063 L p F P
0 g
s
.949 .899 .742 r
.54071 .65063 m .53918 .64669 L .54348 .6395 L p F P
0 g
s
.802 .357 0 r
.52831 .58069 m .52998 .58399 L .52666 .58011 L p F P
0 g
s
.802 .357 0 r
.52666 .58011 m .52515 .57711 L .52831 .58069 L p F P
0 g
s
.877 .476 .024 r
.5308 .58575 m .5337 .58939 L .53553 .59467 L p F P
0 g
s
.795 .365 0 r
.52998 .58399 m .5308 .58575 L .5337 .58939 L p F P
0 g
s
.651 .758 .928 r
.7621 .35312 m .77502 .34883 L .77789 .35278 L p F P
0 g
s
.478 .679 .953 r
.5169 .65921 m .52196 .65879 L .51863 .65529 L p F P
0 g
s
.478 .679 .953 r
.51863 .65529 m .51513 .65535 L .5169 .65921 L p F P
0 g
s
.546 .685 .93 r
.50618 .65574 m .51513 .65535 L .5169 .65921 L p F P
0 g
s
.988 .882 .626 r
.54506 .63087 m .5458 .63291 L .54348 .6395 L p F P
0 g
s
.509 .671 .937 r
.51513 .65535 m .50618 .65574 L .50283 .65155 L p F P
0 g
s
.651 .758 .928 r
.77789 .35278 m .79085 .34849 L .79368 .35243 L p F P
0 g
s
.651 .758 .928 r
.79085 .34849 m .77789 .35278 L .77502 .34883 L p F P
0 g
s
.142 .454 .884 r
.49858 .64995 m .50283 .65155 L .49947 .64745 L p F P
0 g
s
.142 .454 .884 r
.49947 .64745 m .49647 .64616 L .49858 .64995 L p F P
0 g
s
0 .125 .634 r
.47703 .63133 m .47384 .62781 L .46874 .6235 L p F P
0 g
s
.996 .773 .423 r
.54484 .62288 m .54414 .62898 L .54506 .63087 L p F P
0 g
s
.998 .779 .45 r
.54272 .61906 m .54484 .62288 L .54414 .62898 L p F P
0 g
s
.977 .709 .308 r
.54484 .62288 m .54272 .61906 L .54263 .61321 L p F P
0 g
s
.16 .485 .9 r
.4858 .63902 m .4837 .63824 L .48032 .63419 L p F P
0 g
s
0 .1 .611 r
.47703 .63133 m .48032 .63419 L .47691 .63053 L p F P
0 g
s
0 .1 .611 r
.47691 .63053 m .47384 .62781 L .47703 .63133 L p F P
0 g
s
.693 .807 .936 r
.52767 .65603 m .52196 .65879 L .51863 .65529 L p F P
0 g
s
.998 .834 .545 r
.54348 .63161 m .54414 .62898 L .54506 .63087 L closepath p F P
0 g
s
.988 .882 .626 r
.54348 .63161 m .54506 .63087 L p .54348 .6395 L F P
0 g
s
.94 .889 .752 r
.54198 .63553 m .54348 .6395 L .53918 .64669 L p F P
0 g
s
.988 .882 .626 r
.54348 .6395 m .54198 .63553 L .54348 .63161 L p F P
0 g
s
.826 .388 0 r
.5308 .58575 m .52998 .58399 L .52666 .58011 L p F P
0 g
s
.983 .708 .336 r
.54026 .60945 m .54263 .61321 L .54272 .61906 L p F P
0 g
s
.948 .628 .198 r
.54263 .61321 m .54026 .60945 L .5395 .60382 L p F P
0 g
s
.111 .453 .885 r
.49647 .64616 m .49393 .64248 L .4858 .63902 L p F P
0 g
s
.051 .428 .869 r
.48321 .63534 m .4858 .63902 L .49393 .64248 L p F P
0 g
s
.16 .485 .9 r
.48032 .63419 m .48321 .63534 L .4858 .63902 L p F P
0 g
s
.957 .631 .231 r
.53686 .60011 m .5395 .60382 L .54026 .60945 L p F P
0 g
s
.913 .549 .103 r
.5395 .60382 m .53686 .60011 L .53553 .59467 L p F P
0 g
s
.509 .671 .937 r
.50283 .65155 m .51286 .65162 L .51513 .65535 L p F P
0 g
s
.472 .66 .944 r
.51286 .65162 m .50283 .65155 L .49947 .64745 L p F P
0 g
s
.693 .807 .936 r
.51863 .65529 m .52613 .65209 L .52767 .65603 L p F P
0 g
s
.742 .859 .934 r
.53111 .64973 m .52613 .65209 L .52767 .65603 L p F P
0 g
s
.742 .859 .934 r
.52767 .65603 m .53441 .6523 L .53111 .64973 L p F P
0 g
s
.925 .555 .141 r
.53262 .59102 m .53553 .59467 L .53686 .60011 L p F P
0 g
s
.877 .476 .024 r
.53553 .59467 m .53262 .59102 L .5308 .58575 L p F P
0 g
s
.892 .485 .065 r
.52762 .58217 m .5308 .58575 L .53262 .59102 L p F P
0 g
s
.826 .388 0 r
.52666 .58011 m .52762 .58217 L .5308 .58575 L p F P
0 g
s
.651 .758 .928 r
.77502 .34883 m .788 .34453 L .79085 .34849 L p F P
0 g
s
.878 .881 .833 r
.53918 .64669 m .53441 .6523 L .53111 .64973 L p F P
0 g
s
.878 .881 .833 r
.53111 .64973 m .53746 .64279 L .53918 .64669 L p F P
0 g
s
.94 .889 .752 r
.53918 .64669 m .53746 .64279 L .54198 .63553 L p F P
0 g
s
.434 .661 .957 r
.51513 .65535 m .51863 .65529 L .5153 .65171 L p F P
0 g
s
.434 .661 .957 r
.5153 .65171 m .51286 .65162 L .51513 .65535 L p F P
0 g
s
.992 .815 .564 r
.54414 .62898 m .54199 .62518 L p .54026 .63165 L F P
0 g
s
.992 .815 .564 r
.54026 .63165 m .54348 .63161 L .54414 .62898 L p F P
0 g
s
.998 .779 .45 r
.54414 .62898 m .54199 .62518 L .54272 .61906 L p F P
0 g
s
.071 .424 .869 r
.49647 .64616 m .49947 .64745 L .4961 .6435 L p F P
0 g
s
.071 .424 .869 r
.4961 .6435 m .49393 .64248 L .49647 .64616 L p F P
0 g
s
.087 .464 .888 r
.48321 .63534 m .48032 .63419 L .47691 .63053 L p F P
0 g
s
.986 .87 .634 r
.54198 .63553 m .54026 .63165 L .54348 .63161 L closepath p F P
0 g
s
.996 .772 .469 r
.54034 .61531 m .54272 .61906 L .54199 .62518 L p F P
0 g
s
.983 .708 .336 r
.54272 .61906 m .54034 .61531 L .54026 .60945 L p F P
0 g
s
.672 .798 .942 r
.52613 .65209 m .51863 .65529 L .5153 .65171 L p F P
0 g
s
.985 .703 .361 r
.53762 .60575 m .54026 .60945 L .54034 .61531 L p F P
0 g
s
.957 .631 .231 r
.54026 .60945 m .53762 .60575 L .53686 .60011 L p F P
0 g
s
.932 .878 .76 r
.54026 .63165 m .54198 .63553 L .53746 .64279 L p F P
0 g
s
.472 .66 .944 r
.49947 .64745 m .51027 .64796 L .51286 .65162 L p F P
0 g
s
.435 .652 .95 r
.51027 .64796 m .49947 .64745 L .4961 .6435 L p F P
0 g
s
.051 .428 .869 r
.49393 .64248 m .49103 .63889 L .48321 .63534 L p F P
0 g
s
.008 .414 .857 r
.48007 .63181 m .48321 .63534 L .49103 .63889 L p F P
0 g
s
.087 .464 .888 r
.47691 .63053 m .48007 .63181 L .48321 .63534 L p F P
0 g
s
.961 .63 .262 r
.53396 .59647 m .53686 .60011 L .53762 .60575 L p F P
0 g
s
.925 .555 .141 r
.53686 .60011 m .53396 .59647 L .53262 .59102 L p F P
0 g
s
.932 .558 .175 r
.52944 .58745 m .53262 .59102 L .53396 .59647 L p F P
0 g
s
.892 .485 .065 r
.53262 .59102 m .52944 .58745 L .52762 .58217 L p F P
0 g
s
.672 .798 .942 r
.5153 .65171 m .52509 .64798 L .52613 .65209 L p F P
0 g
s
.711 .834 .941 r
.5278 .64688 m .52509 .64798 L .52613 .65209 L p F P
0 g
s
.711 .834 .941 r
.52613 .65209 m .53111 .64973 L .5278 .64688 L p F P
0 g
s
.394 .645 .957 r
.51286 .65162 m .5153 .65171 L .51195 .6481 L p F P
0 g
s
.394 .645 .957 r
.51195 .6481 m .51027 .64796 L .51286 .65162 L p F P
0 g
s
.864 .87 .841 r
.53746 .64279 m .53111 .64973 L .5278 .64688 L p F P
0 g
s
.864 .87 .841 r
.5278 .64688 m .53551 .63895 L .53746 .64279 L p F P
0 g
s
.932 .878 .76 r
.54023 .63164 m .54026 .63165 L p .53746 .64279 L F P
0 g
s
.932 .878 .76 r
.53746 .64279 m .53551 .63895 L .54023 .63164 L p F P
0 g
s
.992 .815 .564 r
.54199 .62518 m .54024 .63161 L .54026 .63165 L p F P
0 g
s
.986 .815 .587 r
.53959 .62143 m .54199 .62518 L .54024 .63161 L p F P
0 g
s
.996 .772 .469 r
.54199 .62518 m .53959 .62143 L .54034 .61531 L p F P
0 g
s
.012 .4 .852 r
.49393 .64248 m .4961 .6435 L .49272 .63973 L p F P
0 g
s
.012 .4 .852 r
.49272 .63973 m .49103 .63889 L .49393 .64248 L p F P
0 g
s
.653 .802 .954 r
.52509 .64798 m .5153 .65171 L .51195 .6481 L p F P
0 g
s
.992 .762 .485 r
.5377 .61161 m .54034 .61531 L .53959 .62143 L p F P
0 g
s
.985 .703 .361 r
.54034 .61531 m .5377 .61161 L .53762 .60575 L p F P
0 g
s
.435 .652 .95 r
.4961 .6435 m .50742 .64437 L .51027 .64796 L p F P
0 g
s
.402 .647 .957 r
.50742 .64437 m .4961 .6435 L .49272 .63973 L p F P
0 g
s
.982 .696 .383 r
.53471 .60211 m .53762 .60575 L .5377 .61161 L p F P
0 g
s
.961 .63 .262 r
.53762 .60575 m .53471 .60211 L .53396 .59647 L p F P
0 g
s
.008 .414 .857 r
.49103 .63889 m .48779 .63539 L .48007 .63181 L p F P
0 g
s
.975 .85 .654 r
.54023 .63164 m .54024 .63161 L .54026 .63165 L closepath p F P
0 g
s
.965 .838 .668 r
.54024 .63161 m .54023 .63164 L .53694 .62991 L p F P
0 g
s
.965 .838 .668 r
.53694 .62991 m .53779 .62788 L .54024 .63161 L p F P
0 g
s
.986 .815 .587 r
.54024 .63161 m .53779 .62788 L .53959 .62143 L p F P
0 g
s
.962 .627 .289 r
.53077 .5929 m .53396 .59647 L .53471 .60211 L p F P
0 g
s
.932 .558 .175 r
.53396 .59647 m .53077 .5929 L .52944 .58745 L p F P
0 g
s
.933 .881 .76 r
.53551 .63895 m .54023 .63164 L .53694 .62991 L p F P
0 g
s
.653 .802 .954 r
.52516 .64445 m .52509 .64798 L p .51195 .6481 L F P
0 g
s
.684 .814 .945 r
.52509 .64798 m .52516 .64445 L .5278 .64688 L closepath p F P
0 g
s
.362 .633 .957 r
.51027 .64796 m .51195 .6481 L .50859 .64451 L p F P
0 g
s
.362 .633 .957 r
.50859 .64451 m .50742 .64437 L .51027 .64796 L p F P
0 g
s
.979 .803 .596 r
.53692 .61775 m .53959 .62143 L .53779 .62788 L p F P
0 g
s
.992 .762 .485 r
.53959 .62143 m .53692 .61775 L .5377 .61161 L p F P
0 g
s
.852 .837 .83 r
.53551 .63895 m .53331 .63516 L p .52516 .64445 L F P
0 g
s
.852 .837 .83 r
.52516 .64445 m .5278 .64688 L .53551 .63895 L p F P
0 g
s
.933 .881 .76 r
.53694 .62991 m .53331 .63516 L .53551 .63895 L p F P
0 g
s
0 .385 .838 r
.49103 .63889 m .49272 .63973 L .48933 .63616 L p F P
0 g
s
0 .385 .838 r
.48933 .63616 m .48779 .63539 L .49103 .63889 L p F P
0 g
s
.653 .802 .954 r
.51195 .6481 m .52447 .6438 L .52516 .64445 L p F P
0 g
s
.64 .789 .954 r
.52447 .6438 m .51195 .6481 L .50859 .64451 L p F P
0 g
s
.985 .751 .499 r
.53478 .60798 m .5377 .61161 L .53692 .61775 L p F P
0 g
s
.982 .696 .383 r
.5377 .61161 m .53478 .60798 L .53471 .60211 L p F P
0 g
s
.402 .647 .957 r
.49272 .63973 m .50435 .64083 L .50742 .64437 L p F P
0 g
s
.372 .646 .962 r
.50435 .64083 m .49272 .63973 L .48933 .63616 L p F P
0 g
s
.977 .688 .402 r
.53153 .59855 m .53471 .60211 L .53478 .60798 L p F P
0 g
s
.962 .627 .289 r
.53471 .60211 m .53153 .59855 L .53077 .5929 L p F P
0 g
s
.955 .826 .677 r
.53779 .62788 m .53694 .62991 L .53364 .62757 L p F P
0 g
s
.955 .826 .677 r
.53364 .62757 m .5351 .62422 L .53779 .62788 L p F P
0 g
s
.979 .803 .596 r
.53779 .62788 m .5351 .62422 L .53692 .61775 L p F P
0 g
s
.915 .861 .773 r
.53331 .63516 m .53694 .62991 L .53364 .62757 L p F P
0 g
s
.81 .835 .87 r
.52447 .6438 m .52461 .64369 L .52516 .64445 L closepath p F P
0 g
s
.852 .837 .83 r
.53331 .63516 m .52461 .64369 L .52516 .64445 L p F P
0 g
s
.338 .625 .957 r
.50742 .64437 m .50859 .64451 L .50522 .64095 L p F P
0 g
s
.338 .625 .957 r
.50522 .64095 m .50435 .64083 L .50742 .64437 L p F P
0 g
s
.971 .79 .603 r
.53399 .61413 m .53692 .61775 L .5351 .62422 L p F P
0 g
s
.985 .751 .499 r
.53692 .61775 m .53399 .61413 L .53478 .60798 L p F P
0 g
s
.839 .833 .841 r
.53082 .63143 m .53331 .63516 L .52461 .64369 L p F P
0 g
s
.915 .861 .773 r
.53364 .62757 m .53082 .63143 L .53331 .63516 L p F P
0 g
s
.64 .789 .954 r
.50859 .64451 m .52113 .64056 L .52447 .6438 L p F P
0 g
s
.632 .78 .952 r
.52113 .64056 m .50859 .64451 L .50522 .64095 L p F P
0 g
s
.801 .827 .872 r
.52461 .64369 m .52447 .6438 L .52113 .64056 L p F P
0 g
s
.801 .827 .872 r
.52113 .64056 m .52173 .6401 L .52461 .64369 L p F P
0 g
s
.839 .833 .841 r
.52461 .64369 m .52173 .6401 L .53082 .63143 L p F P
0 g
s
.977 .739 .509 r
.53159 .60442 m .53478 .60798 L .53399 .61413 L p F P
0 g
s
.977 .688 .402 r
.53478 .60798 m .53159 .60442 L .53153 .59855 L p F P
0 g
s
.372 .646 .962 r
.48933 .63616 m .50106 .63733 L .50435 .64083 L p F P
0 g
s
.946 .814 .682 r
.5351 .62422 m .53364 .62757 L .53031 .62473 L p F P
0 g
s
.946 .814 .682 r
.53031 .62473 m .53214 .62061 L .5351 .62422 L p F P
0 g
s
.971 .79 .603 r
.5351 .62422 m .53214 .62061 L .53399 .61413 L p F P
0 g
s
.899 .842 .779 r
.53082 .63143 m .53364 .62757 L .53031 .62473 L p F P
0 g
s
.325 .624 .958 r
.50435 .64083 m .50522 .64095 L .50184 .63744 L p F P
0 g
s
.325 .624 .958 r
.50184 .63744 m .50106 .63733 L .50435 .64083 L p F P
0 g
s
.962 .777 .607 r
.53079 .61057 m .53399 .61413 L .53214 .62061 L p F P
0 g
s
.977 .739 .509 r
.53399 .61413 m .53079 .61057 L .53159 .60442 L p F P
0 g
s
.632 .78 .952 r
.50522 .64095 m .51778 .63721 L .52113 .64056 L p F P
0 g
s
.63 .774 .95 r
.51778 .63721 m .50522 .64095 L .50184 .63744 L p F P
0 g
s
.833 .827 .842 r
.528 .62779 m .53082 .63143 L .52173 .6401 L p F P
0 g
s
.899 .842 .779 r
.53031 .62473 m .528 .62779 L .53082 .63143 L p F P
0 g
s
.796 .822 .872 r
.52173 .6401 m .52113 .64056 L .51778 .63721 L p F P
0 g
s
.796 .822 .872 r
.51778 .63721 m .51866 .63655 L .52173 .6401 L p F P
0 g
s
.833 .827 .842 r
.52173 .6401 m .51866 .63655 L .528 .62779 L p F P
0 g
s
.938 .801 .683 r
.53214 .62061 m .53031 .62473 L .52697 .62143 L p F P
0 g
s
.938 .801 .683 r
.52697 .62143 m .52893 .61707 L .53214 .62061 L p F P
0 g
s
.962 .777 .607 r
.53214 .62061 m .52893 .61707 L .53079 .61057 L p F P
0 g
s
.886 .823 .78 r
.528 .62779 m .53031 .62473 L .52697 .62143 L p F P
0 g
s
.63 .774 .95 r
.50184 .63744 m .51441 .63377 L .51778 .63721 L p F P
0 g
s
.83 .82 .84 r
.52483 .62424 m .528 .62779 L .51866 .63655 L p F P
0 g
s
.886 .823 .78 r
.52697 .62143 m .52483 .62424 L .528 .62779 L p F P
0 g
s
.793 .817 .871 r
.51866 .63655 m .51778 .63721 L .51441 .63377 L p F P
0 g
s
.793 .817 .871 r
.51441 .63377 m .51538 .63304 L .51866 .63655 L p F P
0 g
s
.83 .82 .84 r
.51866 .63655 m .51538 .63304 L .52483 .62424 L p F P
0 g
s
.25 Mabswid
.7767 0 m
.93606 .25393 L
s
.93606 .25393 m
1 .77889 L
s
1 .77889 m
.82258 .55004 L
s
.82258 .55004 m
.7767 0 L
s
.06283 .27285 m
0 .79565 L
s
0 .79565 m
.82258 .55004 L
s
.82258 .55004 m
.7767 0 L
s
.7767 0 m
.06283 .27285 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{981.438, 461.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000?E0001cB000`400?l00000o`00003ooooonf[o
oookJ_oooo]Zf?oonfX00?oooo]Zoooonf[ooookJ]Sooo]Z003ooookJ_oooo]Zoooonf[HoookJP00
oooonf[ooookJ_oooo]Zf?oonfX00?oooo]Zoooonf[ooookJ]Sooo]Z003ooookJ_oooo]Zoooonf[H
oookJP00oooonf[ooookJ_oooo]Zf?oonfX00?oooo]Zoooonf[ooookJ]Sooo]Z003ooookJ_oooo]Z
oooonf[HoookJP00oooonf[ooookJ_oooo]Zf?oonfX00?oooo]Zoooonf[ooookJ]Sooo]Z003ooook
JTGooo]Z0_l0003ooookJ_oooo]ZTOoonfX00?oooo]Z@_oonfX3o`000003oookJ_l0003ooo]Z0?oo
oo]ZoooonfZ@oookJP00oooonfY0oookJP;o00001?oonfX2o`000?oooo]ZoooonfZ@oookJP00oooo
nfXmoookJP?o00001_oonfX00ol0003ooo]Zo`00003ooookJ_oooo]Z4_oonfX2o`0007_ooo]Z003o
oookJS_ooo]Z0_l00009oookJP03o`000?oonf[o00000?oooo]ZoooonfX?oookJP?o000000?ooo]Z
o`000?oonfX0N_oonfX00?oooo]Z>OoonfX2o`0000_ooo]Z00Co0000oookJ_oonf[o0000oooonf[o
oookJP_ooo]Z0ol00004oookJP;o0000N_oonfX00?oooo]Z=_oonfX3o`0000gooo]Z00Co0000oook
J_oonf[o0000oooonf[ooookJPWooo]Z0_l00007oookJP03o`000?oonf[o000007Wooo]Z003ooook
JSCooo]Z0_l0000@oookJP05o`000?oonf[ooo]ZoookJ_l00000oooonf[ooookJPGooo]Z0ol00009
oookJP03o`000?oonf[o000007Wooo]Z003ooookJS7ooo]Z0ol0000BoookJP03o`000?oonf[ooo]Z
00;ooo]Z00?o0000oookJ_oonfX0oooonf[ooookJP;o00003?oonfX01?l0003ooo]ZoookJ_l0001h
oookJP00oooonfX_oookJP;o00005OoonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
0?oooo]Zo?oonfX3o`0000kooo]Z00Co0000oookJ_oonf[o0000N?oonfX00?oooo]Z;?oonfX3o`00
01Sooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP3ooookJ_Sooo]Z0ol0000Boook
JP04o`000?oonf[ooo]Zo`0007Oooo]Z003ooookJR[ooo]Z0_l0000KoookJP03o`000?oonf[ooo]Z
00?ooo]Z00?o0000oookJ_oonfX0oooonf[eoookJP;o00005OoonfX01Ol0003ooo]ZoookJ_oonf[o
000007Kooo]Z003ooookJROooo]Z0ol0000MoookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oook
J_oonfX0oooonf[boookJP?o00005ooonfX01Ol0003ooo]ZoookJ_oonf[o000007Kooo]Z003ooook
JRGooo]Z0_l0000PoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0oooonf[^oook
JP?o00006_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z07?ooo]Z003ooookJR?o
oo]Z0_l0000RoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0oooonf[/oookJP;o
00007OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z07;ooo]Z003ooookJR3ooo]Z
0ol0000ToookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0oooonf[XoookJP?o0000
7ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z07;ooo]Z003ooookJQkooo]Z0_l0
000WoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0oooonf[UoookJP;o00008_oo
nfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z077ooo]Z003ooookJQ_ooo]Z0ol0000Y
oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0oooonf[RoookJP?o00009?oonfX0
0ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z077ooo]Z003ooookJQWooo]Z0_l0000/oook
JP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0oooonf[NoookJP?o00009ooonfX00ol0
003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z073ooo]Z003ooookJQKooo]Z0ol0000^oookJP03
o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0oooonf[KoookJP;o0000:_oonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z06oooo]Z003ooookJQCooo]Z0_l0000aoookJP03o`00
0?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0oooonf[HoookJP?o0000;?oonfX00ol0003ooo]Z
oookJP06oookJP03o`000?oonf[ooo]Z06oooo]Z003ooookJQ;ooo]Z0_l0000coookJP03o`000?oo
nf[ooo]Z00Wooo]Z00?o0000oookJ_oonfX0oooonf[EoookJP;o0000;ooonfX00ol0003ooo]Zoook
JP07oookJP03o`000?oonf[ooo]Z06kooo]Z003ooookJPoooo]Z0ol0000eoookJP03o`000?oonf[o
oo]Z00Wooo]Z00?o0000oookJ_oonfX0oooonf[BoookJP?o0000<_oonfX00ol0003ooo]ZoookJP07
oookJP03o`000?oonf[ooo]Z06gooo]Z003ooookJPgooo]Z0_l0000hoookJP03o`000?oonf[ooo]Z
00[ooo]Z00?o0000oookJ_oonfX0oooonf[>oookJP?o0000=OoonfX00ol0003ooo]ZoookJP07oook
JP03o`000?oonf[ooo]Z06gooo]Z003ooookJP[ooo]Z0ol0000joookJP03o`000?oonf[ooo]Z00_o
oo]Z00?o0000oookJ_oonfX0oooonf[;oookJP;o0000>?oonfX00ol0003ooo]ZoookJP08oookJP03
o`000?oonf[ooo]Z06cooo]Z003ooookJPSooo]Z0_l0000moookJP03o`000?oonf[ooo]Z00_ooo]Z
00?o0000oookJ_oonfX0oooonf[8oookJP?o0000>_oonfX00ol0003ooo]ZoookJP09oookJP03o`00
0?oonf[ooo]Z06_ooo]Z003ooookJPGooo]Z0ol0000ooookJP03o`000?oonf[ooo]Z00cooo]Z00?o
0000oookJ_oonfX0oooonf[4oookJP?o0000?OoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oo
nf[ooo]Z06_ooo]Z003ooookJP?ooo]Z0_l00012oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000
oookJ_oonfX0oooonf[1oookJP;o0000@?oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[o
oo]Z06[ooo]Z003ooookJP?o0000A?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z
0?oooo]Z__oonfX3o`0004;ooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP1Zoook
JP00oOoonfX2o`0004Sooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP3ooookJ[_o
oo]Z0_l00015oookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0JOoonfX00?_ooo]Z
0_l0001:oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0oooonfZhoookJP?o0000
AooonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z06Sooo]Z003hoookJP?o0000C?oo
nfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z0?oooo]Z]?oonfX3o`0004[ooo]Z00?o
0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP1XoookJP00m_oonfX2o`0004oooo]Z00?o0000
oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP3ooookJ[7ooo]Z0_l0001=oookJP03o`000?oonf[o
oo]Z00gooo]Z00?o0000oookJ_oonfX0IooonfX00??ooo]Z0ol0001AoookJP03o`000?oonf[ooo]Z
00oooo]Z00?o0000oookJ_oonfX0oooonfZ^oookJP?o0000CooonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z06Kooo]Z003aoookJP;o0000E?oonfX00ol0003ooo]ZoookJP0@oookJP03
o`000?oonf[ooo]Z0?oooo]ZZ_oonfX3o`0005?ooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003o
oo]ZoookJP1VoookJP00k_oonfX3o`0005Kooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Z
oookJP3ooookJZOooo]Z0_l0001FoookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0
IOoonfX00>cooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0oooo
nfZToookJP?o0000F?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z06Gooo]Z003Y
oookJP?o0000FooonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z0?oooo]ZXOoonfX2
o`0005_ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP1ToookJP00iooonfX2o`00
05kooo]Z00?o0000oookJ_oonfX04_oonfX00ol0003ooo]ZoookJP3ooookJYkooo]Z0ol0001Moook
JP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0HooonfX00>Gooo]Z0_l0001PoookJP03
o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0oooonfZJoookJP?o0000H?oonfX00ol0003o
oo]ZoookJP0@oookJP03o`000?oonf[ooo]Z06?ooo]Z003RoookJP?o0000H_oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z0?oooo]ZUooonfX2o`0006?ooo]Z00?o0000oookJ_oonfX0
4OoonfX00ol0003ooo]ZoookJP1RoookJP00h?oonfX2o`0006Gooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP3ooookJYCooo]Z0ol0001UoookJP03o`000?oonf[ooo]Z01;ooo]Z00?o
0000oookJ_oonfX0HOoonfX00=gooo]Z0ol0001WoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000
oookJ_oonfX0oooonfZAoookJP;o0000J?oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[o
oo]Z067ooo]Z003KoookJP;o0000J_oonfX00ol0003ooo]ZoookJP0FoookJP03o`000?oonf[ooo]Z
0?oooo]ZSOoonfX3o`0006[ooo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP1Poook
JP00f?oonfX3o`0006cooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP3ooookJX[o
oo]Z0ol0001]oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0H?oonfX00=Kooo]Z
0_l0001_oookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0oooonfZ7oookJP;o0000
L?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z05oooo]Z003CoookJP?o0000LOoo
nfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z0?oooo]ZQ?oonfX3o`0007;ooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP1NoookJP00dOoonfX2o`0007Cooo]Z00?o0000
oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP3ooookJX3ooo]Z0ol0001foookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX0G_oonfX00<oooo]Z0_l0001goookJP03o`000?oonf[ooo]Z
01Sooo]Z00?o0000oookJ_oonfX0oooonfYmoookJP;o0000NOoonfX00ol0003ooo]ZoookJP0Eoook
JP03o`000?oonf[ooo]Z05gooo]Z003<oookJP?o0000NOoonfX00ol0003ooo]ZoookJP0HoookJP03
o`000?oonf[ooo]Z0?oooo]ZN_oonfX3o`0007_ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP1LoookJP00b_oonfX2o`0007cooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]Z
oookJP3ooookJWOooo]Z0_l0001noookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0
G?oonfX00<Oooo]Z0ol0001noookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0oooo
nfYcoookJP?o0000P?oonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z05_ooo]Z0035
oookJP;o0000POoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z0?oooo]ZL?oonfX3
o`0008?ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP1KoookJP00`_oonfX3o`00
08?ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP3ooookJVgooo]Z0_l00026oook
JP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0F_oonfX00<3ooo]Z0_l00026oookJP03
o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0oooonfYZoookJP?o0000R?oonfX00ol0003o
oo]ZoookJP0IoookJP03o`000?oonf[ooo]Z05Wooo]Z002moookJP?o0000R?oonfX00ol0003ooo]Z
oookJP0LoookJP03o`000?oonf[ooo]Z0?oooo]ZI_oonfX3o`0008_ooo]Z00?o0000oookJ_oonfX0
6OoonfX00ol0003ooo]ZoookJP1IoookJP00^ooonfX2o`0008_ooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP3ooookJV?ooo]Z0_l0002>oookJP03o`000?oonf[ooo]Z01[ooo]Z00?o
0000oookJ_oonfX0F?oonfX00;Wooo]Z0_l0002=oookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000
oookJ_oonfX0oooonfYPoookJP?o0000T?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[o
oo]Z05Oooo]Z002foookJP?o0000SooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z
0?oooo]ZGOoonfX2o`0009?ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP1Goook
JP00]?oonfX2o`0009;ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP3ooookJUWo
oo]Z0ol0002FoookJP03o`000?oonf[ooo]Z01_ooo]Z00?o0000oookJ_oonfX0E_oonfX00;7ooo]Z
0ol0002DoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0oooonfYFoookJP?o0000
VOoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z05Gooo]Z002_oookJP;o0000Uooo
nfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z0?oooo]ZDooonfX2o`0009cooo]Z00?o
0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP1EoookJP00[?oonfX3o`0009Wooo]Z00?o0000
oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP3ooookJU3ooo]Z0ol0002NoookJP03o`000?oonf[o
oo]Z01gooo]Z00?o0000oookJ_oonfX0E?oonfX00:[ooo]Z0_l0002LoookJP03o`000?oonf[ooo]Z
027ooo]Z00?o0000oookJ_oonfX0oooonfY<oookJP?o0000XOoonfX00ol0003ooo]ZoookJP0Moook
JP03o`000?oonf[ooo]Z05Cooo]Z002XoookJP;o0000W_oonfX00ol0003ooo]ZoookJP0RoookJP03
o`000?oonf[ooo]Z0?oooo]ZBOoonfX2o`000:Cooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003o
oo]ZoookJP1CoookJP00YOoonfX3o`000:3ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Z
oookJP3ooookJTKooo]Z0ol0002VoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
D_oonfX00:?ooo]Z0_l0002ToookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0oooo
nfY3oookJP;o0000ZOoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z05;ooo]Z002P
oookJP?o0000Y_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z0?oooo]Z?ooonfX3
o`000:_ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP1AoookJP00W_oonfX2o`00
0:Wooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP3ooookJScooo]Z0ol0002^oook
JP03o`000?oonf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0D?oonfX009_ooo]Z0ol0002[oookJP03
o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0oooonfXioookJP;o0000/OoonfX00ol0003o
oo]ZoookJP0QoookJP03o`000?oonf[ooo]Z053ooo]Z002IoookJP;o0000[_oonfX00ol0003ooo]Z
oookJP0ToookJP03o`000?oonf[ooo]Z0?oooo]Z=_oonfX3o`000;?ooo]Z00?o0000oookJ_oonfX0
8_oonfX00ol0003ooo]ZoookJP1?oookJP00U_oonfX3o`000;3ooo]Z00?o0000oookJ_oonfX09Ooo
nfX00ol0003ooo]ZoookJP3ooookJS?ooo]Z0_l0002goookJP03o`000?oonf[ooo]Z027ooo]Z00?o
0000oookJ_oonfX0CooonfX009Cooo]Z0_l0002coookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX0oooonfX_oookJP?o0000^OoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[o
oo]Z04kooo]Z002BoookJP;o0000]OoonfX00ol0003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z
0?oooo]Z;?oonfX3o`000;cooo]Z00?o0000oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP1=oook
JP00SooonfX3o`000;Oooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP3ooookJRWo
oo]Z0_l0000CoookJP;o0000Z_oonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z04go
oo]Z002=oookJP;o0000^_oonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z0?oooo]Z
9OoonfX3o`0001Gooo]Z0_l0002ZoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0
C?oonfX008[ooo]Z0ol0002loookJP03o`000?oonf[ooo]Z02Sooo]Z00?o0000oookJ_oonfX0oooo
nfXRoookJP?o00006?oonfX2o`000:[ooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Zoook
JP1;oookJP00R?oonfX2o`000;oooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP3o
oookJQoooo]Z0_l0000KoookJP;o0000Z_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z04_ooo]Z0025oookJP?o0000`OoonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z
0?oooo]Z7?oonfX3o`0001gooo]Z00?o0000oookJ_oonfX0ZOoonfX00ol0003ooo]ZoookJP0Voook
JP03o`000?oonf[ooo]Z04[ooo]Z0023oookJP;o0000a?oonfX00ol0003ooo]ZoookJP0ZoookJP03
o`000?oonf[ooo]Z0?oooo]Z6OoonfX2o`00023ooo]Z00?o0000oookJ_oonfX0ZOoonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z04[ooo]Z0020oookJP?o0000a_oonfX00ol0003ooo]Z
oookJP0[oookJP03o`000?oonf[ooo]Z0?oooo]Z5OoonfX3o`0002;ooo]Z00?o0000oookJ_oonfX0
ZOoonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z04Wooo]Z001noookJP;o0000bOoo
nfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z0?oooo]Z4_oonfX3o`0002Gooo]Z00?o
0000oookJ_oonfX0ZOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z04Sooo]Z001l
oookJP;o0000booonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX2
o`0002Sooo]Z00?o0000oookJ_oonfX0ZOoonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[o
oo]Z04Sooo]Z001ioookJP?o0000cOoonfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z
0?oooo]Z2ooonfX3o`0002[ooo]Z00?o0000oookJ_oonfX0Z_oonfX00ol0003ooo]ZoookJP0Xoook
JP03o`000?oonf[ooo]Z04Oooo]Z001goookJP;o0000d?oonfX00ol0003ooo]ZoookJP0]oookJP03
o`000?oonf[ooo]Z0?oooo]Z2?oonfX3o`0002gooo]Z00?o0000oookJ_oonfX0Z_oonfX00ol0003o
oo]ZoookJP0YoookJP03o`000?oonf[ooo]Z04Kooo]Z001doookJP?o0000dooonfX00ol0003ooo]Z
oookJP0]oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX2o`00033ooo]Z00?o0000oookJ_oonfX0
Z_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z04Kooo]Z001boookJP;o0000e_oo
nfX00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z0?oooo]Z0_oonfX3o`0003;ooo]Z00?o
0000oookJ_oonfX0Z_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z04Gooo]Z001_
oookJP?o0000f?oonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z0?kooo]Z0_l0000e
oookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP15
oookJP00KOoonfX2o`000=_ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]ZoookJP3joook
JP?o0000=ooonfX00ol0003ooo]ZoookJP2ZoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oook
J_oonfX0A?oonfX006[ooo]Z0ol0003MoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oo
nfX0mooonfX3o`0003[ooo]Z00?o0000oookJ_oonfX0Z_oonfX00ol0003ooo]ZoookJP0/oookJP03
o`000?oonf[ooo]Z04?ooo]Z001XoookJP;o0000h?oonfX00ol0003ooo]ZoookJP0`oookJP03o`00
0?oonf[ooo]Z0?Cooo]Z0_l0000moookJP03o`000?oonf[ooo]Z0:[ooo]Z00?o0000oookJ_oonfX0
;?oonfX00ol0003ooo]ZoookJP13oookJP00I_oonfX2o`000>;ooo]Z00?o0000oookJ_oonfX0<Ooo
nfX00ol0003ooo]ZoookJP3`oookJP?o0000?ooonfX00ol0003ooo]ZoookJP2ZoookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0@_oonfX006?ooo]Z0ol0003ToookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX0k_oonfX2o`0004;ooo]Z00?o0000oookJ_oonfX0Z_oonfX0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z047ooo]Z001QoookJP;o0000iooonfX00ol0
003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z0>[ooo]Z0ol00014oookJP03o`000?oonf[ooo]Z
0:[ooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP11oookJP00G_oonfX3o`000>Wo
oo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP3VoookJP?o0000AooonfX00ol0003o
oo]ZoookJP2ZoookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0@?oonfX005cooo]Z
0_l0003/oookJP03o`000?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0i?oonfX2o`0004[ooo]Z
00?o0000oookJ_oonfX0ZooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z043ooo]Z
001IoookJP?o0000k_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[ooo]Z0>3ooo]Z0ol0
001<oookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0;ooonfX00ol0003ooo]Zoook
JP0ooookJP00EooonfX2o`000?7ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP3M
oookJP?o0000CooonfX00ol0003ooo]ZoookJP2[oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000
oookJ_oonfX0?_oonfX005Gooo]Z0_l0003coookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oook
J_oonfX0f_oonfX2o`0005;ooo]Z00?o0000oookJ_oonfX0ZooonfX00ol0003ooo]ZoookJP0`oook
JP03o`000?oonf[ooo]Z03kooo]Z001BoookJP?o0000mOoonfX00ol0003ooo]ZoookJP0foookJP03
o`000?oonf[ooo]Z0=Kooo]Z0ol0001DoookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oo
nfX0<OoonfX00ol0003ooo]ZoookJP0moookJP00D?oonfX2o`000?Sooo]Z00?o0000oookJ_oonfX0
=_oonfX00ol0003ooo]ZoookJP3DoookJP;o0000EooonfX00ol0003ooo]ZoookJP2[oookJP03o`00
0?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0??oonfX004gooo]Z0ol0003joookJP03o`000?oo
nf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0d?oonfX3o`0005Wooo]Z00?o0000oookJ_oonfX0Zooo
nfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z03cooo]Z001;oookJP;o0000oOoonfX0
0ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z0<cooo]Z0ol0001LoookJP03o`000?oonf[o
oo]Z0:_ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP0koookJP00B?oonfX3o`00
0?oooo]Z0OoonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z0<[ooo]Z0_l0001Ooook
JP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0joook
JP00A_oonfX2o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z0<Ko
oo]Z0ol0001QoookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003o
oo]ZoookJP0joookJP00@ooonfX3o`000?oooo]Z1_oonfX00ol0003ooo]ZoookJP0hoookJP03o`00
0?oonf[ooo]Z0<?ooo]Z0ol0001ToookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o0000oookJ_oonfX0
=OoonfX00ol0003ooo]ZoookJP0ioookJP00@OoonfX2o`000?oooo]Z2OoonfX00ol0003ooo]Zoook
JP0ioookJP03o`000?oonf[ooo]Z0<3ooo]Z0_l0001WoookJP03o`000?oonf[ooo]Z0:_ooo]Z00?o
0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0ioookJP00?ooonfX2o`000?oooo]Z2ooonfX0
0ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z0;cooo]Z0ol0001YoookJP03o`000?oonf[o
oo]Z0:_ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0hoookJP00??oonfX3o`00
0?oooo]Z3OoonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[ooo]Z0;[ooo]Z0_l0001/oook
JP03o`000?oonf[ooo]Z0:cooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0goook
JP00>_oonfX2o`000?oooo]Z4?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z0;Ko
oo]Z0ol0001^oookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003o
oo]ZoookJP0goookJP00=ooonfX3o`000?oooo]Z4_oonfX00ol0003ooo]ZoookJP0loookJP03o`00
0?oonf[ooo]Z0;;ooo]Z0ol0001aoookJP03o`000?oonf[ooo]Z0:cooo]Z00?o0000oookJ_oonfX0
=ooonfX00ol0003ooo]ZoookJP0foookJP00=_oonfX2o`000?oooo]Z5?oonfX00ol0003ooo]Zoook
JP0loookJP03o`000?oonf[ooo]Z0;3ooo]Z0_l0001coookJP;o0000[_oonfX00ol0003ooo]Zoook
JP0hoookJP03o`000?oonf[ooo]Z03Gooo]Z000foookJP03o`000?oonf[o00000?oooo]Z4ooonfX0
0ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z0:cooo]Z0ol0001eoookJP;o0000[_oonfX0
0ol0003ooo]ZoookJP0hoookJP03o`000?oonf[ooo]Z03Gooo]Z000foookJP04o`000?oonf[ooo]Z
o`000?oooo]Z4_oonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z0:[ooo]Z0_l0001h
oookJP;o0000[_oonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z03Cooo]Z000foook
JP05o`000?oonf[ooo]ZoookJ_l00000oooonfXAoookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000
oookJ_oonfX0Y_oonfX3o`0007[ooo]Z0_l0002^oookJP03o`000?oonf[ooo]Z03Wooo]Z00?o0000
oookJ_oonfX0=?oonfX003Gooo]Z00?o0000oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP3ooook
JPkooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP2RoookJP?o0000OOoonfX2o`00
0:kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP0coookJP00=OoonfX00ol0003o
oo]ZoookJP04oookJP03o`000?oonf[ooo]Z0?oooo]Z3OoonfX00ol0003ooo]ZoookJP0ooookJP03
o`000?oonf[ooo]Z0:3ooo]Z0_l00020oookJP03o`000?oonf[ooo]Z0:gooo]Z00?o0000oookJ_oo
nfX0>_oonfX2o`0003Cooo]Z000eoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX0
oooonfX<oookJP03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX0W?oonfX3o`0008;ooo]Z
00?o0000oookJ_oonfX0[OoonfX00ol0003ooo]ZoookJP0goookJP?o000000?ooo]Zo`000?oonfX0
<ooonfX003Gooo]Z00?o0000oookJ_oonfX01_oonfX00ol0003ooo]ZoookJP3ooookJP_ooo]Z00?o
0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP2HoookJP?o0000QOoonfX00ol0003ooo]Zoook
JP2]oookJP03o`000?oonf[ooo]Z03Cooo]Z0ol00004oookJP03o`000?oonf[ooo]Z03;ooo]Z000e
oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0oooonfX:oookJP03o`000?oonf[o
oo]Z047ooo]Z00?o0000oookJ_oonfX0U_oonfX2o`0008Sooo]Z0_l0002^oookJP03o`000?oonf[o
oo]Z037ooo]Z0ol00007oookJP03o`000?oonf[ooo]Z03;ooo]Z000eoookJP03o`000?oonf[ooo]Z
00Sooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oook
J_oonfX0T_oonfX3o`0008[ooo]Z00?o0000oookJ_oonfX0[_oonfX00ol0003ooo]ZoookJP0]oook
JP?o00002_oonfX00ol0003ooo]ZoookJP0boookJP00=?oonfX00ol0003ooo]ZoookJP0:oookJP03
o`000?oonf[ooo]Z0?oooo]Z2?oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z093o
oo]Z0_l0002=oookJP;o0000[ooonfX00ol0003ooo]ZoookJP0ZoookJP?o00003_oonfX00ol0003o
oo]ZoookJP0aoookJP00=?oonfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z0?oooo]Z
2?oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z08cooo]Z0ol0002?oookJP03o`00
0?oonf[ooo]Z0:kooo]Z00?o0000oookJ_oonfX09ooonfX3o`00017ooo]Z00?o0000oookJ_oonfX0
<OoonfX003Cooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP3ooookJPOooo]Z00?o
0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP28oookJP?o0000T_oonfX00ol0003ooo]Zoook
JP2^oookJP03o`000?oonf[ooo]Z02Cooo]Z0ol0000DoookJP03o`000?oonf[ooo]Z037ooo]Z000d
oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP03o`000?oonf[o
oo]Z04?ooo]Z00?o0000oookJ_oonfX0QooonfX2o`0009Cooo]Z00?o0000oookJ_oonfX0[_oonfX0
0ol0003ooo]ZoookJP0QoookJP?o00005ooonfX00ol0003ooo]ZoookJP0aoookJP00=?oonfX00ol0
003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z0?oooo]Z1OoonfX00ol0003ooo]ZoookJP14oook
JP03o`000?oonf[ooo]Z08Kooo]Z00?o0000oookJ_l00000TooonfX00ol0003ooo]ZoookJP2^oook
JP03o`000?oonf[ooo]Z01kooo]Z0ol0000JoookJP03o`000?oonf[ooo]Z037ooo]Z000doookJP03
o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0oooonfX4oookJP03o`000?oonf[ooo]Z04Go
oo]Z00?o0000oookJ_oonfX0QOoonfX01?l0003ooo]ZoookJ_l0002BoookJP03o`000?oonf[ooo]Z
0:kooo]Z00?o0000oookJ_oonfX06ooonfX3o`0001gooo]Z00?o0000oookJ_oonfX0<OoonfX003Co
oo]Z00?o0000oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP3ooookJP?ooo]Z00?o0000oookJ_oo
nfX0AOoonfX00ol0003ooo]ZoookJP25oookJP05o`000?oonf[ooo]ZoookJ_l00000TOoonfX00ol0
003ooo]ZoookJP2^oookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0000PoookJP03o`000?oonf[ooo]Z
037ooo]Z000coookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0oooonfX2oookJP03
o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0Q?oonfX00ol0003ooo]ZoookJP02oookJP03
o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX0[_oonfX00ol0003ooo]ZoookJP0EoookJP?o
00008ooonfX00ol0003ooo]ZoookJP0aoookJP00<ooonfX00ol0003ooo]ZoookJP0CoookJP03o`00
0?oonf[ooo]Z0?oooo]Z0OoonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z08?ooo]Z
00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP2=oookJP03o`000?oonf[ooo]Z0:kooo]Z
00?o0000oookJ_oonfX04_oonfX3o`0002Oooo]Z00?o0000oookJ_oonfX0<?oonfX003?ooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z04Oooo]Z00?o
0000oookJ_oonfX0P_oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z08cooo]Z00?o
0000oookJ_oonfX0[_oonfX00ol0003ooo]ZoookJP0?oookJP?o0000:_oonfX00ol0003ooo]Zoook
JP0`oookJP00<ooonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z0?Sooo]Z0_l00004
oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP06
oookJP03o`000?oonf[ooo]Z08_ooo]Z00?o0000oookJ_oonfX0[_oonfX00ol0003ooo]ZoookJP0<
oookJP?o0000;OoonfX00ol0003ooo]ZoookJP0`oookJP00<ooonfX00ol0003ooo]ZoookJP0Foook
JP03o`000?oonf[ooo]Z0?Gooo]Z0_l00002ojK1k@05o`000?oonf[ooo]ZoookJ_l00000B_oonfX0
0ol0003ooo]ZoookJP21oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX0R_oonfX0
0ol0003ooo]ZoookJP2_oookJP03o`000?oonf[ooo]Z00Sooo]Z0ol0000`oookJP03o`000?oonf[o
oo]Z033ooo]Z000coookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0l_oonfX2o`00
00?oY/7]0ol00002oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000oookJ_oonfX0P?oonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z08Wooo]Z00?o0000oookJ_oonfX0[ooonfX00ol0
003ooo]ZoookJP05oookJP?o0000<ooonfX00ol0003ooo]ZoookJP0`oookJP00<_oonfX00ol0003o
oo]ZoookJP0IoookJP03o`000?oonf[ooo]Z0>kooo]Z0ol000000onV`Ngo0000o`000002o`0000;o
Y/7]0_l000000ooonf[o0000oookJP1;oookJP03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oo
nfX02OoonfX00ol0003ooo]ZoookJP28oookJP03o`000?oonf[ooo]Z0:oooo]Z00?o0000oookJ_oo
nfX00_oonfX3o`0003Kooo]Z00?o0000oookJ_oonfX0<?oonfX003;ooo]Z00?o0000oookJ_oonfX0
6_oonfX00ol0003ooo]ZoookJP3ZoookJP?o000000OoY/7]o`000?l0003o0000ojK1kOl0003oY/7]
00?o000000CoY/7]o`000?oonf[o0000C?oonfX00ol0003ooo]ZoookJP1ooookJP03o`000?oonf[o
oo]Z00[ooo]Z00?o0000oookJ_oonfX0QooonfX00ol0003ooo]ZoookJP2_oookJP03o`000?oonf[o
000000;o0000>OoonfX00ol0003ooo]ZoookJP0`oookJP00<_oonfX00ol0003ooo]ZoookJP0Koook
JP03o`000?oonf[ooo]Z0>Gooo]Z1?l00002ojK1k@;o00001?nV`Nd2o`0000CoY/7]0ol0001=oook
JP03o`000?oonf[ooo]Z07kooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP26oook
JP03o`000?oonf[ooo]Z0:kooo]Z0ol0000loookJP03o`000?oonf[ooo]Z033ooo]Z000boookJP03
o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0hOoonfX3o`000003ojK1kOl0003oY/7]00?o
000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003o000004go
oo]Z00?o0000oookJ_oonfX0OOoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z08Go
oo]Z00?o0000oookJ_oonfX0ZooonfX3o`000003oookJ_l0003ooo]Z03cooo]Z00?o0000oookJ_oo
nfX0<?oonfX003;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP3NoookJP;o0000
1?nV`Nd2o`0000CoY/7]0_l00003ojK1k@?o00000onV`Nd3o`0004kooo]Z00?o0000oookJ_oonfX0
O?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z08Cooo]Z00?o0000oookJ_oonfX0
Z?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0_oookJP00<_oo
nfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z0=[ooo]Z0ol000000onV`Ngo0000ojK1
k@03o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?l000000_l00002ojK1k@Co00000_nV
`Nd2o`0004kooo]Z00?o0000oookJ_oonfX0NooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oo
nf[ooo]Z08?ooo]Z00?o0000oookJ_oonfX0YOoonfX3o`0000Oooo]Z00?o0000oookJ_oonfX0??oo
nfX00ol0003ooo]ZoookJP0_oookJP00<OoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[o
oo]Z0=Oooo]Z0_l00003ojK1k@?o00000onV`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo0000
ojK1k@03o`000003ojK1kOl0003oY/7]00Go0000C_oonfX00ol0003ooo]ZoookJP1koookJP03o`00
0?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0P_oonfX00ol0003ooo]ZoookJP2RoookJP?o0000
2_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02oooo]Z000aoookJP03o`000?oo
nf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0dooonfX3o`000003ojK1kOl0003o000000;o00000_nV
`Nd4o`0000;oY/7]0_l00004ojK1k@;o00001?nV`Nd3o`0000;oY/7]1?l0001=oookJP03o`000?oo
nf[ooo]Z07[ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP21oookJP03o`000?oo
nf[ooo]Z09oooo]Z0ol0000=oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0;ooo
nfX0037ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP3?oookJP?o000000OoY/7]
o`000?l0003o0000ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000
ojK1k@03o`000003ojK1kOl0003oY/7]00?o00000_nV`Nd3o`000003ojK1kOl0003oY/7]00;o0000
COoonfX00ol0003ooo]ZoookJP1ioookJP03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0
P?oonfX00ol0003ooo]ZoookJP2LoookJP?o00004?oonfX00ol0003ooo]ZoookJP0loookJP03o`00
0?oonf[ooo]Z02oooo]Z000aoookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0b_oo
nfX4o`0000;oY/7]0_l00004ojK1k@;o00001?nV`Nd3o`0000;oY/7]1?l00002ojK1k@Co000000Oo
Y/7]o`000?l0003o0000ojK1kOl0003oY/7]00?o000000?oY/7]o`000?oonfX0C?oonfX00ol0003o
oo]ZoookJP1ioookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003o
oo]ZoookJP2IoookJP?o00004ooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02oo
oo]Z000aoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0a_oonfX3o`000003ojK1
kOl0003oY/7]00?o00000_nV`Nd01?l0003oY/7]o`000?l00002ojK1k@04o`000?nV`Ngo0000o`00
00;oY/7]0ol00003ojK1k@?o00000onV`Nd2o`0000CoY/7]0_l000001?nV`Ngo0000ojK1kOnV`Nd2
o`0004gooo]Z00?o0000oookJ_oonfX0N?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z07kooo]Z00?o0000oookJ_oonfX0U_oonfX3o`0001Oooo]Z00?o0000oookJ_oonfX0>ooonfX0
0ol0003ooo]ZoookJP0_oookJP00<OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z
0<?ooo]Z0_l00004ojK1k@?o00000onV`Nd3o`0000?oY/7]0ol000001onV`Ngo0000o`000?l0003o
Y/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00?o000000?o
Y/7]o`000?nV`Nd00ol000000onV`Ngo0000oookJP1<oookJP03o`000?oonf[ooo]Z07Sooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP1moookJP03o`000?oonf[ooo]Z09?ooo]Z0ol0
000JoookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0;ooonfX0037ooo]Z00?o0000
oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP30oookJP;o00000_nV`Nd01?l0003oY/7]o`000?l0
0002ojK1k@Co00000_nV`Nd4o`0000;oY/7]0_l00004ojK1k@;o00001?nV`Nd2o`0000CoY/7]0_l0
0003ojK1k@Co00000_nV`Nd3o`0004gooo]Z00?o0000oookJ_oonfX0M_oonfX00ol0003ooo]Zoook
JP0GoookJP03o`000?oonf[ooo]Z07cooo]Z00?o0000oookJ_oonfX0T?oonfX3o`0001gooo]Z00?o
0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0^oookJP00<?oonfX00ol0003ooo]ZoookJP0X
oookJP03o`000?oonf[ooo]Z0;cooo]Z0ol00003ojK1k@?o000000OoY/7]o`000?l0003o0000ojK1
kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03o`000003ojK1
kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000o`000002o`0000;oY/7]
1?l00002ojK1k@;o0000COoonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z01Sooo]Z
00?o0000oookJ_oonfX0NooonfX00ol0003ooo]ZoookJP2=oookJP?o00008?oonfX00ol0003ooo]Z
oookJP0loookJP03o`000?oonf[ooo]Z02kooo]Z000`oookJP03o`000?oonf[ooo]Z02Wooo]Z00?o
0000oookJ_oonfX0]ooonfX4o`0000;oY/7]1?l00002ojK1k@;o00001?nV`Nd2o`0000CoY/7]0_l0
0003ojK1k@?o00000onV`Nd3o`0000?oY/7]0ol000001onV`Ngo0000o`000?l0003oY/7]o`000?nV
`Nd00ol000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003ooo]Z04cooo]Z00?o0000oookJ_oo
nfX0MOoonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z07[ooo]Z00?o0000oookJ_oo
nfX0R_oonfX3o`0002?ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP0^oookJP00
<?oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z0;?ooo]Z0ol000000onV`Ngo0000
ojK1k@03o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000
ojK1k@03o`000003ojK1kOl0003o000000;o00000_nV`Nd4o`0000;oY/7]1?l00002ojK1k@;o0000
1?nV`Nd2o`0000CoY/7]0_l00003ojK1k@?o0000COoonfX00ol0003ooo]ZoookJP1doookJP03o`00
0?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oonfX0NOoonfX00ol0003ooo]ZoookJP27oookJP?o0000
9_oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02kooo]Z000`oookJP03o`000?oo
nf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0/?oonfX2o`0000CoY/7]0_l00004ojK1k@;o00000onV
`Nd3o`0000?oY/7]0ol000001onV`Ngo0000o`000?l0003oY/7]o`000?nV`Nd00ol000000onV`Ngo
0000ojK1k@03o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo
0000ojK1k@08o`0000;oY/7]0_l0001=oookJP03o`000?oonf[ooo]Z07?ooo]Z00?o0000oookJ_oo
nfX06ooonfX00ol0003ooo]ZoookJP1goookJP;o0000Q_oonfX3o`0002Wooo]Z00?o0000oookJ_oo
nfX0??oonfX00ol0003ooo]ZoookJP0^oookJP00<?oonfX00ol0003ooo]ZoookJP0/oookJP03o`00
0?oonf[ooo]Z0:cooo]Z0ol000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00?o0000
00?oY/7]o`000?l000000_l00002ojK1k@Co00000_nV`Nd2o`0000CoY/7]0_l00004ojK1k@;o0000
0onV`Nd3o`0000?oY/7]0ol00003ojK1k@?o000000OoY/7]o`000?l0003o0000ojK1kOl0003oY/7]
00?o000000?oY/7]o`000?oonfX0C?oonfX00ol0003ooo]ZoookJP1coookJP03o`000?oonf[ooo]Z
01cooo]Z00?o0000oookJ_oonfX0M_oonfX2o`0008?ooo]Z0ol0000/oookJP03o`000?oonf[ooo]Z
03cooo]Z00?o0000oookJ_oonfX0;_oonfX0033ooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP2YoookJP?o00000_nV`Nd4o`0000;oY/7]1?l000000onV`Ngo0000o`000002ojK1k@04
o`000?nV`Ngo0000o`0000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]00?o000000?o
Y/7]o`000?nV`Nd00ol000000onV`Ngo0000o`000002o`0000;oY/7]1?l00002ojK1k@Co00000_nV
`Nd2o`0000;oY/7]00?o0000ojK1kOl000000_l00002ojK1k@?o0000COoonfX00ol0003ooo]Zoook
JP1boookJP03o`000?oonf[ooo]Z01gooo]Z00?o0000oookJ_oonfX0MOoonfX00ol0003ooo]Zoook
JP1ooookJP?o0000;ooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02kooo]Z000_
oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0Y_oonfX2o`0000;oY/7]0ol00003
ojK1k@?o00000onV`Nd2o`0000CoY/7]0_l00004ojK1k@;o00000_nV`Nd4o`0000;oY/7]1?l00000
0onV`Ngo0000o`000002ojK1k@04o`000?nV`Ngo0000o`0000;oY/7]00Co0000ojK1kOl0003o0000
0_nV`Nd01?l0003oY/7]o`000?l00002ojK1k@04o`000?nV`Ngo0000o`0000;oY/7]0ol00002ojK1
k@;o0000C?oonfX00ol0003ooo]ZoookJP1boookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oook
J_oonfX0M?oonfX00ol0003ooo]ZoookJP1loookJP?o0000<_oonfX00ol0003ooo]ZoookJP0loook
JP03o`000?oonf[ooo]Z02kooo]Z000_oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oo
nfX0X_oonfX3o`000007ojK1kOl0003o0000o`000?nV`Ngo0000ojK1k@03o`000003ojK1kOl0003o
Y/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03o`000004ojK1kOl0003o
0000o`0000?oY/7]0ol00003ojK1k@;o00001?nV`Nd2o`0000CoY/7]0_l00003ojK1k@?o00000onV
`Nd7o`000003ojK1kOl0003oY/7]00;o00000_nV`Nd00ol0003ooo]ZoookJP1:oookJP03o`000?oo
nf[ooo]Z073ooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP1coookJP;o0000N_oo
nfX3o`0003Gooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0]oookJP00;ooonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z09_ooo]Z00?o0000oookJ_l000000ol00002
ojK1k@;o00001?nV`Nd2o`0000?oY/7]0ol00003ojK1k@?o00000onV`Nd3o`000007ojK1kOl0003o
0000o`000?nV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd0
0ol000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003o000000;o00000_nV`Nd4o`0000;oY/7]
0_l00004ojK1k@;o00001?nV`Nd2o`0004cooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]Z
oookJP0QoookJP03o`000?oonf[ooo]Z07;ooo]Z00?o0000oookJ_oonfX0M_oonfX3o`0003Sooo]Z
00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0]oookJP00;ooonfX00ol0003ooo]Zoook
JP0boookJP03o`000?oonf[ooo]Z09Wooo]Z0ol000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0
003oY/7]00?o000000?oY/7]o`000?l000000_l00002ojK1k@Co00000_nV`Nd4o`0000;oY/7]0_l0
0004ojK1k@;o00001?nV`Nd2o`0000?oY/7]0ol00003ojK1k@?o000000OoY/7]o`000?l0003o0000
ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03o`000003
ojK1kOl0003oY/7]00?o000000?oY/7]o`000?l00000BooonfX00ol0003ooo]ZoookJP1_oookJP03
o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0LOoonfX2o`0007Cooo]Z0ol0000coookJP;o
00001ooonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02gooo]Z000_oookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0U_oonfX3o`0000;oY/7]0ol00003ojK1k@?o0000
00OoY/7]o`000?l0003o0000ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV
`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV
`Ngo0000o`000002o`0000;oY/7]1?l00002ojK1k@;o00001?nV`Nd2o`0000CoY/7]0_l00003ojK1
k@?o00000onV`Nd3o`000006ojK1kOl0003o0000o`000?nV`Ngo0000C?oonfX00ol0003ooo]Zoook
JP1^oookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0L?oonfX00ol0003ooo]Zoook
JP1`oookJP?o0000<ooonfX3o`000003ojK2kOl0003ooo]Z00Kooo]Z00?o0000oookJ_oonfX0??oo
nfX00ol0003ooo]ZoookJP0]oookJP00;ooonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o
oo]Z09?ooo]Z0_l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0_l00004ojK1k@;o00001?nV`Nd3
o`0000;oY/7]0ol00003ojK1k@?o00000onV`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo0000
ojK1k@03o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000
ojK1k@03o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000ol00002ojK1k@;o0000
1?nV`Nd2o`0004cooo]Z00?o0000oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP0ToookJP03o`00
0?oonf[ooo]Z06oooo]Z0_l0001^oookJP?o0000<ooonfX3o`0000GoY/;]00?o0000oookJ_oonfX0
1?oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02gooo]Z000^oookJP03o`000?oo
nf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0SooonfX3o`000007ojK1kOl0003o0000o`000?nV`Ngo
0000ojK1k@02o`0000;oY/7]00Co0000ojK1kOl0003o00000_nV`Nd01?l0003oY/7]o`000?l00002
ojK1k@04o`000?nV`Ngo0000o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd4o`0000;oY/7]0_l0
0004ojK1k@;o00000onV`Nd3o`0000?oY/7]0ol00003ojK1k@?o000000OoY/7]o`000?l0003o0000
ojK1kOl0003oY/7]00Go000000OoY/7]o`000?l0003o0000ojK1kOl0003oY/7]00?o000000?oY/7]
o`000?oonfX0BooonfX00ol0003ooo]ZoookJP1]oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX0K_oonfX00ol0003ooo]ZoookJP1ZoookJP?o0000<ooonfX3o`000004ojK2kOl0003o
Y/;]ojK2k@?o00000_nV`^d00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z03cooo]Z00?o
0000oookJ_oonfX0;OoonfX002kooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP2:
oookJPCo00000_nV`Nd2o`0000CoY/7]0_l00003ojK1k@?o00000onV`Nd3o`0000?oY/7]0ol00000
1onV`Ngo0000o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@04o`000?nV`Ngo0000o`0000;o
Y/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]00?o000000?oY/7]o`000?l000000_l00002
ojK1k@Co00000_nV`Nd4o`0000;oY/7]0_l00004ojK1k@;o00000onV`Nd3o`0000?oY/7]0ol00003
ojK1k@?o0000C?oonfX00ol0003ooo]ZoookJP1/oookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000
oookJ_oonfX0KOoonfX00ol0003ooo]ZoookJP1WoookJP?o0000<ooonfX3o`0000GoY/;]0_l00002
ojK2k@;o00000_nV`^d00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000
oookJ_oonfX0;OoonfX002kooo]Z00?o0000oookJ_oonfX0>?oonfX00ol0003ooo]ZoookJP26oook
JP?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003o0000
00;o00000_nV`Nd4o`0000;oY/7]1?l00002ojK1k@;o00001?nV`Nd2o`0000?oY/7]0ol00003ojK1
k@?o00000_nV`Nd4o`000003ojK1kOl0003o000000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0
003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0
003o000000?o000000?oY/7]o`000?l000000_l00002ojK1k@Co00000_nV`Nd2o`0004_ooo]Z00?o
0000oookJ_oonfX0K?oonfX00ol0003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z06cooo]Z00?o
0000oookJ_oonfX0I?oonfX3o`0003?ooo]Z0ol00003ojK2k@?o00001?nV`^d00ol0003oY/;]ojK2
k@04ojK2k@05o`000?oonf[ooo]ZoookJ_l00000?_oonfX00ol0003ooo]ZoookJP0]oookJP00;_oo
nfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z08;ooo]Z1?l00002ojK1k@Co00000_nV
`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00?o
000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003o000000;o
00000_nV`Nd4o`0000;oY/7]0ol00003ojK1k@;o00001?nV`Nd2o`0000;oY/7]1?l00002ojK1k@Co
00000_nV`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo0000ojK1k@03o`000003ojK1kOl0003o
Y/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000oookJP1;oookJP03o`000?oonf[o
oo]Z06[ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1[oookJP03o`000?oonf[o
oo]Z067ooo]Z0ol0000doookJP;o00000onV`^d2o`000004ojK2kOl0003oY/;]ojK2k@?o000000Co
Y/;]o`000?nV`^goY/;]0ol000000onV`^go0000oookJP02oookJP03o`000?oonf[ooo]Z03cooo]Z
00?o0000oookJ_oonfX0;OoonfX002kooo]Z00?o0000oookJ_oonfX0>_oonfX00ol0003ooo]Zoook
JP1noookJP?o00000onV`Nd3o`0000?oY/7]0ol00002ojK1k@;o00001?nV`Nd3o`0000;oY/7]0ol0
0003ojK1k@?o00000onV`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo0000ojK1k@03o`000003
ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03o`000004
ojK1kOl0003o0000o`0000?oY/7]0ol00003ojK1k@?o00000_nV`Nd2o`0000CoY/7]0_l000000onV
`Ngo0000ojK1k@03o`0000?oY/7]0ol00003ojK1k@?o0000C?oonfX00ol0003ooo]ZoookJP1Yoook
JP03o`000?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP1Noook
JP?o0000=?oonfX3o`0000;oY/;]0_l00005ojK2k@;o00001OnV`^d2o`0000GoY/;]00Co0000oook
J_oonf[o0000?ooonfX00ol0003ooo]ZoookJP0/oookJP00;_oonfX00ol0003ooo]ZoookJP0koook
JP03o`000?oonf[ooo]Z07[ooo]Z0ol000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]
00?o000000?oY/7]o`000?nV`Nd00_l00002ojK1k@04o`000?nV`Ngo0000o`0000;oY/7]0ol00002
ojK1k@Co00000_nV`Nd4o`0000;oY/7]0_l00004ojK1k@;o00001?nV`Nd2o`0000?oY/7]0ol00003
ojK1k@?o000000OoY/7]o`000?l0003o0000ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd0
0ol000000onV`Ngo0000ojK1k@02o`0000;oY/7]00Go0000ojK1kOl0003o0000ojK1k@04o`0000;o
Y/7]1?l00002ojK1k@Co00000_nV`Nd2o`0004_ooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003o
oo]ZoookJP0[oookJP03o`000?oonf[ooo]Z06Wooo]Z00?o0000oookJ_oonfX0FooonfX3o`0003;o
oo]Z1Ol00002ojK2k@;o000000CoY/;]o`000?nV`^goY/;]0ol000001?nV`^go0000ojK2kOnV`^d3
o`000004ojK2kOl0003oY/;]ojK2k@?o000000GoY/;]o`000?oonf[ooo]Zo`00000ooookJP03o`00
0?oonf[ooo]Z02cooo]Z000^oookJP03o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0Mooo
nfX2o`0000CoY/7]0_l00004ojK1k@;o00000onV`Nd3o`0000?oY/7]0ol000001onV`Ngo0000o`00
0?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@04o`000?nV`Ngo0000o`0000;oY/7]00Oo0000ojK1
kOl0003o0000ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000o`00
0002o`0000;oY/7]1?l00002ojK1k@;o00001?nV`Nd2o`0000?oY/7]0ol00003ojK1k@?o00000onV
`Nd3o`000003ojK1kOl0003o000000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]00?o
000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000oookJP1;oookJP03o`000?oonf[ooo]Z06So
oo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP1XoookJP03o`000?oonf[ooo]Z05So
oo]Z0ol0000aoookJPCo00001?nV`^d2o`0000GoY/;]0_l00005ojK2k@;o00001OnV`^d2o`0000Go
Y/;]00?o0000oookJ_l00000?ooonfX00ol0003ooo]ZoookJP0/oookJP00;OoonfX00ol0003ooo]Z
oookJP0noookJP03o`000?oonf[ooo]Z07Cooo]Z0_l000000onV`Ngo0000ojK1k@03o`000003ojK1
kOl0003oY/7]00?o000000?oY/7]o`000?l000000_l00002ojK1k@Co00000_nV`Nd2o`0000CoY/7]
0_l00004ojK1k@;o00000onV`Nd3o`0000;oY/7]1?l00002ojK1k@Co000000KoY/7]o`000?l0003o
Y/7]o`000?nV`Nd3o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV
`Ngo0000o`000002o`0000;oY/7]1?l00002ojK1k@Co00000_nV`Nd2o`0000CoY/7]0_l00002ojK1
k@Co00000_nV`Nd3o`0000?oY/7]0ol0001<oookJP03o`000?oonf[ooo]Z06Oooo]Z00?o0000oook
J_oonfX0;OoonfX00ol0003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z05Gooo]Z0ol0000aoook
JP?o00000_nV`^d00ol0003oY/;]o`000002o`0000;oY/;]00?o0000ojK2kOl000000_l00002ojK2
k@03o`000?nV`^go000000;o000000CoY/;]o`000?nV`^goY/;]0ol000001?nV`^go0000ojK2kOnV
`^d3o`0000;oY/;]0_l0000ooookJP03o`000?oonf[ooo]Z02cooo]Z000]oookJP03o`000?oonf[o
oo]Z03oooo]Z00?o0000oookJ_oonfX0L?oonfX3o`0000;oY/7]1?l00002ojK1k@Co000000KoY/7]
o`000?l0003oY/7]o`000?nV`Nd3o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd0
0ol000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000?oY/7]
0ol00003ojK1k@;o00000onV`Nd3o`0000;oY/7]0ol00003ojK1k@?o000000OoY/7]o`000?l0003o
0000ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03o`00
0003ojK1kOl0003oY/7]00Oo00000onV`Nd3o`0000;oY/7]1?l00002ojK1k@;o0000BooonfX00ol0
003ooo]ZoookJP1WoookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0
003ooo]ZoookJP1BoookJP?o0000<_oonfX2o`0000KoY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0
003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00005ojK2k@;o00000_nV`^d2o`00
00;oY/;]00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0/oookJP00;OoonfX00ol0003o
oo]ZoookJP10oookJP03o`000?oonf[ooo]Z06_ooo]Z1?l00002ojK1k@?o00000onV`Nd3o`0000?o
Y/7]0_l00002ojK1k@Co00000_nV`Nd4o`0000;oY/7]0ol00003ojK1k@?o000000OoY/7]o`000?l0
003o0000ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03
o`000003ojK1kOl0003oY/7]00;o00000_nV`Nd3o`0000;oY/7]1?l00002ojK1k@;o00001?nV`Nd2
o`0000?oY/7]0ol00003ojK1k@?o00000onV`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo0000
ojK1k@03o`000003ojK1kOl0003oY/7]00;o00000_nV`Nd01_l0003oY/7]o`000?l0003oY/7]o`00
04cooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z
06Gooo]Z00?o0000oookJ_oonfX0CooonfX3o`0003;ooo]Z0ol000001?nV`^go0000ojK2kOnV`^d3
o`000004ojK2kOl0003oY/;]ojK2k@?o000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000
ojK2k@03o`0000?oY/;]0ol00004ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l0000noookJP03o`00
0?oonf[ooo]Z02cooo]Z000]oookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0J?oo
nfX2o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1
k@03o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`0000;oY/7]
0ol00002ojK1k@?o00000onV`Nd3o`0000?oY/7]0ol00003ojK1k@?o000000OoY/7]o`000?l0003o
0000ojK1kOl0003oY/7]00;o00000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00ol0
00000onV`Ngo0000o`000002o`0000;oY/7]1?l00002ojK1k@Co00000_nV`Nd2o`0000;oY/7]00Co
0000ojK1kOl0003o00000onV`Nd3o`0000?oY/7]0ol00002ojK1k@?o0000BooonfX00ol0003ooo]Z
oookJP1VoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]Z
oookJP1<oookJP?o0000<_oonfX3o`0000GoY/;]0_l00005ojK2k@;o00001OnV`^d2o`0000GoY/;]
00Co0000ojK2kOnV`^goY/;]0_l000001?nV`^go0000ojK2kOnV`^d3o`000004ojK2kOl0003oY/;]
ojK2k@?o000000?oY/;]o`000?oonfX0?OoonfX00ol0003ooo]ZoookJP0/oookJP00;OoonfX00ol0
003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z06Gooo]Z0_l00002ojK1k@Co00000_nV`Nd3o`00
00?oY/7]0ol000001onV`Ngo0000o`000?l0003oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1
k@03o`000003ojK1kOl0003oY/7]00;o00000_nV`Nd01?l0003oY/7]o`000?l00002ojK1k@?o0000
0_nV`Nd4o`0000;oY/7]1?l00002ojK1k@Co00000_nV`Nd2o`0000?oY/7]0ol00003ojK1k@?o0000
0_nV`Nd4o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@03o`00
0003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000o`000002o`00
00;oY/7]1?l00002ojK1k@?o00000_nV`Nd2o`0004_ooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0
003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oonfX0BOoonfX3o`00
03;ooo]Z0ol000001?nV`^go0000ojK2kOnV`^d3o`000004ojK2kOl0003oY/;]ojK2k@?o000000Co
Y/;]o`000?nV`^goY/;]0ol00002ojK2k@?o00001?nV`^d2o`0000GoY/;]0_l00005ojK2k@;o0000
1?nV`^d2o`0003gooo]Z00?o0000oookJ_oonfX0;?oonfX002gooo]Z00?o0000oookJ_oonfX0@ooo
nfX00ol0003ooo]ZoookJP1QoookJP?o000000CoY/7]o`000?l0003o00000onV`Nd3o`0000;oY/7]
1?l00002ojK1k@;o00001?nV`Nd2o`0000?oY/7]0ol00003ojK1k@?o00000onV`Nd3o`000007ojK1
kOl0003o0000o`000?nV`Ngo0000ojK1k@02o`0000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0
003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000o`000002o`0000;oY/7]1?l0
0002ojK1k@?o00000onV`Nd2o`0000?oY/7]0ol00002ojK1k@?o00000onV`Nd3o`0000?oY/7]0ol0
00001onV`Ngo0000o`000?l0003oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03o`000003
ojK1kOl0003oY/7]00;o00000_nV`Nd00ol0003ooo]ZoookJP19oookJP03o`000?oonf[ooo]Z06?o
oo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z04Ko
oo]Z0ol0000boookJP?o00001OnV`^d2o`0000GoY/;]0_l00005ojK2k@;o00000_nV`^d2o`000004
ojK2kOl0003oY/;]ojK2k@?o000000CoY/;]o`000?nV`^goY/;]0ol000001?nV`^go0000ojK2kOnV
`^d3o`000004ojK2kOl0003oY/;]ojK2k@Go0000?_oonfX00ol0003ooo]ZoookJP0[oookJP00;?oo
nfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z05gooo]Z0ol000001onV`Ngo0000o`00
0?l0003oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@02o`0000;oY/7]00Co0000ojK1kOl0
003o00000_nV`Nd01Ol0003oY/7]o`000?l0003oY/7]00Co00000_nV`Nd4o`0000;oY/7]1?l00002
ojK1k@;o00001?nV`Nd2o`0000?oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`000007ojK1kOl0003o
0000o`000?nV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd0
0ol000000onV`Ngo0000ojK1k@02o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd4o`0000;oY/7]
0ol00003ojK1k@;o00000onV`Nd3o`0000?oY/7]0ol00003ojK1k@?o0000B_oonfX00ol0003ooo]Z
oookJP1SoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]Z
oookJP13oookJP?o0000<_oonfX3o`0000;oY/;]00?o0000ojK2kOl000000_l00002ojK2k@03o`00
0?nV`^go000000;o00000onV`^d3o`0000?oY/;]0_l00005ojK2k@;o00001OnV`^d2o`0000GoY/;]
0_l00005ojK2k@;o00000onV`^d00ol0003oY/;]o`00000moookJP03o`000?oonf[ooo]Z02_ooo]Z
000/oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0F?oonfX4o`0000;oY/7]0_l0
0004ojK1k@;o00000onV`Nd3o`0000?oY/7]0ol00003ojK1k@?o000000?oY/7]o`000?l000000_nV
`Nd01?l0003oY/7]o`000?l00002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@03o`00
0003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?l000000_l00002ojK1k@?o00000onV`Nd3o`00
00;oY/7]0_l00004ojK1k@;o00000onV`Nd3o`0000?oY/7]0ol00003ojK1k@?o000000OoY/7]o`00
0?l0003o0000ojK1kOl0003oY/7]00;o00000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV
`Nd00ol000000onV`Ngo0000o`000003o`000003ojK1kOl0003o000000;o00000_nV`Nd4o`0000;o
Y/7]1?l00002ojK1k@;o0000B_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[ooo]Z03Go
oo]Z00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP10oookJP?o0000<ooonfX2o`0000Ko
Y/;]00?o0000ojK2kOnV`^d01?nV`^d01?l0003oY/;]ojK2kOnV`^d2o`000003ojK2kOl0003oY/;]
00?o00000_nV`^d00ol0003oY/;]o`000002o`0000;oY/;]00?o0000ojK2kOl000000_l00002ojK2
k@03o`000?nV`^go000000;o00000_nV`^d00ol0003oY/;]o`000002o`0000;oY/;]0ol000001OnV
`^go0000ojK2kOnV`^go000003cooo]Z00?o0000oookJ_oonfX0:ooonfX002cooo]Z00?o0000oook
J_oonfX0AooonfX00ol0003ooo]ZoookJP1EoookJP;o00000_nV`Nd01?l0003oY/7]o`000?l00002
ojK1k@05o`000?nV`Ngo0000o`000?nV`Nd01?l00002ojK1k@Co00000_nV`Nd4o`0000;oY/7]0_l0
0004ojK1k@;o00000onV`Nd3o`0000;oY/7]1?l00002ojK1k@?o000000OoY/7]o`000?l0003o0000
ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@02o`0000;o
Y/7]00Go0000ojK1kOl0003o0000ojK1k@04o`0000;oY/7]1?l00002ojK1k@Co00000_nV`Nd2o`00
00CoY/7]0_l00003ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000001onV`Ngo0000o`000?l0003o
Y/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00?o000000?o
Y/7]o`000?oonfX0B_oonfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o
0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP0moookJP?o0000<ooonfX3o`000004ojK2kOl0
003oY/;]ojK2k@?o00000_nV`^d3o`0000CoY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00CoY/;]
00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00CoY/;]
00?o0000ojK2kOnV`^d00_l00002ojK2k@03o`000?nV`^go000000;o00000_nV`^d00ol0003ooo]Z
oookJP0ioookJP03o`000?oonf[ooo]Z02_ooo]Z000/oookJP03o`000?oonf[ooo]Z04Sooo]Z00?o
0000oookJ_oonfX0DOoonfX3o`0000?oY/7]0ol00003ojK1k@?o000000?oY/7]o`000?l000000_nV
`Nd01?l0003oY/7]o`000?l00002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@03o`00
0003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?l000000_l00002ojK1k@?o00000onV`Nd3o`00
00;oY/7]0_l00004ojK1k@;o00000onV`Nd3o`0000?oY/7]0ol00003ojK1k@?o000000?oY/7]o`00
0?l000000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1
k@03o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?l000000_l00002ojK1k@?o00000onV
`Nd3o`0000;oY/7]0_l00003ojK1k@?o00000onV`Nd3o`0000?oY/7]0ol00003ojK1k@?o0000B_oo
nfX00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0G_oo
nfX00ol0003ooo]ZoookJP0joookJP?o0000<ooonfX3o`0000GoY/;]0_l00002ojK2k@;o000000Co
Y/;]o`000?nV`^goY/;]0ol000001?nV`^go0000ojK2kOnV`^d3o`000004ojK2kOl0003oY/;]ojK2
k@?o000000CoY/;]o`000?nV`^goY/;]0ol000001?nV`^go0000ojK2kOnV`^d3o`0000;oY/;]0ol0
0004ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOl000001?nV`^d00ol0003ooo]Zoook
JP0hoookJP03o`000?oonf[ooo]Z02_ooo]Z000/oookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000
oookJ_oonfX0COoonfX3o`0000;oY/7]1?l00002ojK1k@Co00000_nV`Nd2o`0000?oY/7]0ol00003
ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000001onV`Ngo0000o`000?l0003oY/7]o`000?nV`Nd0
0ol000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00;o00000_nV`Nd01Ol0003oY/7]
o`000?l0003oY/7]00Co00000_nV`Nd4o`0000;oY/7]1?l00002ojK1k@;o00000onV`Nd3o`0000;o
Y/7]1?l00002ojK1k@?o00000onV`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo0000ojK1k@03
o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd01ol00002ojK1k@Co00000_nV`Nd4
o`0000;oY/7]1?l00002ojK1k@;o0000B_oonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[o
oo]Z03Sooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0goookJP?o0000<ooonfX3
o`0000?oY/;]0ol00003ojK2k@;o00001OnV`^d2o`0000GoY/;]0_l00005ojK2k@;o00001OnV`^d2
o`0000GoY/;]0_l00002ojK2k@;o000000CoY/;]o`000?nV`^goY/;]0ol000001?nV`^go0000ojK2
kOnV`^d3o`000003ojK2kOl0003oY/;]00Co000000?oY/;]o`000?oonfX0>OoonfX00ol0003ooo]Z
oookJP0[oookJP00;?oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z04Wooo]Z0ol0
00000onV`Ngo0000ojK1k@02o`0000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]00?o
000000?oY/7]o`000?l000000_l00002ojK1k@Co00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@?o
00000_nV`Nd3o`0000?oY/7]0ol00003ojK1k@?o00000onV`Nd3o`000003ojK1kOl0003o000000;o
Y/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol00000
0onV`Ngo0000o`000002o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`0000;oY/7]0_l00003
ojK1k@?o00000onV`Nd3o`0000?oY/7]0ol000000onV`Ngo0000o`000002ojK1k@07o`000?nV`Ngo
0000o`000?nV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd0
0ol000000onV`Ngo0000o`000019oookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0
>OoonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z03Cooo]Z0ol0000boookJPCo0000
0onV`^d2o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`0000;oY/;]
00?o0000ojK2kOl000000_l00002ojK2k@03o`000?nV`^go000000;o00000_nV`^d3o`0000CoY/;]
0ol00004ojK2k@;o00001OnV`^d2o`0000GoY/;]0_l00005ojK2k@;o00001OnV`^d00ol0003ooo]Z
oookJP0goookJP03o`000?oonf[ooo]Z02_ooo]Z000[oookJP03o`000?oonf[ooo]Z04cooo]Z00?o
0000oookJ_oonfX0A_oonfX2o`0000?oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`000003ojK1kOl0
003o000000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV
`Nd00ol000000onV`Ngo0000ojK1k@02o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd4o`0000;o
Y/7]1?l00002ojK1k@;o00000onV`Nd3o`0000;oY/7]1?l00002ojK1k@?o000000OoY/7]o`000?l0
003o0000ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@02
o`0000;oY/7]00Go0000ojK1kOl0003o0000ojK1k@04o`0000;oY/7]1?l00002ojK1k@Co00000_nV
`Nd2o`0000;oY/7]00Co0000ojK1kOl0003o00000_nV`Nd3o`0000?oY/7]0ol00003ojK1k@?o0000
00KoY/7]o`000?l0003o0000ojK1kOl0001:oookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oook
J_oonfX0>_oonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z037ooo]Z0ol0000aoook
JPCo00001?nV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@04ojK2
k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00_l00002ojK2k@03o`000?nV`^go0000
00;o00000_nV`^d00ol0003oY/;]o`000002o`000004ojK2kOl0003oY/;]ojK2k@?o000000CoY/;]
o`000?nV`^goY/;]0ol000001?nV`^go0000ojK2kOnV`^d3o`0000;oY/;]0ol00004ojK2k@03o`00
0?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0:ooonfX002_ooo]Z00?o0000oookJ_oonfX0COoo
nfX00ol0003ooo]ZoookJP13oookJP;o000000?oY/7]o`000?l000000_l00002ojK1k@Co00000_nV
`Nd3o`0000?oY/7]0_l00004ojK1k@;o00000_nV`Nd4o`0000;oY/7]0ol00003ojK1k@?o000000Oo
Y/7]o`000?l0003o0000ojK1kOl0003oY/7]00;o00000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]
o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003o000000;o00000_nV`Nd3
o`0000?oY/7]0ol00002ojK1k@;o00001?nV`Nd2o`0000?oY/7]0ol00003ojK1k@?o00000onV`Nd3
o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@03o`000003ojK1
kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000001?nV`Ngo0000o`000?l00002ojK1k@Co
00000_nV`Nd4o`0000;oY/7]0_l00003ojK1k@?o0000B_oonfX00ol0003ooo]ZoookJP1MoookJP03
o`000?oonf[ooo]Z03cooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]ZoookJP0^oookJP?o
0000<OoonfX3o`0000;oY/;]00?o0000ojK2kOl000000_l000001?nV`^go0000ojK2kOnV`^d3o`00
0004ojK2kOl0003oY/;]ojK2k@?o000000CoY/;]o`000?nV`^goY/;]0ol00002ojK2k@?o00001?nV
`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV
`^d2o`0000GoY/;]0_l00005ojK2k@;o00000_nV`^d2o`000004ojK2kOl0003oY/;]ojK2k@?o0000
00?oY/;]o`000?oonfX0>?oonfX00ol0003ooo]ZoookJP0ZoookJP00:ooonfX00ol0003ooo]Zoook
JP1>oookJP03o`000?oonf[ooo]Z03oooo]Z0ol000000onV`Ngo0000o`000002ojK1k@04o`000?nV
`Ngo0000o`0000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]00?o000000?oY/7]o`00
0?nV`Nd00ol000001?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd4o`0000;oY/7]0_l00003
ojK1k@?o00000onV`Nd3o`0000;oY/7]1?l00002ojK1k@?o000000OoY/7]o`000?l0003o0000ojK1
kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@02o`0000;oY/7]
00Go0000ojK1kOl0003o0000ojK1k@04o`0000;oY/7]1?l00002ojK1k@Co00000_nV`Nd2o`0000;o
Y/7]1?l00002ojK1k@?o00000onV`Nd3o`0000?oY/7]0ol000001onV`Ngo0000o`000?l0003oY/7]
o`000?nV`Nd00_l00002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@03o`000003ojK1
kOl0003o000000;o00000_nV`Nd2o`0004Wooo]Z00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]Z
oookJP0moookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX0:ooonfX3o`0003;ooo]Z
0_l00006ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00005ojK2k@;o00001OnV`^d2o`0000;oY/;]
0_l000001?nV`^go0000ojK2kOnV`^d3o`000004ojK2kOl0003oY/;]ojK2k@?o000000CoY/;]o`00
0?nV`^goY/;]0ol000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l00003
ojK2k@?o00000onV`^d2o`0000CoY/;]0ol00005ojK2k@03o`000?oonf[ooo]Z03Kooo]Z00?o0000
oookJ_oonfX0:_oonfX002_ooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP0joook
JPCo00000_nV`Nd2o`0000?oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000001onV
`Ngo0000o`000?l0003oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@02o`0000;oY/7]00Go
0000ojK1kOl0003o0000ojK1k@04o`0000;oY/7]1?l00002ojK1k@?o00000onV`Nd3o`0000;oY/7]
0ol00002ojK1k@?o00000onV`Nd3o`0000?oY/7]0ol00003ojK1k@?o000000?oY/7]o`000?l00000
0_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03o`00
0004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1k@Co00000_nV`Nd4o`0000;oY/7]0ol00002
ojK1k@?o00000onV`Nd3o`0000;oY/7]0ol000001onV`Ngo0000o`000?l0003oY/7]o`000?nV`Nd0
0ol000000onV`Ngo0000oookJP19oookJP03o`000?oonf[ooo]Z05cooo]Z00?o0000oookJ_oonfX0
?_oonfX00ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z02Sooo]Z0ol0000boookJP?o0000
00CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl0
00000_l00003ojK2k@?o00000onV`^d2o`0000GoY/;]0_l00005ojK2k@;o00001OnV`^d2o`0000Go
Y/;]00?o0000ojK2kOnV`^d01?nV`^d01?l0003oY/;]ojK2kOnV`^d2o`000003ojK2kOl0003oY/;]
00?o00000_nV`^d00ol0003oY/;]o`000002o`000004ojK2kOl0003o0000ojK2k@?o000000?oY/;]
o`000?oonfX0=ooonfX00ol0003ooo]ZoookJP0ZoookJP00:ooonfX00ol0003ooo]ZoookJP1@oook
JP03o`000?oonf[ooo]Z03Oooo]Z0_l00002ojK1k@05o`000?nV`Ngo0000o`000?nV`Nd01?l00002
ojK1k@Co00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@?o00000_nV`Nd3o`0000?oY/7]0ol00003
ojK1k@?o000000?oY/7]o`000?l000000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd0
0ol000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00;o00000_nV`Nd3o`0000;oY/7]
1?l00002ojK1k@Co00000_nV`Nd4o`0000;oY/7]0_l00003ojK1k@?o00000_nV`Nd3o`0000?oY/7]
0ol000001onV`Ngo0000o`000?l0003oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@02o`00
0003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000o`000002o`00
00;oY/7]1?l00002ojK1k@?o00000_nV`Nd2o`0000CoY/7]0_l00003ojK1k@?o0000B_oonfX00ol0
003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0EooonfX00ol0
003ooo]ZoookJP0UoookJP?o0000<_oonfX3o`0000GoY/;]0_l00005ojK2k@03o`000?nV`^goY/;]
00CoY/;]00Co0000ojK2kOnV`^goY/;]0_l000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000
ojK2kOl000000_l00002ojK2k@03o`000?nV`^go000000;o000000CoY/;]o`000?nV`^goY/;]0ol0
00001?nV`^go0000ojK2kOnV`^d3o`0000;oY/;]0ol00004ojK2k@;o00001OnV`^d00ol0003oY/;]
ojK2k@04ojK2k@03o`000?nV`^goY/;]00;oY/;]00?o0000ojK2kOl000001OnV`^d2o`0003Kooo]Z
00?o0000oookJ_oonfX0:_oonfX002_ooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]Zoook
JP0coookJP?o00000onV`Nd3o`000003ojK1kOl0003o000000;oY/7]00Oo0000ojK1kOl0003o0000
ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@02o`0000;o
Y/7]0ol00002ojK1k@Co00000_nV`Nd4o`0000;oY/7]0_l00003ojK1k@?o00000_nV`Nd4o`0000;o
Y/7]0ol00003ojK1k@?o000000OoY/7]o`000?l0003o0000ojK1kOl0003oY/7]00;o00000_nV`Nd0
1ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03o`000003ojK1
kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]1?l00002ojK1k@;o00000onV`Nd3o`0000?oY/7]
0ol00002ojK1k@Co00000_nV`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo0000ojK1k@03o`00
0003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00_l000000onV`Ngo0000ojK1k@03o`00
0003ojK1kOl0003o000000;o00000_nV`Nd2o`0004Wooo]Z00?o0000oookJ_oonfX0FooonfX00ol0
003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX08_oonfX3o`00
03;ooo]Z0ol00002ojK2k@03o`000?nV`^go000000;o000000CoY/;]o`000?nV`^goY/;]0ol00002
ojK2k@?o00001?nV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@04
ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00005ojK2k@;o00000_nV`^d2o`000004ojK2kOl0003o
Y/;]ojK2k@?o000000CoY/;]o`000?nV`^goY/;]0ol000001?nV`^go0000ojK2kOnV`^d3o`000004
ojK2kOl0003oY/;]ojK2k@?o00000_nV`^d3o`0000CoY/;]00?o0000oookJ_oonfX0<ooonfX00ol0
003ooo]ZoookJP0ZoookJP00:ooonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z02ko
oo]Z1?l00002ojK1k@Co00000_nV`Nd2o`0000?oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`0000?o
Y/7]0ol000001onV`Ngo0000o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@07o`000?nV`Ngo
0000o`000?nV`Ngo0000ojK1k@03o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000?oY/7]
0ol00002ojK1k@Co00000_nV`Nd2o`0000?oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`0000;oY/7]
0ol000001onV`Ngo0000o`000?l0003oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@02o`00
00;oY/7]00Go0000ojK1kOl0003o0000ojK1k@04o`0000;oY/7]1?l00002ojK1k@?o00000onV`Nd3
o`0000;oY/7]0_l00003ojK1k@?o00000onV`Nd3o`0000?oY/7]0ol00002ojK1k@?o000000OoY/7]
o`000?l0003o0000ojK1kOl0003oY/7]00?o000000?oY/7]o`000?oonfX0BOoonfX00ol0003ooo]Z
oookJP1JoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]Z
oookJP0OoookJP?o0000<ooonfX2o`0000KoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000;oY/;]
0_l00002ojK2k@03o`000?nV`^go000000;o000000CoY/;]o`000?nV`^goY/;]0ol000001?nV`^go
0000ojK2kOnV`^d3o`000004ojK2kOl0003oY/;]ojK2k@?o00000_nV`^d3o`0000CoY/;]0ol00004
ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00005ojK2k@;o00001OnV`^d2o`0000GoY/;]0_l00002
ojK2k@;o000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000oookJP0doookJP03o`000?oo
nf[ooo]Z02[ooo]Z000ZoookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0:ooonfX2
o`0000;oY/7]00Co0000ojK1kOl0003o00000_nV`Nd01Ol0003oY/7]o`000?l0003oY/7]00Co0000
0_nV`Nd3o`0000?oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]0ol00003ojK1k@?o0000
0_nV`Nd4o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@03o`00
0003ojK1kOl0003oY/7]00;o00000_nV`Nd01Ol0003oY/7]o`000?l0003oY/7]00Co00000_nV`Nd4
o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol00003ojK1k@?o00000onV`Nd3
o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@03o`000003ojK1
kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00_l000000onV`Ngo0000o`000002o`000003ojK1
kOl0003o000000?o00000_nV`Nd4o`0000;oY/7]0ol000000onV`Ngo0000o`000002o`0000;oY/7]
0ol00003ojK1k@?o0000BOoonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z04;ooo]Z
00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP0LoookJP?o0000<ooonfX3o`0000;oY/;]
0ol00004ojK2k@?o00001?nV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]
0_l00005ojK2k@;o00001OnV`^d2o`0000;oY/;]0_l000001?nV`^go0000ojK2kOnV`^d3o`000004
ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go0000
00;o000000CoY/;]o`000?nV`^goY/;]0ol00002ojK2k@?o00001?nV`^d2o`000003ojK2kOl0003o
Y/;]00;oY/;]0_l00005ojK2k@03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0:_oonfX0
02[ooo]Z00?o0000oookJ_oonfX0EOoonfX2o`0002Sooo]Z0ol00003ojK1k@?o00000onV`Nd3o`00
0003ojK1kOl0003o000000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]00?o000000?o
Y/7]o`000?nV`Nd00_l00002ojK1k@04o`000?nV`Ngo0000o`0000;oY/7]0ol00002ojK1k@Co0000
0_nV`Nd3o`0000?oY/7]0_l00002ojK1k@Co00000_nV`Nd3o`0000?oY/7]0ol00003ojK1k@?o0000
00?oY/7]o`000?l000000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00ol000000onV
`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00;o00000_nV`Nd3o`0000;oY/7]1?l00002ojK1
k@Co00000_nV`Nd2o`0000;oY/7]1?l00002ojK1k@?o00000onV`Nd3o`0000?oY/7]0ol000000onV
`Ngo0000o`000002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@03o`000003ojK1kOl0
003oY/7]00?o000000CoY/7]o`000?l0003o00000onV`Nd3o`0000;oY/7]1?l00002ojK1k@;o0000
BOoonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0
DooonfX00ol0003ooo]ZoookJP0IoookJP?o0000<_oonfX4o`0000;oY/;]0_l000001?nV`^go0000
ojK2kOnV`^d3o`000004ojK2kOl0003oY/;]ojK2k@?o000000CoY/;]o`000?nV`^goY/;]0ol00000
0onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l00003ojK2k@?o00000onV`^d2
o`0000GoY/;]0_l00005ojK2k@;o00001OnV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^go
Y/;]00?oY/;]0_l00002ojK2k@;o00000_nV`^d00ol0003oY/;]o`000002o`000004ojK2kOl0003o
Y/;]ojK2k@?o000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000oookJP0coookJP03o`00
0?oonf[ooo]Z02[ooo]Z000ZoookJP03o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX08_oo
nfX3o`0000;oY/7]1?l00002ojK1k@Co00000_nV`Nd2o`0000?oY/7]0ol00002ojK1k@Co00000_nV
`Nd3o`0000?oY/7]0ol000001onV`Ngo0000o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@07
o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@03o`000004ojK1kOl0003o0000o`0000?oY/7]0ol0
0002ojK1k@Co00000_nV`Nd4o`0000;oY/7]0_l00003ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol0
0003ojK1k@?o000000OoY/7]o`000?l0003o0000ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV
`Nd00ol000000onV`Ngo0000ojK1k@03o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1
k@Co00000_nV`Nd4o`0000;oY/7]0_l00003ojK1k@?o000000?oY/7]o`000?l000000_l00003ojK1
k@?o000000OoY/7]o`000?l0003o0000ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00_l0
00000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003ooo]Z04Oooo]Z0ol0001IoookJP03o`000?oo
nf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0FoookJP?o0000<Ooo
nfX4o`0000CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]0_l00005ojK2k@;o00001OnV
`^d00ol0003oY/;]ojK2k@04ojK2k@04o`000?nV`^goY/;]ojK2k@;o000000?oY/;]o`000?nV`^d0
0ol00002ojK2k@03o`000?nV`^go000000;o000000CoY/;]o`000?nV`^goY/;]0ol000001?nV`^go
0000ojK2kOnV`^d3o`000004ojK2kOl0003oY/;]ojK2k@?o00000_nV`^d3o`0000CoY/;]00?o0000
ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@?o00001?nV`^d2o`0000GoY/;]00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0ZoookJP00:_oonfX00ol0003ooo]ZoookJP1Hoook
JP03o`000?oonf[ooo]Z01kooo]Z0ol000000onV`Ngo0000ojK1k@02o`0000;oY/7]00Co0000ojK1
kOl0003o00000_nV`Nd01Ol0003oY/7]o`000?l0003oY/7]00Co00000_nV`Nd3o`0000?oY/7]0ol0
0002ojK1k@Co000000CoY/7]o`000?l0003o00000onV`Nd3o`0000?oY/7]0ol00002ojK1k@?o0000
00OoY/7]o`000?l0003o0000ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00_l00002ojK1
k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@03o`000003ojK1kOl0003o000000;o00000_nV
`Nd3o`0000?oY/7]0ol00002ojK1k@Co000000CoY/7]o`000?l0003o00000onV`Nd3o`0000;oY/7]
1?l00002ojK1k@?o000000OoY/7]o`000?l0003o0000ojK1kOl0003oY/7]00?o000000?oY/7]o`00
0?nV`Nd00_l000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`00
0?l000000_l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0_l00003ojK1k@?o00000onV`Nd3o`00
00;oY/7]0ol00003ojK1k@?o0000A?oonfX3o`0000;ooo]Z00?o0000oookJ_oonfX0EooonfX00ol0
003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z053ooo]Z0_l0000EoookJP?o0000<OoonfX3o`00
0004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go
000000;o00000_nV`^d00ol0003oY/;]o`000002o`0000;oY/;]0ol00004ojK2k@?o00001?nV`^d2
o`0000GoY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d2
o`0000GoY/;]0_l00002ojK2k@;o000000CoY/;]o`000?nV`^goY/;]0ol000001?nV`^go0000ojK2
kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000_nV`^d5o`0000;oY/;]0ol00004ojK2k@03o`00
0?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0:OoonfX002[ooo]Z00?o0000oookJ_oonfX0FOoo
nfX00ol0003ooo]ZoookJP0JoookJPCo00000_nV`Nd3o`0000?oY/7]0ol00003ojK1k@?o000000?o
Y/7]o`000?l000000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00ol000000onV`Ngo
0000ojK1k@02o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd4o`0000;oY/7]0ol00002ojK1k@?o
00000_nV`Nd3o`0000?oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`000006ojK1kOl0003o0000ojK1
kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00;o000000?oY/7]
o`000?l000000_l00002ojK1k@Co00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@;o00000onV`Nd3
o`0000?oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo0000
ojK1k@03o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000
o`000002o`0000;oY/7]1?l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0_l00010oookJP?o0000
1OoonfX00ol0003ooo]ZoookJP1GoookJP03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX0
CooonfX00ol0003ooo]ZoookJP0AoookJP?o0000<OoonfX3o`0000GoY/;]0_l00005ojK2k@03o`00
0?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@02o`0000;oY/;]
00?o0000ojK2kOl000000_l00002ojK2k@03o`000?nV`^go000000;o000000CoY/;]o`000?nV`^go
Y/;]0ol000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000onV`^d3o`00
00CoY/;]0ol00003ojK2k@;o00001OnV`^d2o`0000GoY/;]0_l00005ojK2k@03o`000?nV`^goY/;]
00CoY/;]00?o0000ojK2kOnV`^d00_l00002ojK2k@03o`000?nV`^go000000;o000000?oY/;]o`00
0?oonfX0<_oonfX00ol0003ooo]ZoookJP0YoookJP00:_oonfX00ol0003ooo]ZoookJP1JoookJP03
o`000?oonf[ooo]Z01Kooo]Z0ol00003ojK1k@?o00000_nV`Nd4o`0000;oY/7]1?l000001?nV`Ngo
0000o`000?l00003ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000001onV`Ngo0000o`000?l0003o
Y/7]o`000?nV`Nd00_l00002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@03o`000003
ojK1kOl0003oY/7]00;o00000_nV`Nd3o`0000;oY/7]1?l00002ojK1k@Co00000_nV`Nd3o`0000?o
Y/7]0_l00002ojK1k@?o00000onV`Nd3o`0000?oY/7]0ol000000onV`Ngo0000o`000002ojK1k@07
o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00?o000000?oY/7]
o`000?nV`Nd00_l000000onV`Ngo0000o`000002o`0000;oY/7]1?l00002ojK1k@?o00000onV`Nd3
o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00003ojK1k@?o00000_nV`Nd3o`000007ojK1kOl0
003o0000o`000?nV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV
`Nd00_l000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003o000003cooo]Z0ol00008oookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP1>oookJP;o
00003ooonfX3o`00037ooo]Z0ol00002ojK2k@03o`000?nV`^go000000;o00000_nV`^d00ol0003o
Y/;]o`000002o`000004ojK2kOl0003oY/;]ojK2k@?o00000_nV`^d3o`0000CoY/;]00?o0000ojK2
kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00005ojK2
k@;o00001OnV`^d01?l0003oY/;]ojK2kOnV`^d2o`000004ojK2kOl0003oY/;]ojK2k@?o000000?o
Y/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go000000;o000000CoY/;]o`000?nV`^goY/;]
0ol000001?nV`^go0000ojK2kOnV`^d3o`0000;oY/;]0ol00003ojK2k@;o00001_nV`^d00ol0003o
Y/;]ojK2k@03ojK2k@03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0:OoonfX002Wooo]Z
00?o0000oookJ_oonfX0G?oonfX00ol0003ooo]ZoookJP0CoookJP;o000000?oY/7]o`000?nV`Nd0
0ol000000onV`Ngo0000ojK1k@02o`0000;oY/7]00Co0000ojK1kOl0003o00000_nV`Nd3o`0000;o
Y/7]1?l00002ojK1k@?o00000onV`Nd3o`0000;oY/7]0ol00002ojK1k@?o00000onV`Nd3o`0000;o
Y/7]1?l00002ojK1k@?o000000OoY/7]o`000?l0003o0000ojK1kOl0003oY/7]00;o00000_nV`Nd0
1ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03o`000004ojK1
kOl0003o0000o`0000;oY/7]1?l00002ojK1k@Co00000_nV`Nd2o`0000?oY/7]0ol00002ojK1k@?o
00000onV`Nd3o`0000?oY/7]0ol000000onV`Ngo0000o`000002ojK1k@07o`000?nV`Ngo0000o`00
0?nV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00?o000000CoY/7]o`000?l0003o00000_nV
`Nd4o`0000;oY/7]1?l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol00003ojK1k@?o00000onV
`Nd3o`0000;oY/7]0ol000001_nV`Ngo0000o`000?l0003oY/;]o`0003Wooo]Z0ol0000;oookJP03
o`000?oonf[ooo]Z05Oooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003ooo]ZoookJP1=oookJP03
o`000?oonf[ooo]Z00_ooo]Z0ol0000boookJP;o00001_nV`^d00ol0003oY/;]ojK2k@04ojK2k@03
o`000?nV`^goY/;]00?oY/;]0_l00002ojK2k@;o00000_nV`^d00ol0003oY/;]o`000002o`000004
ojK2kOl0003oY/;]ojK2k@?o000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03
o`0000?oY/;]0ol00003ojK2k@?o00001?nV`^d2o`0000GoY/;]0_l00005ojK2k@03o`000?nV`^go
Y/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]0_l00002ojK2k@;o000000CoY/;]
o`000?nV`^goY/;]1Ol00002ojK2k@?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?oo
nf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0:OoonfX002Wooo]Z00?o0000oookJ_oonfX0GOoonfX0
0ol0003ooo]ZoookJP0?oookJP?o00000_nV`Nd4o`0000;oY/7]1?l00002ojK1k@?o000000OoY/7]
o`000?l0003o0000ojK1kOl0003oY/7]00;o00000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`00
0?nV`Nd00ol000000onV`Ngo0000ojK1k@02o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`00
00?oY/7]0ol000000onV`Ngo0000o`000002o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`00
00;oY/7]0ol000001onV`Ngo0000o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@07o`000?nV
`Ngo0000o`000?nV`Ngo0000ojK1k@03o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;o
Y/7]1?l00002ojK1k@Co000000CoY/7]o`000?l0003o00000onV`Nd3o`0000;oY/7]0ol00003ojK1
k@?o000000OoY/7]o`000?l0003o0000ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV`Nd00ol0
00000onV`Ngo0000ojK1k@05o`000003ojK1kOl0003o000000;oY/7]0ol00002ojK1k@Co00000_nV
`Nd4o`0000;oY/7]0ol000001?nV`Ngo0000o`000?l00003ojK2k@?o0000=OoonfX3o`0000oooo]Z
00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z04cooo]Z
0_l00009oookJP?o0000<_oonfX3o`000004ojK2kOl0003oY/;]ojK2k@?o00000_nV`^d3o`0000Co
Y/;]0ol00004ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000Go
Y/;]0_l00005ojK2k@04o`000?nV`^goY/;]ojK2k@;o000000?oY/;]o`000?nV`^d00ol00002ojK2
k@03o`000?nV`^go000000;o000000CoY/;]o`000?nV`^goY/;]0ol000001?nV`^go0000ojK2kOnV
`^d3o`000004ojK2kOl0003oY/;]ojK2k@?o00000_nV`^d3o`0000CoY/;]0ol00003ojK2k@;o0000
1OnV`^d2o`0000?oY/;]00Co0000ojK2kOl0003o00001OnV`^d00ol0003oY/;]ojK2k@04ojK2k@03
o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0:OoonfX002Wooo]Z00?o0000oookJ_oonfX0
G_oonfX00ol0003ooo]ZoookJP0;oookJP?o00000_nV`Nd3o`0000?oY/7]0ol00003ojK1k@?o0000
0_nV`Nd3o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000001onV`Ngo0000
o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1
k@03o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`0000?oY/7]
0ol000000onV`Ngo0000o`000002o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`000006ojK1
kOl0003o0000ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@02o`0000;oY/7]00Go0000ojK1
kOl0003o0000ojK1k@04o`0000;oY/7]1?l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0_l00003
ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol00003ojK1k@?o000000OoY/7]o`000?l0003o0000ojK1
kOl0003oY/7]00;o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03o`000004ojK1
kOl0003o0000o`0000;oY/7]1?l00002ojK2k@;o0000<OoonfX3o`0001;ooo]Z00?o0000oookJ_oo
nfX0E_oonfX00ol0003ooo]ZoookJP1;oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oookJ_oo
nfX01OoonfX3o`0003?ooo]Z0_l00005ojK2k@;o00000_nV`^d2o`0000;oY/;]00?o0000ojK2kOl0
00000_l000001?nV`^go0000ojK2kOnV`^d3o`000004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]
o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go000000;o00000_nV`^d3o`0000CoY/;]0_l00005
ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]0_l00005
ojK2k@;o00000_nV`^d2o`000004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d00ol0
0002ojK2k@03o`000?nV`^go000000;o000000CoY/;]o`000?nV`^goY/;]1?l000001?nV`^go0000
o`000?l00004ojK2k@?o00001?nV`^d00ol0003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z02Wo
oo]Z000YoookJP03o`000?oonf[ooo]Z05oooo]Z00?o0000oookJ_oonfX01ooonfX3o`000003ojK1
kOl0003oY/7]00;o00000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00ol000000onV
`Ngo0000ojK1k@02o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`0000?oY/7]0ol000000onV
`Ngo0000o`000002o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`000006ojK1kOl0003o0000
ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@02o`0000;oY/7]00Oo0000ojK1kOl0003o0000
ojK1kOl0003oY/7]00?o000000CoY/7]o`000?l0003o00000onV`Nd3o`0000;oY/7]1?l00002ojK1
k@?o00000_nV`Nd3o`0000;oY/7]0ol00003ojK1k@?o00000onV`Nd3o`000006ojK1kOl0003o0000
ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00;o000000?o
Y/7]o`000?nV`Nd00ol000000onV`Ngo0000o`000002o`0000;oY/7]0ol00003ojK1k@?o00000_nV
`Nd8o`0000?oY/7]0ol00002ojK1k@?o00000onV`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo
0000ojK1k@02o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?oonfX0;?oonfX4o`0001Go
oo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z04[o
oo]Z00?o0000oookJ_oonfX00_oonfX3o`0003?ooo]Z0ol00002ojK2k@?o00001?nV`^d00ol0003o
Y/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00005ojK2k@;o00001OnV`^d00ol0003o
Y/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00;o00000_nV`^d00ol0003oY/;]o`000002o`000004
ojK2kOl0003oY/;]ojK2k@?o000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03
o`0000?oY/;]0ol00004ojK2k@?o00000onV`^d2o`0000GoY/;]0_l00005ojK2k@03o`000?nV`^go
Y/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000;oY/;]0_l000001?nV`^go0000ojK2kOnV
`^d3o`000004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?oonfX0;_oonfX00ol0003ooo]Z
oookJP0YoookJP00:OoonfX00ol0003ooo]ZoookJP1PoookJP03o`000?oonf[ooo]Z00?ooo]Z1?l0
0002ojK1k@?o00000onV`Nd3o`0000;oY/7]1?l00002ojK1k@?o000000OoY/7]o`000?l0003o0000
ojK1kOl0003oY/7]00;o00000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00ol00000
1?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol00003ojK1k@;o00000_nV
`Nd3o`0000?oY/7]0ol00003ojK1k@?o00000_nV`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo
0000ojK1k@03o`000003ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo
0000o`000002o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd4o`0000;oY/7]0_l00002ojK1k@Co
00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@Co000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd3
o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00_l000000onV`Ngo0000o`000002
o`0000;oY/7]1?l00002ojK1k@?o00000_nV`Nd4o`000004ojK1kOl0003o0000o`0000?oY/7]0ol0
0002ojK2k@?o00000onV`^d3o`0002Wooo]Z0ol0000IoookJP03o`000?oonf[ooo]Z05Gooo]Z00?o
0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP19oookJPGo0000<_oonfX4o`0000;oY/;]0_l0
00001?nV`^go0000ojK2kOnV`^d3o`000004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV
`^d00ol00002ojK2k@03o`000?nV`^go000000;o00000_nV`^d3o`0000CoY/;]0ol00004ojK2k@03
o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]0_l00005ojK2k@04
o`000?nV`^goY/;]ojK2k@;o000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03
o`0000;oY/;]00?o0000ojK2kOl000000_l000001?nV`^go0000ojK2kOnV`^d3o`000004ojK2kOl0
003oY/;]ojK2k@?o00000_nV`^d3o`0000CoY/;]00Co0000ojK2kOnV`^go00000_nV`^d2o`0000Go
Y/;]0_l00005ojK2k@03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0:OoonfX002Wooo]Z
00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]Zo`000002o`0000?oY/7]0ol00002ojK1k@Co0000
0_nV`Nd3o`0000?oY/7]0ol000000onV`Ngo0000o`000002o`0000;oY/7]0ol00003ojK1k@?o0000
0_nV`Nd4o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@02o`00
0003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol000001?nV`Ngo0000o`000?l00002
ojK1k@Co00000_nV`Nd4o`0000;oY/7]0ol000000onV`Ngo0000o`000002o`0000;oY/7]0ol00003
ojK1k@?o00000_nV`Nd4o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0ol000000onV`Ngo0000
ojK1k@02o`0000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]00?o000000CoY/7]o`00
0?l0003o00000onV`Nd3o`0000;oY/7]1?l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol00003
ojK1k@?o00000onV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0ol000000onV`Ngo0000
ojK1k@03o`000003ojK1kOl0003oY/7]00;o000000?oY/7]o`000?l000000_l00002ojK1k@Co0000
0_nV`Nd3o`0000;oY/;]1?l00002ojK2k@;o00009OoonfX3o`0001cooo]Z00?o0000oookJ_oonfX0
EOoonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z04Oooo]Z0ol0000aoookJPCo0000
1?nV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d0
1?nV`^d00ol0003oY/;]ojK2k@02o`0000;oY/;]00?o0000ojK2kOl000000_l00002ojK2k@03o`00
0?nV`^go000000;o000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03o`0000;o
Y/;]00?o0000ojK2kOl000000_l00003ojK2k@?o00000onV`^d2o`0000GoY/;]0_l00005ojK2k@03
o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]0_l00002ojK2k@;o
000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2
kOl000000_l000001?nV`^go0000ojK2kOnV`^d3o`0000;oY/;]00?o0000oookJ_oonfX0;?oonfX0
0ol0003ooo]ZoookJP0XoookJP00:?oonfX00ol0003ooo]ZoookJP1RoookJP;o000000?oY/7]o`00
0?nV`Nd00ol000000onV`Ngo0000ojK1k@02o`0000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0
003oY/7]00?o000000CoY/7]o`000?l0003o00000onV`Nd3o`0000;oY/7]1?l00002ojK1k@?o0000
0_nV`Nd3o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000001onV`Ngo0000
o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1
k@03o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]
0ol00002ojK1k@?o00000onV`Nd3o`0000?oY/7]0ol00002ojK1k@?o000000OoY/7]o`000?l0003o
0000ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00_l000000onV`Ngo0000ojK1k@03o`00
0003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]1?l00002ojK1k@Co000000CoY/7]o`00
0?l0003o00000_nV`Nd3o`000003ojK1kOl0003oY/7]00?o00000onV`Nd3o`000006ojK1kOl0003o
0000ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@03o`000003ojK2kOl0003oY/;]00;o0000
00?oY/;]o`000?nV`^d00ol000000onV`^go0000o`00000QoookJP?o00007ooonfX00ol0003ooo]Z
oookJP1EoookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0@ooonfX3o`000003oook
J_l0003ooo]Z02kooo]Z0ol000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o
00000_nV`^d00ol0003oY/;]o`000002o`0000?oY/;]0ol00003ojK2k@?o00001?nV`^d00ol0003o
Y/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000Go
Y/;]00?o0000ojK2kOnV`^d01?nV`^d01?l0003oY/;]ojK2kOnV`^d2o`000003ojK2kOl0003oY/;]
00?o00000_nV`^d00ol0003oY/;]o`000002o`000004ojK2kOl0003oY/;]ojK2k@?o000000CoY/;]
o`000?nV`^goY/;]0ol00002ojK2k@?o00001?nV`^d3o`0000?oY/;]0_l00005ojK2k@;o00001OnV
`^d00ol0003oY/;]o`000004ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00002ojK2k@;o000000?o
Y/;]o`000?oonfX0;OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX00ol0003ooo]ZoookJP1O
oookJP?o00000_nV`Nd4o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`000006ojK1kOl0003o
0000ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@02o`0000;oY/7]00Go0000ojK1kOl0003o
0000ojK1k@04o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`0000?oY/7]0ol000000onV`Ngo
0000o`000002o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`000006ojK1kOl0003o0000ojK1
kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@02o`0000;oY/7]00Go0000ojK1kOl0003o0000ojK1
k@04o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd4o`0000;oY/7]0ol000000onV`Ngo0000o`00
0002o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`000006ojK1kOl0003o0000ojK1kOl0003o
Y/7]0ol000000onV`Ngo0000ojK1k@02o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?l0
00000_l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]1?l00002ojK1k@;o00000_nV`Nd3o`0000?o
Y/7]0ol00003ojK2k@?o00000_nV`^d3o`000006ojK2kOl0003o0000o`000?nV`^go00007_oonfX3
o`0002;ooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oonf[o
oo]Z03oooo]Z0ol00004oookJP03o`000?oonf[ooo]Z02_ooo]Z0_l00005ojK2k@;o00001OnV`^d0
0ol0003oY/;]ojK2k@04ojK2k@04o`000?nV`^goY/;]ojK2k@;o000000?oY/;]o`000?nV`^d00ol0
0002ojK2k@03o`000?nV`^go000000;o000000CoY/;]o`000?nV`^goY/;]0ol000001?nV`^go0000
ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000onV`^d3o`0000?oY/;]0ol00004ojK2k@;o
00001OnV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00005ojK2k@;o
00000_nV`^d2o`000004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d00ol00002ojK2
k@03o`000?nV`^go000000;o000000CoY/;]o`000?nV`^goY/;]0ol00002ojK2k@?o00001?nV`^d3
o`0000?oY/;]0_l00005ojK2k@03o`000?oonf[ooo]Z02_ooo]Z00?o0000oookJ_oonfX0:?oonfX0
02Sooo]Z00?o0000oookJ_oonfX0G?oonfX3o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`00
00;oY/7]0ol00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol00003ojK1k@?o000000?oY/7]o`00
0?l000000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@07o`000?nV
`Ngo0000o`000?nV`Ngo0000ojK1k@03o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1
k@Co00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o00000onV`Nd3o`0000?oY/7]0ol000001_nV
`Ngo0000o`000?nV`Ngo0000ojK1k@?o000000?oY/7]o`000?nV`Nd00_l00002ojK1k@07o`000?nV
`Ngo0000o`000?nV`Ngo0000ojK1k@03o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1
k@Co00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o00000onV`Nd3o`0000;oY/7]1?l000001_nV
`Ngo0000o`000?nV`Ngo0000ojK1k@?o000000?oY/7]o`000?nV`Nd00_l00002ojK1k@07o`000?nV
`Ngo0000o`000?nV`Ngo0000ojK1k@03o`000004ojK1kOl0003o0000o`0000;oY/7]1?l00002ojK1
k@Co00000_nV`^d3o`000004ojK2kOl0003o0000o`0000?oY/;]0ol0000JoookJP?o00009_oonfX0
0ol0003ooo]ZoookJP1DoookJP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0>ooonfX3
o`0000Oooo]Z00?o0000oookJ_oonfX0:?oonfX3o`000003ojK2kOl0003oY/;]00?o00000_nV`^d0
0ol0003oY/;]o`000002o`0000?oY/;]0ol00003ojK2k@;o00001OnV`^d00ol0003oY/;]ojK2k@04
ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00005ojK2k@;o00001OnV`^d01?l0003oY/;]ojK2kOnV
`^d2o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`000004ojK2kOl0
003oY/;]ojK2k@?o000000CoY/;]o`000?nV`^goY/;]0ol00002ojK2k@?o00001?nV`^d3o`0000?o
Y/;]0_l00005ojK2k@;o00001OnV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?o
Y/;]0_l00002ojK2k@;o000000CoY/;]o`000?l0003oY/;]0ol000000onV`^go0000ojK2k@03o`00
00;oY/;]00?o0000ojK2kOl000000_l000000onV`^go0000oookJP0/oookJP03o`000?oonf[ooo]Z
02Sooo]Z000XoookJP03o`000?oonf[ooo]Z05Wooo]Z0ol000000onV`Ngo0000ojK1k@02o`0000;o
Y/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]00;o00000_nV`Nd01Ol0003oY/7]o`000?l0
003oY/7]00Co00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@Co000000CoY/7]o`000?l0003o0000
0onV`Nd3o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`000006ojK1kOl0003o0000ojK1kOl0
003oY/7]0ol000000onV`Ngo0000ojK1k@02o`0000;oY/7]00Go0000ojK1kOl0003o0000ojK1k@04
o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd4o`000004ojK1kOl0003o0000o`0000;oY/7]1?l0
0002ojK1k@?o00000onV`Nd3o`0000;oY/7]0ol000001onV`Ngo0000o`000?l0003oY/7]o`000?nV
`Nd00ol000000onV`Ngo0000ojK1k@02o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?l0
00000_l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd3o`0000?o
Y/7]0ol00003ojK1k@?o00000_nV`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo0000ojK1k@02
o`0000;oY/7]00Oo0000ojK1kOl0003o0000ojK2kOl0003oY/;]00?o000000CoY/;]o`000?l0003o
00000_nV`^d4o`0000;oY/;]0_l0000FoookJP?o0000:OoonfX00ol0003ooo]ZoookJP1DoookJP03
o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0=ooonfX3o`0000[ooo]Z00?o0000oookJ_oo
nfX09OoonfX3o`0000GoY/;]00?o0000ojK2kOnV`^d01?nV`^d01?l0003oY/;]ojK2kOnV`^d2o`00
0003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`000004ojK2kOl0003oY/;]
ojK2k@?o000000?oY/;]o`000?nV`^d00ol00003ojK2k@?o00001?nV`^d3o`0000?oY/;]0_l00005
ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]0_l00002
ojK2k@;o000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03o`0000;oY/;]00?o
0000ojK2kOl000000_l000001?nV`^go0000ojK2kOnV`^d3o`000004ojK2kOl0003oY/;]ojK2k@?o
00000_nV`^d3o`0000?oY/;]0_l00005ojK2k@;o00001OnV`^d00ol0003oY/;]ojK2k@04ojK2k@03
o`000?nV`^goY/;]00?oY/;]0_l0000[oookJP03o`000?oonf[ooo]Z02Sooo]Z000XoookJP03o`00
0?oonf[ooo]Z05Kooo]Z1?l00002ojK1k@?o00000onV`Nd3o`0000;oY/7]1?l00002ojK1k@?o0000
00?oY/7]o`000?l000000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00ol000000onV
`Ngo0000ojK1k@02o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]1?l00002ojK1
k@?o00000_nV`Nd3o`0000;oY/7]1?l00002ojK1k@?o00000onV`Nd3o`000006ojK1kOl0003o0000
ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@02o`0000;oY/7]00Go0000ojK1kOl0003o0000
ojK1k@04o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000000onV`Ngo0000
o`000002o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`000006ojK1kOl0003o0000ojK1kOl0
003oY/7]0ol000000onV`Ngo0000ojK1k@02o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`00
0?l000000_l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`00
0004ojK1kOl0003o0000o`0000?oY/7]0ol00003ojK1k@?o00000_nV`^d3o`000007ojK2kOl0003o
0000o`000?nV`^go0000ojK2k@02o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?oonfX0
4_oonfX3o`0002cooo]Z00?o0000oookJ_oonfX0E?oonfX00ol0003ooo]ZoookJP1DoookJP03o`00
0?oonf[ooo]Z03?ooo]Z0ol0000=oookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00003ojK1k@?o0000
1?nV`^d3o`0000?oY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d0
0onV`^d2o`0000GoY/;]00Co0000ojK2kOnV`^goY/;]0_l000001?nV`^go0000ojK2kOnV`^d3o`00
0003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`000004ojK2kOl0003oY/;]
ojK2k@?o00000_nV`^d3o`0000CoY/;]0ol00003ojK2k@;o00001OnV`^d2o`0000GoY/;]00?o0000
ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d2o`0000;oY/;]0_l00000
0onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l000001?nV`^go0000ojK2kOnV
`^d3o`000004ojK2kOl0003oY/;]ojK2k@?o00000_nV`^d3o`0000CoY/;]00?o0000oookJ_oonfX0
:?oonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX00ol0003ooo]ZoookJP1CoookJP?o00000onV
`Nd3o`0000;oY/7]1?l00002ojK1k@?o00000onV`Nd3o`000003ojK1kOl0003o000000;o00000_nV
`Nd3o`0000;oY/7]1?l00002ojK1k@?o000000OoY/7]o`000?l0003o0000ojK1kOl0003oY/7]00;o
00000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@05o`000?nV`Ngo
0000o`000?nV`Nd01?l00002ojK1k@?o00000onV`Nd3o`0000;oY/7]1?l000001?nV`Ngo0000o`00
0?l00002ojK1k@Co00000_nV`Nd3o`0000?oY/7]0ol000000onV`Ngo0000o`000002ojK1k@07o`00
0?nV`Ngo0000o`000?nV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00;o000000?oY/7]o`00
0?nV`Nd00ol000001?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol00002
ojK1k@?o00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@Co000000KoY/7]o`000?l0003oY/7]o`00
0?nV`Nd3o`000003ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000
ojK1k@03o`000004ojK1kOl0003o0000o`0000;oY/7]1?l00002ojK1k@Co00000_nV`Nd3o`000004
ojK2kOl0003o0000o`0000?oY/;]0ol00002ojK2k@?o00000onV`^d3o`0000kooo]Z1?l0000_oook
JP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0EOoonfX00ol0003ooo]ZoookJP0_oook
JP?o00004?oonfX00ol0003ooo]ZoookJP0OoookJP?o00000onV`Nd2o`000004ojK2kOl0003oY/;]
ojK2k@?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go000000;o000000CoY/;]
o`000?nV`^goY/;]0ol00002ojK2k@?o00001?nV`^d3o`0000?oY/;]0_l00005ojK2k@;o00001OnV
`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00002ojK2k@;o000000Co
Y/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl00000
0_l000001?nV`^go0000ojK2kOnV`^d3o`000004ojK2kOl0003oY/;]ojK2k@?o00000_nV`^d3o`00
00CoY/;]0ol00003ojK2k@;o00001OnV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]
00;oY/;]0ol00005ojK2k@;o00000_nV`^d2o`000004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]
o`000?oonfX0:OoonfX00ol0003ooo]ZoookJP0XoookJP00:?oonfX00ol0003ooo]ZoookJP1Aoook
JP;o00000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@07o`000?nV
`Ngo0000o`000?nV`Ngo0000ojK1k@03o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1
k@?o00000onV`Nd3o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000?oY/7]0ol00002ojK1
k@?o00000onV`Nd3o`000003ojK1kOl0003o000000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0
003oY/7]00?o000000?oY/7]o`000?nV`Nd00_l00002ojK1k@?o00000_nV`Nd3o`0000?oY/7]0ol0
0002ojK1k@Co000000CoY/7]o`000?l0003o00000onV`Nd3o`0000;oY/7]0ol00003ojK1k@?o0000
0_nV`Nd4o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@02o`00
0003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd4o`00
00;oY/7]0ol00002ojK1k@?o00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@?o00000onV`Nd3o`00
0007ojK1kOl0003o0000o`000?nV`Ngo0000ojK1k@02o`000003ojK1kOl0003oY/7]00?o000000?o
Y/7]o`000?nV`Nd00ol000001?nV`^go0000o`000?l00002ojK2k@Co00000_nV`^d3o`0000;oY/;]
1?l000001?nV`^go0000o`000?l0000:oookJP?o0000<ooonfX00ol0003ooo]ZoookJP1DoookJP03
o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0:ooonfX3o`0001?ooo]Z00?o0000oookJ_oo
nfX06ooonfX4o`0000CoY/7]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV
`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00000_nV`^d2o`000004ojK2kOl0003oY/;]ojK2
k@?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go000000;o00000_nV`^d00ol0
003oY/;]o`000002o`000004ojK2kOl0003oY/;]ojK2k@?o00000_nV`^d3o`0000CoY/;]00?o0000
ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03
ojK2k@;o00001OnV`^d2o`0000;oY/;]0_l000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0
003oY/;]00?o000000CoY/;]o`000?nV`^goY/;]0ol000001?nV`^go0000ojK2kOnV`^d3o`0000;o
Y/;]0ol000001?nV`^go0000ojK2kOnV`^d3o`0000?oY/;]0_l00005ojK2k@;o00001OnV`^d00ol0
003ooo]ZoookJP0WoookJP03o`000?oonf[ooo]Z02Sooo]Z000WoookJP03o`000?oonf[ooo]Z04oo
oo]Z0ol00003ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol00002ojK1k@Co000000KoY/7]o`000?l0
003oY/7]o`000?nV`Nd3o`000003ojK1kOl0003oY/7]00;o00000_nV`Nd01Ol0003oY/7]o`000?l0
003oY/7]00?o00000onV`Nd3o`0000;oY/7]1?l00002ojK1k@?o000000?oY/7]o`000?l000000ol0
00001?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000001onV`Ngo0000
o`000?l0003oY/7]o`000?nV`Nd00_l000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]
00;o00000_nV`Nd3o`0000;oY/7]1?l00002ojK1k@?o00000_nV`Nd4o`000003ojK1kOl0003o0000
00;o00000_nV`Nd3o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`000006ojK1kOl0003o0000
ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@02o`000003ojK1kOl0003oY/7]00?o000000?o
Y/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000000onV`Ngo0000o`00
0003o`000007ojK1kOl0003o0000o`000?nV`Ngo0000ojK1k@03o`0000;oY/7]0ol00003ojK1k@?o
000000OoY/;]o`000?l0003o0000ojK2kOl0003oY/;]00;o000000?oY/;]o`000?nV`^d00ol00000
0onV`^go0000ojK2k@02o`000003ojK2kOl0003o000000;o00000_nV`^d2o`0000Kooo]Z0ol0000f
oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0F?oonfX00ol0003ooo]ZoookJP0W
oookJP?o00005_oonfX00ol0003ooo]ZoookJP0HoookJP?o000000CoY/7]o`000?nV`NgoY/7]0ol0
00000onV`Ngo0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l00002ojK2k@?o00001?nV
`^d3o`0000CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d01?nV
`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00002ojK2k@;o000000Co
Y/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl00000
0_l000001?nV`^go0000ojK2kOnV`^d3o`0000;oY/;]0ol00004ojK2k@?o00000onV`^d2o`0000Go
Y/;]0_l00005ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00005ojK2k@;o00000_nV`^d2o`000004
ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d00ol000001?nV`^go0000ojK2kOnV`^d3
o`000004ojK2kOl0003oY/;]ojK2k@?o00000_nV`^d00ol0003ooo]ZoookJP0WoookJP03o`000?oo
nf[ooo]Z02Oooo]Z000WoookJP03o`000?oonf[ooo]Z04cooo]Z0ol00002ojK1k@Co00000_nV`Nd3
o`0000?oY/7]0ol000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd3
o`0000?oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@?o000000?oY/7]o`000?nV`Nd0
0_l00002ojK1k@05o`000?nV`Ngo0000o`000?nV`Nd00ol00003ojK1k@?o00000_nV`Nd4o`0000;o
Y/7]0ol00002ojK1k@Co000000CoY/7]o`000?l0003o00000onV`Nd3o`0000;oY/7]1?l00002ojK1
k@?o000000OoY/7]o`000?l0003o0000ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV`Nd00ol0
00000onV`Ngo0000ojK1k@02o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]1?l0
00000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@?o00000onV`Nd3o`0000;oY/7]1?l0
00001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@?o000000?oY/7]o`000?nV`Nd00_l000000onV`Ngo
0000ojK1k@03o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`00
0003ojK1kOl0003o000000?o000000CoY/7]o`000?l0003o00000onV`^d3o`0000;oY/;]0ol00003
ojK2k@?o000000KoY/;]o`000?l0003oY/;]o`000?nV`^d3o`000003ojK2kOl0003ooo]Z00;ooo]Z
0ol0000ioookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]Z
oookJP0SoookJP?o00006OoonfX00ol0003ooo]ZoookJP0FoookJP;o00001OnV`Nd2o`0000GoY/7]
00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@02o`0000;oY/;]00?o0000ojK2kOl00000
0_l000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003o
Y/;]o`000002o`000004ojK2kOl0003oY/;]ojK2k@?o00000_nV`^d3o`0000CoY/;]0ol00004ojK2
k@03o`000?nV`^goY/;]00?oY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2
kOnV`^d00onV`^d2o`0000;oY/;]0_l000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003o
Y/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`000004ojK2kOl0003oY/;]ojK2k@?o00000_nV
`^d3o`0000CoY/;]0ol00003ojK2k@;o00001OnV`^d2o`0000;oY/;]00Co0000ojK2kOnV`^go0000
1OnV`^d2o`0000GoY/;]0_l00002ojK2k@;o000000?oY/;]o`000?oonfX0:?oonfX00ol0003ooo]Z
oookJP0WoookJP009ooonfX00ol0003ooo]ZoookJP1:oookJP;o000000?oY/7]o`000?nV`Nd00_l0
0002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@03o`000004ojK1kOl0003o0000o`00
00?oY/7]0ol00002ojK1k@?o00000onV`Nd3o`000003ojK1kOl0003o000000?o000000CoY/7]o`00
0?l0003o00000_nV`Nd4o`0000;oY/7]0ol00003ojK1k@?o000000?oY/7]o`000?l000000_nV`Nd0
1ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@05o`000?nV`Ngo0000o`000?nV
`Nd01?l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol00003ojK1k@?o000000CoY/7]o`000?l0
003o00000onV`Nd3o`0000;oY/7]1?l00002ojK1k@?o000000OoY/7]o`000?l0003o0000ojK1kOl0
003oY/7]00;o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@02o`0000;oY/7]0ol0
0002ojK1k@Co00000_nV`Nd3o`0000;oY/7]1?l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol0
0003ojK1k@?o00000_nV`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo0000ojK1k@03o`000003
ojK1kOl0003o000000;o000000?oY/7]o`000?l000000ol000001?nV`Ngo0000o`000?l00002ojK1
k@Co00000_nV`Nd4o`0000;oY/;]0ol000000onV`^go0000o`000003o`000004ojK2kOl0003o0000
o`0000;oY/;]0ol00003ojK2k@Go0000??oonfX00ol0003ooo]ZoookJP1CoookJP03o`000?oonf[o
oo]Z05[ooo]Z00?o0000oookJ_oonfX07ooonfX3o`0001cooo]Z00?o0000oookJ_oonfX04ooonfX3
o`000003ojK1kOl0003oY/7]00?o00000onV`Nd3o`0000?oY/;]0ol00004ojK2k@03o`000?nV`^go
Y/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d01?nV`^d0
0ol0003oY/;]ojK2k@03ojK2k@;o00000_nV`^d2o`0000;oY/;]00?o0000ojK2kOl000000_l00000
1?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`00
0002o`0000;oY/;]0ol00004ojK2k@?o00001?nV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV
`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00002ojK2k@;o000000Co
Y/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl00000
0_l000001?nV`^go0000ojK2kOnV`^d3o`0000;oY/;]0ol00004ojK2k@?o00000onV`^d2o`0000Go
Y/;]00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0WoookJP009ooonfX00ol0003ooo]Z
oookJP17oookJP?o00000_nV`Nd4o`0000;oY/7]0ol00002ojK1k@Co000000KoY/7]o`000?l0003o
Y/7]o`000?nV`Nd3o`000003ojK1kOl0003oY/7]00;o00000_nV`Nd01Ol0003oY/7]o`000?l0003o
Y/7]00?o00000onV`Nd3o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd4o`000004ojK1kOl0003o
0000o`0000?oY/7]0ol00002ojK1k@?o00000onV`Nd3o`000003ojK1kOl0003o000000;oY/7]00Oo
0000ojK1kOl0003o0000ojK1kOl0003oY/7]00;o00000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]
o`000?nV`Nd00ol000001?nV`Ngo0000o`000?l00002ojK1k@Co00000_nV`Nd3o`0000?oY/7]0ol0
00001?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000001onV`Ngo0000
o`000?l0003oY/7]o`000?nV`Nd00_l000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]
00;o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1
k@Co00000_nV`Nd3o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1k@Co00000_nV`Nd7
o`000003ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV`Nd00ol000000onV`^go0000ojK2k@03
o`000004ojK2kOl0003o0000o`0000;oY/;]1?l00002ojK2k@?o00000_nV`^d4o`000004ojK2kOl0
003o0000o`0003kooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1KoookJP03o`00
0?oonf[ooo]Z01_ooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z00oooo]Z1?l00005ojK1k@04o`00
0?nV`NgoY/7]ojK1k@;o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go000000;o
00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o00000onV`^d3o`0000Co
Y/;]0ol00003ojK2k@?o00001?nV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?o
Y/;]0_l00005ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00_l00002ojK2k@03
o`000?nV`^go000000;o000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03o`00
00;oY/;]00?o0000ojK2kOl000000_l00002ojK2k@?o00001?nV`^d3o`0000CoY/;]00?o0000ojK2
kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2
k@;o000000KoY/;]o`000?l0003o0000ojK2kOl00002ojK2k@?o000000?oY/;]o`000?nV`^d00ol0
00001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003ooo]Z02Oooo]Z00?o0000oookJ_oonfX0
9ooonfX002Oooo]Z00?o0000oookJ_oonfX0A?oonfX3o`0000;oY/7]0ol00003ojK1k@?o000000?o
Y/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol00003ojK1k@?o000000Ko
Y/7]o`000?l0003oY/7]o`000?nV`Nd3o`000003ojK1kOl0003oY/7]00;o00000_nV`Nd01ol0003o
Y/7]o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol00002
ojK1k@Co000000CoY/7]o`000?l0003o00000onV`Nd3o`0000;oY/7]0ol00003ojK1k@?o00000_nV
`Nd4o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l00002ojK1k@07o`000?nV`Ngo0000o`00
0?nV`Ngo0000ojK1k@03o`000004ojK1kOl0003o0000o`0000;oY/7]1?l00002ojK1k@?o00000onV
`Nd3o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1k@?o00000onV`Nd3o`0000;oY/7]
1?l000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@?o000000?oY/7]o`000?nV`Nd00_l000000onV
`Ngo0000ojK1k@03o`000004ojK1kOl0003o0000o`0000;oY/7]1?l00002ojK1k@Co00000_nV`Nd3
o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]0ol00003ojK2k@?o000000OoY/;]
o`000?l0003o0000ojK2kOl0003oY/;]00;o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000
ojK2k@02o`000003ojK2kOl0003o000000;o00000_nV`^d2o`0003gooo]Z00?o0000oookJ_oonfX0
D_oonfX00ol0003ooo]ZoookJP1LoookJP03o`000?oonf[ooo]Z01Oooo]Z0ol0000RoookJP03o`00
0?oonf[ooo]Z00_ooo]Z1?l00004ojK1k@?o00001?nV`Nd00ol0003oY/;]ojK2k@03ojK2k@03o`00
0?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@04o`00
0?nV`^goY/;]ojK2k@;o000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03o`00
00;oY/;]00?o0000ojK2kOl000000_l000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003o
Y/;]00?o00000onV`^d3o`0000?oY/;]0ol00004ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000
ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@02
o`000004ojK2kOl0003oY/;]ojK2k@?o000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000
ojK2k@03o`000004ojK2kOl0003oY/;]ojK2k@?o00000_nV`^d3o`0000CoY/;]0ol00003ojK2k@?o
00001?nV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000oookJ_oo
nfX09OoonfX00ol0003ooo]ZoookJP0WoookJP009ooonfX00ol0003ooo]ZoookJP11oookJP?o0000
00?oY/7]o`000?nV`Nd00_l00002ojK1k@05o`000?nV`Ngo0000o`000?nV`Nd00ol00003ojK1k@?o
00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@Co000000CoY/7]o`000?l0003o00000_nV`Nd4o`00
00;oY/7]0ol00003ojK1k@?o00000_nV`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo0000ojK1
k@02o`0000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]00;o00000_nV`Nd3o`0000;o
Y/7]1?l00002ojK1k@?o00000_nV`Nd4o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;o
Y/7]0ol00003ojK1k@?o00000_nV`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo0000ojK1k@02
o`0000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]00?o000000CoY/7]o`000?l0003o
00000_nV`Nd4o`0000;oY/7]0ol00002ojK1k@Co000000?oY/7]o`000?l000000_l00002ojK1k@?o
00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@?o000000OoY/7]o`000?l0003o0000ojK1kOl0003o
Y/7]00;o00000_nV`Nd4o`000003ojK1kOl0003oY/7]00?o000000CoY/7]o`000?l0003o00000_nV
`Nd4o`0000;oY/7]0ol00002ojK1k@Co000000CoY/;]o`000?l0003o00000onV`^d3o`0000;oY/;]
0ol00003ojK2k@?o000000KoY/;]o`000?l0003oY/;]o`000?nV`^d3o`000003ojK2kOl0003ooo]Z
03cooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z
01?ooo]Z0ol0000UoookJP03o`000?oonf[ooo]Z00Sooo]Z0ol00002ojK1k@03o`000?nV`Ngo0000
00;o000000CoY/7]o`000?nV`NgoY/7]0ol000000onV`Ngo0000ojK2k@03o`0000;oY/;]00?o0000
ojK2kOl000000_l00002ojK2k@?o00001?nV`^d3o`0000CoY/;]00?o0000ojK2kOnV`^d00onV`^d2
o`0000GoY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d0
1?l0003oY/;]ojK2kOnV`^d2o`000003ojK2kOl0003oY/;]00?o000000CoY/;]o`000?nV`^goY/;]
0ol000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000_nV`^d3o`0000Co
Y/;]0ol00004ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00005ojK2k@;o00001OnV`^d00ol0003o
Y/;]ojK2k@03ojK2k@;o00000_nV`^d2o`000004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`00
0?nV`^d00ol00002ojK2k@Go000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03
o`0000?oY/;]0ol00003ojK2k@03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX09ooonfX0
02Kooo]Z00?o0000oookJ_oonfX0?ooonfX4o`0000;oY/7]0ol00003ojK1k@?o000000?oY/7]o`00
0?l000000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@07o`000?nV
`Ngo0000o`000?nV`Ngo0000ojK1k@02o`0000;oY/7]0ol00002ojK1k@?o00000onV`Nd3o`0000;o
Y/7]1?l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000?o
Y/7]0ol00002ojK1k@?o000000OoY/7]o`000?l0003o0000ojK1kOl0003oY/7]00;o00000_nV`Nd0
1ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]
0ol00002ojK1k@Co000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000;oY/7]
0ol00003ojK1k@?o00000_nV`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo0000ojK1k@02o`00
0003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00_l00002ojK1k@?o00000_nV`Nd4o`00
00;oY/7]0ol00002ojK1k@Co000000?oY/7]o`000?l000000_l000001?nV`Ngo0000o`000?l00003
ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000001onV`Ngo0000o`000?l0003oY/7]o`000?nV`Nd0
0_l000000onV`Ngo0000o`000003o`000003ojK1kOl0003oY/7]00;o000000?oY/;]o`000?l00000
0_l00002ojK2k@Co00000_nV`^d3o`0000;oY/;]1?l000001?nV`^go0000o`000?l00002ojK2k@?o
00000onV`^d3o`0003cooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1NoookJP03
o`000?oonf[ooo]Z00oooo]Z0ol0000XoookJP03o`000?oonf[ooo]Z00Kooo]Z0_l00006ojK1k@03
o`000?nV`NgoY/7]00?oY/7]0_l00005ojK1k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV
`^d00_l00002ojK2k@03o`000?nV`^go000000;o000000CoY/;]o`000?nV`^goY/;]0ol000000onV
`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l000001?nV`^go0000ojK2kOnV`^d3
o`0000;oY/;]0ol00004ojK2k@?o00000onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d00onV`^d2
o`0000GoY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00;o00000_nV`^d00ol0003oY/;]o`000002
o`000004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV
`^go000000;o00000_nV`^d3o`0000CoY/;]0ol00004ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l0
0005ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]00Co
0000ojK2kOnV`^goY/;]0_l000000onV`^go0000ojK2k@03o`000003ojK2kOl0003ooo]Z02Gooo]Z
00?o0000oookJ_oonfX09ooonfX002Kooo]Z00?o0000oookJ_oonfX0??oonfX3o`0000?oY/7]0ol0
00000onV`Ngo0000o`000003o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1k@?o0000
0onV`Nd3o`0000;oY/7]1?l000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o00000_nV`Nd01ol0
003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@?o00000_nV`Nd3o`0000?oY/7]0ol0
0002ojK1k@Co000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000;oY/7]0ol0
0003ojK1k@?o00000_nV`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo0000ojK1k@02o`000003
ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00_l00002ojK1k@?o00000_nV`Nd3o`0000?o
Y/7]0ol00002ojK1k@Co000000?oY/7]o`000?l000000_l000001?nV`Ngo0000o`000?l00003ojK1
k@?o00000_nV`Nd4o`0000;oY/7]0ol000001onV`Ngo0000o`000?l0003oY/7]o`000?nV`Nd00_l0
00000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00;o000000?oY/7]o`000?l000000_l0
0002ojK1k@?o00000_nV`Nd4o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`000004ojK1kOl0
003o0000o`0000?oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`000003ojK2kOl0003o000000;oY/;]
00Oo0000ojK2kOl0003o0000ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00_l000000onV
`^go0000o`000002o`0000;oY/;]0ol00002ojK2k@Co00000_nV`^d2o`0003_ooo]Z00?o0000oook
J_oonfX0D_oonfX00ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z00_ooo]Z0ol0000Zoook
JPGo00000_oonfX3o`0000;oY/7]00?o0000ojK1kOl000000_l000000onV`Ngo0000ojK1k@03o`00
00?oY/7]0ol00003ojK2k@?o00001?nV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]
00?oY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`00
00;oY/;]0_l000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000_nV`^d0
0ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o00000onV`^d3o`0000?oY/;]0ol00004
ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000
ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@02o`0000;oY/;]00?o0000ojK2kOl000000_l00000
1?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o000000CoY/;]o`000?nV`^goY/;]
0ol00002ojK2k@?o00000onV`^d4o`0000?oY/;]0ol00004ojK2k@;o00001OnV`^d00ol0003oY/;]
ojK2k@03ojK2k@;o00009?oonfX00ol0003ooo]ZoookJP0WoookJP009_oonfX00ol0003ooo]Zoook
JP0joookJP;o00000_nV`Nd01Ol0003oY/7]o`000?l0003oY/7]00?o00000onV`Nd3o`0000;oY/7]
1?l00002ojK1k@?o00000_nV`Nd4o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]
0ol00003ojK1k@?o00000_nV`Nd4o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l00002ojK1
k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@02o`0000;oY/7]0ol00002ojK1k@?o00000onV
`Nd3o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o00000_nV
`Nd3o`0000;oY/7]1?l00002ojK1k@?o000000OoY/7]o`000?l0003o0000ojK1kOl0003oY/7]00;o
000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@02o`000003ojK1kOl0003o000000;o
00000_nV`Nd3o`0000;oY/7]1?l00002ojK1k@?o00000_nV`Nd4o`000004ojK1kOl0003o0000o`00
00?oY/7]0ol00002ojK1k@?o00000onV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0ol0
00000onV`Ngo0000ojK1k@02o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`0000;oY/7]0ol0
0002ojK1k@Co00000_nV`Nd3o`000003ojK1kOl0003o000000?o000000CoY/7]o`000?l0003o0000
0onV`^d3o`0000;oY/;]0ol00003ojK2k@?o000000KoY/;]o`000?l0003oY/;]o`000?nV`^d3o`00
0003ojK2kOl0003oY/;]00;o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000o`00000joook
JP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0HOoonfX00ol0003ooo]ZoookJP07oook
JP?o0000;?oonfX00ol0003o]Yfno`000003oij;_`;o00001_nV`Nd00ol0003oY/7]ojK1k@03ojK1
k@04o`000?nV`NgoY/7]ojK1k@;o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go
000000;o00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o00000onV`^d3
o`0000?oY/;]0ol00004ojK2k@?o00001?nV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d0
0ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00Co0000ojK2kOnV`^goY/;]0_l0
00000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l000001?nV`^go0000ojK2
kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000onV`^d3o`0000?oY/;]0ol00004ojK2k@03o`00
0?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d0
0onV`^d2o`0000;oY/;]0_l000001?nV`^go0000ojK2kOnV`^d5o`000004ojK2kOl0003o0000o`00
00;oY/;]00?o0000ojK2kOl000000_l000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003o
Y/;]00?o00000onV`^d00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z02Oooo]Z000Voook
JP03o`000?oonf[ooo]Z03Oooo]Z1?l00002ojK1k@?o000000?oY/7]o`000?l000000_nV`Nd01ol0
003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo
0000ojK1k@02o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]1?l000000onV`Ngo
0000o`000002o`0000;oY/7]0ol00002ojK1k@?o00000onV`Nd3o`0000;oY/7]0ol000001onV`Ngo
0000o`000?l0003oY/7]o`000?nV`Nd00_l000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003o
Y/7]00;o00000_nV`Nd3o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd3o`0000;oY/7]1?l00000
1?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000000onV`Ngo0000o`00
0002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@02o`0000;oY/7]00Go0000ojK1kOl0
003o0000ojK1k@04o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`000003ojK1kOl0003o0000
00?o000000CoY/7]o`000?l0003o00000_nV`Nd4o`0000;oY/7]0ol00002ojK1k@Co000000KoY/7]
o`000?l0003oY/7]o`000?nV`Nd3o`000003ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV`Nd0
0ol000001?nV`Ngo0000o`000?l00002ojK1k@Co00000_nV`^d4o`0000;oY/;]0ol000000onV`^go
0000o`000003o`000004ojK2kOl0003o0000o`0000;oY/;]0ol00003ojK2k@?o00000_nV`^d3o`00
0006ojK2kOl0003o0000o`000?nV`^go0000>_oonfX00ol0003ooo]ZoookJP1AoookJP03o`000?oo
nf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX00ooonfX3o`0002kooo]Z00Co0000okJM__nfWKko0000
1?nNRkl4o`0000CoY/7]0ol00004ojK1k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d0
1?nV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00Co0000ojK2kOnV`^go
Y/;]0_l000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l000001?nV`^go
0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`00
00;oY/;]0ol00004ojK2k@?o00000onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0
003oY/;]ojK2k@03ojK2k@;o00001OnV`^d01?l0003oY/;]ojK2kOnV`^d2o`000003ojK2kOl0003o
Y/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`000004ojK2kOl0003oY/;]ojK2k@?o000000?o
Y/;]o`000?nV`^d00ol00002ojK2k@?o00001?nV`^d3o`0000CoY/;]00?o0000ojK2kOnV`^d00onV
`^d2o`0000?oY/;]00?o0000ojK2kOl000001_nV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV
`^d01?l0003oY/;]ojK2kOnV`^d2o`000003ojK2kOl0003ooo]Z02?ooo]Z00?o0000oookJ_oonfX0
9_oonfX002Kooo]Z00?o0000oookJ_oonfX0=?oonfX3o`0000;oY/7]1?l000000onV`Ngo0000o`00
0002o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]1?l000001_nV`Ngo0000o`00
0?nV`Ngo0000ojK1k@;o00000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l00002
ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol00002ojK1k@Co000000?oY/7]o`000?l000000_l00000
0onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`000007ojK1kOl0003o
0000o`000?nV`Ngo0000ojK1k@02o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd0
0_l000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]
1?l000001?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd3o`0000?oY/7]0ol000001_nV`Ngo
0000o`000?nV`Ngo0000ojK1k@?o000000?oY/7]o`000?nV`Nd00_l000000onV`Ngo0000ojK1k@03
o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1k@?o00000onV`Nd3o`000003ojK1kOl0
003o000000?o000000CoY/7]o`000?l0003o00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@?o0000
00OoY/7]o`000?l0003o0000ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV`^d00ol000000onV
`^go0000ojK2k@03o`000004ojK2kOl0003o0000o`0000;oY/;]1?l00002ojK2k@?o00000_nV`^d4
o`000003ojK2kOl0003o000000;o000000CoY/;]o`000?l0003o00000onV`^d3o`0003[ooo]Z00?o
0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1SoookJP03o`000?oonf[o000000;o0000<?oo
nfX00ol0003o]YfnokJM_P02okJM_PCo00000_nV`Nd00ol0003oY/7]o`000002o`000004ojK1kOl0
003oY/7]ojK1k@?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go000000;o0000
0_nV`^d3o`0000CoY/;]0ol00004ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d0
1?nV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`00
0?nV`^goY/;]00;o00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o0000
0_nV`^d00ol0003oY/;]o`000002o`000004ojK2kOl0003oY/;]ojK2k@?o00000_nV`^d3o`0000Co
Y/;]0ol00003ojK2k@;o00001OnV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?o
Y/;]0_l00005ojK2k@03o`000?nV`^goY/;]00;o00000_nV`^d00ol0003oY/;]o`000002o`000004
ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go0000
00;o00000_nV`^d3o`0000CoY/;]0ol00003ojK2k@?o00001?nV`^d2o`0000GoY/;]00?o0000oook
J_oonfX08OoonfX00ol0003ooo]ZoookJP0VoookJP009_oonfX00ol0003ooo]ZoookJP0boookJP;o
00000_nV`Nd3o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd3o`0000;oY/7]1?l000000onV`Ngo
0000o`000002o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]1?l000001_nV`Ngo
0000o`000?nV`Ngo0000ojK1k@;o00000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd0
0_l00002ojK1k@?o00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@?o00000_nV`Nd4o`000003ojK1
kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]1?l00002ojK1k@?o000000?oY/7]o`000?l00000
0_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@05o`000?nV`Ngo0000
o`000?nV`Nd01?l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000000onV`Ngo0000o`000003
o`000004ojK1kOl0003o0000o`0000;oY/7]1?l00002ojK1k@?o00000_nV`Nd4o`000006ojK1kOl0
003o0000ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@02o`000003ojK1kOl0003oY/7]00?o
000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@Co
000000?oY/7]o`000?l000000_l000001?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd4o`00
00;oY/;]0ol000001onV`^go0000o`000?l0003oY/;]o`000?nV`^d00_l000000onV`^go0000ojK2
k@03o`000003ojK2kOl0003oY/;]00;o000000?oY/;]o`000?l000000_l00002ojK2k@?o00000_nV
`^d4o`0000;oY/;]0_l0000ioookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0I?oo
nfX00ol0003ooo]ZoookJP0_oookJP;o00001?nfWKh2o`0000KoY/7]00?o0000ojK1kOnV`Nd00onV
`Nd2o`0000GoY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@02o`0000;oY/;]00?o
0000ojK2kOl000000_l000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o0000
0_nV`^d00ol0003oY/;]o`000002o`0000;oY/;]0ol00004ojK2k@?o00000onV`^d3o`0000CoY/;]
00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00CoY/;]
00?o0000ojK2kOnV`^d00onV`^d2o`0000;oY/;]0_l000001?nV`^go0000ojK2kOnV`^d3o`000003
ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`000004ojK2kOl0003oY/;]ojK2
k@?o00000_nV`^d3o`0000?oY/;]0ol00004ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2
kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@02o`00
0004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go
000000;o000000CoY/;]o`000?nV`^goY/;]0ol00002ojK2k@03o`000?oonf[ooo]Z023ooo]Z00?o
0000oookJ_oonfX09_oonfX002Gooo]Z00?o0000oookJ_oonfX0<?oonfX4o`000006ojK1kOl0003o
0000ojK1kOl0003oY/7]0_l00002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@02o`00
00;oY/7]0ol00002ojK1k@?o00000onV`Nd3o`0000;oY/7]0ol00003ojK1k@?o000000?oY/7]o`00
0?l000000_l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol00002ojK1k@Co000000KoY/7]o`00
0?l0003oY/7]o`000?nV`Nd2o`0000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]00;o
00000_nV`Nd3o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd3o`0000;oY/7]1?l000001?nV`Ngo
0000o`000?l00003ojK1k@?o00000_nV`Nd3o`0000?oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo
0000ojK1k@?o000000?oY/7]o`000?nV`Nd00_l000000onV`Ngo0000ojK1k@03o`000004ojK1kOl0
003o0000o`0000;oY/7]1?l00002ojK1k@?o00000onV`Nd3o`000003ojK1kOl0003o000000;o0000
0_nV`Nd3o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o000000?o0000
00KoY/7]o`000?l0003oY/7]o`000?nV`Nd3o`000003ojK1kOl0003oY/7]00;o000000?oY/7]o`00
0?l000000_l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000000onV`^go0000o`000003o`00
0004ojK2kOl0003o0000o`0000?oY/;]0ol00002ojK2k@?o00000onV`^d3o`000006ojK2kOl0003o
0000ojK2kOl0003oY/;]0ol000000onV`^go0000ojK2k@02o`000003ojK2kOl0003oY/;]00?o0000
00?oY/;]o`000?l00000>?oonfX00ol0003ooo]ZoookJP1@oookJP03o`000?oonf[ooo]Z06Cooo]Z
00?o0000oookJ_oonfX0;?oonfX3o`000004ojK1kOl0003o]YfnokJM_P;o00000_nV`Nd00ol0003o
Y/7]o`000002o`000003ojK1kOl0003oY/7]00?o00000onV`Nd3o`0000CoY/;]0ol00003ojK2k@03
o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV
`^d01?nV`^d00ol0003oY/;]ojK2k@02o`0000;oY/;]00?o0000ojK2kOl000000_l000000onV`^go
0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l000001?nV`^go0000ojK2kOnV`^d3o`00
0003ojK2kOl0003oY/;]00?o00000onV`^d3o`0000?oY/;]0ol00004ojK2k@03o`000?nV`^goY/;]
00?oY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`00
00;oY/;]0_l000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l000001?nV
`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000_nV`^d3o`0000CoY/;]0ol00004
ojK2k@03o`000?nV`^go000000?oY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000
ojK2kOnV`^d00onV`^d2o`0000;oY/;]0_l000000onV`^go0000oookJP0QoookJP03o`000?oonf[o
oo]Z02Kooo]Z000UoookJP03o`000?oonf[ooo]Z02cooo]Z1?l00002ojK1k@?o00000_nV`Nd4o`00
00;oY/7]0ol00002ojK1k@Co000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd2o`0000;oY/7]00Oo
0000ojK1kOl0003o0000ojK1kOl0003oY/7]00;o00000_nV`Nd01Ol0003oY/7]o`000?l0003oY/7]
00?o00000onV`Nd3o`0000;oY/7]0ol00003ojK1k@?o000000?oY/7]o`000?l000000_l00002ojK1
k@?o00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@?o000000OoY/7]o`000?l0003o0000ojK1kOl0
003oY/7]00;o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@02o`000003ojK1kOl0
003o000000;o00000_nV`Nd3o`0000;oY/7]1?l00002ojK1k@?o000000?oY/7]o`000?l000000ol0
00001?nV`Ngo0000o`000?l00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]1?l000001_nV`Ngo0000
o`000?nV`Ngo0000ojK1k@;o00000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00ol0
00001?nV`Ngo0000o`000?l00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]1?l000000onV`Ngo0000
o`000002o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]0ol00003ojK1k@?o0000
00KoY/7]o`000?l0003oY/7]o`000?nV`Nd3o`000003ojK1kOl0003oY/7]00;o000000?oY/7]o`00
0?nV`Nd00ol000001?nV`Ngo0000o`000?l00003ojK2k@?o00000_nV`^d4o`0000;oY/;]0ol00000
0onV`^go0000o`000003o`000004ojK2kOl0003o0000o`0000;oY/;]0ol00003ojK2k@?o00000_nV
`^d3o`000006ojK2kOl0003o0000o`000?nV`^go0000>?oonfX00ol0003ooo]ZoookJP1@oookJP03
o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0:_oonfX2o`0000GoY/7]00?o0000ojK1kOnV
`Nd01?nV`Nd00ol0003oY/7]ojK1k@03ojK1k@04o`000?nV`NgoY/7]ojK1k@;o000000CoY/;]o`00
0?nV`^goY/;]0ol000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l00000
0onV`^go0000ojK2k@03o`0000?oY/;]0ol00003ojK2k@?o00001?nV`^d00ol0003oY/;]ojK2k@04
ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03
ojK2k@;o00001OnV`^d01?l0003oY/;]ojK2kOnV`^d2o`000003ojK2kOl0003oY/;]00?o000000Co
Y/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl00000
0_l00002ojK2k@?o00001?nV`^d3o`0000?oY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00CoY/;]
00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d00_l00002ojK2k@03o`00
0?nV`^go000000;o000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03o`000004
ojK2kOl0003oY/;]ojK2k@?o00000_nV`^d3o`0000CoY/;]0ol00003ojK2k@;o00001OnV`^d00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Kooo]Z000UoookJP03o`000?oonf[ooo]Z02Wo
oo]Z0ol00003ojK1k@?o00000_nV`Nd3o`0000?oY/7]0ol000000onV`Ngo0000o`000002o`0000;o
Y/7]0ol00002ojK1k@?o00000onV`Nd3o`0000;oY/7]0ol00003ojK1k@?o000000KoY/7]o`000?l0
003oY/7]o`000?nV`Nd3o`000003ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV`Nd00ol00000
1?nV`Ngo0000o`000?l00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]1?l000000onV`Ngo0000o`00
0002o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]1?l00002ojK1k@?o000000?o
Y/7]o`000?l000000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@05
o`000?nV`Ngo0000o`000?nV`Nd00ol00003ojK1k@?o00000_nV`Nd3o`0000?oY/7]0ol000000onV
`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@?o00000onV`Nd3o`0000;oY/7]0ol000001onV
`Ngo0000o`000?l0003oY/7]o`000?nV`Nd00_l000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0
003oY/7]00;o000000?oY/7]o`000?l000000_l00002ojK1k@Co000000?oY/7]o`000?l000000_l0
0002ojK1k@?o000000?oY/7]o`000?l000000ol000001?nV`Ngo0000o`000?l00002ojK1k@?o0000
0onV`Nd3o`0000;oY/7]1?l000001_nV`Ngo0000o`000?nV`^go0000ojK2k@?o000000?oY/;]o`00
0?l000000_l000000onV`^go0000ojK2k@03o`000004ojK2kOl0003o0000o`0000;oY/;]1?l00002
ojK2k@?o000000?oY/;]o`000?l000000ol000000onV`^go0000o`000002o`000004ojK2kOl0003o
0000o`0000?oY/;]0ol0000goookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0I?oo
nfX00ol0003ooo]ZoookJP0WoookJP?o00000_nV`Nd3o`0000CoY/7]0ol00003ojK1k@?o00001?nV
`Nd00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV
`^goY/;]00?oY/;]00Co0000ojK2kOnV`^goY/;]0_l000000onV`^go0000ojK2k@03o`0000;oY/;]
00?o0000ojK2kOl000000_l000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o
00000_nV`^d3o`0000CoY/;]0ol00004ojK2k@?o00000onV`^d2o`0000GoY/;]00?o0000ojK2kOnV
`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@02o`000004
ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go0000
00;o000000CoY/;]o`000?nV`^goY/;]0ol00002ojK2k@?o00000onV`^d3o`0000CoY/;]00?o0000
ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d00ol0003oY/;]o`000003
ojK2k@;o00000_nV`^d2o`000004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d00ol0
00001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003ooo]Z023ooo]Z00?o0000oookJ_oonfX0
9_oonfX002Gooo]Z00?o0000oookJ_oonfX09ooonfX2o`0000;oY/7]00Oo0000ojK1kOl0003o0000
ojK1kOl0003oY/7]00;o00000_nV`Nd01Ol0003oY/7]o`000?l0003oY/7]00?o00000onV`Nd3o`00
00;oY/7]0ol00002ojK1k@Co000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000003o`00
0004ojK1kOl0003o0000o`0000;oY/7]1?l00002ojK1k@?o00000_nV`Nd4o`000006ojK1kOl0003o
0000ojK1kOl0003oY/7]0_l00002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@02o`00
00;oY/7]0ol00002ojK1k@?o00000onV`Nd3o`000003ojK1kOl0003o000000;o00000_nV`Nd4o`00
0004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1k@?o00000onV`Nd3o`000006ojK1kOl0003o
0000ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@02o`000003ojK1kOl0003oY/7]00?o0000
00CoY/7]o`000?l0003o00000_nV`Nd4o`0000;oY/7]0ol00002ojK1k@Co000000?oY/7]o`000?l0
00000_l000001?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd3o`0000?oY/7]0ol000001_nV
`Ngo0000o`000?nV`Ngo0000ojK1k@Go000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd3o`000004
ojK1kOl0003o0000o`0000;oY/7]1?l00002ojK1k@?o000000?oY/7]o`000?l000000ol000000onV
`Ngo0000o`000002o`0000;oY/7]0ol00002ojK2k@?o00000onV`^d3o`0000;oY/;]0ol000001onV
`^go0000o`000?l0003oY/;]o`000?nV`^d00_l000000onV`^go0000ojK2k@03o`000004ojK2kOl0
003o0000o`0000;oY/;]1?l00002ojK2k@?o00000_nV`^d4o`000004ojK2kOl0003o0000o`0003Ko
oo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z02?o
oo]Z1?l00002ojK1k@;o00000_nV`Nd00ol0003oY/7]o`000002o`000003ojK1kOl0003oY/7]00?o
00000_nV`Nd00ol0003oY/7]o`000002o`000003ojK2kOl0003oY/;]00?o00000onV`^d3o`0000?o
Y/;]0ol00004ojK2k@?o00001?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00Co
Y/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d00_l00002ojK2k@03
o`000?nV`^go000000;o000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03o`00
00;oY/;]00?o0000ojK2kOl000000_l00002ojK2k@?o00001?nV`^d3o`0000?oY/;]0ol00004ojK2
k@03o`000?nV`^goY/;]00?oY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2
kOnV`^d00onV`^d2o`0000;oY/;]0_l000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2
kOl000000_l000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000_nV`^d3
o`0000CoY/;]0ol00004ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00005ojK2k@03o`000?nV`^go
Y/;]00?oY/;]0_l00005ojK2k@03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX09_oonfX0
02Gooo]Z00?o0000oookJ_oonfX09?oonfX4o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`00
0006ojK1kOl0003o0000ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@02o`000003ojK1kOl0
003oY/7]00;o00000_nV`Nd3o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd3o`0000;oY/7]1?l0
00000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]1?l0
00001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o000000?oY/7]o`000?nV`Nd00ol000001?nV`Ngo
0000o`000?l00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`00
0003ojK1kOl0003o000000?o000000CoY/7]o`000?l0003o00000_nV`Nd4o`0000;oY/7]0ol00002
ojK1k@Co000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd2o`0000;oY/7]00Oo0000ojK1kOl0003o
0000ojK1kOl0003oY/7]00;o000000?oY/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd4o`00
0003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000ol000001?nV`Ngo0000o`000?l00002
ojK1k@Co00000_nV`Nd3o`0000;oY/7]1?l000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o0000
0_nV`Nd01Ol0003oY/7]o`000?l0003oY/7]00?o00000onV`Nd3o`0000;oY/7]1?l00002ojK1k@?o
000000?oY/;]o`000?l000000ol000000onV`^go0000o`000002o`000004ojK2kOl0003o0000o`00
00?oY/;]0ol00002ojK2k@?o000000OoY/;]o`000?l0003o0000ojK2kOl0003oY/;]00;o000000?o
Y/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@02o`000003ojK2kOl0003o000000;o00000_nV
`^d2o`0003Gooo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oo
nf[ooo]Z01oooo]Z1?l00004ojK1k@03o`000?nV`NgoY/7]00CoY/7]00?o0000ojK1kOnV`Nd00onV
`Nd00ol0003oY/7]ojK1k@04ojK1k@03o`000?nV`^goY/;]00?oY/;]00Co0000ojK2kOnV`^goY/;]
0_l000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l000001?nV`^go0000
ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`0000;o
Y/;]0ol00004ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?o
Y/;]0_l00005ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00_l000001?nV`^go
0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`00
0003ojK2kOl0003oY/;]00?o00000onV`^d3o`0000?oY/;]0ol00004ojK2k@?o00000onV`^d2o`00
00GoY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d00ol0
003oY/;]ojK2k@02o`0000;oY/;]00?o0000ojK2kOl000000_l000001?nV`^go0000o`000?nV`^d3
o`000003ojK2kOl0003oY/;]00?o000000CoY/;]o`000?nV`^goY/;]0ol00002ojK2k@?o00001?nV
`^d3o`0000?oY/;]00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0VoookJP009OoonfX0
0ol0003ooo]ZoookJP0QoookJP?o00000onV`Nd3o`000003ojK1kOl0003o000000;o00000_nV`Nd4
o`000004ojK1kOl0003o0000o`0000;oY/7]1?l00002ojK1k@?o00000_nV`Nd4o`000006ojK1kOl0
003o0000ojK1kOl0003oY/7]0_l00002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@02
o`0000;oY/7]0ol00002ojK1k@?o00000onV`Nd3o`0000;oY/7]0ol00002ojK1k@Co000000?oY/7]
o`000?l000000_l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]1?l000001_nV`Ngo0000o`000?nV
`Ngo0000ojK1k@;o00000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1
k@?o00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@?o00000_nV`Nd4o`000003ojK1kOl0003o0000
00;o00000_nV`Nd3o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o0000
00;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]00;o00000_nV`Nd3o`0000;oY/7]0ol0
0003ojK1k@?o00000_nV`Nd3o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`0000;oY/7]0ol0
0002ojK1k@?o00000onV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0ol000000onV`Ngo
0000ojK1k@02o`000003ojK1kOl0003oY/7]00?o000000CoY/7]o`000?l0003o00000_nV`^d4o`00
00;oY/;]0ol00002ojK2k@Co000000?oY/;]o`000?l000000_l000001?nV`^go0000o`000?l00003
ojK2k@?o00000_nV`^d3o`0000?oY/;]0ol000001_nV`^go0000o`000?nV`^go0000ojK2k@?o0000
00?oY/;]o`000?oonfX0=?oonfX00ol0003ooo]ZoookJP1?oookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX07?oonfX3o`0000;oY/7]00?o0000ojK1kOl000000_l00002ojK1k@03o`00
0?nV`Ngo000000;o000000?oY/7]o`000?nV`Nd00ol00003ojK1k@?o00000onV`Nd3o`0000CoY/;]
00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]
0_l00005ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00_l000001?nV`^go0000
ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`000003
ojK2kOl0003oY/;]00?o00000onV`^d3o`0000?oY/;]0ol00004ojK2k@03o`000?nV`^goY/;]00?o
Y/;]0_l00005ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d01?l0003o
Y/;]ojK2kOnV`^d2o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`00
0003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`0000;oY/;]0ol00004ojK2
k@?o00000onV`^d3o`0000CoY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2
k@;o00001OnV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00000_nV`^d2o`000004ojK2kOl0003oY/;]
ojK2k@?o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000oookJP0OoookJP03o`000?oonf[o
oo]Z02Gooo]Z000UoookJP03o`000?oonf[ooo]Z01oooo]Z0_l00002ojK1k@05o`000?nV`Ngo0000
o`000?nV`Nd00ol00003ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@Co000000?oY/7]
o`000?l000000_l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol00002ojK1k@Co000000KoY/7]
o`000?l0003oY/7]o`000?nV`Nd2o`0000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]
00;o000000?oY/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000000onV
`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]0ol000001onV
`Ngo0000o`000?l0003oY/7]o`000?nV`Nd00_l000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0
003oY/7]00;o000000?oY/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol0
00000onV`Ngo0000o`000003o`000003ojK1kOl0003o000000;o000000CoY/7]o`000?l0003o0000
0onV`Nd3o`0000;oY/7]0ol000001onV`Ngo0000o`000?l0003oY/7]o`000?nV`Nd00_l000000onV
`Ngo0000ojK1k@03o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l00002ojK1
k@?o00000_nV`Nd4o`0000;oY/7]0ol000000onV`Ngo0000o`000003o`000004ojK1kOl0003o0000
o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd3o`000007ojK1kOl0003o0000o`000?nV`^go0000
ojK2k@02o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?l000000_l000000onV`^go0000
o`000002o`0000;oY/;]0ol00002ojK2k@Co00000_nV`^d3o`000003ojK2kOl0003o000000?o0000
00CoY/;]o`000?l0003o00000_nV`^d3o`0000?oY/;]0ol0000eoookJP03o`000?oonf[ooo]Z04ko
oo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0JoookJP;o00001_nV`Nd00ol0003o
Y/7]ojK1k@04ojK1k@03o`000?nV`NgoY/7]00?oY/7]00Co0000ojK1kOnV`NgoY/7]0_l000000onV
`Ngo0000ojK1k@03o`0000;oY/;]00?o0000ojK2kOl000000_l000000onV`^go0000ojK2k@03o`00
00;oY/;]00?o0000ojK2kOl000000_l00002ojK2k@?o00001?nV`^d3o`0000?oY/;]0ol00004ojK2
k@03o`000?nV`^goY/;]00?oY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2
kOnV`^d00onV`^d01?l0003oY/;]ojK2kOnV`^d2o`000003ojK2kOl0003oY/;]00?o00000_nV`^d0
0ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002
o`0000;oY/;]0ol00004ojK2k@?o00000onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d01?nV`^d0
0ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00_l00002
ojK2k@03o`000?nV`^go000000;o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go
000000;o000000CoY/;]o`000?nV`^goY/;]0ol00002ojK2k@?o00000_nV`^d4o`0000CoY/;]0ol0
0003ojK2k@;o00001OnV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003ooo]Zoook
JP0MoookJP03o`000?oonf[ooo]Z02Gooo]Z000ToookJP03o`000?oonf[ooo]Z01gooo]Z1?l00002
ojK1k@?o000000?oY/7]o`000?l000000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd0
0_l000000onV`Ngo0000ojK1k@02o`0000;oY/7]0ol00002ojK1k@?o00000onV`Nd3o`0000;oY/7]
0ol00002ojK1k@Co000000?oY/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd3o`0000?oY/7]
0ol00002ojK1k@?o000000?oY/7]o`000?l000000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`00
0?nV`Nd00_l00002ojK1k@05o`000?nV`Ngo0000o`000?nV`Nd00ol00003ojK1k@?o00000_nV`Nd3
o`0000?oY/7]0ol000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o00000_nV`Nd3
o`0000;oY/7]1?l00002ojK1k@?o000000?oY/7]o`000?l000000_nV`Nd01ol0003oY/7]o`000?l0
003oY/7]o`000?nV`Nd00_l000000onV`Ngo0000ojK1k@03o`000004ojK1kOl0003o0000o`0000;o
Y/7]1?l00002ojK1k@?o00000_nV`Nd4o`000003ojK1kOl0003o000000;o000000CoY/7]o`000?l0
003o00000onV`Nd3o`0000;oY/7]0ol00002ojK1k@Co000000KoY/7]o`000?l0003oY/7]o`000?nV
`Nd3o`000003ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV`Nd00ol000001?nV`Ngo0000o`00
0?l00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`000004ojK1
kOl0003o0000o`0000?oY/;]0ol00002ojK2k@?o00000onV`^d6o`000003ojK2kOl0003oY/;]00?o
000000?oY/;]o`000?nV`^d00_l000000onV`^go0000ojK2k@03o`000004ojK2kOl0003o0000o`00
00;oY/;]1?l00002ojK2k@?o000000?oY/;]o`000?l000001_l0000eoookJP03o`000?oonf[ooo]Z
04kooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0GoookJP?o00000onV`Nd3o`00
00?oY/7]0ol00004ojK1k@?o00001?nV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`^goY/;]
00CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]
00;o00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0
003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o00000onV`^d3o`0000?oY/;]0ol00004ojK2
k@?o00001?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2
kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00;o00000_nV`^d00ol0
003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`00
0004ojK2kOl0003oY/;]ojK2k@?o00000_nV`^d3o`0000?oY/;]0ol00004ojK2k@03o`000?nV`^go
Y/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^go
Y/;]00?oY/;]0_l00002ojK2k@;o000000?oY/;]o`000?nV`^d01?l000000onV`^go0000ojK2k@03
o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`0000;oY/;]0ol00004
ojK2k@?o00000onV`^d00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z02Gooo]Z000Toook
JP03o`000?oonf[ooo]Z01Wooo]Z1?l00002ojK1k@Co000000?oY/7]o`000?l000000_l00002ojK1
k@?o00000_nV`Nd3o`0000;oY/7]1?l000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o00000_nV
`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@?o00000_nV`Nd3o`0000?o
Y/7]0ol00002ojK1k@?o000000?oY/7]o`000?l000000ol000000onV`Ngo0000o`000002o`000003
ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]1?l00002ojK1k@?o000000KoY/7]o`000?l0
003oY/7]o`000?nV`Nd3o`000003ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV`Nd00ol00000
1?nV`Ngo0000o`000?l00002ojK1k@?o00000onV`Nd3o`000003ojK1kOl0003o000000;o00000_nV
`Nd4o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1k@?o00000_nV`Nd4o`000006ojK1
kOl0003o0000ojK1kOl0003oY/7]0_l00002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1
k@02o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd4o`000003ojK1kOl0003o000000;o000000?o
Y/7]o`000?l000000ol000001?nV`Ngo0000o`000?l00002ojK1k@?o00000onV`Nd3o`0000;oY/7]
0ol000001onV`Ngo0000o`000?l0003oY/7]o`000?nV`Nd00_l000000onV`Ngo0000ojK1k@03o`00
0003ojK1kOl0003oY/7]00;o000000?oY/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd4o`00
0003ojK2kOl0003o000000;o000000?oY/;]o`000?l000000ol000001?nV`^go0000o`000?l00002
ojK2k@?o00000onV`^d3o`0000;oY/;]0ol000001onV`^go0000o`000?l0003oY/;]o`000?nV`^d0
0_l000000onV`^go0000ojK2k@07o`0000;oY/;]0ol00002ojK2k@;o0000=?oonfX00ol0003ooo]Z
oookJP1>oookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX05OoonfX3o`0000?oY/7]
0_l000000onV`Ngo0000ojK1k@03o`0000;oY/7]00?o0000ojK1kOl000000_l000001?nV`Ngo0000
ojK1kOnV`Nd3o`000003ojK1kOl0003oY/7]00?o00000onV`Nd3o`0000?oY/;]0ol00004ojK2k@?o
00000onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV
`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@04o`000?nV`^goY/;]ojK2k@;o000000?oY/;]o`00
0?nV`^d00ol00002ojK2k@03o`000?nV`^go000000;o000000CoY/;]o`000?nV`^goY/;]0ol00000
0onV`^go0000ojK2k@03o`0000;oY/;]0ol00004ojK2k@?o00001?nV`^d3o`0000?oY/;]00?o0000
ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000
ojK2kOnV`^d00onV`^d2o`0000;oY/;]0_l000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000
ojK2kOl000000_l000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000_nV
`^d3o`0000CoY/;]0ol00003ojK2k@;o00001OnV`^d01Ol0003oY/;]ojK2kOnV`^go000000;oY/;]
00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00;o0000
00CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03o`000003ojK2kOl0003ooo]Z01go
oo]Z00?o0000oookJ_oonfX09OoonfX002Cooo]Z00?o0000oookJ_oonfX05_oonfX3o`0000?oY/7]
0ol00002ojK1k@?o00000onV`Nd3o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l00000
0_l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol00002ojK1k@Co000000KoY/7]o`000?l0003o
Y/7]o`000?nV`Nd2o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00_l000001?nV
`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd3o`0000?oY/7]0ol000000onV`Ngo0000o`000002
o`0000;oY/7]1?l000001?nV`Ngo0000o`000?l00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]1?l0
00001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o00000_nV`Nd01Ol0003oY/7]o`000?l0003oY/7]
00?o00000_nV`Nd4o`0000;oY/7]0ol00002ojK1k@Co000000?oY/7]o`000?l000000_l000000onV
`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@?o00000onV`Nd3o`0000;oY/7]0ol000001onV
`Ngo0000o`000?l0003oY/7]o`000?nV`Nd00_l000000onV`Ngo0000ojK1k@02o`0000;oY/7]0ol0
0002ojK1k@Co000000?oY/7]o`000?l000000_l00002ojK1k@?o000000?oY/7]o`000?l000000ol0
00000onV`Ngo0000o`000002o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1k@?o0000
0onV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@02o`00
0003ojK2kOl0003o000000;o00000_nV`^d3o`0000;oY/;]1?l00002ojK2k@?o000000?oY/;]o`00
0?l000000ol000000onV`^go0000o`000002o`000004ojK2kOl0003o0000o`0000?oY/;]0ol00002
ojK2k@?o000000KoY/;]o`000?l0003oY/;]o`000?nV`^d3o`000003ojK2kOl0003oY/;]00;o0000
00?oY/;]o`000?oonfX0<ooonfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z06Cooo]Z
00?o0000oookJ_oonfX04OoonfX4o`0000CoY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]
ojK1k@04ojK1k@03o`000?nV`NgoY/7]00?oY/7]0_l00005ojK1k@04o`000?nV`NgoY/7]ojK1k@;o
000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go000000;o000000?oY/;]o`000?nV
`^d00ol00002ojK2k@03o`000?nV`^go000000;o00000_nV`^d3o`0000CoY/;]0ol00003ojK2k@?o
00001?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV
`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d00_l00002ojK2k@03o`000?nV`^go000000;o
000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03o`000004ojK2kOl0003oY/;]
ojK2k@?o00000_nV`^d3o`0000?oY/;]0ol00004ojK2k@?o00001?nV`^d00ol0003oY/;]ojK2k@03
ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000
ojK2kOnV`^d00_l000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000_nV
`^d00ol0003oY/;]o`000002o`000004ojK2kOl0003oY/;]ojK2k@?o00000_nV`^d3o`0000?oY/;]
0ol00004ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00?oY/;]
0_l0000LoookJP03o`000?oonf[ooo]Z02Gooo]Z000ToookJP03o`000?oonf[ooo]Z01Cooo]Z0_l0
0002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@02o`0000;oY/7]00Go0000ojK1kOl0
003o0000ojK1k@03o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd3o`0000;oY/7]1?l000000onV
`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000000onV
`Ngo0000o`000002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@02o`0000;oY/7]00Go
0000ojK1kOl0003o0000ojK1k@03o`0000;oY/7]1?l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]
1?l000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@?o00000onV`Nd3o`000006ojK1
kOl0003o0000ojK1kOl0003oY/7]0_l00002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1
k@02o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000000onV`Ngo0000o`00
0003o`000003ojK1kOl0003o000000;o000000CoY/7]o`000?l0003o00000onV`Nd3o`0000;oY/7]
0ol000001onV`Ngo0000o`000?l0003oY/7]o`000?nV`Nd01?l000000onV`Ngo0000o`000002ojK1
k@05o`000?nV`Ngo0000o`000?nV`Nd00ol00003ojK1k@?o00000_nV`Nd3o`0000;oY/7]1?l00000
0onV`Ngo0000o`000002o`000003ojK1kOl0003o000000?o000000CoY/7]o`000?l0003o00000_nV
`Nd3o`0000?oY/7]0ol000001_nV`^go0000o`000?nV`^go0000ojK2k@?o000000?oY/;]o`000?nV
`^d00_l000000onV`^go0000ojK2k@03o`000004ojK2kOl0003o0000o`0000;oY/;]1?l00002ojK2
k@?o00000_nV`^d9o`000004ojK2kOl0003o0000o`0000;oY/;]0ol00003ojK2k@?o00001?nV`^d0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0I?oonfX0
0ol0003ooo]ZoookJP0>oookJP?o00000_nV`Nd00ol0003oY/7]o`000002o`000003ojK1kOl0003o
Y/7]00?o00000onV`Nd3o`0000?oY/7]0ol00004ojK1k@?o00000onV`Nd2o`0000GoY/;]00?o0000
ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000
ojK2kOnV`^d00_l00002ojK2k@03o`000?nV`^go000000;o000000?oY/;]o`000?nV`^d00ol00002
ojK2k@03o`000?nV`^go000000;o000000?oY/;]o`000?nV`^d00ol00003ojK2k@?o00000onV`^d3
o`0000CoY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d2
o`0000GoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000;oY/;]0_l000000onV`^go0000ojK2k@03
o`0000;oY/;]00?o0000ojK2kOl000000_l000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0
003oY/;]00?o00000_nV`^d3o`0000CoY/;]0ol00003ojK2k@?o00001?nV`^d00ol0003oY/;]ojK2
k@03ojK2k@;o00001OnV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l0
00001onV`^go0000o`000?l0003oY/;]o`000?nV`^d00ol000001?nV`^go0000ojK2kOnV`^d3o`00
0003ojK2kOl0003oY/;]00?o000000CoY/;]o`000?nV`^goY/;]0ol00002ojK2k@?o00001?nV`^d0
0ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z02Gooo]Z000ToookJP03o`000?oonf[ooo]Z
017ooo]Z1?l00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000000onV`Ngo0000o`000002ojK1
k@03o`000?nV`Ngo000000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]00;o00000_nV
`Nd3o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o000000;o00000_nV
`Nd4o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]0ol00003ojK1k@?o000000Ko
Y/7]o`000?l0003oY/7]o`000?nV`Nd2o`0000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003o
Y/7]00;o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@Co000000?oY/7]o`000?l000000_l00000
0onV`Ngo0000o`000003o`000004ojK1kOl0003o0000o`0000;oY/7]0ol00003ojK1k@?o00000_nV
`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo0000ojK1k@02o`000003ojK1kOl0003oY/7]00;o
00000_nV`Nd01Ol0003oY/7]o`000?l0003oY/7]00?o00000onV`Nd3o`0000;oY/7]0ol00002ojK1
k@Co000000?oY/7]o`000?l000000_l000001?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd3
o`0000?oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@?o000000?oY/7]o`000?nV`Nd0
0_l000000onV`Ngo0000ojK1k@02o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd4o`000003ojK1
kOl0003o000000;o000000?oY/7]o`000?l000000ol000001?nV`Ngo0000o`000?l00002ojK2k@?o
00000onV`^d3o`0000;oY/;]0ol000001OnV`^go0000o`000?l0003oY/;]00Co000000?oY/;]o`00
0?nV`^d00ol000000onV`^go0000ojK2k@02o`000004ojK2kOl0003o0000o`0000;oY/;]1?l00002
ojK2k@?o000000?oY/;]o`000?l000000ol00003ojK2k@;o00000onV`^d00ol0003ooo]ZoookJP0`
oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0<
oookJP;o00001_nV`Nd00ol0003oY/7]ojK1k@03ojK1k@04o`000?nV`NgoY/7]ojK1k@;o000000?o
Y/7]o`000?nV`Nd00ol00002ojK1k@03o`000?nV`Ngo000000;o000000?oY/7]o`000?nV`Nd00ol0
0002ojK1k@03o`000?nV`^go000000;o000000CoY/;]o`000?nV`^goY/;]0ol00002ojK2k@?o0000
0onV`^d3o`0000CoY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`00
0?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d01?l0003oY/;]ojK2kOnV`^d2o`000003
ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o
00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o00000onV`^d3o`0000?o
Y/;]0ol00004ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003o
Y/;]ojK2k@03ojK2k@;o00001OnV`^d00ol0003oY/;]ojK2k@02o`0000;oY/;]00?o0000ojK2kOl0
00000_l000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l000000onV`^go
0000ojK2k@03o`0000?oY/;]0ol00003ojK2k@?o00001?nV`^d3o`0000?oY/;]0ol00004ojK2k@03
o`000?nV`^goY/;]00?oY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00002ojK2k@;o
000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000oookJP0JoookJP03o`000?oonf[ooo]Z
02Gooo]Z000ToookJP03o`000?oonf[ooo]Z00kooo]Z0ol00002ojK1k@Co000000?oY/7]o`000?l0
00000_l00002ojK1k@Co000000?oY/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd3o`0000;o
Y/7]1?l000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o00000_nV`Nd01ol0003oY/7]o`000?l0
003oY/7]o`000?nV`Nd00_l000001?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd3o`0000?o
Y/7]0ol000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000?o000000CoY/7]o`000?l0
003o00000_nV`Nd4o`0000;oY/7]0ol00002ojK1k@?o000000OoY/7]o`000?l0003o0000ojK1kOl0
003oY/7]00;o000000?oY/7]o`000?nV`Nd00_l00002ojK1k@?o00000_nV`Nd3o`0000?oY/7]0ol0
0002ojK1k@?o000000?oY/7]o`000?l000000ol000000onV`Ngo0000o`000002o`000003ojK1kOl0
003o000000;o00000_nV`Nd3o`0000;oY/7]0ol00003ojK1k@?o000000KoY/7]o`000?l0003oY/7]
o`000?nV`Nd3o`000003ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV`Nd00_l00002ojK1k@?o
00000_nV`Nd3o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000?o
000000CoY/7]o`000?l0003o00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@?o000000OoY/7]o`00
0?l0003o0000ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV`Nd00_l000000onV`Ngo0000o`00
0002o`0000;oY/7]0ol00002ojK1k@Co00000_nV`^d3o`000003ojK2kOl0003o000000?o000000?o
Y/;]o`000?l000000_l000001?nV`^go0000o`000?l00003ojK2k@?o00000_nV`^d3o`0000?oY/;]
1_l000000onV`^go0000ojK2k@02o`000003ojK2kOl0003oY/;]00?o000000CoY/;]o`000?l0003o
00000onV`^d3o`0000?oY/;]0_l00003ojK2k@03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oo
nfX0C_oonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z00Wooo]Z0ol00003ojK1k@?o
00000onV`Nd3o`0000CoY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@04ojK1k@03
o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd01?nV`Nd00ol0003oY/;]ojK2k@03ojK2k@;o
00000_nV`^d2o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`000004
ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@?o00001?nV`^d3o`00
00?oY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0
003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00Co0000ojK2kOnV`^goY/;]0_l00000
0onV`^go0000ojK2k@03o`000004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d00ol0
00001?nV`^go0000ojK2kOnV`^d3o`0000;oY/;]0ol00003ojK2k@?o00001?nV`^d00ol0003oY/;]
ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]
ojK2k@03ojK2k@04o`000?nV`^goY/;]ojK2k@;o000000?oY/;]o`000?nV`^d00ol000001?nV`^go
0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d01?l00002ojK2
k@?o00000onV`^d3o`0000CoY/;]0ol00004ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00005ojK2
k@03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX09OoonfX002?ooo]Z00?o0000oookJ_oo
nfX03_oonfX00ol0003oY/7]ojK1k@03o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd3o`0000;o
Y/7]1?l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;o
Y/7]1?l00002ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o000000;oY/7]00Oo0000ojK1kOl0
003o0000ojK1kOl0003oY/7]00;o00000_nV`Nd01Ol0003oY/7]o`000?l0003oY/7]00?o00000_nV
`Nd3o`0000?oY/7]0ol00002ojK1k@?o00000_nV`Nd4o`000003ojK1kOl0003o000000;o000000?o
Y/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd4o`000006ojK1kOl0003o0000ojK1kOl0003o
Y/7]0_l000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00;o000000CoY/7]o`000?l0
003o00000onV`Nd3o`0000;oY/7]0ol00003ojK1k@?o000000?oY/7]o`000?l000000_l000000onV
`Ngo0000o`000003o`000004ojK1kOl0003o0000o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd3
o`000007ojK1kOl0003o0000o`000?nV`Ngo0000ojK1k@02o`000003ojK1kOl0003oY/7]00?o0000
00CoY/7]o`000?l0003o00000_nV`Nd3o`0000;oY/7]1?l00002ojK1k@?o000000?oY/7]o`000?l0
00000ol000000onV`Ngo0000o`000002o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1
k@?o000000?oY/7]o`000?l000000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l0
00000onV`Ngo0000ojK2k@03o`000004ojK2kOl0003o0000o`0000;oY/;]1?l00002ojK2k@?o0000
0_nV`^d4o`000003ojK2kOl0003o000000;o000000?oY/;]o`000?l000001_l00003ojK2k@?o0000
0_nV`^d3o`000007ojK2kOl0003o0000o`000?nV`^go0000ojK2k@02o`000003ojK2kOl0003oY/;]
00?o000000?oY/;]o`000?nV`^d00_l00002ojK2k@03o`000?oonf[ooo]Z02oooo]Z00?o0000oook
J_oonfX0C?oonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z00Kooo]Z0ol00003ojK1
k@;o000000?oY/7]o`000?nV`Nd00ol00002ojK1k@03o`000?nV`Ngo000000;o000000?oY/7]o`00
0?nV`Nd00ol00002ojK1k@03o`000?nV`Ngo000000;o00000_nV`Nd3o`0000CoY/7]0ol00003ojK1
k@?o00001?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2
kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d00_l00002ojK2k@03o`000?nV`^go0000
00;o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go000000;o000000CoY/;]o`00
0?nV`^goY/;]0ol00002ojK2k@?o00000onV`^d3o`0000CoY/;]0ol00003ojK2k@;o00001OnV`^d0
0ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00000_nV`^d2
o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`000004ojK2kOl0003o
Y/;]ojK2k@?o00000_nV`^d3o`0000?oY/;]0ol00004ojK2k@?o00000onV`^d2o`0000GoY/;]00?o
0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000;oY/;]0_l0
00000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l000001?nV`^go0000ojK2
kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000_nV`^d3o`0000CoY/;]00?o0000oookJ_oonfX0
6?oonfX00ol0003ooo]ZoookJP0ToookJP008ooonfX00ol0003ooo]ZoookJP0;oookJP?o000000Ko
Y/7]o`000?l0003oY/7]o`000?nV`Nd2o`0000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003o
Y/7]00;o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o00000onV`Nd3o`000003ojK1kOl0003o
000000;o00000_nV`Nd4o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l00002
ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o0000
0_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@?o00000_nV`Nd3o`00
00;oY/7]0ol00002ojK1k@Co000000?oY/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd3o`00
00;oY/7]1?l00002ojK1k@?o000000?oY/7]o`000?l000000_nV`Nd01ol0003oY/7]o`000?l0003o
Y/7]o`000?nV`Nd00_l000000onV`Ngo0000ojK1k@03o`000004ojK1kOl0003o0000o`0000;oY/7]
0ol00003ojK1k@?o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000003o`000003ojK1
kOl0003o000000;o000000CoY/7]o`000?l0003o00000onV`Nd3o`0000;oY/7]0ol000001onV`Ngo
0000o`000?l0003oY/7]o`000?nV`Nd00_l000000onV`Ngo0000ojK1k@02o`0000;oY/7]00Go0000
ojK1kOl0003o0000ojK1k@03o`0000;oY/7]1?l00002ojK1k@?o000000?oY/7]o`000?l000000ol0
00000onV`Ngo0000o`000002o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1k@?o0000
0_nV`Nd3o`000007ojK2kOl0003o0000o`000?nV`^go0000ojK2k@02o`000003ojK2kOl0003oY/;]
00?o000000?oY/;]o`000?nV`^d00_l000000onV`^go0000o`000002o`0000;oY/;]0ol00002ojK2
k@?o000000?oY/;]o`000?l000000ol000000onV`^go0000o`000002o`000004ojK2kOl0003o0000
o`0000GoY/;]00?o0000ojK2kOnV`^d00_nV`^d00ol0003oY/;]ojK2k@03ojK2k@06o`000?nV`^go
Y/;]o`000?nV`^go0000<OoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z06Gooo]Z
00?o0000oookJ_oonfX00_oonfX4o`0000CoY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]
ojK1k@04ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd01?nV`Nd00ol0003oY/7]
ojK1k@02o`0000;oY/7]00?o0000ojK1kOl000000_l000000onV`Ngo0000ojK1k@03o`0000;oY/;]
00?o0000ojK2kOl000000_l000000onV`^go0000ojK2k@03o`0000?oY/;]0ol00003ojK2k@?o0000
1?nV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`00
0?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000;oY/;]0_l000000onV`^go0000
ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l000000onV`^go0000ojK2k@03o`0000;oY/;]
00?o0000ojK2kOl000000_l00002ojK2k@?o00001?nV`^d3o`0000?oY/;]0ol00004ojK2k@03o`00
0?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@;o0000
0_nV`^d2o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2
kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`0000;oY/;]0ol00004ojK2k@?o0000
0onV`^d3o`0000CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`00
0?nV`^goY/;]00?oY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00;o000000CoY/;]o`000?nV`^go
Y/;]0ol000000onV`^go0000oookJP0IoookJP03o`000?oonf[ooo]Z02Cooo]Z000SoookJP03o`00
0?oonf[ooo]Z00Wooo]Z0_l000000onU`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@?o0000
0_nV`Nd4o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l000000onV`Ngo0000ojK1k@02o`00
00;oY/7]00Go0000ojK1kOl0003o0000ojK1k@03o`0000?oY/7]0ol00002ojK1k@?o00000_nV`Nd3
o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`0000;oY/7]1?l000001?nV`Ngo0000o`000?l0
0002ojK1k@Co00000_nV`Nd3o`0000;oY/7]1?l000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o
000000?oY/7]o`000?nV`Nd00_l00002ojK1k@?o00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@?o
000000?oY/7]o`000?l000000_l00002ojK1k@Co000000CoY/7]o`000?l0003o00000onV`Nd3o`00
00;oY/7]0ol00002ojK1k@Co000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd2o`000003ojK1kOl0
003oY/7]00?o000000CoY/7]o`000?l0003o00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@?o0000
00?oY/7]o`000?l000000ol000000onV`Ngo0000o`000002o`000004ojK1kOl0003o0000o`0000?o
Y/7]0ol00002ojK1k@?o00000onV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l00000
0onV`Ngo0000ojK1k@03o`000004ojK1kOl0003o0000o`0000;oY/7]1?l00002ojK1k@?o00000_nV
`Nd4o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000001?nV`^go0000o`00
0?l00003ojK2k@?o00000_nV`^d3o`0000?oY/;]0ol000001_nV`^go0000o`000?nV`^go0000ojK2
k@?o000000?oY/;]o`000?l000000_l000001?nV`^go0000o`000?l00002ojK2k@Co00000_nV`^d3
o`0000?oY/;]0ol00003ojK2k@;o00000onV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d0
0ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z04cooo]Z00?o0000oookJ_oonfX0IOoonfX0
0ol0003ooo]ZoookJP02o`0000;oY/7]00?o0000ojK1kOl000000_l000000onV`Ngo0000ojK1k@03
o`0000?oY/7]0ol00003ojK1k@?o00001?nV`Nd3o`0000?oY/7]00?o0000ojK1kOnV`Nd01?nV`Nd0
0ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d0
1?l0003oY/;]ojK2kOnV`^d2o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`00
0002o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`0000;oY/;]0ol0
0004ojK2k@?o00000onV`^d3o`0000CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2
k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2
k@02o`0000;oY/;]00?o0000ojK2kOl000000_l000000onV`^go0000ojK2k@03o`000004ojK2kOl0
003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@?o00001?nV`^d3o`0000?oY/;]
0_l00005ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]
ojK2k@04ojK2k@03o`000?nV`^goY/;]00;o000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go
0000ojK2k@03o`000004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d00ol00002ojK2
k@?o00001?nV`^d3o`0000?oY/;]0ol00004ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00005ojK2
k@03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX09?oonfX002?ooo]Z00?o0000oookJ_oo
nfX02_oonfX2o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o
00000_nV`Nd3o`0000;oY/7]1?l00002ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o000000;o
Y/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV`Nd00_l00002
ojK1k@?o00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@?o000000?oY/7]o`000?l000000_l00002
ojK1k@Co000000?oY/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]1?l00000
1_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000
ojK1k@02o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1k@?o000000?oY/7]o`000?l0
00000ol000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;o
Y/7]0ol00002ojK1k@Co000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd2o`000003ojK1kOl0003o
Y/7]00?o000000?oY/7]o`000?nV`Nd00_l000001?nV`Ngo0000o`000?l00003ojK1k@Co000000Go
Y/7]o`000?l0003o0000ojK1k@05o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l00000
0ol000001?nV`Ngo0000o`000?l00002ojK1k@?o00000_nV`Nd4o`000006ojK1kOl0003o0000ojK1
kOl0003oY/7]0_l000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00;o000000?oY/7]
o`000?l000000_l00002ojK1k@?o00000_nV`Nd3o`000003ojK2kOl0003o000000?o000000?oY/;]
o`000?l000000_l000000onV`^go0000o`000003o`000004ojK2kOl0003o0000o`0000;oY/;]0ol0
0003ojK2k@Ko000000?oY/;]o`000?nV`^d00_l000000onV`^go0000ojK2k@03o`000003ojK2kOl0
003oY/;]00;o00000_nV`^d3o`0000?oY/;]0_l00003ojK2k@?o00000onV`^d2o`0000?oY/;]00?o
0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z06Gooo]Z0ol0
0005ojK1k@03o`000?nV`NgoY/7]00?oY/7]00Co0000ojK1kOnV`NgoY/7]0_l000000onV`Ngo0000
ojK1k@03o`0000;oY/7]00?o0000ojK1kOl000000_l000000onV`Ngo0000ojK1k@03o`0000;oY/7]
00?o0000ojK1kOl000000_l00002ojK1k@?o00001?nV`Nd3o`0000?oY/;]0ol00004ojK2k@03o`00
0?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`00
0?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00_l00002ojK2k@03o`000?nV`^go000000;o0000
00?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go000000;o000000?oY/;]o`000?nV`^d0
0ol00003ojK2k@?o00000onV`^d3o`0000CoY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00CoY/;]
00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d00ol0003oY/;]
ojK2k@02o`0000;oY/;]00?o0000ojK2kOl000000_l000000onV`^go0000ojK2k@03o`0000;oY/;]
00?o0000ojK2kOl000000_l000001?nV`^go0000ojK2kOnV`^d3o`0000;oY/;]0ol00003ojK2k@?o
00001?nV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d00ol0003oY/;]ojK2k@03ojK2k@;o
00001?nV`^d2o`0000;oY/;]0_l000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]
00?o000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03o`0000;oY/;]0ol00004
ojK2k@03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX09?oonfX002?ooo]Z00?o0000oook
J_oonfX03?oonfX2o`0000;oY/7]0ol00002ojK1k@?o00000onV`Nd3o`000003ojK1kOl0003o0000
00;o00000_nV`Nd4o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l00002ojK1
k@?o00000_nV`Nd3o`0000;oY/7]1?l000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o00000_nV
`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l000001?nV`Ngo0000o`000?l00003ojK1
k@?o00000_nV`Nd3o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o0000
00;o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`000006ojK1kOl0003o0000
ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@02o`000004ojK1kOl0003o0000o`0000?oY/7]
0ol00002ojK1k@?o00000_nV`Nd4o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l00000
0_l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]1?l00002ojK1k@?o000000KoY/7]o`000?l0003o
Y/7]o`000?nV`Nd5o`000004ojK1kOl0003o0000ojK1k@?o00000onV`Nd3o`0000;oY/7]0ol00002
ojK1k@Co000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002
ojK1k@?o00000_nV`Nd3o`0000?oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@?o0000
00?oY/7]o`000?nV`Nd00_l000001?nV`^go0000o`000?l00003ojK2k@?o00000_nV`^d3o`0000;o
Y/;]1?l000000onV`^go0000o`000002o`000003ojK2kOl0003o000000?o000000CoY/;]o`000?l0
003o00000_nV`^d3o`0000;oY/;]0ol00005ojK2k@07o`000?nV`^goY/;]o`000?nV`^go0000ojK2
k@03o`000003ojK2kOl0003oY/;]00;o00000_nV`^d3o`0000;oY/;]0ol00003ojK2k@03o`000?oo
nf[ooo]Z02cooo]Z00?o0000oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1QoookJPCo00000onV
`Nd3o`0000CoY/7]0_l00004ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd01?nV
`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00CoY/7]00?o0000ojK1kOnV`Nd00_l0
0002ojK1k@03o`000?nV`Ngo000000;o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV
`^go000000;o000000?oY/;]o`000?nV`^d00ol00003ojK2k@?o00000onV`^d3o`0000CoY/;]0ol0
0003ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2
k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00Co0000ojK2kOnV`^goY/;]0_l000000onV`^go0000
ojK2k@03o`000004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d00ol000001?nV`^go
0000ojK2kOnV`^d3o`0000;oY/;]0ol00003ojK2k@?o00001?nV`^d3o`0000?oY/;]00?o0000ojK2
kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2
kOnV`^d00onV`^d2o`0000;oY/;]0_l000000onV`^go0000ojK2k@03o`000004ojK2kOl0003oY/;]
ojK2k@?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@?o00001?nV`^d3o`0000?oY/;]0ol00002
ojK2k@03o`000?nV`^go000000GoY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00005
ojK2k@03o`000?nV`^goY/;]00;o000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000oook
JP0GoookJP03o`000?oonf[ooo]Z02Cooo]Z000SoookJP03o`000?oonf[ooo]Z00cooo]Z00Co0000
ojK1kOl0003o00000_nV`Nd00ol0003oY/7]o`000002ojK1k@05o`000?nV`Ngo0000o`000?nV`Nd0
0ol00003ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@Co000000?oY/7]o`000?l00000
0_l000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]
0ol000000onV`Ngo0000o`000002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@02o`00
0003ojK1kOl0003oY/7]00;o00000_nV`Nd3o`0000;oY/7]0ol00003ojK1k@?o000000?oY/7]o`00
0?l000000_l000000onV`Ngo0000o`000002o`0000;oY/7]1?l000001?nV`Ngo0000o`000?l00002
ojK1k@Co00000_nV`Nd3o`000003ojK1kOl0003o000000;oY/7]00Oo0000ojK1kOl0003o0000ojK1
kOl0003oY/7]00;o000000?oY/7]o`000?nV`Nd00_l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]
1?l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o00000_nV`Nd4o`000004ojK1
kOl0003o0000o`0000;oY/7]1?l00002ojK1k@?o000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd3
o`000003ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV`Nd00_l000000onV`Ngo0000o`000002
o`0000;oY/7]0ol00002ojK1k@Co000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002
o`000003ojK1kOl0003o000000?o000000CoY/7]o`000?l0003o00000_nV`Nd3o`0000?oY/7]0ol0
00001_nV`^go0000o`000?nV`^go0000ojK2k@?o000000?oY/;]o`000?nV`^d00_l000000onV`^go
0000ojK2k@02o`000003ojK2kOl0003o000000;o00000_nV`^d3o`0000;oY/;]1?l000000onV`^go
0000o`000002o`000003ojK2kOl0003o000000;o00000onV`^d3o`0000?oY/;]00?o0000ojK2kOnV
`^d00_nV`^d00ol0003oY/;]ojK2k@03ojK2k@07o`000?nV`^goY/;]o`000?nV`^go0000ojK2k@02
o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[o
oo]Z04cooo]Z00?o0000oookJ_oonfX0G_oonfX3o`000003ojK1kOl0003oY/7]00?o00000_nV`Nd0
0ol0003oY/7]o`000002o`000003ojK1kOl0003oY/7]00?o00000_nV`Nd01?l0003oY/7]o`000?l0
0003ojK1k@?o00000onV`Nd3o`0000CoY/7]0ol00003ojK1k@03o`000?nV`NgoY/7]00CoY/7]00?o
0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00Co
0000ojK2kOnV`^goY/;]0_l000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl00000
0_l000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l00002ojK2k@?o0000
0onV`^d3o`0000CoY/;]0ol00003ojK2k@;o00001OnV`^d00ol0003oY/;]ojK2k@03ojK2k@;o0000
1OnV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00000_nV`^d2o`000003ojK2kOl0003oY/;]00?o0000
0_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]
o`000002o`0000;oY/;]0ol00003ojK2k@?o00001?nV`^d3o`0000?oY/;]0_l00005ojK2k@03o`00
0?nV`^goY/;]00?oY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00;o00000_nV`^d00ol0003oY/;]
o`000002o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2
kOl0003oY/;]00?o00000_nV`^d3o`0000CoY/;]0ol00003ojK2k@?o00001?nV`^d00ol0003oY/;]
ojK2k@03ojK2k@;o00001OnV`^d00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z02Cooo]Z
000RoookJP03o`000?oonf[ooo]Z00kooo]Z0_l00002ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0
003o000000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV
`Nd00_l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol00003ojK1k@?o000000?oY/7]o`000?l0
00000_l00002ojK1k@Co000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000;o
Y/7]0ol00002ojK1k@?o00000_nV`Nd4o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l00002
ojK1k@05o`000?nV`Ngo0000o`000?nV`Nd00ol00002ojK1k@?o00000onV`Nd3o`0000;oY/7]0ol0
00000onV`Ngo0000o`000002o`0000;oY/7]1?l000001?nV`Ngo0000o`000?l00003ojK1k@?o0000
0_nV`Nd3o`0000;oY/7]0ol000001onV`Ngo0000o`000?l0003oY/7]o`000?nV`Nd00_l000000onV
`Ngo0000ojK1k@02o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd4o`0000;oY/7]0ol000000onV
`Ngo0000o`000002o`0000;oY/7]1?l000001?nV`Ngo0000o`000?l00002ojK1k@?o00000onV`Nd3
o`0000;oY/7]0ol000000onV`Ngo0000o`000002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000
ojK1k@02o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]0ol00003ojK1k@?o0000
00?oY/7]o`000?l000000_l000000onV`Ngo0000o`000003o`000004ojK1kOl0003o0000o`0000;o
Y/;]0ol00003ojK2k@?o00000_nV`^d3o`000006ojK2kOl0003o0000ojK2kOl0003oY/;]0ol00000
0onV`^go0000ojK2k@02o`000003ojK2kOl0003o000000;o00000_nV`^d3o`0000?oY/;]0_l00003
ojK2k@?o00000onV`^d2o`0000?oY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00;oY/;]00?o0000
ojK2kOnV`^d00_nV`^d00ol0003oY/;]ojK2k@02o`000003ojK2kOl0003ooo]Z02cooo]Z00?o0000
oookJ_oonfX0C?oonfX00ol0003ooo]ZoookJP1LoookJP;o00001OnV`Nd00ol0003oY/7]ojK1k@04
ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd01?nV`Nd00ol0003oY/7]ojK1k@02
o`000003ojK1kOl0003oY/7]00?o00000_nV`Nd00ol0003oY/7]o`000002o`000003ojK1kOl0003o
Y/7]00?o00000_nV`Nd00ol0003oY/7]o`000002o`0000;oY/7]0ol00004ojK2k@?o00000onV`^d3
o`0000CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^go
Y/;]00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@02o`000003ojK2kOl0003o
Y/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o00000_nV`^d0
0ol0003oY/;]o`000002o`0000;oY/;]0ol00004ojK2k@?o00000onV`^d3o`0000CoY/;]00?o0000
ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000
ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@02o`000003ojK2kOl0003oY/;]00?o00000_nV`^d0
0ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o00000onV`^d3o`0000?oY/;]0ol00004
ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000
ojK2kOnV`^d01?nV`^d01?l0003oY/;]ojK2kOl00002ojK2k@03o`000?nV`^goY/;]00;o00000_nV
`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`00
0002o`000003ojK2kOl0003oY/;]00?o00000onV`^d3o`0000?oY/;]00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0ToookJP008_oonfX00ol0003ooo]ZoookJP0@oookJP;o000000?oY/7]
o`000?l000000_l000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@Co00000_nV`Nd3
o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l00002ojK1k@03o`000?nV`Ngo000000;oY/7]
00Go0000ojK1kOl0003o0000ojK1k@03o`0000?oY/7]0ol00002ojK1k@?o00000_nV`Nd3o`0000;o
Y/7]1?l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;o
Y/7]0ol00003ojK1k@?o000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd2o`0000;oY/7]00Oo0000
ojK1kOl0003o0000ojK1kOl0003oY/7]00;o000000CoY/7]o`000?l0003o00000onV`Nd3o`0000;o
Y/7]0ol000000onV`Ngo0000o`000003o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l0
00000_l000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@?o000000OoY/7]o`000?l0
003o0000ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV`Nd00_l00002ojK1k@05o`000?nV`Ngo
0000o`000?nV`Nd01?l000000onV`Ngo0000o`000002o`0000;oY/7]0ol000000onV`Ngo0000o`00
0002o`000003ojK1kOl0003o000000?o000000?oY/7]o`000?l000000_l000001?nV`Ngo0000o`00
0?l00003ojK1k@?o00000_nV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0ol000000onV
`Ngo0000ojK1k@02o`000003ojK1kOl0003oY/7]00?o000000CoY/7]o`000?l0003o00000_nV`Nd3
o`0000;oY/7]1?l000000onV`^go0000o`000002o`000003ojK2kOl0003o000000?o000000?oY/;]
o`000?l000000_l000001?nV`^go0000o`000?l00002ojK2k@?o00000onV`^d3o`000006ojK2kOl0
003o0000ojK2kOl0003oY/;]0ol000000onV`^go0000o`000002o`000003ojK2kOl0003oY/;]00;o
00000_nV`^d3o`0000?oY/;]0_l00003ojK2k@?o00000_nV`^d3o`0000?oY/;]0_l00003ojK2k@03
o`000?nV`^goY/;]00?oY/;]00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP1<oookJP03
o`000?oonf[ooo]Z05Wooo]Z0ol000000onV`Ngo0000ojK1k@03o`0000?oY/7]0ol00003ojK1k@?o
00001?nV`Nd3o`0000?oY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@04ojK1k@03
o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd01?nV`Nd00ol0003oY/7]ojK1k@02o`0000;o
Y/;]00?o0000ojK2kOl000000_l000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl0
00000_l000000onV`^go0000ojK2k@03o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d3o`0000Co
Y/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?o
Y/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@02o`0000;oY/;]00?o0000ojK2kOl0
00000_l000000onV`^go0000ojK2k@03o`000004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`00
0?nV`^d00ol00002ojK2k@?o00001?nV`^d3o`0000?oY/;]0ol00004ojK2k@03o`000?nV`^goY/;]
00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@04o`000?nV`^goY/;]
ojK2k@;o000000?oY/;]o`000?nV`^d00ol000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0
003oY/;]00?o000000CoY/;]o`000?nV`^goY/;]0ol00002ojK2k@?o00000onV`^d3o`0000CoY/;]
0ol00003ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]
ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00Co0000ojK2kOnV`^goY/;]0_l000000onV`^go
0000ojK2k@03o`000003ojK2kOl0003ooo]Z01Gooo]Z00?o0000oookJ_oonfX09?oonfX002;ooo]Z
00?o0000oookJ_oonfX04OoonfX2o`0000;oY/7]0ol00002ojK1k@Co000000?oY/7]o`000?l00000
0_l00002ojK1k@Co000000CoY/7]o`000?l0003o00000_nV`Nd4o`0000;oY/7]0ol00002ojK1k@?o
000000?oY/7]o`000?l000000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l00000
0onV`Ngo0000ojK1k@02o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]1?l00000
0onV`Ngo0000o`000002o`000003ojK1kOl0003o000000?o000000CoY/7]o`000?l0003o00000_nV
`Nd3o`0000?oY/7]0ol00002ojK1k@?o000000?oY/7]o`000?l000000_nV`Nd01ol0003oY/7]o`00
0?l0003oY/7]o`000?nV`Nd00_l000001?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd3o`00
00;oY/7]0ol00002ojK1k@Co000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`00
00;oY/7]0ol00002ojK1k@?o00000onV`Nd3o`000003ojK1kOl0003o000000;o000000KoY/7]o`00
0?l0003oY/7]o`000?nV`Nd3o`000004ojK1kOl0003o0000o`0000;oY/7]0ol00003ojK1k@?o0000
0_nV`Nd3o`000003ojK1kOl0003o000000?o000000?oY/7]o`000?l000000_l000001?nV`Ngo0000
o`000?l00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]0ol000001onV`Ngo0000o`000?l0003oY/7]
o`000?nV`Nd00_l000000onV`Ngo0000ojK1k@02o`000003ojK1kOl0003o000000;o00000_nV`^d3
o`0000;oY/;]1?l00002ojK2k@?o000000?oY/;]o`000?l000000_l000000onV`^go0000o`000003
o`000004ojK2kOl0003o0000o`0000;oY/;]0ol00005ojK2k@03o`000?nV`^goY/;]00;oY/;]00Oo
0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00_l00002ojK2k@;o
00000onV`^d3o`0000?oY/;]0_l00003ojK2k@?o00000onV`^d00ol0003ooo]ZoookJP0ZoookJP03
o`000?oonf[ooo]Z04[ooo]Z00?o0000oookJ_oonfX0EooonfX3o`0000GoY/7]00Co0000ojK1kOnV
`NgoY/7]0_l000000onV`Ngo0000ojK1k@03o`0000;oY/7]00?o0000ojK1kOl000000_l000000onV
`Ngo0000ojK1k@03o`0000;oY/7]00Co0000ojK1kOl0003o00000onV`Nd3o`0000?oY/7]0ol00004
ojK1k@?o00000onV`Nd00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000
ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@04o`000?nV`^goY/;]ojK2k@;o000000?o
Y/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l0
00000onV`^go0000ojK2k@03o`0000?oY/;]0ol00003ojK2k@?o00001?nV`^d3o`0000?oY/;]00?o
0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l0
0005ojK2k@03o`000?nV`^goY/;]00;o00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0
003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`0000;oY/;]0ol00003ojK2k@?o00001?nV
`^d3o`0000?oY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00005ojK2k@03o`000?nV
`^goY/;]00?oY/;]0_l00002ojK2k@;o000000?oY/;]o`000?nV`^d00ol000001?nV`^go0000ojK2
kOnV`^d3o`000003ojK2kOl0003oY/;]00?o000000CoY/;]o`000?nV`^goY/;]0ol00002ojK2k@?o
00000onV`^d3o`0000CoY/;]0ol00003ojK2k@;o00001OnV`^d00ol0003oY/;]ojK2k@03ojK2k@03
o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX09?oonfX002;ooo]Z00?o0000oookJ_oonfX0
4_oonfX00ol0003oY/7]o`000002ojK1k@?o00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@?o0000
00?oY/7]o`000?l000000_l00002ojK1k@Co000000?oY/7]o`000?l000000_l000000onV`Ngo0000
o`000002o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd4o`000006ojK1kOl0003o0000ojK1kOl0
003oY/7]0_l000000onV`Ngo0000ojK1k@02o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd3o`00
00?oY/7]0ol000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000?o000000?oY/7]o`00
0?l000000_l000001?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o
000000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV`Nd0
0_l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@Co000000?oY/7]o`000?l00000
0_l000000onV`Ngo0000o`000003o`000004ojK1kOl0003o0000o`0000;oY/7]0ol00002ojK1k@Co
000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd2o`000003ojK1kOl0003oY/7]00?o000000?oY/7]
o`000?nV`Nd00_l000001?nV`Ngo0000o`000?l00002ojK1k@Co00000_nV`Nd3o`000003ojK1kOl0
003o000000;o00000_nV`Nd4o`000003ojK1kOl0003o000000;o000000CoY/7]o`000?l0003o0000
0onV`Nd3o`0000;oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK2k@?o000000?oY/;]o`00
0?nV`^d00_l000000onV`^go0000ojK2k@03o`000004ojK2kOl0003o0000o`0000;oY/;]0ol00002
ojK2k@Co000000?oY/;]o`000?l000000_l00003ojK2k@?o00000_nV`^d3o`0000?oY/;]00?o0000
ojK2kOnV`^d00_nV`^d00ol0003oY/;]ojK2k@03ojK2k@07o`000?nV`^goY/;]o`000?nV`^go0000
ojK2k@02o`000003ojK2kOl0003oY/;]00?o00000_nV`^d2o`0000?oY/;]0ol00002ojK2k@03o`00
0?oonf[ooo]Z02[ooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP1CoookJPCo0000
0onV`Nd3o`0000CoY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@04ojK1k@03o`00
0?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd01?nV`Nd00ol0003oY/7]ojK1k@02o`000003ojK1
kOl0003oY/7]00?o00000_nV`Nd00ol0003oY/7]o`000002o`000003ojK1kOl0003oY/7]00?o0000
0_nV`Nd00ol0003oY/;]o`000002o`0000;oY/;]0ol00004ojK2k@?o00000onV`^d3o`0000CoY/;]
00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00CoY/;]
00?o0000ojK2kOnV`^d00onV`^d01?l0003oY/;]ojK2kOnV`^d2o`000003ojK2kOl0003oY/;]00?o
00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o00000_nV`^d3o`0000Co
Y/;]0ol00003ojK2k@?o00001?nV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003o
Y/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00_l000000onV`^go
0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l000000onV`^go0000ojK2k@03o`0000;o
Y/;]00?o0000ojK2kOl000000_l00002ojK2k@?o00001?nV`^d3o`0000?oY/;]0ol00003ojK2k@;o
00001OnV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d2o`0000CoY/;]0_l00002ojK2k@;o
000000?oY/;]o`000?nV`^d00ol000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]
00?o00000_nV`^d3o`0000CoY/;]0ol00003ojK2k@03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX08ooonfX002;ooo]Z00?o0000oookJ_oonfX04ooonfX01ol0003oY/7]o`000?l0003oY/7]
o`000?nV`Nd00_l00002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@02o`000004ojK1
kOl0003o0000o`0000?oY/7]0ol00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]1?l000000onV`Ngo
0000o`000002o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@Co
000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd2o`000003ojK1kOl0003oY/7]00;o00000_nV`Nd0
1Ol0003oY/7]o`000?l0003oY/7]00?o00000_nV`Nd3o`0000?oY/7]0ol000000onV`Ngo0000o`00
0002o`000003ojK1kOl0003o000000?o000000?oY/7]o`000?l000000_l000001?nV`Ngo0000o`00
0?l00003ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol000001onV`Ngo0000o`000?l0003oY/7]o`00
0?nV`Nd00_l000000onV`Ngo0000ojK1k@02o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd3o`00
00?oY/7]0ol000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`00
00;oY/7]0ol00002ojK1k@Co00000_nV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l0
0002ojK1k@05o`000?nV`Ngo0000o`000?nV`Nd00ol00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]
0ol000000onV`Ngo0000o`000003o`000003ojK1kOl0003o000000;o000000CoY/7]o`000?l0003o
00000_nV`Nd4o`0000;oY/;]0ol00002ojK2k@?o000000OoY/;]o`000?l0003o0000ojK2kOl0003o
Y/;]00;o000000?oY/;]o`000?nV`^d00_l000000onV`^go0000o`000002o`0000?oY/;]0_l00003
ojK2k@;o00000onV`^d3o`0000?oY/;]0_l00003ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@02
ojK2k@03o`000?nV`^goY/;]00;oY/;]00?o0000ojK2kOnV`^d00_l000000onV`^go0000ojK2k@02
o`000003ojK2kOl0003oY/;]00;o000000?oY/;]o`000?oonfX0:ooonfX00ol0003ooo]ZoookJP1:
oookJP03o`000?oonf[ooo]Z053ooo]Z0ol00002ojK1k@04o`000?nV`Ngo0000o`0000;oY/7]00?o
0000ojK1kOl000000_l00002ojK1k@?o00001?nV`Nd3o`0000?oY/7]0ol00004ojK1k@?o00000onV
`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00CoY/7]00?o0000ojK1kOnV`Nd00onV
`Nd00ol0003oY/7]ojK1k@04ojK1k@03o`000?nV`^goY/;]00;o00000_nV`^d00ol0003oY/;]o`00
0002o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`0000;oY/;]0ol0
0003ojK2k@?o00001?nV`^d3o`0000?oY/;]0ol00004ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o
0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00;o00000_nV
`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`00
0002o`000003ojK2kOl0003oY/;]00?o00000_nV`^d3o`0000CoY/;]0ol00003ojK2k@?o00001?nV
`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV
`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00;o000000CoY/;]o`000?nV`^goY/;]
0ol000000onV`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]
o`000002o`0000;oY/;]0ol00003ojK2k@?o00001?nV`^d3o`0000?oY/;]0_l00005ojK2k@03o`00
0?nV`^goY/;]00?oY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00;o000000CoY/;]o`000?nV`^go
Y/;]0ol000000onV`^go0000ojK2k@03o`000003ojK2kOl0003ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX08ooonfX002;ooo]Z00?o0000oookJ_oonfX05?oonfX2o`0000;oY/7]0ol00002ojK1k@?o0000
0_nV`Nd3o`000003ojK1kOl0003o000000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]
00;o000000?oY/7]o`000?nV`Nd00_l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1
k@Co000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1
k@?o00000_nV`Nd4o`0000;oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o00000_nV
`Nd01Ol0003oY/7]o`000?l0003oY/7]00?o00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@?o0000
00?oY/7]o`000?l000000ol000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o0000
00?oY/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd3o`000007ojK1kOl0003o0000o`000?nV
`Ngo0000ojK1k@02o`000003ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV`Nd00ol000001?nV
`Ngo0000o`000?l00002ojK1k@?o00000_nV`Nd4o`000003ojK1kOl0003o000000;o000000?oY/7]
o`000?l000000_l00002ojK1k@Co000000CoY/7]o`000?l0003o00000_nV`Nd3o`0000?oY/7]0ol0
00001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo
0000ojK1k@02o`000004ojK1kOl0003o0000o`0000;oY/7]1?l00002ojK1k@?o000000?oY/7]o`00
0?l000000_l00002ojK2k@Co000000?oY/;]o`000?l000000_l000001?nV`^go0000o`000?l00003
ojK2k@?o00000_nV`^d3o`000006ojK2kOl0003o0000ojK2kOl0003oY/;]0ol000000onV`^go0000
ojK2k@02o`0000;oY/;]0_l00003ojK2k@?o00000onV`^d2o`0000?oY/;]0ol00003ojK2k@;o0000
0onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@02ojK2k@03o`00
0?nV`^goY/;]00;oY/;]00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP1:oookJP03o`00
0?oonf[ooo]Z04gooo]Z0ol00006ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd0
0_l00002ojK1k@03o`000?nV`Ngo000000;o000000?oY/7]o`000?nV`Nd00ol00002ojK1k@03o`00
0?nV`Ngo000000;o000000?oY/7]o`000?nV`Nd00ol00003ojK1k@;o00001?nV`Nd3o`0000?oY/7]
0ol00004ojK1k@?o00000onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]
00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@02o`000003ojK2kOl0003oY/;]00?o0000
0_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o000000CoY/;]o`000?l0003o
Y/;]0ol00002ojK2k@?o00000onV`^d3o`0000CoY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00Co
Y/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?o
Y/;]00?o0000ojK2kOnV`^d00_l00002ojK2k@03o`000?nV`^go000000;o000000?oY/;]o`000?nV
`^d00ol00002ojK2k@03o`000?nV`^go000000;o000000?oY/;]o`000?nV`^d00ol00003ojK2k@?o
00000onV`^d3o`0000?oY/;]0ol00004ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00005ojK2k@03
o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@02o`000003
ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o
00000onV`^d3o`0000?oY/;]0ol00003ojK2k@?o00001?nV`^d00ol0003oY/;]ojK2k@03ojK2k@;o
00001OnV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oo
nfX08ooonfX002;ooo]Z00?o0000oookJ_oonfX05_oonfX2o`000003ojK1kOl0003o000000;o0000
00?oY/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]1?l00002ojK1k@?o0000
00KoY/7]o`000?l0003oY/7]o`000?nV`Nd2o`0000;oY/7]00?o0000ojK1kOl000000_nV`Nd3o`00
00;oY/7]0ol00002ojK1k@?o00000onV`Nd3o`000003ojK1kOl0003o000000;o000000?oY/7]o`00
0?l000000_l00002ojK1k@Co000000CoY/7]o`000?l0003o00000_nV`Nd4o`0000;oY/7]0ol00000
1_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o00000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`00
0?nV`Nd00_l000001?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o
000000;o00000_nV`Nd4o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l00002
ojK1k@?o00000_nV`Nd3o`0000;oY/7]1?l000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o0000
00?oY/7]o`000?nV`Nd00_l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]1?l000000onV`Ngo0000
o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000ol000001?nV`Ngo0000
o`000?l00002ojK1k@?o00000_nV`Nd3o`0000?oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000
ojK1k@;o00000_nV`Nd01Ol0003oY/7]o`000?l0003oY/7]00?o00000_nV`Nd4o`0000;oY/;]0ol0
00000onV`^go0000o`000002o`000003ojK2kOl0003o000000?o000000?oY/;]o`000?l000000_l0
00001?nV`^go0000o`000?l00004ojK2k@03o`000?nV`^goY/;]00?oY/;]00Oo0000ojK2kOnV`^go
0000ojK2kOl0003oY/;]00;o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@02o`00
00;oY/;]0ol00002ojK2k@?o00000onV`^d2o`0000?oY/;]0ol00003ojK2k@;o00000onV`^d2o`00
00?oY/;]00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP1:oookJP03o`000?oonf[ooo]Z
04Wooo]Z1?l00004ojK1k@?o00000onV`Nd3o`0000CoY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0
003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00CoY/7]00?o0000ojK1kOnV`Nd00onV`Nd01?l0
003oY/7]ojK1kOnV`Nd2o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol00002
ojK1k@03o`000?nV`Ngo000000;o000000?oY/7]o`000?nV`^d00ol00003ojK2k@?o00000onV`^d3
o`0000CoY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d0
0ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00;oY/;]00?o0000o`1>bOl000000_nV`^d2
o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003o
Y/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`0000;oY/;]0ol00004ojK2k@?o00000onV`^d3
o`0000?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^go
Y/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d01?l0003oY/;]ojK2kOnV`^d2o`000003ojK2kOl0
003oY/;]00?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go000000;o000000?o
Y/;]o`000?nV`^d00ol00002ojK2k@?o00001?nV`^d3o`0000?oY/;]0ol00004ojK2k@03o`000?nV
`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@02ojK2k@;o00000onV
`^d2o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV
`^go000000;o000000?oY/;]o`000?nV`^d00ol00002ojK2k@?o00001?nV`^d3o`0000?oY/;]00?o
0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0SoookJP008OoonfX00ol0003ooo]ZoookJP0H
oookJP;o00000_nV`Nd3o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o
000000;o00000_nV`Nd4o`000004ojK1kOl0003o0000o`0000;oY/7]1?l00002ojK1k@?o000000Ko
Y/7]o`000?l0003oY/7]o`000?nV`Nd2o`0000;oY/7]00?o0000ojK1kOl000000_nV`Nd01Ol0003o
Y/7]o`000?l0003oY/7]00?o00000_nV`Nd3o`0000?oY/7]0ol000000onV`Ngo0000o`000002o`00
0003ojK1kOl0003o000000;o00000_nV`Nd4o`000004ojK1kOl0003o0000o`0000;oY/7]1?l00002
ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o000000;oY/7]00Oo0000ojK1kOl0003o0000ojK1
kOl0003oY/7]00;o000000CoY/7]o`000?l0003o00000onV`Nd3o`0000;oY/7]0ol000000onV`Ngo
0000o`000002o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o
00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o000000OoY/7]o`000?l0003o0000ojK1kOl0003o
Y/7]00;o000000?oY/7]o`000?nV`Nd00_l000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002
ojK1k@?o000000?oY/7]o`000?l000000ol000000onV`Ngo0000o`000002o`000003ojK1kOl0003o
000000;o000000?oY/7]o`000?l000000ol000001?nV`Ngo0000o`000?l00002ojK1k@?o00000onV
`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l000000onV`^go0000ojK2k@03o`000004
ojK2kOl0003o0000o`0000;oY/;]0ol00002ojK2k@Co000000?oY/;]o`000?l000000_l00003ojK2
k@;o00000onV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d00ol0003oY/;]ojK2k@02ojK2
k@;o00001?nV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l000000onV`^go0000ojK2
k@03o`0000;oY/;]0_l00003ojK2k@?o00000_nV`^d3o`0000?oY/;]0_l00003ojK2k@03o`000?oo
nf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP16oookJP?o00000_nV
`Nd00ol0003oY/7]o`000002o`000003ojK1kOl0003oY/7]00?o00000_nV`Nd00ol0003oY/7]o`00
0002o`000003ojK1kOl0003oY/7]00?o00000_nV`Nd3o`0000CoY/7]0ol00003ojK1k@?o00001?nV
`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd01?nV
`Nd00ol0003oY/7]ojK1k@03ojK1k@04o`000?nV`^goY/;]ojK2k@;o000000?oY/;]o`000?nV`^d0
0ol00002ojK2k@03o`000?nV`^go000000;o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000
ojK2k@03o`0000?oY/;]0ol00003ojK2k@?o00001?nV`^d3o`000004ojK2kOl0003o0000o`0000Go
Y/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00Co
Y/;]00?o0000ojK2kOnV`^d00_l000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]
00?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go000000;o00000_nV`^d3o`00
00?oY/;]0ol00004ojK2k@?o00000onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0
003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00_l00002ojK2
k@03o`000?nV`^go000000;o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go0000
00;o00000_nV`^d3o`0000?oY/;]0ol00004ojK2k@?o00000_nV`^d3o`0000GoY/;]00?o0000ojK2
kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2
kOnV`^d00_l000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o000000?oY/;]
o`000?oonfX04_oonfX00ol0003ooo]ZoookJP0SoookJP008OoonfX00ol0003ooo]ZoookJP0Hoook
JP04o`000?nV`Ngo0000o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]1?l00000
0onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o00000_nV`Nd4o`000004ojK1kOl0003o
0000o`0000;oY/7]1?l00002ojK1k@?o00000_nV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003o
Y/7]0_l00002ojK1k@05o`000?nV`Ngo0000o`000?nV`Nd00ol00002ojK1k@?o00000onV`Nd3o`00
0003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l00002ojK1k@Co000000?oY/7]o`00
0?l000000_l000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@?o000000?oY/7]o`00
0?l000000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l000001?nV`Ngo0000o`00
0?l00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]2Ol000000onV`Ngo0000o`000002o`000003ojK1
kOl0003o000000;o000000?oY/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd3o`000003ojK1
kOl0003o000000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]00;o000000CoY/7]o`00
0?l0003o00000onV`Nd3o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd4o`000003ojK1kOl0003o
000000;o000000?oY/7]o`000?l000000ol000001?nV`Ngo0000o`000?l00002ojK1k@?o00000_nV
`^d3o`000007ojK2kOl0003o0000o`000?nV`^go0000ojK2k@02o`000003ojK2kOl0003oY/;]00;o
000000?oY/;]o`000?l000000_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0ol00003ojK2k@;o
00000onV`^d2o`0000?oY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00;oY/;]00?o0000ojK2kOnV
`^d00_nV`^d00ol0003oY/;]ojK2k@02o`000003ojK2kOl0003oY/;]00;o000000?oY/;]o`000?nV
`^d00_l00002ojK2k@?o00000onV`^d2o`0000?oY/;]00?o0000oookJ_oonfX09_oonfX00ol0003o
oo]ZoookJP1:oookJP03o`000?oonf[ooo]Z04Cooo]Z0_l00006ojK1k@03o`000?nV`NgoY/7]00?o
Y/7]00?o0000ojK1kOnV`Nd01?nV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00;o
00000_nV`Nd00ol0003oY/7]o`000002o`000003ojK1kOl0003oY/7]00?o00000_nV`Nd00ol0003o
Y/7]o`000002o`000003ojK1kOl0003oY/7]00?o00000onV`Nd2o`0000CoY/7]0ol00003ojK1k@?o
00001?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV
`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@04o`000?nV`^goY/;]ojK2k@;o000000?oY/;]o`00
0?nV`^d00ol00002ojK2k@03o`000?nV`^go000000;o000000?oY/;]o`000?nV`^d00ol000000onV
`^go05;>o`000003o`0000?oY/;]0ol00003ojK2k@?o00001?nV`^d3o`0000?oY/;]00?o0000ojK2
kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2
k@03o`000?nV`^goY/;]00;o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go0000
00;o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go000000;o00000_nV`^d3o`00
00?oY/;]0ol00004ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]
00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@02o`000003ojK2kOl0003oY/;]
00?o00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00Go00000_nV`^d3o`00
00;oY/;]0ol00003ojK2k@?o00001?nV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d00onV`^d2o`00
00GoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z
02?ooo]Z000QoookJP03o`000?oonf[ooo]Z01Wooo]Z0_l000001_nV`Ngo0000o`000?nV`Ngo0000
ojK1k@;o000000?oY/7]o`000?nV`Nd00_l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol00003
ojK1k@?o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000;oY/7]1?l00000
0onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]0ol00000
1_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o00000_nV`Nd01Ol0003oY/7]o`000?l0003oY/7]00?o
00000_nV`Nd3o`0000?oY/7]0ol00002ojK1k@?o000000?oY/7]o`000?l000000_l00002ojK1k@Co
000000?oY/7]o`000?l000000_l000001?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd3o`00
0006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l00002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo
0000ojK1k@06o`0000?oY/7]0ol00002ojK1k@?o000000?oY/7]o`000?l000000_l00002ojK1k@Co
000000?oY/7]o`000?l000000_l000001?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd3o`00
0006ojK1kOl0003o0000ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@02o`000003ojK1kOl0
003oY/7]00;o000000?oY/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0
003o000000?o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000004ojK2kOl0
003o0000o`0000?oY/;]0ol00002ojK2k@?o000000KoY/;]o`000?l0003oY/;]o`000?nV`^d3o`00
0003ojK2kOl0003oY/;]00;o000000?oY/;]o`000?nV`^d00_l00002ojK2k@?o00000onV`^d2o`00
00?oY/;]0_l00003ojK2k@?o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]
00?oY/;]00?o0000ojK2kOnV`^d00_nV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00ol0
00000onV`^go0000ojK2k@02o`0000;oY/;]00?o0000oookJ_oonfX09_oonfX00ol0003ooo]Zoook
JP19oookJP03o`000?oonf[ooo]Z04;ooo]Z0_l00003ojK1k@?o00000onV`Nd3o`0000CoY/7]0ol0
0003ojK1k@?o00001?nV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o
0000ojK1kOnV`Nd01?nV`Nd00ol0003oY/7]ojK1k@03ojK1k@04o`000?nV`NgoY/7]ojK1k@;o0000
00?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03o`0000;oY/7]00?o0000ojK2kOl00000
0_l000000onV`^go0000ojK2k@03o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d3o`0000CoY/;]
00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]
00?o0000ojK2kOnV`^d00_nV`^d01?l0EM3o0000o`1Dcol0<k@3o`000003ojK2kOl0003oY/;]00?o
00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV
`^d00ol00003ojK2k@?o00000onV`^d3o`0000CoY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00?o
Y/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00Co
Y/;]00?o0000ojK2kOnV`^d00_l000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl0
00000_l000000onV`^go0000ojK2k@03o`0000;oY/;]0ol00004ojK2k@?o00000onV`^d3o`0000Co
Y/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?o
Y/;]00Ko0000ojK2kOnV`^goY/;]o`000?nV`^d2o`0000;oY/;]0_l000000onV`^go0000ojK2k@03
o`000004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@?o00001?nV
`^d3o`0000?oY/;]0ol00003ojK2k@03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX08ooo
nfX0027ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003oY/7]ojK1k@04o`0000;oY/7]0ol00000
1_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o000000?oY/7]o`000?nV`Nd00_l00002ojK1k@05o`00
0?nV`Ngo0000o`000?nV`Nd00ol00002ojK1k@?o00000onV`Nd3o`0000;oY/7]0ol000000onV`Ngo
0000o`000002o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`000004ojK1kOl0003o0000o`00
00;oY/7]1?l00002ojK1k@?o000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd2o`0000;oY/7]00Oo
0000ojK1kOl0003o0000ojK1kOl0003oY/7]00;o000000CoY/7]o`000?l0003o00000onV`Nd3o`00
00;oY/7]0ol000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000?o000000?oY/7]o`00
0?l000000_l000001?nV`Ngo0000o`000?l00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]0ol00000
0onV`Ngo0000o`000002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@02o`000004ojK1
kOl0003o0000o`0000;oY/7]1?l00002ojK1k@?o000000?oY/7]o`000?l000000_l000000onV`Ngo
0000o`000003o`000003ojK1kOl0003o000000;o000000CoY/7]o`000?l0003o00000_nV`Nd3o`00
00?oY/7]0ol00002ojK1k@?o000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd3o`000003ojK1kOl0
003oY/7]00;o000000CoY/7]o`000?l0003o00000_nV`Nd4o`0000;oY/7]0ol000000onV`^go0000
o`000002o`000003ojK2kOl0003o000000?o000000?oY/;]o`000?l000000_l000001?nV`^go0000
o`000?l00004ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00_nV`^d01ol0003o
Y/;]ojK2kOl0003oY/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@02o`0000;oY/;]0_l00003
ojK2k@?o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@?o00000onV`^d2o`0000?oY/;]00?o0000
ojK2kOnV`^d00_nV`^d00ol0003oY/;]ojK2k@03ojK2k@06o`000?nV`^goY/;]o`000?nV`^go0000
:?oonfX00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z043ooo]Z0ol00002ojK1k@;o0000
0_nV`Nd01?l0003oY/7]o`000?l00002ojK1k@03o`000?nV`Ngo000000;o000000?oY/7]o`000?nV
`Nd00ol00002ojK1k@03o`000?nV`Ngo000000;o00000_nV`Nd3o`0000CoY/7]0_l00004ojK1k@?o
00000onV`Nd3o`0000CoY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@03ojK1k@03
o`000?nV`NgoY/7]00CoY/7]00?o0000ojK2kOnV`^d00onV`^d01?l0003oY/;]ojK2kOnV`^d2o`00
0003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go0000
00;o00000_nV`^d3o`0000CoY/;]0ol00003ojK2k@?o00000onV`^d3o`0000;oY/;]00Go05G@o`00
0?l0AlKo03>do`000003ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d0
0ol0003oY/;]ojK2k@03ojK2k@04o`000?nV`^goY/;]ojK2k@;o000000?oY/;]o`000?nV`^d00ol0
00001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000_nV`^d3o`0000CoY/;]
0ol00003ojK2k@?o00000onV`^d3o`0000CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]
ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00_l00002ojK2k@03o`00
0?nV`^go000000;o000000?oY/;]o`000?nV`^d00ol000001?nV`^go0000ojK2kOnV`^d3o`000003
ojK2kOl0003oY/;]00?o00000_nV`^d3o`0000CoY/;]0ol00003ojK2k@Co00000_nV`^d2o`0000Go
Y/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d00_l000001?nV`^go
0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol00002ojK2
k@03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX08ooonfX0027ooo]Z00?o0000oookJ_oo
nfX07?oonfX2o`0000;oY/7]1?l000001?nV`Ngo0000o`000?l00002ojK1k@Co00000_nV`Nd3o`00
00;oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o00000_nV`Nd01ol0003oY/7]o`00
0?l0003oY/7]o`000?nV`Nd00_l000001?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd3o`00
0003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]1?l000001?nV`Ngo0000o`000?l00002
ojK1k@Co00000_nV`Nd3o`0000;oY/7]0ol000000onV`Ngo0000o`000002ojK1k@07o`000?nV`Ngo
0000o`000?nV`Ngo0000ojK1k@02o`000004ojK1kOl0003o0000o`0000;oY/7]0ol00003ojK1k@?o
000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000;oY/7]1?l000000onV`Ngo
0000o`000002o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1k@?o000000KoY/7]o`00
0?l0003oY/7]o`000?nV`Nd2o`0000;oY/7]00Go0000ojK1kOl0003o0000ojK1k@03o`0000;oY/7]
0ol00003ojK1k@?o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1
kOl0003o000000?o000000?oY/7]o`000?l000000_l000001?nV`Ngo0000o`000?l00002ojK1k@?o
00000onV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l000000onV`Ngo0000ojK1k@03
o`000004ojK1kOl0003o0000o`0000;oY/;]0ol00002ojK2k@Co000000?oY/;]o`000?l000000_l0
0003ojK2k@;o00000onV`^d3o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]00;oY/;]00?o
0000ojK2kOnV`^d00onV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l000000onV`^go
0000o`000003o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d3o`0000?oY/;]0_l00003ojK2k@;o
00000onV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d00ol0003ooo]ZoookJP0UoookJP03
o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oonfX0??oonfX4o`0000?oY/7]00?o0000ojK1kOnV
`Nd01?nV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV
`Nd01?nV`Nd00ol0003oY/7]ojK1k@02o`0000;oY/7]00?o0000ojK1kOl000000_l000000onV`Ngo
0000ojK1k@03o`000003ojK1kOl0003oY/7]00?o00000_nV`Nd00ol0003oY/7]o`000002o`0000;o
Y/7]0ol00004ojK1k@;o00001?nV`Nd3o`0000?oY/;]0ol00004ojK2k@03o`000?nV`^goY/;]00?o
Y/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00;o
00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV
`^d00ol00002ojK2k@07o`000?nV`^go0000o`000?l<FM?o0000o`1HdP03o`0000?oY/;]0ol00004
ojK2k@?o00000onV`^d3o`0000CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03
ojK2k@;o00001OnV`^d00ol0003oY/;]ojK2k@02o`000004ojK2kOl0003oY/;]ojK2k@?o000000?o
Y/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l0
0002ojK2k@?o00000onV`^d3o`0000CoY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o
0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d00ol0003oY/;]ojK2
k@02o`000004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000
ojK2k@03o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d3o`0000CoY/;]00?o0000ojK2kOnV`^d0
0onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@02o`000003ojK2
kOl0003ooo]Z013ooo]Z00?o0000oookJ_oonfX08_oonfX0027ooo]Z00?o0000oookJ_oonfX07_oo
nfX2o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]1?l000000onV`Ngo0000o`00
0002o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o000000?o
Y/7]o`000?l000000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l000001?nV`Ngo
0000o`000?l00003ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o000000;o000000?oY/7]o`00
0?l000000_l00002ojK1k@Co000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`00
00;oY/7]0ol00002ojK1k@?o000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd2o`0000;oY/7]00Go
0000ojK1kOl0003o0000ojK1k@03o`0000;oY/7]0ol00003ojK1k@?o000000?oY/7]o`000?l00000
1ol000000onV`Ngo0000o`000003o`000003ojK1kOl0003o000000;o000000CoY/7]o`000?l0003o
00000_nV`Nd3o`0000?oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o000000?oY/7]
o`000?nV`Nd00ol000001?nV`Ngo0000o`000?l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]1?l0
00000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000ol0
00001?nV`Ngo0000o`000?l00002ojK1k@?o00000_nV`Nd3o`000007ojK1kOl0003o0000o`000?nV
`^go0000ojK2k@02o`000003ojK2kOl0003oY/;]00;o000000?oY/;]o`000?l000000_l00003ojK2
k@;o00000onV`^d2o`0000?oY/;]0ol00003ojK2k@;o00000onV`^d2o`0000?oY/;]0ol00003ojK2
k@03o`000?nV`^goY/;]00;oY/;]00?o0000ojK2kOnV`^d00_nV`^d2o`000004ojK2kOl0003o0000
ojK2k@Co000000?oY/;]o`000?nV`^d00_l00002ojK2k@?o00000_nV`^d3o`0000?oY/;]0_l00003
ojK2k@?o00000_nV`^d3o`0000?oY/;]00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP18
oookJP03o`000?oonf[ooo]Z03Wooo]Z0ol000000onV`Ngo0000ojK1k@03o`0000;oY/7]00?o0000
ojK1kOl000000_l00002ojK1k@?o00001?nV`Nd2o`0000CoY/7]0ol00003ojK1k@03o`000?nV`Ngo
Y/7]00CoY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`Ngo
Y/7]00CoY/7]00?o0000ojK1kOnV`Nd00_l00002ojK1k@03o`000?nV`Ngo000000;o000000?oY/7]
o`000?nV`Nd00ol000000onV`Ngo0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l00002
ojK2k@?o00000onV`^d3o`0000CoY/;]0ol00003ojK2k@05o`000?nV`^goY/;]ojK2kOl000000_nV
`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d01?nV
`^d01Ol0003oY/;]ojK2kOl0003o35WC00Ko00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2
kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`0000;oY/;]0ol00003ojK2k@?o0000
1?nV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d0
0onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00;o000000?oY/;]o`000?nV`^d0
0ol00002ojK2k@03o`000?nV`^go000000;o000000?oY/;]o`000?nV`^d00ol000001?nV`^go0000
ojK2kOnV`^d3o`0000;oY/;]0ol00003ojK2k@?o00001?nV`^d3o`0000?oY/;]00?o0000ojK2kOnV
`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d00onV`^d3o`000006ojK2kOl0003o0000ojK2
kOl0003oY/;]0ol000000onV`^go0000ojK2k@03o`000004ojK2kOl0003oY/;]ojK2k@?o000000?o
Y/;]o`000?nV`^d00ol00002ojK2k@?o00001?nV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d00onV
`^d2o`0000oooo]Z00?o0000oookJ_oonfX08_oonfX0023ooo]Z00?o0000oookJ_oonfX08?oonfX2
o`0000?oY/7]0ol00002ojK1k@?o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002
o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o00000_nV`Nd3
o`0000;oY/7]0ol00002ojK1k@?o000000?oY/7]o`000?l000000_nV`Nd01ol0003oY/7]o`000?l0
003oY/7]o`000?nV`Nd00_l000001?nV`Ngo0000o`000?l00002ojK1k@?o00000onV`Nd3o`000003
ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l00002ojK1k@Co000000?oY/7]o`000?l0
00000_l000001?nV`Ngo0000o`000?l00002ojK1k@Co00000_nV`Nd3o`000006ojK1kOl0003o0000
ojK1kOl0003oY/7]0_l000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003o000000Ko00000_nV
`Nd3o`0000?oY/7]0ol000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?o
Y/7]o`000?l000000ol000001?nV`Ngo0000o`000?l00002ojK1k@?o00000_nV`Nd4o`000006ojK1
kOl0003o0000ojK1kOl0003oY/7]0_l000000onV`Ngo0000ojK1k@02o`000003ojK1kOl0003o0000
00;o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd4o`000003ojK1kOl0003o0000
00;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000;oY/;]0ol00002ojK2
k@?o000000KoY/;]o`000?l0003oY/;]o`000?nV`^d3o`000003ojK2kOl0003oY/;]00;o00000_nV
`^d2o`0000?oY/;]0ol00003ojK2k@;o00000onV`^d2o`0000?oY/;]0ol00003ojK2k@;o00000onV
`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]00?oY/;]00Oo0000ojK2kOnV`^go0000
ojK2kOl0003oY/;]00;o000000?oY/;]o`000?nV`^d00ol00002ojK2k@;o00000onV`^d2o`0000?o
Y/;]0ol00003ojK2k@03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003o
oo]ZoookJP0foookJP?o00001OnV`Nd00ol0003oY/7]ojK1k@04ojK1k@03o`000?nV`NgoY/7]00;o
00000_nV`Nd00ol0003oY/7]o`000002o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV
`Nd00ol00002ojK1k@03o`000?nV`Ngo000000;o00000_nV`Nd3o`0000CoY/7]0_l00004ojK1k@?o
00000onV`Nd00ol0003oY/7]ojK1k@04ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV
`Nd00onV`Nd00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00;o00000_nV`^d01?l0003o
Y/;]o`000?l00002ojK2k@03o`000?nV`^go000000;o000000?oY/;]o`000?nV`^d00ol00002ojK2
k@03o`000?nV`^go000000;o00000_nV`^d3o`0000?oY/;]0ol00004ojK2k@?o00000onV`^d00ol0
003oY/;]o`000002o`0000;o8F_L00?o03g1o`0AU_l000000onV`^d00ol0003oY/;]ojK2k@03ojK2
k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00_l000000onV`^go0000ojK2k@03o`00
00;oY/;]00?o0000ojK2kOl000000_l000000onV`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]
00?o00000onV`^d3o`0000?oY/;]0ol00004ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@03ojK2
k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2
k@;o00000_nV`^d2o`000003ojK2kOl0003oY/;]00?o000000CoY/;]o`000?nV`^goY/;]0ol00000
0onV`^go0000ojK2k@03o`0000;oY/;]0ol00004ojK2k@?o00000onV`^d5o`000003ojK2kOl0003o
000000GoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d0
0ol0003oY/;]ojK2k@02o`000004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d00ol0
00000onV`^go0000ojK2k@03o`0000?oY/;]00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zoook
JP0RoookJP008?oonfX00ol0003ooo]ZoookJP0QoookJP07o`000?nV`Ngo0000o`000?nV`Ngo0000
ojK1k@02o`000004ojK1kOl0003o0000o`0000;oY/7]0ol00003ojK1k@?o00000_nV`Nd3o`000003
ojK1kOl0003o000000;o00000_nV`Nd4o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l0
00000_l000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@?o000000KoY/7]o`000?l0
003oY/7]o`000?nV`Nd2o`0000;oY/7]00Go0000ojK1kOl0003o0000ojK1k@03o`0000;oY/7]0ol0
0003ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l0
0002ojK1k@Co000000CoY/7]o`000?l0003o00000_nV`Nd3o`0000;oY/7]1?l000000onV`Ngo0000
o`000002o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l00002ojK1k@05o`000?nV`Ngo0000
o`000?nV`Nd00ol00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]1?l000000onV`Ngo0000o`000002
o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o000000?oY/7]
o`000?l000000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l000000onV`Ngo0000
ojK1k@02o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]0ol000000onV`Ngo0000
o`000002o`0000;oY/7]1?l000000onV`^go0000o`000002o`000004ojK2kOl0003o0000o`0000Co
Y/;]00?o0000ojK2kOnV`^d00onV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l00000
0onV`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00;o00000_nV`^d2o`0000?oY/;]0ol00003
ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@02
ojK2k@03o`000?nV`^goY/;]00;oY/;]00?o0000ojK2kOnV`^d00_l000000onV`^go0000ojK2k@02
o`000003ojK2kOl0003oY/;]00;o00000_nV`^d3o`0000;oY/;]00?o0000oookJ_oonfX08ooonfX0
0ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z03;ooo]Z1?l00004ojK1k@;o00001?nV`Nd3
o`0000?oY/7]00?o0000ojK1kOnV`Nd01?nV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`Ngo
Y/7]00?oY/7]00?o0000ojK1kOnV`Nd01?nV`Nd00ol0003oY/7]ojK1k@02o`0000;oY/7]00?o0000
ojK1kOl000000_l000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00?o00000onV`Nd3
o`0000?oY/7]0ol00003ojK1k@?o00001?nV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d01?nV`^d0
0ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d0
0ol0003oY/;]ojK2k@02o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002
o`000003ojK2kOl0003oY/;]00?o00000_nV`^d6o`000004o`14a_l0003o016Fo`0000?oY/;]0ol0
0004ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o
0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@04o`000?nV`^goY/;]ojK2k@;o0000
00?oY/;]o`000?nV`^d00ol000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o
00000_nV`^d3o`0000CoY/;]0ol00003ojK2k@?o00000onV`^d3o`0000CoY/;]00?o0000ojK2kOnV
`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d00ol0003oY/;]ojK2k@02o`000004
ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d02Ol00002ojK2k@?o00001?nV`^d3o`00
00?oY/;]0ol00004ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d00ol0
003oY/;]ojK2k@03ojK2k@04o`000?nV`^goY/;]ojK2k@;o000000?oY/;]o`000?oonfX03OoonfX0
0ol0003ooo]ZoookJP0RoookJP008?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?nV`NgoY/7]
00?o000000?oY/7]o`000?l000000_nV`Nd00ol0003oY/7]o`000002ojK1k@07o`000?nV`Ngo0000
o`000?nV`Ngo0000ojK1k@02o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1k@?o0000
00?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000;oY/7]1?l000000onV`Ngo0000
o`000002o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]0ol000001_nV`Ngo0000
o`000?nV`Ngo0000ojK1k@;o00000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l0
00001?nV`Ngo0000o`000?l00002ojK1k@?o00000onV`Nd3o`000003ojK1kOl0003o000000;o0000
00?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@?o0000
0_nV`Nd3o`0000?oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o000000?oY/7]o`00
0?nV`Nd00_l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol000000onV`Ngo0000o`000003o`00
0003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000001?nV`Ngo0000o`000?l00003
ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@?o0000
00?oY/7]o`000?nV`Nd00_l000001?nV`Ngo0000o`000?l00002ojK1k@Co00000_nV`^d3o`000003
ojK2kOl0003o000000;o00000onV`^d2o`0000?oY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00;o
Y/;]00?o0000ojK2kOnV`^d00_nV`^d00ol0003oY/;]ojK2k@03ojK2k@07o`000?nV`^goY/;]o`00
0?nV`^go0000ojK2k@02o`000003ojK2kOl0003oY/;]00?o000000CoY/;]o`000?l0003o00000onV
`^d2o`0000?oY/;]0_l00003ojK2k@?o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV
`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00_nV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV
`^d00_l000000onV`^go0000oookJP0ToookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000oookJ_oo
nfX0<?oonfX2o`0000;oY/7]00?o0000ojK1kOl000000_l000000onV`Ngo0000ojK1k@03o`0000;o
Y/7]00Co0000ojK1kOl0003o00000onV`Nd3o`0000?oY/7]0ol00004ojK1k@;o00001?nV`Nd3o`00
00?oY/7]00?o0000ojK1kOnV`Nd01?nV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]
00?oY/7]00Co0000ojK1kOnV`NgoY/7]0_l000000onV`Ngo0000ojK1k@03o`0000;oY/7]00Co0000
ojK1kOl0003o00000_nV`Nd00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o00000onV
`^d3o`0000?oY/;]0ol00003ojK2k@?o00001?nV`^d3o`0000?oY/;]00Co0000ojK2kOl0003o0000
0_nV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d0
0_l00002ojK2k@;o00000_lXI=H2oaQMe003o`14a_l0003o000000;o00000_nV`^d00ol0003oY/;]
o`000002o`000003ojK2kOl0003oY/;]00?o00000_nV`^d3o`0000CoY/;]0ol00003ojK2k@?o0000
0onV`^d3o`0000CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@;o0000
1OnV`^d00ol0003oY/;]ojK2k@02o`000004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV
`^d00ol000000onV`^go0000ojK2k@03o`000004ojK2kOl0003oY/;]ojK2k@?o00000_nV`^d3o`00
00?oY/;]0ol00004ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d4o`00
00;oY/;]00?o0000ojK2kOnV`^d00_l00002ojK2k@Go000000?oY/;]o`000?nV`^d00ol000001?nV
`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000_nV`^d3o`0000?oY/;]0ol00004
ojK2k@?o00000onV`^d2o`0000GoY/;]00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0R
oookJP008?oonfX00ol0003ooo]ZoookJP0SoookJP;o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1
k@?o00000_nV`Nd3o`000003ojK1kOl0003o000000;oY/7]00Oo0000ojK1kOl0003o0000ojK1kOl0
003oY/7]00;o000000CoY/7]o`000?l0003o00000_nV`Nd3o`0000?oY/7]0ol000000onV`Ngo0000
o`000002o`000003ojK1kOl0003o000000;o00000_nV`Nd4o`000003ojK1kOl0003o000000;o0000
00CoY/7]o`000?l0003o00000_nV`Nd4o`0000;oY/7]0ol00002ojK1k@?o000000KoY/7]o`000?l0
003oY/7]o`000?nV`Nd2o`0000;oY/7]00Go0000ojK1kOl0003o0000ojK1k@03o`0000;oY/7]0ol0
0002ojK1k@?o00000_nV`Nd4o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l0
00000onV`Ngo0000o`000003o`000004ojK1kOl0003o0000o`0000;oY/7]0ol00002ojK1k@?o0000
00OoY/7]o`000?l0003o0000ojK1kOl0003oY/7]00;o000000?oY/7]o`000?nV`Nd00_l000001?nV
`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o000000;o000000?oY/7]
o`000?l000000ol000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000CoY/7]
o`000?l0003o00000_nV`Nd4o`0000;oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o
000000?oY/7]o`000?nV`^d00ol000001?nV`^go0000o`000?l00003ojK2k@;o00000onV`^d2o`00
00?oY/;]0ol00003ojK2k@;o00000onV`^d2o`0000?oY/;]0ol00003ojK2k@03o`000?nV`^goY/;]
00;oY/;]00?o0000ojK2kOnV`^d00_nV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00ol0
00000onV`^go0000ojK2k@02o`0000;oY/;]0_l00003ojK2k@?o00000onV`^d2o`0000?oY/;]0_l0
0003ojK2k@?o00000_nV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d00ol0003oY/;]ojK2
k@02ojK2k@03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]Zoook
JP0]oookJP?o00001OnV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00CoY/7]00?o
0000ojK1kOnV`Nd00_l00002ojK1k@04o`000?nV`Ngo0000o`0000;oY/7]00?o0000ojK1kOl00000
0_l000000onV`Ngo0000ojK1k@03o`0000;oY/7]00Co0000ojK1kOl0003o00000onV`Nd3o`0000?o
Y/7]0ol00004ojK1k@;o00001?nV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00Co
Y/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/;]ojK2k@03ojK2k@04o`000?nV`^goY/;]ojK2
k@;o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2
kOl000000_l000000onV`^go0000ojK2k@03o`0000;oY/;]0ol00004ojK2k@?o00000onV`^d3o`00
00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d2o`000006obQTe_lNG=;o65gDo`1<bol0003o04?50_l0
0003ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00_l00002ojK2k@03o`000?nV
`^go000000;o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`0000;oY/;]00?o
0000ojK2kOl000000_l00002ojK2k@?o00000onV`^d3o`0000CoY/;]0ol00003ojK2k@03o`000?nV
`^goY/;]00?oY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV
`^d2o`0000;oY/;]0_l000000onV`^go0000ojK2k@03o`000004ojK2kOl0003oY/;]ojK2k@?o0000
00?oY/;]o`000?nV`^d00ol00002ojK2k@?o00000onV`^d6o`000004ojK2kOl0003o0000o`0000?o
Y/;]00?o0000ojK2kOnV`^d01?nV`^d2o`0000CoY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000Go
Y/;]00?o0000ojK2kOnV`^d00_l000000onV`^go0000ojK2k@03o`000004ojK2kOl0003oY/;]ojK2
k@?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@?o00001?nV`^d00ol0003ooo]ZoookJP0:oook
JP03o`000?oonf[ooo]Z02;ooo]Z000PoookJP03o`000?oonf[ooo]Z02Gooo]Z0_l000000onV`Ngo
0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l00002ojK1k@?o
00000_nV`Nd3o`0000;oY/7]0ol000000onV`Ngo0000o`000002ojK1k@03o`000?nV`Ngo000000;o
Y/7]00Go0000ojK1kOl0003o0000ojK1k@03o`0000;oY/7]0ol00003ojK1k@?o000000?oY/7]o`00
0?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o00000_nV`Nd4o`00
0003ojK1kOl0003o000000;o000000CoY/7]o`000?l0003o00000_nV`Nd4o`0000;oY/7]0ol00000
1_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o000000?oY/7]o`000?nV`Nd00_l00002ojK1k@Co0000
00CoY/7]o`000?l0003o00000_nV`Nd3o`000003ojK1kOl0003o000000;o00000_nV`Nd4o`000003
ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000;o
Y/7]0ol00002ojK1k@?o000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd3o`000003ojK1kOl0003o
Y/7]00;o000000CoY/7]o`000?l0003o00000_nV`Nd3o`0000;oY/7]1?l000000onV`Ngo0000o`00
0002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l00002ojK1k@Co000000Co
Y/7]o`000?l0003o00000_nV`Nd3o`0000;oY/7]0ol000001onV`^go0000o`000?l0003oY/;]o`00
0?nV`^d00_l000000onV`^go0000ojK2k@02o`0000;oY/;]0_l00003ojK2k@?o00000onV`^d2o`00
00?oY/;]0_l00003ojK2k@?o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]
00;oY/;]00?o0000ojK2kOnV`^d00onV`^d01Ol0003oY/;]ojK2kOl0003oY/;]00Co000000?oY/;]
o`000?nV`^d00ol000001?nV`^go0000o`000?l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0ol0
0003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Zoook
JP17oookJP03o`000?oonf[ooo]Z02Wooo]Z1?l00003ojK1k@?o00001?nV`Nd2o`0000CoY/7]0ol0
0003ojK1k@03o`000?nV`NgoY/7]00CoY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1
k@03ojK1k@03o`000?nV`NgoY/7]00CoY/7]00?o0000ojK1kOnV`Nd00_l000000onV`Ngo0000ojK1
k@03o`0000;oY/7]00?o0000ojK1kOl000000_l000000onV`Ngo0000ojK1k@03o`0000;oY/7]0ol0
0004ojK1k@?o00000onV`Nd3o`0000?oY/;]0ol00004ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o
0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o
0000ojK2kOnV`^d00_l00002ojK2k@Go000000?oY/;]o`000?nV`^d00ol000000onV`^go0000ojK2
k@03o`0000?oY/;]0ol00002ojK2k@0;o`000?m;M]_oBgKKo`000?lNG=;o0000o`1<bol0003o04?5
o`0S[?l000000onV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03
ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@02
o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003o
Y/;]00?o00000_nV`^d3o`0000CoY/;]0ol00003ojK2k@?o00000onV`^d3o`0000CoY/;]00?o0000
ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d00ol0003oY/;]ojK2k@02
o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?l000001?l000000onV`^go0000ojK2k@03
o`0000;oY/;]0ol00004ojK2k@?o00000onV`^d3o`0000?oY/;]0ol00004ojK2k@03o`000?nV`^go
Y/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d00_l00000
1?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003ooo]Z00_ooo]Z00?o0000oookJ_oonfX08_oo
nfX0023ooo]Z00?o0000oookJ_oonfX09_oonfX2o`000003ojK1kOl0003o000000;o00000_nV`Nd3
o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]
o`000?l000000_l00002ojK1k@?o00000_nV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]
0_l00002ojK1k@05o`000?nV`Ngo0000o`000?nV`Nd00ol00002ojK1k@?o00000_nV`Nd3o`0000?o
Y/7]0ol000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l0
00000_l00002ojK1k@Co000000CoY/7]o`000?l0003o00000_nV`Nd3o`0000;oY/7]1?l000000onV
`Ngo0000o`000002o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l000001?nV`Ngo0000o`00
0?l00003ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l00000
0_l00002ojK1k@Co000000?oY/7]o`000?l000000_l000001?nV`Ngo0000o`000?l00002ojK1k@Co
00000_nV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l000000onV`Ngo0000ojK1k@02
o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o000000?o000000?oY/7]
o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000CoY/;]
o`000?l0003o00001OnV`^d00ol0003oY/;]ojK2k@02ojK2k@07o`000?nV`^goY/;]o`000?nV`^go
0000ojK2k@02o`000003ojK2kOl0003oY/;]00?o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@?o
00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d3o`0000?oY/;]00?o0000ojK2kOnV
`^d00_nV`^d2o`0000?oY/;]00Oo0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00?o00000_nV`^d2
o`0000?oY/;]0_l00003ojK2k@?o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?oonf[o
oo]Z027ooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0WoookJP?o00000_nV`Nd0
1?l0003oY/7]o`000?l00002ojK1k@03o`000?nV`Ngo000000;o000000?oY/7]o`000?nV`Nd00ol0
00000onV`Ngo0000ojK1k@03o`0000?oY/7]0ol00003ojK1k@?o00000onV`Nd3o`0000CoY/7]0ol0
0003ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd01?nV`Nd00ol0003oY/7]ojK1
k@03ojK1k@03o`000?nV`NgoY/7]00;o00000_nV`Nd00ol0003oY/7]o`000002o`000003ojK1kOl0
003oY/7]00?o00000_nV`^d01?l0003oY/;]o`000?l00002ojK2k@03o`000?nV`^go000000;o0000
0_nV`^d3o`0000?oY/;]0ol00004ojK2k@?o00000onV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d0
1?nV`^d2o`0000CoY/;]00?o0000ojK2kOnV`^d00onV`^d01?l0003oY/;]ojK2kOnV`^d2o`000003
ojK2kOl0003oY/;]00Go000000WoBgKKobaNdOl/G]7o0000oa]IdOl0003o04G6o`0]]Ol06:800_l0
00000onV`^go0000ojK2k@03o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d3o`0000CoY/;]0ol0
0003ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2
k@03ojK2k@03o`000?nV`^goY/;]00;o000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000
ojK2k@03o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`0000;oY/;]
0ol00003ojK2k@?o00001?nV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d00onV`^d5o`0000;oY/;]
00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@02o`000004ojK2kOl0003oY/;]ojK2k@?o
000000?oY/;]o`000?l000000ol000000onV`^go0000ojK2k@03o`000004ojK2kOl0003oY/;]ojK2
k@?o00000_nV`^d3o`0000?oY/;]0ol00004ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@03ojK2
k@;o00001OnV`^d00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z02;ooo]Z000OoookJP03
o`000?oonf[ooo]Z02Sooo]Z0_l00003ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol000000onV`Ngo
0000o`000002o`0000;oY/7]0ol00002ojK1k@Co000000?oY/7]o`000?l000000_l000000onV`Ngo
0000o`000002o`0000;oY/7]0ol00002ojK1k@?o000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd2
o`000003ojK1kOl0003oY/7]00;o00000_nV`Nd01Ol0003oY/7]o`000?l0003oY/7]00?o00000_nV
`Nd3o`0000;oY/7]0ol00002ojK1k@Co000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`00
0002o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o000000?o
Y/7]o`000?l000000_nV`Nd01ol0003oY/7]o`000?l0003oY/7]o`000?nV`Nd00_l000001?nV`Ngo
0000o`000?l00002ojK1k@?o00000onV`Nd3o`000003ojK1kOl0003o000000;o000000?oY/7]o`00
0?l000000_l000000onV`Ngo0000o`000002o`0000;oY/7]1?l000001?nV`Ngo0000o`000?l00002
ojK1k@?o00000_nV`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo0000ojK1k@02o`000003ojK1
kOl0003oY/7]00;o000000CoY/7]o`000?l0003o00000_nV`Nd4o`0000;oY/7]0ol000000onV`Ngo
0000o`000002o`000003ojK1kOl0003o000000;o00000onV`^d3o`0000?oY/;]0_l00003ojK2k@03
o`000?nV`^goY/;]00;oY/;]00?o0000ojK2kOnV`^d00_nV`^d00ol0003oY/;]ojK2k@02o`000003
ojK2kOl0003oY/;]00;o000000?oY/;]o`000?nV`^d00_l00002ojK2k@?o00000onV`^d2o`0000?o
Y/;]0_l00003ojK2k@;o00000onV`^d3o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d00ol0003o
Y/;]ojK2k@02ojK2k@03o`000?nV`^goY/;]00;o000000?oY/;]o`000?nV`^d00_l000000onV`^go
0000ojK2k@02o`0000;oY/;]0ol00002ojK2k@?o00000onV`^d2o`0000?oY/;]00?o0000oookJ_oo
nfX08?oonfX00ol0003ooo]ZoookJP16oookJP03o`000?oonf[ooo]Z02Gooo]Z0_l00006ojK1k@03
o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@03ojK1k@04
o`000?nV`NgoY/7]ojK1k@;o000000?oY/7]o`000?nV`Nd00ol00002ojK1k@04o`000?nV`Ngo0000
o`0000;oY/7]00?o0000ojK1kOl000000_l00002ojK1k@?o00001?nV`Nd2o`0000CoY/7]0ol00003
ojK1k@?o00001?nV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000
ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00;o00000_nV`^d0
1?l0003oY/;]o`000?l00002ojK2k@03o`000?nV`^go000000;o000000?oY/;]o`000?nV`^d00ol0
0002ojK2k@04o`000?nV`^go0000o`0000?oY/;]0ol00002ojK2k@Co00001?nV`^d2o`0000CoY/;]
00?o0000ojK2kOnV`^d00onV`^d01Ol0003oY/;]ojK2kOnV`^go000000;oAFcD00?o0000obaNdOl/
G]400ol000001?l0ALKo02feo`000?l00002ojK2k@04o`000?nV`^goY/;]ojK2k@;o000000?oY/;]
o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`000004ojK2kOl0003oY/;]ojK2k@?o00000_nV
`^d3o`0000?oY/;]0ol00003ojK2k@?o00001?nV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d00onV
`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV
`^goY/;]00;o000000?oY/;]o`000?nV`^d00ol000001?nV`^go0000ojK2kOnV`^d3o`000003ojK2
kOl0003oY/;]00?o00000_nV`^d9o`0000CoY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00?oY/;]
0_l00005ojK2k@;o00001?nV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00000_nV`^d2o`000003ojK2
kOl0003oY/;]00?o000000CoY/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03o`0000;o
Y/;]0ol00003ojK2k@?o00001?nV`^d00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z027o
oo]Z000OoookJP03o`000?oonf[ooo]Z02Wooo]Z00Oo0000ojK1kOl0003o0000ojK1kOl0003oY/7]
00;o000000?oY/7]o`000?nV`Nd00_l000001?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd3
o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l00002ojK1k@Co000000?oY/7]
o`000?l000000_l000001?nV`Ngo0000o`000?l00002ojK1k@Co00000_nV`Nd3o`0000;oY/7]0ol0
00001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o000000?oY/7]o`000?nV`Nd00_l00002ojK1k@?o
00000_nV`Nd3o`0000;oY/7]0ol000000onV`Ngo0000o`000002o`0000;oY/7]1?l000000onV`Ngo
0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l00002ojK1k@?o
00000_nV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l000000onV`Ngo0000ojK1k@03
o`000004ojK1kOl0003o0000o`0000;oY/7]0ol00002ojK1k@?o000000?oY/7]o`000?l000000ol0
00000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l0
00000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@?o000000KoY/7]o`000?l0003oY/7]
o`000?nV`Nd2o`000003ojK1kOl0003oY/7]00?o000000CoY/7]o`000?l0003o00000_nV`Nd3o`00
00?oY/;]0_l00003ojK2k@?o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00001?nV`^d00ol0
003oY/;]ojK2k@02ojK2k@03o`000?nV`^goY/;]00;oY/;]00Oo0000ojK2kOnV`^go0000ojK2kOl0
003oY/;]00?o000000?oY/;]o`000?nV`^d00_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0ol0
0003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o
0000ojK2kOnV`^d00_nV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l000000onV`^go
0000ojK2k@03o`0000;oY/;]0_l00003ojK2k@03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX0A_oonfX00ol0003ooo]ZoookJP0SoookJP;o00000onV`Nd3o`0000?oY/7]0ol00003ojK1k@?o
00001?nV`Nd2o`0000CoY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@04ojK1k@03
o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd00_l00002ojK1k@03o`000?nV`Ngo000000;o
000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03o`0000;oY/7]00?o0000ojK1kOl0
00000_l00002ojK1k@?o00000onV`Nd3o`0000CoY/7]0ol00003ojK2k@?o00000onV`^d00ol0003o
Y/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003o
Y/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00;o000000?oY/;]o`000?nV`^d01_l000001onV`^go
0000o`000?l0003oY/;]o`000?nV`^d00ol00002ojK2k@?o00001?nV`^d4o`000008odE/e?l0003o
=f?BobaNdOl0003o<fOFo`000?l0A/L3o`0000CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003o
Y/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00002ojK2k@;o000000?oY/;]o`000?nV
`^d00ol000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l000000onV`^go
0000ojK2k@03o`0000;oY/;]0ol00004ojK2k@?o00000onV`^d3o`0000?oY/;]0ol00004ojK2k@03
o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV
`^d00_l000000onV`^go0000o`000003o`0000;oY/;]00?o0000ojK2kOl000000_l000000onV`^go
0000ojK2k@03o`0000;oY/;]0ol00004ojK2k@?o00000onV`^d3o`0000?oY/;]0ol00004ojK2k@03
o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV
`^d00_l000000onV`^go0000ojK2k@03o`000004ojK2kOl0003oY/;]ojK2k@?o000000?oY/;]o`00
0?oonfX02_oonfX00ol0003ooo]ZoookJP0QoookJP007ooonfX00ol0003ooo]ZoookJP0ZoookJP03
o`000?nV`NgoY/7]00?o00000_nV`Nd4o`000006ojK1kOl0003oY/7]ojK1kOl0003oY/7]0_l00000
0onV`Ngo0000ojK1k@02o`000004ojK1kOl0003o0000o`0000;oY/7]0ol00003ojK1k@?o000000?o
Y/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o00000_nV
`Nd4o`000003ojK1kOl0003o000000;o000000CoY/7]o`000?l0003o00000_nV`Nd4o`0000;oY/7]
0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o000000?oY/7]o`000?nV`Nd00_l000001?nV
`Ngo0000o`000?l00003ojK1k@Co000000GoY/7]o`000?l0003o0000ojK1k@04o`000003ojK1kOl0
003o000000;o00000_nV`Nd4o`000003ojK1kOl0003o000000;o000000CoY/7]o`000?l0003o0000
0_nV`Nd3o`0000;oY/7]1?l000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o000000?oY/7]o`00
0?nV`Nd00_l000001?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o
000000;o000000?oY/7]o`000?l000000_l00002ojK1k@Co000000?oY/7]o`000?l000000_l00000
1?nV`Ngo0000o`000?l00002ojK1k@?o00000_nV`Nd4o`000006ojK1kOl0003o0000ojK1kOl0003o
Y/7]0_l000000onV`^go0000ojK2k@02o`0000;oY/;]0_l00004ojK2k@;o00000onV`^d2o`0000?o
Y/;]0_l00003ojK2k@?o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]00;o
Y/;]00?o0000ojK2kOnV`^d00onV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l00000
0onV`^go0000ojK2k@02o`0000;oY/;]0ol00002ojK2k@?o00000onV`^d2o`0000?oY/;]0_l00003
ojK2k@?o00000_nV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d00ol0003oY/;]ojK2k@02
ojK2k@03o`000?nV`^goY/;]00;o000000?oY/;]o`000?l000000_l000000onV`^go0000oookJP0P
oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX08?oonfX3o`0000;oY/7]0_l00000
0onV`Ngo0000ojK1k@03o`0000;oY/7]00Co0000ojK1kOl0003o00000_nV`Nd00ol0003oY/7]o`00
0002o`000003ojK1kOl0003oY/7]00?o00000onV`Nd2o`0000CoY/7]0ol00003ojK1k@?o00001?nV
`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd00onV
`Nd00ol0003oY/7]ojK1k@04ojK1k@03o`000?nV`NgoY/7]00;o00000_nV`Nd01?l0003oY/7]o`00
0?l00002ojK1k@03o`000?nV`Ngo000000;o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000
ojK2k@03o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d3o`0000CoY/;]0ol00003ojK2k@03o`00
0?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00ol000000onV`^go0000ojK2k@04ojK2k@03o`00
0?nV`^goY/;]00;o00000_nV`^d00ol0003oY/;]o`000002o`000004ojK2kOl0003oY/;]o`0000;o
CfgA0_l000002?lgHm;o0000o`000?lcImKo4Dc8o`aAcOl0003o[CD00ol00002ojK2k@?o00000onV
`^d3o`0000?oY/;]0ol00004ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV
`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00_l0
0002ojK2k@03o`000?nV`^go000000;o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000ojK2
k@03o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d3o`0000CoY/;]0ol00003ojK2k@Go000000?o
Y/;]o`000?nV`^d01OnV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00;o000000Co
Y/;]o`000?nV`^goY/;]0ol000000onV`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00?o0000
00CoY/;]o`000?nV`^goY/;]0ol00002ojK2k@?o00000onV`^d3o`0000?oY/;]0ol00004ojK2k@03
o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000oookJ_oo
nfX02?oonfX00ol0003ooo]ZoookJP0QoookJP007ooonfX00ol0003ooo]ZoookJP0[oookJP;o0000
0_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o000000;oY/7]
00?o0000ojK1kOl000000_nV`Nd01Ol0003oY/7]o`000?l0003oY/7]00?o00000_nV`Nd3o`0000;o
Y/7]0ol00002ojK1k@Co000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003
ojK1kOl0003o000000;o00000_nV`Nd4o`000004ojK1kOl0003o0000o`0000;oY/7]0ol00002ojK1
k@?o000000?oY/7]o`000?l000000_nV`Nd00ol0003oY/7]o`000003o`000004ojK1kOl0003o0000
ojK1k@?o00000_nV`Nd3o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o
000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002
ojK1k@?o00000_nV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0ol000000onV`Ngo0000
ojK1k@02o`000004ojK1kOl0003o0000o`0000;oY/7]0ol00002ojK1k@Co000000?oY/7]o`000?l0
00000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l0
00000_l00002ojK1k@?o00000_nV`Nd3o`0000CoY/;]00Oo0000ojK2kOnV`^go0000ojK2kOl0003o
Y/;]00?o000000?oY/;]o`000?nV`^d00_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0ol00003
ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@?o00000_nV`^d00ol0003oY/;]ojK2k@03
ojK2k@03o`000?nV`^goY/;]00;oY/;]00Oo0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00;o0000
0_nV`^d3o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0ol00003ojK2k@;o0000
0onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`00
0?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0A_oonfX00ol0003ooo]ZoookJP0LoookJPCo0000
0onV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00CoY/7]00?o0000ojK1kOnV`Nd0
0onV`Nd00ol0003oY/7]ojK1k@03ojK1k@04o`000?nV`NgoY/7]ojK1k@;o000000?oY/7]o`000?nV
`Nd00ol000000onV`Ngo0000ojK1k@03o`0000;oY/7]00?o0000ojK1kOl000000_l00002ojK1k@?o
00000onV`Nd3o`0000CoY/7]0_l00004ojK1k@?o00000onV`Nd00ol0003oY/7]ojK1k@04ojK1k@03
o`000?nV`NgoY/7]00?oY/7]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@04
o`000?nV`^goY/;]ojK2k@;o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`00
00;oY/;]00?o0000ojK2kOl000000_l00002ojK2k@?o00000onV`^d3o`0000CoY/;]1Ol000001?nV
`^go0000o`000?l00003ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d3
o`000005odm]dOmAL]GoDG;EocMSd_l000000_l^GLl2oa5<b003o`aAcOl08Zko[CD000?o000000?o
Y/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l0
0002ojK2k@?o00000onV`^d3o`0000CoY/;]0ol00003ojK2k@?o00000onV`^d00ol0003oY/;]ojK2
k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d01?l0003oY/;]ojK2
kOnV`^d2o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol000001?nV`^go0000
ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00So00000onV`^d3o`0000CoY/;]0ol00003ojK2k@03
o`000?nV`^goY/;]00?oY/;]0_l00005ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00004ojK2k@;o
00000_nV`^d2o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol000001?nV`^go
0000ojK2kOnV`^d3o`0000;oY/;]0ol00003ojK2k@?o00000onV`^d3o`0000CoY/;]00?o0000oook
J_oonfX01ooonfX00ol0003ooo]ZoookJP0QoookJP007ooonfX00ol0003ooo]ZoookJP0]oookJP;o
000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o
00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd2
o`0000;oY/7]00?o0000ojK1kOl000000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o000000?oY/7]
o`000?l000000_l00002ojK1k@Co000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002
o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd3
o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]
0ol000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o00000_nV`Nd4o`000003ojK1
kOl0003o000000;o000000?oY/7]o`000?l000000_l000001?nV`Ngo0000o`000?l00002ojK1k@Co
00000_nV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l000000onV`Ngo0000ojK1k@02
o`0000;oY/7]0ol00002ojK1k@?o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002
o`000003ojK1kOl0003o000000?o000000?oY/7]o`000?l000000_l00003ojK1k@;o00000onV`^d0
0ol0003oY/;]ojK2k@02ojK2k@03o`000?nV`^goY/;]00?oY/;]00Oo0000ojK2kOnV`^go0000ojK2
kOl0003oY/;]00;o00000_nV`^d2o`0000?oY/;]0ol00003ojK2k@;o00000onV`^d2o`0000?oY/;]
0_l00003ojK2k@;o00000onV`^d3o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]00;oY/;]
00Oo0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00?o000000?oY/;]o`000?l000000_l00002ojK2
k@;o00000onV`^d2o`0000?oY/;]0ol00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2
k@?o00000onV`^d00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oook
J_oonfX06OoonfX3o`0000?oY/7]0_l00004ojK1k@;o00001?nV`Nd3o`0000?oY/7]0ol00004ojK1
k@;o00001?nV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1
kOnV`Nd01?nV`Nd00ol0003oY/7]ojK1k@02o`0000;oY/7]00Co0000ojK1kOl0003o00000_nV`Nd0
0ol0003oY/7]o`000002o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol00003
ojK1k@?o00000onV`Nd3o`0000?oY/;]0ol00004ojK2k@;o00001?nV`^d01ol0003oY/;]ojK2kOnV
`^go0000ojK2kOl000001OnV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00;o0000
00?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV`^go000000?o000000?oDCNDo`000?l00000
0_l000000onV`^go0000ojK2k@03o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d2ofAid`;o0000
0_mAL]D2o`000006obiMcol0003o4Dc8o`U7a_l<DLgo02:^0_l00003ojK2k@03o`000?nV`^goY/;]
00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@02o`000003ojK2kOl0003oY/;]
00?o00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`00
0?nV`^d00ol00003ojK2k@?o00000onV`^d3o`0000?oY/;]0ol00003ojK2k@;o00001OnV`^d00ol0
003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00004ojK2k@Ko000000?oY/;]o`00
0?nV`^d00ol00002ojK2k@03o`000?nV`^go000000;o000000?oY/;]o`000?nV`^d00ol00002ojK2
k@?o00000onV`^d3o`0000CoY/;]0ol00003ojK2k@?o00000onV`^d2o`0000GoY/;]00?o0000ojK2
kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@;o00000_nV`^d2o`000003ojK2kOl0003oY/;]
00?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@?o00003OoonfX00ol0003ooo]ZoookJP0Qoook
JP007ooonfX00ol0003ooo]ZoookJP0^oookJP;o000000?oY/7]o`000?l000000_l00002ojK1k@?o
00000_nV`Nd4o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000001?nV`Ngo
0000o`000?l00002ojK1k@Co00000_nV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l0
00000onV`Ngo0000ojK1k@02o`000004ojK1kOl0003o0000o`0000?oY/7]0ol00002ojK1k@?o0000
00?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@Co0000
00?oY/7]o`000?l000000_l000001?nV`Ngo0000o`000?l00002ojK1k@Co000000KoY/7]o`000?l0
003oY/7]o`000?nV`Nd2o`000003ojK1kOl0003oY/7]00;o000000CoY/7]o`000?l0003o00000_nV
`Nd3o`0000?oY/7]0ol000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?o
Y/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000;oY/7]1?l000001?nV`Ngo0000o`00
0?l00002ojK1k@?o00000_nV`Nd3o`000007ojK1kOl0003o0000o`000?nV`Ngo0000ojK1k@02o`00
0004ojK1kOl0003o0000o`0000;oY/7]0ol00002ojK1k@?o000000?oY/7]o`000?l000000ol00003
ojK1k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@02
ojK2k@07o`000?nV`^goY/;]o`000?nV`^go0000ojK2k@02o`000003ojK2kOl0003oY/;]00?o0000
0_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0ol00003ojK2k@;o0000
0onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d00ol0003oY/;]ojK2k@03ojK2k@07o`00
0?nV`^goY/;]o`000?nV`^go0000ojK2k@02o`000003ojK2kOl0003oY/;]00;o00000_nV`^d3o`00
00;oY/;]0ol00003ojK2k@;o00000onV`^d2o`0000?oY/;]0ol00002ojK2k@03o`000?oonf[ooo]Z
01kooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0FoookJP?o00000onV`Nd2o`00
0003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol00002ojK1k@04o`000?nV`Ngo0000
o`0000;oY/7]00?o0000ojK1kOl000000_l00002ojK1k@?o00000onV`Nd3o`0000CoY/7]0_l00004
ojK1k@?o00000onV`Nd00ol0003oY/7]ojK1k@04ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000
ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@03ojK1k@04o`000?nV`NgoY/7]ojK1k@;o000000?o
Y/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l0
0002ojK2k@?o00000onV`^d9o`0000CoY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o
0000ojK2kOnV`^d01?nV`^d01?l0003oY/;]ojK2kOl00002oe4gU003obTKR_l0003o000000;o0000
00?oY/;]o`000?nV`^d00_nV`^d2o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d0
1Ol000001_mTNM?o0000oe5ZcOmAJ/goDG;Eo`0000;o>Uo=00Go0000oamCbol0003o2DO6o`0/]@03
o`0000?oY/;]0ol00004ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^go
Y/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@04o`000?nV`^go
Y/;]ojK2k@;o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`000003ojK2kOl0
003oY/;]00?o00000onV`^d3o`0000?oY/;]0ol00003ojK2k@?o00001?nV`^d4o`0000;oY/;]00?o
0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o
0000ojK2kOnV`^d00_l000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l0
00000onV`^go0000ojK2k@03o`0000;oY/;]0ol00004ojK2k@?o00000onV`^d3o`0000?oY/;]0ol0
0003ojK2k@;o00001OnV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00;o00004Ooo
nfX00ol0003ooo]ZoookJP0QoookJP007ooonfX00ol0003ooo]ZoookJP0_oookJP;o00000onV`Nd3
o`0000;oY/7]0ol000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]
o`000?l000000_l00002ojK1k@?o00000_nV`Nd4o`000004ojK1kOl0003o0000o`0000;oY/7]0ol0
0002ojK1k@Co000000KoY/7]o`000?nV`NgoY/7]o`000?nV`Nd2o`000003ojK1kOl0003oY/7]00;o
000000CoY/7]o`000?l0003o00000_nV`Nd3o`0000?oY/7]0ol000000onV`Ngo0000o`000007o`00
0003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd3o`00
00;oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o00000_nV`Nd01Ol0003oY/7]o`00
0?l0003oY/7]00?o00000_nV`Nd3o`0000;oY/7]0ol000000onV`Ngo0000o`000002o`0000;oY/7]
1?l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l00000
0_l000000onV`Ngo0000o`000002o`0000;oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1
k@;o000000?oY/7]o`000?nV`Nd00_l000001?nV`Ngo0000o`000?l00004ojK1k@;o00000onV`Nd2
o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d3o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^go
Y/;]00;oY/;]00?o0000ojK2kOnV`^d00_nV`^d00ol0003oY/;]ojK2k@02o`000003ojK2kOl0003o
000000;o000000?oY/;]o`000?nV`^d00_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0ol00003
ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@?o00000_nV`^d2o`0000CoY/;]00?o0000
ojK2kOnV`^d00_nV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l000000onV`^go0000
ojK2k@03o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000oookJ_oonfX0
7OoonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z01?ooo]Z0ol00004ojK1k@03o`00
0?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@04ojK1k@03o`00
0?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd00_l00002ojK1k@04o`000?nV`Ngo0000o`0000;o
Y/7]00?o0000ojK1kOl000000_l000000onV`Ngo0000ojK1k@03o`0000;oY/7]00Co0000ojK1kOl0
003o00000onV`Nd3o`0000?oY/7]0ol00003ojK1k@?o00001?nV`Nd2o`0000CoY/7]00?o0000ojK1
kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2
kOnV`^d00_l00002ojK2k@04o`000?nV`^go0000o`0000;oY/;]0_l000001_o^]YKo0000on:YV?oR
ZISo0000ojK2k@?o000000?oY/;]o`000?nV`^d00ol00003ojK2k@;o00001?nV`^d3o`0000?oY/;]
0ol00002oe4gU0Go00000onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]
00Co0000ojK2kOnV`^go00000omUM<d2o`0000;oDF[=0_l000000oljGlgo?6C@o`000002oa18a@03
o`000?l08Jgo000000?o00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o
00000_nV`^d3o`0000CoY/;]0ol00003ojK2k@?o00000onV`^d3o`0000CoY/;]00?o0000ojK2kOnV
`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00Co0000ojK2kOnV
`^goY/;]0_l000000onV`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0
003oY/;]o`000007o`0000?oY/;]0ol00003ojK2k@?o00001?nV`^d3o`0000?oY/;]00?o0000ojK2
kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2
kOnV`^d00_l000000onV`^go0000ojK2k@04o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`00
0?nV`^d00ol00002ojK2k@?o00001?nV`^d3o`0000?oY/;]0ol00003ojK2k@03o`000?oonf[ooo]Z
01;ooo]Z00?o0000oookJ_oonfX08OoonfX001kooo]Z00?o0000oookJ_oonfX0<OoonfX01ol0003o
Y/7]o`000?l0003oY/7]o`000?nV`Nd00_l000001?nV`Ngo0000o`000?l00002ojK1k@?o00000_nV
`Nd3o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?o
Y/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o000000Ko
Y/7]o`000?l0003oY/7]o`000?nV`Nd2o`0000;oY/7]00Go0000ojK1kOl0003o0000ojK1k@08o`00
00;oY/7]0ol000000onV`Ngo0000o`000002o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`00
0003ojK1kOl0003o000000;o000000CoY/7]o`000?l0003o00000_nV`Nd4o`0000;oY/7]0ol00000
1_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o000000?oY/7]o`000?nV`Nd00_l000001?nV`Ngo0000
o`000?l00003ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l0
00000_l000000onV`Ngo0000o`000002o`0000;oY/7]1?l000001?nV`Ngo0000o`000?l00002ojK1
k@?o00000_nV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1
k@02o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0ol00003ojK2k@;o00000onV
`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]00;oY/;]00?o0000ojK2kOnV`^d00onV
`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l000000onV`^go0000ojK2k@02o`0000;o
Y/;]0ol00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d3o`0000?o
Y/;]0_l00003ojK2k@03o`000?nV`^goY/;]00;oY/;]00?o0000ojK2kOnV`^d00_nV`^d00ol0003o
Y/;]ojK2k@02o`000003ojK2kOl0003o000000;o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@03
o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0AOoonfX00ol0003ooo]ZoookJP0@oookJP?o
000000?oY/7]o`000?nV`Nd00ol00003ojK1k@;o00001?nV`Nd2o`0000CoY/7]0ol00003ojK1k@?o
00001?nV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV
`Nd00onV`Nd00ol0003oY/7]ojK1k@04ojK1k@03o`000?nV`NgoY/7]00;o000000?oY/7]o`000?nV
`Nd00ol00002ojK1k@04o`000?nV`Ngo0000o`0000;oY/7]00?o0000ojK1kOl000000_l00002ojK1
k@?o00000onV`Nd3o`0000CoY/7]0_l00004ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@04ojK2
k@03o`000?nV`^goY/;]00?oY/;]0ol00002on:YV0;o00001OnV`^d01?l0003oY/;]ojK2kOnV`^d2
o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d01?l000000omnDiCo0000oeXkTP03
o`000003obTLS?l007So000000;o00000onV`^d3o`0000?oY/;]0ol00004ojK2k@;o00000omUM<d3
o`000007oe5ZcOl0003o@fC>od=Tc_l0003o?6C@o`000002oa18a@04o`000?l08Jgo0000o`0000Co
Y/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@02o`0000;oY/;]00?o0000ojK2kOl0
00000_l000000onV`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00?o00000_nV`^d3o`0000Co
Y/;]0ol00003ojK2k@?o00000onV`^d3o`0000CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003o
Y/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]1_l000000onV`^go0000ojK2k@03o`000003
ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o
00000_nV`^d3o`0000?oY/;]0ol00004ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@03ojK2k@;o
00001OnV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00;o000000CoY/;]o`000?nV
`^goY/;]0ol000000onV`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00?o00005_oonfX00ol0
003ooo]ZoookJP0QoookJP007_oonfX00ol0003ooo]ZoookJP0boookJP03o`000?nV`NgoY/7]00?o
000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd2o`0000;oY/7]00?o0000ojK1kOl000000_nV`Nd3
o`0000;oY/7]0ol00002ojK1k@?o000000?oY/7]o`000?l000000_l00002ojK1k@Co000000?oY/7]
o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]
o`000?l000000_l00002ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o000000;o000000KoY/7]
o`000?l0003oY/7]o`000?nV`Nd2o`000004ojK1kOl0003o0000o`0000?oY/7]0ol000000onV`Ngo
0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo
0000o`000002o`0000;oY/7]1?l000001?nV`Ngo0000o`000?l00002ojK1k@?o00000_nV`Nd3o`00
0006ojK1kOl0003o0000ojK1kOl0003oY/7]0ol000000onV`Ngo0000ojK1k@02o`000004ojK1kOl0
003o0000o`0000;oY/7]0ol00002ojK1k@?o000000?oY/7]o`000?l000000ol000000onV`Ngo0000
o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000001?nV`Ngo0000
o`000?l00004ojK1k@03o`000?nV`NgoY/7]00?oY/7]00Oo0000ojK2kOnV`^go0000ojK2kOl0003o
Y/;]00;o000000?oY/;]o`000?nV`^d00_l00002ojK2k@;o00000onV`^d3o`0000?oY/;]0_l00003
ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@02
ojK2k@03o`000?nV`^goY/;]00;oY/;]00Oo0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00?o0000
00?oY/;]o`000?l000000_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@?o0000
0onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d00ol0003oY/;]ojK2k@02ojK2k@03o`00
0?nV`^goY/;]00;o000000?oY/;]o`000?l000000_l000000onV`^go0000ojK2k@02o`0000;oY/;]
00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z00kooo]Z
0ol00005ojK1k@04o`000?nV`NgoY/7]ojK1k@;o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo
0000ojK1k@03o`0000;oY/7]00Co0000ojK1kOl0003o00000_nV`Nd00ol0003oY/7]o`000002o`00
00;oY/7]0ol00003ojK1k@?o00001?nV`Nd2o`0000CoY/7]0ol00003ojK1k@03o`000?nV`NgoY/7]
00?oY/7]00?o0000ojK1kOnV`Nd01?nV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]
00;o00000_nV`Nd01?l0003oY/7]o`000?l00002ojK1k@03o`000?nV`Ngo000000;o000000?oY/;]
o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`0000?oY/;]0ol00003ojK2k@?o000000CoY/;]
o`000?o^^9Sok[RH0ol000000ooFWI[o0000o`000002o`0000CoY/;]00?o0000ojK2kOnV`^d00onV
`^d00ol0003oY/;]ojK2k@02ojK2k@Co00001?mnDi@01?mJ>i;o0000oe<jU_mC>YH7o`000003ojK2
kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`000007ojK2kOmdO<goM7c=o`000?mU
M<go0000oem`c@03oeU^cP;o000000So@fC>ocULboliG<_o?6C@ob1=aOl@B<Go5dg8o`0T/0Co0000
0onV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`00
0?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00_l00002ojK2k@03o`000?nV`^go000000;o0000
00?oY/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl00000
0_l00002ojK2k@?o00000onV`^d3o`0000?oY/;]1Ol00002ojK2k@03o`000?nV`^goY/;]00?oY/;]
00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00?oY/;]
00?o0000ojK2kOnV`^d00_l000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl00000
0_l000000onV`^go0000ojK2k@03o`0000;oY/;]0ol00003ojK2k@?o00001?nV`^d3o`0000?oY/;]
00?o0000ojK2kOnV`^d00onV`^d2o`0000GoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003ooo]Z
oookJP0GoookJP03o`000?oonf[ooo]Z027ooo]Z000NoookJP03o`000?oonf[ooo]Z03?ooo]Z0_l0
0002ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o
000000?oY/7]o`000?nV`Nd00_l000001?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV`Nd3o`00
0003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`00
00;oY/7]1?l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000CoY/7]o`00
0?l0003o00000_nV`Nd3o`000003ojK1kOl0003o000000;oY/7]00Go0000ojK1kOl0003o0000ojK1
k@03o`0000;oY/7]0ol00002ojK1k@?o000000?oY/7]o`000?l000000_l00002ojK1k@Co000000?o
Y/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000Co
Y/7]o`000?l0003o00000_nV`Nd4o`0000;oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1
k@;o000000?oY/7]o`000?nV`Nd00_l000001?nV`Ngo0000o`000?l00003ojK1k@?o000000?oY/7]
o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o00000onV`Nd2
o`0000?oY/7]0ol00003ojK2k@03o`000?nV`^goY/;]00;oY/;]00?o0000ojK2kOnV`^d00_nV`^d0
1ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l00002ojK2k@?o00000onV`^d2o`0000?oY/;]
0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0ol00003ojK2k@;o00000onV`^d2o`0000?oY/;]
00?o0000ojK2kOnV`^d00_nV`^d00ol0003oY/;]ojK2k@02ojK2k@03o`000?nV`^goY/;]00;o0000
00?oY/;]o`000?nV`^d00_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0ol00002ojK2k@?o0000
0onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d00ol0003oY/;]ojK2k@02ojK2k@03o`00
0?nV`^goY/;]00?oY/;]00Ko0000ojK2kOnV`^go0000ojK2kOl0000MoookJP03o`000?oonf[ooo]Z
04Cooo]Z00?o0000oookJ_oonfX02_oonfX4o`0000CoY/7]0_l00004ojK1k@03o`000?nV`NgoY/7]
00?oY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@04ojK1k@03o`000?nV`NgoY/7]
00?oY/7]00?o0000ojK1kOnV`Nd00_l00002ojK1k@04o`000?nV`Ngo0000o`0000;oY/7]00?o0000
ojK1kOl000000_l000000onV`Ngo0000ojK1k@03o`0000;oY/7]0ol00004ojK1k@;o00001?nV`Nd3
o`0000?oY/7]0ol00003ojK1k@03o`000?nV`NgoY/7]00CoY/7]00?o0000ojK1kOnV`Nd00onV`Nd0
0ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00Co0000ojK2kOnV`^goY/;]0_l0
00000onV`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00Co000000?ok[RHo`000?oT[9T01?l0
0002om>GU@oo00000onMJiP01?l0003oOU>DogiCU?mnDi@3o`000004oe<jU_l0003o0000obXNSP?o
00001?nV`^d00ol0003oY/;]ojK2k@04ojK2k@05o`000?nV`^goY/;]ojK2kOl000000_mdO<d00ol0
003oIGC=o`000002o`0000;oFFk>0_mHKll2o`0000;o>Ec;0_lPCLD2o`000003o`0T/?l0003o0000
00?o00000_nV`^d3o`0000CoY/;]0ol00003ojK2k@?o00000onV`^d3o`0000?oY/;]00?o0000ojK2
kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2
kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@02o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`00
0?nV`^d01_l000001?nV`^go0000o`000?l00002ojK2k@?o00000onV`^d3o`0000?oY/;]0ol00004
ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000
ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@02o`000003ojK2kOl0003oY/;]00?o000000?oY/;]
o`000?nV`^d01?l000000onV`^go0000ojK2k@03o`0000;oY/;]0ol00003ojK2k@?o00001?nV`^d3
o`0001gooo]Z00?o0000oookJ_oonfX08?oonfX001kooo]Z00?o0000oookJ_oonfX0=OoonfX2o`00
0003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000001?nV`Ngo0000o`000?l00002
ojK1k@Co00000_nV`Nd3o`000006ojK1kOl0003oY/7]ojK1kOl0003oY/7]0_l000000onV`Ngo0000
ojK1k@02o`000004ojK1kOl0003o0000o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd4o`000003
ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003
ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000
ojK1k@;o000000?oY/7]o`000?nV`Nd00_l000001?nV`Ngo0000o`000?l00003ojK1k@?o00000_nV
`Nd3o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`00
0002o`000003ojK1kOl0003o000000;o00000_nV`Nd4o`000004ojK1kOl0003o0000o`0000;oY/7]
0ol00002ojK1k@?o000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd3o`000004ojK1kOl0003o0000
o`0000?oY/7]0_l00002ojK1k@?o00000onV`Nd2o`0000?oY/7]0_l00004ojK2k@;o00000onV`^d2
o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]00;oY/;]00Co0000ojK2kOnV`^go00000_nV
`^d01ol0003oY/;]o`000?l0003oY/;]o`000?nV`^d00_l00002ojK2k@;o00000onV`^d2o`0000?o
Y/;]0_l00003ojK2k@?o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?o
Y/;]00?o0000ojK2kOnV`^d00onV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l00000
0onV`^go0000ojK2k@02o`0000;oY/;]0_l00003ojK2k@?o00000onV`^d2o`0000?oY/;]0_l00003
ojK2k@;o00000onV`^d2o`0000?oY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00;oY/;]00?o0000
oookJ_oonfX06_oonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z00Sooo]Z0_l00002
ojK1k@03o`000?nV`Ngo000000;o00000_nV`Nd3o`0000CoY/7]0_l00004ojK1k@;o00001?nV`Nd3
o`0000?oY/7]0ol00003ojK1k@03o`000?nV`NgoY/7]00CoY/7]00?o0000ojK1kOnV`Nd00onV`Nd0
0ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00;o00000_nV`Nd00ol0003oY/7]o`000002
o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol00002ojK1k@04o`000?nV`Ngo
0000o`0000?oY/7]0ol00003ojK1k@?o00000onV`Nd3o`0000CoY/;]0_l000001OnV`^go0000ojK2
kOnV`^go000000GoY/;]00?o0000ojK2kOnV`^d00onV`^d01_l0003oY/;]ojK2kOl0003ok[VIo`00
00;oi:bI00?o0000omBNW_l000001?l00004olF:UP03o`000?ncOY[o/gjJ00?o/gjJ0_l00005oie[
V0Co000000GoPEJGo`000?mL?ICo0000oe@lV002o`000003o`02ROl0003o000000;o00001?nV`^d3
o`0000?oY/;]1_l000000omdO<go0000ofMab@02ofMab@?o00000_mHKll02?m6H<Wo>Ec;ocULbol0
003o84g5oaI6`_lGCLSo02fd0ol000000onV`^go0000o`000002ojK2k@03o`000?nV`^go000000;o
000000?oY/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`0000;oY/;]0ol00004ojK2k@?o
00000onV`^d3o`0000?oY/;]0ol00004ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@03ojK2k@03
o`000?nV`^goY/;]00?oY/;]1?l00003ojK2k@03o`000?nV`^goY/;]00;o000000?oY/;]o`000?nV
`^d00ol000000onV`^go0000ojK2k@03o`0000;oY/;]00?o0000ojK2kOl000000_l00002ojK2k@?o
00000onV`^d3o`0000?oY/;]0ol00004ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@03ojK2k@03
o`000?nV`^goY/;]00?oY/;]0ol00004ojK2k@03o`000?nV`^goY/;]00;o000000?oY/;]o`000?nV
`^d00ol000001?nV`^go0000ojK2kOnV`^d3o`00027ooo]Z00?o0000oookJ_oonfX08?oonfX001ko
oo]Z00?o0000oookJ_oonfX0=_oonfX2o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l0
00000_l00002ojK1k@?o00000_nV`Nd4o`000004ojK1kOl0003o0000o`0000;oY/7]0ol00002ojK1
k@?o000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd2o`0000;oY/7]00?o0000ojK1kOl000000_nV
`Nd3o`0000;oY/7]0ol000000onV`Ngo0000o`000007o`000003ojK1kOl0003o000000;o00000_nV
`Nd4o`000003ojK1kOl0003o000000;o000000CoY/7]o`000?l0003o00000_nV`Nd3o`0000;oY/7]
0ol000000onV`Ngo0000o`000002ojK1k@07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@02o`00
0004ojK1kOl0003o0000o`0000;oY/7]0ol00002ojK1k@?o000000?oY/7]o`000?l000000_l00002
ojK1k@Co000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o
000000;o000000CoY/7]o`000?l0003o00000_nV`Nd4o`000005ojK1kOl0003o0000ojK2kOl00000
0onV`Nd00ol2003o0000ojK1k@02o`0000;oY/7]0_l00003ojK1k@;o00000onV`Nd3o`0000?oY/;]
0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]00?oY/;]
00?o0000ojK2kOnV`^d00_nV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l000000onV
`^go0000ojK2k@02o`0000;oY/;]0_l00003ojK2k@?o00000onV`^d2o`0000?oY/;]0_l00003ojK2
k@;o00000onV`^d2o`0000?oY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00;oY/;]00?o0000ojK2
kOnV`^d00_nV`^d01Ol0003oY/;]ojK2kOl0003oY/;]00Co000000?oY/;]o`000?nV`^d00ol00000
1?nV`^go0000o`000?l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@?o00000_nV
`^d3o`0000?oY/;]00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oo
nf[ooo]Z00Oooo]Z00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@02o`0000;oY/7]00?o
0000ojK1kOl000000_l000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00?o00000_nV
`Nd01?l0003oY/7]o`000?l00003ojK1k@;o00001?nV`Nd3o`0000?oY/7]0ol00003ojK1k@?o0000
1?nV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd0
0onV`Nd00ol0003oY/7]ojK1k@04ojK1k@03o`000?nV`NgoY/7]00;o000000?oY/7]o`000?nV`Nd0
0ol00002ojK1k@04o`000?nV`Ngo0000o`0000;oY/;]00?o0000ojK2kOl000000_l00002ojK2k@?o
00000onV`^d3o`0000CoY/;]0_l00004ojK2k@;o000000Cok[VIo`000?l0003o00000ooDWYh00ol0
003odi^Jom>KVP03o`000003olF:U_l0003o000000Co/gjJ00?o0000ojmiV?l000000_nMJiP4o`00
00CoPEJG0_l000001_mM?iKo0000o`000?m:=YSo0000o`05S0;o000000OoY/;]o`000?l0003o0000
ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oOgk8ogMjb@02ogMjb@?o00000omWLLT2oe][b@;o
F6o?0_m6H<T01_l0003o;5C7obaDaol0003o5TK2o`0]]0?o00001_nV`^d00ol0003oY/;]ojK2k@03
ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00_l00002ojK2k@03o`000?nV`^go
000000;o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`000004ojK2kOl0003o
Y/;]ojK2k@?o00000_nV`^d3o`0000?oY/;]0ol00003ojK2k@Go00000_nV`^d3o`0000?oY/;]00?o
0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o
0000ojK2kOnV`^d00_l000000onV`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00?o00000_nV
`^d00ol0003oY/;]o`000002o`0000;oY/;]0ol00003ojK2k@?o00000onV`^d3o`0000CoY/;]0ol0
0003ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0002Cooo]Z00?o
0000oookJ_oonfX08?oonfX001kooo]Z00?o0000oookJ_oonfX0=ooonfX2o`0000;oY/7]0ol00002
ojK1k@Co000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o
000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002
ojK1k@?o000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd2o`000003ojK1kOl0003o000000Ko0000
0_nV`Nd3o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o0000
00?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o0000
0_nV`Nd3o`0000;oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o000000?oY/7]o`00
0?nV`Nd00_l000001?nV`Ngo0000o`000?l00003ojK1k@?o000000?oY/7]o`000?l000000_l00000
0onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l00000
0onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK2k@Co00000_nOS;l02?l2003o0000ojK1kOnV
`Ngo0000ojK1kOl0003oY/7]0_l000000onV`Ngo0000ojK1k@02o`0000?oY/;]0_l00003ojK2k@;o
00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d3o`0000?oY/;]0_l00003ojK2k@03
o`000?nV`^goY/;]00;oY/;]00?o0000ojK2kOnV`^d00_nV`^d01ol0003oY/;]ojK2kOl0003oY/;]
o`000?nV`^d00_l00002ojK2k@?o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2
o`0000?oY/;]0ol00002ojK2k@?o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d2
o`0000?oY/;]00Oo0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00?o000000CoY/;]o`000?l0003o
00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d3o`0000;oY/;]00?o0000oookJ_oo
nfX06OoonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z00Sooo]Z0ol00004ojK1k@03
o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@03ojK1k@03
o`000?nV`NgoY/7]00CoY/7]00?o0000ojK1kOnV`Nd00_l000000onV`Ngo0000ojK1k@03o`0000;o
Y/7]00Co0000ojK1kOl0003o00000_nV`Nd01?l0003oY/7]o`000?l00003ojK1k@?o00000onV`Nd3
o`0000?oY/7]0ol00004ojK1k@;o00001?nV`Nd3o`0000?oY/7]00?o0000ojK1kOnV`Nd00onV`Nd0
0ol0003oY/7]ojK1k@04ojK1k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00_l00000
1?nV`^go0000om_8aooKb<L2o`0000;oY/;]00?o0000ojK2kOl000000_l000000onV`^go0000ojK2
k@03o`0000;oY/;]0_l00002onF^V`?o000000Goe9jNo`000?oCVi[odi^Jo`000002olR>V0co0000
0onLK9X01?l0003oPEJGoh5FUon1EYL2o`0000;oGCnF0_l000000om:=YSo0000o`06S003o`0000Go
Y/;]00?o0000ojK2kOnV`^d00ol00003ogmnb0?oMg[900CoMGW:o`000?mWLLWoIg790_l00002oe][
b@;o000000SoAV39odAQbom4HL_o;5C7oa]6`OlFA/;o0SNjo`0]]0Ko00000onV`^d3o`0000?oY/;]
0ol00003ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]
ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00002ojK2k@;o000000?oY/;]o`000?nV`^d0
0ol000000onV`^go0000ojK2k@06o`000004ojK2kOl0003o0000o`0000;oY/;]0ol00003ojK2k@?o
00000onV`^d3o`0000?oY/;]0ol00004ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV
`^d00onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00;o000000?oY/;]o`000?nV
`^d00ol000000onV`^go0000ojK2k@03o`000004ojK2kOl0003oY/;]ojK2k@?o00000_nV`^d3o`00
00?oY/;]0ol00003ojK2k@?o0000:?oonfX00ol0003ooo]ZoookJP0PoookJP007OoonfX00ol0003o
oo]ZoookJP0joookJP;o00000_nV`Nd3o`0000;oY/7]0ol000000onV`Ngo0000o`000002o`000003
ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@Co000000?oY/7]o`000?l0
00000_l000001?nV`Ngo0000o`000?l00002ojK1k@?o000000?oY/7]o`000?l000000_l000000onV
`Ngo0000o`000002ojK1k@03o`000?nV`Ngo000000;oY/7]0ol00002ojK1k@?o00000_nV`Nd3o`00
0003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd4o`00
0003ojK1kOl0003o000000;o000000CoY/7]o`000?l0003o00000_nV`Nd3o`0000;oY/7]0ol00000
0onV`Ngo0000o`000002ojK1k@05o`000?nV`Ngo0000o`000?nV`Nd00ol00002ojK1k@?o00000_nV
`Nd3o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l00002ojK1k@Co000000?o
Y/7]o`000?l000000ol00003okJL_P03o`000?nOS;oo000000;o00001?nV`Nd00ol0003oY/7]ojK1
k@02ojK1k@03o`000?nV`^goY/;]00;o000000?oY/;]o`000?nV`^d00_l00002ojK2k@;o00000onV
`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d3o`0000?oY/;]0_l00003ojK2k@;o00000onV
`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV
`^d00ol000000onV`^go0000ojK2k@02o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?o
Y/;]0_l00003ojK2k@?o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d00ol0003o
Y/;]ojK2k@02ojK2k@07o`000?nV`^goY/;]o`000?nV`^go0000ojK2k@03o`000003ojK2kOl0003o
Y/;]00;o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d00ol0003ooo]ZoookJP0I
oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX02_oonfX3o`0000?oY/7]0ol00004
ojK1k@;o00001?nV`Nd2o`0000CoY/7]0ol00003ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000
ojK1kOnV`Nd01?nV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00;o00000_nV`Nd0
1?l0003oY/7]o`000?l00002ojK1k@04o`000?nV`Ngo0000o`0000;oY/7]00?o0000ojK1kOl00000
0_l000000onV`Ngo0000ojK1k@03o`0000;oY/7]0ol00004ojK1k@;o00001?nV`Nd3o`0000?oY/;]
0ol00003ojK2k@05o`000?nV`^goY/;]ojK2kOl000000ooKb<L01_l0003ofLC6o`000?l0003oY/;]
o`0000GoY/;]00?o0000ojK2kOnV`^d00_l000000onV`^go0000o`000003o`0000;ofZ>L1?l00004
olR>V0;o00001?ncOi/00ol0003o[gZIo`000005oia/VPCo000000GoQ5ZHo`000?l0003o0000ofi=
V@02o`000005oaTHT?l01Xco5anJo`000?nV`^d00ol00004ojK2k@Oo00000_mgN/T00ol0003oMGW:
o`000002ofMab@;oJ6k60_mKJlT2oeQ[b`;o00000_m4HL/01?l0003o6dK1o`000?l2=kX4o`000007
ojK2kOl0003o0000o`000?nV`^go0000ojK2k@03o`0000;oY/;]00Co0000ojK2kOl0003o00000onV
`^d3o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d3o`0000CoY/;]00?o0000ojK2kOnV`^d00onV
`^d00ol0003oY/;]ojK2k@03ojK2k@Co00000_nV`^d2o`0000;oY/;]0_l000000onV`^go0000ojK2
k@03o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol00003ojK2k@?o00000onV
`^d3o`0000?oY/;]0ol00003ojK2k@?o00001?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV
`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d2o`0000;oY/;]0_l000000onV`^go0000o`00
0003o`000003ojK2kOl0003oY/;]00?o0000;?oonfX00ol0003ooo]ZoookJP0PoookJP007OoonfX0
0ol0003ooo]ZoookJP0joookJP07o`000?nV`Ngo0000o`000?nV`Ngo0000ojK1k@02o`000004ojK1
kOl0003o0000o`0000;oY/7]0ol00003ojK1k@?o000000?oY/7]o`000?l000000_l000000onV`Ngo
0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo
0000o`000002o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]0ol000001_nV`Ngo
0000o`000?nV`Ngo0000ojK1k@;o000000?oY/7]o`000?nV`Nd00_l000001?nV`Ngo0000o`000?l0
0002ojK1k@?o00000_nV`Nd4o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l0
00000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l0
00000onV`Ngo0000o`000002o`0000;oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o
000000?oY/7]o`000?nV`Nd00_l000001?nV`Ngo0000o`000?l00002ojK1k@?o000000?oY/7]o`00
0?l000000ol000000onV`Ngo0000o`000002o`000004ojK1kOl0003o0000o`0000;o]Ybn1?l00003
ojK1k@;o00000onV`Nd2o`0000?oY/;]00?o0000ojK2kOnV`^d00onV`^d01ol0003oY/;]ojK2kOl0
003oY/;]o`000?nV`^d00_l000000onV`^go0000ojK2k@02o`0000;oY/;]0_l00003ojK2k@;o0000
0onV`^d3o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`00
0?nV`^goY/;]00;oY/;]00?o0000ojK2kOnV`^d00onV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`00
0?nV`^d00_l000000onV`^go0000ojK2k@02o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d3o`00
00?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]
00;oY/;]00?o0000ojK2kOnV`^d00onV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l0
0002ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000oookJ_oonfX06?oonfX00ol0003ooo]Zoook
JP13oookJP03o`000?oonf[ooo]Z00_ooo]Z00Co0000ojK1kOl0003o00000_nV`Nd00ol0003oY/7]
o`000002o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol00003ojK1k@;o0000
1?nV`Nd2o`0000CoY/7]0ol00003ojK1k@?o00000onV`Nd00ol0003oY/7]ojK1k@04ojK1k@03o`00
0?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`00
0?nV`NgoY/7]00;o00000_nV`Nd00ol0003oY/7]o`000002o`000003ojK1kOl0003oY/7]00?o0000
00?oY/7]o`000?nV`^d00ol00003ojK2k@;o00001?nV`^d2o`000006om[8b?l0003oflS7o`000?oI
a<Ko00000_oG`L@00ol0003oY/;]o`000002o`0000?oY/;]00Oo0000ojK2kOnV`^goY/;]o`000?o^
^Y_o000000;oi[2L00?o0000omZSW?oJXi`00_l000001_oBVico0000o`000?l0003ob8jHo`0000;o
_HJI00Co0000ok=oVoncOi_o00000_n_NYT00ol0003oW6bJoia/VP04o`0000?oQ5ZH0_l00003ofi=
V@;o000000?o6AR@o`000?l000000_l00002ojK2k@?o00000_nV`^d00ol0003oRH34oh9naP04oh9n
aPCo000000?oMGW:o`000?l000000_mXK/H3o`0000;oF6_;00OoAec4odAQbom4HL_o;do2oa]6`OlQ
Bl?o0SNj00Go00001OnV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`^goY/;]00;o000000?o
Y/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00?o00000onV
`^d3o`0000?oY/;]0ol00003ojK2k@Go000000CoY/;]o`000?l0003o00001?nV`^d00ol0003oY/;]
ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d01?l0003oY/;]
ojK2kOnV`^d2o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol000000onV`^go
0000ojK2k@03o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d3o`0000?oY/;]0ol00003ojK2k@;o
00001OnV`^d2o`0000CoY/;]00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0PoookJP00
7OoonfX00ol0003ooo]ZoookJP0koookJP03o`000?nV`NgoY/7]00?o000000?oY/7]o`000?l00000
0_nV`Nd00ol0003oY/7]o`000002ojK1k@05o`000?nV`Ngo0000o`000?nV`Nd00ol00002ojK1k@?o
000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@Co
000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000004ojK1kOl0003o0000o`00
00;oY/7]0ol00002ojK1k@?o000000?oY/7]o`000?l000000_nV`Nd00ol0003oY/7]o`000002ojK1
k@?o00000_nV`Nd3o`0000;oY/7]0ol000000onV`Ngo0000o`000002o`000003ojK1kOl0003o0000
00;o000000?oY/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd4o`000004ojK1kOl0003o0000
o`0000;oY/7]0ol00002ojK1k@?o000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd2o`000004ojK1
kOl0003o0000o`0000?oY/7]0ol00002ojK1k@?o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o
00000onV`^d2o`0000?oY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00;oY/;]00?o0000ojK2kOnV
`^d00_nV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l00002ojK2k@;o00000onV`^d3
o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d3
o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d00ol0003oY/;]ojK2k@02ojK2k@07o`000?nV`^go
Y/;]o`000?nV`^go0000ojK2k@02o`0000;oY/;]0_l00003ojK2k@?o00000_nV`^d3o`0000?oY/;]
0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@?o00000_nV`^d00ol0003oY/;]
ojK2k@03ojK2k@07o`000?nV`^goY/;]o`000?nV`^go0000ojK2k@02o`0000;oY/;]0_l00003ojK2
k@03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP0<oook
JP03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@03ojK1
k@04o`000?nV`NgoY/7]ojK1k@;o000000?oY/7]o`000?nV`Nd00ol000000onV`Ngo0000ojK1k@03
o`0000;oY/7]00Co0000ojK1kOl0003o00000onV`Nd2o`0000CoY/7]0ol00003ojK1k@?o00000onV
`Nd3o`0000CoY/7]0_l00004ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd00onV
`Nd00ol0003oY/7]ojK1k@03ojK1k@04o`000?nV`^goY/;]ojK2k@;o000000?oY/;]o`000?nV`^d0
0ol000000onV`^go0000om[8b002om[8b003o`000?oIa<Ko000000?oel740_l00002ojK2k@;o0000
1?nV`^d5o`0000;oi[2L0ol00002olnIW@;o00000_o:TYX=o`0000?oVfbK0_l000001?n4FYSo0000
ohEMVol00002ofi=V@?o000000?o6AR@ob<XWOl000000ol000000onV`^go0000ojK2k@03o`0000?o
RH341?n2O/H01?l0003oN7S6ogQha_mhN<H2o`0000CoJ6k60omLIlD00ol0003oAec4odMLa002o`00
0003obm?`_l0003o8D_300So00001?nV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0
003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00Co0000ojK2kOnV`^goY/;]0_l00000
0onV`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00Wo00000onV`^d3o`0000?oY/;]0ol00003
ojK2k@?o00000onV`^d3o`0000CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03
ojK2k@03o`000?nV`^goY/;]00?oY/;]00Co0000ojK2kOnV`^goY/;]0_l000000onV`^go0000ojK2
k@03o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@?o00001?nV
`^d3o`0000?oY/;]0ol0000boookJP03o`000?oonf[ooo]Z023ooo]Z000MoookJP03o`000?oonf[o
oo]Z03cooo]Z0_l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol000001_nV`Ngo0000o`000?nV
`Ngo0000ojK1k@;o000000CoY/7]o`000?l0003o00000_nV`Nd3o`0000?oY/7]0ol000000onV`Ngo
0000o`000007o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo
0000o`000002o`000003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]0ol000001_nV`Ngo
0000o`000?nV`Ngo0000ojK1k@;o000000?oY/7]o`000?nV`Nd00_l000001?nV`Ngo0000o`000?l0
0002ojK1k@?o000000?oY/7]o`000?l000000_l00002ojK1k@Co000000?oY/7]o`000?l000000_l0
00000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l0
00001?nV`Ngo0000o`000?l00002ojK1k@?o000000?oY/7]o`000?l000000_nV`Nd01ol0003oY/7]
o`000?l0003oY/7]o`000?nV`Nd00_l00002ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1
k@;o00000onV`^d2o`0000CoY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2
kOnV`^d00_nV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l000000onV`^go0000ojK2
k@03o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV
`^d3o`0000;oY/;]0ol00003ojK2k@;o00000onV`^d00ol0003oY/;]ojK2k@02ojK2k@07o`000?nV
`^goY/;]o`000?nV`^go0000ojK2k@02o`000003ojK2kOl0003oY/;]00;o00000_nV`^d3o`0000;o
Y/;]0ol00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d3o`0000;o
Y/;]00?o0000ojK2kOnV`^d00onV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l00000
0onV`^go0000oookJP0HoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX03_oonfX3
o`0000CoY/7]0_l00004ojK1k@;o00001?nV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`Ngo
Y/7]00?oY/7]00?o0000ojK1kOnV`Nd01?nV`Nd00ol0003oY/7]ojK1k@02o`000003ojK1kOl0003o
Y/7]00?o000000?oY/7]o`000?nV`Nd00ol00002ojK1k@04o`000?nV`Ngo0000o`0000;oY/7]00?o
0000ojK1kOl000000_l00002ojK1k@?o00000onV`Nd3o`0000?oY/7]0ol00004ojK1k@;o00001?nV
`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00;oY/;]0_l000001?oJb<So0000omS4
a_l00003omO1a003o`000?oD_<;oe;c200?o000000GoY/;]o`000?l0003o0000ojK2k@02o`0000;o
k[^L0ol00002ombVW@Co00001?o:TYX01_l0003o_XNJokj7V_l0003o/h2Lo`0000?o[g^J00?o0000
oi]/VonKK9/00_nKK9/7o`000009ofi=VOl0003oITfPofI=X?m2=9[o0000ob<XWOl0003o002600;o
00000_nV`^d7o`0000?oPWk60_moO<H01?l0003oN7S6ogQha_l00003ofeaaP03ofQ^a_l0003oG6O5
00;oG6O500?oFFO7o`000?m7G<@00_m4G<H00ol_Cl;o7T>lob5;``05o`000003ojK2kOl0003oY/;]
00?o00000_nV`^d3o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d3o`0000CoY/;]00?o0000ojK2
kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@Co00000_nV`^d01?l0003oY/;]ojK2kOnV`^d2
o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03
o`0000;oY/;]0ol00004ojK2k@?o00000onV`^d3o`0000?oY/;]0ol00003ojK2k@;o00001OnV`^d0
0ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00_l00000
1?nV`^go0000ojK2kOnV`^d3o`000003ojK2kOl0003oY/;]00?o00000_oonfX00ol0003ooo]Zoook
JP0aoookJP03o`000?oonf[ooo]Z023ooo]Z000MoookJP03o`000?oonf[ooo]Z03kooo]Z0_l00000
0onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000CoY/7]o`000?l0003o00000_nV
`Nd3o`000003ojK1kOl0003o000000;oY/7]00?o0000ojK1kOl000000_nV`Nd01Ol0003oY/7]o`00
0?l0003oY/7]00So00000_nV`Nd3o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l00000
0_l00002ojK1k@?o00000_nV`Nd4o`000003ojK1kOl0003o000000;o000000CoY/7]o`000?l0003o
00000_nV`Nd3o`0000;oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o000000CoY/7]
o`000?l0003o00000onV`Nd3o`0000;oY/7]0ol000000onV`Ngo0000o`000002o`000003ojK1kOl0
003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0
003o000000;o000000?oY/7]o`000?l000000_l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]00Co
0000ojK1kOl0003oY/7]0_l00002ojK1k@;o00000onV`Nd2o`0000?oY/;]0_l00003ojK2k@?o0000
0onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d0
0_nV`^d00ol0003oY/;]ojK2k@02ojK2k@03o`000?nV`^goY/;]00;o000000?oY/;]o`000?nV`^d0
0_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]
0ol00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d00ol0003oY/;]
ojK2k@02ojK2k@07o`000?nV`^goY/;]o`000?nV`^go0000ojK2k@02o`0000;oY/;]0ol00003ojK2
k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0ol00002ojK2
k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00_nV`^d00ol0003ooo]ZoookJP0Foook
JP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003oY/7]o`000002o`00
00;oY/7]0ol00003ojK1k@?o00001?nV`Nd2o`0000CoY/7]0_l00004ojK1k@?o00000onV`Nd00ol0
003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd01?nV`Nd00ol0
003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00;o00000_nV`Nd01?l0003oY/7]o`000?l00002
ojK1k@04o`000?nV`Ngo0000o`0000;oY/7]00?o0000ojK1kOl000000_l00002ojK2k@?o00000onV
`^d3o`0000CoY/;]1?l000001?oLb<Go0000omS4a_oHa<H2o`000004omO1a?l0003oe;c2omBl`P;o
000000CockS4o`000?l0003o00001?nV`^d01Ol0003ok[^LonjkW?l0003oi[:M00;o000000Cog:JM
o`000?o<V:3oc9RP1ol000000onnQi[o0000o`000005ojmkVP06o`000?nKK9_o0000o`000?nNLYoo
00001?n4GYh2o`0000?oITfP00?o0000od8dV_l000001?l000001OnV`^go0000o`000?nCQ/;o0000
00CoRX7400?o0000oh9na_l000001ol00003ofeaaP08ofY`aol0003oG6O5o`000?mIIlOo0000odML
a?l00002odALaP03o`000?lN@kco000000Go000000CoY/;]o`000?nV`^goY/;]0_l000000onV`^go
0000ojK2k@03o`000003ojK2kOl0003oY/;]00?o00000_nV`^d01?l0003oY/;]o`000?l00003ojK2
k@?o00000onV`^d3o`0000?oY/;]1Ol000001?nV`^go0000o`000?l00004ojK2k@03o`000?nV`^go
Y/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^go
Y/;]00;o00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o000000?oY/;]
o`000?nV`^d00ol00002ojK2k@?o00001?nV`^d3o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d0
0ol0003oY/;]ojK2k@03ojK2k@;o00001OnV`^d00ol0003ooo]ZoookJP04oookJP03o`000?oonf[o
oo]Z037ooo]Z00?o0000oookJ_oonfX07ooonfX001gooo]Z00?o0000oookJ_oonfX0?ooonfX2o`00
0003ojK1kOl0003o000000;o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd3o`00
00;oY/7]0ol000000onV`Ngo0000o`000002o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l0
00001?nV`Ngo0000o`000?l00002ojK1k@?o00000_nV`Nd4o`000003ojK1kOl0003o000000;o0000
00?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o0000
00?oY/7]o`000?l000000_l000001?nV`Ngo0000o`000?l00002ojK1k@Co000000KoY/7]o`000?nV
`NgoY/7]o`000?nV`Nd2o`000003ojK1kOl0003oY/7]00;o000000CoY/7]o`000?l0003o00000_nV
`Nd3o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`00
0002o`000003ojK1kOl0003o000000;o00000_nV`Nd4o`000003ojK1kOl0003o000000;o00000onV
`Nd00ol0003oY/7]ojK1k@02ojK1k@07o`000?nV`NgoY/7]o`000?nV`Ngo0000ojK1k@02o`000003
ojK1kOl0003oY/;]00;o00000_nV`^d2o`0000CoY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?o
Y/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]00?o
Y/;]00Oo0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00;o000000?oY/;]o`000?nV`^d00_l00002
ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@?o00000onV`^d2o`0000?oY/;]0_l00003
ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d01ol0003oY/;]ojK2kOl0
003oY/;]o`000?nV`^d00ol000001?nV`^go0000o`000?l00003ojK2k@;o00000onV`^d2o`0000?o
Y/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0ol00002ojK2k@?o00000onV`^d00ol0003o
oo]ZoookJP0EoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003o
Y/7]ojK1k@02o`0000;oY/7]00Co0000ojK1kOl0003o00000_nV`Nd00ol0003oY/7]o`000002o`00
0003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol00002ojK1k@?o00001?nV`Nd2o`00
00CoY/7]0_l00004ojK1k@?o00000onV`Nd3o`0000?oY/7]00?o0000ojK1kOnV`Nd01?nV`Nd00ol0
003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK2kOnV`^d00_l00002ojK2
k@04o`000?nV`^go0000o`0000;oY/;]00?o0000ojK2kOl000000_l000001OnV`^go0000ojK2kOl0
003og/S300;o000000Cof<C6o`000?oF`LGoe/750_l000001OoD_<;o0000om6i`_oA^L;o000000?o
cKK30ol000001?nV`^go0000o`000?l00002onJbW@03o`000?oNZIko000000;o000000?oc9RPo`00
0?o;UYl00_o;UYl00ol0003o]h>MokN3W@0:o`0000CoWW:O00So0000ohANW_l0003o0000ohEOW_mY
CIko0000ofI=X0;o000000Go@SBJo`000?l0003o5QnJo`00PP02o`0000?oThK200Ko0000ohZ1a?n:
PLCoRX74ohUn`Ol00004oh=l``;o00000omiM/<2ofeaaP04o`000?mZL<Oo0000oeaWaP;o000000?o
FFO7o`000?m8F<000_m4G<H01Ol_B[go7T>lo`000?l0003onk9R00?o00000_nV`^d00ol0003oY/;]
ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]
ojK2k@02o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d02Ol00003ojK2k@?o0000
0onV`^d3o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@04ojK2k@03o`00
0?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@02o`000004ojK2
kOl0003oY/;]ojK2k@?o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`0000;o
Y/;]0ol00003ojK2k@?o00001?nV`^d3o`0000[ooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003o
oo]ZoookJP0OoookJP007?oonfX00ol0003ooo]ZoookJP11oookJP;o00000_nV`Nd4o`000003ojK1
kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1
kOl0003o000000;o000000?oY/7]o`000?l000000_l000001?nV`Ngo0000o`000?l00002ojK1k@?o
000000?oY/7]o`000?l000000_nV`Nd00ol0003oY/7]o`000002ojK1k@?o00000_nV`Nd3o`0000;o
Y/7]0ol000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l0
00000_l000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd3o`0000;o
Y/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o000000CoY/7]o`000?l0003o00000_nV
`Nd3o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd4o`000003ojK1kOl0003o000000;o00000onV
`Nd2o`0000?oY/7]0_l00003ojK1k@03o`000?nV`NgoY/7]00;oY/7]00?o0000ojK1kOnV`Nd00_nV
`Nd01?l0003oY/;]ojK2kOl00002ojK2k@04o`000?nV`^go0000o`0000;oY/;]0_l00003ojK2k@;o
00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@?o
00000onV`^d00ol0003oY/;]ojK2k@02ojK2k@03o`000?nV`^goY/;]00;oY/;]00Oo0000ojK2kOnV
`^go0000ojK2kOl0003oY/;]00;o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@?o00000_nV`^d3
o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^go
Y/;]00;oY/;]00Go0000ojK2kOnV`^go0000ojK2k@05o`000003ojK2kOl0003o000000;o00000_nV
`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@?o00000_nV
`^d00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z04;ooo]Z00?o0000oookJ_oonfX04_oo
nfX00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd00onV
`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00;o00000_nV`Nd00ol0003oY/7]o`00
0002o`000003ojK1kOl0003oY/7]00?o000000?oY/7]o`000?nV`Nd00ol00003ojK1k@;o00001?nV
`Nd2o`0000CoY/7]0ol00003ojK1k@?o00000onV`Nd3o`0000?oY/;]00?o0000ojK2kOnV`^d01?nV
`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00Go0000omk8`ooNb<?o0000
omc4`P02o`000005omK1aOl0003od[k7om:naooD_<800_l000000ooA^L;o0000olff``02olff``04
o`000?o9/lCobK?4o`0000;ok[bN0ol00002omjYWP03o`000?oDWiooe9nO00;o00000_o;UYl00ol0
003o]h>MokN3W@02okN3W@03o`000?n_Oj3o[gnP00Co[gnP00?o0000oiibWonNLYl00_nNLYl00ol0
003oQ5jNohEOWP03ohEOWP04ofU=W_l0003o0000ofM>X@;o000000GoFTFPo`000?lF7i[o0000o`00
T002o`0000?oThK200?o0000ohZ1a?n9O/400_n9O/401Ol0003oPgc3oh=l`on3O<?oP7[300GoNGK3
0ol000000omZL<Oo0000oeeT`P02oeeT`P?oB5S000?o0000obm:_Ol_B[d00_l000001?ok/V;o0000
o`000?l00003ojK2k@?o00000onV`^d3o`0000CoY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00?o
Y/;]00?o0000ojK2kOnV`^d00onV`^d4o`0000;oY/;]00Co0000ojK2kOnV`^goY/;]0_l000000onV
`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol00002ojK2
k@?o00001?nV`^d3o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@03ojK2
k@;o00001OnV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00;o000000?oY/;]o`00
0?nV`^d00ol000001?nV`^go0000ojK2kOnV`^d3o`0000oooo]Z00?o0000oookJ_oonfX0;ooonfX0
0ol0003ooo]ZoookJP0OoookJP007?oonfX00ol0003ooo]ZoookJP13oookJP;o000000?oY/7]o`00
0?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`00
0?l000000_l000000onV`Ngo0000o`000007o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd3o`00
0006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l000000onV`Ngo0000ojK1k@02o`000004ojK1kOl0
003o0000o`0000;oY/7]0ol000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@Co0000
00?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o0000
00CoY/7]o`000?l0003o00000_nV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l00000
0onV`Ngo0000ojK1k@02o`0000;oY/7]0ol00002ojK1k@?o000000?oY/7]o`000?l000000_l00003
ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/;]00?o0000
ojK2kOnV`^d00onV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l000000onV`^go0000
ojK2k@02o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o0000
0onV`^d3o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d00ol0003oY/;]ojK2k@02ojK2k@07o`00
0?nV`^goY/;]o`000?nV`^go0000ojK2k@02o`000003ojK2kOl0003oY/;]00;o00000_nV`^d2o`00
00?oY/;]0ol00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`00
00?oY/;]00?o0000ojK2kOnV`^d00_nV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_l000000onV
`^go0000o`000002o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2
k@;o00000onV`^d00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oook
J_oonfX04ooonfX3o`0000?oY/7]0ol00004ojK1k@;o00001?nV`Nd2o`0000CoY/7]00?o0000ojK1
kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00?oY/7]00Co0000ojK1
kOnV`NgoY/7]0_l000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00?o000000?oY/7]
o`000?nV`Nd00ol00002ojK1k@04o`000?nV`Ngo0000o`0000?oY/7]0_l00004ojK2k@?o00000onV
`^d3o`0000?oY/;]0ol000001OnV`^go0000o`000?oNb<?o000000;og<C20ol00003om:na`03o`00
0?oB^L;od[W200?o000000CocKK3o`000?o9/lCobK?40ol000000oo^_9ko0000onNdWP03o`0000?o
e9nO1ol00002okN3W@03o`000?n_Oj3o[gnP00Co[gnP00?o0000oiibWol000000_l000000onMLZ3o
0000ohEOWP02ohEOWP;o00000_mZCYh2o`0000?oFTFP00Co0000oc@eXol0093o001D2ol000001?n3
O<?o0000o`000?n0N/<3ogUf``04ogEc`om^Kl?oKVo3ofi_``;o00000omMI<800omIHl;oB5S0odQH
`002odAG`@03obm:_Ol0003o000000Ko000000?oY/;]o`000?nV`^d00ol00002ojK2k@03o`000?nV
`^go000000;o00000_nV`^d3o`0000?oY/;]0ol00003ojK2k@Go000000CoY/;]o`000?l0003o0000
1?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d0
0onV`^d00ol0003oY/;]ojK2k@02o`0000;oY/;]00?o0000ojK2kOl000000_l000000onV`^go0000
ojK2k@03o`000003ojK2kOl0003oY/;]00?o00000_nV`^d3o`0000?oY/;]0ol00004ojK2k@?o0000
0onV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@;o0000
4ooonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01oooo]Z000LoookJP03o`000?oo
nf[ooo]Z04Cooo]Z0_l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@So00000_nV
`Nd4o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000001?nV`Ngo0000o`00
0?l00002ojK1k@?o00000_nV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l000001?nV
`Ngo0000o`000?l00003ojK1k@?o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002
o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002
o`000003ojK1kOl0003o000000;o000000CoY/7]o`000?l0003o00000_nV`Nd3o`0000;oY/7]1?l0
00001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o000000CoY/7]o`000?l0003o00000onV`Nd2o`00
00?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`^d3o`00
00?oY/;]00?o0000ojK2kOnV`^d00_nV`^d00ol0003oY/;]ojK2k@02ojK2k@07o`000?nV`^goY/;]
o`000?nV`^go0000ojK2k@02o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l0
0003ojK2k@?o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d00ol0003oY/;]ojK2
k@02ojK2k@03o`000?nV`^goY/;]00;oY/;]00Oo0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00;o
00000_nV`^d3o`0000;oY/;]0ol00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o
00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]00;oY/;]00?o0000ojK2kOnV
`^d00_l000000onV`^go0000o`000002o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?o
Y/;]0_l00003ojK2k@03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003o
oo]ZoookJP0DoookJP04o`000?nV`Ngo0000o`0000;oY/7]00?o0000ojK1kOl000000_l00002ojK1
k@?o00000onV`Nd3o`0000?oY/7]0ol00004ojK1k@;o00001?nV`Nd2o`0000CoY/7]00?o0000ojK1
kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1
kOnV`Nd01?nV`Nd00ol0003oY/7]ojK1k@02o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`00
0?nV`^d00ol00002ojK2k@04o`000?nV`^go0000o`0000?oY/;]0ol000001OoNb<?o0000omc4`_oL
a<;o000000;of/7100Co0000om:naooB_/Oo00000_oB^L800ol0003od;K0om2f`002o`0000;obK?4
00?o0000olV_`?oX_j/00_l00002onNdWP03o`000?oOZioo000000?o000000GobYJPo`000?o:UZ3o
bYJPo`000002ol>>W@_o00001?nMLZ04o`000007ohURWol0003oJTjNofY>W_l0003oFTFPo`000002
oeY5X004o`000?ld=J?o0000o``[Z`;o00000_nCQ;l00ol0003oRWo2ohYo`P03ohYo`P04o`000?n3
N/7oPg[1oh=j`@;o000000?oNGK3o`000?l000000om^Kl<2ofY]``04o`000?mMI<;o0000oeUS`P?o
000000GoA5O1o`000?l0003o0000ooc0O`04o`0000?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0
003oY/;]ojK2k@02o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d02Ol00003ojK2
k@?o00000onV`^d3o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@04ojK2
k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@02o`00
0003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]
00?o00000_nV`^d3o`0000?oY/;]0ol00003ojK2k@?o00005ooonfX00ol0003ooo]ZoookJP0^oook
JP03o`000?oonf[ooo]Z01oooo]Z000LoookJP03o`000?oonf[ooo]Z04Cooo]Z00Oo0000ojK1kOl0
003o0000ojK1kOl0003oY/7]00;o00000_nV`Nd3o`0000;oY/7]2?l000000onV`Ngo0000o`000002
o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002
o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002
o`0000;oY/7]0ol000001_nV`Ngo0000ojK1kOnV`Ngo0000ojK1k@;o000000CoY/7]o`000?l0003o
00000_nV`Nd3o`0000;oY/7]0ol000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o
000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o
00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd2
o`000003ojK1kOl0003oY/7]00;o00000_nV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2
o`0000?oY/;]0_l00004ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^go
Y/;]00;oY/;]00Oo0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00;o000000?oY/;]o`000?nV`^d0
0_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0ol00003ojK2k@;o00000onV`^d2o`0000?oY/;]
0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d01ol0003oY/;]
ojK2kOl0003oY/;]o`000?nV`^d00_l00002ojK2k@?o00000_nV`^d3o`0000?oY/;]0_l00003ojK2
k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2
kOnV`^d00_nV`^d00ol0003oY/;]ojK2k@02o`000003ojK2kOl0003o000000;o000000?oY/;]o`00
0?l000000_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000oookJ_oonfX04ooonfX00ol0
003ooo]ZoookJP11oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000ojK1kOnV`Nd00onV`Nd00ol0
003oY/7]ojK1k@02o`0000;oY/7]00Co0000ojK1kOl0003o00000_nV`Nd01?l0003oY/7]o`000?l0
0002ojK1k@03o`000?nV`Ngo000000;o000000?oY/7]o`000?nV`Nd00ol00002ojK1k@?o00000onV
`Nd3o`0000CoY/7]0_l00004ojK1k@;o00001?nV`Nd3o`0000?oY/7]00?o0000ojK2kOnV`^d00onV
`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00_l0
00001?nV`^go0000o`000?oNb<<2o`000006omc4`_l0003of/71om[1`Ol0003oekbo0ol000000ooB
^L;o0000om2f`002om2f`003o`000?o>/[ko000000?o00000_oX_j/3o`0000;ogj^O00?o0000omJR
X?oFXZ001Ol00004ol>>W@03o`000?njQiko000000Co/82Q0_l00004oiebX0;o00001?n9HYl3o`00
00;oMUNP00?o0000oeY5X?l000000_l000000ol04iSo32^[o``[Z`02o`0000;oThBo00Go0000ohYo
`_n:Ol;oRWo2ohUl_`05oh=j`@07o`000?miLl3oNG?0ogUc`?l0003oKVo3o`000002ofY]``05o`00
0?mMIL;o0000o`000?mIHl800_m8E;/01Om4El7o0000ooK6Vol0003oo<1o00Go00001?nV`^d3o`00
00?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@Co00000_nV`^d01?l0
003oY/;]ojK2kOnV`^d2o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol00000
0onV`^go0000ojK2k@03o`0000;oY/;]0ol00004ojK2k@?o00000onV`^d3o`0000?oY/;]0ol00003
ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@03
ojK2k@03o`000?nV`^goY/;]00;o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03
o`0001cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0OoookJP007?oonfX00ol0
003ooo]ZoookJP15oookJP;o00000_nV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]1_l0
0002ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l0
00000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd4o`000004ojK1kOl0
003o0000o`0000;oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o000000?oY/7]o`00
0?nV`Nd00_l000001?nV`Ngo0000o`000?l00002ojK1k@?o000000?oY/7]o`000?l000000_l00000
0onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@Co000000?oY/7]o`000?l000000_l00000
0onV`Ngo0000o`000002o`000004ojK1kOl0003o0000o`0000CoY/7]00?o0000ojK1kOnV`Nd00_nV
`Nd01ol0003oY/7]ojK1kOl0003oY/7]o`000?nV`Nd00_l00002ojK1k@;o00000onV`Nd2o`0000?o
Y/7]0_l00004ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?o
Y/;]00?o0000ojK2kOnV`^d00_nV`^d00ol0003oY/;]ojK2k@02ojK2k@07o`000?nV`^goY/;]o`00
0?nV`^go0000ojK2k@02o`0000;oY/;]0_l00003ojK2k@?o00000onV`^d2o`0000?oY/;]0_l00003
ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d00ol0003oY/;]ojK2k@02
ojK2k@07o`000?nV`^goY/;]o`000?nV`^go0000ojK2k@02o`000003ojK2kOl0003oY/;]00?o0000
0_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o0000
0onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d00ol0003oY/;]ojK2k@02ojK2k@03o`00
0?nV`^goY/;]00;o000000?oY/;]o`000?l000000_l00002ojK2k@;o00000onV`^d00ol0003ooo]Z
oookJP0BoookJP03o`000?oonf[ooo]Z047ooo]Z00?o0000oookJ_oonfX05_oonfX3o`0000CoY/7]
00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00?oY/7]
00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@02o`0000;oY/7]00Co0000ojK1kOl0003o
00000_nV`Nd00ol0003oY/7]o`000002o`000003ojK1kOl0003oY/7]00?o00000_nV`Nd3o`0000?o
Y/7]0ol00004ojK2k@;o00001?nV`^d2o`0000CoY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00;o
Y/;]00?o0000omk8`ol000000_oIaLD2o`000005om[1`Ol0003oekboomNl_ol000000_oC^L03o`00
0005om2f`?l0003oc[:noljb__l000000_o:[kl2o`000003onRoZol0003oikBO00?o00000ooFXZ00
0ol0003oaYBRolJDXP04o`000005ol>>WOl0003o^XNNokZ7W_l000000on`P:401?l0003o[GfOo`00
0?nMLZ03o`000003oiaaXOl0003oRF:O00;oRF:O0_l00004ogIGX0;o00000_m3@:P01Ol`<j?o0000
o`000?l<:j_o001j00;o000000CoThBoo`000?n:Ol;oRWo20on9O;l3oh=j`@03oh1h`?miLl3oNG?0
00?oNG?00ol00002ofY]``04o`000?mNH[koGV:no`0000?oB5Bk00Go0000ooK6Vol0003o0000oog3
O006o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d5o`0000;oY/;]0_l00004ojK2k@03o`000?nV
`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV
`^goY/;]00;o00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o000000?o
Y/;]o`000?nV`^d00ol00002ojK2k@?o00000onV`^d3o`0000?oY/;]0ol00004ojK2k@?o00000onV
`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000oookJ_oonfX07_oo
nfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z01oooo]Z000LoookJP03o`000?oonf[o
oo]Z04Oooo]Z0_l000001?nV`Ngo0000o`000?l00002ojK1k@Ko000000?oY/7]o`000?nV`Nd00_l0
00000onV`Ngo0000ojK1k@02o`000004ojK1kOl0003o0000o`0000;oY/7]0ol00002ojK1k@?o0000
0_nV`Nd4o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000
o`000002o`000003ojK1kOl0003o000000;o000000CoY/7]o`000?l0003o00000_nV`Nd3o`0000;o
Y/7]0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o000000CoY/7]o`000?l0003o00000_nV
`Nd3o`0000;oY/7]1?l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?o
Y/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000?oY/7]0_l00003ojK1k@;o00000onV
`Nd00ol0003oY/7]ojK1k@02ojK1k@07o`000?nV`NgoY/7]o`000?nV`Ngo0000ojK1k@02o`0000;o
Y/7]0_l00004ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?o
Y/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d01ol0003o
Y/;]ojK2kOl0003oY/;]o`000?nV`^d00_l00002ojK2k@?o00000onV`^d2o`0000?oY/;]0_l00003
ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000
ojK2kOnV`^d00_nV`^d00ol0003oY/;]ojK2k@02ojK2k@03o`000?nV`^goY/;]00;o000000?oY/;]
o`000?l000000_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2
o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d0
0ol0003oY/;]ojK2k@02o`000003ojK2kOl0003o000000;o000000?oY/;]o`000?oonfX04ooonfX0
0ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z01Wooo]Z0ol00003ojK1k@?o00000onV`Nd3
o`0000?oY/7]0ol00004ojK1k@;o00001?nV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`Ngo
Y/7]00?oY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@02o`0000;oY/7]00Co0000
ojK1kOl0003o00000_nV`^d00ol0003oY/;]o`000002o`000003ojK2kOl0003oY/;]00?o00000_nV
`^d3o`0000?oY/;]0ol00004ojK2k@;o000000?oY/;]o`000?l000000ooIaLD01?l0003ofL31o`00
0?l00002omNl_`04omBi_ol0003odkW0o`0000;odKJo00Go0000oljb__o>/[koc[:no`000002olZ_
_`03o`000?oY`:Wo000000?o000000?oh:jRo`000?l000000_l00003olJDXP04o`000?o4TZ?oa9:S
olBBX`co00001?nLLJ401_l0003oRF:Oo`000?l0003oRFBQo`0000?oMUNP0_l000000omCA:;o0000
od=0Z002oc0cX`04o`4QYOl0003o00RIo`00T@Wo000000CoPg[1o`000?l0003oP7S00omiLl001?mf
LL3oKfg0ofm]`?m_KL02o`0000?oGV:n00CoFEjno`000?m8E;_oB5Bk0_l000000oohbY[o0000o`00
0004o`000007ojK2kOl0003o0000o`000?nV`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00Wo
00000onV`^d3o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d3o`0000?oY/;]00?o0000ojK2kOnV
`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV
`^d00_l000000onV`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00?o00000_nV`^d00ol0003o
Y/;]o`000002o`0000;oY/;]0ol00003ojK2k@?o00000onV`^d3o`0002Cooo]Z00?o0000oookJ_oo
nfX0:ooonfX00ol0003ooo]ZoookJP0OoookJP007?oonfX00ol0003ooo]ZoookJP18oookJP;o0000
00?oY/7]o`000?l000000_l000001?nV`Ngo0000o`000?l00002ojK1k@Co00000_nV`Nd3o`000007
ojK1kOl0003oY/7]ojK1kOl0003oY/7]o`000002ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o
000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o
000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o
000000;o000000CoY/7]o`000?l0003o00000_nV`Nd4o`000007ojK1kOl0003oY/7]ojK1kOl0003o
Y/7]o`000002ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol000000onV`Ngo0000o`000002o`000003
ojK1kOl0003o000000;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?o
Y/7]00?o0000ojK1kOnV`Nd00_nV`NdDo`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?o
Y/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]00;o
Y/;]00Oo0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00?o00000_nV`^d2o`0000?oY/;]0_l00003
ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003
ojK2k@;o00000onV`^d00ol0003oY/;]ojK2k@02ojK2k@03o`000?nV`^goY/;]00;o000000?oY/;]
o`000?l000000_l000001?nV`^go0000o`000?l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l0
0003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d00ol0003oY/;]ojK2
k@02ojK2k@06o`000?nV`^goY/;]o`000?nV`^go00005?oonfX00ol0003ooo]ZoookJP10oookJP03
o`000?oonf[ooo]Z01[ooo]Z00Co0000ojK1kOl0003o00000_nV`Nd01?l0003oY/7]o`000?l00002
ojK1k@04o`000?nV`Ngo0000o`0000?oY/7]0ol00003ojK1k@?o00000onV`Nd3o`0000?oY/7]0ol0
0004ojK1k@;o00001?nV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`^goY/;]00?oY/;]00?o
0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@02o`0000;oY/;]00Co0000ojK2kOl0003o0000
0_nV`^d00ol0003oY/;]o`000002o`000005ojK2kOl0003oY/;]o`000?oQakh00_l000002?oIaLGo
0000omW0`OoI`<7o0000omRm_ooG_;oo00000_oD^Kl02Ol0003odKJoom6f_ol0003ocKC1o`000?o>
/[ko0000olb`_P02o`0000;ojL2Y00?o0000on>gZOl000000_oP[Z800ol0003ofJFQomVUX@03o`00
0003olJDX_l0003oa9:S00?oa9:S00Co0000ok^7WonkQioo00000_n`P:401?l0003o[GfOojemWol0
0004oiaaX@So000000CoMUNPo`000?mbFJKo00000_mCA:800ol0003oA46Xoc0cX`04o`000004o`00
TOl0003oTh:no`0000CoRWfo00Co0000ohAh__n4N;koQ7Rn0_l000000omiLl3o0000ogIa`003ofm]
`00:o`000?mZJ[oo0000oeiR__l0003oFEjno`000?m8E;_o0000oo3=[P?o000000?on/fHo`000?l0
00000ol00005ojK2k@03o`000?nV`^goY/;]00?oY/;]1_l000000onV`^go0000ojK2k@03o`000003
ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@?o00000onV`^d3o`0000Co
Y/;]0ol00003ojK2k@?o00000onV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003o
Y/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00CoY/;]00?o0000ojK2kOnV`^d00_l000000onV`^go
0000ojK2k@03o`000003ojK2kOl0003oY/;]00?o0000:?oonfX00ol0003ooo]ZoookJP0/oookJP03
o`000?oonf[ooo]Z01kooo]Z000KoookJP03o`000?oonf[ooo]Z04[ooo]Z0ol000001?nV`Ngo0000
o`000?l00002ojK1k@?o00000_nV`Nd4o`000004ojK1kOl0003o0000o`0000;oY/7]0ol000001_nV
`Ngo0000o`000?nV`Ngo0000ojK1k@;o000000CoY/7]o`000?l0003o00000_nV`Nd3o`0000;oY/7]
0ol000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l00000
0_l000000onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]
0ol000001_nV`Ngo0000o`000?nV`Ngo0000ojK1k@;o000000?oY/7]o`000?nV`Nd00_l000001?nV
`Ngo0000o`000?l00002ojK1k@?o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2
o`0000?oY/7]0_l00003ojK1kAko00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2
o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d0
0ol0003oY/;]ojK2k@02o`000003ojK2kOl0003oY/;]00;o000000?oY/;]o`000?nV`^d00_l00002
ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003
ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d01ol0003oY/;]ojK2kOl0
003oY/;]o`000?nV`^d00ol000001?nV`^go0000o`000?l00003ojK2k@;o00000onV`^d2o`0000?o
Y/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d00ol0003o
Y/;]ojK2k@02ojK2k@03o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX0@?oonfX00ol0003o
oo]ZoookJP0KoookJP03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003o
Y/7]ojK1k@02o`0000;oY/7]00Co0000ojK1kOl0003o00000_nV`Nd01?l0003oY/7]o`000?l00002
ojK1k@04o`000?nV`Ngo0000o`0000?oY/7]0ol00003ojK1k@?o00000onV`Nd3o`0000?oY/7]0ol0
0003ojK2k@?o00001?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o
0000ojK2kOnV`^d00onV`^d00ol0003ohLNno`000002omo3_@;o000000_ofL31o`000?oH_Koof;fo
o`000?oF^[ko0000omBi_ol0003odKJoo`000003olfd`@04oljb__l0003o0000olb`_P?o00000_oS
]jT3o`0000?ofJFQ00?o0000olnLX_o?W:801_l00003ok^7W`03o`000?n`P:7o000000Co[GfO1?l0
0002oiifY@CoRFJT0ol00003og9IYP06oe=4X_l0003o0000odA1Z?l0003oBDBZ0_l[?[800ol0003o
032go`00QP02o`0000?oRWfo00?oRGZlohAh__n4N;h00on4N;h00ol0003oNW6mogYa_@02o`000006
ofm]`?l0003oJVZoofYZ_ol0003oGF:n0_l000001?mIG[ko0000on;Baol00002oo;@[P03o`000?oj
cISo000000?o000000CoY/;]o`000?l0003o00001?nV`^d4o`0000;oY/;]00?o0000ojK2kOnV`^d0
0onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d0
0_l00002ojK2k@04o`000?nV`^go0000o`0000;oY/;]00?o0000ojK2kOl000000_l000000onV`^go
0000ojK2k@03o`0000;oY/;]0ol00003ojK2k@?o00000onV`^d3o`0000?oY/;]0ol00004ojK2k@?o
00000onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000oookJ_oo
nfX0:_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01kooo]Z000KoookJP03o`00
0?oonf[ooo]Z04Oooo]Z0ol00002oookJP;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000
o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000001?nV`Ngo0000
o`000?l00002ojK1k@?o000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd2o`000003ojK1kOl0003o
Y/7]00;o000000CoY/7]o`000?l0003o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o00000_nV
`Nd4o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`00
0002o`000004ojK1kOl0003o0000o`0000;oY/7]0ol00002ojK1k@?o000000KoY/7]o`000?l0003o
Y/7]o`000?nV`Nd2o`0000;oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1
k@;o00000onV`NdWo`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2
k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2
kOnV`^d00_nV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l00002ojK2k@;o00000onV
`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV
`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV
`^d00ol000001?nV`^go0000o`000?l00002ojK2k@?o00000onV`^d2o`0000?oY/;]0_l00003ojK2
k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d00ol0003ooo]ZoookJP0Aoook
JP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX07?oonfX3o`0000?oY/7]0ol00003ojK1
k@03o`000?nV`NgoY/7]00CoY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@03ojK1
k@03o`000?nV`NgoY/7]00;o000000?oY/7]o`000?nV`Nd00ol00002ojK1k@04o`000?nV`Ngo0000
o`0000;oY/7]00Co0000ojK1kOl0003o00000onV`^d2o`0000CoY/;]0ol00003ojK2k@?o00000onV
`^d3o`0000?oY/;]0ol00002ojK2k@;o00000ooO`kd4o`000003omRm_ol0003oe[Zn00;oe[Zn0ol0
0004olfd`@03o`000?o=/;gocK2m00;o000000Goj/2Yo`000?l0003o0000omR/Z`05o`0000CocibR
0_l00002ol>CX`co000000?oW76Qo`000?nNMZD00_nNMZD02On9IZCo0000o`000?l0003oRFJTo`00
0?mcFJGo0000og9IYP02o`0000;oIE6V0_l000001?m9A:[o9S^aob/n/_l08ZP2o`0`]`?o000000Co
RWfoohUj_?n9N[coRGZl1?n4N;h00on0MKgoNW6mogYa_@02ogYa_@?o00000_mZJ[l00ol0003oGUjj
oeiN^P02o`000004on;Baol0003o0000oo;@[P;o000000?oo=2Fo`000?l000000_l000000onV`^go
0000ojK2k@08o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d3o`0000?oY/;]00?o0000ojK2kOnV
`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV
`^d00_l000000onV`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV
`^d00ol00003ojK2k@?o00000onV`^d3o`0000?oY/;]0ol00003ojK2k@?o0000<?oonfX00ol0003o
oo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01kooo]Z000KoookJP03o`000?oonf[ooo]Z04Cooo]Z
0ol00006oookJP;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1
kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000004ojK1
kOl0003o0000o`0000;oY/7]1?l00002ojK1k@?o000000OoY/7]o`000?nV`NgoY/7]o`000?nV`Ngo
000000;oY/7]0ol00002ojK1k@?o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002
o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002
o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000001?nV`Ngo0000o`000?l0
0002ojK1k@?o00000_nV`Nd01?l0003oY/7]o`000?nV`Nd2o`0000;oY/7]0_l00003ojK1k@;o0000
0onV`Nd2o`0000?oY/7];Ol00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o0000
0onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d3o`0000?oY/;]0_l00003ojK2k@03o`00
0?nV`^goY/;]00;oY/;]00Oo0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00;o00000_nV`^d2o`00
00?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`00
00?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]00;oY/;]00Go0000ojK2kOnV`^go0000ojK2k@04
o`0000;oY/;]0ol00002ojK2k@?o00000_nV`^d3o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2
o`0000?oY/;]0_l00003ojK2k@03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX0?ooonfX0
0ol0003ooo]ZoookJP0NoookJP;o00001?nV`Nd2o`0000CoY/7]0ol00003ojK1k@?o00000onV`Nd3
o`0000?oY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@04ojK1k@03o`000?nV`Ngo
Y/7]00?oY/7]00?o0000ojK2kOnV`^d00_l000000onV`^go0000ojK2k@03o`000003ojK2kOl0003o
Y/;]00?o00000_nV`^d01?l0003oY/;]o`000?l00002ojK2k@04o`000?nV`^go0000o`0000?oY/;]
0ol000000ooRa[go0000o`000002omo3_@;og;nl00?o0000omVl_Ol000000ooF^[h00ol0003oe;Nl
omBg_003o`000004olfd`Ol0003ocK2molf`_@;o00000_oZ`:T01_l0003oi;RYo`000?l0003of:b[
o`0000;ofJRU0ol000001_o?W:;o0000olJDX_l0003o`i>So`0000Go]8BQ00?o0000ojf1YOn]PJD0
0on]PJD2o`0000?oWWJU0_l00004ohUVY003o`000?mcFJGo000000?o000000?oIE6Vo`000?mHDJl0
0_l00002obHk/@04o`000?l08ZSo032go`00QPKo00000on4N;h3oh1e_@;oNW6m00CoMVjlofYV_?mZ
I[coJVJl0ol000001?mNG[[o0000omCAeooDdML2o`000005onKGaol0003om=>]o`000?old9H01?l0
00001OnV`^go0000o`000?l0003oY/;]00;o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000
ojK2k@03o`000003ojK2kOl0003oY/;]00?o00000_nV`^d3o`0000CoY/;]0ol00003ojK2k@?o0000
0onV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`00
0?nV`^goY/;]00?oY/;]00Co0000ojK2kOnV`^goY/;]0_l000000onV`^go0000ojK2k@03o`000003
ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol0000eoookJP03o`000?oonf[ooo]Z02Wo
oo]Z00?o0000oookJ_oonfX07_oonfX001_ooo]Z00?o0000oookJ_oonfX0@OoonfX3o`0000[ooo]Z
0_l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]
0ol00002ojK1k@Co000000CoY/7]o`000?l0003o00000_nV`Nd3o`000006ojK1kOl0003o0000ojK1
kOl0003oY/7]0_l000001?nV`Ngo0000o`000?l00002ojK1k@?o000000?oY/7]o`000?l000000_l0
00000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l0
00000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l0
0003ojK1k@03o`000?nV`NgoY/7]00;oY/7]00Oo0000ojK1kOnV`Ngo0000ojK1kOl0003oY/7]00;o
00000onV`Nd2o`0000?oY/7]9?l000000onI5`?o0000o`00000:o`000003ojK2kOl0003oY/;]00;o
00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o
00000onV`^d3o`0000;oY/;]0ol00003ojK2k@;o00000onV`^d00ol0003oY/;]ojK2k@02ojK2k@07
o`000?nV`^goY/;]o`000?nV`^go0000ojK2k@02o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2
o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d0
0ol0003oY/;]ojK2k@02ojK2k@;o000000GoY/;]o`000?nV`^go0000ojK2k@02o`000003ojK2kOl0
003oY/;]00;o00000_nV`^d3o`0000;oY/;]0ol00002ojK2k@?o00000onV`^d2o`0000?oY/;]0_l0
0003ojK2k@03o`000?oonf[ooo]Z00oooo]Z00?o0000oookJ_oonfX0?ooonfX00ol0003ooo]Zoook
JP0NoookJP03o`000?nV`Ngo000000;o00000_nV`Nd01?l0003oY/7]o`000?l00002ojK1k@04o`00
0?nV`Ngo0000o`0000?oY/7]0_l00004ojK1k@;o00001?nV`Nd2o`0000CoY/7]0ol00003ojK1k@?o
00000onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV
`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00;o000000GoY/;]o`000?l0
003oh/Jmo`000002omo3_0;o000000Cog;nlo`000?l0003ofKbm0_l000000ooF^[ko0000omBg_002
omBg_0;o000000Kock:lo`000?l0003ocK2mo`000?o:[;/3o`0000;oi;RY00Co0000omf`ZOl0003o
00000_oIZ:D00ol0003odYnSom:OX`08o`0000;o]8BQ0_l00005ojf1Y@03o`000?nNMZGo000000;o
000000?oWWJUo`000?n9IZ@00_n9IZ@3o`0000?oLeVU0_l00002oeQA[`;o00000_lV>k401?l0003o
02:Xo`000?l00002o`1?c@03o`0Z[ol0003oRW^m00;o000000?oQ7Rno`000?l000000_l000001?mj
LKgo0000ogI^_?mfK[`2ofYV_004o`000?m[I;SoJfBho`0000;oe=7G00Go0000omGCeooEdmOo0000
on[La@08o`0000;oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`00
0?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00_l00002ojK2k@03o`000?nV`^go000000;o0000
00?oY/;]o`000?nV`^d00ol00002ojK2k@?o00000onV`^d3o`0000?oY/;]0ol00003ojK2k@?o0000
0onV`^d3o`0000CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`00
0?nV`^goY/;]00?oY/;]00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP0YoookJP03o`00
0?oonf[ooo]Z01kooo]Z000KoookJP03o`000?oonf[ooo]Z03kooo]Z0ol0000?oookJP;o00000_nV
`Nd3o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`00
0002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`00
0002o`000003ojK1kOl0003o000000;o000000CoY/7]o`000?l0003o00000_nV`Nd3o`000006ojK1
kOl0003o0000ojK1kOl0003oY/7]0_l000001?nV`Ngo0000o`000?l00002ojK1k@?o000000?oY/7]
o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]
o`000?l000000_l000000onV`Ngo0000o`000002o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd0
0ol0003oY/7]ojK1k@02ojK1k@03o`000?nV`NgoY/7]00;o000000?oY/7]o`000?nV`Nd04Ol00000
0om/00oo0000o`00000Qo`000008ojK2kOl0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d2o`0000;o
Y/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?o
Y/;]0ol00002ojK2k@?o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d01ol0003o
Y/;]ojK2kOl0003oY/;]o`000?nV`^d00_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003
ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003
ojK2k@03o`000?nV`^goY/;]00;oY/;]00Oo0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00;o0000
0_nV`^d2o`0000?oY/;]0ol00002ojK2k@?o00000_nV`^d3o`0000;oY/;]00?o0000oookJ_oonfX0
3ooonfX00ol0003ooo]ZoookJP0ooookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000ojK1kOnV`Nd0
1?nV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00;o000000?oY/7]o`000?nV`Nd0
0ol000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00?o00000_nV`Nd01?l0003oY/7]
o`000?l00003ojK1k@;o00001?nV`^d2o`0000CoY/;]0_l00004ojK2k@?o00000onV`^d3o`0000?o
Y/;]00?o0000ojK2kOnV`^d00_nV`^d2o`000007on;6_Ol0003ogl>lomo3_?l0003ogKnko`000002
omZl_003o`000?oG^KcoekVl00?o000000Goe;Nlo`000?oA/[_odK:ko`000002olj_^`?o00000_o[
`JT3o`0000;ogK2Y00Co0000om6UZol0003o00000ooBWj<01Ol0003o`I6Uol6AYOo1TJGo000000?o
_Y2V2ol00005oiifY@?o000000?oS6RTo`000?mcFJD00omcFJD02?l0003oH56Yo`000?mHDJoo0000
oeQA[ol0003o9S^a0_lZ?K82o`000003o`0DXol0Clgo03Vm00Co00001?n1M;`00ol0003oMffjogM]
^P02o`000003ogI^_?l0003o000000;o00000_oDdML00ol0003oeM?GomGCe`02o`000003on[LaOl0
003o000000Ko00000onV`^d3o`0000?oY/;]0ol00003ojK2k@?o00001?nV`^d00ol0003oY/;]ojK2
k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00_l000000onV`^go0000ojK2
k@03o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol00003ojK2k@;o00001?nV
`^d3o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d3o`0003cooo]Z00?o0000oookJ_oonfX0:?oo
nfX00ol0003ooo]ZoookJP0NoookJP006ooonfX00ol0003ooo]ZoookJP0koookJP?o00004_oonfX0
1Ol0003oY/7]o`000?l0003oY/7]00?o00000_nV`Nd3o`000003ojK1kOl0003o000000;o000000?o
Y/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?o
Y/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000Co
Y/7]o`000?l0003o00000_nV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l000001?nV
`Ngo0000o`000?l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o00000onV`Nd2
o`0000CoY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]00?o0000ojK1kOnV`Nd00_nV`Nd0
0ol0003oY/7]o`00000Zo`000003ojLW3Ol0003o000000Wo00001?nV`^d01ol0003oY/;]ojK2kOl0
003oY/;]o`000?nV`^d00_l000000onV`^go0000ojK2k@02o`0000;oY/;]0_l00003ojK2k@;o0000
0onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d3o`0000?oY/;]0_l00003ojK2k@;o0000
0onV`^d00ol0003oY/;]ojK2k@02ojK2k@07o`000?nV`^goY/;]o`000?nV`^go0000ojK2k@02o`00
00;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`00
00?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d01?l0
003oY/;]ojK2kOl00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d0
0ol0003ooo]ZoookJP0>oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX08OoonfX3
o`0000?oY/7]0ol00003ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd00onV`Nd0
0ol0003oY/7]ojK1k@03ojK1k@03o`000?nV`NgoY/7]00CoY/7]00?o0000ojK1kOnV`Nd00_l00000
0onV`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol00002
ojK2k@?o00000onV`^d3o`0000CoY/;]0ol00002on?6^`;o000000Cogl>lo`000?oM_k_ogKnk0_l0
00001OoJ_;co0000o`000?oG^Kco000000;odkNn0_l000001OoA/[_o0000o`000?o>[k_o000000;o
bZjm00Go0000on_1ZOo[`JWo0000onFjZ@03o`0000;odJF[1Ol00004ol6AY@03o`000?nnT:Ko_Y2V
00;o_Y2V00?o0000okR8Xol000000on]PJD00ol0003o[7nTo`000005oiifY@;o00000on<J:@01_l0
003oLeVUog=IYOmcFJGoO5nVo`0000;oH56Y0_l00002oeQA[`04o`000?lX?;7o:Sfbod5<]`;o<E;4
00?o01BSo`000?l0>Kd00_l000000ol2JM_o0000o`000003o`0000?oMffj0ol00002oj76l`03o`00
0?oDdMOo000000;oeM?G00?o0000omKEeol000000ol000000oo^h<;o0000o`000005o`000003ojK2
kOl0003oY/;]00?o00000onV`^d2o`0000CoY/;]0ol00003ojK2k@?o00000onV`^d3o`0000?oY/;]
00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]
00Co0000ojK2kOnV`^goY/;]0_l000000onV`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00?o
000000?oY/;]o`000?nV`^d00ol00002ojK2k@?o0000@_oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z01kooo]Z000JoookJP03o`000?oonf[ooo]Z03Wooo]Z0ol0000FoookJP07o`00
0?nV`Ngo0000o`000?nV`Ngo0000ojK1k@02o`000004ojK1kOl0003o0000o`0000;oY/7]0ol00000
0onV`Ngo0000o`000002o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol00002
ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o000000OoY/7]o`000?nV`NgoY/7]o`00
0?nV`Ngo000000;oY/7]00?o0000ojK1kOl000000_nV`Nd3o`0000;oY/7]0ol00003ojK1k@;o0000
0onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1kA?o0000
00?oQQ/_o`000?l000003_l000000onR<2ko0000oj@_9P0;o`000003ojLP0?l0003o000000Go0000
0onV`^d00ol0003oY/;]ojK2k@02ojK2k@03o`000?nV`^goY/;]00;oY/;]00Oo0000ojK2kOnV`^go
0000ojK2kOl0003oY/;]00;o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`00
00?oY/;]0ol00002ojK2k@?o00000_nV`^d3o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]
00;oY/;]00Oo0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00;o00000_nV`^d2o`0000?oY/;]0_l0
0003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l0
0003ojK2k@;o00000onV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l00002ojK2k@;o
00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oo
nfX0?ooonfX00ol0003ooo]ZoookJP0SoookJP;o00001?nV`Nd2o`0000CoY/7]0_l00004ojK1k@;o
00001?nV`Nd2o`0000CoY/7]0ol00003ojK1k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV
`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00;o00000_nV`^d01?l0003o
Y/;]o`000?l00002ojK2k@03o`000?nV`^go000000;o000000?oY/;]o`000?nV`^d00_l000000ooS
a[_o0000on73^P02o`000004omfo^ol0003og;bjombl^P;o000000Gof;Zlo`000?oC]kkodkNno`00
0002om:c^`Co00000oo:[[d00ol0003ojl6Yo`000002onFjZ@03o`000?oO/ZWo000000?o00000ooB
Y:L6o`0000?o_Y2V00Oo0000okR8XonhR:?o^8RSo`000?n]PJGo000000?o[7nT00?o0000oiifYOl0
00000_l000000onLMJGo0000ohaXY003ohaXY003o`000?mcFJGoO5nV00;oO5nV00?oH56Yo`000?m_
Fj/00_l000001?mHDJoo=Cn^o`000?l00002od5<]`;o<E;400Ko01BSo`000?l0003o036ho`000?l=
KMh2o`0000;oGjGf0ol00006oj76l`;o000000?oeM?Go`000?l000000ol000001Oo^hL;o0000onkP
`_l0003ooN:H00;o00001OnV`^d01?l0003oY/;]ojK2kOnV`^d2o`000003ojK2kOl0003oY/;]00?o
000000?oY/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`0000;oY/;]0ol00003ojK2k@?o
00000onV`^d3o`0000?oY/;]0ol00004ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV
`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00;o0000AooonfX00ol0003o
oo]ZoookJP0VoookJP03o`000?oonf[ooo]Z01kooo]Z000JoookJP03o`000?oonf[ooo]Z03Kooo]Z
0ol0000JoookJP;o00000_nV`Nd3o`000008ojK1kOl0003oY/7]ojK1kOl0003oY/7]o`000?nV`Nd3
o`0000?oY/7]0ol000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]
o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]
o`000?l000000_l000000onV`Ngo0000o`000002o`000004ojK1kOl0003o0000o`0000;oY/7]0ol0
0002ojK1k@?o000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd2o`0000;oY/7]0_l00003ojK1k@;o
00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l000000onV`Ngo
0000o`00000Co`0000?oRbHo00?o0000oiH_?ol000000_nF;C/00ol0003oWcM0o`000002oj0f?0co
000000?o[C<Lo`000?l000001?l000000ona:@3o0000o`000004o`0000?oY/;]0_l00003ojK2k@;o
00000onV`^d00ol0003oY/;]ojK2k@02ojK2k@07o`000?nV`^goY/;]o`000?nV`^go0000ojK2k@02
o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d3
o`0000;oY/;]0ol00002ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@02ojK2k@05o`000?nV`^go
Y/;]o`000?nV`^d01?l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV
`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV
`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l00002ojK2k@;o00000onV`^d2o`0000?o
Y/;]00?o0000oookJ_oonfX03?oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z02Co
oo]Z00?o0000ojK1kOl000000_l000000onV`Ngo0000ojK1k@03o`000003ojK1kOl0003oY/7]00?o
00000_nV`Nd3o`0000?oY/7]0ol00003ojK1k@?o00001?nV`^d2o`0000CoY/;]0_l00004ojK2k@;o
00001?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV
`^d00onV`^d2o`000007onC6^Ol0003o0000on73^_l0003og[nio`000003ombl^P06o`000?oJ^KWo
0000o`000?oC]kko00000ooB/k/01?l0003odK2iom6`^Ol00002olZ^_@06o`000?oZ`J[o0000o`00
0?oU^ZWo00000_oO/ZT01?l0003of:^ZomR[Z_l00003om:TY`04o`000?o;VjGobi^Uol^KYA7o0000
0onLMJD9o`000003ogaOY_l0003o000000?oKe^[0_l00002ocDo[P03o`000?m1C;Oo@Dbg00;o<E;4
00?o03Vlo`000?l000002?l000001?mOYOKo0000oj76lonQa_<7o`0000;oe]GG00Go0000om[Fe?l0
003o0000onkP`P02o`000004oogRV?l0003o0000ojK2k@;o00001?nV`^d00ol0003oY/;]ojK2k@03
ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@02
o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol00003ojK2k@;o00001?nV`^d3
o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d3o`0000?oY/;]00?o0000oookJ_oonfX0BOoonfX0
0ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01kooo]Z000JoookJP03o`000?oonf[ooo]Z
03?ooo]Z0ol0000OoookJP;o000000CoY/7]o`000?l0003o00000_nV`Nd3o`000006ojK1kOl0003o
Y/7]ojK1kOl0003oY/7]0_l000001?nV`Ngo0000o`000?l00002ojK1k@?o000000?oY/7]o`000?l0
00000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l0
00000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l0
00000_l000000onV`Ngo0000o`000002o`000004ojK1kOl0003o0000o`0000;oY/7]0ol00002ojK1
k@04o`000?nV`Ngo0000ojK1k@;o00000_nV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2
o`0000?oY/7]0_l00003ojK1k@[o00000_mL020Ro`0000;o/3d^0ol000000onf?bCo0000o`000009
o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d0
1ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]
0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@?o00000_nV`^d3o`0000;oY/;]
00?o0000ojK2kOnV`^d00_nV`^d00ol0003oY/;]ojK2k@02o`000003ojK2kOl0003o000000;o0000
00CoY/;]o`000?l0003o00000_nV`^d3o`0000;oY/;]0ol00003ojK2k@;o00000onV`^d2o`0000?o
Y/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d01ol0003o
Y/;]ojK2kOl0003oY/;]o`000?nV`^d00_l00002ojK2k@;o00000onV`^d00ol0003ooo]ZoookJP0;
oookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000oookJ_oonfX09OoonfX00ol0003oY/7]ojK1k@03
ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd00_l00002ojK1k@04o`000?nV`Ngo
0000o`0000;oY/7]00Co0000ojK1kOl0003o00000_nV`^d00ol0003oY/;]o`000002o`0000;oY/;]
0ol00003ojK2k@?o00000onV`^d3o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d3o`0000;oY/;]
00Ko0000onK5]Ol0003o0000on;3^Ol00002omjo^@;o000000Kog;bjo`000?oJ^KWof[Vio`000?oG
]KL3o`000003om:c^ol0003odK2i00;odK2i1?l000000ooZ`J[o0000onFkZ`04o`0000?of:^Z1?l0
0003ol^KY@03o`000?o2TjGo000000;o_Y2W00?o0000ok:5Y?nbQJ@00_nbQJ@2o`0000Co/8JX00?o
0000oiaeYOnLMJD00_l000000onNN:So0000o`000003ohe]Z@03o`000?mjHZ_oNV:[00?o00000om_
Fj/02?l0003oDe2ao`000?le?jko0000oci<^?l0003o6T:m0_l000001?l0>Kco<FGEoc5UeOl0A<D2
o`000003oaach_l0003oIZGd00;oIZGd1ol00002oj?9m005o`000?oFeMOo0000om[Fe?l000000_oM
g]L00ol0003ol>?0o`000003o`0000;oY/;]0ol00003ojK2k@?o00000onV`^d3o`0000?oY/;]0ol0
0003ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d01?l0003oY/;]ojK2
kOnV`^d2o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000
ojK2k@03o`0000;oY/;]0ol00003ojK2k@?o0000C_oonfX00ol0003ooo]ZoookJP0VoookJP03o`00
0?oonf[ooo]Z01gooo]Z000JoookJP03o`000?oonf[ooo]Z033ooo]Z0ol0000SoookJP;o000000?o
Y/7]o`000?l000000_l000001?nV`Ngo0000o`000?l00002ojK1k@?o000000KoY/7]o`000?l0003o
Y/7]o`000?nV`Nd2o`000004ojK1kOl0003o0000o`0000;oY/7]0ol000000onV`Ngo0000o`000002
o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002
o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002
o`000003ojK1kOl0003o000000;o00000onV`Nd00ol0003oY/7]ojK1k@02ojK1k@07o`000?nV`Ngo
Y/7]o`000?nV`Ngo0000ojK1k@02o`0000;oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]
2_l000000om:01Oo0000o`000009o`0000;oQBM900?o0000ohl_BOl000004Ol00002oje6A`;o0000
0_neCDH4o`000003okQ8=?l0003o000000?o000000?o]SH;o`000?l000001Ol00003ojK2k@;o0000
0onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d00ol0003oY/;]ojK2k@02ojK2k@07o`00
0?nV`^goY/;]o`000?nV`^go0000ojK2k@02o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`00
00?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d00ol0
003oY/;]ojK2k@02ojK2k@07o`000?nV`^goY/;]o`000?nV`^go0000ojK2k@02o`0000;oY/;]0_l0
0003ojK2k@?o00000_nV`^d3o`0000;oY/;]0ol00002ojK2k@?o00000_nV`^d3o`0000;oY/;]0ol0
0002ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@02ojK2k@05o`000?nV`^goY/;]o`000?nV`^d0
1?l000000onV`^go0000oookJP0=oookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0
9ooonfX2o`0000CoY/7]0_l00004ojK1k@03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd0
0onV`Nd00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00;o00000_nV`^d01?l0003oY/;]
o`000?l00002ojK2k@04o`000?nV`^go0000o`0000;oY/;]00Co0000ojK2kOl0003o00000onV`^d2
o`0000CoY/;]0_l00004ojK2k@Co000000?oi/Feo`000?oT`K@00_l000001?oN_kWo0000omZm^ooJ
_K/2o`000005omZi^Ol0003oekFgomNe]ol000000_oC/[P3o`000004om6`^Ol0003ocZbholj/^0?o
00000_oU^j/00ol0003ohKFZon6eZP02o`000005omR[Z_l0003oc:6/o`000?oBY:P01_l000000oo2
TjGo0000o`000005ok:5Y003o`000?n`QZSo/8JX00Co/8JX1_l00005ohe]Z@;o00000_mjHZ/2o`00
00;oKe^[00So0000oe=@/OmCD;7o0000od9>^?l0003oDURko`0000;oAEk700Oo03Vlo`93`olaIMGo
04g<o`14aOl0003oAH?V00So00001_nSbO@00ol0003of]KDo`000002omgNe`?o000000?ol^Jmo`00
0?l000000_l000000onV`^go0000ojK2k@03o`0000;oY/;]0ol00003ojK2k@?o00000onV`^d3o`00
00?oY/;]0ol00004ojK2k@;o00001?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]
00?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@02o`000003ojK2kOl0003oY/;]
00?o0000DooonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01gooo]Z000JoookJP03
o`000?oonf[ooo]Z02gooo]Z0ol0000WoookJP;o000000?oY/7]o`000?l000000_l000000onV`Ngo
0000o`000002o`000004ojK1kOl0003o0000o`0000;oY/7]0ol000001_nV`Ngo0000o`000?nV`Ngo
0000ojK1k@;o000000CoY/7]o`000?l0003o00000_nV`Nd3o`000003ojK1kOl0003o000000;o0000
00?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o0000
00?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000?oY/7]0_l00003ojK1k@;o0000
0onV`Nd00ol0003oY/7]ojK1k@02ojK1k@07o`000?nV`NgoY/7]o`000?nV`Ngo0000ojK1k@02o`00
00;oY/7]0_l00003ojK1k@;o00000onV`Nd?o`0000?oNAa41ol00002oi<jF004o`000?nM@USoWD9H
o`0000;oWD5E00?o0000ojE9F?l000000onVBEH2o`000003oji=D_l0003o000000Oo000000?o]Ta2
o`000?l000001?l000000onkA2?o0000o`000007o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2
o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d00ol0003oY/;]ojK2k@02ojK2k@04o`000?nV`^go
Y/;]o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV
`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV
`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l00002ojK2k@;o00000onV`^d2o`0000?o
Y/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@?o00000_nV`^d3o`0000;o
Y/;]00?o0000ojK2kOnV`^d00_nV`^d01?l0003oY/;]ojK2kOl00002ojK2k@03o`000?oonf[ooo]Z
00_ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0XoookJP?o00000onV`Nd3o`00
00?oY/7]0ol00003ojK1k@?o00000onV`Nd3o`0000CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0
003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00_l000000onV
`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00?o000000KoY/;]o`000?nV`^go0000onO4/_l0
0002onC1]003o`000?oR_[?o000000?of[fk00?o0000omZh]ol000000_l000001OoG]KOoe;>ho`00
0?oC/[So000000;od;2j0_l000001?o>[;So0000onG5]ooUaKL3o`0000?ohKFZ00?o0000omZ^Zol0
00000_l000000oo<XJco0000olfPZP02olfPZP03o`000?nmT:Oo_I2W013o00001?nONZX00ol0003o
SFfYohe]Z@02ohe]Z@;o00000omjHZ/00ol0003oJeb_ofmKZ`02o`000003oe=@/Ol0003oI5^c00;o
00000_mBF;/00ol0003oAEk7odENa`03o`000003o`1=c?l0003o000000Co00000om_Y_<00ol0003o
XlWdoj?9m003o`000008ojO=m?l0003o0000o`000?oMg]Oo0000on3QeOl00002oo;V_@03o`000?ol
hhco000000?oY/;]00?o0000ojK2kOnV`^d00_l000000onV`^go0000ojK2k@03o`0000;oY/;]00Co
0000ojK2kOl0003o00000_nV`^d01?l0003oY/;]o`000?l00003ojK2k@?o00000onV`^d3o`0000?o
Y/;]0ol00003ojK2k@?o00000onV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003o
oo]ZoookJP1EoookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX07OoonfX001[ooo]Z
00?o0000oookJ_oonfX0:_oonfX3o`0002_ooo]Z0_l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]
0ol00002ojK1k@?o00000_nV`Nd2o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l000001?nV
`Ngo0000o`000?l00002ojK1k@?o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd3
o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@03o`000?nV`Ngo
Y/7]00;oY/7]00Co0000ojK1kOnV`Ngo00000_nV`Nd2o`0000?oY/7]0_l000000onV`Ngo0000o`00
000:o`0000;oK0ln00?o0000ogTLA?l000000ol000000on:<ECo0000o`00000Jo`0000;o^5A@1ol0
00000onnCcOo0000o`000004o`000003ol=53?l0003o000000?o00000_nV`^d2o`0000?oY/;]0_l0
0003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d01ol0003oY/;]ojK2
kOl0003oY/;]o`000?nV`^d00_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o
00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03
o`000?nV`^goY/;]00;oY/;]00Oo0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00;o00000_nV`^d2
o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2
o`0000?oY/;]0_l00003ojK2k@06o`000?nV`^goY/;]o`000?nV`^go00003OoonfX00ol0003ooo]Z
oookJP0moookJP03o`000?oonf[ooo]Z02Wooo]Z00Co0000ojK1kOl0003o00000_nV`Nd01?l0003o
Y/7]o`000?l00002ojK1k@04o`000?nV`Ngo0000o`0000?oY/7]0_l00004ojK2k@?o00000onV`^d3
o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^go
Y/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oilBbonO4/P03o`0000;oh[jc0_l00000
1OoJ_K_o0000omZh]ooJ^;Oo000000;of;Ff0_l000000ooD/kSo0000om2`^P02om2`^P04o`000?o?
[KOo0000o`0000;oiLFg1?l000001OoQ]J[o0000omZ^ZooJ[Z_o000000;odjN[0_l00002olfPZP03
o`000?nmT:Oo_I2W00;o_I2W00?o0000okZ?Z_njSjX00onjSjX2o`0000CoZh:Y00?o0000oj^2Z?l0
00001OnONZX01_l0003oSFfYo`000?l0003oSfjYo`0000?oNV:[0_l00003of]L[`05o`000?mTFk?o
I5^cofAK/ol000000_mBF;/01OlfE<Co0000odENaol@AlCo0T?300Co000000CoEXWVo`000?lTM>;o
00000omhZ?400om_Y_?o0000o`000004ojO=m004o`000?nfeO3o]]G`o`0000;oh>7E00?o0000oo;V
_Ol000001?l00003ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d01?nV`^d00ol0
003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00;o000000?oY/;]o`000?nV`^d00ol000000onV
`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00?o00000_nV`^d3o`0000?oY/;]0ol00003ojK2
k@?o0000FooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01gooo]Z000IoookJP03
o`000?oonf[ooo]Z02Oooo]Z1?l0000`oookJP;o000000?oY/7]o`000?l000000_l000000onV`Ngo
0000o`000002o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000001?nV`Ngo
0000o`000?l00002ojK1k@?o000000OoY/7]o`000?nV`NgoY/7]o`000?nV`Ngo000000;oY/7]0ol0
0002ojK1k@?o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`0000;oY/7]0_l0
0003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]00Oo
0000ojK1kOnV`Ngo0000ojK1kOl0003oY/7]00;o00000_nV`Nd;o`000003oed2>?l0003oK0ln00Wo
00000_n>>f001ol0003oUdASoiM4Hol0003oV4=Po`000?nPBf803Ol00002ok9IH@;o00000_njGf47
o`0000;o`Ua>0ol000001?o6FCco0000o`000?o8D282o`000003ol910?l0003o]bh000;o00000_nV
`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV
`^d00ol0003oY/;]ojK2k@02ojK2k@07o`000?nV`^goY/;]o`000?nV`^go0000ojK2k@02o`0000;o
Y/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?o
Y/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d01ol0003o
Y/;]ojK2kOl0003oY/;]o`000?nV`^d00_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003
ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d00ol0003oY/;]ojK2k@02
ojK2k@03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX0?OoonfX00ol0003ooo]ZoookJP0Z
oookJP03o`000?nV`NgoY/7]00?oY/7]00?o0000ojK1kOnV`Nd00onV`Nd00ol0003oY/7]ojK1k@02
o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol00002ojK2k@04o`000?nV`^go
0000o`0000?oY/;]0_l00004ojK2k@;o00001?nV`^d2o`0000CoY/;]0_l00004ojK2k@;o00000_nV
`^d00ol0003oilBbo`000002onG0/P?o000000Kog[Zco`000?l0003o0000omZh]ol00003omRe]P04
o`000?oF/[Go0000o`0000;od;2j00?o0000oln]]oo?[KL00_l000001_oUaKOo0000omjl]_oN_;Ko
0000on2eZ`Co00000ooCYj/7o`0000;o_I2W00?o0000okZ?Z_njSjX00_njSjX00ol0003o]XVWo`00
0003oj^2Z@04o`000?n[PZSoZh:Xo`0000;oWgZZ1?l00004ohm^Z@06o`000?mjHZ_o0000o`000?n2
Ij_o00000_m[G:l01?l0003oMV>`o`000?mTFk<2o`000005odmI_OmBF;_o0000o`000?m5G/L00ol0
0002od9]eP;o000000?oEXWVo`000?l000002?l00002ojc<l@09o`000?nfeO3o0000o`000?oPhMGo
0000onCTd_l0003om>Rj00Go00001?nV`^d2o`0000CoY/;]0ol00003ojK2k@?o00000onV`^d00ol0
003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0
003oY/;]ojK2k@02o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol0001Ooook
JP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX07OoonfX001Wooo]Z00?o0000oookJ_oo
nfX09?oonfX3o`0003Gooo]Z0_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o
000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o
000000CoY/7]o`000?l0003o00000_nV`Nd3o`000006ojK1kOl0003o0000ojK1kOl0003oY/7]0_l0
00001?nV`Ngo0000o`000?l00002ojK1k@?o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o0000
0onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000;oY/7]00?o0000ojK1kOnV`Nd0
0_nV`Nd01Ol0003oY/7]ojK1kOl0003oY/7]01Co00000_n>>f0:o`0000?oXeE`00?o0000ojaKKon/
Ffl00on/Ffl00ol0003o/V5`ok9QL008o`0000;o^emN0_l00002ol=VGP?o000000?o`ea9o`000?l0
00002ol00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?o
Y/;]0_l00003ojK2k@;o00000onV`^d00ol0003oY/;]ojK2k@02ojK2k@07o`000?nV`^goY/;]o`00
0?nV`^go0000ojK2k@02o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003
ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000
ojK2kOnV`^d00_nV`^d01?l0003oY/;]ojK2kOl00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l0
0003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o
0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z02_ooo]Z0ol0
0003ojK1k@?o00000onV`Nd00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o
0000ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@02o`000003ojK2kOl0003oY/;]00?o000000?o
Y/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`0000;oY/;]0ol00003ojK2k@Go00000ooU
`;800ol0003ohkfao`000002omjj/`03o`000?oK]kCo000000;o000000Kof;Ffo`000?oF/[Goe[:e
o`000?oC[[@3o`000004oln]]ol0003o0000onK5]P;o000000Gog[bfo`000?l0003oh;F[o`000002
om^a[PCo000000Goaif]o`000?o<X:[oc:2Zo`000002olNM[@Go000000?o^XnZo`000?nfRJL00_nf
RJL9o`0000?oWGVZ00Co0000ohm^ZOn?KZWoSfjY0_l00005oh9WZ`04of]L[ol0003oMV>`ogIS/0?o
000000?oEEbno`000?l000000ol000001OmEJ<[o44O4o`000?mEMmSo@VgF00Oo00000on2Znl2o`00
00;o[<ca00Co0000ojc<lOl0003o_M__0_l00002onCTdP;o000000Gon>Fao`000?l0003o0000ojK2
k@03o`000003ojK2kOl0003oY/;]00?o00000_nV`^d3o`0000?oY/;]0ol00003ojK2k@?o00000onV
`^d3o`0000?oY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV
`^d00ol0003ooo]ZoookJP1QoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX07Ooo
nfX001Wooo]Z00?o0000oookJ_oonfX08OoonfX3o`0003Wooo]Z0_l000000onV`Ngo0000o`000002
o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002
o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000001?nV`Ngo0000o`000?l0
0002ojK1k@?o000000KoY/7]o`000?l0003oY/7]o`000?nV`Nd2o`0000;oY/7]0_l00003ojK1k@;o
00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o
00000onV`Nd2o`0000?oY/7]00?o0000ojK1kOl000003Ol00002ogX[G003o`000?n5=5oo000000Go
000000CoTdM/o`000?nKCVkoVdi^4ol000001?ndHVgo0000ok]XK_l00002ok]WJ`Oo00000_o4IU/5
o`000004oleTA?l0003o0000olYC8PKo00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV
`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV
`^goY/;]00;oY/;]00Oo0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00;o00000_nV`^d2o`0000?o
Y/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?o
Y/;]0_l00003ojK2k@;o00000onV`^d01Ol0003oY/;]ojK2kOl0003oY/;]00Co00000_nV`^d2o`00
00?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00002ojK2k@?o00000_nV`^d3o`00
00;oY/;]00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0moookJP03o`000?oonf[ooo]Z
02gooo]Z0_l00004ojK1k@;o00001?nV`Nd2o`0000CoY/;]0_l00004ojK2k@?o00000onV`^d00ol0
003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0
003oY/;]ojK2k@02o`0000;oY/;]00Co0000ojK2kOl0003o00000_nV`^d2o`000005onS3[ol0003o
0000onG0/_l000000_oS_K42o`000004omjj/ol0003ofkNdo`0000;of;Ff0_l000001OoF/[Go0000
om>^]?oC[[Co000000;od:^d0_l00002onK5]P03o`000?oQ_kGo000000?o00000ooK/Jh00ol0003o
eZ^/omJ[[005o`0000Coaif]00Co0000okZ?Z_l0003o^XnZ1ol00004ojj7[003o`000?nMNJ[oWGVZ
00;oWGVZ2_l000000on2Ij_o0000o`000003ogIS/003o`000?m^IKSo000000?o00000_mOHkl00ol0
003oEFS:oeEXbP02o`0000;oEGOH0_l000001?mUSnKo0000odb3iOm<PnD7o`0000;o/Lk_0_l00002
olKSk0;o000000?ojNO>o`000?l000000_l000000onV`^go0000ojK2k@04ojK2k@03o`000?nV`^go
Y/;]00;o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`0000;oY/;]0ol00003
ojK2k@?o00000onV`^d3o`0000?oY/;]0ol00003ojK2k@?o0000IooonfX00ol0003ooo]ZoookJP0Q
oookJP03o`000?oonf[ooo]Z01gooo]Z000IoookJP03o`000?oonf[ooo]Z01kooo]Z0ol0000moook
JP;o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o0000
00;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000004ojK1kOl0003o0000
o`0000;oY/7]0ol00002ojK1k@04o`000?nV`Ngo0000ojK1k@;o00000_nV`Nd2o`0000?oY/7]0_l0
0003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l0
0002ojK1k@Ko000000?o=`0Wo`000?l000001?l000000om^85So0000ogX[G004o`0000;oRSm[00?o
0000oi=7K_l000001Ol00002oimHN@03o`000?nVGW_o000000?oYemj0_l00003ojiUNP;o00000one
JWX<o`0000;oaFmZ0ol000001?o;KEgo0000oli^Eoo>KUL2o`000003oliQ>ol0003obU<R00Ko0000
0_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o0000
0onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d00ol0003oY/;]ojK2k@02ojK2k@07o`00
0?nV`^goY/;]o`000?nV`^go0000ojK2k@02o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`00
00?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d00ol0
003oY/;]ojK2k@02ojK2k@05o`000?nV`^goY/;]o`000?nV`^d01?l000001?nV`^go0000o`000?l0
0002ojK2k@?o00000_nV`^d3o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o
0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0loookJP03o`000?oonf[ooo]Z02kooo]Z00?o
0000ojK1kOl000000_l000000onV`Ngo0000ojK1k@03o`0000;oY/;]0ol00003ojK2k@?o00000onV
`^d3o`0000CoY/;]0_l00004ojK2k@;o00001?nV`^d2o`0000CoY/;]00?o0000ojK2kOnV`^d00onV
`^d00ol0003oY/;]ojK2k@02ojK2k@?o00000_oV_jl2o`000004on>m/Ol0003ohKZ`on6j/0?o0000
0ooH]KH00ol0003oek6co`000002o`000004om>^]?l0003od:^dom2[]0Co00000_oQ_kD01?l0003o
g;Vdombi]?l00002om^a[P05o`000?oFZjcoeZ^/omJ[[?l000000_o?Y:d3o`0000;oaif]00Co0000
okZ?Z_njSj[o^XnZ0_l00004okN?[@03o`000?n^Qjco[XN/00Co[XN/00?o0000oieiZ_l000000ol0
0005oi1c[P03o`000?n0J[3o000000Co000000CoMV>`o`000?l0003o00000_m^IKP01ol0003oGf>o
oemS_omOHkooBf?9o`000?mEJ<X00_lhIM<01?l0003oEGOHo`000?lfImD2o`000003odb3iOl0003o
000000?oRjo^00Oo0000ogZ]lol0003o0000okOAkOl0003oa^?/00;o000000?od>cXo`000?o?gN<0
1?l00002ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]
00?o0000ojK2kOnV`^d00_l000000onV`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00?o0000
0_nV`^d01?l0003oY/;]o`000?l00003ojK2k@;o0000KOoonfX00ol0003ooo]ZoookJP0PoookJP03
o`000?oonf[ooo]Z01gooo]Z000IoookJP03o`000?oonf[ooo]Z01_ooo]Z0ol00012oookJP;o0000
00?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`000003ojK1kOl0003o000000;o0000
00CoY/7]o`000?l0003o00000_nV`Nd3o`0000;oY/7]0ol00002ojK1k@?o000000?oY/7]o`000?l0
00000_l00003ojK1k@03o`000?nV`NgoY/7]00;oY/7]00Co0000ojK1kOnV`Ngo00000_nV`Nd2o`00
00?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`00
00?oY/7]0_l000000onV`Ngo0000o`000008o`0000;oKR1H1?l00002oh0gJ@03o`000?n:?f_o0000
00?o00000_nGDGT2o`0000;oWeQi4_l000000oneJW[o0000okeaNP02okeaNP04o`000?nnLGWo_W5i
o`0000;oaWQi1Ol000000oo=MV[o0000o`000003o`000003olm[D?l0003ocV4k00?o000000?oeV4Q
o`000?l000000_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2
o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d0
0ol0003oY/;]ojK2k@02ojK2k@04o`000?nV`^goY/;]o`0000;oY/;]0_l00003ojK2k@;o00000onV
`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000;oY/;]0ol00002ojK2k@?o00000_nV
`^d3o`0000;oY/;]0_l00003ojK2k@04o`000?nV`^goY/;]o`0000;oY/;]0_l00003ojK2k@;o0000
0onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000oookJ_oonfX0
2?oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000ojK1kOnV`Nd0
0onV`Nd00ol0003oY/;]ojK2k@02o`0000;oY/;]00Co0000ojK2kOl0003o00000_nV`^d01?l0003o
Y/;]o`000?l00002ojK2k@03o`000?nV`^go000000;o00000_nV`^d3o`0000?oY/;]0ol00003ojK2
k@?o00000onV`^d3o`0000?oY/;]0ol000001?nV`^go0000on_1Z_l00002onJo[`06o`000?oT_:ko
0000o`000?oQ^[3o00000_oN]jl01?l0003of;FfomRe]_l00002omNa/`03o`000?oE[k;oeJnb00Go
00000_oVaKD3o`0000?og;Vd1Ol000000ooFZjco0000olnT[@02olnT[@03o`000?o7WJgoaif]00Co
00000_njSjX00ol0003o]hn]okN?[@03okN?[@04o`000?n^Qjco[XN/ojj7[0Go00000onOOZl00ol0
003oT7>^oi1c[P02oi1c[P?o00000_n6K[07o`00000=ofiU^?l0003oHfS2o`000?mOHkoo0000od]S
bOl0003oDfS;o`000?lhIM?o0000oeIge`02o`000004og>FiOl0003oH8WSof29h`Ko000000?oQ[7a
o`000?ngdNd00_l00002om3/j003o`000?o?gN?o000000Co00000onV`^d3o`0000?oY/;]0ol00003
ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000
ojK2kOnV`^d01?nV`^d00ol0003oY/;]ojK2k@02o`00077ooo]Z00?o0000oookJ_oonfX08?oonfX0
0ol0003ooo]ZoookJP0LoookJP006OoonfX00ol0003ooo]ZoookJP0HoookJP?o0000A_oonfX2o`00
0003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`00
0003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`00
0004ojK1kOl0003o0000o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd01ol0003oY/7]ojK1kOl0
003oY/7]o`000?nV`Nd00_l00002ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o0000
0onV`Nd2o`0000?oY/7]0_l00003ojK1k@?o000000?o0@00o`000?l000001?l000001omL3doo0000
o`000?l0003oMBeVo`000?n0=fT01Ol00002ohm;N003o`000?nGDGWoUe5i00Go00000_nRHXH00ol0
003oZ6R6o`000002ojYYQP04o`000?n`KXKo/6j6o`0000;o/Fn600?o0000okIcQ_l000000_ngM8H<
o`0000;oaWMg1_l00002om1gI@03o`000?o?Je3o000000;o000000CofFdio`000?l0003oeUlG0ol0
00000onV`^go0000ojK2k@02o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l0
0003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l0
0003ojK2k@07o`000?nV`^goY/;]o`000?nV`^go0000ojK2k@02o`0000;oY/;]0_l00002ojK2k@?o
00000_nV`^d3o`0000;oY/;]0ol00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o
00000onV`^d2o`0000?oY/;]00Oo0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00;o00000_nV`^d2
o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?oonf[o
oo]Z00Oooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0aoookJP;o00001?nV`^d0
0ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d0
0ol0003oY/;]ojK2k@02o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV`^d00ol00000
0onV`^go0000ojK2k@03o`0000;oY/;]0ol00004ojK2k@?o000000Cojl6Zo`000?l0003o00000_oT
_:h00ol0003oh[R]o`000003omjg[`Co000000?oek6co`000?oE[k800_oE[k801?l0003odjbao`00
0?l00003onK5]@06o`000?oS`;Co0000o`000?oL^KCo00000_oC/;H00ol0003oeZ^/omJ[[003o`00
0004olnT[Ol0003oaif]o`0000;oaif]00?o0000ol>HZoo3V:/03?l00002ojV4[@;o00001OnOOZl0
1Ol0003oT7>^o`000?l0003oTG>^00Co000000?oQVj`o`000?mmK;D00ommK;D3o`0000;oHfS20ol0
00001Om;HlWo0000of9ac?mRLLco>6GC00;o00000_mQO]P02?l0003oH8WSo`000?l0003oH8WSo`00
0?nE/nco00000_n6/O42o`00000;okgDjol0003od>cXo`000?o?gN?o0000omcPfOl0003ok_O0o`00
0?nV`^d00_l00002ojK2k@04o`000?nV`^go0000o`0000?oY/;]0_l00004ojK2k@;o00001?nV`^d2
o`0000CoY/;]0_l00004ojK2k@?o00000onV`^d00ol0003ooo]ZoookJP1boookJP03o`000?oonf[o
oo]Z023ooo]Z00?o0000oookJ_oonfX07?oonfX001Wooo]Z00?o0000oookJ_oonfX05OoonfX3o`00
04[ooo]Z0_l00002ojK1k@?o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`00
0003ojK1kOl0003o000000;o000000?oY/7]o`000?l000000_l000000onV`Ngo0000o`000002o`00
00?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000;oY/7]00?o0000ojK1kOnV`Nd00_nV`Nd01?l0
003oY/7]ojK1kOl00002ojK1k@03o`000?nV`Ngo000000;oY/7]0_l00003ojK1k@;o00000onV`Nd2
o`0000?oY/7]0_l00003ojK1k@;o00000_nV`Nd6o`000003od/0BOl0003o000000?o000000?oMBeV
o`000?l000000_l00002ohI3MP03o`000?n?BgSoSd]h00Go00000_nKGHD00ol0003oXV:6oj9RQP02
oj9RQQ3o000000?o]gB6o`000?nmN8H00_nmN8H00ol0003o_gZ6okmjQP02o`0000;oah651?l00000
1?o?OgOo0000om20M_o@P7H6o`000004omYgC_l0003o0000omY/<PGo000000SoY/;]o`000?nV`^go
Y/;]o`000?nV`^go0000ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2
o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d0
0ol0003oY/;]ojK2k@02ojK2k@05o`000?nV`^goY/;]o`000?nV`^d00ol00002ojK2k@;o00000onV
`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV
`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d01?l0003oY/;]ojK2kOl00002ojK2k@;o0000
0onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000oookJ_oonfX0
1_oonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z03;ooo]Z0ol00003ojK2k@?o0000
0onV`^d3o`0000?oY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d0
0onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00;o00000_nV`^d00ol0003oY/;]
o`000002o`000003ojK2kOl0003o000000;o00000_oX_JX3o`0000;oh[R]0_l000001_oN]joo0000
om^c[ooK/joo0000omR_[`?o000000CoeJnbo`000?oC[;7odjba0ol000001_oVaKGo0000on?0]?oS
`;Co0000omjk]0;o000000?odk2fo`000?l000000_oFZj`00ol0003odJ^bom6[/P04o`000003olNM
[Ol0003o`iR[00?o`iR[0_l00003okN?[@04o`000?ncRj_o/h^[o`0000?oZHB]00?o0000ojZ5[Ol0
00001?nOOZl01?l0003oT7>^oi5c[_nALjh3o`0000?oQVj`00?oQW6do`000?mmK;D00ommK;D01_l0
003oMVjlogI^_?l0003oHfS2o`0000?oJVc200Go0000of9ac?mRLLcoHW7<o`000003of5nf0;o0000
0_miV^H6o`0000;oU;C]0ol000001?o?gN?og>3IomcPfOoLh=T4o`0000GoY/;]00?o0000ojK2kOnV
`^d00_l000000onV`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00?o00000_nV`^d3o`0000?o
Y/;]0ol00003ojK2k@?o0000N?oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01co
oo]Z000HoookJP03o`000?oonf[ooo]Z01?ooo]Z0ol0001=oookJP05o`000?nV`Ngo0000o`000?nV
`Nd00ol00002ojK1k@?o00000_nV`Nd3o`000003ojK1kOl0003o000000;o000000?oY/7]o`000?l0
00000_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?o
Y/7]00?o0000ojK1kOnV`Nd00_nV`Nd00ol0003oY/7]o`000002ojK1k@03o`000?nV`Ngo000000?o
Y/7]0_l00002ojK1k@;o00000onV`Nd2o`0000?oY/7]2?l00002od/0B@;o000000CoJ29Ro`000?l0
003o00000_mk>W@00ol0003oQT=fo`000004o`0000;oU5N500?o0000oi]MQOnKGHD02?l000001On[
LY;o0000ojecTon]Li?o000000;o/WNB00Ko0000ok=iToncNI?o0000okQlT_l00002okUnT`[o0000
0_o7PHD00ol0003oah65olN1Q@03o`0000;od81f00?o0000om60Lol000000_l000001?oJP6;o0000
o`000?oLMdT2o`000003om][:Ol0003odeX100;o000000?oY/;]o`000?nV`^d00onV`^d01ol0003o
Y/;]ojK2kOl0003oY/;]o`000?nV`^d00_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003
ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00002
ojK2k@03o`000?nV`^goY/;]00;oY/;]00Co0000ojK2kOnV`^go00000_nV`^d2o`0000?oY/;]0_l0
0003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l0
0003ojK2k@;o00000onV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l000001?nV`^go
0000o`000?l00002ojK2k@?o00000_nV`^d3o`0000;oY/;]0ol00002ojK2k@03o`000?oonf[ooo]Z
00Kooo]Z00?o0000oookJ_oonfX0>ooonfX00ol0003ooo]ZoookJP0coookJP04o`000?nV`^go0000
o`0000?oY/;]0_l00004ojK2k@;o00001?nV`^d2o`0000CoY/;]0_l00004ojK2k@;o00001?nV`^d2
o`0000CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@07o`000?o^_Z3o
0000o`000?oX_J[o0000onBk[003o`0000;ogkF/0_l000000ooK/joo0000omV`[`02o`0000;oe:jb
1Ol000001_oMb<Co0000o`000?l0003ohl2do`0000;og[^d00?o0000omZf]?l000001?l00003om6[
/P03o`000?o3Vjoo`i^_00Co00000_o3V:/01_l0003o_9>/okbC[?l0003o]hn]o`0000?o/h^[00Co
0000ojV4[OnYQ:go00000onZQJd00ol0003oWgj_o`000005o`0000?oTG>^00?o0000ohI^/?n6LK@0
0_n6LK@01Ol0003oOFbeoge/]OmiL;co000000?oMVjl0ol00002ofY/`P;oKg_?0_mRLL`2o`000003
ofn7f_mQO]So000000Co00000_miV^H00ol0003oU;C]o`000002o`000003oiS<nOl0003o000000?o
g>3I0_l000000oo`mkSo0000ojK2k@03o`0000?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003o
Y/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00;o000000?oY/;]o`000?nV`^d00ol000000onV`^go
0000ojK2k@03o`0007gooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0LoookJP00
6?oonfX00ol0003ooo]ZoookJP0@oookJP?o0000DOoonfX2o`000007ojK1kOl0003oY/7]ojK1kOl0
003oY/7]o`000002ojK1k@?o000000CoY/7]o`000?l0003o00000_nV`Nd3o`0000?oY/7]0_l00003
ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003
ojK1k@03o`000?nV`NgoY/7]00;oY/7]00Co0000ojK1kOnV`Ngo00000_nV`Nd2o`0000?oY/7]0_l0
0002ojK1k@;o00000onV`Nd5o`000003ocT0@_l0003o000000Co000000?oL35ao`000?mk>W@01?l0
0002oha@Q003o`000?nDEhGoU5N500Go00000_nNJ9800ol0003oZW6CojYaT`02ojYaT`;o00001?n]
Li<2o`0000?o/gVC0_l00004okUnT`05o`000?o5Qi7oaHNAolF7TOl000000_o0Q988o`000003olf6
Q?l0003o000000So000000CogH5No`000?l0003ogWM31_l000000onV`^go0000o`000003ojK2k@03
o`000?nV`^goY/;]00;oY/;]00Co0000ojK2kOnV`^go00000_nV`^d2o`0000?oY/;]0_l00003ojK2
k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000;oY/;]0ol00002ojK2
k@;o00000onV`^d2o`0000?oY/;]00Oo0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00;o00000_nV
`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV
`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]00;oY/;]00?o0000ojK2kOl000000_nV
`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000_ooo]Z00?o0000oookJ_oonfX0>ooo
nfX00ol0003ooo]ZoookJP0doookJP03o`000?nV`^goY/;]00;o00000_nV`^d01ol0003oY/;]o`00
0?l0003oY/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`0000;oY/;]0ol00003ojK2k@?o
00000onV`^d3o`0000?oY/;]0ol00003ojK2k@?o000000CoY/;]o`000?o^_Z3ok[jP0ol00002onBk
[003o`000?oR]jWo000000;ogkF/00?o0000omfbZol000000ol00003omB^/P04o`000?oCZjoodj^_
o`0000?ogLS400Ko0000on?0]Ol0003o0000omjk]?l00002omZf]004o`000?oD/;Goe;2eo`0000?o
dJ^b00?o0000ol>K[oo3Vjl00_o3Vjl00ol0003o`ib`ol>L/00Fo`0000;oWWf^00?o0000oi5c[_nA
Ljh02?l000001OmmK;Go0000ogU`_?miL;co000000;oMVjl00CoKg?6o`000?mWK/KoIfk60_l00003
ofmkc`?o000000CoKhOJo`000?mDOMgo00000on5XNH3o`0000GoV<ci0_l000000ooLh=Wo0000o`00
0003o`0000;oY/;]0ol00003ojK2k@?o00000onV`^d3o`0000?oY/;]00?o0000ojK2kOnV`^d00onV
`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?oonf[ooo]Z07oooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP0LoookJP006?oonfX00ol0003ooo]ZoookJP0=oookJP?o0000E_oonfX0
0ol0003oY/7]ojK1k@03o`000004ojK1kOl0003o0000ojK1k@?o00000_nV`Nd3o`0000?oY/7]0_l0
0002ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l0
0003ojK1k@;o00000onV`Nd2o`0000?oY/7]00Oo0000ojK1kOnV`Ngo0000ojK1kOl0003oY/7]00;o
00000_nV`Nd2o`0000?oY/7]1_l000000ola03_o0000o`000004o`000003og0aLOl0003o000000;o
00000_n2BH800ol0003oS524o`000004o`0000;oV6BB00Co0000oiiXT_nNJ9;oWVRB8?l00002olR;
TP03o`000?o8Ri?ob8^C00?o00000_oARH<00ol0003odXZ3om::P`02o`0000;og8Ya0_l000001_oO
PU_o0000o`000?oPMcco0000om]W50?o000000?oY/;]o`000?l000000onV`^d2o`0000?oY/;]00Oo
0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00;o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o
00000onV`^d2o`0000?oY/;]0_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o
00000onV`^d00ol0003oY/;]ojK2k@02ojK2k@04o`000?nV`^goY/;]o`0000;oY/;]0_l00003ojK2
k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00002ojK2
k@?o00000_nV`^d3o`0000;oY/;]00Oo0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00;o00000_nV
`^d2o`0000?oY/;]0_l0000?oookJP03o`000?oonf[ooo]Z03_ooo]Z00?o0000oookJ_oonfX0=_oo
nfX00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00;oY/;]00?o0000ojK2kOnV`^d00onV
`^d00ol0003oY/;]ojK2k@02o`0000;oY/;]00Co0000ojK2kOl0003o00000_nV`^d01?l0003oY/;]
o`000?l00003ojK2k@;o00001?nV`^d2o`0000CoY/;]1Ol00002on^jX0?o00000_oR]jT3o`0000;o
gK:[00Co0000om^_ZooK[j_o00000_oD[[801?l0003odj^_om>[[ooCZjl2o`000004omg8a?l0003o
fL;2o`0000;og[^d00Co0000omZf]?oJ][Co00000ooD/;D3o`000003om6[/_l0003o`i^_00?o`i^_
00Go0000ol>L/?o3W;3o`ib`o`000003okN@[@;o00001OndT;400ol0003oZ8NaojR7/@04o`0000Co
WWf^1Ol000000onBNK?oQG:fohEb]P02ohEb]P;o00000_mjK[X3o`000004ogI^_?l0003oKg?6ofmc
aP;o00000_mdMLH01Ol0003oKg_?ofmkcol0003oFW3?00;oO93K1?l000000on5XNKo0000o`000005
o`0000;oXmKj1?l000000ooUmMCo0000o`000002o`0000;oY/;]0ol00003ojK2k@?o00000onV`^d3
o`0000?oY/;]0ol00003ojK2k@?o0000Q?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[o
oo]Z01cooo]Z000HoookJP03o`000?oonf[ooo]Z00[ooo]Z0ol0001JoookJP;o000000GoY/7]o`00
0?l0003o0000ojK1k@02o`000003ojK1kOl0003oY/7]00;o00000_nV`Nd2o`0000?oY/7]0_l00003
ojK1k@;o00000onV`Nd2o`0000;oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003
ojK1k@;o00000onV`Nd2o`0000?oY/7]00?o0000ojK1kOnV`Nd00_nV`Nd01?l0003oY/7]ojK1kOl0
0002ojK1k@;o00000onV`Nd6o`000005od41Dol0003o0000o`000?mS9fh00_l000001?mh@H7o0000
oh99P_n2BH84o`0000;oTEjB00?o0000oiQTT_nHI9801_l000000onTMj7o0000ojQlXP03ojQlXP;o
00001?ndQJ<2o`0000Co]HNT00Co0000ol6?XOo1Sj7o`HnQ0_l00003ol6>X003o`000?o1T:?o`I2S
00Ko000000Cob8^Co`000?oDU8ooe9B?1_l000001OoJTH7o0000o`000?l0003ogX]_00;o000000?o
hH9Fo`000?l000001?l00002ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV
`^d01?l0003oY/;]ojK2kOl00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o0000
0_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o0000
0onV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l00002ojK2k@;o00000onV`^d2o`00
00?oY/;]0_l00002ojK2k@?o00000_nV`^d3o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`00
00?oY/;]00?o0000ojK2kOnV`^d00_nV`^d01?l0003oY/;]ojK2kOl00002ojK2k@;o00004ooonfX0
0ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z03Oooo]Z0ol00003ojK2k@;o00001?nV`^d2
o`0000CoY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^go
Y/;]00;o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`000005ojK2kOl0003o
Y/;]o`000?o`^YP00_l000000oo[^Z3o0000o`000003o`0000;oh;>X0ol00003om^_Z`Go000000Co
dj^_o`000?oObL;oglW20_l000001?oI`/;o0000omjk]?oN^k@2o`000004omZf]?l0003oe;2eomB`
]@;o00000_oAZk88o`000003ol>L/?l0003o]i2]00?o]i2]00?o0000okB@/OndT;400ondT;44o`00
00?oZ8Na00?o0000oiim[_l000001?l00005oi9i/`05ohEb]_l0003o0000ohYd]Ol000001OmjK[X3
o`000003ofmca_l0003oM7G600?oM7G61?l000000omJL<ooO93Ko`000002ofZ4fP;o00000_nAZNH0
0ol0003oOJO^o`000002oj?FnP05o`000?nSe_[o0000o`000?o<nNP01?l000001_nV`^go0000o`00
0?nV`^go0000ojK2k@?o000000?oY/;]o`000?nV`^d00ol000000onV`^go0000ojK2k@03o`0000;o
Y/;]0ol0002:oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX07?oonfX001Sooo]Z
00?o0000oookJ_oonfX01ooonfX3o`0005kooo]Z0_l000001?nV`Ngo0000o`000?l00002ojK1k@?o
00000_nV`Nd00ol0003oY/7]ojK1k@02o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?o
Y/7]0_l00003ojK1k@;o00000_nV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?o
Y/7]0_l00003ojK1k@07o`000?nV`NgoY/7]o`000?nV`Ngo0000ojK1k@02o`000003ojK1kOl0003o
000000?o000000Go@@5Co`000?l0003o0000of<WKP02o`000003ogQ1POl0003o000000;o00000_n8
F9400ol0003oTEjBo`000004o`0000;oW76P00?o0000oj9dWol000000_nTMj400ol0003oZ7bRojQl
XP0Eo`000003ol6>X?l0003o`I2S00;o`I2S00Co0000olfHW_o=V9ko00000_o9Uj83o`000004omBD
Sol0003odI>Bo`0000;odYBB0ol000001OoLTh3o0000o`000?l0003oh8a/00So00000_nV`^d2o`00
00?oY/;]0_l00003ojK2k@;o00000onV`^d01ol0003oY/;]ojK2kOl0003oY/;]o`000?nV`^d00_l0
0002ojK2k@;o00000onV`^d2o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l0
0003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]00;oY/;]00Co
0000ojK2kOnV`^go00000_nV`^d2o`0000;oY/;]0ol00002ojK2k@;o00000onV`^d2o`0000?oY/;]
0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d01?l0003oY/;]
ojK2kOl0000FoookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0>_oonfX2o`0000Co
Y/;]0_l00003ojK2k@?o00000onV`^d3o`0000?oY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00?o
Y/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@;o000000Kol;ZHo`000?o]
]iSo0000onRgXOl00002onBcXP;o000000?oh;>Xo`000?oN/:P01?l000000ooH[:_o0000o`000002
om>Y[@;o00000_oObL800ol0003ogLC1o`000003o`0000;of[Vg0ol000001_oD/;Go0000olVX]ol0
003odJ^bo`0000?ocJRd00?o0000oknJ/OnoV[401?l00002okN@[@;o00000ondT;44o`0000;oZ8Na
1_l00003oin2/`03o`000?nBNK?oTWVc00;oTWVc0_l00004ohYd]@05o`000?mjK[[oNVjjogY^^_n2
LkT00omcL<43o`0000?oM7G600Co0000ogR3d_mhPm;oN8?B0_l000001OmZQ=[o0000o`000?mZQ=[o
000000?oTJWV1?l00002ok7Bl@06o`000?o<nNSo0000omWUg_l0003ogOfl0_l00004ojK2k@03o`00
0?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@02o`0008oooo]Z
00?o0000oookJ_oonfX06ooonfX00ol0003ooo]ZoookJP0LoookJP006?oonfX00ol0003ooo]Zoook
JP04oookJP?o0000H_oonfX2o`0000;oY/7]0ol00003ojK1k@07o`000?nV`NgoY/7]o`000?nV`Ngo
0000ojK1k@02o`0000;oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o
00000onV`Nd2o`0000;oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@03
o`000?nV`NgoY/7]00;oY/7]00?o0000ojK1kOnV`Nd01?l000001?lZ04Wo0000o`000?mA5fP3o`00
0005ofXfOOl0003o0000ogm@T?l000000on8F943o`0000;oUVbP00?o0000oiaaX?nLLJ000_nLLJ02
o`000003ojAgXOl0003o000000Co00000_nbTkL01?l0003o/8b`ok2</?n`S;02o`0000?o_9B^00?o
0000okJB/Ol000000_nkU:l00ol0003o_9bhokbL^009o`0000?obINR0_l000000oo?VYoo0000o`00
0002o`0000;odYBB00?o0000omZJSol000000_l000000ooNUGoo0000o`000008o`0000?oY/;]0_l0
0003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOnV`^d00_nV`^d01?l0003oY/;]ojK2
kOl00002ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]
0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d01Ol0003oY/;]
ojK2kOl0003oY/;]00?o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?o
Y/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?oonf[ooo]Z01Oo
oo]Z00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0joookJP03o`000?nV`^go000000;o
000000?oY/;]o`000?nV`^d00_l00003ojK2k@;o00001?nV`^d2o`0000CoY/;]0_l00004ojK2k@;o
00001?nV`^d2o`0000CoY/;]0_l00003ojK2k@;o00000_o]]iP4o`000004onBcX_l0003ohK6Uo`00
00;og[2X00?o0000omb]YooL[JL00_l000001?oH[:_o0000om>Y[OoCZJd2o`000006omo9`_l0003o
gLC1omg4`Ol0003ofL300_l00002omZi]`03o`000?oG];KoekBf00?o000000?obJRgo`000?o=Z;@0
0_o=Z;@01Ol0003o_iZaoknJ/OnoV[7o000000?o_i^c3ol000000on[SKGo0000oin2/`05oin2/`Co
000000?oTgVco`000?n:M;D00on:M;D00ol0003oNVjjogY^^P02oh9c^@?oLg3100?o0000ogef`Ol0
00000_maN</2o`0000CoN8?B00Co0000oh>Gg_n3UmkoPiON1?l000002_n@[>Wo0000oi2/jOn@[>Wo
0000ok7BlOl0003oc?WXo`000?oIiMh2o`000003onch[OnV`^goY/;]00;o00001?nV`^d2o`0000Co
Y/;]0_l00004ojK2k@03o`000?oonf[ooo]Z093ooo]Z00?o0000oookJ_oonfX06ooonfX00ol0003o
oo]ZoookJP0KoookJP005ooonfX00ol0003ooo]ZoookJP02oookJP?o0000IooonfX2o`0000?oY/7]
0_l00002ojK1k@03o`000?nV`NgoY/7]00;oY/7]00Co0000ojK1kOnV`Ngo00000_nV`Nd2o`0000?o
Y/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?o
Y/7]0_l00002ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@?o000000Co000To`000?l0
003o00000_mA5fP2o`000003ofXfOOl0003o000000CoOe2@0ol000000on?Ij3o0000oiI/X003oiI/
X003o`000?nLLJ3o000000Co00000_nZR;400ol0003oZXJ^o`000003ok:C]`04o`000?n`S;3o/8b`
o`0000;o/Hja00?o0000okbD[_l000000onfT[42o`0000?o_9bh00?o0000olRQ/Oo8XK400_o8XK40
0ol0003o`:6jo`000008o`0000;odIjQ1?l000000ooJVXoo0000ombMT003o`000003on6GO_l0003o
000000Oo00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00Go0000
ojK2kOnV`^go0000ojK2k@03o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l0
0003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000;oY/;]00?o
0000ojK2kOnV`^d00_nV`^d01?l0003oY/;]ojK2kOl00002ojK2k@;o00000onV`^d2o`0000?oY/;]
0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000_nV`^d3o`0001cooo]Z
00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP0koookJP03o`000?nV`^goY/;]00?oY/;]
00?o0000ojK2kOnV`^d00_l000000onV`^go0000ojK2k@03o`000003ojK2kOl0003oY/;]00?o0000
00?oY/;]o`000?nV`^d00ol00002ojK2k@?o00000onV`^d3o`0000?oY/;]1?l000001?ob]Xgo0000
o`000?l00002on^dV@?o00000_oQ/JD3o`0000?og:fW00Go0000omZ[Y_l0003o0000om>Y[@02o`00
0005on38`Ol0003o0000omg4`Ol000000_oI`<001?l0003odKS1o`000?l00003omNd]P03o`000?oA
[kOodJng00?o000000?ocJRdo`000?noV[400onoV[401?l0003o_i^coknK/onoVk<3o`000003okFA
/Ol0003o000000Co/Y:e00?o0000ojR7/Ol000001?n[SKD00ol0003oWh:coin2/`04o`0000;oTgVc
2?l000001omjK[[o0000o`000?l0003oPW>iog=``Ol000000_mmM/401Ol0003oLGS;og5hbol0003o
L7O:00Ko00001?n3Umh01?l0003oT:cYo`000?n@[>T4o`000003ok_Hkol0003ofNGN00;o000000?o
k?R]o`000?l000000_nV`^d3o`0000?oY/;]0ol00003ojK2k@?o0000U_oonfX00ol0003ooo]Zoook
JP0JoookJP03o`000?oonf[ooo]Z01_ooo]Z000GoookJP03o`000?oonf[o000000;o0000JooonfX2
o`0000?oY/7]0_l00003ojK1k@;o00000_nV`Nd01?l0003oY/7]ojK1kOl00002ojK1k@03o`000?nV
`Ngo000000;oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV
`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000_nV`Nd2o`0000?oY/7]0_l00002ojK1k@Go000000Go
>PAOo`000?l0003o0000oe`[NP02o`000004ogI9S_l0003oOe2@ogm@T0?o00000on?Ij000ol0003o
UVbPoiI/X005o`000003ojF8]_nZR;7oZXRa00CoZXRa00?o0000ok:C]onbTkL04Ol00002okbL^005
o`000?o8XK7ob:6aolRQ/Ol000000_o0XKX2o`0000;ocjNa00?o0000olNV]oo7Y[L00ol000000ooA
WZ7o0000om6OX`06o`000005omjOT?l0003o0000o`000?oSV7`00_l000000oo/Uf?o0000onj>A003
o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@05o`000?nV`^go
Y/;]ojK2kOl000000_nV`^d00ol0003oY/;]ojK2k@02o`0000?oY/;]0_l00003ojK2k@;o00000onV
`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00002ojK2k@;o00000onV
`^d2o`0000?oY/;]00Co0000ojK2kOnV`^go00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o0000
0onV`^d2o`0000?oY/;]0_l00002ojK2k@?o00000_nV`^d2o`00027ooo]Z00?o0000oookJ_oonfX0
>OoonfX00ol0003ooo]ZoookJP0moookJP;o00001?nV`^d00ol0003oY/;]ojK2k@02ojK2k@03o`00
0?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@02o`0000;oY/;]
00Co0000ojK2kOl0003o00000_nV`^d01?l0003oY/;]o`000?l00003ojK2k@Co000000Wokk:>o`00
0?l0003ojkBIo`000?oX/IWo0000on6aYOl000000_oO[Z<2o`000006omb]Yol0003ofZ^VomZ[Y_l0
003oejNV0_l000001OoPb<7o0000omg4`?oMa<3o000000;ofL3000?o0000om6h`OoA^<400ol00000
0ooG];Ko0000om6_]`02om6_]`;o000000?ocJRdo`000?l000002?l00004okFA/@03o`000?nbT[Go
/Y:e00Co/Y:e00?o0000oj^=]On[SKD01_l00002oij1/`Co00000_nEOkT01?l0003oRWZko`000?l0
0002ohil^P04o`000?n1MkooPGNooh5g_`;o00001?mmM/42o`0000;oL7O:1?n3SMD00ol0003oLhCE
o`000007o`0000CoTl[j0ol000001?oGn]oo0000o`000?nV`^d2o`000003ojK2kOl0003oY/;]00?o
000000?oY/;]o`000?nV`^d00ol0002JoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000oookJ_oo
nfX06ooonfX001Oooo]Z0_l0001_oookJP;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@03o`00
0?nV`NgoY/7]00;oY/7]00?o0000ojK1kOl000000onV`Nd2o`0000;oY/7]0_l00003ojK1k@;o0000
0onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o0000
0_nV`Nd2o`000003ojK1kOl0003o000000;o000000?o>PAOo`000?l000000_mL:gX2o`0000;oMTV>
0ol00002ohMQW`03o`000?n?Ij3o000000Co000000?oVWV]o`000?l000000_nUR;H3o`0000;oZXRa
1Ol00002ojfI``;o00000on/U;h2o`0000Co[iJm0_l00002okZT``So000000Go`:6jo`000?o?Yk7o
cjNao`000003olNV]`03o`000?oEZZgoeJZ]00?o000000GodInSo`000?oIXiko0000om^WW`03o`00
0003on2QT?l0003o000000Wo00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`00
00;oY/;]0_l00003ojK2k@04o`000?nV`^goY/;]o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2
o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00002ojK2k@;o00000onV`^d2
o`0000?oY/;]0_l00003ojK2k@07o`000?nV`^goY/;]o`000?nV`^go0000ojK2k@02o`0000;oY/;]
0_l00003ojK2k@;o00000_nV`^d3o`0000;oY/;]0_l00003ojK2k@;o00009OoonfX00ol0003ooo]Z
oookJP0ioookJP03o`000?oonf[ooo]Z03kooo]Z0ol00003ojK2k@;o00001?nV`^d2o`0000CoY/;]
0_l00004ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]
ojK2k@02o`000009ojK2kOl0003o0000oo>^OOl0003okk:>o`000?o/[hoo000000;oj;6I1?l00000
0ooO[Z?o0000omf[XP04o`000005omNWY_l0003o0000omC;dOl000000ooMa<02o`000005omW0`?l0
003odKS1om6h`Ol000000_oG];H3o`000005om6_]ol0003oaZFiolJU^Ol000000oo8Y[LEo`0000?o
Z8Zf00?o0000oij1/ol000000_l000000onPQkWo0000oiEo^@03oiEo^@;o00001On>O;X3o`000003
oh1g_on4OlKoQ7o600;oQ7o600?oOGK1o`000?l000000_l000001?m`Ml[oPhgEoh>=eOl00002og>4
e@03o`000?n?XN7oSj7Q00;oSj7Q0_l000001OnCb_[o0000o`000?l0003oWmWl00Ko00001OnV`^d0
0ol0003oY/;]ojK2k@03ojK2k@03o`000?oonf[ooo]Z09cooo]Z00?o0000oookJ_oonfX06OoonfX0
0ol0003ooo]ZoookJP0KoookJP006OoonfX00ol0003ooo]ZoookJP1]oookJP;o00000onV`Nd2o`00
00?oY/7]0_l00003ojK1k@;o00000onV`Nd02?l0003oY/7]ojK1kOl0003oY/7]o`000?nV`Ngo0000
0onV`Nd2o`0000;oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o0000
0onV`Nd2o`0000?oY/7]0_l00003ojK1k@[o000000KoIcn=o`000?mfBHko0000ogiKW_l00002ohMQ
W`?o00000_nDM:d00ol0003oVWV]o`000005o`0000;oY97100?o0000ojN@_Ol000000_nUU/D00ol0
003o[IW3ojfI``02o`000008ok>]d_l0003o[9BnojbD__l0003o^;CFo`000?n_U[d3o`000004okfg
e?l0003o^ZC3o`0000Co`[K>00Co0000okfZa_nmZ/Ko_J[61ol000001_o7Y[Oo0000omFZ[OoEZZgo
0000om2/]0Co00000_oKYil00ol0003og:VQo`000002o`000004on:TT?l0003o0000onfRM`Oo0000
0onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000;oY/;]0_l00003ojK2k@07o`00
0?nV`^goY/;]o`000?nV`^go0000ojK2k@02o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`00
00?oY/;]0_l00002ojK2k@?o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`00
00?oY/;]00?o0000ojK2kOnV`^d00_nV`^d01?l0003oY/;]ojK2kOl00002ojK2k@;o00000_nV`^d2
o`0000?oY/;]0_l00003ojK2k@;o0000:OoonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[o
oo]Z043ooo]Z0_l00003ojK2k@?o00000onV`^d3o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d3
o`0000?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0003oljimo`000002o`000006onb_Sol0003o
0000o`000?oU[I[o00000_oPZid01?l0003ogJ^Romf[X_l00002om^XX@?o000000Koelc?o`000?oA
a/oo0000omg4`?l00002omZo_`;o000000KodKS1o`000?o=]<7o0000omNd]_l00002om:c^P?o0000
00?oaZFio`000?l000000ol00003okbJ]0;o00001?nlVkL00ol0003o/i:do`000003ok:A]@03o`00
0?neUkSo000000GoZ8Zf0_l00005oj27^@Co000000?oUWnho`000?n>O;X00on>O;X2o`0000?oP7No
00Co0000ohAoa_n4OlKoQ7o60_l00003ohB8c`ko00000onOfO`01ol0003o`?C`o`000?oBi^Co0000
ol?j^OnV`^d00ol00003ojK2k@?o0000X_oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[o
oo]Z01_ooo]Z000JoookJP03o`000?oonf[ooo]Z06kooo]Z0_l00002ojK1k@;o00000onV`Nd2o`00
00?oY/7]0_l00003ojK1k@03o`000?nV`NgoY/7]00;oY/7]00Co0000ojK1kOnV`Ngo00000_nV`Nd2
o`0000?oY/7]0_l00003ojK1k@;o00000_nV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2
o`0000?oY/7]0_l00002ojK2k@Go000000?oBAaeo`000?l000000_mW?hdAo`000003oj2@`ol0003o
Y97100;oY9710ol00003ojFFa@;o00001Onc[M801?n/U;ko0000okRde_nh]=H2o`0000Go_KOD00?o
0000ol:fc_o2]/h00_o2]/h01Ong[<ko0000okfZa_nmZ/Ko000000;oa[gA00Co0000ol>_aOo3[lGo
`jo51Ol00002om2/]003o`000?o@[[Ood:jg00Co000000?og:VQo`000?oN[:<02?l000000oocWEKo
0000o`000002o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000;oY/;]0_l00003ojK2k@;o
00000onV`^d00ol0003oY/;]ojK2k@02ojK2k@04o`000?nV`^goY/;]o`0000;oY/;]0_l00003ojK2
k@;o00000onV`^d2o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2
k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@05o`000?nV`^goY/;]o`000?nV`^d00_l00003
ojK2k@;o00000onV`^d2o`0000?ooo]Z00?o0000oookJ_oonfX09ooonfX00ol0003ooo]ZoookJP0i
oookJP03o`000?oonf[ooo]Z043ooo]Z00Co0000ojK2kOl0003o00000_nV`^d01?l0003oY/;]o`00
0?l00002ojK2k@04o`000?nV`^go0000o`0000?oY/;]0_l00004ojK2k@;o00001?nV`^d2o`0000Co
Y/;]0_l00002ojK2k@?o000000GolJ]no`000?l0003o0000onZ]S`03o`0000;oh:^M0ol00003om^X
X@;o00000_oGc<l2o`000005om76col0003of[noomZo_ol000000_oH_l82o`000003olfd`Ol0003o
000000;od[>j00?o0000om2_^Oo@[kT01Ol000000oo8Y[Oo0000okbJ]002okbJ]003okjL]_l0003o
_9^g00;o_9^g00Co0000ok>B]?ncT[Co00000_nbTKD01?l0003o]INhokFG^?l00003ojR:]P;o0000
00CoZHbgo`000?nPQkWoX8Ni1?l00005oiIo^003o`000?n>O;[o000000Ko000000CoP7NoohAoa_n4
OlKo00000_mjNLH01?l0003oQ8S?ohB8con4R<l2o`0000GoP97J0_nJZn<00ol0003oRjGVo`000003
o`000006ok7Flol0003o0000om;Vi?o8oN7o00001?nV`^d2o`000:Sooo]Z00?o0000oookJ_oonfX0
5ooonfX00ol0003ooo]ZoookJP0KoookJP006ooonfX2o`0006oooo]Z0_l00003ojK1k@;o00000_nV
`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd01?l0003oY/7]ojK1kOl00002ojK1k@;o0000
0onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000_nV`Nd2o`0000?oY/7]0_l00003ojK1k@;o0000
0onV`Nd5o`000003oad0E?l0003o000000Go000000CoMUVSo`000?mmG:7oOEbQ0ol00002ohig]003
o`000?nGOkSoUgnh00?o00000onPT<<4o`0000;oZJCA00Ko0000ojFFaOl0003o0000ojfdgOl00004
ok>]dP;o00000_nh]=H4o`0000;o_KOD0ol00002ol:fcP04o`000?ng[<ko]jc>okN/cP;o00000_o6
_M401Ol0003o^Jo?o`000?o3[lGo000000?obkk>1Ol000001_o@[[Oo0000o`000?oH[Zko0000omff
/0;o000000?ogZbSo`000?oO[Z@00_l000001?o/[8[o0000o`000?ocZ786o`0000?oY/;]0_l00003
ojK2k@;o00000onV`^d2o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00Co0000
ojK2kOnV`^go00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l0
0003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000;oY/;]00Co
0000ojK2kOnV`^go00000_nV`^d2o`0000?oY/;]0_l00008oookJP03o`000?oonf[ooo]Z02Kooo]Z
00?o0000oookJ_oonfX0>OoonfX00ol0003ooo]ZoookJP11oookJP03o`000?nV`^goY/;]00?oY/;]
00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@02o`000003ojK2kOl0003oY/;]00?o0000
00?oY/;]o`000?nV`^d00ol00002ojK2k@?o00000onV`^d2o`000003ojK2kOl0003olj5T00?o0000
00GokZR0o`000?l0003o0000onNZT003o`0000;ogZNL1Ol00002omO<c`03o`000?oEbLko000000;o
000000Gof[noo`000?oH_l;of;o2o`000002omFk`@?o000000?od[>jo`000?l000000ol00002ol:T
^P03o`000?o8Y[Oo000000Go000000Co_Ybfo`000?nlVkOo00001?ncT[@2o`0000Co]INh00Co0000
ojR:]_l0003oZHbg1Ol00003oin6^004o`000?nFOkSoUWnhoiIo^0Co00000onBPl001?l0003oQX35
ohJ0aOn6P<DEo`0000;oVK?Z1Ol000000oo8oN7o0000o`000003o`000:_ooo]Z00?o0000oookJ_oo
nfX05ooonfX00ol0003ooo]ZoookJP0KoookJP007OoonfX00ol0003ooo]ZoookJP1]oookJP;o0000
0onV`Nd2o`0000?oY/7]0_l00002ojK1k@;o00000onV`Nd2o`0000?oY/7]00Oo0000ojK1kOnV`Ngo
0000ojK1kOl0003oY/7]00;o00000_nV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000_nV`Nd2o`00
00?oY/7]0_l00003ojK1k@;o00000onV`^d7o`000003oePdRol0003o000000?oMUVS0ol000000on;
N;Wo0000ohig]002ohig]0?o00000_nKS<<01_l0003oX933oj2@`ol0003oY:CEo`0000CoZJCA1ol0
00001?nc[M;o0000o`000?nU/N42o`0000CoYK;Q0_l00002ojN`gPCo00001?ng[<h2o`000003olJm
dOl0003o^Jo?00;o^Jo?00So0000ol^nc_o;_/kobkk>okj_b_l0003oc;?1o`0000;ob[K61?l00002
omff/005o`000?oJ]kCo0000o`000?oO[Z@03Ol00003ojK2k@;o00000onV`^d2o`0000;oY/;]0_l0
0003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@04o`000?nV`^goY/;]o`0000;oY/;]
0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]
0_l00003ojK2k@;o00000onV`^d2o`0000;oY/;]0_l00003ojK2k@07o`000?nV`^goY/;]o`000?nV
`^go0000ojK2k@02o`0000cooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0goook
JP03o`000?oonf[ooo]Z04Cooo]Z0_l00003ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@03ojK2
k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00_l00002ojK2k@07o`000?nV`^go0000
o`000?nV`^go0000ojK2k@04o`000007oo2OIol0003okZR0o`000?o[YX;o0000onNZT00:o`000004
omO<col0003oeLW>o`0000?odlK>0_l000000ooH_l;o0000omFk`@02omFk`@Ko000000?od:nio`00
0?o2Y;X00oo2Y;X01Ol0003oaJJjolFV^_o5Y[[o000000;o^YZg4_l00002ojN>^`03o`000?nOQ[So
WhJh00?oWhJh1?l000000onHQ[ko0000o`000004oi:3`007o`000?n6P<GoQX35ohJ0aOl0003oQh34
o`000004ohZ8b`03o`000?n3SMGo000000;oPXcD00?o0000oiBQg_nDXMh00onDXMh00ol0003oVK?Z
oiVcjP02o`0000;oW=Wm0_l000001?o8oN7o0000o`000?l0002_oookJP03o`000?oonf[ooo]Z01Ko
oo]Z00?o0000oookJ_oonfX06ooonfX001kooo]Z00?o0000oookJ_oonfX0KOoonfX2o`0000?oY/7]
0_l00003ojK1k@;o00000onV`Nd2o`0000;oY/7]0_l00003ojK1k@03o`000?nV`NgoY/7]00;oY/7]
00Co0000ojK1kOnV`Ngo00000_nV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000;o
Y/7]0_l00003ojK2k@;o00000_nV`^d2o`000003o`00@ol0003o<@U^00Go00000_mfFJ<2o`0000Co
RgRi0ol000001?nDQL7o0000oi^<`onKS<<3o`0000?oY:CE0_l00002ojVTd@03o`000?nT]>Co0000
00?oZ;GR0_nP_>d01ol0003oYK7Qo`000?l0003oW;oao`000?nU/^401ol000000onL^Ngo0000o`00
0002o`0000;oY;CT1?l00002okV_c`?o000000?obkk>o`000?nn[lX00_nn[lX01Ol0003ob[K6olZf
a_o:]/Ko000000;od<?=0ol00002omZg]006o`000?oK^KOo0000on2bY_l0003ok;JI0_l000000oob
/hSo0000o`000006o`0000?oY/;]0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00003ojK2
k@;o00000onV`^d2o`0000?oY/;]00Oo0000ojK2kOnV`^go0000ojK2kOl0003oY/;]00;o000000?o
Y/;]o`000?l000000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l0
0003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]00;oY/;]00?o
0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o
0000oookJ_oonfX0AOoonfX2o`0000CoY/;]0_l00004ojK2k@;o00001?nV`^d2o`0000CoY/;]00?o
0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@02ojK2k@06o`000?nV`^go0000onb:>ol0003o
l9mW0_l00002on^VPPGo00000_oOXY<02?l0003oa/cNolK<g_l0003of<_=o`000?oEbLko00000ooC
a/h00ol0003obkk>o`000002o`000004omFk`Ol0003o0000o`0000;obK7200?o0000om2_^Oo@[kT0
0ol00002ol:T^P;o00000_o5Y[X00ol0003o^YZgokZJ]`02okZJ]`03o`000?niW;_o^Ibk00;o^Ibk
00?o0000okJG]on`U;T01?n`U;T00ol0003o/9:ho`000005ojN>^`03o`000?nOQ[So000000Ko0000
0_nHQKh00ol0003oTX?0oi:3`003oi:3`003o`000?n6P<GoQh3400?oQh3400Co0000ohZ8bon:R<_o
RXS;0_l00004oh:<e003o`000?nDXMkoU:7N00Co00001?nLfOd01Ol0003o^OO`o`000?l0003oWnRL
0;;ooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0KoookJP007ooonfX2o`0006ko
oo]Z0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000_nV`Nd2o`0000?o
Y/7]00Co0000ojK1kOnV`Ngo00000_nV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`00
00?oY/;]0_l00002ojK2k@;o000000?oY/;]o`000?l000001Ol00003ofI;WPCo00000on;N;T2o`00
0003oiB5`Ol0003o000000?o00000_nOWm@00ol0003oY:CEojBTe@04o`0000;oY;CT0ol00003oj2l
k@?o00000_nL_o46o`0000?oI/gk0_l00004og7=oP;o00000on<c_h2o`0000?oY[GT0_l00002okj_
bP06o`000?nj]]Go^[KEo`000?o:]/Ko00000_o@`ld2olO4e`;o000000Cof[Ndo`000?oK^KOofkVg
0ol000001?o/]YWo0000o`000?ob/hP6o`000003ojK2kOl0003o000000?oY/;]0_l00002ojK2k@;o
00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOnV
`^d00_nV`^d00ol0003oY/;]o`000002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o
00000onV`^d2o`0000?oY/;]0_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o
00004_oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oo
nfX0A_oonfX3o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d3o`0000?oY/;]0ol00003ojK2k@;o
00001?nV`^d8o`0000;ojJ>30ol000000ooOXY?o0000olK<gP02olK<gP;o000000?oe/S=o`000?oC
a/h00_oCa/h00ol0003obkk>ol^ncP04o`000003omFk`Ol0003obK7200;obK7200CoaJo4o`000?o@
[kWo00000_o;/;l6o`0000Go^YZg00Go0000okVL^oniW;_o^Ibko`000002okJG]`Co/9Bi00Co0000
ok2B^?n`T[So00001?nWS[/3o`000005oj6=__l0003o0000oj6<__l000001OnHQKh00ol0003oTX?0
o`00000Fo`0000;oTZSU00Go0000oicIoOl0003o0000ojoHm@02o`000003okSmeol0003ooo]Z0;?o
oo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0JoookJP008OoonfX00ol0003ooo]Z
oookJP1]oookJP;o00000_nV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]
0_l00002ojK1k@04o`000?nV`NgoY/7]o`0000;oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?o
Y/7]0_l00003ojK2k@;o00000onV`^d5o`000003od@VQ_l0003o000000;oIT^N00Co0000ogi^]_mn
K[KoOVjf1ol00002oifRf004o`000?nOWmCoWioDoinOe0Co00000_nS^^T4o`000003oig7mOl0003o
000000?o00000on7eOl2o`0000?oL=7m00?o0000odo:j?l000003?l00002of?6o@03o`000?nV]NCo
000000;o000000CoV[W^okW2hOni`^7o00001?nj]]D00ol0003od<?=o`000002olO4e`;o000000So
eKc1o`000?l0003ofkVgo`000?oL_;Wo0000ombo^`[o00000_nV`^d2o`0000?oY/;]0_l00002ojK2
k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00002ojK2
k@04o`000?nV`^goY/;]o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003
ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0001Oooo]Z00?o0000
oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z04Oooo]Z00Co0000
ojK2kOl0003o00000_nV`^d01?l0003oY/;]o`000?l00003ojK2k@;o00001?nV`^d2o`0000?oY/;]
0ol00003ojK2k@?o00000onV`^d:o`000003onFOQOl0003o000000;oa/cN0_l00002olC8g@04o`00
0?oDa/co0000om?6cPCo000000?oak_>o`000?oE^l000ol00002olVa`P?oaJo400Go0000ol^`_oo;
/;oobk2oo`000003oknS_@?o00000onjV[L2okbM^@03o`000?niW;_o000000Co]YNg0_n`U;T5ok2B
^0Oo00001OnQS;h00ol0003oV8FnoiR5_P05o`0000?oTXW71OnASL/00ol0003oRHkBo`000002ohR>
dP03o`000?nCWM[oTigJ00CoTigJ00?o0000oi:XiOnBZ>D00ol00002ojoHm@;o000000?o^?gGo`00
0?oonfX0]OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01[ooo]Z000RoookJP03
o`000?oonf[ooo]Z06gooo]Z0_l00003ojK1k@;o00000_nV`Nd2o`0000?oY/7]0_l00003ojK1k@;o
00000onV`Nd2o`0000?oY/7]00?o0000ojK1kOl000000onV`Nd2o`0000;oY/7]0_l00003ojK1k@;o
00000onV`^d2o`0000?oY/;]0_l00002ojK2k@So000000?oIT^No`000?mgJ;H00omnK[H00on6OL;o
0000oi2:b@02oi2:b@04o`000?nMX]SoWJ;HoifRf0Co00000_nS_>/4o`000003oig>nOl0003o0000
00;o000000?oQ=_noh;Jo_n2f_h01?l00002oaBT^@co000000CoWgBRo`000?l0003o00000_l3ULD3
o`000003of?6oOl0003o000000Go00000_na`nL6o`000005olO4eol0003o`kW@ol>id?l000000_oD
_lD3o`0000;og;nk00Go0000onRnZol0003o0000oo6oW006o`0000;oY/;]0_l00003ojK2k@;o0000
0_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o0000
0_nV`^d01?l0003oY/;]ojK2kOl00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o
00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0001cooo]Z00?o0000oookJ_oo
nfX08ooonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000ojK2kOnV
`^d00onV`^d00ol0003oY/;]ojK2k@02o`000003ojK2kOl0003oY/;]00?o000000?oY/;]o`000?nV
`^d00_l00002ojK2k@04o`000?nV`^go0000o`0000?oY/;]0_l00003ojK2k@?o000000?ojXQ6o`00
0?l000000_oYVG04o`000003olK<g_l0003oa<SM00;oa<SM00?o0000ol75gOl000000ol000000oo;
_/ko0000olNkcP02olNkcP04o`000?oA]l7odKO1om6g`@?o000000?oaJo4o`000?l000000_o;/;l0
0ol0003o_j>moknS_@02oknS_@03o`000?o2X[So`Z:h00co000000?o/9Bio`000?l000001_l00004
ojNB`003o`000?nQS;koXHbn00;oXHbn1?l000001?nJSLGo0000o`000?l00004oi:9a`04o`000?nA
SL_oTHg;oi6=b`?o00001?n8S]800ol0003oTigJoi>MfP06o`0000CoU/gk1?l0002goookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX06_oonfX002?ooo]Z0_l0001^oookJP;o00000onV
`Nd2o`0000?oY/7]0_l00002ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@04o`000?nV
`NgoY/7]o`0000;oY/7]0_l00003ojK1k@;o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o0000
00KoY/;]o`000?l0003o0000ob`FP_l00002oe]:Y0?o000000?oMfRfogi^]_n6OL800on6OL800ol0
003oT8[9o`000005o`000003oinbiOl0003oXkc[00;o000000?oX=;io`000?l000000_l00003ohSN
o@Go00000_oEXZ44o`0000?o`XjN0_l00002ok21XP04o`000?n^OZ7o0000oimdXPCo00000_n=IZ40
1?l0003oLEBQo`000?lSZ]h6o`000003ogO:ool0003o000000?o000000KoWK_]ol35g_o0aMko0000
ol>id?l00002oknmf00<o`000?oD_lGo0000om?2bOl0003og;nko`000?oL_[_o0000onW2[Ol0003o
lKnL1_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?o
Y/;]0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]00Co0000ojK2kOnV`^go00000_nV`^d2o`00
00?oY/;]0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`00
027ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0goookJP03o`000?oonf[ooo]Z
04Wooo]Z0ol00003ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o0000ojK2kOnV`^d00onV`^d00ol0
003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00;o000000?oY/;]o`000?nV`^d00ol000000onV
`^go0000o`Ugh@02o`000008onR8C?l0003o0000o`000?nSaO7o0000olW=gOl00003olC8g@Go0000
0_oA`l`3o`000006olNkc_l0003o`kS@o`000?oA]l7o00000oo<//45o`0000Co_j>m0_nlXl400ol0
003o`Z:ho`000004okjW`P;o00001?ngW[l00on`V;ko0000ok2B^005ok2B^003o`000?nWT/3oYi;0
00CoYi;000Go0000oj6<__l0003o0000oj:Ca004o`0000;oVXc400?o0000oi:9aonBRLL00onBRLL0
0ol0003oTHg;o`00000:o`000006oi:Uh_l0003oTZCRoi:Th_l0003oU/gk1?l00002olK[k[[ooo]Z
00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0JoookJP009OoonfX00ol0003ooo]Zoook
JP1/oookJP;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000_nV`Nd2o`0000?oY/7]0_l0
0003ojK1k@04o`000?nV`NgoY/7]o`0000;oY/7]0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]
0_l00003ojK2k@Oo000000?oFdZTo`000?l000000_mfJKP8o`000004oiNQfol0003o0000o`0000;o
Wk;U0ol000001?nPd_Wo0000o`000?nBhOh2oiGQoPWo00000_oEXZ400ol0003oaIBSo`00000<o`00
00;oWG>R00Co0000oheVXOn=IZ7oSFJQ0_l00002ogaLX`;o00000_lh0005o`0000?oWK_]0ol00000
0onkan?o0000oknmf003oknmf004o`000?oC`/Wo0000om;4c@;o000000?og;jko`000?oY`Zd00_l0
00000ooc`ico0000o`000004o`0000?oY/;]0_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l0
0003ojK2k@;o00000onV`^d2o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d01?l0003oY/;]ojK2
kOl00002ojK2k@;o00000onV`^d2o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]
0_l0000UoookJP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]Z
oookJP1;oookJP;o00001?nV`^d2o`0000CoY/;]0_l00003ojK2k@?o00000onV`^d00ol0003oY/;]
ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]1?l00005oj?5l@03o`000?o8c=co000000;o0000
00?o`LGMo`000?l000000_nn`mh00ol0003odL?<o`000002oljoc0;o000000?o`kS@o`000?l00000
0oo<//401?l0003obKW;olViboo9^L/7o`0000;o_:?100?o0000okjW`_nnYl800onnYl800onjWkko
0000okNN_`02okNN_`?o/9Rn00?o0000ok2B^?n`T[P00_l000000onbWL?o0000ojNB`003ojNB`0?o
000000KoXY?4o`000?l0003o0000oj:Ba?l00004oiZ<a0Oo00001?nATm800ol0003oUigHoiNMf003
oiNMf004o`000?nBYN;o0000oi:ThPCo00000_nMhOd00ol0003oa^_^o`00002loookJP03o`000?oo
nf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX06_oonfX002Kooo]Z0_l0001]oookJP;o00000onV`Nd2
o`0000?oY/7]0_l00003ojK1k@;o00000_nV`Nd2o`0000?oY/7]0_l00003ojK1k@04o`000?nV`Ngo
Y/7]o`0000;oY/7]0_l00003ojK2k@;o00000onV`^d2o`0000;oY/;]0_l00003ojK2k@;o000000Co
1`1fo`000?m3>9ko@cRN1Ol00002ogmka@04o`000?nGX]coUj;LoiNRg0?o000000?oVjSOo`000?l0
00000_l000001?nSd?Oo0000o`000?l00002oiGQoP;o000000WoD/k7o`000?o`bZ[o0000onVoZ_l0
003ogkB[o`000?oO[Z<01?l000000oo5U:?o0000ol>CY002ol>CY005o`000?njR:3o0000ok21X_l0
00000_n^OZ400ol0003oWG>RoiecXP02oiecXP?o000000WoSFRSo`000?mlG:?oO5bSo`000?mMC:Go
0000odi8Zolm?JL00_l000000ol_Znko0000o`000002o`0000?oRLWm00?o0000okK7iol000000_l0
0002ok[0g`09o`000?oBa<god/C=o`000?oFc=3o0000omg4_ol0003ojlJ^00;o000000?om/JKo`00
0?l000001?l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`00
00?oY/;]0_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]00Co0000ojK2kOnV`^go00000_nV`^d2
o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l0000ZoookJP03o`000?oonf[o
oo]Z027ooo]Z00?o0000oookJ_oonfX0=ooonfX00ol0003ooo]ZoookJP1<oookJP?o00000onV`^d3
o`0000?oY/;]0_l00004ojK2k@;o00001?nV`^d2o`0000CoY/;]0_l00003ojK2k@Ko000000?oX/Ca
o`000?l000000ol000000oo1aMgo0000okk3gP03okk3gP;o00000_o>_l`00ol0003obK_=olVkc@02
o`000004oknfd_l0003oc;;1o`0000?obKW;0_nn[LP00ol0003obJfno`000003ol:W_PGo00000_nn
Yl83okZO_P03o`000?ngW[oo/9Rn00?o/9Rn00?o0000ok2B^?l000001?nbWL<2o`000003ojNB`?l0
003o000000?o00001?nRT/@00ol0003oVXc4o`000002o`000003oibDbol0003oUY;>00;oUY;>00?o
UY;=o`000?nATm801?nATm801_l0003oUigHoiNMf?nGWMSo0000oiNMf0?o00001?nGa_P5o`000;go
oo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0JoookJP00:?oonfX00ol0003ooo]Z
oookJP1[oookJP;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000;oY/7]
0_l00003ojK1k@04o`000?nV`NgoY/7]o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000;o
Y/;]0_l00002ojK2k@;o000000?o1`1fo`000?m3>9h00_l00002ofYS^003o`000?moNlGoOg_500;o
Og_51ol000000onTbO?o0000o`000002o`000005oj?No?l0003o0000o`000?n5j^D01_l000002OoY
_j[o0000o`000?l0003ogjjSo`000?oHYJ;o0000oljLX`05o`0000;o^XRP0_l00003ojinX@03o`00
0?nMLj;oWG>R00So000000?oN5jXo`000?mMC:D00_l000000olm?JOo0000oa4/ZP08o`000004ogVo
oOl0003o/LOZok77jP;o000000Co]<?Uo`000?oBa<go00000_oFc=000ooCcM?o0000o`000003o`00
0003ooK6Vol0003o000000Go00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`00
00?oY/;]0_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@04o`000?nV`^goY/;]
o`0000;oY/;]0_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l0000_oookJP03o`000?oonf[o
oo]Z027ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1=oookJP04o`000?nV`^go
0000o`0000;oY/;]00Co0000ojK2kOl0003o00000_nV`^d3o`0000?oY/;]0ol00003ojK2k@?o0000
0onV`^d2o`0000CoY/;]1_l00003oj32l@?o000000So_/?No`000?l0003o0000ok[0gol0003oc[o<
o`0000;obK_=00Co0000olBfcOo4]/goa;K=0ol00002olVib`?o_Zg80_l00003ol:W_P05o`000?o0
/Lco`;7<o`000?nnY/805?l00005ojVF``04o`000?nRT/CoXY;4oj:Ba0Co00001?nLU</2o`0000;o
UY;=3?l00002oiJVh@03o`000?nGa_So000000;o000000?oV]gmo`000?l000000_l0002noookJP03
o`000?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX06_oonfX002Wooo]Z00?o0000oookJ_oonfX0
K?oonfX2o`0000;oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00003ojK1k@;o0000
0_nV`Nd01?l0003oY/;]ojK2kOl00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@Oo
00000_mJFKL2o`000003ogEeaOl0003o000000?o000000?oUZOQo`000?l000001?l000000onUg__o
0000o`000007o`000007ooWLZOl0003o0000o`000?oZ`:Wo0000on:fZ@05o`0000;ocYbS0_l00002
ol>CY0co000000?oX7RVoheZY_n=JZH00ol000001?miGZOo0000ogQNZ?l00002ofeGZ009o`000?mC
C:co0000ocM6]Ol008co0000o`1oe_l0003o07;<00Ko000000?o[<K]o`000?l000000_l00002omK<
d003om?=dol0003odlkE00;o000000Coh<k6o`000?l0003on<ZI1?l000000onV`^go0000o`000002
ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000;oY/;]0_l00003
ojK2k@;o00000onV`^d2o`0000?oY/;]00Go0000ojK2kOnV`^go0000ojK2k@02o`0000?oY/;]0_l0
0003ojK2k@;o0000=?oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o
0000oookJ_oonfX0CooonfX00ol0003oY/;]ojK2k@03ojK2k@04o`000?nV`^goY/;]o`0000;oY/;]
00Co0000ojK2kOl0003o00000_nV`^d01?l0003oY/;]o`000?l00003ojK2k@;o00000onV`^d:o`00
00GoX<;a00?o0000olC9gOl000001?nj`=l3o`000003olVkcOl0003oa;K=00;oa;K=0_o3`mX00ol0
003obKW;o`000002o`000004okj]b?l0003o^Zc<o`0000;o`ZNn00?o0000ol2ac?o0/L`00_o0/L`0
0ol0003o^YjlokZN_002okZN_003o`000?nh[<go000000;o]IZl0_l00002ok:UbP03o`000?n^VlCo
[Y_400;o[Y_400?o[J3;o`000?nYU/<01OnYU/<3o`0000;oXiW;00?o0000oibDbonLU</01ol00002
oiZQfP03o`000?nKX]WoVj;I00?oVj;I0_l00002oiJVh@Co00000onJgOd00ol0003o_Nccokg/l`31
oookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX06_oonfX002[ooo]Z0_l0001]oook
JP;o00000onV`Nd2o`0000;oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/7]0_l00002ojK2
k@04o`000?nV`^goY/;]o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]1Ol00000
1?mSJL?o0000oeYI]ol00002ogEea@04o`000?nDY^;oU:KRoiBVhP?o00000onVdoL5o`000003oi;`
i_l0003o000000Go000000ComM6Yo`000?l0003oj/2Y0ol000000ooG[:_o0000omRXYP06o`000005
ol>CY?l0003o]8FRokB5X_l000001On]PZH00ol0003oX7RVo`000003o`0000;oSFZV00?o0000ogUN
Yol000000_l000000om]EjSo0000o`000005o`000003o`00S?n;003o000000Oo00000_nX`^`3o`00
0004om?=dol0003odlkEo`0000;odm3F00Go0000on;Baol0003o0000oo[=U`03o`0000;oY/;]0_l0
0002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l0
0003ojK2k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOl000000_nV`^d2o`0000?oY/;]0_l0
000ioookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]Zoook
JP1@oookJP?o00000onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00?o
0000ojK2kOnV`^d00_l000000onV`^go0000ojK2k@02o`000003ojK2kOl0003o000000?o00000onV
`^d5o`0000?oTLGi00Co0000ol77gol0003o^/3O0_l00002okFnh@;o00000_o4]/d01?l0003o`l?J
ol?3f_o3`mX2o`0000?oa[?70ol000000onj[<co0000o`000004ol2ac0;o00000onjW[`01?l0003o
^:c=okR/cOnh[<d2o`0000Go/ZG:00?o0000ojjKa?n]X</00on]X</00ol0003oZIK3ojVF``02o`00
0003ojZQcOl0003oXiW;00;oXiW;1?l000001OnMU<[o0000o`000?nNWmCo000000GoVZ7J00?o0000
oi^RfOnKX]T01_l00004oiW7m`;o000000?o_Ncco`000?oonfX0`ooonfX00ol0003ooo]ZoookJP0@
oookJP03o`000?oonf[ooo]Z01Wooo]Z000/oookJP03o`000?oonf[ooo]Z06_ooo]Z0_l00003ojK1
k@;o00000onV`Nd2o`0000;oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000?oY/;]00?o0000ojK2
kOl000000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000_nV`^d3o`000004obX[WOl0003oHfW3
of=Y``So000000?oUZcUo`000?nVdoL03?l000000ooijjco0000ooSIZ`02o`000006oo38Z_l0003o
0000on>hZOl0003og:nY0_l000001?oHZ:Ko0000om6OY?l00002ol2BYPgo00000_nON:L01?l0003o
SFZVoheZY_n=JZH2o`0000;oNEjW0_l00002of1G/0Go000000?o01NUo`000?n100000ol000000omR
]_co0000o`000003o`0000;oY<?_0_l000002?oCc]Go0000om?@e_oCd=Ko0000omCBeol0003oi]O7
1Ol00002ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000;oY/;]
0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00002ojK2k@04o`000?nV`^goY/;]o`0000;o
Y/;]0_l0000moookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003o
oo]ZoookJP1BoookJP;o00001?nV`^d2o`0000?oY/;]0ol00003ojK2k@03o`000?nV`^goY/;]00?o
Y/;]1?l00002ojK2k@03o`000?nV`^goY/;]00;o000000?oY/;]o`000?nV`^d01Ol00002oiC4m`03
o`000?o1amoo000000;o000000Ko]KkQo`000?n__NCo0000olBfcOl00003ol?3fP03o`000?nh]]Oo
000000?oa[?700?o0000ol2^b?o0[/P01Ol000001oo0/Lco0000okFVbOneY/Wo0000okZN_?l00000
1?nh[<d00ol0003o/ZG:ok:UbP03ok:UbP;o00001On]X</01?l0003oZIK3o`000?nZXLd6o`0000;o
XYS;0_l00005oijOe006o`000?nJXM[oVZ7JoiZQf_l0003oVZ7J0ol00003oi^^i003o`000?nIaoOo
000000;o000000?oV]kno`000?l00000aooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[o
oo]Z01Wooo]Z000]oookJP03o`000?oonf[ooo]Z06_ooo]Z0_l00003ojK1k@;o00000onV`Nd2o`00
00;oY/7]0_l00003ojK1k@;o00000onV`^d2o`0000?oY/;]00?o0000ojK2kOl000000onV`^d2o`00
00;oY/;]0_l00003ojK2k@;o000000SoY/;]o`000?l0003o0000obX[WOm6Dk_o0000of=Y``;o0000
0on>Xn<00ol0003oUZcUoiJ/i@06o`000004ojWWn_l0003o0000ojSgj0So000000Colm2/o`000?l0
003oj/6Z0_l00002omb_Z@Ko00000_o0TZH01ol0003o_Y6WokjAYonnTJOo0000okR9Y?l000000on]
PZH2o`0000CoWgRW0ol000004On@K:Ko0000ogUNYomiGZOo0000ofQGZol0003oH5N`o`000?mQEk3o
0000ocI5]Ol3<kKo0000o`0GYOl4D/oo00n=00?o000000GoG:ojo`000?l0003o0000ojC3k`02o`00
0007oj;4lOl0003o0000o`000?oCd=Ko0000omCBe`02o`000003onKGaol0003o000000Co00000_nV
`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000;oY/;]0_l00003ojK2k@;o00000onV
`^d2o`0000?oY/;]0_l00003ojK2k@;o00000_nV`^d00ol0003oY/;]ojK2k@12oookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP1CoookJP?o00000onV
`^d2o`0000CoY/;]0_l00004ojK2k@Co000000CoY/;]o`000?l0003o00000onV`^d00ol0003oY/;]
ojK2k@03ojK2k@03o`000?nV`^goY/;]00;o000000?oOl?mo`000?l000000_l00003okg6h@;o0000
00?o[kgTo`000?l000000oo3`mX01ol0003o^;KGokRfeonh]]Oo0000olJcaol000000oo0[/P2okfl
f@03o`000?o0/L_o`;7<00So00000_nh[<d2o`0000Co/ZG:00?o0000ok:SbOl000001On]X</4o`00
00?oZ9o=00?o0000oj:HbonRV</00_l000000onTX=;o0000oijOe005oijOe0?o00000_nMZ]l2o`00
00;oVjkT1?l00002oi[NoP?o0000b?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z
01Wooo]Z000^oookJP;o0000K?oonfX2o`0000?oY/7]0_l00003ojK1k@;o00000onV`Nd2o`0000;o
Y/;]0_l00003ojK2k@;o00000onV`^d01?l0003oY/;]ojK2kOl00002ojK2k@;o00000_nV`^d2o`00
00?oY/;]7Ol000000oo]n;co0000o`000003o`000004oo?@[?l0003o0000on[1ZPGo000000Cod:F/
o`000?oAXjSodJ>X1ol00002okR9Y003o`000?n]PZKo[H:V00So00000on@K:H01Ol0003oNEjWoh9T
Z?l0003oJ5N[00?o000000GoHEN`od57/Ol0003oBe>io`<c]P02o`0000;o03c00ol000001OmJZ_Wo
0000o`000?l0003oX/Ca00;o000000KoXLGbol[?g_o:cmko0000omCBeol00002omGCe`03o`000?oZ
gLGo000000Go00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000;oY/;]0_l0
0003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00002ojK2k@;o000000?oY/;]o`000?oonfX0AOoo
nfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0EOoo
nfX2o`0000?oY/;]0ol00003ojK2k@So00001?nV`^d2o`0000CoY/;]0_l00003ojK2k@?o000000Co
Y/;]o`000?l0003oI[cm1?l00003okS3h`Co00000_o3`mX4okRfe`;o00000_o0[/P01?l0003o_KcI
okflfOnm_=T2o`0000?o^jO500Co0000okRZbonhZ/_o00000_nhZl`7o`000003ok:Ub_l0003o0000
00Go00000_n]X/`00ol0003oZ9o=ojROc@03ojROc@;o00001OnTX=800ol0003oWYoDo`000002o`00
0004oj6YgOl0003oWJ[OoifZg`Ko00001?nLcOT4o`000<[ooo]Z00?o0000oookJ_oonfX03_oonfX0
0ol0003ooo]ZoookJP0IoookJP00<?oonfX00ol0003ooo]ZoookJP1ZoookJP;o00000onV`Nd2o`00
00?oY/7]0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]
00?oY/;]0_l00003ojK2k@;o00000_nV`^d4o`0000;oEfO700Ko0000oh2IhOn0VN7oP9WQo`000?n>
XN45o`000004ojkYnOl0003o0000ok7Sn0;o000000?o__O_o`000?l000001_l000001?oahkko0000
o`000?o_bJX2o`000005onFiZOl0003og[:Zo`000?oGZjX00_l00002om6SZ006o`000?o:VZGo0000
ol:CY_l0003o_Y6W1ol000000on`QZWo0000oiigY`02oiigY`So000000CoPVBXo`000?meH:coMF2/
0_l00002od57/@;oBe>i00Co>US6o`0V/Ol09[7o03c00_l000000ol2J]_o0000oeZVm`03o`0000;o
XLGb0ol000001_o;dMko0000omGCeooEdmOo0000omKEe`?o000000CooN:Mo`000?l0003o00000onV
`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000;oY/;]0_l00003ojK2k@;o00000onV
`^d2o`0000?oY/;]0_l00002ojK2k@03o`000?oonf[ooo]Z04Oooo]Z00?o0000oookJ_oonfX07?oo
nfX00ol0003ooo]ZoookJP0eoookJP03o`000?oonf[ooo]Z05Gooo]Z00Co0000ojK2kOl0003o0000
0_nV`^d00ol0003oY/;]o`000006o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d2o`0000CoY/;]
0_l00002ojK2k@;o000000?o?:cdo`000?l000000_l00005ok2mh`;o000000So^;KGo`000?l0003o
0000ok6fg?l0003o`:k8o`0000?o_KcI00?o0000ok:`e_l000000_nkYlD00ol0003o^:[;okRZb`02
okRZb`;o00001OnfYLP00ol0003o/Z;8ok:Rb004ok:Rb003o`000?n]X/co[J;<00?o[J;<00?o0000
ojROcOl000000_l000000onXY=;o0000ojBPdP04ojBPdP;o00000onQZMd5o`0000CoWl;a1Ol00000
0onYh_[ooo]ZoookJP3<oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX06OoonfX0
037ooo]Z00?o0000oookJ_oonfX0JooonfX2o`0000;oY/7]0_l00003ojK1k@;o00000onV`^d2o`00
00?oY/;]0_l00002ojK2k@;o000000CoY/;]o`000?nV`^goY/;]0_l00003ojK2k@;o00000onV`^d2
o`0000;oY/;]0ol00002oeMWa`03ofb1eol0003o000000Co00000_nWdoL3o`000005ok7Sn?l0003o
0000o`000?n_mkl01ol000001oobkL3o0000o`000?l0003ojLfho`000?oZ`JX01?l00002omN[ZPKo
00000_o2TjH00ol0003o_Y6Wo`000003ok:5Y@03o`000?n`QZWo/8JY00;o/8JY00?o0000oiigYol0
00000ol00002oi1`Z`03o`000?moIZco000000;o00000_meH:`01?m]H[CoG5Nco`000?m1Ak42od]C
^@03obE9_ol9@;oo02Ja00Co000000Co3VkOo`000?l0003oGjGf0ol00003oj76l`;o000000?oeM?G
o`000?oFeML00_l000000oo_hL;o0000o`000004o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2
o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00002ojK2k@;o0000C?oonfX0
0ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0E_oonfX0
0ol0003oY/;]ojK2k@03ojK2k@Go000000?oY/;]o`000?nV`^d00_l00002ojK2k@04o`000?nV`^go
0000o`0000;oY/;]00Co0000ojK2kOl0003o00000_nV`^d3o`0000?oY/;]0ol00002ojK2k@03o`00
0?l0Qm?o08OC00;o000000Oo/;gSo`000?l0003o0000ojRoj_l0003o`/;I00?o00000_na]]`3o`00
00;o_KcI1?nb/=H2o`0000Go^:[;00Co0000okJUb?nfYLSo]ZG80_l000000ona]Mco0000ok:Rb002
ok:Rb0;o000000?o[K3Jo`000?n]X/`01?n]X/`2o`0000GoZ:CB0ol00003ojF]g@Co000000GoXJWL
oj:lk?nR_>co0000oio2l@03o`0000;oV]Wm00?o0000ojWRn_l00000dOoonfX00ol0003ooo]Zoook
JP0<oookJP03o`000?oonf[ooo]Z01Wooo]Z000boookJP;o0000K?oonfX2o`0000?oY/7]0_l00002
ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00002ojK2k@04o`000?nV`^goY/;]o`0000;oY/;]0_l0
0003ojK2k@;o00000onV`^d2o`000004ojK2kOl0003o0000obI3^PCo00000_n3U=`5o`000003ok3U
n?l0003o000000[o000000?ol^boo`000?l000000_l000000ooYcKSo0000onG4]`03o`000004on2d
Z_l0003o0000o`0000;obj2/00?o0000olbOZoo<Wj/04Ol000001?nPO:_o0000oi1`Zon@L:/3o`00
00;oOfJ/00Go0000ogEP[?l0003oKF:doeaG/`02o`000007odaD^_l0003o0000o`000?l9@;oo0000
ocQXeP03o`000004oaiehol0003oIjGdofNUm0?o00000onQao<2o`000003omKEeol0003of]KD00;o
000000GolNBoo`000?l0003o0000ojK2k@02o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`00
00;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l0001@oookJP03o`000?oonf[ooo]Z
01cooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP1GoookJPGo000000?oY/;]o`00
0?nV`^d01?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00Co0000ojK2
kOnV`^go00000_nV`^d01?l0003oY/;]o`000?l00002ojK2k@04o`000?nV`^go0000o`0000;oY/;]
1?l00005ojRojP04o`000?nl_mco_;oLokbog0So00000_nb/=H2o`0000?o^:[;0_l00002ok:lh@03
o`000?nfYLSo000000Co/KGL0ol00004ojf`fPCo00000_nY[m`00ol0003oZ:CBo`000002o`000004
ojVdhOl0003oYJgMojF]g@Go00001_nR_>`01ol0003oV]Wmoi[IoOnJfOgo0000oh_[l?l00000e?oo
nfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z01Wooo]Z000doookJP03o`000?oonf[o
oo]Z06[ooo]Z0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d0
0ol0003oY/;]o`000002ojK2k@;o00000onV`^d2o`0000?oY/;]1_l00003ogRLj0?o00000_nD[^P6
o`000005olGmh_l0003o0000o`000?o;ol`00_l000001_oakl;o0000o`000?obh[co0000onkC^0?o
000000OoiLBgo`000?oU^jco0000on2dZ_l0003ofJj[00Go000000Goc9n[o`000?nmT:So_I2Xo`00
0004okZ@Z`;o00000on/PjT2o`0000;oX7b[1?l00002oi9aZP04o`000?moIZcoOfJ/o`0000;oLF6`
0_l00002of]Q]003o`000?mJG[coFUjl00;oCF?800Go2dS6o`000?l0003o157>o`000002odR4iPKo
00001?nSb_@01?l0003of]KDo`000?oMgmL5o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`00
00;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l0001EoookJP03o`000?oonf[ooo]Z
01_ooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1FoookJP?o000000?ooo]Zo`00
0?l000001?nV`^d2o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@03ojK2
k@03o`000?nV`^goY/;]00?oY/;]00Co0000ojK2kOnV`^go00000_nV`^d00ol0003oY/;]o`000003
o`0000CoO/Wo00Co0000ok>hgOnc^=go/kSM0_l000000on[_NKo0000okflf@04o`000004oj^bgOl0
003o^:[;o`0000Co/[cQ0_l00004ok6eg0;o00001On]/=X2o`0000GoZJoL0_l00002ojVdh@Oo0000
0_nT^nT00ol0003oX[c/oj:lk003o`0000;oWM;j0ol0003GoookJP03o`000?oonf[ooo]Z00_ooo]Z
00?o0000oookJ_oonfX06OoonfX003Gooo]Z00?o0000oookJ_oonfX0J_oonfX2o`0000?oY/;]0_l0
0003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l000001?nV`^go0000ojK2kOnV`^d2o`0000;oY/;]
0_l00003ojK2k@;o00000onV`^d8o`000003ogRLj?l0003oU:kX00Go000000?o__S]o`000?l00000
0_l000001?oGom?oboo<o`000?o^lLL2o`000003oo;U_ol0003o000000;o000000Ooj/bgo`000?oU
aKKo0000omfl]_l0003oh;B[00;o000000?ofJj[o`000?oBYj/00_l000000oo<X:_o0000o`000002
o`000007okjBZOl0003o^Y2[okZ@Zol0003o]HZWo`000002ojb3Z@Go00000_nNNZ/02?l0003oTW6Z
oi9aZ_nBLJ[o0000ogmV[?l0003oQV^/0_maHK03o`000007of]Q]?mMHKkoFUjloeYN_?loF/KoCF?8
oaY=aP02o`000004odU`eol0003o0000odR4iPCo000000CoL:Kbo`000?l0003o00000_nVcO@2o`00
0005omgOeol0003o0000oo?W_?oejKT00_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00002
ojK2k@;o00000onV`^d2o`0000?oY/;]0_l0001JoookJP03o`000?oonf[ooo]Z01[ooo]Z00?o0000
oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP1CoookJP?o00001OoonfX3o`0000?oY/;]0_l00004
ojK2k@;o00001?nV`^d2o`0000?oY/;]0ol00003ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@03
ojK2k@06o`000?nV`^goY/;]ojK2kOl0003oO/Wo1_l00005oj^miP03o`000?nd]][o];KJ00;o];KJ
1Ol00002ok:lh@03o`000?n`]Mco000000;o/KGL0_l00002ok2af@?o[K3J0_l000000on^/M[o0000
ojV_g002ojV_g0Ko00000_nV/^400ol0003oY[gZo`000005ojBkj@;o00000_nMd_X2o`000003ogkT
l_l0003ooo]Z0=Wooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0HoookJP00=_oo
nfX2o`0006_ooo]Z0_l00003ojK2k@;o00000onV`^d2o`0000;oY/;]0_l00003ojK2k@03o`000?nV
`^goY/;]00?oY/;]0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l000000oliE<?o0000o`00
0002ogjDg`?o000000?oZm[ho`000?n[f_P01_l000000ooGom?o0000o`000002o`000003ong[b?l0
003o000000;o000000?okM6go`000?l000000_oUaKH3o`000003on2dZol0003of[6^00?o00000_o6
WJh2o`0000;oaif]2ol000000on^R:go0000oiijZ`03oiijZ`Oo000000?oQV^/o`000?l000000_mk
Ik48o`000006oaY=a_l0003oBG3GodU`eol0003oFH[V1?l000001?miZ?7o0000o`000?l00002ojc<
l@?o000000?ohN;Eo`000?l000001?l00003ojK2k@;o00000onV`^d2o`0000?oY/;]0_l00002ojK2
k@;o00000onV`^d2o`0005oooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0coook
JP03o`000?oonf[ooo]Z04oooo]Z1?l0000:oookJP;o00000onV`^d3o`0000?oY/;]0ol00003ojK2
k@;o00001?nV`^d2o`0000CoY/;]0_l00003ojK2k@?o00000onV`^d3o`0000?oY/;]00Ko0000obl0
0?l_003o;`00o`000?n[_NH3o`0000;oNL_o00Co0000okBff_l0003o00000on]^^<>o`000003ojf`
f_l0003o000000Go00001OnZ]>02o`0000GoY[gZ0ol00004oio@n@03o`000?mni?;o00000=kooo]Z
00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0HoookJP00>?oonfX00ol0003ooo]Zoook
JP1YoookJP;o00000onV`^d2o`0000?oY/;]0_l00002ojK2k@;o000000CoY/;]o`000?nV`^goY/;]
0_l00003ojK2k@;o00000onV`^d2o`0000;oY/;]0_l00002ojK2k@Co000000?oHI3Wo`000?l00000
1?l000001?nhiOGo0000o`000?l00002olCPk@03o`000?o2mngo000000Ko000000Cokmjno`000?l0
003okM6g1?l000001?oQ_[Go0000ombh]?l00002omZa[P03o`000?oEZZco000000Go000000?oaif]
o`000?njT:/00_l00004okN@[P03o`000?n^R:go[XR]00;o[XR]1Ol00003oi9e[`03o`000?n5K[7o
000000Co000000GoNfNao`000?mdJKSoM6Vho`000002ofIW_`04o`000?mLK<[oG6c:o`0000;oFgWH
0_l000000omXT>Go0000o`000002oh>[k`;o00000on/c?400ol0003o_Mc_o`000003o`000003ooWW
[ol0003oY/;]00;o00000onV`^d2o`0000?oY/;]0_l00002ojK2k@;o00000onV`^d2o`0006?ooo]Z
00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04cooo]Z
0ol0000>oookJP04o`000?nV`^go0000o`0000;oY/;]00Co0000ojK2kOl0003o00000onV`^d2o`00
00?oY/;]0ol00003ojK2k@?o00000onV`^d2o`0000CoY/;]0_l00003ojK2k@?o00000onV`^d3o`00
0003obl00?l0003oNL_o00GoNL_o00?o0000ojfjhon]^^<00_l00002ogk>o`03o`000?na]=_o0000
00;o00000_nY_NP00ol0003o/;7Ho`000002o`000004ojZki_l0003o[[3Jojj`fP?o000000?oZKgX
o`000?nZ]>000ol00003ojG4k`?o00001?nAe_h4o`000>?ooo]Z00?o0000oookJ_oonfX02OoonfX0
0ol0003ooo]ZoookJP0HoookJP00>OoonfX00ol0003ooo]ZoookJP1ZoookJP;o00000_nV`^d2o`00
00?oY/;]0_l00003ojK2k@03o`000?nV`^go000000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`00
00;oY/;]0_l000001?nV`^go0000o`000?l00003of6@i`03o`000?nA[NWoTJgY00Go00000_o4h>d0
0ooAn>Go0000olgii`02o`000004omcggOl0003o0000onG^e0Go000000?ojL^fo`000?oVaKD00_l0
0002ombh]0Co000000GoeJZ/o`000?o>Y:gocZB]o`000002olJM[A3o00000_nQOjl01?l0003oTWF_
oi9e[onBMJl2o`0000;oRW6a00?o0000ogUY]_l000000_l000002OmdJKSo0000ofU/`_l0003oIVNo
oe9Wb_l0003oG6c:ocmXd`03o`000004oce[e_l0003o0000oe25i@Ko000000Go/Lk_o`000?l0003o
0000om3^j004o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000;oY/;]0_l0001XoookJP03
o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX0<ooonfX00ol0003ooo]ZoookJP19oookJP?o
00004_oonfX00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00;o000000?oY/;]o`000?nV
`^d00_l00002ojK2k@04o`000?nV`^go0000o`0000?oY/;]0_l00003ojK2k@?o00000onV`^d2o`00
00CoY/;]0_l00004ojK2k@;o00000onV`^d3o`000003o`jLd_l0003o000000KoO/ko00?o0000ojVm
j?nY_NP01?nY_NP00ol0003oZ[_VojZkiP03ojZkiP;o00001OnY_NP01?l0003oYLC_ojG4konUa>l2
o`0000;oNMSm0_l000000onAe_ko0000o`00003XoookJP03o`000?oonf[ooo]Z00Wooo]Z00?o0000
oookJ_oonfX06?oonfX003[ooo]Z0_l0001[oookJP;o00000_nV`^d2o`0000?oY/;]0_l000001?nV
`^go0000ojK2kOnV`^d2o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000?oY/;]1Ol00002
off8g0?o000000?oZMGgo`000?l000000ol000000ooAn>Go0000o`000007o`000004onOWd?l0003o
i=O9onCGb@;o000000?oi/Feo`000?oR`;D00ol00002om:_]P07o`000?oEZjgo0000o`000?o>Y:go
0000olJM[P02o`0000?o`iR[0_l00002okN@[P03o`000?ncRj_o000000?oZXF]0_l00004oj5o[`05
o`000?nBMJoo0000oi=f[ol000000_n:LK42o`0000?oPFne0_l000000omYK<;o0000of=X`P02o`00
0008oeY/bol0003o0000oe]ieol0003oIWoHogJFi?l00002ofB;h`;o000000?oS:o]o`000?l00000
0_ngdNd3o`000004oloNi?l0003o0000o`0000?oY/;]0_l00003ojK2k@;o00000onV`^d2o`0006co
oo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]ZoookJP0coookJP03o`000?oonf[ooo]Z04Go
oo]Z1?l0000FoookJP?o00000onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?o
Y/;]00?o0000ojK2kOnV`^d00_l000000onV`^go0000ojK2k@02o`0000;oY/;]00Co0000ojK2kOl0
003o00000_nV`^d3o`0000?oY/;]0ol00003ojK2k@;o00001?nV`^d2o`0000;oY/;]2ol00003of_=
o@?o00001?mldOl3o`0000CoOmCo00Go0000ogWHoOmif?go0000obL0003_oookJP03o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX06?oonfX003cooo]Z00?o0000oookJ_oonfX0JOoonfX2o`00
00;oY/;]0_l00003ojK2k@03o`000?nV`^goY/;]00?oY/;]0_l00003ojK2k@;o00000_nV`^d2o`00
00?oY/;]0_l00003ojK2k@?o000000?o?g?Lo`000?l000001_l00003ok;Sm`05o`000?oKl=oo0000
o`000?oTl=D00_l000000ooWh<co0000onOWd002o`000003onCGbOl0003ohLo600?o000000Goh/2e
o`000?oN^[Co0000om:_]P02o`000003omF[[Ol0003od:Zb00Ko000000Ko`iR[o`000?nlTjco0000
okN@[_l00003ok>;Z`05o`000?nZQJgo0000ojZ6[_l000000_nQOjl2o`000009oi9e[onCMZooTgJ_
oi=f[ol0003oRW6ao`000?n9M;Go000000?oPFne0_mkLK`00ol0003oJFc2o`000002og1``P04o`00
0?mWM<coIgC<o`0000?oIWoH00?o0000ofB;hol000001_l000000onmeN_o0000oloNi002oloNi0Co
00000onV`^d2o`0000?oY/;]0_l0001aoookJP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oo
nfX0<_oonfX00ol0003ooo]ZoookJP12oookJP?o00007?oonfX2o`0000CoY/;]0_l00003ojK2k@?o
00000onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]00?oY/;]00Co0000ojK2kOnV
`^go00000_nV`^d01ol0003oY/;]o`000?l0003oY/;]o`000?nV`^d00ol00002ojK2k@?o00000onV
`^d2o`0000Wooo]Z0ol00004oe_7n@;o00000omZco`4o`000003of3@m?oonf[ooo]Z0?Kooo]Z00?o
0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0HoookJP00?OoonfX00ol0003ooo]ZoookJP1Y
oookJP;o00000onV`^d3o`0000;oY/;]0_l00003ojK2k@;o00000onV`^d2o`0000;oY/;]0_l00003
ojK2k@;o00000onV`^d4o`000003ogfLi_l0003oTKSa00;o000000Co`M_]o`000?l0003o00000_nm
io<3o`000005onOWd?l0003oin3<o`000?oUf/X00_l000002ooTdlGo0000on7?a_l0003ogLS3o`00
0?oR`;Go0000omjj]?l0003ofKFe00Go000000God:Zbo`000?o2Vjoo`Y^_o`000002ol:K/13o0000
00?oWgj_o`000?l000002Ol000000on1KkGoOW>log]a_002og]a_0;o00000_m`L<83og=mcP;o0000
00CoLhSIofIof?l0003o00000omkV^D00ol0003oUKC]oiFdk@03o`0000;ocmkT0_l000001?o^n;Co
0000o`000?l00003ojK2k@;o0000MOoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z
03;ooo]Z00?o0000oookJ_oonfX0?ooonfX3o`00023ooo]Z0ol00003ojK2k@;o00001?nV`^d2o`00
00CoY/;]0_l00003ojK2k@?o00000onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV`^goY/;]
00;oY/;]00?o0000ojK2kOnV`^d00_l00002ojK2k@04o`000?nV`^go0000o`000?oooo]Z5ooonfX0
0ol0003ooo]ZoookJP06oookJP03o`000?oonf[ooo]Z01Sooo]Z000noookJP;o0000J_oonfX2o`00
0004ojK2kOl0003oY/;]ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@;o00000_nV`^d2
o`0000?oY/;]0_l00003ojK2k@[o00000_nmio<00ol0003obMWVomC[i@05o`000006onGJb_l0003o
0000onCCaOl0003oh/g30_l000001?oMb<?o0000o`000?oN^[@2o`000006omVe]Ol0003odjneom>_
]Ol0003od:Zb0_l00002ol:K[`04ol>L/?l0003o`Y^`o`0000?o]i2^00?o0000okB@/OndT;400_nd
T;401_l0003oZHRaojV8/OnYR;7o0000oimn[`Go00000_nENk<4ohUd]P0:o`000?n1KkGo0000o`00
0?mnLkcoNg6lo`000?mdM/Ko0000ofeaaP;o00000_mcOLh01?l0003oH7;?o`000?mcR=T2o`0000;o
Qj7U1?l00003oiO<nP;o000000?og_CLo`000?l000000_nV`^d2o`0007[ooo]Z00?o0000oookJ_oo
nfX05_oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z03cooo]Z1?l0000UoookJP;o
00000onV`^d3o`0000?oY/;]0ol00003ojK2k@;o00001?nV`^d2o`0000?oY/;]0ol00003ojK2k@;o
00001?nV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?oonf[ooo]Z0?oooo]Z6?oonfX00ol0003o
oo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Sooo]Z0010oookJP03o`000?oonf[ooo]Z06Sooo]Z
00?o0000ojK2kOnV`^d00onV`^d2o`0000?oY/;]0_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]
0_l00002ojK2k@;o00000_nV`^d2o`0000;oE9G_0_l00003ojKAmP;o000000?obMWVo`000?oDjnD0
0ol00002omGTh@;o000000goimW6o`000?l0003o0000on;=`ol0003oglS2o`000?oI`L;o0000omjj
]?l0003of[Rg00;o000000?odjneo`000?o9YkL00_l000000oo<YkCo0000o`000005o`000003okN@
[_l0003o000000?o]92a0_l00002ojV8/@Co00000_nQPk<00ol0003oUG^coiEk/`02oiEk/`04ohUd
]_l0003o0000ohig]@?oOg6j1?l000001?mdM/Ko0000ogQha_mhN<H2o`000004of1bcol0003oOi3J
ogn@fPWo000000?oX]Ojo`000?o1kO801?l0001ooookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000
oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP0ioookJP?o0000:OoonfX01?l0003oY/;]o`000?l0
0003ojK2k@;o00001?nV`^d2o`0000?oY/;]0ol00003ojK2k@;o00001?nV`^d2o`0000?oY/;]0ol0
0003ojK2k@?o0000oooonfXMoookJP03o`000?oonf[ooo]Z00Gooo]Z00?o0000oookJ_oonfX06?oo
nfX0047ooo]Z00?o0000oookJ_oonfX0JOoonfX2o`0000?oY/;]0_l00003ojK2k@;o00000_nV`^d2
o`0000?oY/;]0_l00003ojK2k@;o00000_nV`^d2o`000003ojK2kOl0003o000000?o000000GoY]7f
o`000?l0003o0000ok7Hm002o`000007omC[iOl0003of>COo`000?oEi>7o0000omSPg@03o`000007
onGBa?l0003ohlg2o`000?oOb<;o0000omc4`@03o`0000;of[Rg00Ko0000omJc]_l0003o0000olVW
]ol00002olbW]004o`000?noV[;o_iZbo`0000?o_i^c2ol000000on/SKGo0000oj63/`03oj63/`03
o`000?nENk?o000000;o00001?n>MkD2ogma^P04ohIf^_mhLl7oN7?1ogQc`@?o00000_mhN<H00ol0
003oO8GAogb5d@02o`000003ofj6f_l0003o000000;oTZSU1?l000001onado;o0000o`000?l0003o
fNKOomKk/ol00000P?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z037ooo]Z00?o
0000oookJ_oonfX0=_oonfX3o`0002gooo]Z00?o0000ojK2kOnV`^d00_l000000onV`^go0000ojK2
k@03o`000003ojK2kOl0003oY/;]00;o00000onV`^d2o`0000?oY/;]0ol00003ojK2k@;o00001?nV
`^d2o`000?oooo]Z8ooonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z01Oooo]Z0012
oookJP;o0000J_oonfX2o`0000?oY/;]0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00003
ojK2k@;o00000_nV`^d2o`000004ojK2kOl0003o0000of>?iP?o000000?o/MSdo`000?l000000_n_
f?D02_l0003of>COo`000?oJg][o0000omSPgOl0003ofMGDo`000?oGe]H2o`000005on?=`_l0003o
0000omc4`Ol000000_oI_l03o`000004omJc]_l0003odJjgom6^]`Ko000000Go_iZbo`000?noVk?o
_i^co`000002okFA/@03o`000?ndT;7o000000;o/Y:e00?o0000ojV7/Ol000000on/SKD00ol0003o
XH>co`000003o`000003oiIk/ol0003o000000Co000000SoOg6jo`000?l0003oQWJjogQc`Ol0003o
PGS0o`0000;oMW[:0ol00002ogb5d@03o`000?n6UmgoQYOM00[o000000?ofNKOo`000?oFnk<0POoo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX0<_oo
nfX4o`00037ooo]Z00?o0000ojK2kOnV`^d00onV`^d00ol0003oY/;]ojK2k@03ojK2k@03o`000?nV
`^goY/;]00;o000000?oY/;]o`000?nV`^d00_l00002ojK2k@04o`000?nV`^go0000o`0000;oY/;]
0ol0003ooookJRSooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]ZoookJP0GoookJP00A?oo
nfX00ol0003ooo]ZoookJP1YoookJP;o00000_nV`^d2o`0000?oY/;]0_l00002ojK2k@;o00000onV
`^d2o`0000?oY/;]0_l00002ojK2k@Wo000000?o^]G^o`000?l000000_ngfO402Ol0003of]kJo`00
0?oKfMKo0000omWEe?l0003ofM;Bo`000002omK@d`03o`000?oPb<7o000000;o000000?ofKo0o`00
0?o@]l401?l000001_oA[[Oo0000olFU^?l0003oc:Ndo`0000;ob:Jg1_l00002okFA/@03o`000?nb
T[Go/Y:e00;o/Y:e00?o0000ojb=]On/SKD02Ol00002oiN1^@;o00000_nAOKX00ol0003oQ7ZoohAj
_`02o`0000?oPGS00_l000001?meNLWoQXkDohJ>e?n6S]@8o`0000CoTl[k00?o0000omWVgol00000
0_l00022oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]Z
oookJP0_oookJP?o0000=ooonfX2o`0000CoY/;]0_l00003ojK2k@03o`000?nV`^goY/;]00?oY/;]
00?o0000ojK2kOnV`^d00onV`^d01?l0003oY/;]ojK2kOl0003ooookJRgooo]Z00?o0000oookJ_oo
nfX00ooonfX00ol0003ooo]ZoookJP0GoookJP00AOoonfX2o`0006[ooo]Z0_l00002ojK2k@;o0000
0onV`^d2o`0000?oY/;]0_l00002ojK2k@;o00000onV`^d2o`0000;oY/;]0ol000000ol9HMSo0000
o`000003o`000003okoCjOl0003o000000;o_MW^0ol000001?oKeM;o0000omWBd_oId]83o`000006
omC;dOl0003ogLC0o`000?oJ_koo00000_o@]l401?o</l7o0000o`000?oB/[X3o`000003olFU^?l0
003ob:Jg00;ob:Jg00?o0000okbI]?l000000onlVkL:o`000004ojR;]_l0003o0000o`0000;oXXRh
00?o0000oiN1^OnGPKT00ol00004oi5m^P;o000000GoQ7VoohN1aOn7PLGoQh75oh5h`004o`0000;o
QXkD00?o0000ogN5e?l000000on@XMl00ol0003oTl[ko`000002o`000003oikJo?l0003o000000;o
0000Q?oonfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oo
nfX0;?oonfX3o`0003_ooo]Z0ol00003ojG2kP;o00001?nV`^h2o`0000?oY/;]0ol00003ojK2k@03
o`000?oonf[ooo]Z0?oooo]Z;OoonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z01Oo
oo]Z0017oookJP03o`000?oonf[ooo]Z06Sooo]Z0_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]
0_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0ol000000on0Z^oo0000o`000003o`000004okgI
k_l0003o`]SZol;HjP;oaMGV0_l000002?oId];o0000omS>d?l0003oelc?o`000?oAaLoo00000_oJ
_kl3o`000005olbc`Ol0003o0000om:b^_l000000_o?[kT3o`000005olRV]ol0003o_9VdokbI]?l0
00000_nlVkL01_l0003o/i:dok>B]?l0003o/Y:eo`0000;o]INh00Ko0000ojR;]_nXRkKo0000ojV<
]ol00002oj:8^0Co00000_nHP;P00ol0003oTGfjo`000005o`000003ohAi_on7PLGoQh7500;o0000
0on7RLh:o`0000?oW][l0_l000000oo3o]go0000oookJP25oookJP03o`000?oonf[ooo]Z01;ooo]Z
00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0XoookJPCo0000@?oonfX2o`0000?oYL;^
0ol00003ojK2kP;o00001?nV`^h2o`000?oooo]Z<ooonfX00ol0003ooo]ZoookJP02oookJP03o`00
0?oonf[ooo]Z01Oooo]Z0018oookJP03o`000?oonf[ooo]Z06Sooo]Z0_l00003ojK2k@;o00000_nV
`^d2o`0000?oY/;]0_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0ol000000on;/o7o0000oiNn
l`03o`000004ol;Hj_l0003oaMGVolGEiP;oa];S0_l000001OoHc]3o0000omO<col0003oeLS>00;o
000000Gof[noo`000?oG_l;o0000omBk`@04o`0000?ocjni00?o0000ol:S^_l000002_l000001?nc
T[Co0000okFG^?neUkP9o`000003oj67^?l0003o000000Go00000onDQ;l00ol0003oRH;5ohV2a@0:
o`0000?oPi;I0_l000000on=YNGo0000o`000003o`000003om?XiOo3o]go000008Sooo]Z00?o0000
oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02Gooo]Z0ol00013
oookJP04o`000?oonf[o0000o`0000CoYL;^0_l00003ojG2kP?o0000oooonfXhoookJP05o`000?oo
nf[ooo]ZoookJ_l000006OoonfX004Wooo]Z0_l0001YoookJP;o00000onV`^d2o`0000;oY/;]0_l0
0003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00003ojK2k@Go000000KoUKcbo`000?l0003o0000
olGEi_l00002olKBh`;oaloP0_l000001?oGc<oo0000omG8c_l00002om;6cP03o`000?oG_l;o0000
00;oe;_100?o0000olV``_o9/<800_l000001Oo?[kWo0000ol:S^_o2Xk[o000000;oa:Fj00?o0000
okZJ]onjV[L00_l00003okVL^PCo00000_n`U;T00ol0003oZ8jjojR>^P02ojR>^P?o000000?oXXfn
o`000?nIQkh00_nIQkh00onJQ[go0000oiB4_`03oiB4_`04o`000?n9P/GoRX74o`0000?oSHW:0_l0
0003ohF=d`Go00000_nI/nT4o`000003ol?ngOl0003ooo]Z08Sooo]Z00?o0000oookJ_oonfX04Ooo
nfX00ol0003ooo]ZoookJP0`oookJP03o`000?oonf[ooo]Z02;ooo]Z0ol00016oookJP03o`000?oo
nf[ooo]Z00?o00000onU`^h2o`000?oooo]Z?_oonfX01?l0003ooo]ZoookJ_l0000IoookJP00Booo
nfX00ol0003ooo]ZoookJP1WoookJP;o00000onV`^d2o`0000;oY/;]0_l00003ojK2k@;o00000_nV
`^d2o`0000?oY/;]0_l00003ojK2k@Go000000KoWlOdo`000?l0003o0000olKBhol00002olO?h0;o
a/_N0_l000001_oEb<ko0000om;6c_oBa/ko0000ol^mc@;o000000?oe;_1o`000?o9/<800_o9/<80
1Ol0003ocjnio`000?l0003o`Z>j00Co00000onjV[L01_nkWKWo0000okVL^_niW;[o0000okJG]`Co
/9Bi00?o/9>ho`000?nXS[X00_nXS[X2o`0000;oXXfn0ol00004oiZ6_@03o`000?nDQ;ooU8Bo00[o
000000?oQHgCo`000?l000001ol00002oi[Io@?o000000?oQmF4oookJ_oonfX0R?oonfX00ol0003o
oo]ZoookJP0@oookJP03o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX07ooonfX4o`0004Wo
oo]Z00Ko0000oookJ_oonf[ooo]Zo`000?nU`^h2o`000?oooo]Z@_oonfX00ol0003ooo]Zo`00000I
oookJP00C?oonfX00ol0003ooo]ZoookJP1WoookJP;o00000onV`^d2o`0000;oY/;]0_l00003ojK2
k@;o00000onV`^d3o`0000;oY/;]0_l00002ojK2k@Go000000KoX/Oco`000?l0003o0000olO?h?l0
0002olK;gP03o`000?o4b=go000000;o000000?od/K>o`000?o;_Ld00_l000000ooD^l3o0000o`00
0002olV``P03olF^`ol0003o000000;obZno00?o0000oknS_?noXk`01ol000000oniW;[o0000okJG
]`02okJG]`;o/9Bi00?o/9>ho`000?l000001ol00002oj:<_@03o`000?nJQ[goVXJm00Go000000?o
U8W6oi>=b_nCSLX00_nCSLX00ol0003oS8oAo`000002oh^>d@06o`000?nEW=WoUIcIoiFLfOl0003o
U:WT1Ol000001?n^fOKo0000ojgicOl0002<oookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000oook
J_oonfX0;ooonfX00ol0003ooo]ZoookJP0LoookJP?o0000COoonfX00ol0003ooo]ZoookJP02oook
JP03o`000?oonf[ooo]Z0?oooo]Z@_oonfX01?l0003ooo]ZoookJ_l0000HoookJP00COoonfX2o`00
06Sooo]Z0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00004ojK2k@;o00000_nV`^d2o`00
00;oY/;]1Ol000000onSa_;o0000o`000002o`000004olK;g_l0003oa<SMolC8g@;o000000Coe<G<
o`000?o;_Lgo00000_o7^/h2o`000003om2g`Ol0003o000000?o000000?obZnoo`000?noXk`00_no
Xk`00ol0003o`Z6ho`000003okjV`@Ko000000?o/9Bio`000?l000000_n`T[P00ol0003oZ9:oojRB
_`02ojRB_`03o`000?nRS;goXXbm00Co000000?oVhg4o`000?l000001?nDRLH3oi>=bP;o00000_n;
S]48o`0000?oULgk1?l0002>oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX0;ooo
nfX00ol0003ooo]ZoookJP0HoookJPCo0000D?oonfX00ol0003ooo]ZoookJP3ooookJTSooo]Z00?o
0000oookJ_l000006?oonfX004oooo]Z00?o0000oookJ_oonfX0I_oonfX2o`0000?oY/;]0ol00003
ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00002ojK2k@;o00000onV`^d01?l0003o27KQo`000?l0
0003oj?5l@;o000000Coa<SMo`000?l0003o`LGM0_l000001_oA`/co0000o`000?o7^/ko0000ol>h
c`;o00000_o;//400ol0003obKW:olVibP02o`0000;o_j>l0_nkXl000ol0003o_ZK1okjV`@02okjV
`@;o00000ongWKh01on`Ukgo0000ok2B^?n`T[So0000ok:M`_l000001?nXT[l3o`000004oj>Ca?l0
003o0000o`0000;oW8g300?o0000oiB9a_nDRLH00ol000000onCSL[o0000o`000003o`0000;oV9gG
00?o0000oiBUhOl000001?l00002oi[Ro@;o0000T?oonfX00ol0003ooo]ZoookJP0>oookJP03o`00
0?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX05OoonfX3o`0005Cooo]Z00?o0000oookJ_oonfX0
oooonfY9oookJP;o00006?oonfX0053ooo]Z00?o0000oookJ_oonfX0I_oonfX2o`0000CoY/;]0_l0
0003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00002ojK2k@;o00000onV`^d01?l0003o0G?No`00
0?l00004oj;4l@05o`000?o1aMgo0000o`000?nn`]d00_l00002olfoc0Go000000?obk;1o`000?o9
^LX00_o9^LX00ol0003ob:bmo`000006o`0000;o_ZK10_njWkd00ol0003o]ifnok2G_@02ok2G_@;o
00000onbWL82o`000003ojRB_ol0003o000000;o00000_nST/<7o`000003oiNCcOnHT/co000000?o
TiCA00Go0000oiRMeonHWMOo0000oiRMe`03o`0000?oU/Kh1?l0002BoookJP03o`000?oonf[ooo]Z
00kooo]Z00?o0000oookJ_oonfX0;_oonfX00ol0003ooo]ZoookJP0BoookJP?o0000EooonfX00ol0
003ooo]ZoookJP3ooookJTSooo]Z0ol0000HoookJP00DOoonfX2o`0006Wooo]Z0_l00002ojK2k@;o
00000onV`^d2o`0000;oY/;]0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]00?o0000o`1^f?l0
00000_l00003oj32l@;o000000?o_/;Mo`000?nj`=h00_l00002olVkc004o`000?o4]/coa;K<olBf
c0;o00000_o9^LX2okj/b004o`000?o2Y[ko`ZJno`0000;o_k3;4Ol00004ojVF`P06o`000?nST/?o
Xi;3o`000?nTVL[o00000_nMULX3o`000003oiRBc?l0003o000000Oo000000?oUjKPo`000?l00000
0_l00003oiSMoP;o0000U?oonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX03_oonfX4o`0005[ooo]Z00?o0000oookJ_oonfX0oooonfY4oookJPCo0000
6ooonfX005?ooo]Z00?o0000oookJ_oonfX0IooonfX2o`0000;oY/;]0_l00003ojK2k@;o00000_nV
`^d2o`0000?oY/;]0_l00002ojK2k@;o00000onV`^d2o`000003o`1Sc_l0003o000000;oT<Kj00Wo
0000olC9gOl0003o^/3No`000?ne_^3o0000olVkc?l000000oo4]/`00oo3`]Wo0000olVibP02o`00
0005okj/b?l0003o0000ol:V__l000000ono/</02?l0003o^YjlokZN_?njW[co0000okR[c?l0003o
]IZl0_l000000oncY<Wo0000ojnK``02ojnK``03ojfPb_l0003oZIK200CoZIK200?o0000ojBIb_l0
00001?l000001?nNU<Wo0000o`000?l00002oi^Qf@03o`000?nLX]SoW:;H00;oW:;H0ol00003oiW7
m`?o000000?o_>kdoookJ_oonfX0UOoonfX00ol0003ooo]ZoookJP0<oookJP03o`000?oonf[ooo]Z
02kooo]Z00?o0000oookJ_oonfX02ooonfX3o`0005kooo]Z00?o0000oookJ_oonfX0oooonfY0oook
JPCo00007ooonfX005Cooo]Z00?o0000oookJ_oonfX0IooonfX2o`0000;oY/;]0_l00003ojK2k@;o
00000_nV`^d2o`0000?oY/;]0_l00002ojK2k@;o00000onV`^d6o`000003oi36n_l0003o`LOO00;o
000000?o]KkPo`000?l000000_o4]/`00ol0003o`l;Iol?2f@02o`0000;oa[;71_l000001_no/<_o
0000okFUb?l0003o^Yjlo`0000;o^:_<0_l00003ok>Tb@;o00001?n]X<X7o`000003oj>HbOl0003o
000000;o00000_nPWm<01Ol0003oVj7Ioi^QfOl0003oVj7I00Co000000?oW:kTo`000?nIaoL00_l0
00001?nGg_ko0000o`000?l0002IoookJP03o`000?oonf[ooo]Z00_ooo]Z00?o0000oookJ_oonfX0
;_oonfX00ol0003ooo]ZoookJP08oookJP?o0000HOoonfX00ol0003ooo]ZoookJP3ooookJScooo]Z
1?l0000SoookJP00EOoonfX2o`0006Sooo]Z0_l00002ojK2k@;o00000onV`^d2o`0000;oY/;]0_l0
0003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l000000onV`^go0000o`000003o`0000;o_LGQ0_l0
00000on__>?o0000o`000002ol?2f@04o`000?nh]MKo0000o`0000;o_jg700Co0000okflf?l0003o
`;3;4_l000000on]X<[o0000o`000002o`0000;oZIo<0ol00002ojFPd@05o`000?nPWm?oX9oCo`00
0?nPWm<00_l000001?nNZMoo0000o`000?l00002oib^i0?o000000CoUmkno`000?l0003o[_?dVooo
nfX00ol0003ooo]ZoookJP0;oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX01Ooo
nfX4o`0006Cooo]Z00?o0000oookJ_oonfX0oooonfXioookJP?o00009ooonfX005Oooo]Z00?o0000
oookJ_oonfX0I_oonfX2o`0000;oY/;]0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00003
ojK2k@;o00000_nV`^d2o`000003ojK2kOl0003o000000?o00000onh`^85o`000006okRee_l0003o
/[GKo`000?no[LOo00000_nm_=P2o`0000;o^jO500Ko0000okRYbonhZL_o0000okR[c?l00002okJT
a`03o`000?ncY<Wo000000?o/Z;70_l00003ojjQb`06o`000?nYWlco0000o`000?nYXm7o00000_nU
X=401?l0003oYJ3Ao`000?l00002oj6Yg0?o000000?oWjWNo`000?l000000_l00003oic=n@;o0000
W_oonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
0_oonfX3o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXeoookJPCo0000:_oonfX005Sooo]Z00?o
0000oookJ_oonfX0I_oonfX2o`0000;oY/;]0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l0
0004ojK2k@;o00000_nV`^d2o`000003ojK2kOl0003o=ZWb00?o000000Ko/;gSo`000?l0003oZ;kY
o`000?o2`MT2o`000003ok:efol0003o000000;o_KcH00Go0000ok:_eOl0003o^jO5o`000004okRY
b`03o`000?nfY<Oo]ZC700;o]ZC700?o0000ok:RaonbX/L00_nbX/L00ol0003o[Z7;ojjQb`02ojjQ
b`03o`000?nYXm7oZJ?A00?oZJ?A0_l00002ojF]g003o`000?nQZMcoXJWL00Co00000onO`_43o`00
0003ojOTnol0003ooo]Z0:3ooo]Z00?o0000oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0]oook
JP03o`000?oonf[o000000;o0000JooonfX00ol0003ooo]ZoookJP3ooookJS7ooo]Z1?l0000^oook
JP00FOoonfX2o`0006Oooo]Z0_l00002ojK2k@;o00000onV`^d2o`0000?oY/;]0ol00002ojK2k@;o
00000onV`^d2o`0000;oY/;]0_l00003ojK2k@03oajCjol0003o000000CoZ;kY00?o0000okbog?nl
_m`01_l000000onb[mGo0000o`000002okRYb`;o000000?o/[cQo`000?nfY<L00_l000001?na]=_o
0000o`000?l00002ojj`f@?o00000onZ[m/01_l0003oZJ?Ao`000?l0003oZK?Po`0000;oYJgL1?l0
0003oj:lj`;o00000_nHf_h00ol0003oOnOYoookJP2ToookJP03o`000?oonf[ooo]Z00Wooo]Z00?o
0000oookJ_oonfX0;?oonfX2o`0006kooo]Z00?o0000oookJ_oonfX0oooonfX]oookJPCo0000<_oo
nfX005_ooo]Z00?o0000oookJ_oonfX0IOoonfX2o`0000?oY/;]0ol00002ojK2k@;o00000onV`^d2
o`0000;oY/;]0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]1?l00003ogc9o`07o`000?nc^=co
/kSLo`000?n[_>Ko0000okflf007o`0000;o/[cQ0_l00003ok6df`03ok2af?l0003o[[3I00;o[[3I
00?o[[3Jo`000?nZ[m/00onZ[m/8o`0000?oYK[Y0_l00003oicCn`;o0000Z?oonfX00ol0003ooo]Z
oookJP09oookJP03o`000?oonf[ooo]Z02kooo]Z00?o0000oookJ_oonfX0JooonfX00ol0003ooo]Z
oookJP3ooookJRWooo]Z1?l0000foookJP00G?oonfX00ol0003ooo]ZoookJP1VoookJP;o00000onV
`^d2o`0000;oY/;]0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00002ojK2k@;o00000onV
`^d2o`000004ojK2kOl0003o0000obb[j@;o00001?n[_>H01?l0003o]KKIokFffOl00002ojfihP03
o`000?nb_>7o000000Wo000000?o[[3Io`000?l000001Ol00002oj^dg`03o`000?nW/^3oY[gZ00;o
Y[gZ0_l00003oik@n@;o000000?oLmo/oookJ_oonfX0Z_oonfX00ol0003ooo]ZoookJP08oookJP03
o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX0J_oonfX00ol0003ooo]ZoookJP3ooookJRGo
oo]Z1?l0000joookJP00GOoonfX2o`0006Oooo]Z0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]
0_l00002ojK2k@;o00000onV`^d2o`0000;oY/;]0_l00003ojK2k@;o00001?oonfX00olo003o0000
o`000004ogG;o`03o`000?n]^N;o[KWR00;o[KWR00Oo0000ok6cf_na/m[o0000ojVmj?l0003o/;3H
00;o00000_n[^nD2o`0000CoZKcW0_l00003ojG3k`;o00000on?eol2o`000003oeG@g_oonf[ooo]Z
0:oooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP0`oookJP;o0000J_oonfX00ol0
003ooo]ZoookJP3ooookJR7ooo]Z1?l0000noookJP00GooonfX00ol0003ooo]ZoookJP1UoookJP;o
00000onV`^d2o`0000;oY/;]0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l00002ojK2k@;o
00003OoonfX00olZZ>_o0975o`000002o`0000?oN/ko00?o0000ojVmj?nY_NP00_nY_NP00ol0003o
Zk_Uoj^ki@03ogSAo`?o00000omjdol2o`0000?oL]Kk00?o0000oegCjOmMdnT0]_oonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0I_oonfX00ol0003o
oo]ZoookJP3ooookJQkooo]Z1?l00012oookJP00H?oonfX00ol0003ooo]ZoookJP1UoookJP;o0000
0onU`^h2o`0000;oY/;]0_l00003ojK2k@;o00000_nV`^d2o`0000?oY/;]0_l0000HoookJP03oaNR
fOl0003o000000_o000000?oN]?oo`000?ma00<0_ooonfX00ol0003ooo]ZoookJP05oookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP3ooookJQ_ooo]Z
0ol00016oookJP00HOoonfX2o`0006Kooo]Z0_l00003ojG2kP;o00000_nV`^h2o`0000?oY/;^0_l0
0002ojK2k@;o0000k?oonfX00ol0003ooo]ZoookJP05oookJP03o`000?oonf[ooo]Z03Cooo]Z0_l0
001UoookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX4o`0004Wooo]Z001SoookJP03o`000?oonf[o
oo]Z06Cooo]Z0_l00003ojG2kP;o00000_nU`^h2o`0000?oY/;^0_l0003`oookJP03o`000?oonf[o
oo]Z00Cooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1RoookJP03o`000?oonf[o
oo]Z0?oooo]Z4ooonfX4o`0004gooo]Z001ToookJP;o0000IOoonfX2o`0000?oYL;^0ol0003hoook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP1Qoook
JP03o`000?oonf[ooo]Z0?oooo]Z3ooonfX4o`00057ooo]Z001VoookJP03o`000?oonf[ooo]Z06?o
oo]Z0ol0003moookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0=ooonfX2o`00067o
oo]Z00?o0000oookJ_oonfX0oooonfX;oookJPCo0000EOoonfX006Oooo]Z00?o0000oookJ_oonfX0
HOoonfX00ol0003ooo]ZoookJP3noookJP03o`000?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX0
>OoonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z0?oooo]Z1ooonfX4o`0005Wooo]Z
001XoookJP;o0000HOoonfX00ol0003ooo]ZoookJP3ooookJP03o`000?oonf[ooo]Z00;ooo]Z00?o
0000oookJ_oonfX0>_oonfX00ol0003ooo]ZoookJP1MoookJP03o`000?oonf[ooo]Z0?oooo]Z0ooo
nfX4o`0005gooo]Z001ZoookJP03o`000?oonf[ooo]Z05kooo]Z00?o0000oookJ_oonfX0oooonfX1
oookJP05o`000?oonf[ooo]ZoookJ_l00000?OoonfX2o`0005gooo]Z00?o0000oookJ_oonfX0o_oo
nfX4o`00067ooo]Z001[oookJP03o`000?oonf[ooo]Z05gooo]Z00?o0000oookJ_oonfX0oooonfX2
oookJP04o`000?oonf[ooo]Zo`0003oooo]Z00?o0000oookJ_oonfX0F_oonfX00ol0003ooo]Zoook
JP3koookJP?o0000IOoonfX006cooo]Z0_l0001MoookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX0
0ol0003ooo]Zo`000010oookJP03o`000?oonf[ooo]Z05Wooo]Z00?o0000oookJ_oonfX0mooonfX4
o`0006Sooo]Z001^oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0oooonfX3oook
JP04o`000?oonf[ooo]Zo`00043ooo]Z0_l0001IoookJP03o`000?oonf[ooo]Z0??ooo]Z1?l0001/
oookJP00KooonfX00ol0003ooo]ZoookJP1IoookJP03o`000?oonf[ooo]Z0?oooo]Z1?oonfX00ol0
003ooo]Zo`000012oookJP03o`000?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0kooonfX4o`00
073ooo]Z001`oookJP;o0000FOoonfX00ol0003ooo]ZoookJP3ooookJPGooo]Z0_l00013oookJP03
o`000?oonf[ooo]Z05Gooo]Z00?o0000oookJ_oonfX0jooonfX4o`0007Cooo]Z001boookJP03o`00
0?oonf[ooo]Z05Kooo]Z00?o0000oookJ_oonfX0oooonfX4oookJP?o0000A?oonfX2o`0005Gooo]Z
00?o0000oookJ_oonfX0iooonfX4o`0007Sooo]Z001coookJP03o`000?oonf[ooo]Z05Gooo]Z00?o
0000oookJ_oonfX0oooonfX4o`0004Wooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]Zoook
JP3SoookJPCo0000O?oonfX007Cooo]Z0_l0001EoookJP03o`000?oonf[ooo]Z0?_ooo]Z1?l0001>
oookJP03o`000?oonf[ooo]Z057ooo]Z00?o0000oookJ_oonfX0gooonfX4o`00083ooo]Z001foook
JP03o`000?oonf[ooo]Z05;ooo]Z00?o0000oookJ_oonfX0mooonfX4o`0005?ooo]Z0_l0001@oook
JP03o`000?oonf[ooo]Z0=gooo]Z0ol00024oookJP00MooonfX00ol0003ooo]ZoookJP1AoookJP03
o`000?oonf[ooo]Z0??ooo]Z1?l0001IoookJP03o`000?oonf[ooo]Z04gooo]Z00?o0000oookJ_oo
nfX0fOoonfX4o`0008Oooo]Z001hoookJP;o0000DOoonfX00ol0003ooo]ZoookJP3^oookJPGo0000
G_oonfX00ol0003ooo]ZoookJP1<oookJP03o`000?oonf[ooo]Z0=Gooo]Z1?l0002;oookJP00N_oo
nfX00ol0003ooo]ZoookJP1>oookJP03o`000?oonf[ooo]Z0>[ooo]Z1?l0001ToookJP;o0000C?oo
nfX00ol0003ooo]ZoookJP3AoookJPCo0000SooonfX007_ooo]Z00?o0000oookJ_oonfX0COoonfX0
0ol0003ooo]ZoookJP3VoookJPCo0000J_oonfX00ol0003ooo]ZoookJP19oookJP03o`000?oonf[o
oo]Z0<gooo]Z1?l0002CoookJP00O?oonfX2o`0004gooo]Z00?o0000oookJ_oonfX0h_oonfX4o`00
06oooo]Z00?o0000oookJ_oonfX0B?oonfX00ol0003ooo]ZoookJP39oookJPCo0000UooonfX007ko
oo]Z00?o0000oookJ_oonfX0B_oonfX00ol0003ooo]ZoookJP3NoookJPCo0000M?oonfX2o`0004So
oo]Z00?o0000oookJ_oonfX0aOoonfX4o`0009_ooo]Z001ooookJP;o0000B_oonfX00ol0003ooo]Z
oookJP3JoookJPCo0000N_oonfX00ol0003ooo]ZoookJP15oookJP03o`000?oonf[ooo]Z0<7ooo]Z
1?l0002OoookJP00POoonfX00ol0003ooo]ZoookJP17oookJP03o`000?oonf[ooo]Z0=Kooo]Z1?l0
001ooookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0__oonfX3o`000:?ooo]Z0022
oookJP03o`000?oonf[ooo]Z04Kooo]Z00?o0000oookJ_oonfX0d_oonfX4o`0008Cooo]Z0_l00014
oookJP03o`000?oonf[ooo]Z0;[ooo]Z1?l0002VoookJP00PooonfX2o`0004Kooo]Z00?o0000oook
J_oonfX0c_oonfX4o`0008[ooo]Z00?o0000oookJ_oonfX0@OoonfX00ol0003ooo]ZoookJP2foook
JPCo0000Z_oonfX008Gooo]Z00?o0000oookJ_oonfX0@ooonfX00ol0003ooo]ZoookJP3:oookJPCo
0000SooonfX00ol0003ooo]ZoookJP10oookJP03o`000?oonf[ooo]Z0;;ooo]Z1?l0002^oookJP00
Q_oonfX00ol0003ooo]ZoookJP12oookJP03o`000?oonf[ooo]Z0<Kooo]Z1?l0002DoookJP;o0000
@?oonfX00ol0003ooo]ZoookJP2^oookJPCo0000/_oonfX008Oooo]Z0_l00012oookJP03o`000?oo
nf[ooo]Z0<7ooo]Z1Ol0002JoookJP03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX0Z_oo
nfX4o`000;Kooo]Z0029oookJP03o`000?oonf[ooo]Z03oooo]Z00?o0000oookJ_oonfX0_OoonfX4
o`000:3ooo]Z00?o0000oookJ_oonfX0??oonfX00ol0003ooo]ZoookJP2VoookJPCo0000^_oonfX0
08[ooo]Z00?o0000oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP2ioookJPCo0000YOoonfX2o`00
03cooo]Z00?o0000oookJ_oonfX0X_oonfX4o`000;kooo]Z002;oookJP;o0000?_oonfX00ol0003o
oo]ZoookJP2eoookJPCo0000ZooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[ooo]Z09oo
oo]Z0ol00032oookJP00SOoonfX00ol0003ooo]ZoookJP0koookJP03o`000?oonf[ooo]Z0;7ooo]Z
1?l0002`oookJP03o`000?oonf[ooo]Z03Oooo]Z00?o0000oookJ_oonfX0W?oonfX4o`000<Gooo]Z
002>oookJP03o`000?oonf[ooo]Z03[ooo]Z00?o0000oookJ_oonfX0[OoonfX4o`000;Gooo]Z0_l0
000goookJP03o`000?oonf[ooo]Z09Sooo]Z1?l00039oookJP00SooonfX2o`0003Wooo]Z00?o0000
oookJ_oonfX0Z_oonfX4o`000;_ooo]Z00?o0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP2D
oookJPCo0000cOoonfX0097ooo]Z00?o0000oookJ_oonfX0=_oonfX00ol0003ooo]ZoookJP2Voook
JPCo0000`?oonfX2o`0003Cooo]Z00?o0000oookJ_oonfX0T?oonfX4o`000=7ooo]Z002BoookJP03
o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0X_oonfX4o`000<Kooo]Z00?o0000oookJ_oo
nfX0<OoonfX00ol0003ooo]ZoookJP2<oookJPCo0000eOoonfX009?ooo]Z0_l0000eoookJP03o`00
0?oonf[ooo]Z09kooo]Z1?l0003;oookJP03o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX0
R?oonfX4o`000=Wooo]Z002EoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX0V_oo
nfX4o`000=3ooo]Z0_l0000`oookJP03o`000?oonf[ooo]Z08Gooo]Z0ol0003MoookJP00U_oonfX0
0ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z09Gooo]Z1Ol0003FoookJP03o`000?oonf[o
oo]Z02gooo]Z00?o0000oookJ_oonfX0POoonfX4o`000>3ooo]Z002GoookJP;o0000<OoonfX00ol0
003ooo]ZoookJP2AoookJPCo0000g?oonfX00ol0003ooo]ZoookJP0/oookJP03o`000?oonf[ooo]Z
07gooo]Z1?l0003ToookJP00VOoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z08go
oo]Z1?l0003QoookJP;o0000;?oonfX00ol0003ooo]ZoookJP1ioookJPCo0000j?oonfX009[ooo]Z
00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP29oookJPCo0000iooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z07Gooo]Z1?l0003/oookJP00VooonfX2o`0002gooo]Z00?o
0000oookJ_oonfX0QOoonfX4o`000>cooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]Zoook
JP1aoookJPCo0000l?oonfX009gooo]Z00?o0000oookJ_oonfX0:_oonfX00ol0003ooo]ZoookJP21
oookJPCo0000lOoonfX2o`0002Sooo]Z00?o0000oookJ_oonfX0KOoonfX4o`000?Cooo]Z002Noook
JP;o0000:_oonfX00ol0003ooo]ZoookJP1moookJPCo0000mooonfX00ol0003ooo]ZoookJP0Uoook
JP03o`000?oonf[ooo]Z06Wooo]Z1?l0003hoookJP00X?oonfX00ol0003ooo]ZoookJP0WoookJP03
o`000?oonf[ooo]Z07Wooo]Z1?l0003loookJP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oo
nfX0I_oonfX3o`000?cooo]Z002QoookJP03o`000?oonf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX0
MOoonfX4o`000?oooo]Z0_oonfX2o`0002Cooo]Z00?o0000oookJ_oonfX0H_oonfX4o`000?oooo]Z
002RoookJP;o00009_oonfX00ol0003ooo]ZoookJP1aoookJPCo0000oooonfX8oookJP03o`000?oo
nf[ooo]Z027ooo]Z00?o0000oookJ_oonfX0G_oonfX4o`000?oooo]Z1?oonfX00:Cooo]Z00?o0000
oookJ_oonfX08ooonfX00ol0003ooo]ZoookJP1]oookJPCo0000oooonfX=oookJP03o`000?oonf[o
oo]Z01oooo]Z00?o0000oookJ_oonfX0FooonfX4o`000?oooo]Z2?oonfX00:Gooo]Z00?o0000oook
J_oonfX08_oonfX00ol0003ooo]ZoookJP1XoookJPGo0000oooonfXBoookJP;o00007ooonfX00ol0
003ooo]ZoookJP1GoookJPCo0000oooonfX<oookJP00Y_oonfX2o`0002;ooo]Z00?o0000oookJ_oo
nfX0I?oonfX4o`000?oooo]Z6OoonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z05?o
oo]Z1?l0003ooookJQ3ooo]Z002XoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
H?oonfX4o`000?oooo]Z7_oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z04oooo]Z
1?l0003ooookJQCooo]Z002YoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0G?oo
nfX4o`000?oooo]Z8ooonfX2o`0001_ooo]Z00?o0000oookJ_oonfX0BooonfX4o`000?oooo]Z6?oo
nfX00:[ooo]Z0_l0000NoookJP03o`000?oonf[ooo]Z05Sooo]Z1?l0003ooookJRWooo]Z00?o0000
oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP18oookJP?o0000oooonfXLoookJP00[?oonfX00ol0
003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z05Cooo]Z1?l0003ooookJRkooo]Z00?o0000oook
J_oonfX05ooonfX00ol0003ooo]ZoookJP14oookJPCo0000oooonfXOoookJP00[OoonfX00ol0003o
oo]ZoookJP0JoookJP03o`000?oonf[ooo]Z053ooo]Z1?l0003ooookJS?ooo]Z0_l0000GoookJP03
o`000?oonf[ooo]Z043ooo]Z1?l0003ooookJR?ooo]Z002^oookJP;o00006_oonfX00ol0003ooo]Z
oookJP1<oookJPCo0000oooonfXioookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
??oonfX4o`000?oooo]Z9ooonfX00;3ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Zoook
JP18oookJPCo0000oooonfXnoookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0>?oo
nfX4o`000?oooo]Z:ooonfX00;7ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003ooo]ZoookJP14
oookJPCo0000oooonfY3oookJP;o00004ooonfX00ol0003ooo]ZoookJP0doookJPCo0000oooonfX_
oookJP00/_oonfX2o`0001Kooo]Z00?o0000oookJ_oonfX0@?oonfX4o`000?oooo]ZBOoonfX00ol0
003ooo]ZoookJP0@oookJP03o`000?oonf[ooo]Z033ooo]Z1?l0003ooookJS?ooo]Z002doookJP03
o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX0>ooonfX5o`000?oooo]ZC_oonfX00ol0003o
oo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02cooo]Z1?l0003ooookJSOooo]Z002eoookJP03o`00
0?oonf[ooo]Z01;ooo]Z00?o0000oookJ_oonfX0=ooonfX4o`000?oooo]ZE?oonfX2o`0000oooo]Z
00?o0000oookJ_oonfX0:OoonfX3o`000?oooo]Z>ooonfX00;Kooo]Z0_l0000AoookJP03o`000?oo
nf[ooo]Z03Cooo]Z1?l0003ooookJU[ooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003ooo]Zoook
JP0UoookJPCo0000oooonfXnoookJP00^?oonfX00ol0003ooo]ZoookJP0>oookJP03o`000?oonf[o
oo]Z033ooo]Z1?l0003ooookJUoooo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0Q
oookJPCo0000oooonfY2oookJP00^OoonfX00ol0003ooo]ZoookJP0=oookJP03o`000?oonf[ooo]Z
02cooo]Z1?l0003ooookJVCooo]Z0_l0000;oookJP03o`000?oonf[ooo]Z01gooo]Z1?l0003ooook
JTKooo]Z002joookJP;o00003OoonfX00ol0003ooo]ZoookJP0XoookJPCo0000oooonfYZoookJP03
o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX06_oonfX4o`000?oooo]ZB_oonfX00;cooo]Z
00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0ToookJPCo0000oooonfY_oookJP03o`00
0?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX05_oonfX4o`000?oooo]ZC_oonfX00;gooo]Z0_l0
000:oookJP03o`000?oonf[ooo]Z023ooo]Z1?l0003ooookJWCooo]Z0_l00006oookJP03o`000?oo
nf[ooo]Z01;ooo]Z1?l0003ooookJU;ooo]Z002ooookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000
oookJ_oonfX07?oonfX4o`000?oooo]ZN_oonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[o
oo]Z00kooo]Z1?l0003ooookJUKooo]Z0030oookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oook
J_oonfX06?oonfX4o`000?oooo]ZOooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z
00_ooo]Z0ol0003ooookJU[ooo]Z0031oookJP;o00001_oonfX00ol0003ooo]ZoookJP0DoookJPCo
0000oooonfZ4oookJP;o00000_oonfX00ol0003ooo]ZoookJP07oookJPCo0000oooonfYMoookJP00
`ooonfX00ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00oooo]Z1Ol0003ooookJX[ooo]Z
00?o0000oookJ_l000001OoonfX4o`000?oooo]ZHOoonfX00<Cooo]Z00?o0000oookJ_oonfX00_oo
nfX00ol0003ooo]ZoookJP0;oookJPCo0000oooonfZ@oookJP;o000000?ooo]Zo`000?l000000_l0
003ooookJVGooo]Z0035oookJP;o00000_oonfX00ol0003ooo]ZoookJP07oookJPCo0000oooonfZE
oookJP;o0000oooonfYYoookJP00aooonfX00ol0003ooo]Zo`000005oookJPCo0000oooonf[ooook
J_oooo]Z1OoonfX00<Sooo]Z0_l000000ooonf[o0000o`000002o`000?oooo]Zoooonf[ooookJPWo
oo]Z0039oookJP;o0000oooonf[ooookJ_oooo]Z3OoonfX00?oooo]Zoooonf[ooookJ]Sooo]Z003o
oookJ_oooo]Zoooonf[HoookJP00oooonf[ooookJ_oooo]Zf?oonfX00?oooo]Zoooonf[ooookJ]So
oo]Z003ooookJ_oooo]Zoooonf[HoookJP00oooonf[ooookJ_oooo]Zf?oonfX00?oooo]Zoooonf[o
oookJ]Sooo]Z003ooookJ_oooo]Zoooonf[HoookJP00oooonf[ooookJ_oooo]Zf?oonfX00?oooo]Z
oooonf[ooookJ]Sooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 980.438}, {460.312, 0}} -> {-0.0511801, -0.0235056, \
0.00214431, 0.00214431}, {{23.8125, 468}, {449.312, 10.9375}} -> {-0.0366616, \
-0.0229436, 0.00208536, 0.00208536}, {{512.375, 956.562}, {449.312, 10.9375}} -> \
{-1.12632, -0.0303476, 0.00221742, 0.00221742}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{4, 1920}, {0, 1178}},
WindowSize->{1282, 1152},
WindowMargins->{{75, Automatic}, {Automatic, 0}},
WindowTitle->"Lecture 26 MIT 3.016 (Fall 2005)   \[Copyright] W. Craig Carter \
2003-2005",
StyleDefinitions -> "3016_Carter.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "mmtag:26:special_functions"->{
    Cell[1754, 51, 113, 1, 64, "Title",
      CellTags->"mmtag:26:special_functions"]},
  "mmtag:26:Bessels_ODE"->{
    Cell[1950, 58, 75, 1, 65, "Subsection",
      CellTags->"mmtag:26:Bessels_ODE"]},
  "mmtag:26:Bessels_function"->{
    Cell[3586, 119, 151, 3, 50, "Input",
      CellTags->{
      "mmtag:26:Bessels_function", "mmtag:26:BesselJ[]", 
        "mmtag:26:BesselY[]"}],
    Cell[3740, 124, 201, 4, 68, "Output",
      CellTags->{
      "mmtag:26:Bessels_function", "mmtag:26:BesselJ[]", 
        "mmtag:26:BesselY[]"}]},
  "mmtag:26:BesselJ[]"->{
    Cell[3586, 119, 151, 3, 50, "Input",
      CellTags->{
      "mmtag:26:Bessels_function", "mmtag:26:BesselJ[]", 
        "mmtag:26:BesselY[]"}],
    Cell[3740, 124, 201, 4, 68, "Output",
      CellTags->{
      "mmtag:26:Bessels_function", "mmtag:26:BesselJ[]", 
        "mmtag:26:BesselY[]"}]},
  "mmtag:26:BesselY[]"->{
    Cell[3586, 119, 151, 3, 50, "Input",
      CellTags->{
      "mmtag:26:Bessels_function", "mmtag:26:BesselJ[]", 
        "mmtag:26:BesselY[]"}],
    Cell[3740, 124, 201, 4, 68, "Output",
      CellTags->{
      "mmtag:26:Bessels_function", "mmtag:26:BesselJ[]", 
        "mmtag:26:BesselY[]"}]},
  "mmtag:26:MyPlotStyle[]__example_graphics_option_function"->{
    Cell[4291, 147, 221, 4, 50, "Input",
      CellTags->"mmtag:26:MyPlotStyle[]__example_graphics_option_function"]},
  "mmtag:26:Bessels_function__visualizing"->{
    Cell[4537, 155, 180, 3, 50, "Input",
      CellTags->"mmtag:26:Bessels_function__visualizing"],
    Cell[4720, 160, 48558, 1250, 364, 16101, 844, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"mmtag:26:Bessels_function__visualizing"],
    Cell[53281, 1412, 184, 4, 68, "Output",
      CellTags->"mmtag:26:Bessels_function__visualizing"]},
  "mmtag:26:steady_state_diffusion_in_cylinder"->{
    Cell[146272, 3990, 3094, 84, 231, "Text",
      CellTags->{
      "mmtag:26:steady_state_diffusion_in_cylinder", 
        "mmtag:26:cyliner__steady_state_diffusion"}]},
  "mmtag:26:cyliner__steady_state_diffusion"->{
    Cell[146272, 3990, 3094, 84, 231, "Text",
      CellTags->{
      "mmtag:26:steady_state_diffusion_in_cylinder", 
        "mmtag:26:cyliner__steady_state_diffusion"}]},
  "mmtag:26:Legendre_ODE"->{
    Cell[149415, 4080, 78, 1, 65, "Subsection",
      CellTags->"mmtag:26:Legendre_ODE"]},
  "mmtag:26:LegendreP[]"->{
    Cell[151055, 4140, 125, 2, 50, "Input",
      CellTags->{"mmtag:26:LegendreP[]", "mmtag:26:LegendreQ[]"}],
    Cell[151183, 4144, 169, 3, 68, "Output",
      CellTags->{"mmtag:26:LegendreP[]", "mmtag:26:LegendreQ[]"}]},
  "mmtag:26:LegendreQ[]"->{
    Cell[151055, 4140, 125, 2, 50, "Input",
      CellTags->{"mmtag:26:LegendreP[]", "mmtag:26:LegendreQ[]"}],
    Cell[151183, 4144, 169, 3, 68, "Output",
      CellTags->{"mmtag:26:LegendreP[]", "mmtag:26:LegendreQ[]"}]},
  "mmtag:26:HypergeometricU[]"->{
    Cell[516242, 13768, 275, 5, 43, "Subsubsection",
      CellTags->{"mmtag:26:HypergeometricU[]", "mmtag:26:LaguerreL[]"}],
    Cell[516520, 13775, 133, 1, 48, "Subtitle",
      CellTags->{"mmtag:26:HypergeometricU[]", "mmtag:26:LaguerreL[]"}]},
  "mmtag:26:LaguerreL[]"->{
    Cell[516242, 13768, 275, 5, 43, "Subsubsection",
      CellTags->{"mmtag:26:HypergeometricU[]", "mmtag:26:LaguerreL[]"}],
    Cell[516520, 13775, 133, 1, 48, "Subtitle",
      CellTags->{"mmtag:26:HypergeometricU[]", "mmtag:26:LaguerreL[]"}]},
  "mmtag:26:hydrogen_atom__visualizatio_of_orbitals"->{
    Cell[550803, 14639, 208, 4, 80, "Subtitle",
      CellTags->"mmtag:26:hydrogen_atom__visualizatio_of_orbitals"]},
  "mmtag:26:SphericalHarmonicYJ[]"->{
    Cell[552552, 14686, 207, 3, 50, "Input",
      CellTags->"mmtag:26:SphericalHarmonicYJ[]"]},
  "mmtag:26:ContourPlot3D[]__example_of_hydrogen_orbitals"->{
    Cell[554322, 14756, 314, 6, 67, "Input",
      CellTags->"mmtag:26:ContourPlot3D[]__example_of_hydrogen_orbitals"],
    Cell[554639, 14764, 771677, 32185, 379, 564495, 29623, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"mmtag:26:ContourPlot3D[]__example_of_hydrogen_orbitals"],
    Cell[1326319, 46951, 202, 4, 68, "Output",
      CellTags->"mmtag:26:ContourPlot3D[]__example_of_hydrogen_orbitals"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"mmtag:26:special_functions", 19199237, 883180},
  {"mmtag:26:Bessels_ODE", 19199353, 883183},
  {"mmtag:26:Bessels_function", 19199472, 883186},
  {"mmtag:26:BesselJ[]", 19199798, 883195},
  {"mmtag:26:BesselY[]", 19200124, 883204},
  {"mmtag:26:MyPlotStyle[]__example_graphics_option_function", 19200488, \
883213},
  {"mmtag:26:Bessels_function__visualizing", 19200653, 883216},
  {"mmtag:26:steady_state_diffusion_in_cylinder", 19201064, 883224},
  {"mmtag:26:cyliner__steady_state_diffusion", 19201285, 883229},
  {"mmtag:26:Legendre_ODE", 19201487, 883234},
  {"mmtag:26:LegendreP[]", 19201606, 883237},
  {"mmtag:26:LegendreQ[]", 19201858, 883242},
  {"mmtag:26:HypergeometricU[]", 19202116, 883247},
  {"mmtag:26:LaguerreL[]", 19202392, 883252},
  {"mmtag:26:hydrogen_atom__visualizatio_of_orbitals", 19202696, 883257},
  {"mmtag:26:SphericalHarmonicYJ[]", 19202852, 883260},
  {"mmtag:26:ContourPlot3D[]__example_of_hydrogen_orbitals", 19203011, \
883263}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 113, 1, 64, "Title",
  CellTags->"mmtag:26:special_functions"],
Cell[1870, 54, 55, 0, 48, "Subtitle"],

Cell[CellGroupData[{
Cell[1950, 58, 75, 1, 65, "Subsection",
  CellTags->"mmtag:26:Bessels_ODE"],

Cell[CellGroupData[{
Cell[2050, 63, 154, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2229, 70, 138, 2, 57, "Input"],
Cell[2370, 74, 435, 11, 73, "Output"]
}, Open  ]],
Cell[2820, 88, 741, 27, 86, "Text"],

Cell[CellGroupData[{
Cell[3586, 119, 151, 3, 50, "Input",
  CellTags->{
  "mmtag:26:Bessels_function", "mmtag:26:BesselJ[]", "mmtag:26:BesselY[]"}],
Cell[3740, 124, 201, 4, 68, "Output",
  CellTags->{
  "mmtag:26:Bessels_function", "mmtag:26:BesselJ[]", "mmtag:26:BesselY[]"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3990, 134, 298, 11, 43, "Subsubsection"],
Cell[4291, 147, 221, 4, 50, "Input",
  CellTags->"mmtag:26:MyPlotStyle[]__example_graphics_option_function"],

Cell[CellGroupData[{
Cell[4537, 155, 180, 3, 50, "Input",
  CellTags->"mmtag:26:Bessels_function__visualizing"],
Cell[4720, 160, 48558, 1250, 364, 16101, 844, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"mmtag:26:Bessels_function__visualizing"],
Cell[53281, 1412, 184, 4, 68, "Output",
  CellTags->"mmtag:26:Bessels_function__visualizing"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53502, 1421, 126, 2, 50, "Input"],
Cell[53631, 1425, 37571, 1126, 364, 17080, 868, "GraphicsData", "PostScript", \
"Graphics"],
Cell[91205, 2553, 130, 3, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[91372, 2561, 130, 2, 50, "Input"],
Cell[91505, 2565, 54619, 1417, 364, 18952, 972, "GraphicsData", "PostScript", \
"Graphics"],
Cell[146127, 3984, 130, 3, 68, "Output"]
}, Open  ]],
Cell[146272, 3990, 3094, 84, 231, "Text",
  CellTags->{
  "mmtag:26:steady_state_diffusion_in_cylinder", 
    "mmtag:26:cyliner__steady_state_diffusion"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[149415, 4080, 78, 1, 65, "Subsection",
  CellTags->"mmtag:26:Legendre_ODE"],
Cell[149496, 4083, 651, 20, 86, "Text"],

Cell[CellGroupData[{
Cell[150172, 4107, 154, 3, 57, "Input"],
Cell[150329, 4112, 444, 11, 73, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[150810, 4128, 220, 8, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[151055, 4140, 125, 2, 50, "Input",
  CellTags->{"mmtag:26:LegendreP[]", "mmtag:26:LegendreQ[]"}],
Cell[151183, 4144, 169, 3, 68, "Output",
  CellTags->{"mmtag:26:LegendreP[]", "mmtag:26:LegendreQ[]"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[151401, 4153, 76, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[151502, 4157, 190, 3, 84, "Input"],
Cell[151695, 4162, 471, 11, 102, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[152215, 4179, 85, 1, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[152325, 4184, 74, 1, 50, "Input"],
Cell[152402, 4187, 113, 2, 68, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[152564, 4195, 162, 5, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[152751, 4204, 134, 2, 50, "Input"],
Cell[152888, 4208, 35369, 951, 364, 14517, 689, "GraphicsData", "PostScript", \
"Graphics"],
Cell[188260, 5161, 130, 3, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[188427, 5169, 134, 2, 50, "Input"],
Cell[188564, 5173, 38111, 951, 364, 13262, 640, "GraphicsData", "PostScript", \
"Graphics"],
Cell[226678, 6126, 130, 3, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[226845, 6134, 134, 2, 50, "Input"],
Cell[226982, 6138, 39667, 1085, 364, 16004, 788, "GraphicsData", \
"PostScript", "Graphics"],
Cell[266652, 7225, 130, 3, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[266819, 7233, 143, 2, 50, "Input"],
Cell[266965, 7237, 134887, 3224, 364, 33797, 1971, "GraphicsData", \
"PostScript", "Graphics"],
Cell[401855, 10463, 130, 3, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[402022, 10471, 143, 2, 50, "Input"],
Cell[402168, 10475, 113892, 3282, 364, 39580, 2360, "GraphicsData", \
"PostScript", "Graphics"],
Cell[516063, 13759, 130, 3, 68, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[516242, 13768, 275, 5, 43, "Subsubsection",
  CellTags->{"mmtag:26:HypergeometricU[]", "mmtag:26:LaguerreL[]"}],
Cell[516520, 13775, 133, 1, 48, "Subtitle",
  CellTags->{"mmtag:26:HypergeometricU[]", "mmtag:26:LaguerreL[]"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[516690, 13781, 218, 4, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[516933, 13789, 155, 3, 50, "Input"],
Cell[517091, 13794, 141, 3, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[517269, 13802, 74, 1, 50, "Input"],
Cell[517346, 13805, 33309, 826, 364, 10993, 546, "GraphicsData", \
"PostScript", "Graphics"],
Cell[550658, 14633, 130, 3, 68, "Output"]
}, Open  ]],
Cell[550803, 14639, 208, 4, 80, "Subtitle",
  CellTags->"mmtag:26:hydrogen_atom__visualizatio_of_orbitals"],
Cell[551014, 14645, 44, 0, 46, "Text"],
Cell[551061, 14647, 316, 7, 174, "Text"],
Cell[551380, 14656, 917, 21, 311, "Input"],
Cell[552300, 14679, 249, 5, 66, "Text"],
Cell[552552, 14686, 207, 3, 50, "Input",
  CellTags->"mmtag:26:SphericalHarmonicYJ[]"],
Cell[552762, 14691, 60, 1, 50, "Input"],

Cell[CellGroupData[{
Cell[552847, 14696, 79, 1, 50, "Input"],
Cell[552929, 14699, 118, 2, 110, "Output"]
}, Open  ]],
Cell[553062, 14704, 198, 3, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[553297, 14712, 67, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[553389, 14716, 73, 1, 50, "Input"],
Cell[553465, 14719, 131, 2, 121, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[553633, 14726, 76, 1, 50, "Input"],
Cell[553712, 14729, 107, 2, 68, "Output"]
}, Open  ]],
Cell[553834, 14734, 59, 1, 50, "Input"],

Cell[CellGroupData[{
Cell[553918, 14739, 118, 3, 50, "Input"],
Cell[554039, 14744, 55, 1, 68, "Output"]
}, Open  ]],
Cell[554109, 14748, 188, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[554322, 14756, 314, 6, 67, "Input",
  CellTags->"mmtag:26:ContourPlot3D[]__example_of_hydrogen_orbitals"],
Cell[554639, 14764, 771677, 32185, 379, 564495, 29623, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"mmtag:26:ContourPlot3D[]__example_of_hydrogen_orbitals"],
Cell[1326319, 46951, 202, 4, 68, "Output",
  CellTags->"mmtag:26:ContourPlot3D[]__example_of_hydrogen_orbitals"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1326558, 46960, 62, 1, 50, "Input"],
Cell[1326623, 46963, 44, 1, 94, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1326704, 46969, 124, 3, 50, "Input"],
Cell[1326831, 46974, 177, 3, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1327045, 46982, 270, 5, 67, "Input"],
Cell[1327318, 46989, 2530718, 119890, 388, 2232805, 116208, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3858039, 166881, 132, 3, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3858208, 166889, 280, 5, 67, "Input"],
Cell[3858491, 166896, 2413422, 118328, 388, 2199177, 115678, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6271916, 285226, 132, 3, 68, "Output"]
}, Open  ]],
Cell[6272063, 285232, 92, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[6272180, 285239, 45, 1, 50, "Input"],
Cell[6272228, 285242, 4890373, 237243, 643, 4427190, 231520, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11162604, 522487, 132, 3, 68, "Output"]
}, Open  ]],
Cell[11162751, 522493, 70, 0, 46, "Text"],
Cell[11162824, 522495, 2030, 37, 272, "Input"],
Cell[11164857, 522534, 104, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[11164986, 522541, 67, 1, 50, "Input"],
Cell[11165056, 522544, 528713, 16201, 468, 240117, 12634, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11693772, 538747, 135, 3, 68, "Output"]
}, Open  ]],
Cell[11693922, 538753, 114, 3, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11694073, 538761, 67, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[11694165, 538765, 65, 1, 50, "Input"],
Cell[11694233, 538768, 3375892, 155210, 473, 2841723, 148611, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15070128, 693980, 135, 3, 68, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15070312, 693989, 83, 1, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[15070420, 693994, 71, 1, 50, "Input"],
Cell[15070494, 693997, 676097, 23904, 382, 385920, 20317, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15746594, 717903, 135, 3, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15746766, 717911, 65, 1, 50, "Input"],
Cell[15746834, 717914, 3451489, 165238, 470, 3044890, 160214, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19198326, 883154, 135, 3, 68, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

